import numpy as np

# MERCURY - VSOP87 Series Version E
# BARYCENTRIC DYNAMICAL ECLIPTIC AND EQUINOX J2000
# Rectangular (X,Y,Z) Coordinates in AU (Astronomical Units)

# Series Validity Span: 2000 BC < Date < 6000 AD
# Theoretical accuracy over span: ±1 arc sec

# t = (JD - 2451545) / 365250

# VSOP87 Functions Source Code
# Generated By The VSOP87 Source Code Generator Tool
# (c) Jay Tanner 2018
# Original language: C++
# Ported and pythonized by Marcel Völschow in 2018

# Ref:
# Planetary Theories in Rectangular and Spherical Variables
# VSOP87 Solutions
# Pierre Bretagnon, Gerard Francou
# Journal of Astronomy & Astrophysics
# vol. 202, p309-p315
# 1988




# -------------------------------------------------------------------------------------------------------------
# Main functions
# -------------------------------------------------------------------------------------------------------------

def JD_day(JD):
	a = np.floor(JD+0.5)
	if ( a < 2299161 ):
		c = a+1524
	else:
		b = np.floor((a-1867216.25)/36524.25)
		c = a+b-np.floor(b/4)+1525
	d = np.floor((c-122.1)/365.25)
	e = np.floor(365.25*d)
	f = np.floor((c-e)/30.6001)

	return np.floor(c-e-np.floor(30.6001*f)+(JD+0.5-a))


def JD_month(JD):
	a = np.floor(JD+0.5)
	if ( a < 2299161 ):
		c = a+1524
	else:
		b = np.floor((a-1867216.25)/36524.25)
		c = a+b-np.floor(b/4)+1525
	d = np.floor((c-122.1)/365.25)
	e = np.floor(365.25*d)
	f = np.floor((c-e)/30.6001)

	return	f-1-12*np.floor(f/14)


def JD_year(JD):
	a = np.floor(JD+0.5)
	if ( a < 2299161 ):
		c = a+1524
	else:
		b = np.floor((a-1867216.25)/36524.25)
		c = a+b-np.floor(b/4)+1525
	d = np.floor((c-122.1)/365.25)
	e = np.floor(365.25*d)
	f = np.floor((c-e)/30.6001)
	M = JD_month(JD)

	return d-4715-np.floor((7+M)/10)


def JD_UT(JD):
	return (JD-(np.floor(JD-0.5)+0.5))*24

def Mercury_X (JD):
	t = (JD - 2451545.) / 365250.
	return Mercury_X0(t) + Mercury_X1(t) + Mercury_X2(t) + Mercury_X3(t) + Mercury_X4(t) + Mercury_X5(t)

def Mercury_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Mercury_Y0(t) + Mercury_Y1(t) + Mercury_Y2(t) + Mercury_Y3(t) + Mercury_Y4(t) + Mercury_Y5(t)

def Mercury_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Mercury_Z0(t) + Mercury_Z1(t) + Mercury_Z2(t) + Mercury_Z3(t) + Mercury_Z4(t) + Mercury_Z5(t)

def Venus_X (JD):
	t = (JD - 2451545.) / 365250.
	return Venus_X0(t) + Venus_X1(t) + Venus_X2(t) + Venus_X3(t) + Venus_X4(t) + Venus_X5(t)

def Venus_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Venus_Y0(t) + Venus_Y1(t) + Venus_Y2(t) + Venus_Y3(t) + Venus_Y4(t) + Venus_Y5(t)

def Venus_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Venus_Z0(t) + Venus_Z1(t) + Venus_Z2(t) + Venus_Z3(t) + Venus_Z4(t) + Venus_Z5(t)

def Earth_X (JD):
	t = (JD - 2451545.) / 365250.
	return Earth_X0(t) + Earth_X1(t) + Earth_X2(t) + Earth_X3(t) + Earth_X4(t) + Earth_X5(t)

def Earth_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Earth_Y0(t) + Earth_Y1(t) + Earth_Y2(t) + Earth_Y3(t) + Earth_Y4(t) + Earth_Y5(t)

def Earth_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Earth_Z0(t) + Earth_Z1(t) + Earth_Z2(t) + Earth_Z3(t) + Earth_Z4(t) + Earth_Z5(t)

def Mars_X (JD):
	t = (JD - 2451545.) / 365250.
	return Mars_X0(t) + Mars_X1(t) + Mars_X2(t) + Mars_X3(t) + Mars_X4(t) + Mars_X5(t)

def Mars_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Mars_Y0(t) + Mars_Y1(t) + Mars_Y2(t) + Mars_Y3(t) + Mars_Y4(t) + Mars_Y5(t)

def Mars_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Mars_Z0(t) + Mars_Z1(t) + Mars_Z2(t) + Mars_Z3(t) + Mars_Z4(t) + Mars_Z5(t)

def Jupiter_X (JD):
	t = (JD - 2451545.) / 365250.
	return Jupiter_X0(t) + Jupiter_X1(t) + Jupiter_X2(t) + Jupiter_X3(t) + Jupiter_X4(t) + Jupiter_X5(t)

def Jupiter_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Jupiter_Y0(t) + Jupiter_Y1(t) + Jupiter_Y2(t) + Jupiter_Y3(t) + Jupiter_Y4(t) + Jupiter_Y5(t)

def Jupiter_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Jupiter_Z0(t) + Jupiter_Z1(t) + Jupiter_Z2(t) + Jupiter_Z3(t) + Jupiter_Z4(t) + Jupiter_Z5(t)

def Saturn_X (JD):
	t = (JD - 2451545.) / 365250.
	return Saturn_X0(t) + Saturn_X1(t) + Saturn_X2(t) + Saturn_X3(t) + Saturn_X4(t) + Saturn_X5(t)

def Saturn_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Saturn_Y0(t) + Saturn_Y1(t) + Saturn_Y2(t) + Saturn_Y3(t) + Saturn_Y4(t) + Saturn_Y5(t)

def Saturn_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Saturn_Z0(t) + Saturn_Z1(t) + Saturn_Z2(t) + Saturn_Z3(t) + Saturn_Z4(t) + Saturn_Z5(t)

def Uranus_X (JD):
	t = (JD - 2451545.) / 365250.
	return Uranus_X0(t) + Uranus_X1(t) + Uranus_X2(t) + Uranus_X3(t) + Uranus_X4(t) + Uranus_X5(t)

def Uranus_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Uranus_Y0(t) + Uranus_Y1(t) + Uranus_Y2(t) + Uranus_Y3(t) + Uranus_Y4(t) + Uranus_Y5(t)

def Uranus_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Uranus_Z0(t) + Uranus_Z1(t) + Uranus_Z2(t) + Uranus_Z3(t) + Uranus_Z4(t) + Uranus_Z5(t)

def Neptune_X (JD):
	t = (JD - 2451545.) / 365250.
	return Neptune_X0(t) + Neptune_X1(t) + Neptune_X2(t) + Neptune_X3(t) + Neptune_X4(t) + Neptune_X5(t)

def Neptune_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Neptune_Y0(t) + Neptune_Y1(t) + Neptune_Y2(t) + Neptune_Y3(t) + Neptune_Y4(t) + Neptune_Y5(t)

def Neptune_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Neptune_Z0(t) + Neptune_Z1(t) + Neptune_Z2(t) + Neptune_Z3(t) + Neptune_Z4(t) + Neptune_Z5(t)

def Sun_X (JD):
	t = (JD - 2451545.) / 365250.
	return Sun_X0(t) + Sun_X1(t) + Sun_X2(t) + Sun_X3(t) + Sun_X4(t) + Sun_X5(t)

def Sun_Y (JD):
	t = (JD - 2451545.) / 365250.
	return Sun_Y0(t) + Sun_Y1(t) + Sun_Y2(t) + Sun_Y3(t) + Sun_Y4(t) + Sun_Y5(t)

def Sun_Z (JD):
	t = (JD - 2451545.) / 365250.
	return Sun_Z0(t) + Sun_Z1(t) + Sun_Z2(t) + Sun_Z3(t) + Sun_Z4(t) + Sun_Z5(t)




# -------------------------------------------------------------------------------------------------------------
# Auxiliary functions
# -------------------------------------------------------------------------------------------------------------


def Mercury_X0 (t):

	X0 = 0.
	X0 += 0.37546285495*np.cos(4.39651506942 + 26087.9031415742*t)
	X0 += 0.03825746037*np.cos(1.16485604343 + 52175.8062831484*t)
	X0 -= 0.02596241714
	X0 += 0.00584261236*np.cos(4.21599394757 + 78263.70942472259*t)
	X0 += 0.00495586029*np.cos(3.74115422358 + 529.6909650946*t)
	X0 += 0.00271797490*np.cos(4.01600769847 + 213.299095438*t)
	X0 += 0.00155435621*np.cos(2.17052060921 + 38.1330356378*t)
	X0 += 0.00105716677*np.cos(0.98379033182 + 104351.61256629678*t)
	X0 += 0.00083792888*np.cos(2.33967639910 + 74.7815985673*t)
	X0 += 0.00021011726*np.cos(4.03469353923 + 130439.51570787099*t)
	X0 += 0.00012216168*np.cos(4.05786119279 + 1059.3819301892*t)
	X0 += 0.00007626285*np.cos(3.24347023009 + 426.598190876*t)
	X0 += 0.00004433373*np.cos(0.80236674527 + 156527.41884944518*t)
	X0 += 0.00001941401*np.cos(1.01217625416 + 206.1855484372*t)
	X0 += 0.00001940365*np.cos(4.79909733719 + 149.5631971346*t)
	X0 += 0.00001888858*np.cos(3.89255617078 + 220.4126424388*t)
	X0 += 0.00001434125*np.cos(3.86895692507 + 522.5774180938*t)
	X0 += 0.00001406213*np.cos(0.47615061971 + 536.8045120954*t)
	X0 += 0.00001186821*np.cos(0.77658632871 + 76.2660712756*t)
	X0 += 0.00000974967*np.cos(3.85319674536 + 182615.32199101939*t)
	X0 += 0.00000700327*np.cos(4.45478725367 + 24978.5245894808*t)
	X0 += 0.00000626468*np.cos(1.18563492001 + 27197.2816936676*t)
	X0 += 0.00000813685*np.cos(3.25483611884 + 36.6485629295*t)
	X0 += 0.00000767074*np.cos(4.22743731914 + 39.6175083461*t)
	X0 += 0.00000624812*np.cos(0.27936893005 + 73.297125859*t)
	X0 += 0.00000467479*np.cos(4.35792521143 + 1589.0728952838*t)
	X0 += 0.00000375923*np.cos(5.16022341123 + 7.1135470008*t)
	X0 += 0.00000398749*np.cos(1.86365789543 + 20426.571092422*t)
	X0 += 0.00000315851*np.cos(6.15857821682 + 419.4846438752*t)
	X0 += 0.00000314857*np.cos(2.49951875103 + 639.897286314*t)
	X0 += 0.00000277216*np.cos(3.77909548342 + 31749.2351907264*t)
	X0 += 0.00000278645*np.cos(4.93493981951 + 110.2063212194*t)
	X0 += 0.00000276845*np.cos(4.89238788428 + 6283.0758499914*t)
	X0 += 0.00000190657*np.cos(4.27201801941 + 53285.1848352418*t)
	X0 += 0.00000226936*np.cos(5.27772010421 + 103.0927742186*t)
	X0 += 0.00000216130*np.cos(5.80363672433 + 316.3918696566*t)
	X0 += 0.00000181790*np.cos(4.94857138217 + 1109.3785520934*t)
	X0 += 0.00000194418*np.cos(0.67806013045 + 4551.9534970588*t)
	X0 += 0.00000221028*np.cos(0.62082250658 + 208703.22513259358*t)
	X0 += 0.00000190713*np.cos(1.17385212686 + 5661.3320491522*t)
	X0 += 0.00000138492*np.cos(1.22446421973 + 51066.427731055*t)
	X0 += 0.00000151693*np.cos(2.67604566886 + 51116.4243529592*t)
	X0 += 0.00000135803*np.cos(2.00186470730 + 1.4844727083*t)
	X0 += 0.00000116610*np.cos(2.42632951225 + 632.7837393132*t)
	X0 += 0.00000106112*np.cos(3.12532830282 + 433.7117378768*t)
	X0 += 0.00000100462*np.cos(3.02865667414 + 1052.2683831884*t)
	X0 += 0.00000114338*np.cos(0.56002737806 + 57837.1383323006*t)
	X0 += 0.00000109057*np.cos(3.15530148270 + 1162.4747044078*t)
	X0 += 0.00000075179*np.cos(6.06954012703 + 27147.28507176339*t)
	X0 += 0.00000074528*np.cos(4.92454709213 + 46514.4742339962*t)
	X0 += 0.00000070803*np.cos(0.79035955122 + 1066.49547719*t)
	X0 += 0.00000093010*np.cos(0.02433900731 + 10213.285546211*t)
	X0 += 0.00000068378*np.cos(0.19832816518 + 25132.3033999656*t)
	X0 += 0.00000065034*np.cos(4.90982770245 + 21535.9496445154*t)
	X0 += 0.00000057815*np.cos(5.70200416012 + 14765.2390432698*t)
	X0 += 0.00000058577*np.cos(5.41671940122 + 27043.5028831828*t)
	X0 += 0.00000056837*np.cos(1.32380222396 + 949.1756089698*t)
	X0 += 0.00000060503*np.cos(4.99652964522 + 47623.8527860896*t)
	X0 += 0.00000052662*np.cos(2.29801650543 + 26617.5941066688*t)
	X0 += 0.00000066085*np.cos(0.27580418539 + 846.0828347512*t)
	X0 += 0.00000057105*np.cos(5.28946104639 + 12566.1516999828*t)
	X0 += 0.00000063197*np.cos(5.79375225998 + 148.0787244263*t)
	X0 += 0.00000063056*np.cos(0.73665975080 + 224.3447957019*t)
	X0 += 0.00000047830*np.cos(1.04296800531 + 79373.08797681599*t)
	X0 += 0.00000051287*np.cos(3.67162149494 + 234791.12827416777*t)
	X0 += 0.00000048308*np.cos(3.65259825204 + 25558.2121764796*t)
	X0 += 0.00000048571*np.cos(5.72915514275 + 77204.32749453338*t)
	X0 += 0.00000048172*np.cos(3.06679584815 + 3340.6124266998*t)
	X0 += 0.00000034348*np.cos(5.67940957102 + 51646.11531805379*t)
	X0 += 0.00000032947*np.cos(2.99496495895 + 955.5997416086*t)
	X0 += 0.00000044563*np.cos(2.47566796995 + 41962.5207369374*t)
	X0 += 0.00000037824*np.cos(4.58891701161 + 35.1640902212*t)
	X0 += 0.00000031150*np.cos(1.37429681895 + 63.7358983034*t)
	X0 += 0.00000028371*np.cos(0.70323037778 + 30639.856638633*t)
	X0 += 0.00000030669*np.cos(4.22235088222 + 11.0457002639*t)
	X0 += 0.00000031389*np.cos(4.27598213407 + 77154.33087262919*t)
	X0 += 0.00000027626*np.cos(6.14846127958 + 37410.5672398786*t)
	X0 += 0.00000031953*np.cos(3.61313384181 + 83925.04147387479*t)
	X0 += 0.00000028737*np.cos(3.71532292172 + 151.0476698429*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000027138*np.cos(0.33631401741 + 39609.6545831656*t)
	X0 += 0.00000023212*np.cos(2.29683623821 + 53131.406024757*t)
	X0 += 0.00000026667*np.cos(6.25618354827 + 36301.18868778519*t)
	X0 += 0.00000021980*np.cos(4.66869175639 + 2118.7638603784*t)
	X0 += 0.00000025545*np.cos(3.71486034105 + 11322.6640983044*t)
	X0 += 0.00000023782*np.cos(3.76207354349 + 227.5261894396*t)
	X0 += 0.00000023267*np.cos(0.46827104623 + 85.8272988312*t)
	X0 += 0.00000022744*np.cos(1.67012539714 + 71.8126531507*t)
	X0 += 0.00000020743*np.cos(5.68024807830 + 15874.6175953632*t)
	X0 += 0.00000023509*np.cos(3.99714350287 + 13521.7514415914*t)
	X0 += 0.00000022286*np.cos(3.93734569173 + 2.9689454166*t)
	X0 += 0.00000021989*np.cos(0.11301830216 + 77.7505439839*t)
	X0 += 0.00000016406*np.cos(1.69451902864 + 72602.37737557039*t)
	X0 += 0.00000020026*np.cos(4.02923197304 + 209.3669421749*t)
	X0 += 0.00000016077*np.cos(3.22492362452 + 9103.9069941176*t)
	X0 += 0.00000019681*np.cos(0.87544248531 + 217.2312487011*t)
	X0 += 0.00000019072*np.cos(5.91967226872 + 202.2533951741*t)
	X0 += 0.00000016554*np.cos(2.54975052084 + 735.8765135318*t)
	X0 += 0.00000015716*np.cos(5.27155686277 + 742.9900605326*t)
	X0 += 0.00000021076*np.cos(1.76532979749 + 73711.75592766379*t)
	X0 += 0.00000015060*np.cos(2.81388532705 + 18849.2275499742*t)
	X0 += 0.00000018273*np.cos(3.06935035992 + 323.5054166574*t)
	X0 += 0.00000017360*np.cos(3.01137661271 + 138.5174968707*t)
	X0 += 0.00000017093*np.cos(2.11618772835 + 51749.20809227239*t)
	X0 += 0.00000015488*np.cos(4.00542220967 + 515.463871093*t)
	X0 += 0.00000015401*np.cos(0.38409642418 + 7238.67559160*t)
	X0 += 0.00000013833*np.cos(2.86060252439 + 53235.18821333759*t)
	X0 += 0.00000016621*np.cos(2.16299341033 + 50586.73338786459*t)
	X0 += 0.00000016955*np.cos(1.83475003851 + 853.196381752*t)
	X0 += 0.00000013461*np.cos(5.21674902395 + 52705.49724824299*t)
	X0 += 0.00000013312*np.cos(5.80885733761 + 25028.521211385*t)
	X0 += 0.00000013751*np.cos(3.01700253042 + 63498.47038145279*t)
	X0 += 0.00000012986*np.cos(3.87848079183 + 26107.57290247399*t)
	X0 += 0.00000013012*np.cos(1.77284954668 + 26068.2333806744*t)
	X0 += 0.00000013561*np.cos(3.25355689343 + 51220.20654153979*t)
	X0 += 0.00000013481*np.cos(2.49743950723 + 103292.23063610759*t)
	X0 += 0.00000012122*np.cos(0.43923849384 + 260879.03141574195*t)
	X0 += 0.00000011390*np.cos(1.97720953024 + 19317.1925403286*t)
	X0 += 0.00000011231*np.cos(1.18032609366 + 199.0720014364*t)
	X0 += 0.00000010112*np.cos(2.38879888058 + 77734.01845962799*t)
	X0 += 0.00000011952*np.cos(5.53005209823 + 68050.42387851159*t)
	X0 += 0.00000012080*np.cos(4.09566440961 + 105460.99111839019*t)
	X0 += 0.00000010836*np.cos(0.34185057335 + 543.9180590962*t)
	X0 += 0.00000011585*np.cos(0.61081760500 + 525.7588118315*t)
	X0 += 0.00000011447*np.cos(3.72704255770 + 533.6231183577*t)
	X0 += 0.00000009187*np.cos(2.47899096314 + 40853.142184844*t)
	X0 += 0.00000009526*np.cos(2.10685579050 + 38654.05484155699*t)
	X0 += 0.00000012384*np.cos(3.88491364454 + 45892.73043315699*t)
	X0 += 0.00000008930*np.cos(0.47010685402 + 26084.0218062162*t)
	X0 += 0.00000008927*np.cos(5.18134720032 + 26091.7844769322*t)
	X0 += 0.00000012067*np.cos(3.39979120537 + 65697.55772473979*t)
	X0 += 0.00000008856*np.cos(0.33573269125 + 26514.5013324502*t)
	X0 += 0.00000008880*np.cos(0.74693819701 + 3442.5749449654*t)
	X0 += 0.00000008473*np.cos(0.38165820380 + 110012.94461544899*t)
	X0 += 0.00000008573*np.cos(3.46685189655 + 1692.1656695024*t)
	X0 += 0.00000008768*np.cos(4.86692437236 + 32370.9789915656*t)
	X0 += 0.00000007627*np.cos(3.72724507066 + 56727.7597802072*t)
	X0 += 0.00000008150*np.cos(0.32531424488 + 27676.976036858*t)
	X0 += 0.00000007854*np.cos(2.40990683887 + 1478.8665740644*t)
	X0 += 0.00000007210*np.cos(1.15776232612 + 6770.7106012456*t)
	X0 += 0.00000007185*np.cos(3.51955509534 + 216.4804891757*t)
	X0 += 0.00000007015*np.cos(1.38855213071 + 210.1177017003*t)
	X0 += 0.00000007114*np.cos(2.46075736232 + 415.5524906121*t)
	X0 += 0.00000007049*np.cos(2.53147779108 + 33326.5787331742*t)
	X0 += 0.00000006865*np.cos(4.39764457707 + 117.3198682202*t)
	X0 += 0.00000007200*np.cos(4.03820346831 + 1265.5674786264*t)
	X0 += 0.00000006909*np.cos(2.82613157893 + 956.2891559706*t)
	X0 += 0.00000007466*np.cos(5.01523559500 + 14.2270940016*t)
	X0 += 0.00000007695*np.cos(3.23922848464 + 1581.959348283*t)
	X0 += 0.00000006725*np.cos(2.38169410823 + 647.0108333148*t)
	X0 += 0.00000007373*np.cos(4.54270714371 + 23869.1460373874*t)
	X0 += 0.00000005950*np.cos(5.34652499897 + 79219.30916633119*t)
	X0 += 0.00000007534*np.cos(1.04407773149 + 103242.23401420339*t)
	X0 += 0.00000005961*np.cos(3.04054522257 + 62389.09182935939*t)
	X0 += 0.00000006001*np.cos(5.97534098237 + 59414.4818747484*t)
	X0 += 0.00000006074*np.cos(3.52491992077 + 32858.61374281979*t)
	X0 += 0.00000006397*np.cos(5.30170474809 + 95.9792272178*t)
	X0 += 0.00000005423*np.cos(2.27094643224 + 43071.8992890308*t)
	X0 += 0.00000005824*np.cos(0.72194174801 + 19804.8272915828*t)
	X0 += 0.00000006244*np.cos(5.44473078234 + 70.8494453042*t)
	X0 += 0.00000005074*np.cos(4.24610777191 + 526.5095713569*t)
	X0 += 0.00000006044*np.cos(4.81765546230 + 99799.65906923798*t)
	X0 += 0.00000004978*np.cos(0.09070559075 + 532.8723588323*t)
	X0 += 0.00000006266*np.cos(5.22643441280 + 25874.6040461362*t)
	X0 += 0.00000005875*np.cos(2.36907113150 + 78.7137518304*t)
	X0 += 0.00000005832*np.cos(1.07051866290 + 28306.66024576099*t)
	X0 += 0.00000006109*np.cos(5.67990095410 + 111.4301614968*t)
	X0 += 0.00000005003*np.cos(0.33033193603 + 26301.2022370122*t)
	X0 += 0.00000005657*np.cos(4.82919740832 + 22645.32819660879*t)
	X0 += 0.00000004603*np.cos(4.10818821236 + 26095.016688575*t)
	X0 += 0.00000004092*np.cos(0.55410491255 + 58946.51688439399*t)
	X0 += 0.00000004460*np.cos(0.56879234991 + 1375.7737998458*t)
	X0 += 0.00000005440*np.cos(5.17874103610 + 76674.63652943878*t)
	X0 += 0.00000004418*np.cos(1.60012301239 + 26080.78959457339*t)
	X0 += 0.00000004023*np.cos(1.08659411853 + 1596.1864422846*t)
	X0 += 0.00000003888*np.cos(4.74721605492 + 98690.28051714458*t)
	X0 += 0.00000004739*np.cos(4.78393991380 + 114.3991069134*t)
	X0 += 0.00000005320*np.cos(5.16942669114 + 77837.11123384659*t)
	X0 += 0.00000005183*np.cos(1.85968638934 + 222.8603229936*t)
	X0 += 0.00000004288*np.cos(1.51938558324 + 277.0349937414*t)
	X0 += 0.00000004598*np.cos(0.76405567220 + 146.594251718*t)
	X0 += 0.00000003619*np.cos(5.54847850901 + 129380.13377768178*t)
	X0 += 0.00000003309*np.cos(1.95062167120 + 78793.40038981718*t)
	X0 += 0.00000003903*np.cos(0.75356452005 + 29530.4780865396*t)
	X0 += 0.00000003055*np.cos(5.92110388322 + 79323.09135491178*t)
	X0 += 0.00000003593*np.cos(0.17002529302 + 91785.46086631398*t)
	X0 += 0.00000003054*np.cos(5.55498513785 + 69159.80243060499*t)
	X0 += 0.00000003082*np.cos(2.29839877933 + 94138.32702008578*t)
	X0 += 0.00000003462*np.cos(0.65717640120 + 71980.63357473118*t)
	X0 += 0.00000002908*np.cos(3.48998577457 + 286966.93455731616*t)
	X0 += 0.00000003697*np.cos(6.07251486266 + 89586.37352302698*t)
	X0 += 0.00000003754*np.cos(1.04640420137 + 490.3340891794*t)
	X0 += 0.00000002722*np.cos(5.88257146743 + 44937.1306915484*t)
	X0 += 0.00000002714*np.cos(5.41990364356 + 103821.92160120218*t)
	X0 += 0.00000003249*np.cos(0.27004450324 + 16983.9961474566*t)
	X0 += 0.00000003195*np.cos(4.87662483707 + 2218.7571041868*t)
	X0 += 0.00000002650*np.cos(4.82437940961 + 52156.1365222486*t)
	X0 += 0.00000002821*np.cos(3.44307787269 + 299.1263942692*t)
	X0 += 0.00000003239*np.cos(2.70670864860 + 25934.1243310894*t)
	X0 += 0.00000003208*np.cos(2.94509218256 + 26241.681952059*t)
	X0 += 0.00000003418*np.cos(2.52366884638 + 351.8165923087*t)
	X0 += 0.00000002655*np.cos(2.90453219642 + 625.6701923124*t)
	X0 += 0.00000003077*np.cos(0.02256903738 + 77308.10968311399*t)
	X0 += 0.00000002481*np.cos(5.31236272529 + 24498.8302462904*t)
	X0 += 0.00000003094*np.cos(0.86497244960 + 131548.89425996438*t)
	X0 += 0.00000002982*np.cos(0.59289983624 + 109.9456887885*t)
	X0 += 0.00000002670*np.cos(0.64762614763 + 52195.47604404819*t)
	X0 += 0.00000002225*np.cos(3.43314585329 + 136100.84775702319*t)
	X0 += 0.00000002352*np.cos(2.71420212859 + 6681.2248533996*t)
	X0 += 0.00000001969*np.cos(5.16585183325 + 64741.95798313119*t)
	X0 += 0.00000002412*np.cos(4.23189156828 + 54394.56338733519*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000001942*np.cos(1.68431166303 + 58458.88213313979*t)
	X0 += 0.00000002561*np.cos(0.03725644332 + 1169.5882514086*t)
	X0 += 0.00000001869*np.cos(0.48618542978 + 82815.66292178139*t)
	X0 += 0.00000001825*np.cos(1.94930670328 + 52179.6876185064*t)
	X0 += 0.00000001832*np.cos(5.52981828535 + 66941.04532641819*t)
	X0 += 0.00000002311*np.cos(2.79299718787 + 1045.1548361876*t)
	X0 += 0.00000001778*np.cos(1.93899005409 + 25619.9381512198*t)
	X0 += 0.00000001820*np.cos(3.52168197550 + 52171.9249477904*t)
	X0 += 0.00000002115*np.cos(2.90697905251 + 51535.90899683439*t)
	X0 += 0.00000001965*np.cos(5.03484402548 + 45405.0956819028*t)
	X0 += 0.00000001705*np.cos(3.71423083400 + 26555.8681319286*t)
	X0 += 0.00000001639*np.cos(3.39953737033 + 52602.4044740244*t)
	X0 += 0.00000001664*np.cos(3.83119379567 + 5327.4761083828*t)
	X0 += 0.00000001925*np.cos(5.78531479532 + 13655.8604911764*t)
	X0 += 0.00000001946*np.cos(3.29035282124 + 1155.361157407*t)
	X0 += 0.00000001650*np.cos(1.58612017312 + 125887.56221081219*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001656*np.cos(3.01808711333 + 440.8252848776*t)
	X0 += 0.00000001514*np.cos(3.39500148443 + 53764.8791784322*t)
	X0 += 0.00000001866*np.cos(4.09501965735 + 129330.13715577759*t)
	X0 += 0.00000001539*np.cos(5.57331447211 + 65.2203710117*t)
	X0 += 0.00000001627*np.cos(4.79352239798 + 48733.23133818299*t)
	X0 += 0.00000001673*np.cos(4.32252049417 + 52168.69273614759*t)
	X0 += 0.00000001445*np.cos(6.10060041654 + 88476.99497093359*t)
	X0 += 0.00000001433*np.cos(1.48123692595 + 942.062061969*t)
	X0 += 0.00000001539*np.cos(2.12017582322 + 105307.21230790539*t)
	X0 += 0.00000001536*np.cos(1.96319343567 + 102762.53967101299*t)
	X0 += 0.00000001393*np.cos(1.25587354727 + 26081.27458267419*t)
	X0 += 0.00000001393*np.cos(4.39574517890 + 26094.53170047421*t)
	X0 += 0.00000001411*np.cos(1.31309973304 + 49957.0491789616*t)
	X0 += 0.00000001529*np.cos(2.73364151205 + 85502.38501632259*t)
	X0 += 0.00000001247*np.cos(4.05247492508 + 51962.5071877104*t)
	X0 += 0.00000001266*np.cos(6.24072120577 + 35191.8101356918*t)
	X0 += 0.00000001458*np.cos(1.93796370187 + 103925.01437542078*t)
	X0 += 0.00000001390*np.cos(6.12238564495 + 412.3710968744*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001537*np.cos(3.43210104670 + 52389.1053785864*t)
	X0 += 0.00000001483*np.cos(1.40459440941 + 210.8514148832*t)
	X0 += 0.00000001421*np.cos(5.99347128723 + 225.8292684102*t)
	X0 += 0.00000001472*np.cos(3.48774945967 + 215.7467759928*t)
	X0 += 0.00000001157*np.cos(5.00834366696 + 2648.454825473*t)
	X0 += 0.00000001096*np.cos(2.83518032659 + 422.6660376129*t)
	X0 += 0.00000001074*np.cos(3.22867432953 + 1795.258443721*t)
	X0 += 0.00000001049*np.cos(0.50853077542 + 309.2783226558*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001411*np.cos(1.66986522557 + 50057.04242277*t)
	X0 += 0.00000001022*np.cos(0.96352485877 + 145.6310438715*t)
	X0 += 0.00000001422*np.cos(2.40975714524 + 152.5321425512*t)
	X0 += 0.00000001014*np.cos(1.81620829580 + 74821.13447975718*t)
	X0 += 0.00000001232*np.cos(0.84010473770 + 52182.9198301492*t)
	X0 += 0.00000001068*np.cos(5.82601643881 + 26727.8004278882*t)
	X0 += 0.00000000963*np.cos(2.31649309053 + 155468.03691925599*t)
	X0 += 0.00000000979*np.cos(2.33360006154 + 84.3428261229*t)
	X0 += 0.00000000955*np.cos(6.15602120913 + 1272.6810256272*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000000991*np.cos(3.22224423668 + 117873.36400788819*t)
	X0 += 0.00000001075*np.cos(0.57961253778 + 212.3358875915*t)
	X0 += 0.00000001070*np.cos(4.31120526838 + 214.2623032845*t)
	X0 += 0.00000000939*np.cos(3.69536889843 + 12432.0426503978*t)
	X0 += 0.00000000956*np.cos(1.51577387873 + 124778.18365871879*t)
	X0 += 0.00000001244*np.cos(2.87441597074 + 184.7272873558*t)
	X0 += 0.00000001098*np.cos(2.95983802473 + 137.0330241624*t)
	X0 += 0.00000000889*np.cos(3.98790631605 + 213.2509113282*t)
	X0 += 0.00000000889*np.cos(0.90251570889 + 213.3472795478*t)
	X0 += 0.00000000851*np.cos(3.47856448633 + 85034.42002596818*t)
	X0 += 0.00000000907*np.cos(3.70816916557 + 98068.53671630539*t)
	X0 += 0.00000000973*np.cos(4.53434491997 + 437.6438911399*t)
	X0 += 0.00000000827*np.cos(4.98534406085 + 104881.30353139139*t)
	X0 += 0.00000000819*np.cos(0.57163728715 + 529.6427809848*t)
	X0 += 0.00000000819*np.cos(3.76946397274 + 529.7391492044*t)
	X0 += 0.00000000811*np.cos(2.26915207928 + 288.0806940053*t)
	X0 += 0.00000000827*np.cos(4.70714045338 + 25661.3049506982*t)
	X0 += 0.00000000794*np.cos(5.34803060760 + 120226.23016165999*t)
	X0 += 0.00000000846*np.cos(2.52472705200 + 51123.53789995999*t)
	X0 += 0.00000001037*np.cos(4.27554240329 + 527.2432845398*t)
	X0 += 0.00000001031*np.cos(0.06363683037 + 532.1386456494*t)
	X0 += 0.00000000903*np.cos(5.45953667423 + 52026.2430860138*t)
	X0 += 0.00000000797*np.cos(4.06306935733 + 203.7378678824*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000000734*np.cos(5.35841388096 + 112.9146342051*t)
	X0 += 0.00000000923*np.cos(2.83668265777 + 115674.27666460119*t)
	X0 += 0.00000000714*np.cos(1.92373551526 + 628.8515860501*t)
	X0 += 0.00000000706*np.cos(0.25739782784 + 313054.83769889036*t)
	X0 += 0.00000000802*np.cos(3.91721323343 + 157636.79740153858*t)
	X0 += 0.00000000929*np.cos(3.79917679735 + 55618.3812281138*t)
	X0 += 0.00000000773*np.cos(2.32134386344 + 95247.70557217918*t)
	X0 += 0.00000000723*np.cos(2.69407605052 + 105410.99449648599*t)
	X0 += 0.00000000670*np.cos(2.85882489359 + 2008.557539159*t)
	X0 += 0.00000000859*np.cos(5.91464456306 + 51109.31080595839*t)
	X0 += 0.00000000661*np.cos(3.20309638077 + 2111.6503133776*t)
	X0 += 0.00000000716*np.cos(2.17754981522 + 129909.82474277639*t)
	X0 += 0.00000000926*np.cos(2.97025862788 + 160.6088973985*t)
	X0 += 0.00000000824*np.cos(3.32690900700 + 838.9692877504*t)
	X0 += 0.00000000650*np.cos(3.13131829872 + 64607.84893354619*t)
	X0 += 0.00000000673*np.cos(0.86671401461 + 28206.6670019526*t)
	X0 += 0.00000000607*np.cos(1.59220678788 + 78244.0396638228*t)
	X0 += 0.00000000631*np.cos(0.50050985480 + 430.5303441391*t)
	X0 += 0.00000000608*np.cos(3.76574069937 + 2221.856634597*t)
	X0 += 0.00000000692*np.cos(2.83117936839 + 9.5612275556*t)
	X0 += 0.00000000659*np.cos(5.75914725971 + 52022.0274726636*t)
	X0 += 0.00000000832*np.cos(2.20242516999 + 380.12776796*t)
	X0 += 0.00000000739*np.cos(3.07428442368 + 103396.01282468818*t)
	X0 += 0.00000000615*np.cos(5.13985428393 + 1368.660252845*t)
	X0 += 0.00000000585*np.cos(0.20238616925 + 162188.75089859738*t)
	X0 += 0.00000000665*np.cos(4.44780311571 + 1063.3140834523*t)
	X0 += 0.00000000639*np.cos(3.15793381912 + 12.5301729722*t)
	X0 += 0.00000000599*np.cos(0.38463092695 + 423.4167971383*t)
	X0 += 0.00000000674*np.cos(5.81169972173 + 38519.945791972*t)
	X0 += 0.00000000648*np.cos(3.43475812975 + 528.7277572481*t)
	X0 += 0.00000000646*np.cos(0.90574398043 + 530.6541729411*t)
	X0 += 0.00000000590*np.cos(2.65601790847 + 71025.03383312259*t)
	X0 += 0.00000000552*np.cos(0.88446392196 + 1055.4497769261*t)
	X0 += 0.00000000538*np.cos(6.04102038970 + 127.4717966068*t)
	X0 += 0.00000000673*np.cos(5.99514165920 + 52329.58509363319*t)
	X0 += 0.00000000556*np.cos(2.51501816541 + 10021.8372800994*t)
	X0 += 0.00000000661*np.cos(5.96096138275 + 77623.81213840858*t)
	X0 += 0.00000000506*np.cos(4.78871089926 + 23754.70674870219*t)
	X0 += 0.00000000672*np.cos(3.08200615608 + 221.3758502853*t)
	X0 += 0.00000000633*np.cos(4.13478072308 + 45494.58142974879*t)
	X0 += 0.00000000566*np.cos(2.70414246898 + 728.762966531*t)
	X0 += 0.00000000490*np.cos(2.97472409276 + 71.6002048296*t)
	X0 += 0.00000000649*np.cos(1.32346646305 + 22.0914005278*t)
	X0 += 0.00000000471*np.cos(4.83320292258 + 77.962992305*t)
	X0 += 0.00000000624*np.cos(2.86175235996 + 330.6189636582*t)
	X0 += 0.00000000466*np.cos(4.75460050527 + 84546.78527471398*t)
	X0 += 0.00000000592*np.cos(3.30852715140 + 7994.5284420242*t)
	X0 += 0.00000000475*np.cos(0.67495503078 + 1073.6090241908*t)
	X0 += 0.00000000652*np.cos(2.72637797985 + 388.4651552382*t)
	X0 += 0.00000000545*np.cos(5.80602159358 + 52099.5402118728*t)
	X0 += 0.00000000456*np.cos(1.94151045577 + 90829.86112470538*t)
	X0 += 0.00000000469*np.cos(3.29068228268 + 26237.46633870879*t)
	X0 += 0.00000000574*np.cos(5.66932742997 + 87.3117715395*t)
	X0 += 0.00000000521*np.cos(0.86596201958 + 80482.46652890938*t)
	X0 += 0.00000000614*np.cos(3.69895971929 + 78283.37918562238*t)
	X0 += 0.00000000444*np.cos(4.63869120122 + 151975.46535238638*t)
	X0 += 0.00000000440*np.cos(6.26532535664 + 27140.17152476259*t)
	X0 += 0.00000000605*np.cos(1.98317483331 + 984.6003316219*t)
	X0 += 0.00000000541*np.cos(3.08246188636 + 72.3339180125*t)
	X0 += 0.00000000472*np.cos(0.86276697768 + 155418.04029735178*t)
	X0 += 0.00000000467*np.cos(5.34128135139 + 212.7778305762*t)
	X0 += 0.00000000469*np.cos(3.53622250201 + 108903.56606335558*t)
	X0 += 0.00000000466*np.cos(5.83324087524 + 213.8203602998*t)
	X0 += 0.00000000447*np.cos(1.04087892038 + 78256.59587772179*t)
	X0 += 0.00000000418*np.cos(2.75937640828 + 429.7795846137*t)
	X0 += 0.00000000475*np.cos(1.66738717949 + 860.3099287528*t)
	X0 += 0.00000000453*np.cos(3.64418740188 + 26137.8997634784*t)
	X0 += 0.00000000454*np.cos(2.00715474668 + 26037.90651966999*t)
	X0 += 0.00000000436*np.cos(0.82989514902 + 2333.196392872*t)
	X0 += 0.00000000418*np.cos(5.03310520138 + 128850.44281258718*t)
	X0 += 0.00000000429*np.cos(2.31358963023 + 29428.515568274*t)
	X0 += 0.00000000419*np.cos(5.00087241120 + 78267.59076008058*t)
	X0 += 0.00000000400*np.cos(0.83625504703 + 28421.0995344462*t)
	X0 += 0.00000000438*np.cos(1.02063855266 + 78050.41032928458*t)
	X0 += 0.00000000502*np.cos(0.81791649248 + 26720.68688088739*t)
	X0 += 0.00000000446*np.cos(5.82498138989 + 25984.8103673556*t)
	X0 += 0.00000000426*np.cos(2.83085905523 + 27154.3986187642*t)
	X0 += 0.00000000422*np.cos(2.30407366448 + 93028.94846799239*t)
	X0 += 0.00000000511*np.cos(4.91405448075 + 77.2292791221*t)
	X0 += 0.00000000441*np.cos(6.19559752006 + 26190.99591579279*t)
	X0 += 0.00000000517*np.cos(4.94804650401 + 25455.119402261*t)
	X0 += 0.00000000390*np.cos(4.99072482742 + 130012.91751699499*t)
	X0 += 0.00000000384*np.cos(0.64251152112 + 340.7708920448*t)
	X0 += 0.00000000366*np.cos(3.54049188579 + 22747.2907148744*t)
	X0 += 0.00000000364*np.cos(0.17059200526 + 78690.30761559859*t)
	X0 += 0.00000000360*np.cos(2.87002870666 + 114564.89811250778*t)
	X0 += 0.00000000418*np.cos(0.29020498002 + 78259.82808936459*t)
	X0 += 0.00000000352*np.cos(0.48243014753 + 52643.7712735028*t)
	X0 += 0.00000000447*np.cos(4.62889752225 + 76144.94556434419*t)
	X0 += 0.00000000393*np.cos(0.20924522982 + 78477.00852016058*t)
	X0 += 0.00000000354*np.cos(2.54868316520 + 62.2514255951*t)
	X0 += 0.00000000395*np.cos(3.93999186550 + 52.6901980395*t)
	X0 += 0.00000000337*np.cos(0.17003651408 + 79852.78232000639*t)
	X0 += 0.00000000406*np.cos(2.27584736071 + 350.3321196004*t)
	X0 += 0.00000000396*np.cos(1.99989177453 + 145.1097790097*t)
	X0 += 0.00000000423*np.cos(1.38576321047 + 46848.3301747656*t)
	X0 += 0.00000000328*np.cos(5.12139261865 + 72936.23331633979*t)
	X0 += 0.00000000356*np.cos(6.07425645036 + 48835.19385644859*t)
	X0 += 0.00000000385*np.cos(6.13244198192 + 909.8187330546*t)
	X0 += 0.00000000335*np.cos(2.06671111251 + 18207.81398823521*t)
	X0 += 0.00000000316*np.cos(4.36448926663 + 76044.9523205358*t)
	X0 += 0.00000000403*np.cos(5.17867896855 + 131395.11544947959*t)
	X0 += 0.00000000310*np.cos(0.83186759417 + 1905.4647649404*t)
	X0 += 0.00000000313*np.cos(3.62090724113 + 234.6397364404*t)
	X0 += 0.00000000368*np.cos(5.56337901283 + 25565.3257234804*t)
	X0 += 0.00000000382*np.cos(1.81523910449 + 186.2117600641*t)
	X0 += 0.00000000417*np.cos(1.80274920701 + 71492.99882347698*t)
	X0 += 0.00000000299*np.cos(4.63500144403 + 25973.46385288896*t)
	X0 += 0.00000000297*np.cos(1.02156805675 + 26202.34243025941*t)
	X0 += 0.00000000400*np.cos(1.38752434540 + 454.9093665273*t)
	X0 += 0.00000000372*np.cos(4.82853244691 + 3.1813937377*t)
	X0 += 0.00000000285*np.cos(1.16807752441 + 52182.4348420484*t)
	X0 += 0.00000000372*np.cos(1.49143639581 + 19406.6782881746*t)
	X0 += 0.00000000280*np.cos(0.70712927501 + 3.9321532631*t)
	X0 += 0.00000000293*np.cos(4.67573472055 + 23969.1392811958*t)
	X0 += 0.00000000303*np.cos(4.97988934115 + 51707.84129279399*t)
	X0 += 0.00000000287*np.cos(2.94652251384 + 26164.1692128498*t)
	X0 += 0.00000000309*np.cos(2.68979490218 + 362.8622925726*t)
	X0 += 0.00000000370*np.cos(3.57337038653 + 26162.6847401415*t)
	X0 += 0.00000000321*np.cos(0.05550391453 + 26610.48055966799*t)
	X0 += 0.00000000324*np.cos(6.13605453847 + 20760.4270331914*t)
	X0 += 0.00000000335*np.cos(0.71030115582 + 200.7689224658*t)
	X0 += 0.00000000267*np.cos(6.27484488465 + 143961.26714946238*t)
	X0 += 0.00000000311*np.cos(4.44573637765 + 297.6419215609*t)
	X0 += 0.00000000289*np.cos(1.92464337356 + 529.1697002328*t)
	X0 += 0.00000000366*np.cos(2.92406939426 + 604.4725636619*t)
	X0 += 0.00000000288*np.cos(2.41719522186 + 530.2122299564*t)
	X0 += 0.00000000366*np.cos(5.76748576672 + 111590.28815789679*t)
	X0 += 0.00000000314*np.cos(1.84357518690 + 108.4612160802*t)
	X0 += 0.00000000259*np.cos(3.65477257312 + 1485.9801210652*t)
	X0 += 0.00000000258*np.cos(5.37268509995 + 181555.94006083018*t)
	X0 += 0.00000000262*np.cos(4.15566435137 + 1258.4539316256*t)
	X0 += 0.00000000343*np.cos(2.03380599265 + 26013.1215430069*t)
	X0 += 0.00000000252*np.cos(1.39861971442 + 2125.8774073792*t)
	X0 += 0.00000000274*np.cos(1.54026728979 + 565.1156877467*t)
	X0 += 0.00000000325*np.cos(0.32647938806 + 703.6331846174*t)
	X0 += 0.00000000252*np.cos(0.59000537549 + 25668.418497699*t)
	X0 += 0.00000000244*np.cos(4.83556134823 + 51756.3216392732*t)
	X0 += 0.00000000268*np.cos(0.19545433539 + 140.001969579*t)
	X0 += 0.00000000285*np.cos(4.30750157848 + 52169.17772424839*t)
	X0 += 0.00000000243*np.cos(0.44342371962 + 1062.5633239269*t)
	X0 += 0.00000000248*np.cos(0.09445957496 + 210.3783341312*t)
	X0 += 0.00000000248*np.cos(4.79327801971 + 216.2198567448*t)
	X0 += 0.00000000241*np.cos(3.24545153339 + 37.611770776*t)
	X0 += 0.00000000255*np.cos(4.90697050745 + 153.4953503977*t)
	X0 += 0.00000000321*np.cos(1.57031879808 + 25771.5112719176*t)
	X0 += 0.00000000320*np.cos(4.08881851808 + 26404.2950112308*t)
	X0 += 0.00000000237*np.cos(3.72326482255 + 212.5483359126*t)
	X0 += 0.00000000237*np.cos(0.47343036140 + 124156.43985787958*t)
	X0 += 0.00000000236*np.cos(1.16575065097 + 214.0498549634*t)
	X0 += 0.00000000236*np.cos(4.23871934676 + 38.6543004996*t)
	X0 += 0.00000000305*np.cos(3.88207196267 + 78270.82297172339*t)
	X0 += 0.00000000252*np.cos(4.61065643475 + 209.106309744*t)
	X0 += 0.00000000247*np.cos(0.27272991614 + 217.491881132*t)
	X0 += 0.00000000225*np.cos(3.38119852586 + 223.5940361765*t)
	X0 += 0.00000000274*np.cos(5.58277756568 + 77211.44104153418*t)
	X0 += 0.00000000224*np.cos(5.51904045547 + 38.084851528*t)
	X0 += 0.00000000223*np.cos(1.96313876697 + 38.1812197476*t)
	X0 += 0.00000000279*np.cos(2.68601229144 + 77197.21394753258*t)
	X0 += 0.00000000259*np.cos(4.47711002004 + 32769.1279949738*t)
	X0 += 0.00000000218*np.cos(4.72556155170 + 100909.03762133139*t)
	X0 += 0.00000000277*np.cos(4.66039961569 + 26507.38778544939*t)
	X0 += 0.00000000245*np.cos(4.21060733239 + 173.9422195228*t)
	X0 += 0.00000000220*np.cos(0.21393446501 + 111122.32316754239*t)
	X0 += 0.00000000213*np.cos(0.60035314724 + 16066.0658614748*t)
	X0 += 0.00000000212*np.cos(3.53403079789 + 42153.969003049*t)
	X0 += 0.00000000234*np.cos(0.55106604784 + 74.2603337055*t)
	X0 += 0.00000000233*np.cos(0.98887023825 + 75.3028634291*t)
	X0 += 0.00000000208*np.cos(2.11083387325 + 146314.13330323418*t)
	X0 += 0.00000000230*np.cos(5.88454220643 + 141762.17980617538*t)
	X0 += 0.00000000241*np.cos(4.57150130406 + 150866.08680029298*t)
	X0 += 0.00000000247*np.cos(0.56642494969 + 252.6559713532*t)
	X0 += 0.00000000210*np.cos(0.69225590128 + 183724.70054311278*t)
	X0 += 0.00000000204*np.cos(0.84533704687 + 18.1592472647*t)
	X0 += 0.00000000282*np.cos(1.41766310537 + 563.6312150384*t)
	X0 += 0.00000000219*np.cos(0.30631385523 + 1699.2792165032*t)
	X0 += 0.00000000279*np.cos(2.23082630295 + 78114.14622758799*t)
	X0 += 0.00000000211*np.cos(1.74747254431 + 130969.20667296558*t)
	X0 += 0.00000000243*np.cos(1.23801467525 + 11610.5519583742*t)
	X0 += 0.00000000265*np.cos(2.55781243216 + 39743.7636327506*t)
	X0 += 0.00000000207*np.cos(5.75479453376 + 142.4496501338*t)
	X0 += 0.00000000222*np.cos(0.56159148263 + 81706.28436968799*t)
	X0 += 0.00000000204*np.cos(0.27721513871 + 417.0369633204*t)
	X0 += 0.00000000195*np.cos(4.23402090499 + 66.70484372*t)
	X0 += 0.00000000197*np.cos(2.60291082834 + 52815.7035694624*t)
	X0 += 0.00000000211*np.cos(5.13588313603 + 37.1698277913*t)
	X0 += 0.00000000247*np.cos(0.88342639891 + 71582.48457132299*t)
	X0 += 0.00000000244*np.cos(2.23408992933 + 51742.09454527159*t)
	X0 += 0.00000000227*np.cos(5.15751336106 + 207.8824694666*t)
	X0 += 0.00000000203*np.cos(2.35104519506 + 39.0962434843*t)
	X0 += 0.00000000202*np.cos(4.05217682796 + 207.6700211455*t)
	X0 += 0.00000000184*np.cos(3.89765737558 + 1898.3512179396*t)
	X0 += 0.00000000202*np.cos(2.33370581573 + 25881.717593137*t)
	X0 += 0.00000000196*np.cos(3.28084664215 + 26294.08869001139*t)
	X0 += 0.00000000219*np.cos(6.03807342488 + 218.7157214094*t)
	X0 += 0.00000000206*np.cos(5.35930784504 + 88.865680217*t)
	X0 += 0.00000000188*np.cos(2.41909448761 + 1471.7530270636*t)
	X0 += 0.00000000185*np.cos(4.15018423748 + 508.3503240922*t)
	X0 += 0.00000000195*np.cos(0.82662766477 + 218.9281697305*t)
	X0 += 0.00000000177*np.cos(1.97797395237 + 14477.35118320*t)
	X0 += 0.00000000197*np.cos(3.05228592369 + 1574.8458012822*t)
	X0 += 0.00000000224*np.cos(4.06529944699 + 1056.2005364515*t)
	X0 += 0.00000000220*np.cos(1.08810755857 + 7880.08915333899*t)
	X0 += 0.00000000174*np.cos(3.31130146787 + 339142.74084046457*t)
	X0 += 0.00000000169*np.cos(4.11217724456 + 106570.36967048359*t)
	X0 += 0.00000000184*np.cos(6.12955693514 + 129483.91596626239*t)
	X0 += 0.00000000172*np.cos(0.97217516384 + 51543.0225438352*t)
	X0 += 0.00000000172*np.cos(2.96155542160 + 526.7702037878*t)
	X0 += 0.00000000186*np.cos(0.73069210814 + 554.0699874828*t)
	X0 += 0.00000000194*np.cos(2.50663265946 + 28.5718080822*t)
	X0 += 0.00000000185*np.cos(2.73333187819 + 103711.71527998279*t)
	X0 += 0.00000000169*np.cos(1.38093325803 + 532.6117264014*t)
	X0 += 0.00000000217*np.cos(3.59114151623 + 124.433415221*t)
	X0 += 0.00000000176*np.cos(1.20681960915 + 525.4981794006*t)
	X0 += 0.00000000172*np.cos(5.60194767636 + 211.8146227297*t)
	X0 += 0.00000000192*np.cos(3.25987344029 + 50483.640613646*t)
	X0 += 0.00000000188*np.cos(3.44598602635 + 569.0478410098*t)
	X0 += 0.00000000158*np.cos(0.33551046271 + 528.9402055692*t)
	X0 += 0.00000000157*np.cos(4.00545168863 + 530.44172462*t)
	X0 += 0.00000000191*np.cos(5.22978475164 + 155997.72788435058*t)
	X0 += 0.00000000177*np.cos(0.70756419313 + 32.1951448046*t)
	X0 += 0.00000000196*np.cos(5.36844580786 + 121335.60871375339*t)
	X0 += 0.00000000191*np.cos(4.12314886390 + 183.2428146475*t)
	X0 += 0.00000000179*np.cos(1.49110102879 + 5.9378908332*t)
	X0 += 0.00000000170*np.cos(5.83704197169 + 305.3461693927*t)
	X0 += 0.00000000207*np.cos(1.81656116060 + 73.8183907208*t)
	X0 += 0.00000000149*np.cos(3.30525660286 + 33967.99229491319*t)
	X0 += 0.00000000152*np.cos(2.53081717814 + 78109.93061423779*t)
	X0 += 0.00000000167*np.cos(3.75899797460 + 467.9649903544*t)
	X0 += 0.00000000175*np.cos(1.28027815287 + 217.964961884*t)
	X0 += 0.00000000153*np.cos(1.95502612633 + 44181.27784112419*t)
	X0 += 0.00000000148*np.cos(4.39633643688 + 519.3960243561*t)
	X0 += 0.00000000155*np.cos(3.25656297117 + 188276.65404017158*t)
	X0 += 0.00000000178*np.cos(5.74884343681 + 131498.89763806018*t)
	X0 += 0.00000000147*np.cos(3.63497942528 + 82.8583534146*t)
	X0 += 0.00000000158*np.cos(2.94930459323 + 61279.713277266*t)
	X0 += 0.00000000205*np.cos(3.72849237219 + 51322.60990139639*t)
	X0 += 0.00000000159*np.cos(5.67523653240 + 70269.18098269838*t)
	X0 += 0.00000000203*np.cos(2.54569209930 + 453.424893819*t)
	X0 += 0.00000000191*np.cos(5.96603240618 + 425.1137181677*t)
	X0 += 0.00000000148*np.cos(3.53096991388 + 414.0680179038*t)
	X0 += 0.00000000200*np.cos(0.25134097583 + 1439.5096981492*t)
	X0 += 0.00000000165*np.cos(5.22234420384 + 231.4583427027*t)
	X0 += 0.00000000142*np.cos(3.09515542757 + 50593.84693486539*t)
	X0 += 0.00000000148*np.cos(4.64350567688 + 104331.94280539699*t)
	X0 += 0.00000000141*np.cos(5.69421526925 + 408.4389436113*t)
	X0 += 0.00000000152*np.cos(5.28423765869 + 52101.02468458109*t)
	X0 += 0.00000000158*np.cos(2.76578351678 + 78417.48823520739*t)
	X0 += 0.00000000173*np.cos(5.18821469013 + 26624.70765366959*t)
	X0 += 0.00000000191*np.cos(6.04625942487 + 75.7448064138*t)
	X0 += 0.00000000149*np.cos(3.15621899577 + 533.8837507886*t)
	X0 += 0.00000000157*np.cos(3.61532012746 + 208.633228992*t)
	X0 += 0.00000000180*np.cos(3.80266288374 + 1685.0521225016*t)
	X0 += 0.00000000139*np.cos(2.47064593676 + 52278.89905736699*t)
	X0 += 0.00000000153*np.cos(4.99836680146 + 47.6942631934*t)
	X0 += 0.00000000184*np.cos(2.16301573772 + 1021.2488945514*t)
	X0 += 0.00000000162*np.cos(0.92049935752 + 25780.3455206046*t)
	X0 += 0.00000000139*np.cos(5.84452648935 + 373.9079928365*t)
	X0 += 0.00000000155*np.cos(3.01838392403 + 13362.4497067992*t)
	X0 += 0.00000000159*np.cos(4.73827541063 + 26395.46076254379*t)
	X0 += 0.00000000138*np.cos(5.61172177506 + 214.7835681463*t)
	X0 += 0.00000000129*np.cos(1.54390762080 + 203.0041546995*t)
	X0 += 0.00000000128*np.cos(5.24161490581 + 479.2883889155*t)
	X0 += 0.00000000150*np.cos(4.09326692088 + 23888.81579828719*t)
	X0 += 0.00000000149*np.cos(0.46707747400 + 104371.28232719658*t)
	X0 += 0.00000000130*np.cos(4.64320618121 + 22759.76748529401*t)
	X0 += 0.00000000125*np.cos(1.65138113985 + 66653.15746634839*t)
	X0 += 0.00000000127*np.cos(3.92908708947 + 54294.57014352679*t)
	X0 += 0.00000000139*np.cos(3.82303818931 + 52808.59002246159*t)
	X0 += 0.00000000133*np.cos(1.43643107625 + 102232.84870591838*t)
	X0 += 0.00000000130*np.cos(2.26702486739 + 654.1243803156*t)
	X0 += 0.00000000170*np.cos(2.57893150930 + 78187.44335344699*t)
	X0 += 0.00000000144*np.cos(1.54442458059 + 4.192785694*t)
	X0 += 0.00000000139*np.cos(1.22510407970 + 251.4321310758*t)
	X0 += 0.00000000119*np.cos(1.41360479766 + 178063.36849396059*t)
	X0 += 0.00000000160*np.cos(5.11540883899 + 265.9892934775*t)
	X0 += 0.00000000121*np.cos(3.91397388740 + 181505.94343892598*t)
	X0 += 0.00000000121*np.cos(5.05113331022 + 56.6223513026*t)
	X0 += 0.00000000122*np.cos(2.54446157327 + 52072.71350892979*t)
	X0 += 0.00000000139*np.cos(5.71941525592 + 97112.93697469679*t)
	X0 += 0.00000000115*np.cos(6.22459411775 + 539.9859058331*t)
	X0 += 0.00000000115*np.cos(4.07185769679 + 104344.49901929598*t)
	X0 += 0.00000000117*np.cos(1.54182773466 + 110634.68841628819*t)
	X0 += 0.00000000127*np.cos(0.21479421217 + 26521.614879451*t)
	X0 += 0.00000000112*np.cos(1.81733872734 + 154938.34595416138*t)
	X0 += 0.00000000111*np.cos(0.50939039069 + 18093.37469954999*t)
	X0 += 0.00000000114*np.cos(0.09813992796 + 213.1872208534*t)
	X0 += 0.00000000114*np.cos(4.79116773360 + 213.4109700226*t)
	X0 += 0.00000000113*np.cos(0.81015998025 + 25754.0472008048*t)
	X0 += 0.00000000108*np.cos(5.76941118774 + 25448.00585526019*t)
	X0 += 0.00000000123*np.cos(5.10501021239 + 98.8999885246*t)
	X0 += 0.00000000146*np.cos(0.58342798299 + 60055.89543648739*t)
	X0 += 0.00000000108*np.cos(2.35657716458 + 24176.703658357*t)
	X0 += 0.00000000116*np.cos(0.64506154486 + 524.0618908021*t)
	X0 += 0.00000000110*np.cos(4.84051151993 + 26421.7590823436*t)
	X0 += 0.00000000115*np.cos(3.69498632982 + 535.3200393871*t)
	X0 += 0.00000000104*np.cos(0.13113326845 + 68241.87214462319*t)
	X0 += 0.00000000127*np.cos(0.63003020942 + 540.7366653585*t)
	X0 += 0.00000000104*np.cos(1.75849927543 + 156100.82065856918*t)
	X0 += 0.00000000110*np.cos(5.00176300515 + 116917.76426627958*t)
	X0 += 0.00000000121*np.cos(1.57094829203 + 28286.9904848612*t)
	X0 += 0.00000000143*np.cos(0.64505147056 + 25551.09862947879*t)
	X0 += 0.00000000118*np.cos(0.24752969879 + 983.1158589136*t)
	X0 += 0.00000000141*np.cos(5.41856442991 + 50579.61984086379*t)
	X0 += 0.00000000101*np.cos(4.14115345148 + 26198.1094627936*t)
	X0 += 0.00000000118*np.cos(0.19804778544 + 525.0250986486*t)
	X0 += 0.00000000105*np.cos(1.29654862161 + 963.4027029714*t)
	X0 += 0.00000000100*np.cos(3.71645704441 + 529.851023789*t)
	X0 += 0.00000000100*np.cos(0.62422783083 + 529.5309064002*t)
	X0 += 0.00000000100*np.cos(5.46137709146 + 25035.6347583858*t)
	X0 += 0.00000000101*np.cos(2.84451540031 + 74923.09699802278*t)
	X0 += 0.00000000099*np.cos(1.87542989608 + 198.321241911*t)
	X0 += 0.00000000109*np.cos(3.14296852629 + 51639.00177105299*t)
	X0 += 0.00000000119*np.cos(3.40917089591 + 2324.9494088156*t)
	X0 += 0.00000000111*np.cos(1.30109743855 + 80.1982245387*t)
	X0 += 0.00000000096*np.cos(4.17152569130 + 213.5115437591*t)
	X0 += 0.00000000096*np.cos(0.71778197027 + 213.0866471169*t)
	X0 += 0.00000000100*np.cos(3.26577605891 + 104564.91166173479*t)
	X0 += 0.00000000120*np.cos(0.30678874176 + 134991.46920492979*t)
	X0 += 0.00000000098*np.cos(0.40293133382 + 31415.379249957*t)
	X0 += 0.00000000099*np.cos(0.19873228449 + 551.031606097*t)
	X0 += 0.00000000110*np.cos(0.16237016300 + 24356.7807886416*t)
	X0 += 0.00000000111*np.cos(4.13924061941 + 534.3568315406*t)
	X0 += 0.00000000117*np.cos(1.76475239313 + 524.2743391232*t)
	X0 += 0.00000000125*np.cos(4.85236761160 + 21.3406410024*t)
	X0 += 0.00000000095*np.cos(5.28465176922 + 327.4375699205*t)
	X0 += 0.00000000127*np.cos(4.13213704562 + 104138.31347085879*t)
	X0 += 0.00000000096*np.cos(0.03168784215 + 1802.3719907218*t)
	X0 += 0.00000000115*np.cos(2.57406093768 + 535.107591066*t)
	X0 += 0.00000000100*np.cos(2.94090698274 + 195.1398481733*t)
	X0 += 0.00000000103*np.cos(5.28415599079 + 55516.4187098482*t)
	X0 += 0.00000000096*np.cos(0.06385619665 + 35.685355083*t)
	X0 += 0.00000000093*np.cos(5.06100768596 + 52125.80966124419*t)
	X0 += 0.00000000113*np.cos(1.72263005108 + 114.1384744825*t)
	X0 += 0.00000000090*np.cos(3.88628119026 + 54509.0026760204*t)
	X0 += 0.00000000102*np.cos(4.42228976166 + 219.891377577*t)
	X0 += 0.00000000102*np.cos(1.76819684789 + 104355.49390165479*t)
	X0 += 0.00000000092*np.cos(0.93585280841 + 29416.03879785439*t)
	X0 += 0.00000000089*np.cos(3.13856979181 + 1382.8873468466*t)
	X0 += 0.00000000099*np.cos(3.05816380866 + 51951.46148744649*t)
	X0 += 0.00000000101*np.cos(5.00210914828 + 26941.0995233262*t)
	X0 += 0.00000000093*np.cos(5.47802579149 + 27780.06881107659*t)
	X0 += 0.00000000086*np.cos(2.85915032438 + 228.276948965*t)
	X0 += 0.00000000092*np.cos(5.92381365319 + 140652.80125408198*t)
	X0 += 0.00000000101*np.cos(0.37463492787 + 52250.5878817157*t)
	X0 += 0.00000000100*np.cos(3.39323367399 + 96.8729990951*t)
	X0 += 0.00000000110*np.cos(1.19226098509 + 49527.35145767539*t)
	X0 += 0.00000000106*np.cos(1.95430653957 + 157483.01859105378*t)
	X0 += 0.00000000085*np.cos(0.07491193588 + 52325.36948028299*t)
	X0 += 0.00000000084*np.cos(2.61330768505 + 74.7334144575*t)
	X0 += 0.00000000084*np.cos(5.20716850754 + 74.8297826771*t)
	X0 += 0.00000000088*np.cos(5.23856931735 + 36109.7404216736*t)
	X0 += 0.00000000114*np.cos(1.15232105885 + 177.8743727859*t)
	X0 += 0.00000000092*np.cos(4.54873108884 + 51219.51712717779*t)
	X0 += 0.00000000099*np.cos(4.86416581345 + 97580.90196505119*t)
	X0 += 0.00000000096*np.cos(5.49023224946 + 27819.0254945068*t)
	X0 += 0.00000000083*np.cos(3.06701367899 + 53228.07466633679*t)
	X0 += 0.00000000086*np.cos(4.71420290052 + 52065.59996192899*t)
	X0 += 0.00000000087*np.cos(1.13401038923 + 40.5807161926*t)
	X0 += 0.00000000100*np.cos(0.37157933173 + 52225.8029050526*t)
	X0 += 0.00000000102*np.cos(5.36307297883 + 119116.85160956658*t)
	X0 += 0.00000000086*np.cos(3.22100292543 + 104778.21075717278*t)
	X0 += 0.00000000080*np.cos(3.16723228694 + 27999.1026247914*t)
	X0 += 0.00000000081*np.cos(3.33902328234 + 191.2076949102*t)
	X0 += 0.00000000093*np.cos(1.06738164563 + 74.5209661364*t)
	X0 += 0.00000000082*np.cos(3.52865654881 + 78731.674415077*t)
	X0 += 0.00000000091*np.cos(6.01617993088 + 12725.453434775*t)
	X0 += 0.00000000093*np.cos(0.46802035326 + 75.0422309982*t)
	X0 += 0.00000000079*np.cos(4.31891477024 + 38.0211610532*t)
	X0 += 0.00000000079*np.cos(3.16332905605 + 38.2449102224*t)
	X0 += 0.00000000080*np.cos(1.40233563562 + 191.9584544356*t)
	X0 += 0.00000000079*np.cos(4.46070108071 + 278.5194664497*t)
	X0 += 0.00000000080*np.cos(3.95392779576 + 175.1660598002*t)
	X0 += 0.00000000083*np.cos(2.35608099285 + 300.6108669775*t)
	X0 += 0.00000000078*np.cos(0.92843223712 + 30.0562807905*t)
	X0 += 0.00000000097*np.cos(5.32653372215 + 259.5088859231*t)
	X0 += 0.00000000079*np.cos(3.22192807282 + 40565.2543247742*t)
	X0 += 0.00000000091*np.cos(4.58356981907 + 51859.41441349179*t)
	X0 += 0.00000000078*np.cos(5.89716715733 + 53242.3017603384*t)
	X0 += 0.00000000077*np.cos(2.50991636518 + 205.2223405907*t)
	X0 += 0.00000000076*np.cos(1.13153106088 + 102132.85546210999*t)
	X0 += 0.00000000079*np.cos(3.22173800911 + 105940.68546158058*t)
	X0 += 0.00000000085*np.cos(0.43515691954 + 44.070926471*t)
	X0 += 0.00000000096*np.cos(6.24127646307 + 131.4039498699*t)
	X0 += 0.00000000091*np.cos(3.88112259566 + 80.7194894005*t)
	X0 += 0.00000000090*np.cos(4.23026579034 + 51013.33157874059*t)
	X0 += 0.00000000089*np.cos(0.85475471665 + 1911.1994832172*t)
	X0 += 0.00000000075*np.cos(4.78657001260 + 3328.13565628019*t)
	X0 += 0.00000000089*np.cos(2.51053764331 + 137678.19129947099*t)
	X0 += 0.00000000078*np.cos(2.59112277976 + 74.6215398729*t)
	X0 += 0.00000000078*np.cos(5.22948432343 + 74.9416572617*t)
	X0 += 0.00000000075*np.cos(2.21732650708 + 302.164775655*t)
	X0 += 0.00000000073*np.cos(5.12605342426 + 50696.93970908399*t)
	X0 += 0.00000000102*np.cos(3.34060456120 + 104347.73123093879*t)
	X0 += 0.00000000072*np.cos(3.05203065820 + 170049.17029103659*t)
	X0 += 0.00000000072*np.cos(4.81698863150 + 213.5597278689*t)
	X0 += 0.00000000072*np.cos(0.07231943414 + 213.0384630071*t)
	X0 += 0.00000000088*np.cos(0.84909576958 + 52492.19815280499*t)
	X0 += 0.00000000096*np.cos(4.24511131293 + 483.2205421786*t)
	X0 += 0.00000000078*np.cos(5.73315772437 + 103285.11708910679*t)
	X0 += 0.00000000076*np.cos(2.77567349877 + 25021.4076643842*t)
	X0 += 0.00000000074*np.cos(1.54799312825 + 52595.29092702359*t)
	X0 += 0.00000000075*np.cos(1.65964856775 + 77844.22478084739*t)
	X0 += 0.00000000076*np.cos(5.29592084579 + 25953.79409198919*t)
	X0 += 0.00000000069*np.cos(3.45966511571 + 529.4785167735*t)
	X0 += 0.00000000069*np.cos(0.88102053266 + 529.9034134157*t)
	X0 += 0.00000000094*np.cos(3.68180477512 + 248.7238180901*t)
	X0 += 0.00000000093*np.cos(3.12123076178 + 52698.38370124219*t)
	X0 += 0.00000000077*np.cos(3.59376629306 + 518.6452648307*t)
	X0 += 0.00000000071*np.cos(1.81949696208 + 99024.13645791399*t)
	X0 += 0.00000000069*np.cos(5.67393312508 + 27669.86248985719*t)
	X0 += 0.00000000082*np.cos(4.53867872623 + 8194.2753332086*t)
	X0 += 0.00000000070*np.cos(3.97459919519 + 24998.19435038059*t)
	X0 += 0.00000000066*np.cos(2.02327672376 + 635.9651330509*t)
	X0 += 0.00000000073*np.cos(0.37194429847 + 26222.0121911592*t)
	X0 += 0.00000000066*np.cos(4.21010251137 + 78270.33798362259*t)
	X0 += 0.00000000075*np.cos(0.63857154574 + 104358.72611329758*t)
	X0 += 0.00000000068*np.cos(1.33087179491 + 25977.69682035479*t)
	X0 += 0.00000000065*np.cos(3.48280450372 + 2214.7430875962*t)
	X0 += 0.00000000065*np.cos(5.87150671106 + 12546.481939083*t)
	X0 += 0.00000000068*np.cos(2.13534804773 + 207643.84320240439*t)
	X0 += 0.00000000073*np.cos(3.92326982541 + 97670.38771289718*t)
	X0 += 0.00000000077*np.cos(5.28001515588 + 104202.04936916218*t)
	X0 += 0.00000000080*np.cos(5.28926332171 + 77829.99768684579*t)
	X0 += 0.00000000063*np.cos(3.22324471895 + 20.6069278195*t)
	X0 += 0.00000000084*np.cos(0.70408445885 + 424.1505103212*t)
	X0 += 0.00000000079*np.cos(3.79946681872 + 25446.4895798352*t)
	X0 += 0.00000000082*np.cos(1.17323562782 + 154.0166152595*t)
	X0 += 0.00000000065*np.cos(5.99619164093 + 284.1485407422*t)
	X0 += 0.00000000076*np.cos(3.59374291647 + 831.8557407496*t)
	X0 += 0.00000000081*np.cos(3.70025004502 + 37.8724032069*t)
	X0 += 0.00000000069*np.cos(2.58402361347 + 275.5505210331*t)
	X0 += 0.00000000071*np.cos(3.88813675038 + 835.0371344873*t)
	X0 += 0.00000000080*np.cos(3.78188046031 + 38.3936680687*t)
	X0 += 0.00000000073*np.cos(0.88865626886 + 115.8835796217*t)
	X0 += 0.00000000062*np.cos(3.49840489113 + 150244.34299945379*t)
	X0 += 0.00000000070*np.cos(3.33224029594 + 27684.0895838588*t)
	X0 += 0.00000000072*np.cos(6.12464480054 + 50800.03248330259*t)
	X0 += 0.00000000063*np.cos(1.68487980742 + 27177.6119327678*t)
	X0 += 0.00000000070*np.cos(4.93912259682 + 17893.6278083656*t)
	X0 += 0.00000000062*np.cos(4.07249777023 + 52290.24557183361*t)
	X0 += 0.00000000059*np.cos(1.39971005804 + 52061.36699446317*t)
	X0 += 0.00000000074*np.cos(1.85368417401 + 26729.31670331319*t)
	X0 += 0.00000000069*np.cos(2.49762583501 + 511.5317178299*t)
	X0 += 0.00000000078*np.cos(5.50238014696 + 26086.4186688659*t)
	X0 += 0.00000000077*np.cos(2.35428024909 + 103299.34418310839*t)
	X0 += 0.00000000058*np.cos(0.25471831888 + 46.2097904851*t)
	X0 += 0.00000000068*np.cos(1.09479629612 + 643.8294395771*t)
	X0 += 0.00000000077*np.cos(0.15680563848 + 26089.38761428249*t)
	X0 += 0.00000000079*np.cos(5.72688311333 + 531.1754378029*t)
	X0 += 0.00000000058*np.cos(2.64366803071 + 167850.08294774959*t)
	X0 += 0.00000000079*np.cos(0.46444983025 + 404.5067903482*t)
	X0 += 0.00000000077*np.cos(4.08353330283 + 618.5566453116*t)
	X0 += 0.00000000056*np.cos(3.75317204098 + 209812.60368468695*t)
	X0 += 0.00000000056*np.cos(1.44522132533 + 842.1506814881*t)
	X0 += 0.00000000062*np.cos(0.88771657360 + 99.1606209555*t)
	X0 += 0.00000000065*np.cos(1.84460485390 + 547.8502123593*t)
	X0 += 0.00000000062*np.cos(4.06674027154 + 68.8437077341*t)
	X0 += 0.00000000058*np.cos(1.54141936736 + 25508.2155545754*t)
	X0 += 0.00000000065*np.cos(5.37982266335 + 3178.1457905676*t)
	X0 += 0.00000000055*np.cos(5.11846973847 + 44295.7171298094*t)
	X0 += 0.00000000061*np.cos(0.01100073598 + 121.2520214833*t)
	X0 += 0.00000000076*np.cos(4.86986651697 + 528.2064923863*t)
	X0 += 0.00000000074*np.cos(5.40235174363 + 90695.75207512038*t)
	X0 += 0.00000000056*np.cos(5.41213842126 + 22625.658435709*t)
	X0 += 0.00000000075*np.cos(4.71498755910 + 227.3137411185*t)
	X0 += 0.00000000058*np.cos(5.00595087071 + 24448.8336243862*t)
	X0 += 0.00000000057*np.cos(3.38008527236 + 2641.3412784722*t)
	X0 += 0.00000000066*np.cos(1.74137162401 + 77795.74443436819*t)
	X0 += 0.00000000060*np.cos(3.25440342504 + 137210.22630911658*t)
	X0 += 0.00000000053*np.cos(6.01392123943 + 52252.07235442399*t)
	X0 += 0.00000000055*np.cos(5.16128806691 + 172402.03644480839*t)
	X0 += 0.00000000063*np.cos(0.49748028885 + 77410.51304297059*t)
	X0 += 0.00000000061*np.cos(3.81064825215 + 650.9429865779*t)
	X0 += 0.00000000064*np.cos(4.29409388919 + 159.1244246902*t)
	X0 += 0.00000000055*np.cos(3.60654464612 + 107794.18751126219*t)
	X0 += 0.00000000061*np.cos(2.96999279527 + 429.0458714308*t)
	X0 += 0.00000000067*np.cos(1.36610006933 + 19.66976089979*t)
	X0 += 0.00000000052*np.cos(3.24674394448 + 2538.2485042536*t)
	X0 += 0.00000000054*np.cos(4.25219663118 + 60370.08161635699*t)
	X0 += 0.00000000057*np.cos(3.46227126270 + 92.940845832*t)
	X0 += 0.00000000072*np.cos(1.66730834668 + 2199.087343287*t)
	X0 += 0.00000000070*np.cos(4.72694535646 + 24864.08530079559*t)
	X0 += 0.00000000068*np.cos(0.43233787470 + 219.4494345923*t)
	X0 += 0.00000000059*np.cos(5.80351575464 + 33.9402499438*t)
	X0 += 0.00000000062*np.cos(5.86330508473 + 2.4476805548*t)
	X0 += 0.00000000054*np.cos(0.83991353377 + 25938.3399444396*t)
	X0 += 0.00000000062*np.cos(6.09623774456 + 425.6349830295*t)
	X0 += 0.00000000051*np.cos(5.10012533555 + 1048.3362299253*t)
	X0 += 0.00000000052*np.cos(5.67389658184 + 26312.2479372761*t)
	X0 += 0.00000000051*np.cos(4.20616611062 + 55503.94193942859*t)
	X0 += 0.00000000054*np.cos(3.07019079387 + 59.8037450403*t)
	X0 += 0.00000000051*np.cos(1.38932880278 + 126996.94076290558*t)
	X0 += 0.00000000050*np.cos(1.48104982763 + 960.2213092337*t)
	X0 += 0.00000000059*np.cos(5.90527689512 + 72.0732855816*t)
	X0 += 0.00000000050*np.cos(0.12167728428 + 426.6463749858*t)
	X0 += 0.00000000064*np.cos(4.78297114148 + 269.9214467406*t)
	X0 += 0.00000000050*np.cos(4.78368432558 + 514.7131115676*t)
	X0 += 0.00000000051*np.cos(5.96112457648 + 387.2413149608*t)
	X0 += 0.00000000055*np.cos(1.61378048542 + 42.3258213318*t)
	X0 += 0.00000000052*np.cos(4.12665298549 + 26667.590728573*t)
	X0 += 0.00000000061*np.cos(2.99099061629 + 38813.3565763492*t)
	X0 += 0.00000000063*np.cos(1.40789341724 + 750.1036075334*t)
	X0 += 0.00000000050*np.cos(3.20702872042 + 426.5500067662*t)
	X0 += 0.00000000063*np.cos(3.98505374586 + 494.2662424425*t)
	X0 += 0.00000000053*np.cos(2.43583780027 + 2428.0421830342*t)
	X0 += 0.00000000050*np.cos(1.22898875729 + 58857.03113654799*t)
	X0 += 0.00000000049*np.cos(5.77137528617 + 129799.61842155698*t)
	X0 += 0.00000000047*np.cos(5.83569926578 + 544.6688186216*t)
	X0 += 0.00000000048*np.cos(2.00982466333 + 39.3568759152*t)
	X0 += 0.00000000055*np.cos(4.77668766562 + 157057.10981453978*t)
	X0 += 0.00000000066*np.cos(1.07578161516 + 78257.08086582259*t)
	X0 += 0.00000000047*np.cos(5.68018085277 + 51969.62073471119*t)
	X0 += 0.00000000055*np.cos(5.26856872787 + 81.8951455681*t)
	X0 += 0.00000000050*np.cos(0.62769089958 + 27726.9726587622*t)
	X0 += 0.00000000059*np.cos(2.11187321665 + 488.8496164711*t)
	X0 += 0.00000000047*np.cos(6.07590356304 + 76681.75007643958*t)
	X0 += 0.00000000064*np.cos(0.02610133525 + 76571.54375522019*t)
	X0 += 0.00000000048*np.cos(3.85151205518 + 77630.92568540938*t)
	X0 += 0.00000000047*np.cos(4.16677363723 + 27044.1922975448*t)
	X0 += 0.00000000047*np.cos(2.89523133719 + 155571.81910783658*t)
	X0 += 0.00000000063*np.cos(4.17349551052 + 1364.7280995819*t)
	X0 += 0.00000000054*np.cos(5.79169304973 + 23919.1426592916*t)
	X0 += 0.00000000054*np.cos(3.62421804697 + 427.5613987225*t)
	X0 += 0.00000000052*np.cos(4.38844382678 + 210.5907824523*t)
	X0 += 0.00000000063*np.cos(0.92748869514 + 27311.72098235281*t)
	X0 += 0.00000000051*np.cos(0.50117453824 + 216.0074084237*t)
	X0 += 0.00000000046*np.cos(4.79961635192 + 106.2741679563*t)
	X0 += 0.00000000050*np.cos(4.62538441124 + 1056.9342496344*t)
	X0 += 0.00000000046*np.cos(0.24060913723 + 29550.14784743939*t)
	X0 += 0.00000000048*np.cos(1.32358795195 + 501.3797894433*t)
	X0 += 0.00000000051*np.cos(1.39209045161 + 28736.3579670472*t)
	X0 += 0.00000000062*np.cos(1.33564279040 + 176953.98994186718*t)
	X0 += 0.00000000053*np.cos(0.23746311564 + 27037.07875054399*t)
	X0 += 0.00000000050*np.cos(1.09462754777 + 355.7487455718*t)
	X0 += 0.00000000044*np.cos(5.16479782395 + 74.0308390419*t)
	X0 += 0.00000000044*np.cos(4.12941573514 + 2751.5475996916*t)
	X0 += 0.00000000055*np.cos(2.70454523909 + 14.977853527*t)
	X0 += 0.00000000057*np.cos(3.17248775727 + 491.8185618877*t)
	X0 += 0.00000000043*np.cos(0.99595677376 + 213.4591541324*t)
	X0 += 0.00000000043*np.cos(3.89366939283 + 213.1390367436*t)
	X0 += 0.00000000043*np.cos(2.65544175682 + 75.5323580927*t)
	X0 += 0.00000000043*np.cos(0.76354191371 + 220.4608265486*t)
	X0 += 0.00000000049*np.cos(0.25668378883 + 1279.794572628*t)
	X0 += 0.00000000043*np.cos(5.65844331747 + 78903.60671103658*t)
	X0 += 0.00000000053*np.cos(0.29722112114 + 54087.0057663656*t)
	X0 += 0.00000000054*np.cos(0.68459749075 + 187.6962327724*t)
	X0 += 0.00000000043*np.cos(3.66662961756 + 16703.062133499*t)
	X0 += 0.00000000057*np.cos(0.63863230611 + 1061.829610744*t)
	X0 += 0.00000000050*np.cos(5.56308110598 + 296.1574488526*t)
	X0 += 0.00000000042*np.cos(2.08219460796 + 78188.92782615528*t)
	X0 += 0.00000000053*np.cos(2.13789461791 + 147423.51185532758*t)
	X0 += 0.00000000048*np.cos(5.60385784254 + 65831.6667743248*t)
	X0 += 0.00000000048*np.cos(5.45683494266 + 25138.7275326044*t)
	X0 += 0.00000000053*np.cos(0.12507223621 + 52381.99183158559*t)
	X0 += 0.00000000041*np.cos(4.51930257295 + 128.9562693151*t)
	X0 += 0.00000000049*np.cos(5.16281052467 + 26709.6469424134*t)
	X0 += 0.00000000056*np.cos(5.45458264580 + 1057.8974574809*t)
	X0 += 0.00000000053*np.cos(1.93518633525 + 601.7642506762*t)
	X0 += 0.00000000040*np.cos(0.81354779862 + 132658.27281205778*t)
	X0 += 0.00000000047*np.cos(5.03443210464 + 679.2541622292*t)
	X0 += 0.00000000054*np.cos(4.48267339963 + 207.1487562837*t)
	X0 += 0.00000000054*np.cos(0.20680001648 + 153.7788104848*t)
	X0 += 0.00000000040*np.cos(4.11879245377 + 1059.430114299*t)
	X0 += 0.00000000048*np.cos(0.50977666152 + 25466.159340735*t)
	X0 += 0.00000000047*np.cos(2.16892174570 + 76667.52298243798*t)
	X0 += 0.00000000042*np.cos(3.87088947499 + 220.364458329*t)
	X0 += 0.00000000046*np.cos(4.69192941021 + 10.2949407385*t)
	X0 += 0.00000000040*np.cos(1.64818311544 + 26823.77965510599*t)
	X0 += 0.00000000044*np.cos(0.08844410692 + 365230.64398203876*t)
	X0 += 0.00000000051*np.cos(5.74770428324 + 344.7030453079*t)
	X0 += 0.00000000049*np.cos(1.91714086006 + 75930.51303185058*t)
	X0 += 0.00000000054*np.cos(1.04857075083 + 188.9200730498*t)
	X0 += 0.00000000040*np.cos(4.01884342217 + 25352.02662804239*t)
	X0 += 0.00000000046*np.cos(5.62653039055 + 104275.34649502118*t)
	X0 += 0.00000000041*np.cos(2.70677059989 + 67.6680515665*t)
	X0 += 0.00000000044*np.cos(0.03463265500 + 214364.55718174578*t)
	X0 += 0.00000000044*np.cos(1.85079090927 + 52712.61079524379*t)
	X0 += 0.00000000044*np.cos(0.29252718625 + 179.3588454942*t)
	X0 += 0.00000000051*np.cos(1.98801868265 + 182085.63102592478*t)
	X0 += 0.00000000044*np.cos(1.83547130154 + 289.5651667136*t)
	X0 += 0.00000000040*np.cos(4.83551999164 + 149.45132255*t)
	X0 += 0.00000000044*np.cos(6.15351278676 + 28256.66362385679*t)
	X0 += 0.00000000040*np.cos(0.02735864866 + 436.1594184316*t)
	X0 += 0.00000000047*np.cos(2.80270200743 + 1038.0412891868*t)
	X0 += 0.00000000038*np.cos(5.81365212706 + 104505.39137678158*t)
	X0 += 0.00000000037*np.cos(3.31019033964 + 1788.1448967202*t)
	X0 += 0.00000000043*np.cos(5.33420928917 + 25867.49049913539*t)
	X0 += 0.00000000045*np.cos(2.39073394193 + 358.9301393095*t)
	X0 += 0.00000000037*np.cos(5.57899251145 + 104197.83375581198*t)
	X0 += 0.00000000047*np.cos(1.00325671943 + 523.5406259403*t)
	X0 += 0.00000000042*np.cos(5.19722521758 + 25169.9728555924*t)
	X0 += 0.00000000036*np.cos(2.92998162283 + 68.1893164283*t)
	X0 += 0.00000000038*np.cos(3.94772947506 + 26102.1302355758*t)
	X0 += 0.00000000038*np.cos(3.51956196186 + 130459.18546877075*t)
	X0 += 0.00000000040*np.cos(0.92098132614 + 1059.3337460794*t)
	X0 += 0.00000000036*np.cos(4.54511004825 + 128320.75184749259*t)
	X0 += 0.00000000037*np.cos(3.02198266683 + 26118.2300025786*t)
	X0 += 0.00000000038*np.cos(5.64242804993 + 212.0270710508*t)
	X0 += 0.00000000037*np.cos(5.53010012107 + 214.5711198252*t)
	X0 += 0.00000000037*np.cos(1.67070947391 + 24203.0019781568*t)
	X0 += 0.00000000036*np.cos(2.65041173436 + 26057.57628056979*t)
	X0 += 0.00000000039*np.cos(2.30481475888 + 1514.2912967165*t)
	X0 += 0.00000000040*np.cos(0.87236752974 + 497.4476361802*t)
	X0 += 0.00000000038*np.cos(1.66427845773 + 26402.0893214438*t)
	X0 += 0.00000000038*np.cos(5.13531782692 + 9384.8410080752*t)
	X0 += 0.00000000039*np.cos(0.46607609112 + 27005.83342755599*t)
	X0 += 0.00000000035*np.cos(4.30307025009 + 672.1406152284*t)
	X0 += 0.00000000047*np.cos(2.48361583884 + 50.4025761791*t)
	X0 += 0.00000000035*np.cos(4.65523345776 + 89.7594520943*t)
	X0 += 0.00000000035*np.cos(5.32328344021 + 69.1525242748*t)
	X0 += 0.00000000037*np.cos(5.42747720341 + 78366.80219894118*t)
	X0 += 0.00000000037*np.cos(4.00811594346 + 25773.71696170459*t)
	X0 += 0.00000000043*np.cos(2.91924315729 + 312.4597163935*t)
	X0 += 0.00000000034*np.cos(3.56462720934 + 27566.76971563859*t)
	X0 += 0.00000000040*np.cos(1.58760278423 + 149.6750717192*t)
	X0 += 0.00000000035*np.cos(0.56576540054 + 78896.49316403578*t)
	X0 += 0.00000000034*np.cos(1.75287834063 + 26073.67604757259*t)
	X0 += 0.00000000038*np.cos(1.41911789835 + 130419.8459469712*t)
	X0 += 0.00000000044*np.cos(2.53375250429 + 157586.80077963437*t)
	X0 += 0.00000000042*np.cos(3.33159283750 + 535.8413042489*t)
	X0 += 0.00000000034*np.cos(3.67701355195 + 25985.94062330859*t)
	X0 += 0.00000000036*np.cos(3.18170063426 + 144.1465711632*t)
	X0 += 0.00000000033*np.cos(0.53966934587 + 51852.30086649099*t)
	X0 += 0.00000000033*np.cos(2.37919979646 + 54.1746707478*t)
	X0 += 0.00000000035*np.cos(4.00506060972 + 27972.80430499159*t)
	X0 += 0.00000000035*np.cos(2.61916970082 + 27463.67694142*t)
	X0 += 0.00000000044*np.cos(3.78834210571 + 237.6781178262*t)
	X0 += 0.00000000033*np.cos(1.99538084924 + 26189.8656598398*t)
	X0 += 0.00000000035*np.cos(1.74685819003 + 529.9515975255*t)
	X0 += 0.00000000035*np.cos(2.59415719377 + 529.4303326637*t)
	X0 += 0.00000000032*np.cos(0.69003641909 + 207593.84658050018*t)
	X0 += 0.00000000035*np.cos(3.16175106244 + 51653.22886505459*t)
	X0 += 0.00000000032*np.cos(4.15757729853 + 206.1373643274*t)
	X0 += 0.00000000032*np.cos(0.69603648293 + 522.529233984*t)
	X0 += 0.00000000044*np.cos(0.60569420427 + 1512.8068240082*t)
	X0 += 0.00000000034*np.cos(3.91727152081 + 522.6256022036*t)
	X0 += 0.00000000032*np.cos(4.94879963135 + 81.3738807063*t)
	X0 += 0.00000000036*np.cos(3.21789957686 + 143.6253063014*t)
	X0 += 0.00000000034*np.cos(5.20057828474 + 1361.5467058442*t)
	X0 += 0.00000000032*np.cos(4.93095676351 + 767.3690829208*t)
	X0 += 0.00000000034*np.cos(3.96853644086 + 51868.2486621788*t)
	X0 += 0.00000000038*np.cos(5.50377225938 + 64901.25971792339*t)
	X0 += 0.00000000036*np.cos(3.05228952146 + 106.9767433719*t)
	X0 += 0.00000000043*np.cos(3.02087771501 + 51528.79544983359*t)
	X0 += 0.00000000040*np.cos(4.86610913022 + 1593.0050485469*t)
	X0 += 0.00000000036*np.cos(0.94812382604 + 130226.21661243298*t)
	X0 += 0.00000000042*np.cos(0.56126000400 + 26308.315784013*t)
	X0 += 0.00000000031*np.cos(1.35404435495 + 35.212274331*t)
	X0 += 0.00000000031*np.cos(5.57428335318 + 78160.61665050399*t)
	X0 += 0.00000000033*np.cos(1.35404998174 + 1060.3451380357*t)
	X0 += 0.00000000030*np.cos(1.18953789068 + 1585.1407420207*t)
	X0 += 0.00000000032*np.cos(4.46013138626 + 204151.27163553478*t)
	X0 += 0.00000000032*np.cos(2.18005598447 + 51432.81622261579*t)
	X0 += 0.00000000030*np.cos(0.82681675219 + 130432.40216087017*t)
	X0 += 0.00000000030*np.cos(2.78120590799 + 116783.65521669458*t)
	X0 += 0.00000000032*np.cos(1.19634441527 + 26011.6370702986*t)
	X0 += 0.00000000030*np.cos(4.81616957225 + 182188.72380014337*t)
	X0 += 0.00000000030*np.cos(4.58762516085 + 49842.60989027639*t)
	X0 += 0.00000000036*np.cos(1.23021540997 + 181.0557665236*t)
	X0 += 0.00000000029*np.cos(4.88576757444 + 181026.24909573558*t)
	X0 += 0.00000000031*np.cos(4.17809672541 + 26083.97098831109*t)
	X0 += 0.00000000029*np.cos(4.00562317628 + 23439.44831610119*t)
	X0 += 0.00000000030*np.cos(3.25773726286 + 94329.77528619739*t)
	X0 += 0.00000000030*np.cos(5.47125895037 + 458.8415197904*t)
	X0 += 0.00000000030*np.cos(1.04324019127 + 206.233732547*t)
	X0 += 0.00000000028*np.cos(0.70524581752 + 80382.47328510099*t)
	X0 += 0.00000000030*np.cos(0.97454681171 + 77101.23472031478*t)
	X0 += 0.00000000033*np.cos(3.71848916507 + 245.5424243524*t)
	X0 += 0.00000000031*np.cos(3.62133003349 + 13541.42120249119*t)
	X0 += 0.00000000027*np.cos(5.91976429127 + 101011.00013959699*t)
	X0 += 0.00000000037*np.cos(4.29084367097 + 37698.4550999484*t)
	X0 += 0.00000000034*np.cos(3.84184270652 + 92.0470739547*t)
	X0 += 0.00000000029*np.cos(4.54475250390 + 426.0769260142*t)
	X0 += 0.00000000029*np.cos(1.50978551760 + 26091.83529483729*t)
	X0 += 0.00000000027*np.cos(1.62628759375 + 52509.6622239178*t)
	X0 += 0.00000000027*np.cos(2.00149954913 + 643.0786800517*t)
	X0 += 0.00000000027*np.cos(0.05278402845 + 130652.81480330898*t)
	X0 += 0.00000000028*np.cos(4.62722813500 + 54374.8936264354*t)
	X0 += 0.00000000029*np.cos(0.41759634551 + 536.7563279856*t)
	X0 += 0.00000000027*np.cos(4.36788488657 + 113.3877149571*t)
	X0 += 0.00000000026*np.cos(3.63270001708 + 536.8526962052*t)
	X0 += 0.00000000034*np.cos(1.33764060023 + 77307.42026875199*t)
	X0 += 0.00000000028*np.cos(5.03737783889 + 183570.92173262799*t)
	X0 += 0.00000000026*np.cos(5.99681746879 + 26049.7701059364*t)
	X0 += 0.00000000030*np.cos(4.55790675044 + 247.2393453818*t)
	X0 += 0.00000000030*np.cos(0.32859851834 + 24395.7374720718*t)
	X0 += 0.00000000034*np.cos(1.25342876252 + 22003.9146348698*t)
	X0 += 0.00000000033*np.cos(6.20284454959 + 77726.90491262719*t)
	X0 += 0.00000000029*np.cos(4.59659721132 + 136722.59155786238*t)
	X0 += 0.00000000035*np.cos(1.49684301877 + 52483.36390411799*t)
	X0 += 0.00000000031*np.cos(2.95281812365 + 567.8240007324*t)
	X0 += 0.00000000033*np.cos(2.75649306165 + 49953.94964855139*t)
	X0 += 0.00000000026*np.cos(1.90176515926 + 76784.84285065818*t)
	X0 += 0.00000000026*np.cos(4.09640475404 + 2001.4439921582*t)
	X0 += 0.00000000031*np.cos(6.01278123151 + 87367.61641884019*t)
	X0 += 0.00000000026*np.cos(2.06712180785 + 312.1990839626*t)
	X0 += 0.00000000027*np.cos(4.56810285368 + 558.0021407459*t)
	X0 += 0.00000000029*np.cos(2.06052680441 + 51226.63067417859*t)
	X0 += 0.00000000028*np.cos(5.93842433817 + 34282.1784747828*t)
	X0 += 0.00000000026*np.cos(2.19672734069 + 528.4189407074*t)
	X0 += 0.00000000033*np.cos(5.60590635849 + 68.5618234438*t)
	X0 += 0.00000000026*np.cos(2.14391745890 + 530.9629894818*t)
	X0 += 0.00000000034*np.cos(2.24082486732 + 81.0013736908*t)
	X0 += 0.00000000032*np.cos(3.35937950567 + 161079.37234650398*t)
	X0 += 0.00000000031*np.cos(4.07910584606 + 75615.25459924959*t)
	X0 += 0.00000000033*np.cos(6.12422500331 + 78039.36462902068*t)
	X0 += 0.00000000032*np.cos(3.06209611372 + 885.4397106664*t)
	X0 += 0.00000000027*np.cos(0.11026948051 + 69.3649725959*t)
	X0 += 0.00000000027*np.cos(0.91518492018 + 1223.81784077861*t)
	X0 += 0.00000000033*np.cos(2.48498925172 + 123200.84011627098*t)
	X0 += 0.00000000029*np.cos(0.08978768557 + 26575.53789282839*t)
	X0 += 0.00000000025*np.cos(3.43998049238 + 78338.49102328988*t)
	X0 += 0.00000000024*np.cos(2.66945427931 + 24824.745778996*t)
	X0 += 0.00000000029*np.cos(5.32028981868 + 181.7583419392*t)
	X0 += 0.00000000024*np.cos(6.14830012198 + 41.0537969446*t)
	X0 += 0.00000000031*np.cos(0.66559323336 + 235.3904959658*t)
	X0 += 0.00000000029*np.cos(5.58510707424 + 25600.26839032*t)
	X0 += 0.00000000027*np.cos(0.73776364996 + 27170.98337386779*t)
	X0 += 0.00000000027*np.cos(4.92586138125 + 25004.8229092806*t)
	X0 += 0.00000000026*np.cos(5.97260588863 + 39450.3528483734*t)
	X0 += 0.00000000023*np.cos(3.00242836566 + 27351.06050415239*t)
	X0 += 0.00000000027*np.cos(4.38319692097 + 88.7962442478*t)
	X0 += 0.00000000024*np.cos(2.49215995784 + 129373.02023068098*t)
	X0 += 0.00000000025*np.cos(2.88697470245 + 50064.15596977079*t)
	X0 += 0.00000000026*np.cos(5.05798020797 + 427.1194557378*t)
	X0 += 0.00000000026*np.cos(0.46301099062 + 206.706813299*t)
	X0 += 0.00000000023*np.cos(5.42203185877 + 146.3818033969*t)
	X0 += 0.00000000027*np.cos(1.76553297822 + 143005.66740785378*t)
	X0 += 0.00000000024*np.cos(2.92749869616 + 447.9388318784*t)
	X0 += 0.00000000023*np.cos(3.27216589351 + 52609.51802102519*t)
	X0 += 0.00000000027*np.cos(1.29818173739 + 24072.9214697764*t)
	X0 += 0.00000000028*np.cos(3.14979814758 + 65717.22748563958*t)
	X0 += 0.00000000024*np.cos(0.97156468917 + 52286.01260436779*t)
	X0 += 0.00000000026*np.cos(2.59525206009 + 746.9222137957*t)
	X0 += 0.00000000030*np.cos(4.42414087291 + 30171.8916482786*t)
	X0 += 0.00000000023*np.cos(5.88384962075 + 31.5407534988*t)
	X0 += 0.00000000031*np.cos(3.78497688028 + 1058.4187223427*t)
	X0 += 0.00000000023*np.cos(1.70061470411 + 934.9485149682*t)
	X0 += 0.00000000023*np.cos(1.81054497604 + 14.0146456805*t)
	X0 += 0.00000000026*np.cos(4.93016524161 + 342.2553647531*t)
	X0 += 0.00000000025*np.cos(1.41122590276 + 48847.6706268682*t)
	X0 += 0.00000000029*np.cos(0.23984449899 + 23.5758732361*t)
	X0 += 0.00000000026*np.cos(1.50614892755 + 78153.50310350319*t)
	X0 += 0.00000000023*np.cos(2.53647453704 + 523.0986829556*t)
	X0 += 0.00000000023*np.cos(1.32747738833 + 77947.31755506598*t)
	X0 += 0.00000000023*np.cos(1.63079770877 + 123668.80510662538*t)
	X0 += 0.00000000030*np.cos(2.27056118316 + 53906.92863608099*t)
	X0 += 0.00000000022*np.cos(1.83245731848 + 78213.71280281838*t)
	X0 += 0.00000000025*np.cos(5.93871501925 + 26724.8994135984*t)
	X0 += 0.00000000025*np.cos(6.00809531914 + 25450.90686955*t)
	X0 += 0.00000000027*np.cos(3.05550059377 + 258.0244132148*t)
	X0 += 0.00000000029*np.cos(1.56958922292 + 1023.9572075371*t)
	X0 += 0.00000000022*np.cos(5.41897797101 + 50264.6067999312*t)
	X0 += 0.00000000030*np.cos(2.89300380445 + 1731.1223529326*t)
	X0 += 0.00000000029*np.cos(6.26467372784 + 6129.2970395066*t)
	X0 += 0.00000000021*np.cos(3.01607737644 + 420.9691165835*t)
	X0 += 0.00000000022*np.cos(3.40134712578 + 6885.14988993081*t)
	X0 += 0.00000000026*np.cos(4.37859274213 + 28102.884813372*t)
	X0 += 0.00000000024*np.cos(6.19145581405 + 78786.28684281638*t)
	X0 += 0.00000000022*np.cos(1.08435169766 + 491.5579294568*t)
	X0 += 0.00000000028*np.cos(1.89166907104 + 162.0933701068*t)
	X0 += 0.00000000025*np.cos(0.11282707964 + 130435.63437251298*t)
	X0 += 0.00000000022*np.cos(3.21335876929 + 50444.6839302158*t)
	X0 += 0.00000000021*np.cos(0.94006911216 + 51955.39364070959*t)
	X0 += 0.00000000026*np.cos(0.76643908895 + 152.0108776894*t)
	X0 += 0.00000000022*np.cos(3.51848051148 + 103498.41618454478*t)
	X0 += 0.00000000026*np.cos(0.06021608153 + 1158.5425511447*t)
	X0 += 0.00000000021*np.cos(2.37348270979 + 35472.7441496494*t)
	X0 += 0.00000000023*np.cos(2.05327785040 + 103917.90082841998*t)
	X0 += 0.00000000023*np.cos(4.96709654012 + 16342.5825857176*t)
	X0 += 0.00000000025*np.cos(2.29706808754 + 52174.32181044009*t)
	X0 += 0.00000000022*np.cos(3.88895575058 + 78580.10129437919*t)
	X0 += 0.00000000022*np.cos(0.65838685946 + 80596.9058175946*t)
	X0 += 0.00000000024*np.cos(4.28461358360 + 260.9933586314*t)
	X0 += 0.00000000024*np.cos(3.86546209537 + 51841.950342379*t)
	X0 += 0.00000000023*np.cos(2.51081319916 + 4.665866446*t)
	X0 += 0.00000000022*np.cos(2.53548727754 + 337.732510659*t)
	X0 += 0.00000000024*np.cos(3.30132330920 + 1134.1635287565*t)
	X0 += 0.00000000023*np.cos(5.40491354928 + 129387.24732468258*t)
	X0 += 0.00000000021*np.cos(1.80330951791 + 536.2832472336*t)
	X0 += 0.00000000021*np.cos(3.62446848832 + 521.6142102473*t)
	X0 += 0.00000000020*np.cos(1.31076853893 + 51329.7234483972*t)
	X0 += 0.00000000025*np.cos(2.01244999882 + 81604.32185142238*t)
	X0 += 0.00000000020*np.cos(3.10946208664 + 692.5874843535*t)
	X0 += 0.00000000021*np.cos(0.67741466251 + 123758.29085447139*t)
	X0 += 0.00000000027*np.cos(2.90106794933 + 76887.93562487679*t)
	X0 += 0.00000000020*np.cos(0.95102387062 + 1603.2999892854*t)
	X0 += 0.00000000023*np.cos(3.97874341983 + 3462.2447058652*t)
	X0 += 0.00000000020*np.cos(1.71776764968 + 1089.7087911936*t)
	X0 += 0.00000000020*np.cos(2.83591185309 + 212.0752551606*t)
	X0 += 0.00000000020*np.cos(2.05371431350 + 214.5229357154*t)
	X0 += 0.00000000020*np.cos(5.53175498038 + 630.3360587584*t)
	X0 += 0.00000000020*np.cos(2.96877128550 + 2104.5367663768*t)
	X0 += 0.00000000022*np.cos(2.28317396212 + 24491.71669928959*t)
	X0 += 0.00000000021*np.cos(5.53325591048 + 163766.09444104518*t)
	X0 += 0.00000000022*np.cos(3.98134921024 + 50167.24874398939*t)
	X0 += 0.00000000021*np.cos(2.05459082055 + 130289.95251073639*t)
	X0 += 0.00000000026*np.cos(0.67723932625 + 776.9303104764*t)
	X0 += 0.00000000023*np.cos(3.14028242096 + 495.7507151508*t)
	X0 += 0.00000000022*np.cos(5.46738021368 + 391.1734682239*t)
	X0 += 0.00000000020*np.cos(6.09945384418 + 196137.07343261078*t)
	X0 += 0.00000000019*np.cos(5.79794377748 + 2.9207613068*t)
	X0 += 0.00000000023*np.cos(2.69768658787 + 166740.70439565618*t)
	X0 += 0.00000000021*np.cos(0.61205369640 + 96357.08412427259*t)
	X0 += 0.00000000022*np.cos(0.06669236593 + 26126.036177212*t)
	X0 += 0.00000000023*np.cos(4.74205819227 + 353.301065017*t)
	X0 += 0.00000000021*np.cos(6.19036413024 + 320.3240229197*t)
	X0 += 0.00000000019*np.cos(5.50124179878 + 423.6774295692*t)
	X0 += 0.00000000022*np.cos(5.71636060779 + 26734.913974889*t)
	X0 += 0.00000000021*np.cos(5.57097088010 + 621.7380390493*t)
	X0 += 0.00000000019*np.cos(4.66884897067 + 78683.19406859778*t)
	X0 += 0.00000000024*np.cos(2.12828546843 + 145204.75475114079*t)
	X0 += 0.00000000023*np.cos(4.84049690148 + 27223.5800134674*t)
	X0 += 0.00000000019*np.cos(1.51428153438 + 44.7253177768*t)
	X0 += 0.00000000020*np.cos(3.04457317761 + 211.6021744086*t)
	X0 += 0.00000000021*np.cos(3.47252263966 + 73.4090004436*t)
	X0 += 0.00000000019*np.cos(3.69323819425 + 130446.62925487179*t)
	X0 += 0.00000000024*np.cos(3.04675754545 + 52177.29075585669*t)
	X0 += 0.00000000018*np.cos(0.72295496626 + 112231.70171963578*t)
	X0 += 0.00000000024*np.cos(4.23773296616 + 24925.4284371664*t)
	X0 += 0.00000000020*np.cos(0.64353479758 + 372.4235201282*t)
	X0 += 0.00000000025*np.cos(4.82366657336 + 130443.39704322898*t)
	X0 += 0.00000000019*np.cos(1.69613741566 + 6.1503391543*t)
	X0 += 0.00000000023*np.cos(0.24495600934 + 561.934294009*t)
	X0 += 0.00000000020*np.cos(5.54482262721 + 39629.32434406539*t)
	X0 += 0.00000000020*np.cos(5.61075502521 + 157.6399519819*t)
	X0 += 0.00000000021*np.cos(4.72389831021 + 134.5853436076*t)
	X0 += 0.00000000022*np.cos(0.83649888960 + 24952.226269681*t)
	X0 += 0.00000000023*np.cos(5.41241581728 + 8.0767548473*t)
	X0 += 0.00000000018*np.cos(3.20573786676 + 2531.1349572528*t)
	X0 += 0.00000000019*np.cos(6.21298740233 + 24505.94379329119*t)
	X0 += 0.00000000020*np.cos(0.30552664552 + 104819.57755665119*t)
	X0 += 0.00000000019*np.cos(6.23315092064 + 26248.310510959*t)
	X0 += 0.00000000019*np.cos(5.71365941775 + 25927.49577218939*t)
	X0 += 0.00000000018*np.cos(4.18931740994 + 128220.75860368418*t)
	X0 += 0.00000000020*np.cos(5.93600662958 + 25907.8260112896*t)
	X0 += 0.00000000020*np.cos(6.01080370881 + 26267.9802718588*t)
	X0 += 0.00000000019*np.cos(4.93432108959 + 52817.21984488739*t)
	X0 += 0.00000000018*np.cos(1.78785742512 + 53029.0026649004*t)
	X0 += 0.00000000018*np.cos(1.87891344947 + 26411.4085582316*t)
	X0 += 0.00000000022*np.cos(4.75001386674 + 103932.12792242158*t)
	X0 += 0.00000000018*np.cos(5.75169680594 + 99.9113804809*t)
	X0 += 0.00000000018*np.cos(4.90666145829 + 27573.1938482774*t)
	X0 += 0.00000000021*np.cos(6.27990297281 + 130866.11389874699*t)
	X0 += 0.00000000025*np.cos(3.36120084514 + 78313.70604662679*t)
	X0 += 0.00000000018*np.cos(0.81718560103 + 52137.67324751059*t)
	X0 += 0.00000000020*np.cos(5.18305639217 + 233731.74634397858*t)
	X0 += 0.00000000020*np.cos(0.38279809837 + 12412.372889498*t)
	X0 += 0.00000000018*np.cos(3.15536708233 + 78413.27262185719*t)
	X0 += 0.00000000017*np.cos(1.49131618722 + 953.1077622329*t)
	X0 += 0.00000000017*np.cos(2.29182997194 + 53867.97195265079*t)
	X0 += 0.00000000020*np.cos(3.28882834991 + 696.5196376166*t)
	X0 += 0.00000000019*np.cos(5.05188282673 + 1098.7388061044*t)
	X0 += 0.00000000019*np.cos(3.08463122927 + 102659.44689679438*t)
	X0 += 0.00000000018*np.cos(3.28242315954 + 184.9879197867*t)
	X0 += 0.00000000017*np.cos(0.77039059907 + 24602.61243487099*t)
	X0 += 0.00000000017*np.cos(3.04543466944 + 230.5645708254*t)
	X0 += 0.00000000023*np.cos(6.00963896724 + 916.9322800554*t)
	X0 += 0.00000000019*np.cos(6.28210678104 + 132028.58860315479*t)
	X0 += 0.00000000017*np.cos(3.20560881801 + 267.4737661858*t)
	X0 += 0.00000000018*np.cos(3.88202573179 + 182.279606801*t)
	X0 += 0.00000000023*np.cos(6.25048261828 + 6.2197751235*t)
	X0 += 0.00000000018*np.cos(2.54015443097 + 31.019488637*t)
	X0 += 0.00000000019*np.cos(0.27995809484 + 7.4223635415*t)
	X0 += 0.00000000016*np.cos(2.69293004860 + 79330.20490191258*t)
	X0 += 0.00000000017*np.cos(5.12544427579 + 600.5404103988*t)
	X0 += 0.00000000018*np.cos(6.15816966745 + 79315.97780791098*t)
	X0 += 0.00000000016*np.cos(2.78510813583 + 92741.06060792258*t)
	X0 += 0.00000000019*np.cos(2.01731902987 + 86143.79857806159*t)
	X0 += 0.00000000021*np.cos(4.27520120566 + 286.596221297*t)
	X0 += 0.00000000017*np.cos(2.82710574399 + 152.7445908723*t)
	X0 += 0.00000000020*np.cos(3.15496505590 + 1166.4068576709*t)
	X0 += 0.00000000019*np.cos(0.93260332932 + 778.4147831847*t)
	X0 += 0.00000000017*np.cos(0.71577565405 + 537.7677199419*t)
	X0 += 0.00000000016*np.cos(1.31341405081 + 50903.1252575212*t)
	X0 += 0.00000000016*np.cos(2.44368919495 + 3.881335358*t)
	X0 += 0.00000000017*np.cos(0.80031134767 + 526.9826521089*t)
	X0 += 0.00000000019*np.cos(5.70255270090 + 220.9339073006*t)
	X0 += 0.00000000016*np.cos(3.65774554265 + 50689.82616208319*t)
	X0 += 0.00000000016*np.cos(0.85872562979 + 125.9873238985*t)
	X0 += 0.00000000016*np.cos(1.29170718466 + 241.6102710893*t)
	X0 += 0.00000000017*np.cos(0.67834725691 + 32.2433289144*t)
	X0 += 0.00000000016*np.cos(1.08234577224 + 2435.155730035*t)
	X0 += 0.00000000016*np.cos(2.63929129920 + 436.8931316145*t)
	X0 += 0.00000000016*np.cos(0.09975901912 + 135.5485514541*t)
	X0 += 0.00000000017*np.cos(2.24648465702 + 2744.4340526908*t)
	X0 += 0.00000000020*np.cos(5.59753462144 + 141.4864422873*t)
	X0 += 0.00000000016*np.cos(6.10122094573 + 28309.75977617119*t)
	X0 += 0.00000000016*np.cos(3.01487400340 + 627.3671133418*t)
	X0 += 0.00000000016*np.cos(4.26178376234 + 6044.2285813754*t)
	X0 += 0.00000000016*np.cos(0.71201836603 + 2228.9701815978*t)
	X0 += 0.00000000017*np.cos(1.83689902078 + 214.9960164674*t)
	X0 += 0.00000000020*np.cos(4.00993370051 + 505.3119427064*t)
	X0 += 0.00000000015*np.cos(3.31455438934 + 1049.0869894507*t)
	X0 += 0.00000000015*np.cos(2.20607541706 + 319.5732633943*t)
	X0 += 0.00000000015*np.cos(2.51967305706 + 155887.52156313117*t)
	X0 += 0.00000000018*np.cos(1.47352611971 + 576.1613880106*t)
	X0 += 0.00000000016*np.cos(6.07005900395 + 636.7158925763*t)
	X0 += 0.00000000016*np.cos(5.19901196241 + 731.9443602687*t)
	X0 += 0.00000000017*np.cos(3.32835182606 + 55638.05098901359*t)
	X0 += 0.00000000016*np.cos(0.98987078340 + 104358.2411251968*t)
	X0 += 0.00000000018*np.cos(0.61423288161 + 1969.2006632438*t)
	X0 += 0.00000000015*np.cos(0.52512621542 + 235900.50682626116*t)
	X0 += 0.00000000016*np.cos(0.28898343422 + 176332.24614102798*t)
	X0 += 0.00000000016*np.cos(0.38827434188 + 416.3032501375*t)
	X0 += 0.00000000016*np.cos(5.12479514781 + 95.3885263868*t)
	X0 += 0.00000000015*np.cos(3.42730813171 + 52309.9153327334*t)
	X0 += 0.00000000017*np.cos(1.84286799688 + 221.1634019642*t)
	X0 += 0.00000000015*np.cos(3.57429118232 + 532.3992780803*t)
	X0 += 0.00000000015*np.cos(0.29047743947 + 617.8058857862*t)
	X0 += 0.00000000015*np.cos(5.08007114480 + 7.065362891*t)
	X0 += 0.00000000015*np.cos(4.08934218455 + 988.532484885*t)
	X0 += 0.00000000017*np.cos(4.88375242853 + 125112.03959948818*t)
	X0 += 0.00000000016*np.cos(1.99816798814 + 62197.64356324779*t)
	X0 += 0.00000000016*np.cos(3.89518074256 + 273.1028404783*t)
	X0 += 0.00000000016*np.cos(4.69568881762 + 107.0249274817*t)
	X0 += 0.00000000018*np.cos(1.55087961326 + 24.3790223882*t)
	X0 += 0.00000000018*np.cos(2.58391340476 + 421.93232443*t)
	X0 += 0.00000000014*np.cos(2.01138855049 + 211.8628068395*t)
	X0 += 0.00000000014*np.cos(2.87823761610 + 214.7353840365*t)
	X0 += 0.00000000016*np.cos(4.51457964099 + 61560.64729122359*t)
	X0 += 0.00000000018*np.cos(4.94346053652 + 50049.92887576919*t)
	X0 += 0.00000000015*np.cos(2.61658139005 + 50007.0458008658*t)
	X0 += 0.00000000016*np.cos(0.32998009587 + 73.1852512744*t)
	X0 += 0.00000000015*np.cos(0.06610754830 + 26830.8932021068*t)
	X0 += 0.00000000015*np.cos(4.43527029177 + 444.7574381407*t)
	X0 += 0.00000000014*np.cos(0.38206454808 + 133882.09065283638*t)
	X0 += 0.00000000015*np.cos(5.28887949143 + 102755.42612401219*t)
	X0 += 0.00000000015*np.cos(2.92331490635 + 102769.65321801379*t)
	X0 += 0.00000000014*np.cos(5.66688710771 + 193937.98608932378*t)
	X0 += 0.00000000014*np.cos(2.27226995206 + 1058.8606653274*t)
	X0 += 0.00000000017*np.cos(3.47272468105 + 439.1283638482*t)
	X0 += 0.00000000015*np.cos(4.98128142959 + 51.2057253312*t)
	X0 += 0.00000000018*np.cos(3.88128660770 + 523.4711899711*t)
	X0 += 0.00000000016*np.cos(4.13091799370 + 104344.98400739678*t)
	X0 += 0.00000000014*np.cos(1.95123243708 + 26247.2048763664*t)
	X0 += 0.00000000014*np.cos(3.71239259413 + 25928.601406782*t)
	X0 += 0.00000000014*np.cos(3.53454927143 + 219.6618829134*t)
	X0 += 0.00000000015*np.cos(1.90941686167 + 30.7106720963*t)
	X0 += 0.00000000015*np.cos(5.21246865831 + 173511.41499690177*t)
	X0 += 0.00000000013*np.cos(5.70370503525 + 5.4166259714*t)
	X0 += 0.00000000013*np.cos(2.28227257639 + 50380.54783942739*t)
	X0 += 0.00000000014*np.cos(2.58219550011 + 292.0128472684*t)
	X0 += 0.00000000016*np.cos(3.86619726000 + 50910.238804522*t)
	X0 += 0.00000000018*np.cos(5.28683736240 + 45.2465826386*t)
	X0 += 0.00000000015*np.cos(1.80265598681 + 2655.5683724738*t)
	X0 += 0.00000000014*np.cos(1.68702875678 + 1070.4276304531*t)
	X0 += 0.00000000014*np.cos(5.78637079670 + 430.79097657*t)
	X0 += 0.00000000015*np.cos(2.01136997449 + 199.2844497575*t)
	X0 += 0.00000000014*np.cos(4.00457707297 + 429.5189521828*t)
	X0 += 0.00000000013*np.cos(2.97004270413 + 425.8474313506*t)
	X0 += 0.00000000014*np.cos(4.35629855542 + 153084.84390447979*t)
	X0 += 0.00000000014*np.cos(0.97437425190 + 282.4516197128*t)
	X0 += 0.00000000017*np.cos(1.83348947424 + 1151.4290041439*t)
	X0 += 0.00000000016*np.cos(3.71527476533 + 53814.87580033639*t)
	X0 += 0.00000000014*np.cos(0.41808098652 + 25234.70675982219*t)
	X0 += 0.00000000014*np.cos(4.45337551699 + 78149.27013603736*t)
	X0 += 0.00000000016*np.cos(4.39060666970 + 203041.89308344138*t)
	X0 += 0.00000000015*np.cos(6.07885192222 + 77616.69859140778*t)
	X0 += 0.00000000013*np.cos(4.21520509231 + 1585.8915015461*t)
	X0 += 0.00000000017*np.cos(0.48416118894 + 535.9107402181*t)
	X0 += 0.00000000013*np.cos(3.45936802493 + 46.470422916*t)
	X0 += 0.00000000013*np.cos(4.95992660397 + 25654.19140369739*t)
	X0 += 0.00000000016*np.cos(5.76249012660 + 418.5214360287*t)
	X0 += 0.00000000014*np.cos(4.39150540314 + 52161.57918914679*t)
	X0 += 0.00000000013*np.cos(3.90798490709 + 598.8434893694*t)
	X0 += 0.00000000016*np.cos(5.22774546552 + 638.4128136057*t)
	X0 += 0.00000000014*np.cos(0.84211332161 + 78378.14871340781*t)
	X0 += 0.00000000014*np.cos(0.69241893678 + 35833.2236974308*t)
	X0 += 0.00000000013*np.cos(0.46709169716 + 498.6714764576*t)
	X0 += 0.00000000014*np.cos(3.21771971652 + 26076.8574413103*t)
	X0 += 0.00000000014*np.cos(2.44590531469 + 26098.9488418381*t)
	X0 += 0.00000000016*np.cos(0.56654525193 + 51534.3927214094*t)
	X0 += 0.00000000013*np.cos(0.79337465407 + 1592.2542890215*t)
	X0 += 0.00000000015*np.cos(4.25318608646 + 945.2434557067*t)
	X0 += 0.00000000014*np.cos(4.45033215443 + 20043.6745601988*t)
	X0 += 0.00000000016*np.cos(5.92993311098 + 347.8844390456*t)
	X0 += 0.00000000014*np.cos(0.16692912019 + 36.7604375141*t)
	X0 += 0.00000000012*np.cos(3.75584044196 + 421.1815649046*t)
	X0 += 0.00000000014*np.cos(1.93515798949 + 198489.93958638258*t)
	X0 += 0.00000000015*np.cos(2.90133577623 + 205.4347889118*t)
	X0 += 0.00000000013*np.cos(0.54283839653 + 103718.82882698359*t)
	X0 += 0.00000000014*np.cos(2.49938225869 + 1550.939859646*t)
	X0 += 0.00000000016*np.cos(4.43529118981 + 1639.069517188*t)
	X0 += 0.00000000012*np.cos(4.01378199978 + 597.3590166611*t)
	X0 += 0.00000000012*np.cos(5.66254865130 + 122444.98726584678*t)
	X0 += 0.00000000016*np.cos(6.03889434600 + 34082.4315835984*t)
	X0 += 0.00000000012*np.cos(1.26244334627 + 25984.1209529936*t)
	X0 += 0.00000000012*np.cos(4.40118168494 + 26191.68533015479*t)
	X0 += 0.00000000014*np.cos(4.74015829600 + 53265.515074342*t)
	X0 += 0.00000000012*np.cos(3.84453802064 + 560.7104537316*t)
	X0 += 0.00000000012*np.cos(3.79179070423 + 35.4247226521*t)
	X0 += 0.00000000012*np.cos(1.71351399381 + 339.2864193365*t)
	X0 += 0.00000000014*np.cos(5.52394393779 + 147.1155165798*t)
	X0 += 0.00000000016*np.cos(1.82129928700 + 1289.9465010146*t)
	X0 += 0.00000000012*np.cos(5.94982180077 + 181659.72224941078*t)
	X0 += 0.00000000014*np.cos(3.98129674269 + 53399.624123927*t)
	X0 += 0.00000000014*np.cos(1.39672973940 + 192.6921676185*t)
	X0 += 0.00000000014*np.cos(0.98564818086 + 39.5056337615*t)
	X0 += 0.00000000012*np.cos(0.13991027783 + 53771.99272543299*t)
	X0 += 0.00000000012*np.cos(1.72516185425 + 43981.5309499398*t)
	X0 += 0.00000000014*np.cos(2.01080991907 + 7.1617311106*t)
	X0 += 0.00000000012*np.cos(5.92386757303 + 28199.55345495179*t)
	X0 += 0.00000000012*np.cos(4.15404190165 + 2317.8358618148*t)
	X0 += 0.00000000012*np.cos(4.59110069577 + 51596.1186961496*t)
	X0 += 0.00000000013*np.cos(0.25880243151 + 52024.75861330549*t)
	X0 += 0.00000000011*np.cos(4.64769916430 + 52911.68279668019*t)
	X0 += 0.00000000011*np.cos(1.89863893326 + 70383.6202713836*t)
	X0 += 0.00000000011*np.cos(0.00734522377 + 938.1299087059*t)
	X0 += 0.00000000012*np.cos(5.35882506787 + 608.404716925*t)
	X0 += 0.00000000015*np.cos(4.79472245666 + 103883.64757594238*t)
	X0 += 0.00000000012*np.cos(0.86405998048 + 166.828672522*t)
	X0 += 0.00000000014*np.cos(4.32477700221 + 27250.37784598199*t)
	X0 += 0.00000000012*np.cos(5.95648425326 + 527.9940440652*t)
	X0 += 0.00000000012*np.cos(4.66738670229 + 531.387886124*t)
	X0 += 0.00000000013*np.cos(5.01690772702 + 208173.53416749898*t)
	X0 += 0.00000000015*np.cos(0.03679463460 + 163298.12945069079*t)
	X0 += 0.00000000011*np.cos(2.17975116288 + 48713.5615772832*t)
	X0 += 0.00000000011*np.cos(4.53626771028 + 2015.6710861598*t)
	X0 += 0.00000000014*np.cos(1.00856446032 + 52755.49387014719*t)
	X0 += 0.00000000014*np.cos(2.05272684647 + 52041.69723356339*t)
	X0 += 0.00000000011*np.cos(3.36881418888 + 33.1371007917*t)
	X0 += 0.00000000012*np.cos(2.40230884933 + 130363.24963659538*t)
	X0 += 0.00000000014*np.cos(2.76750382786 + 1059.903195051*t)
	X0 += 0.00000000011*np.cos(5.14348161985 + 104276.83096772949*t)
	X0 += 0.00000000015*np.cos(2.03673871596 + 150.5264049811*t)
	X0 += 0.00000000013*np.cos(6.23673461623 + 432.2272651685*t)
	X0 += 0.00000000015*np.cos(5.02019535476 + 86457.98475793119*t)
	X0 += 0.00000000012*np.cos(3.91938817205 + 116.4260963429*t)
	X0 += 0.00000000013*np.cos(1.25530162701 + 52027.72755872209*t)
	X0 += 0.00000000013*np.cos(5.47892889469 + 205.6642835754*t)
	X0 += 0.00000000013*np.cos(3.20863649406 + 78469.89497315978*t)
	X0 += 0.00000000011*np.cos(3.18070767588 + 57503.2823915312*t)
	X0 += 0.00000000011*np.cos(2.09919951698 + 5.6290742925*t)
	X0 += 0.00000000011*np.cos(2.30875109886 + 333.8559407694*t)
	X0 += 0.00000000012*np.cos(2.30318503256 + 120.9913890524*t)
	X0 += 0.00000000011*np.cos(4.76409724067 + 528.2546764961*t)
	X0 += 0.00000000011*np.cos(5.85977371488 + 531.1272536931*t)
	X0 += 0.00000000011*np.cos(1.25057869011 + 20894.5360827764*t)
	X0 += 0.00000000012*np.cos(0.71489552500 + 51439.92976961659*t)
	X0 += 0.00000000012*np.cos(4.22401388053 + 52179.73843641149*t)
	X0 += 0.00000000011*np.cos(1.36669731999 + 206.9363079626*t)
	X0 += 0.00000000010*np.cos(0.52628058703 + 427.3489504014*t)
	X0 += 0.00000000012*np.cos(5.79488724906 + 19958.6061020676*t)
	X0 += 0.00000000011*np.cos(5.64222354696 + 641.41356173899*t)
	X0 += 0.00000000011*np.cos(2.96498568744 + 629.6023455755*t)
	X0 += 0.00000000011*np.cos(3.44074661251 + 150.0844619964*t)
	X0 += 0.00000000011*np.cos(1.70452703232 + 50536.73676596039*t)
	X0 += 0.00000000010*np.cos(3.96428676306 + 1891.2376709388*t)
	X0 += 0.00000000011*np.cos(3.59458961446 + 1148.2476104062*t)
	X0 += 0.00000000012*np.cos(2.51294543080 + 53757.76563143139*t)
	X0 += 0.00000000010*np.cos(2.79700804590 + 78339.97549599818*t)
	X0 += 0.00000000011*np.cos(4.88405989087 + 78800.51393681798*t)
	X0 += 0.00000000013*np.cos(5.16830110187 + 428.0826635843*t)
	X0 += 0.00000000011*np.cos(2.85370771355 + 209.1544938538*t)
	X0 += 0.00000000010*np.cos(4.25860529638 + 84944.93427812219*t)
	X0 += 0.00000000012*np.cos(6.06146445452 + 142871.55835826878*t)
	X0 += 0.00000000010*np.cos(0.83219814671 + 210.3301500214*t)
	X0 += 0.00000000011*np.cos(1.00519361513 + 244.318584075*t)
	X0 += 0.00000000014*np.cos(1.53374794610 + 183145.01295611398*t)
	X0 += 0.00000000014*np.cos(4.25769082986 + 381.6122406683*t)
	X0 += 0.00000000010*np.cos(3.55930973128 + 53093.73656913019*t)
	X0 += 0.00000000010*np.cos(1.32119540129 + 154408.65498906678*t)
	X0 += 0.00000000012*np.cos(1.00985107812 + 28.3111756513*t)
	X0 += 0.00000000010*np.cos(4.22443079945 + 415.2918581812*t)
	X0 += 0.00000000014*np.cos(2.93956277298 + 54344.56676543099*t)
	X0 += 0.00000000014*np.cos(1.44401516208 + 1173.5204046717*t)
	X0 += 0.00000000011*np.cos(4.32318890062 + 27.0873353739*t)
	X0 += 0.00000000011*np.cos(2.53121281826 + 78057.52387628538*t)
	X0 += 0.00000000010*np.cos(4.38248905741 + 605.9570363702*t)
	X0 += 0.00000000012*np.cos(1.32462443773 + 26149.62911631439*t)
	X0 += 0.00000000012*np.cos(4.33900059348 + 26026.177166834*t)
	X0 += 0.00000000013*np.cos(3.98017256784 + 212.4053235607*t)
	X0 += 0.00000000013*np.cos(0.90945359875 + 214.1928673153*t)
	X0 += 0.00000000010*np.cos(1.43862971027 + 25131.61398560359*t)
	X0 += 0.00000000010*np.cos(2.36278600509 + 91919.56991589899*t)
	X0 += 0.00000000010*np.cos(1.51395699369 + 867.4234757536*t)
	X0 += 0.00000000011*np.cos(2.02395638599 + 217.4436970222*t)
	X0 += 0.00000000014*np.cos(3.26945543294 + 53124.98189211819*t)
	X0 += 0.00000000013*np.cos(3.28064944943 + 378.6432952517*t)
	X0 += 0.00000000012*np.cos(5.83805070397 + 76041.85279012559*t)
	X0 += 0.00000000010*np.cos(3.56286217757 + 77940.20400806518*t)
	X0 += 0.00000000010*np.cos(4.17334109977 + 6751.0408403458*t)
	X0 += 0.00000000010*np.cos(0.50269108150 + 28791.5192962498*t)
	X0 += 0.00000000013*np.cos(5.65469308747 + 50270.341518208*t)
	X0 += 0.00000000011*np.cos(5.25033320568 + 77520.71936418998*t)
	X0 += 0.00000000011*np.cos(5.27964044996 + 39763.43339365039*t)
	X0 += 0.00000000010*np.cos(0.66820373958 + 636.9962720242*t)
	X0 += 0.00000000013*np.cos(0.95208862336 + 25241.820306823*t)
	X0 += 0.00000000010*np.cos(4.77279277602 + 181.806526049*t)
	X0 += 0.00000000013*np.cos(4.73304249071 + 60.7669528868*t)
	X0 += 0.00000000009*np.cos(2.58296270636 + 130593.29451835579*t)
	X0 += 0.00000000009*np.cos(1.93570258198 + 26513.8119180882*t)
	X0 += 0.00000000009*np.cos(3.72792244923 + 25661.9943650602*t)
	X0 += 0.00000000011*np.cos(1.50524823194 + 760.25553592*t)
	X0 += 0.00000000013*np.cos(2.90587483400 + 721.6494195302*t)
	X0 += 0.00000000013*np.cos(4.75978960525 + 26161.20026743319*t)
	X0 += 0.00000000013*np.cos(0.90383542596 + 26014.60601571519*t)
	X0 += 0.00000000010*np.cos(3.06250530365 + 24712.1293417284*t)
	X0 += 0.00000000010*np.cos(0.58477845760 + 460.5384408198*t)
	X0 += 0.00000000010*np.cos(2.43967897596 + 104991.50985261079*t)
	X0 += 0.00000000010*np.cos(1.24342292300 + 52061.40717623499*t)
	X0 += 0.00000000011*np.cos(5.57723740117 + 183674.70392120858*t)
	X0 += 0.00000000009*np.cos(3.68049453811 + 1159.2933106701*t)
	X0 += 0.00000000012*np.cos(1.24750093919 + 1041.2226829245*t)
	X0 += 0.00000000009*np.cos(5.98881741458 + 4371.8763667742*t)
	X0 += 0.00000000010*np.cos(5.16716938460 + 23384.2869868986*t)
	X0 += 0.00000000009*np.cos(2.37191444133 + 80174.90890793978*t)
	X0 += 0.00000000012*np.cos(3.47156983874 + 52396.2189255872*t)
	X0 += 0.00000000009*np.cos(3.96944968919 + 103189.13786188899*t)
	X0 += 0.00000000010*np.cos(0.54444836634 + 431.264057322*t)
	X0 += 0.00000000009*np.cos(0.21796861386 + 156547.08861034496*t)
	X0 += 0.00000000010*np.cos(3.86442437133 + 546.956440482*t)
	X0 += 0.00000000009*np.cos(2.34791148855 + 130285.73689738619*t)
	X0 += 0.00000000009*np.cos(5.73768781210 + 405.2575498736*t)
	X0 += 0.00000000012*np.cos(4.72677764054 + 450.9772132642*t)
	X0 += 0.00000000012*np.cos(3.19048334390 + 738.7972748386*t)
	X0 += 0.00000000009*np.cos(3.61118357787 + 104984.39630560997*t)
	X0 += 0.00000000011*np.cos(3.38048420918 + 19367.1891622328*t)
	X0 += 0.00000000009*np.cos(2.34685033934 + 24609.0365675098*t)
	X0 += 0.00000000009*np.cos(5.69493908628 + 76152.05911134499*t)
	X0 += 0.00000000009*np.cos(0.74268878384 + 76255.15188556358*t)
	X0 += 0.00000000009*np.cos(4.41648492428 + 31281.270200372*t)
	X0 += 0.00000000009*np.cos(2.41712554824 + 51130.65144696079*t)
	X0 += 0.00000000009*np.cos(3.64428252561 + 158746.17595363196*t)
	X0 += 0.00000000011*np.cos(5.44274383166 + 218.4069048687*t)
	X0 += 0.00000000009*np.cos(1.96969875107 + 52797.55008398759*t)
	X0 += 0.00000000009*np.cos(5.75989455513 + 1165.6560981455*t)
	X0 += 0.00000000009*np.cos(5.38585404056 + 24844.41553989579*t)
	X0 += 0.00000000009*np.cos(0.27777099065 + 27331.3907432526*t)
	X0 += 0.00000000010*np.cos(1.25786678282 + 230239.17477710896*t)
	X0 += 0.00000000009*np.cos(5.59272866151 + 528.4671248172*t)
	X0 += 0.00000000009*np.cos(0.03279656103 + 465.9550667912*t)
	X0 += 0.00000000009*np.cos(4.03973091884 + 156314.11975400719*t)
	X0 += 0.00000000008*np.cos(5.03177372934 + 530.914805372*t)
	X0 += 0.00000000009*np.cos(0.70755225378 + 754.0357607965*t)
	X0 += 0.00000000009*np.cos(1.62201862141 + 69.6737891366*t)
	X0 += 0.00000000010*np.cos(1.22710162921 + 4022.2625319642*t)
	X0 += 0.00000000008*np.cos(3.74557002417 + 91805.13062721379*t)
	X0 += 0.00000000009*np.cos(5.89077044915 + 23866.04650697719*t)
	X0 += 0.00000000009*np.cos(0.95857873027 + 114.43928868521*t)
	X0 += 0.00000000009*np.cos(1.64864876033 + 41.6444977756*t)
	X0 += 0.00000000008*np.cos(4.86069962324 + 405.9912630565*t)
	X0 += 0.00000000008*np.cos(2.65669489808 + 38634.3850806572*t)
	X0 += 0.00000000008*np.cos(3.04567788139 + 131.5469622218*t)
	X0 += 0.00000000011*np.cos(5.69314298563 + 46046.5092436418*t)
	X0 += 0.00000000008*np.cos(3.30595652486 + 1056.4611688824*t)
	X0 += 0.00000000010*np.cos(1.63940870221 + 448.6895914038*t)
	X0 += 0.00000000009*np.cos(0.74288994112 + 52190.03337714999*t)
	X0 += 0.00000000008*np.cos(3.29997540369 + 192.8522263129*t)
	X0 += 0.00000000011*np.cos(1.68540938250 + 1020.025054274*t)
	X0 += 0.00000000008*np.cos(6.03813286552 + 361.3778198643*t)
	X0 += 0.00000000010*np.cos(3.10787144925 + 391318.54712361297*t)
	X0 += 0.00000000009*np.cos(0.81265678038 + 101703.15774082378*t)
	X0 += 0.00000000010*np.cos(5.98984255240 + 381.3516082374*t)
	X0 += 0.00000000010*np.cos(0.76588647880 + 54060.70744656579*t)
	X0 += 0.00000000009*np.cos(4.70828980485 + 0.7507595254*t)
	X0 += 0.00000000010*np.cos(5.89858083622 + 189.1807054807*t)
	X0 += 0.00000000008*np.cos(0.33717409862 + 464.7312265138*t)
	X0 += 0.00000000010*np.cos(3.69315427501 + 2168.7604822826*t)
	X0 += 0.00000000008*np.cos(0.99970183807 + 6.592282139*t)
	X0 += 0.00000000009*np.cos(3.28890530109 + 36.5366883449*t)
	X0 += 0.00000000009*np.cos(2.36652271316 + 1485.2907067032*t)
	X0 += 0.00000000008*np.cos(2.14298858852 + 209658.82487420218*t)
	X0 += 0.00000000009*np.cos(3.83602212713 + 22595.33157470459*t)
	X0 += 0.00000000008*np.cos(3.42854022505 + 117893.03376878797*t)
	X0 += 0.00000000009*np.cos(0.89908538700 + 52171.87412988529*t)
	X0 += 0.00000000010*np.cos(3.77821648391 + 530.5847369719*t)
	X0 += 0.00000000010*np.cos(0.56246916446 + 528.7971932173*t)
	X0 += 0.00000000008*np.cos(0.66150337713 + 51876.67988887919*t)
	X0 += 0.00000000009*np.cos(4.72230764398 + 556.5176680376*t)
	X0 += 0.00000000011*np.cos(4.78735190834 + 28096.46068073319*t)
	X0 += 0.00000000008*np.cos(4.43807120661 + 422.405405182*t)
	X0 += 0.00000000008*np.cos(2.16844090943 + 128106.31931499895*t)
	X0 += 0.00000000008*np.cos(0.74099606624 + 77956.15180375299*t)
	X0 += 0.00000000009*np.cos(3.62993346343 + 2854.6403739102*t)
	X0 += 0.00000000009*np.cos(4.29850392051 + 29.2049475286*t)
	X0 += 0.00000000008*np.cos(3.85222972174 + 100.3844612329*t)
	X0 += 0.00000000008*np.cos(2.46215429910 + 52400.1510788503*t)
	X0 += 0.00000000008*np.cos(6.23579223483 + 411.620337349*t)
	X0 += 0.00000000008*np.cos(2.46081725742 + 10681.2505365654*t)
	X0 += 0.00000000008*np.cos(0.68482481630 + 1058.6311706638*t)
	X0 += 0.00000000008*np.cos(4.46257369959 + 54824.2611086214*t)
	X0 += 0.00000000010*np.cos(3.07618265192 + 240452.46032331996*t)
	X0 += 0.00000000008*np.cos(0.55712719908 + 77741.13200662879*t)
	X0 += 0.00000000008*np.cos(0.42508106268 + 42790.9652750732*t)
	X0 += 0.00000000008*np.cos(4.91506773158 + 533.8355666788*t)
	X0 += 0.00000000008*np.cos(0.46834372601 + 462.0229135281*t)
	X0 += 0.00000000008*np.cos(4.70625369395 + 52489.992463018*t)
	X0 += 0.00000000008*np.cos(3.86744165099 + 156520.30530244438*t)
	X0 += 0.00000000007*np.cos(5.42400420261 + 26933.9859763254*t)
	X0 += 0.00000000008*np.cos(5.78385088790 + 0.5212648618*t)
	X0 += 0.00000000008*np.cos(6.22890340169 + 79.889407998*t)
	X0 += 0.00000000007*np.cos(6.06395790305 + 52206.1331441528*t)
	X0 += 0.00000000008*np.cos(3.94629223845 + 333.657345044*t)
	X0 += 0.00000000008*np.cos(2.15800762997 + 17098.43543614181*t)
	X0 += 0.00000000009*np.cos(4.26734987210 + 39.7293829307*t)
	X0 += 0.00000000008*np.cos(2.98826447179 + 120.358249606*t)
	X0 += 0.00000000007*np.cos(4.72158791300 + 50290.905119731*t)
	X0 += 0.00000000007*np.cos(4.89759618258 + 521.8266585684*t)
	X0 += 0.00000000010*np.cos(4.49694993347 + 22065.64060961*t)
	X0 += 0.00000000008*np.cos(2.65028306976 + 51112.49219969609*t)
	X0 += 0.00000000009*np.cos(2.14235988572 + 104454.70534051539*t)
	X0 += 0.00000000008*np.cos(5.30486076185 + 3308.4658953804*t)
	X0 += 0.00000000007*np.cos(4.81486070504 + 412.5835451955*t)
	X0 += 0.00000000007*np.cos(0.15046277095 + 313.2104759189*t)
	X0 += 0.00000000009*np.cos(2.63948646596 + 395.578702239*t)
	X0 += 0.00000000009*np.cos(0.18123663037 + 710.7467316182*t)
	X0 += 0.00000000007*np.cos(0.10534331873 + 244.791664827*t)
	X0 += 0.00000000008*np.cos(5.75679711029 + 525.5463635104*t)
	X0 += 0.00000000007*np.cos(4.59358863317 + 19.1224551112*t)
	X0 += 0.00000000007*np.cos(5.72649982853 + 537.5552716208*t)
	X0 += 0.00000000010*np.cos(0.23615439292 + 456.3938392356*t)
	X0 += 0.00000000007*np.cos(1.10080961200 + 27360.58416720139*t)
	X0 += 0.00000000007*np.cos(1.58965037142 + 233.7459645631*t)
	X0 += 0.00000000008*np.cos(0.11827657719 + 187167.27548807819*t)
	X0 += 0.00000000009*np.cos(4.39445007595 + 156507.74908854539*t)
	X0 += 0.00000000008*np.cos(1.73038484337 + 1062.302691496*t)
	X0 += 0.00000000010*np.cos(3.49567833493 + 259.769518354*t)
	X0 += 0.00000000008*np.cos(3.78820033364 + 103.3534066495*t)
	X0 += 0.00000000007*np.cos(3.52893695460 + 1064.7985561606*t)
	X0 += 0.00000000007*np.cos(0.74218080416 + 51086.09749195479*t)
	X0 += 0.00000000008*np.cos(5.53615944362 + 149288.74325784518*t)
	X0 += 0.00000000007*np.cos(3.50458401378 + 1063.5747158832*t)
	X0 += 0.00000000007*np.cos(3.70441477670 + 233681.74972207438*t)
	X0 += 0.00000000007*np.cos(2.34002720858 + 104248.51979207818*t)
	X0 += 0.00000000008*np.cos(5.03600399329 + 77314.53381575279*t)
	X0 += 0.00000000007*np.cos(1.59729628741 + 29396.3690369546*t)
	X0 += 0.00000000007*np.cos(4.06632874380 + 22779.4372461938*t)
	X0 += 0.00000000007*np.cos(5.95614295602 + 26290.15653674829*t)
	X0 += 0.00000000007*np.cos(5.99066738237 + 25885.64974640009*t)
	X0 += 0.00000000009*np.cos(1.08053818223 + 49.9966219042*t)
	X0 += 0.00000000009*np.cos(4.25855108963 + 148.5999892881*t)
	X0 += 0.00000000008*np.cos(4.35494896361 + 1060.1326897146*t)
	X0 += 0.00000000007*np.cos(4.18123300134 + 216.2680408546*t)
	X0 += 0.00000000007*np.cos(3.03792135842 + 156740.71794488319*t)
	X0 += 0.00000000010*np.cos(3.37701481763 + 2703.6161546756*t)
	X0 += 0.00000000008*np.cos(6.18508958274 + 129.9194771616*t)
	X0 += 0.00000000009*np.cos(1.51395746159 + 32132.1317229496*t)
	X0 += 0.00000000008*np.cos(4.55619991306 + 78571.26704569219*t)
	X0 += 0.00000000007*np.cos(3.14378763001 + 52663.44103440259*t)
	X0 += 0.00000000008*np.cos(4.91272317043 + 102872.74599223239*t)
	X0 += 0.00000000007*np.cos(4.34382102751 + 917.9302859818*t)
	X0 += 0.00000000007*np.cos(0.43580348099 + 52073.84376488279*t)
	X0 += 0.00000000008*np.cos(1.89853583330 + 214.9436268407*t)
	X0 += 0.00000000008*np.cos(2.99109033329 + 211.6545640353*t)
	X0 += 0.00000000007*np.cos(3.67619371722 + 149846.19399604558*t)
	X0 += 0.00000000007*np.cos(4.30856641724 + 77417.62658997139*t)
	X0 += 0.00000000007*np.cos(0.72133340576 + 229.9738699944*t)
	X0 += 0.00000000009*np.cos(2.82114719216 + 2957.7331481288*t)
	X0 += 0.00000000009*np.cos(2.22375687747 + 90989.16285949759*t)
	X0 += 0.00000000007*np.cos(0.27683273956 + 81591.84508100279*t)
	X0 += 0.00000000009*np.cos(1.15427906487 + 56259.79478985279*t)
	X0 += 0.00000000007*np.cos(3.54737716837 + 212.4959462859*t)
	X0 += 0.00000000007*np.cos(1.34224899822 + 214.1022445901*t)
	X0 += 0.00000000008*np.cos(2.42480688145 + 73.88782669*t)
	X0 += 0.00000000008*np.cos(5.39618820814 + 75.6753704446*t)
	X0 += 0.00000000008*np.cos(2.28353993312 + 32808.6171209156*t)
	X0 += 0.00000000008*np.cos(3.72293090245 + 49.1787359017*t)
	X0 += 0.00000000008*np.cos(1.79224996176 + 207114.15223730978*t)
	return X0




def Mercury_X1 (t):

	X1 = 0.
	X1 += 0.00317551960
	X1 += 0.00105289001*np.cos(5.91600475006 + 52175.8062831484*t)
	X1 += 0.00032315996*np.cos(2.68247273347 + 78263.70942472259*t)
	X1 += 0.00011992887*np.cos(5.81575112963 + 26087.9031415742*t)
	X1 += 0.00008783198*np.cos(5.73285747425 + 104351.61256629678*t)
	X1 += 0.00002329042*np.cos(2.50023793407 + 130439.51570787099*t)
	X1 += 0.00000898287*np.cos(1.13017425408 + 426.598190876*t)
	X1 += 0.00000776911*np.cos(2.70599281665 + 206.1855484372*t)
	X1 += 0.00000753642*np.cos(2.19133343324 + 220.4126424388*t)
	X1 += 0.00000614473*np.cos(5.55087602844 + 156527.41884944518*t)
	X1 += 0.00000602819*np.cos(3.22822215396 + 1059.3819301892*t)
	X1 += 0.00000572532*np.cos(5.56996049465 + 522.5774180938*t)
	X1 += 0.00000561468*np.cos(5.05753062697 + 536.8045120954*t)
	X1 += 0.00000162192*np.cos(2.31836529248 + 182615.32199101939*t)
	X1 += 0.00000100287*np.cos(3.47715618774 + 7.1135470008*t)
	X1 += 0.00000073443*np.cos(0.36984753681 + 639.897286314*t)
	X1 += 0.00000069028*np.cos(2.91494938058 + 24978.5245894808*t)
	X1 += 0.00000087678*np.cos(1.66401690533 + 419.4846438752*t)
	X1 += 0.00000062918*np.cos(2.73196853262 + 27197.2816936676*t)
	X1 += 0.00000053900*np.cos(1.32943493723 + 433.7117378768*t)
	X1 += 0.00000057346*np.cos(4.24284649448 + 213.299095438*t)
	X1 += 0.00000045572*np.cos(3.51792093438 + 1589.0728952838*t)
	X1 += 0.00000031683*np.cos(4.88628812414 + 1052.2683831884*t)
	X1 += 0.00000042904*np.cos(5.36906063918 + 208703.22513259358*t)
	X1 += 0.00000030504*np.cos(5.46040119636 + 1066.49547719*t)
	X1 += 0.00000031093*np.cos(0.93710976966 + 529.6909650946*t)
	X1 += 0.00000032055*np.cos(2.84895644824 + 149.5631971346*t)
	X1 += 0.00000021371*np.cos(0.56918433581 + 316.3918696566*t)
	X1 += 0.00000018990*np.cos(2.06104675595 + 227.5261894396*t)
	X1 += 0.00000017519*np.cos(5.96830863185 + 51066.427731055*t)
	X1 += 0.00000014011*np.cos(4.17820222846 + 110.2063212194*t)
	X1 += 0.00000013252*np.cos(5.78388474441 + 53285.1848352418*t)
	X1 += 0.00000015902*np.cos(5.77753655907 + 76.2660712756*t)
	X1 += 0.00000012374*np.cos(5.70562636316 + 515.463871093*t)
	X1 += 0.00000011874*np.cos(0.17869376191 + 1109.3785520934*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000011836*np.cos(3.04995551356 + 632.7837393132*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000011337*np.cos(0.34748083260 + 20426.571092422*t)
	X1 += 0.00000011379*np.cos(2.13659786081 + 234791.12827416777*t)
	X1 += 0.00000010223*np.cos(2.19747174258 + 73.297125859*t)
	X1 += 0.00000009014*np.cos(2.86872754290 + 199.0720014364*t)
	X1 += 0.00000008667*np.cos(4.92419711400 + 543.9180590962*t)
	X1 += 0.00000007752*np.cos(3.01481452904 + 949.1756089698*t)
	X1 += 0.00000007532*np.cos(2.70649061616 + 103.0927742186*t)
	X1 += 0.00000008364*np.cos(5.31326841022 + 31749.2351907264*t)
	X1 += 0.00000006296*np.cos(5.47576447612 + 4551.9534970588*t)
	X1 += 0.00000005640*np.cos(6.01550572633 + 853.196381752*t)
	X1 += 0.00000005158*np.cos(1.94900517603 + 209.3669421749*t)
	X1 += 0.00000005079*np.cos(2.96229494906 + 217.2312487011*t)
	X1 += 0.00000004830*np.cos(0.25724123783 + 21535.9496445154*t)
	X1 += 0.00000004653*np.cos(1.72782369127 + 216.4804891757*t)
	X1 += 0.00000004541*np.cos(3.17727011849 + 210.1177017003*t)
	X1 += 0.00000004443*np.cos(0.77043699175 + 323.5054166574*t)
	X1 += 0.00000004843*np.cos(2.73719284227 + 77154.33087262919*t)
	X1 += 0.00000004233*np.cos(3.49063898076 + 63.7358983034*t)
	X1 += 0.00000004247*np.cos(3.39407863893 + 46514.4742339962*t)
	X1 += 0.00000004143*np.cos(0.52208765222 + 647.0108333148*t)
	X1 += 0.00000004379*np.cos(5.09788247126 + 25132.3033999656*t)
	X1 += 0.00000004989*np.cos(3.32377727482 + 14.2270940016*t)
	X1 += 0.00000004317*np.cos(4.28882152308 + 735.8765135318*t)
	X1 += 0.00000004008*np.cos(4.41606139947 + 27147.28507176339*t)
	X1 += 0.00000003755*np.cos(4.17884091449 + 14765.2390432698*t)
	X1 += 0.00000004311*np.cos(4.26366834787 + 51116.4243529592*t)
	X1 += 0.00000003833*np.cos(0.53521442894 + 27043.5028831828*t)
	X1 += 0.00000003445*np.cos(4.34972240938 + 85.8272988312*t)
	X1 += 0.00000003338*np.cos(2.34738225115 + 11.0457002639*t)
	X1 += 0.00000003244*np.cos(6.04240714038 + 526.5095713569*t)
	X1 += 0.00000003181*np.cos(4.57837074085 + 532.8723588323*t)
	X1 += 0.00000003147*np.cos(1.09831959010 + 26617.5941066688*t)
	X1 += 0.00000003134*np.cos(4.68201320654 + 25558.2121764796*t)
	X1 += 0.00000002903*np.cos(4.79566936964 + 525.7588118315*t)
	X1 += 0.00000002864*np.cos(5.82538312855 + 533.6231183577*t)
	X1 += 0.00000002876*np.cos(2.69265723530 + 117.3198682202*t)
	X1 += 0.00000003026*np.cos(5.18732430310 + 260879.03141574195*t)
	X1 += 0.00000002833*np.cos(2.05576755359 + 202.2533951741*t)
	X1 += 0.00000002892*np.cos(5.42640574300 + 26107.57290247399*t)
	X1 += 0.00000002888*np.cos(0.22490912553 + 26068.2333806744*t)
	X1 += 0.00000003213*np.cos(3.80941439686 + 2118.7638603784*t)
	X1 += 0.00000002372*np.cos(2.07173805606 + 26084.0218062162*t)
	X1 += 0.00000002367*np.cos(3.57959596454 + 26091.7844769322*t)
	X1 += 0.00000002514*np.cos(0.74093420826 + 95.9792272178*t)
	X1 += 0.00000002060*np.cos(1.47444774290 + 37410.5672398786*t)
	X1 += 0.00000002055*np.cos(5.42893438245 + 138.5174968707*t)
	X1 += 0.00000001996*np.cos(3.76028525032 + 742.9900605326*t)
	X1 += 0.00000001995*np.cos(5.43702405397 + 30639.856638633*t)
	X1 += 0.00000001993*np.cos(2.49283396541 + 79373.08797681599*t)
	X1 += 0.00000001852*np.cos(5.84724393667 + 1596.1864422846*t)
	X1 += 0.00000001901*np.cos(1.95608888549 + 956.2891559706*t)
	X1 += 0.00000001882*np.cos(0.21679831472 + 47623.8527860896*t)
	X1 += 0.00000001668*np.cos(3.43481125656 + 70.8494453042*t)
	X1 += 0.00000001581*np.cos(1.69266319262 + 9103.9069941176*t)
	X1 += 0.00000001582*np.cos(4.31392718266 + 955.5997416086*t)
	X1 += 0.00000001570*np.cos(4.37765395011 + 78.7137518304*t)
	X1 += 0.00000001491*np.cos(1.26055544534 + 440.8252848776*t)
	X1 += 0.00000001888*np.cos(4.97969744328 + 1581.959348283*t)
	X1 += 0.00000001500*np.cos(0.43230658391 + 19317.1925403286*t)
	X1 += 0.00000001393*np.cos(0.16139897514 + 72602.37737557039*t)
	X1 += 0.00000001561*np.cos(4.53702050944 + 1045.1548361876*t)
	X1 += 0.00000001444*np.cos(1.95141505182 + 74.7815985673*t)
	X1 += 0.00000001356*np.cos(3.28177198592 + 50586.73338786459*t)
	X1 += 0.00000001586*np.cos(3.69811718912 + 12566.1516999828*t)
	X1 += 0.00000001633*np.cos(3.97827565764 + 224.3447957019*t)
	X1 += 0.00000001205*np.cos(3.93561468963 + 52705.49724824299*t)
	X1 += 0.00000001291*np.cos(2.48193614053 + 26095.016688575*t)
	X1 += 0.00000001468*np.cos(2.98912712521 + 23869.1460373874*t)
	X1 += 0.00000001247*np.cos(3.22538051848 + 26080.78959457339*t)
	X1 += 0.00000001170*np.cos(5.49212997481 + 3442.5749449654*t)
	X1 += 0.00000001101*np.cos(1.21730591912 + 53235.18821333759*t)
	X1 += 0.00000001161*np.cos(4.49256510074 + 625.6701923124*t)
	X1 += 0.00000001372*np.cos(5.78877124476 + 103242.23401420339*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000001238*np.cos(1.82183266298 + 51220.20654153979*t)
	X1 += 0.00000001188*np.cos(2.63716562694 + 28306.66024576099*t)
	X1 += 0.00000000995*np.cos(5.66894017064 + 1265.5674786264*t)
	X1 += 0.00000000966*np.cos(3.56558363028 + 53131.406024757*t)
	X1 += 0.00000000857*np.cos(0.94331413205 + 40853.142184844*t)
	X1 += 0.00000000853*np.cos(5.33085598917 + 27676.976036858*t)
	X1 += 0.00000000828*np.cos(1.04707260283 + 25874.6040461362*t)
	X1 += 0.00000000891*np.cos(5.15325597213 + 32858.61374281979*t)
	X1 += 0.00000000806*np.cos(1.95470061860 + 286966.93455731616*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000000938*np.cos(4.56608679745 + 1169.5882514086*t)
	X1 += 0.00000000797*np.cos(4.63253542288 + 26301.2022370122*t)
	X1 += 0.00000000943*np.cos(1.78153635749 + 151.0476698429*t)
	X1 += 0.00000000965*np.cos(1.55576378944 + 412.3710968744*t)
	X1 += 0.00000000867*np.cos(2.13196527993 + 83925.04147387479*t)
	X1 += 0.00000000769*np.cos(3.16951506066 + 942.062061969*t)
	X1 += 0.00000000981*np.cos(0.13945164140 + 22645.32819660879*t)
	X1 += 0.00000000732*np.cos(2.19417873413 + 56727.7597802072*t)
	X1 += 0.00000000808*np.cos(4.76289394654 + 36301.18868778519*t)
	X1 += 0.00000000721*np.cos(1.50346938110 + 18849.2275499742*t)
	X1 += 0.00000000703*np.cos(2.68691048153 + 6770.7106012456*t)
	X1 += 0.00000000772*np.cos(5.23111667516 + 11322.6640983044*t)
	X1 += 0.00000000765*np.cos(1.88382728885 + 39609.6545831656*t)
	X1 += 0.00000000768*np.cos(4.99147918103 + 1155.361157407*t)
	X1 += 0.00000000662*np.cos(3.27821203278 + 52156.1365222486*t)
	X1 += 0.00000000711*np.cos(3.39057215594 + 71.8126531507*t)
	X1 += 0.00000000719*np.cos(4.52061983489 + 77.7505439839*t)
	X1 += 0.00000000619*np.cos(3.92327916834 + 43071.8992890308*t)
	X1 += 0.00000000666*np.cos(0.85409428955 + 15874.6175953632*t)
	X1 += 0.00000000607*np.cos(2.02898715788 + 5661.3320491522*t)
	X1 += 0.00000000627*np.cos(0.70425946008 + 51646.11531805379*t)
	X1 += 0.00000000572*np.cos(2.30412060804 + 309.2783226558*t)
	X1 += 0.00000000736*np.cos(3.24301495973 + 1162.4747044078*t)
	X1 += 0.00000000533*np.cos(0.35442356295 + 52179.6876185064*t)
	X1 += 0.00000000621*np.cos(1.43632380898 + 25028.521211385*t)
	X1 += 0.00000000651*np.cos(5.48424947861 + 29530.4780865396*t)
	X1 += 0.00000000510*np.cos(3.90147691268 + 277.0349937414*t)
	X1 += 0.00000000525*np.cos(4.93316232438 + 26514.5013324502*t)
	X1 += 0.00000000500*np.cos(0.52252923934 + 38654.05484155699*t)
	X1 += 0.00000000507*np.cos(4.51932253005 + 63498.47038145279*t)
	X1 += 0.00000000486*np.cos(0.82245463791 + 422.6660376129*t)
	X1 += 0.00000000467*np.cos(5.15486312196 + 110012.94461544899*t)
	X1 += 0.00000000519*np.cos(2.18877626983 + 52195.47604404819*t)
	X1 += 0.00000000455*np.cos(2.72961773990 + 1692.1656695024*t)
	X1 += 0.00000000439*np.cos(3.21217330239 + 98690.28051714458*t)
	X1 += 0.00000000436*np.cos(4.11931609127 + 33326.5787331742*t)
	X1 += 0.00000000486*np.cos(3.63985026707 + 51749.20809227239*t)
	X1 += 0.00000000527*np.cos(0.13511199028 + 2218.7571041868*t)
	X1 += 0.00000000419*np.cos(1.64150782899 + 7238.67559160*t)
	X1 += 0.00000000433*np.cos(5.12287491235 + 52171.9249477904*t)
	X1 += 0.00000000391*np.cos(5.30832534377 + 1073.6090241908*t)
	X1 += 0.00000000386*np.cos(2.03457265559 + 58946.51688439399*t)
	X1 += 0.00000000388*np.cos(0.61592624795 + 78793.40038981718*t)
	X1 += 0.00000000374*np.cos(1.92168872074 + 234.6397364404*t)
	X1 += 0.00000000402*np.cos(6.00790488958 + 52168.69273614759*t)
	X1 += 0.00000000359*np.cos(1.17874036143 + 846.0828347512*t)
	X1 += 0.00000000384*np.cos(0.93539249733 + 330.6189636582*t)
	X1 += 0.00000000371*np.cos(5.54353838421 + 415.5524906121*t)
	X1 += 0.00000000354*np.cos(1.51714429161 + 62389.09182935939*t)
	X1 += 0.00000000343*np.cos(6.05819298032 + 860.3099287528*t)
	X1 += 0.00000000337*np.cos(4.75525977824 + 71.6002048296*t)
	X1 += 0.00000000370*np.cos(0.98752045979 + 103292.23063610759*t)
	X1 += 0.00000000326*np.cos(4.29715521116 + 79323.09135491178*t)
	X1 += 0.00000000324*np.cos(2.28921417158 + 423.4167971383*t)
	X1 += 0.00000000392*np.cos(2.55718962178 + 129330.13715577759*t)
	X1 += 0.00000000382*np.cos(5.51179087871 + 52182.9198301492*t)
	X1 += 0.00000000401*np.cos(5.75972783493 + 54394.56338733519*t)
	X1 += 0.00000000324*np.cos(3.05393333292 + 77.962992305*t)
	X1 += 0.00000000398*np.cos(3.03220486245 + 1478.8665740644*t)
	X1 += 0.00000000317*np.cos(6.10262679977 + 76674.63652943878*t)
	X1 += 0.00000000316*np.cos(0.91375113764 + 429.7795846137*t)
	X1 += 0.00000000361*np.cos(2.21089537404 + 2.9689454166*t)
	X1 += 0.00000000305*np.cos(5.55791649320 + 145.6310438715*t)
	X1 += 0.00000000374*np.cos(4.41343415577 + 728.762966531*t)
	X1 += 0.00000000322*np.cos(6.04526148570 + 49957.0491789616*t)
	X1 += 0.00000000325*np.cos(4.04813766509 + 68050.42387851159*t)
	X1 += 0.00000000383*np.cos(6.13188528401 + 210.8514148832*t)
	X1 += 0.00000000380*np.cos(5.05058792236 + 215.7467759928*t)
	X1 += 0.00000000312*np.cos(4.91137892283 + 51535.90899683439*t)
	X1 += 0.00000000366*np.cos(4.84960838633 + 77308.10968311399*t)
	X1 += 0.00000000315*np.cos(3.48940938594 + 45405.0956819028*t)
	X1 += 0.00000000318*np.cos(4.23654189229 + 13655.8604911764*t)
	X1 += 0.00000000338*np.cos(5.87862918623 + 148.0787244263*t)
	X1 += 0.00000000255*np.cos(2.25536828287 + 437.6438911399*t)
	X1 += 0.00000000311*np.cos(5.13228886176 + 838.9692877504*t)
	X1 += 0.00000000237*np.cos(2.28726007142 + 3.9321532631*t)
	X1 += 0.00000000259*np.cos(1.48788758809 + 52389.1053785864*t)
	X1 += 0.00000000266*np.cos(5.06649873732 + 38.1330356378*t)
	X1 += 0.00000000234*np.cos(1.60395818860 + 223.5940361765*t)
	X1 += 0.00000000230*np.cos(5.23970398210 + 82815.66292178139*t)
	X1 += 0.00000000230*np.cos(0.83436604790 + 51123.53789995999*t)
	X1 += 0.00000000221*np.cos(5.85413979591 + 508.3503240922*t)
	X1 += 0.00000000235*np.cos(0.14479942195 + 48733.23133818299*t)
	X1 += 0.00000000222*np.cos(3.99294043990 + 66941.04532641819*t)
	X1 += 0.00000000215*np.cos(5.00570874902 + 313054.83769889036*t)
	X1 += 0.00000000227*np.cos(4.13725657267 + 2648.454825473*t)
	X1 += 0.00000000234*np.cos(4.87225306441 + 1272.6810256272*t)
	X1 += 0.00000000207*np.cos(0.32441801559 + 24498.8302462904*t)
	X1 += 0.00000000208*np.cos(1.13897731894 + 57837.1383323006*t)
	X1 += 0.00000000274*np.cos(1.31712695932 + 51109.31080595839*t)
	X1 += 0.00000000218*np.cos(3.35990718284 + 32370.9789915656*t)
	X1 += 0.00000000197*np.cos(2.05074719141 + 53764.8791784322*t)
	X1 += 0.00000000195*np.cos(0.73253707200 + 69159.80243060499*t)
	X1 += 0.00000000201*np.cos(4.02545532193 + 129380.13377768178*t)
	X1 += 0.00000000195*np.cos(2.67914149669 + 50057.04242277*t)
	X1 += 0.00000000200*np.cos(4.46579555836 + 44937.1306915484*t)
	X1 += 0.00000000186*np.cos(1.91764312607 + 136100.84775702319*t)
	X1 += 0.00000000200*np.cos(6.03453757404 + 1375.7737998458*t)
	X1 += 0.00000000179*np.cos(5.25460376556 + 105460.99111839019*t)
	X1 += 0.00000000183*np.cos(2.74450109107 + 10213.285546211*t)
	X1 += 0.00000000174*np.cos(3.75890575398 + 51962.5071877104*t)
	X1 += 0.00000000170*np.cos(0.05120008168 + 78244.0396638228*t)
	X1 += 0.00000000172*np.cos(0.78909849325 + 94138.32702008578*t)
	X1 += 0.00000000199*np.cos(2.97222353917 + 430.5303441391*t)
	X1 += 0.00000000188*np.cos(1.83168099087 + 124.433415221*t)
	X1 += 0.00000000173*np.cos(0.50653444879 + 1368.660252845*t)
	X1 += 0.00000000166*np.cos(4.99522557947 + 1062.5633239269*t)
	X1 += 0.00000000157*np.cos(3.59078806709 + 64741.95798313119*t)
	X1 += 0.00000000156*np.cos(0.89517325452 + 59414.4818747484*t)
	X1 += 0.00000000162*np.cos(2.48823301223 + 16983.9961474566*t)
	X1 += 0.00000000164*np.cos(2.91444613296 + 3.1813937377*t)
	X1 += 0.00000000174*np.cos(1.61176269489 + 65.2203710117*t)
	X1 += 0.00000000163*np.cos(0.77052245905 + 88.865680217*t)
	X1 += 0.00000000155*np.cos(4.69757523405 + 35191.8101356918*t)
	X1 += 0.00000000153*np.cos(0.79359507111 + 160.6088973985*t)
	X1 += 0.00000000154*np.cos(6.16274455061 + 519.3960243561*t)
	X1 += 0.00000000147*np.cos(1.70693555948 + 52602.4044740244*t)
	X1 += 0.00000000159*np.cos(1.72220460391 + 6681.2248533996*t)
	X1 += 0.00000000154*np.cos(2.29441335016 + 19804.8272915828*t)
	X1 += 0.00000000140*np.cos(5.84592048082 + 1258.4539316256*t)
	X1 += 0.00000000181*np.cos(2.25156652773 + 55618.3812281138*t)
	X1 += 0.00000000155*np.cos(3.39294110953 + 99799.65906923798*t)
	X1 += 0.00000000138*np.cos(5.22139410630 + 1055.4497769261*t)
	X1 += 0.00000000138*np.cos(6.20163548170 + 25973.46385288896*t)
	X1 += 0.00000000138*np.cos(5.74171028268 + 26202.34243025941*t)
	X1 += 0.00000000190*np.cos(3.87246923080 + 26727.8004278882*t)
	X1 += 0.00000000136*np.cos(0.07614870196 + 23754.70674870219*t)
	X1 += 0.00000000132*np.cos(0.46806671232 + 654.1243803156*t)
	X1 += 0.00000000135*np.cos(3.41426499833 + 78267.59076008058*t)
	X1 += 0.00000000128*np.cos(4.56870410553 + 88476.99497093359*t)
	X1 += 0.00000000139*np.cos(1.25262181717 + 77734.01845962799*t)
	X1 += 0.00000000134*np.cos(3.33556330332 + 203.0041546995*t)
	X1 += 0.00000000135*np.cos(6.26763497988 + 124778.18365871879*t)
	X1 += 0.00000000148*np.cos(1.14288127596 + 27154.3986187642*t)
	X1 += 0.00000000121*np.cos(6.23051481720 + 2125.8774073792*t)
	X1 += 0.00000000120*np.cos(0.17691589754 + 1063.3140834523*t)
	X1 += 0.00000000118*np.cos(4.77280443966 + 551.031606097*t)
	X1 += 0.00000000120*np.cos(4.45697558744 + 539.9859058331*t)
	X1 += 0.00000000118*np.cos(5.25266695461 + 12432.0426503978*t)
	X1 += 0.00000000121*np.cos(3.61637465924 + 104881.30353139139*t)
	X1 += 0.00000000116*np.cos(4.75079129151 + 25934.1243310894*t)
	X1 += 0.00000000140*np.cos(5.86589845886 + 1056.2005364515*t)
	X1 += 0.00000000113*np.cos(0.89519838976 + 26241.681952059*t)
	X1 += 0.00000000111*np.cos(5.69390808885 + 222.8603229936*t)
	X1 += 0.00000000133*np.cos(4.62837772547 + 22.0914005278*t)
	X1 += 0.00000000110*np.cos(5.99510808456 + 28206.6670019526*t)
	X1 += 0.00000000145*np.cos(1.02699984744 + 25661.3049506982*t)
	X1 += 0.00000000108*np.cos(1.68420561967 + 27140.17152476259*t)
	X1 += 0.00000000115*np.cos(4.02826839099 + 103821.92160120218*t)
	X1 += 0.00000000106*np.cos(5.56501238566 + 28421.0995344462*t)
	X1 += 0.00000000144*np.cos(1.47900802038 + 299.1263942692*t)
	X1 += 0.00000000113*np.cos(5.61187119686 + 155418.04029735178*t)
	X1 += 0.00000000113*np.cos(2.46071266285 + 5327.4761083828*t)
	X1 += 0.00000000109*np.cos(5.11428178041 + 2111.6503133776*t)
	X1 += 0.00000000134*np.cos(3.16966777445 + 21.3406410024*t)
	X1 += 0.00000000136*np.cos(2.92809875864 + 1485.9801210652*t)
	X1 += 0.00000000100*np.cos(3.51095185925 + 25619.9381512198*t)
	X1 += 0.00000000097*np.cos(5.41467539027 + 18.1592472647*t)
	X1 += 0.00000000096*np.cos(3.08170402360 + 191.9584544356*t)
	X1 += 0.00000000130*np.cos(1.24930068630 + 38519.945791972*t)
	X1 += 0.00000000101*np.cos(5.56349300645 + 2333.196392872*t)
	X1 += 0.00000000096*np.cos(2.14218398324 + 26555.8681319286*t)
	X1 += 0.00000000117*np.cos(1.76096469784 + 7994.5284420242*t)
	X1 += 0.00000000120*np.cos(4.77545420807 + 1574.8458012822*t)
	X1 += 0.00000000094*np.cos(3.27399866756 + 74821.13447975718*t)
	X1 += 0.00000000094*np.cos(3.31739742370 + 87.3117715395*t)
	X1 += 0.00000000101*np.cos(1.27086316315 + 33.6796175129*t)
	X1 += 0.00000000109*np.cos(1.60677184759 + 103396.01282468818*t)
	X1 += 0.00000000097*np.cos(1.08688412870 + 105410.99449648599*t)
	X1 += 0.00000000094*np.cos(2.74336450397 + 78256.59587772179*t)
	X1 += 0.00000000110*np.cos(6.08725694137 + 79219.30916633119*t)
	X1 += 0.00000000095*np.cos(0.09924693440 + 58458.88213313979*t)
	X1 += 0.00000000122*np.cos(0.24302263595 + 84.3428261229*t)
	X1 += 0.00000000103*np.cos(4.94647459474 + 91785.46086631398*t)
	X1 += 0.00000000088*np.cos(2.61301107864 + 73711.75592766379*t)
	X1 += 0.00000000097*np.cos(5.87982327909 + 217.964961884*t)
	X1 += 0.00000000089*np.cos(0.10217527089 + 125887.56221081219*t)
	X1 += 0.00000000087*np.cos(3.32576161903 + 231.4583427027*t)
	X1 += 0.00000000097*np.cos(1.64179644592 + 72.3339180125*t)
	X1 += 0.00000000089*np.cos(5.45720829907 + 628.8515860501*t)
	X1 += 0.00000000082*np.cos(0.79472961749 + 155468.03691925599*t)
	X1 += 0.00000000088*np.cos(5.00348782624 + 1699.2792165032*t)
	X1 += 0.00000000082*np.cos(1.77469219848 + 77623.81213840858*t)
	X1 += 0.00000000097*np.cos(5.37398198079 + 71980.63357473118*t)
	X1 += 0.00000000081*np.cos(3.12863861827 + 41962.5207369374*t)
	X1 += 0.00000000081*np.cos(1.26377078095 + 12.5301729722*t)
	X1 += 0.00000000081*np.cos(2.81711911396 + 76044.9523205358*t)
	X1 += 0.00000000086*np.cos(3.03921945697 + 127.4717966068*t)
	X1 += 0.00000000080*np.cos(5.04229374313 + 26137.8997634784*t)
	X1 += 0.00000000085*np.cos(5.30523639998 + 208.633228992*t)
	X1 += 0.00000000080*np.cos(0.61667373644 + 26037.90651966999*t)
	X1 += 0.00000000104*np.cos(2.27911229916 + 78270.82297172339*t)
	X1 += 0.00000000080*np.cos(4.03019573108 + 1471.7530270636*t)
	X1 += 0.00000000076*np.cos(5.75771357218 + 288.0806940053*t)
	X1 += 0.00000000103*np.cos(5.23326876495 + 78283.37918562238*t)
	X1 += 0.00000000088*np.cos(1.89491499121 + 78259.82808936459*t)
	X1 += 0.00000000076*np.cos(4.59002761471 + 64607.84893354619*t)
	X1 += 0.00000000077*np.cos(0.52151658040 + 18207.81398823521*t)
	X1 += 0.00000000096*np.cos(6.22255663987 + 203.7378678824*t)
	X1 += 0.00000000083*np.cos(3.91650291052 + 77211.44104153418*t)
	X1 += 0.00000000076*np.cos(0.40948960322 + 362.8622925726*t)
	X1 += 0.00000000082*np.cos(4.38336427974 + 77197.21394753258*t)
	X1 += 0.00000000072*np.cos(3.81559276845 + 302.164775655*t)
	X1 += 0.00000000075*np.cos(1.95113506965 + 525.0250986486*t)
	X1 += 0.00000000079*np.cos(2.47113265383 + 80482.46652890938*t)
	X1 += 0.00000000069*np.cos(4.21368560293 + 114.3991069134*t)
	X1 += 0.00000000068*np.cos(0.64071253014 + 153.4953503977*t)
	X1 += 0.00000000068*np.cos(0.16388050208 + 9.5612275556*t)
	X1 += 0.00000000068*np.cos(0.99582401938 + 73.8183907208*t)
	X1 += 0.00000000068*np.cos(5.02161386487 + 85034.42002596818*t)
	X1 += 0.00000000067*np.cos(3.83221093171 + 120226.23016165999*t)
	X1 += 0.00000000071*np.cos(2.38708525663 + 534.3568315406*t)
	X1 += 0.00000000065*np.cos(4.96292091927 + 162188.75089859738*t)
	X1 += 0.00000000064*np.cos(0.53528518109 + 75.7448064138*t)
	X1 += 0.00000000064*np.cos(2.43966713771 + 102762.53967101299*t)
	X1 += 0.00000000071*np.cos(2.00840081014 + 108903.56606335558*t)
	X1 += 0.00000000062*np.cos(3.28305785024 + 51756.3216392732*t)
	X1 += 0.00000000066*np.cos(6.17786477200 + 42.5864537627*t)
	X1 += 0.00000000061*np.cos(2.88776849923 + 207.8824694666*t)
	X1 += 0.00000000060*np.cos(2.02282855033 + 218.7157214094*t)
	X1 += 0.00000000070*np.cos(0.83559773197 + 52.6901980395*t)
	X1 += 0.00000000059*np.cos(1.24623136375 + 408.4389436113*t)
	X1 += 0.00000000067*np.cos(0.58534149028 + 152.5321425512*t)
	X1 += 0.00000000078*np.cos(3.78933172192 + 25565.3257234804*t)
	X1 += 0.00000000076*np.cos(0.10784891475 + 77.2292791221*t)
	X1 += 0.00000000064*np.cos(3.30054842989 + 79.2350166922*t)
	X1 += 0.00000000061*np.cos(0.45486168004 + 56.6223513026*t)
	X1 += 0.00000000078*np.cos(0.26259075737 + 71492.99882347698*t)
	X1 += 0.00000000076*np.cos(4.60309339869 + 78477.00852016058*t)
	X1 += 0.00000000063*np.cos(0.77267148826 + 93028.94846799239*t)
	X1 += 0.00000000076*np.cos(3.91621214261 + 51742.09454527159*t)
	X1 += 0.00000000057*np.cos(5.54251181480 + 76144.94556434419*t)
	X1 += 0.00000000055*np.cos(3.57207397234 + 340.7708920448*t)
	X1 += 0.00000000057*np.cos(1.77596246202 + 339142.74084046457*t)
	X1 += 0.00000000055*np.cos(3.08168513239 + 200.7689224658*t)
	X1 += 0.00000000076*np.cos(2.25541605095 + 146.594251718*t)
	X1 += 0.00000000060*np.cos(5.32793915897 + 831.8557407496*t)
	X1 += 0.00000000057*np.cos(1.70642283566 + 117873.36400788819*t)
	X1 += 0.00000000054*np.cos(2.83216128661 + 1.4844727083*t)
	X1 += 0.00000000064*np.cos(5.39890155177 + 13521.7514415914*t)
	X1 += 0.00000000066*np.cos(5.83578469159 + 618.5566453116*t)
	X1 += 0.00000000059*np.cos(1.21407442533 + 71025.03383312259*t)
	X1 += 0.00000000058*np.cos(0.97037460116 + 4.4534181249*t)
	X1 += 0.00000000052*np.cos(2.64769510305 + 2008.557539159*t)
	X1 += 0.00000000054*np.cos(5.76743595117 + 51322.60990139639*t)
	X1 += 0.00000000051*np.cos(3.56752380688 + 225.8292684102*t)
	X1 += 0.00000000053*np.cos(5.07040569914 + 79852.78232000639*t)
	X1 += 0.00000000051*np.cos(4.54732927101 + 62.2514255951*t)
	X1 += 0.00000000053*np.cos(0.21733504041 + 78050.41032928458*t)
	X1 += 0.00000000064*np.cos(5.43530311047 + 1685.0521225016*t)
	X1 += 0.00000000050*np.cos(4.84629478021 + 195.1398481733*t)
	X1 += 0.00000000059*np.cos(3.03603648397 + 2221.856634597*t)
	X1 += 0.00000000052*np.cos(2.15957506124 + 98068.53671630539*t)
	X1 += 0.00000000051*np.cos(6.00939227801 + 131548.89425996438*t)
	X1 += 0.00000000052*np.cos(4.61821041475 + 70.3281804424*t)
	X1 += 0.00000000049*np.cos(4.31351627712 + 350.3321196004*t)
	X1 += 0.00000000049*np.cos(0.37484483697 + 90829.86112470538*t)
	X1 += 0.00000000054*np.cos(1.04718616168 + 10021.8372800994*t)
	X1 += 0.00000000066*np.cos(1.83477065457 + 26610.48055966799*t)
	X1 += 0.00000000051*np.cos(1.79926614465 + 210.3783341312*t)
	X1 += 0.00000000051*np.cos(3.07938265367 + 216.2198567448*t)
	X1 += 0.00000000049*np.cos(5.92307582908 + 963.4027029714*t)
	X1 += 0.00000000061*np.cos(5.73208306041 + 1795.258443721*t)
	X1 += 0.00000000053*np.cos(1.27341801656 + 142.4496501338*t)
	X1 += 0.00000000050*np.cos(5.30296789488 + 81706.28436968799*t)
	X1 += 0.00000000045*np.cos(4.80760215190 + 37.611770776*t)
	X1 += 0.00000000051*np.cos(0.72899300866 + 129909.82474277639*t)
	X1 += 0.00000000050*np.cos(4.51633294079 + 1038.0412891868*t)
	X1 += 0.00000000044*np.cos(5.63991949724 + 524.2743391232*t)
	X1 += 0.00000000044*np.cos(2.67440279390 + 38.6543004996*t)
	X1 += 0.00000000056*np.cos(3.55772283134 + 26624.70765366959*t)
	X1 += 0.00000000045*np.cos(3.09839778780 + 104331.94280539699*t)
	X1 += 0.00000000044*np.cos(4.98395147244 + 535.107591066*t)
	X1 += 0.00000000043*np.cos(4.78106693432 + 78690.30761559859*t)
	X1 += 0.00000000042*np.cos(1.33862549536 + 114564.89811250778*t)
	X1 += 0.00000000043*np.cos(4.16006907854 + 74.6697239827*t)
	X1 += 0.00000000043*np.cos(3.66062507509 + 74.8934731519*t)
	X1 += 0.00000000049*np.cos(5.77857770467 + 207.6700211455*t)
	X1 += 0.00000000049*np.cos(1.81278199589 + 131.4039498699*t)
	X1 += 0.00000000040*np.cos(5.84877872776 + 23969.1392811958*t)
	X1 += 0.00000000047*np.cos(2.28831256912 + 109.9456887885*t)
	X1 += 0.00000000043*np.cos(0.49578719152 + 103925.01437542078*t)
	X1 += 0.00000000052*np.cos(1.00605916556 + 39743.7636327506*t)
	X1 += 0.00000000039*np.cos(1.67338261788 + 1382.8873468466*t)
	X1 += 0.00000000041*np.cos(2.93602685311 + 10.2949407385*t)
	X1 += 0.00000000038*np.cos(0.10561582384 + 77204.32749453338*t)
	X1 += 0.00000000038*np.cos(4.40087475081 + 703.6331846174*t)
	X1 += 0.00000000038*np.cos(4.96138824900 + 33967.99229491319*t)
	X1 += 0.00000000046*np.cos(5.36914408518 + 218.9281697305*t)
	X1 += 0.00000000037*np.cos(3.14446623632 + 151975.46535238638*t)
	X1 += 0.00000000049*np.cos(0.75521435692 + 50579.61984086379*t)
	X1 += 0.00000000037*np.cos(3.08060535588 + 22759.76748529401*t)
	X1 += 0.00000000049*np.cos(2.25743098712 + 25551.09862947879*t)
	X1 += 0.00000000037*np.cos(4.39032344034 + 511.5317178299*t)
	X1 += 0.00000000043*np.cos(4.80730811274 + 26521.614879451*t)
	X1 += 0.00000000035*np.cos(3.18489263300 + 84546.78527471398*t)
	X1 += 0.00000000040*np.cos(0.70008569909 + 52815.7035694624*t)
	X1 += 0.00000000035*np.cos(5.85809750059 + 565.1156877467*t)
	X1 += 0.00000000034*np.cos(0.93646404165 + 26190.99591579279*t)
	X1 += 0.00000000044*np.cos(2.62980232477 + 7880.08915333899*t)
	X1 += 0.00000000041*np.cos(3.03548824144 + 150866.08680029298*t)
	X1 += 0.00000000035*np.cos(6.22608295766 + 547.8502123593*t)
	X1 += 0.00000000040*np.cos(5.00668302258 + 26294.08869001139*t)
	X1 += 0.00000000034*np.cos(0.85062194570 + 89586.37352302698*t)
	X1 += 0.00000000035*np.cos(2.53628638096 + 157636.79740153858*t)
	X1 += 0.00000000038*np.cos(3.93290315553 + 490.3340891794*t)
	X1 += 0.00000000034*np.cos(5.54907603693 + 750.1036075334*t)
	X1 += 0.00000000041*np.cos(0.57259526223 + 25881.717593137*t)
	X1 += 0.00000000037*np.cos(6.26293750649 + 635.9651330509*t)
	X1 += 0.00000000041*np.cos(4.17638990278 + 52329.58509363319*t)
	X1 += 0.00000000042*np.cos(6.01467005956 + 26507.38778544939*t)
	X1 += 0.00000000033*np.cos(4.72754895093 + 25984.8103673556*t)
	X1 += 0.00000000036*np.cos(3.68841887913 + 44181.27784112419*t)
	X1 += 0.00000000033*np.cos(1.27875804610 + 50593.84693486539*t)
	X1 += 0.00000000038*np.cos(5.99103573925 + 483.2205421786*t)
	X1 += 0.00000000035*np.cos(4.68155089578 + 526.7702037878*t)
	X1 += 0.00000000035*np.cos(5.94254789616 + 532.6117264014*t)
	X1 += 0.00000000036*np.cos(0.34367134726 + 130969.20667296558*t)
	X1 += 0.00000000036*np.cos(0.18284823248 + 104355.49390165479*t)
	X1 += 0.00000000032*np.cos(2.37243073610 + 181505.94343892598*t)
	X1 += 0.00000000036*np.cos(3.11876877578 + 46848.3301747656*t)
	X1 += 0.00000000031*np.cos(1.18565768932 + 447.9388318784*t)
	X1 += 0.00000000032*np.cos(1.30247204488 + 105307.21230790539*t)
	X1 += 0.00000000030*np.cos(0.44298905817 + 209.106309744*t)
	X1 += 0.00000000030*np.cos(1.59264152747 + 92.940845832*t)
	X1 += 0.00000000032*np.cos(4.64178119595 + 129483.91596626239*t)
	X1 += 0.00000000030*np.cos(5.20322865236 + 52643.7712735028*t)
	X1 += 0.00000000030*np.cos(4.44526322933 + 217.491881132*t)
	X1 += 0.00000000035*np.cos(1.72609608211 + 265.9892934775*t)
	X1 += 0.00000000031*np.cos(2.51185507502 + 52290.24557183361*t)
	X1 += 0.00000000029*np.cos(5.24573487183 + 25668.418497699*t)
	X1 += 0.00000000028*np.cos(3.34466525843 + 80.1982245387*t)
	X1 += 0.00000000028*np.cos(3.83067185571 + 181555.94006083018*t)
	X1 += 0.00000000038*np.cos(4.84405555580 + 6283.0758499914*t)
	X1 += 0.00000000031*np.cos(4.73782198518 + 51639.00177105299*t)
	X1 += 0.00000000029*np.cos(2.51843531665 + 29416.03879785439*t)
	X1 += 0.00000000029*np.cos(4.21426623259 + 53242.3017603384*t)
	X1 += 0.00000000027*np.cos(4.35707854664 + 1279.794572628*t)
	X1 += 0.00000000031*np.cos(5.18940920282 + 424.1505103212*t)
	X1 += 0.00000000028*np.cos(3.64092818784 + 95247.70557217918*t)
	X1 += 0.00000000033*np.cos(0.34449594524 + 269.9214467406*t)
	X1 += 0.00000000027*np.cos(4.81466818286 + 1802.3719907218*t)
	X1 += 0.00000000026*np.cos(2.32663083381 + 54509.0026760204*t)
	X1 += 0.00000000026*np.cos(2.95753849706 + 52061.36699446317*t)
	X1 += 0.00000000025*np.cos(5.13721031791 + 42153.969003049*t)
	X1 += 0.00000000027*np.cos(5.82028492837 + 1898.3512179396*t)
	X1 += 0.00000000030*np.cos(2.99039613509 + 26941.0995233262*t)
	X1 += 0.00000000025*np.cos(0.42860125930 + 29428.515568274*t)
	X1 += 0.00000000029*np.cos(4.14866394337 + 131498.89763806018*t)
	X1 += 0.00000000028*np.cos(5.32578029265 + 104358.72611329758*t)
	X1 += 0.00000000029*np.cos(1.60408389107 + 25448.00585526019*t)
	X1 += 0.00000000025*np.cos(1.67779796211 + 26237.46633870879*t)
	X1 += 0.00000000024*np.cos(5.28807279458 + 22747.2907148744*t)
	X1 += 0.00000000024*np.cos(2.71950429042 + 54294.57014352679*t)
	X1 += 0.00000000023*np.cos(0.58725165783 + 146314.13330323418*t)
	X1 += 0.00000000023*np.cos(1.56475852877 + 650.9429865779*t)
	X1 += 0.00000000023*np.cos(4.85605613315 + 35.685355083*t)
	X1 += 0.00000000027*np.cos(4.52767940172 + 25021.4076643842*t)
	X1 += 0.00000000022*np.cos(4.74442146801 + 143961.26714946238*t)
	X1 += 0.00000000023*np.cos(3.78299370119 + 25035.6347583858*t)
	X1 += 0.00000000023*np.cos(4.85338065767 + 28.5718080822*t)
	X1 += 0.00000000022*np.cos(0.71803323367 + 337.732510659*t)
	X1 += 0.00000000023*np.cos(0.11555144192 + 643.0786800517*t)
	X1 += 0.00000000025*np.cos(0.72182905302 + 52026.2430860138*t)
	X1 += 0.00000000026*np.cos(1.72512030163 + 27684.0895838588*t)
	X1 += 0.00000000023*np.cos(4.51155345742 + 284.1485407422*t)
	X1 += 0.00000000023*np.cos(1.73611078502 + 188276.65404017158*t)
	X1 += 0.00000000021*np.cos(5.86830807135 + 102132.85546210999*t)
	X1 += 0.00000000023*np.cos(1.39950717748 + 61279.713277266*t)
	X1 += 0.00000000022*np.cos(3.49214829498 + 130012.91751699499*t)
	X1 += 0.00000000021*np.cos(5.78709952320 + 104344.49901929598*t)
	X1 += 0.00000000023*np.cos(6.22294900930 + 191.2076949102*t)
	X1 += 0.00000000027*np.cos(1.37714604800 + 13362.4497067992*t)
	X1 += 0.00000000021*np.cos(0.34726135597 + 137.0330241624*t)
	X1 += 0.00000000022*np.cos(0.10565363711 + 77844.22478084739*t)
	X1 += 0.00000000021*np.cos(2.62420739411 + 40.5807161926*t)
	X1 += 0.00000000021*np.cos(5.21078068231 + 124156.43985787958*t)
	X1 += 0.00000000021*np.cos(3.37519693925 + 934.9485149682*t)
	X1 += 0.00000000021*np.cos(2.93989832001 + 525.4981794006*t)
	X1 += 0.00000000021*np.cos(2.38516672571 + 85502.38501632259*t)
	X1 += 0.00000000023*np.cos(4.92629143648 + 540.7366653585*t)
	X1 += 0.00000000027*np.cos(0.68051286566 + 103299.34418310839*t)
	X1 += 0.00000000021*np.cos(1.14211463317 + 103285.11708910679*t)
	X1 += 0.00000000023*np.cos(0.59531277141 + 1361.5467058442*t)
	X1 += 0.00000000020*np.cos(4.96664866905 + 103711.71527998279*t)
	X1 += 0.00000000021*np.cos(2.16986734764 + 49527.35145767539*t)
	X1 += 0.00000000025*np.cos(0.38304523465 + 96.8729990951*t)
	X1 += 0.00000000026*np.cos(2.05285271079 + 60055.89543648739*t)
	X1 += 0.00000000023*np.cos(0.68702668183 + 77829.99768684579*t)
	X1 += 0.00000000027*np.cos(6.21242304915 + 1905.4647649404*t)
	X1 += 0.00000000020*np.cos(5.54734924390 + 251.4321310758*t)
	X1 += 0.00000000024*np.cos(4.91328411886 + 219.4494345923*t)
	X1 += 0.00000000019*np.cos(3.64972257327 + 52125.80966124419*t)
	X1 += 0.00000000022*np.cos(0.84681454741 + 70269.18098269838*t)
	X1 += 0.00000000019*np.cos(0.04587600812 + 3328.13565628019*t)
	X1 += 0.00000000022*np.cos(1.42374321926 + 104564.91166173479*t)
	X1 += 0.00000000020*np.cos(3.55117744188 + 81.8951455681*t)
	X1 += 0.00000000025*np.cos(0.01235262119 + 24864.08530079559*t)
	X1 += 0.00000000019*np.cos(5.60700670343 + 106570.36967048359*t)
	X1 += 0.00000000025*np.cos(5.65750865200 + 27311.72098235281*t)
	X1 += 0.00000000021*np.cos(1.17914689008 + 344.7030453079*t)
	X1 += 0.00000000018*np.cos(4.78075197963 + 53228.07466633679*t)
	X1 += 0.00000000017*np.cos(1.99727427214 + 479.2883889155*t)
	X1 += 0.00000000018*np.cos(2.62651922515 + 47.6942631934*t)
	X1 += 0.00000000020*np.cos(3.30348564295 + 97580.90196505119*t)
	X1 += 0.00000000018*np.cos(2.61349776359 + 113.3877149571*t)
	X1 += 0.00000000021*np.cos(1.98272438830 + 104371.28232719658*t)
	X1 += 0.00000000017*np.cos(2.59293571203 + 77410.51304297059*t)
	X1 += 0.00000000017*np.cos(4.48959133859 + 235.3904959658*t)
	X1 += 0.00000000018*np.cos(0.65002779822 + 66.70484372*t)
	X1 += 0.00000000020*np.cos(3.91482329597 + 131395.11544947959*t)
	X1 += 0.00000000018*np.cos(0.82070318043 + 436.8931316145*t)
	X1 += 0.00000000017*np.cos(3.10260674166 + 104138.31347085879*t)
	X1 += 0.00000000016*np.cos(5.70285177091 + 1603.2999892854*t)
	X1 += 0.00000000017*np.cos(0.76245918828 + 909.8187330546*t)
	X1 += 0.00000000018*np.cos(0.68490378171 + 358.9301393095*t)
	X1 += 0.00000000021*np.cos(5.05260717886 + 134991.46920492979*t)
	X1 += 0.00000000016*np.cos(6.20867250288 + 100909.03762133139*t)
	X1 += 0.00000000017*np.cos(2.39497408205 + 18093.37469954999*t)
	X1 += 0.00000000017*np.cos(1.44060402818 + 533.8837507886*t)
	X1 += 0.00000000019*np.cos(0.01647605955 + 207.1487562837*t)
	X1 += 0.00000000017*np.cos(1.09605096689 + 417.0369633204*t)
	X1 += 0.00000000016*np.cos(4.32698359511 + 12546.481939083*t)
	X1 += 0.00000000016*np.cos(5.18072747317 + 1788.1448967202*t)
	X1 += 0.00000000018*np.cos(4.91279767114 + 52698.38370124219*t)
	X1 += 0.00000000016*np.cos(0.84901493535 + 25867.49049913539*t)
	X1 += 0.00000000017*np.cos(5.41405900055 + 497.4476361802*t)
	X1 += 0.00000000016*np.cos(5.55931175273 + 183724.70054311278*t)
	X1 += 0.00000000017*np.cos(1.54418014066 + 115674.27666460119*t)
	X1 += 0.00000000017*np.cos(4.81848703132 + 128850.44281258718*t)
	X1 += 0.00000000015*np.cos(2.38102656379 + 16066.0658614748*t)
	X1 += 0.00000000017*np.cos(0.59320479310 + 2.4476805548*t)
	X1 += 0.00000000016*np.cos(5.49478140063 + 175.1660598002*t)
	X1 += 0.00000000016*np.cos(4.29457970004 + 67.6680515665*t)
	X1 += 0.00000000017*np.cos(4.80393132096 + 51528.79544983359*t)
	X1 += 0.00000000020*np.cos(6.13069123005 + 11610.5519583742*t)
	X1 += 0.00000000019*np.cos(3.74384920337 + 155997.72788435058*t)
	X1 += 0.00000000014*np.cos(3.58173383909 + 44295.7171298094*t)
	X1 += 0.00000000015*np.cos(5.15304621208 + 220.4608265486*t)
	X1 += 0.00000000015*np.cos(2.07746651676 + 107794.18751126219*t)
	X1 += 0.00000000014*np.cos(4.52566394568 + 3178.1457905676*t)
	X1 += 0.00000000018*np.cos(4.53931120962 + 51543.0225438352*t)
	X1 += 0.00000000015*np.cos(4.93940053675 + 26308.315784013*t)
	X1 += 0.00000000015*np.cos(4.99636225149 + 518.6452648307*t)
	X1 += 0.00000000015*np.cos(1.33651838433 + 26164.1692128498*t)
	X1 += 0.00000000015*np.cos(0.95581113217 + 146.3818033969*t)
	X1 += 0.00000000015*np.cos(2.26943407259 + 102232.84870591838*t)
	X1 += 0.00000000018*np.cos(3.82088730679 + 119116.85160956658*t)
	X1 += 0.00000000018*np.cos(5.91863678140 + 45494.58142974879*t)
	X1 += 0.00000000015*np.cos(5.17830960776 + 26222.0121911592*t)
	X1 += 0.00000000014*np.cos(2.27264864715 + 416.3032501375*t)
	X1 += 0.00000000019*np.cos(3.55838458417 + 554.0699874828*t)
	X1 += 0.00000000014*np.cos(5.18725769632 + 1049.0869894507*t)
	X1 += 0.00000000015*np.cos(1.74258697688 + 52225.8029050526*t)
	X1 += 0.00000000015*np.cos(3.82786291889 + 76667.52298243798*t)
	X1 += 0.00000000014*np.cos(4.77147651749 + 27999.1026247914*t)
	X1 += 0.00000000018*np.cos(4.93958674569 + 104347.73123093879*t)
	X1 += 0.00000000014*np.cos(3.43030204306 + 116917.76426627958*t)
	X1 += 0.00000000014*np.cos(5.07734306466 + 351.8165923087*t)
	X1 += 0.00000000015*np.cos(4.82510142643 + 365230.64398203876*t)
	X1 += 0.00000000013*np.cos(0.92750711335 + 24176.703658357*t)
	X1 += 0.00000000014*np.cos(0.49576253379 + 25953.79409198919*t)
	X1 += 0.00000000013*np.cos(6.18203275911 + 178063.36849396059*t)
	X1 += 0.00000000017*np.cos(4.23443256776 + 97112.93697469679*t)
	X1 += 0.00000000014*np.cos(4.66254689609 + 429.0458714308*t)
	X1 += 0.00000000015*np.cos(0.24698669297 + 52712.61079524379*t)
	X1 += 0.00000000015*np.cos(0.87904326630 + 4.665866446*t)
	X1 += 0.00000000015*np.cos(1.05658470808 + 52099.5402118728*t)
	X1 += 0.00000000015*np.cos(5.80214824265 + 181.0557665236*t)
	X1 += 0.00000000013*np.cos(4.30617411007 + 76681.75007643958*t)
	X1 += 0.00000000013*np.cos(5.74254354304 + 55503.94193942859*t)
	X1 += 0.00000000016*np.cos(3.48059820580 + 404.5067903482*t)
	X1 += 0.00000000015*np.cos(1.28342499223 + 27669.86248985719*t)
	X1 += 0.00000000014*np.cos(1.82228184088 + 105940.68546158058*t)
	X1 += 0.00000000012*np.cos(1.79845456663 + 111122.32316754239*t)
	X1 += 0.00000000013*np.cos(3.31209041530 + 14477.35118320*t)
	X1 += 0.00000000012*np.cos(1.90118101257 + 636.7158925763*t)
	X1 += 0.00000000012*np.cos(1.57036398698 + 104778.21075717278*t)
	X1 += 0.00000000013*np.cos(4.39267521476 + 140652.80125408198*t)
	X1 += 0.00000000012*np.cos(1.33521638588 + 52072.71350892979*t)
	X1 += 0.00000000013*np.cos(0.94980339171 + 82.8583534146*t)
	X1 += 0.00000000013*np.cos(5.40390266847 + 245.5424243524*t)
	X1 += 0.00000000012*np.cos(4.66725197197 + 111590.28815789679*t)
	X1 += 0.00000000013*np.cos(5.40346920033 + 205.2223405907*t)
	X1 += 0.00000000013*np.cos(5.26586760806 + 501.3797894433*t)
	X1 += 0.00000000012*np.cos(5.96461527769 + 867.4234757536*t)
	X1 += 0.00000000013*np.cos(4.74446229064 + 14.977853527*t)
	X1 += 0.00000000012*np.cos(6.21958146278 + 72936.23331633979*t)
	X1 += 0.00000000015*np.cos(1.55251538013 + 20760.4270331914*t)
	X1 += 0.00000000011*np.cos(2.98365933273 + 25977.69682035479*t)
	X1 += 0.00000000012*np.cos(6.24533055094 + 110634.68841628819*t)
	X1 += 0.00000000012*np.cos(1.33415706168 + 99.9113804809*t)
	X1 += 0.00000000011*np.cos(1.32350368373 + 131.5469622218*t)
	X1 += 0.00000000011*np.cos(5.26972998156 + 2214.7430875962*t)
	X1 += 0.00000000013*np.cos(3.64005382686 + 145.1097790097*t)
	X1 += 0.00000000014*np.cos(1.03063178545 + 78417.48823520739*t)
	X1 += 0.00000000011*np.cos(3.57047418140 + 36109.7404216736*t)
	X1 += 0.00000000011*np.cos(2.67619239702 + 26198.1094627936*t)
	X1 += 0.00000000012*np.cos(2.37418300803 + 211.8146227297*t)
	X1 += 0.00000000014*np.cos(5.29903467924 + 77837.11123384659*t)
	X1 += 0.00000000012*np.cos(5.21668700555 + 31415.379249957*t)
	X1 += 0.00000000011*np.cos(4.12038634021 + 51969.62073471119*t)
	X1 += 0.00000000012*np.cos(6.15491126193 + 130419.8459469712*t)
	X1 += 0.00000000014*np.cos(4.59700663399 + 721.6494195302*t)
	X1 += 0.00000000010*np.cos(5.89161262846 + 214.0498549634*t)
	X1 += 0.00000000014*np.cos(2.66253684701 + 32769.1279949738*t)
	X1 += 0.00000000012*np.cos(5.63886804458 + 198.321241911*t)
	X1 += 0.00000000010*np.cos(4.79225001159 + 2104.5367663768*t)
	X1 += 0.00000000010*np.cos(4.24154253223 + 121.2520214833*t)
	X1 += 0.00000000010*np.cos(0.30174606733 + 28736.3579670472*t)
	X1 += 0.00000000010*np.cos(3.07835250801 + 643.8294395771*t)
	X1 += 0.00000000011*np.cos(0.76353498081 + 59.8037450403*t)
	X1 += 0.00000000010*np.cos(2.52434543093 + 444.7574381407*t)
	X1 += 0.00000000010*np.cos(6.02081320033 + 289.5651667136*t)
	X1 += 0.00000000011*np.cos(6.11985601662 + 206.1373643274*t)
	X1 += 0.00000000010*np.cos(1.78614915805 + 68241.87214462319*t)
	X1 += 0.00000000011*np.cos(3.53222769228 + 108.4612160802*t)
	X1 += 0.00000000011*np.cos(3.62051737282 + 65697.55772473979*t)
	X1 += 0.00000000012*np.cos(4.51767669506 + 38813.3565763492*t)
	X1 += 0.00000000010*np.cos(1.51502620255 + 170049.17029103659*t)
	X1 += 0.00000000010*np.cos(0.65896029584 + 157483.01859105378*t)
	X1 += 0.00000000012*np.cos(1.50419920446 + 12725.453434775*t)
	X1 += 0.00000000010*np.cos(2.48035088853 + 32.1951448046*t)
	X1 += 0.00000000010*np.cos(1.19722150187 + 405.2575498736*t)
	X1 += 0.00000000009*np.cos(1.11423953703 + 152.7445908723*t)
	X1 += 0.00000000010*np.cos(0.60086822741 + 207643.84320240439*t)
	X1 += 0.00000000012*np.cos(0.27544235334 + 26395.46076254379*t)
	X1 += 0.00000000012*np.cos(5.38818267787 + 25780.3455206046*t)
	X1 += 0.00000000009*np.cos(5.33634723608 + 212.5483359126*t)
	X1 += 0.00000000012*np.cos(4.18148179610 + 26724.8994135984*t)
	X1 += 0.00000000012*np.cos(1.48214323511 + 25450.90686955*t)
	X1 += 0.00000000010*np.cos(4.43951347141 + 141762.17980617538*t)
	X1 += 0.00000000009*np.cos(5.62764518642 + 51219.51712717779*t)
	X1 += 0.00000000013*np.cos(3.43354905286 + 114.1384744825*t)
	X1 += 0.00000000009*np.cos(1.40970085491 + 155571.81910783658*t)
	X1 += 0.00000000009*np.cos(2.12559306586 + 177.8743727859*t)
	X1 += 0.00000000009*np.cos(1.49177357269 + 140.001969579*t)
	X1 += 0.00000000009*np.cos(3.80728835859 + 78903.60671103658*t)
	X1 += 0.00000000009*np.cos(1.98340877635 + 78731.674415077*t)
	X1 += 0.00000000010*np.cos(1.06876588648 + 90695.75207512038*t)
	X1 += 0.00000000009*np.cos(1.26040337097 + 98.8999885246*t)
	X1 += 0.00000000012*np.cos(2.28213947586 + 25446.4895798352*t)
	X1 += 0.00000000012*np.cos(3.38148555535 + 26729.31670331319*t)
	X1 += 0.00000000009*np.cos(2.46965123782 + 112.9146342051*t)
	X1 += 0.00000000010*np.cos(1.61631506112 + 604.4725636619*t)
	X1 += 0.00000000009*np.cos(1.39179110846 + 33.9402499438*t)
	X1 += 0.00000000010*np.cos(4.04489455556 + 65831.6667743248*t)
	X1 += 0.00000000009*np.cos(1.97985537350 + 16703.062133499*t)
	X1 += 0.00000000009*np.cos(0.19461343328 + 51707.84129279399*t)
	X1 += 0.00000000009*np.cos(5.42812340959 + 207593.84658050018*t)
	X1 += 0.00000000010*np.cos(3.32445370552 + 3340.6124266998*t)
	X1 += 0.00000000009*np.cos(0.25320629703 + 156100.82065856918*t)
	X1 += 0.00000000009*np.cos(4.92060353422 + 275.5505210331*t)
	X1 += 0.00000000009*np.cos(0.24943313990 + 319.5732633943*t)
	X1 += 0.00000000012*np.cos(6.08675975595 + 176953.98994186718*t)
	X1 += 0.00000000010*np.cos(5.40172694346 + 1592.2542890215*t)
	X1 += 0.00000000010*np.cos(3.63300622629 + 373.9079928365*t)
	X1 += 0.00000000008*np.cos(5.39656213021 + 1148.2476104062*t)
	X1 += 0.00000000009*np.cos(0.88869633066 + 69.1525242748*t)
	X1 += 0.00000000010*np.cos(3.67062813456 + 2015.6710861598*t)
	X1 += 0.00000000011*np.cos(2.32296397326 + 52022.0274726636*t)
	X1 += 0.00000000009*np.cos(0.04502499664 + 49842.60989027639*t)
	X1 += 0.00000000009*np.cos(3.48790336223 + 55516.4187098482*t)
	X1 += 0.00000000009*np.cos(1.60659830268 + 52609.51802102519*t)
	X1 += 0.00000000009*np.cos(2.19657708690 + 1911.1994832172*t)
	X1 += 0.00000000011*np.cos(3.36653560664 + 157057.10981453978*t)
	X1 += 0.00000000010*np.cos(1.95365576783 + 52381.99183158559*t)
	X1 += 0.00000000011*np.cos(5.20033100734 + 842.1506814881*t)
	X1 += 0.00000000008*np.cos(2.92168007680 + 134.5853436076*t)
	X1 += 0.00000000008*np.cos(5.89998501862 + 52182.4348420484*t)
	X1 += 0.00000000009*np.cos(1.92127276195 + 561.934294009*t)
	X1 += 0.00000000008*np.cos(5.71207072786 + 1585.1407420207*t)
	X1 += 0.00000000008*np.cos(6.02739823377 + 5.9378908332*t)
	X1 += 0.00000000008*np.cos(0.07994652584 + 27177.6119327678*t)
	X1 += 0.00000000008*np.cos(5.58367850537 + 24998.19435038059*t)
	X1 += 0.00000000010*np.cos(4.18673679862 + 436.1594184316*t)
	X1 += 0.00000000008*np.cos(2.51541014083 + 214.7835681463*t)
	X1 += 0.00000000009*np.cos(3.91205376466 + 24491.71669928959*t)
	X1 += 0.00000000008*np.cos(2.20996366081 + 159.1244246902*t)
	X1 += 0.00000000009*np.cos(0.07320142790 + 414.0680179038*t)
	X1 += 0.00000000008*np.cos(2.77771386082 + 248.7238180901*t)
	X1 += 0.00000000009*np.cos(3.20602268861 + 19.66976089979*t)
	X1 += 0.00000000008*np.cos(6.13311048887 + 48847.6706268682*t)
	X1 += 0.00000000008*np.cos(6.18114959216 + 42.3258213318*t)
	X1 += 0.00000000010*np.cos(2.59673239232 + 297.6419215609*t)
	X1 += 0.00000000008*np.cos(5.54190257529 + 2001.4439921582*t)
	X1 += 0.00000000007*np.cos(5.62789688432 + 576.1613880106*t)
	X1 += 0.00000000009*np.cos(0.97094953096 + 621.7380390493*t)
	X1 += 0.00000000007*np.cos(4.63407107324 + 629.6023455755*t)
	X1 += 0.00000000008*np.cos(2.62449520780 + 355.7487455718*t)
	X1 += 0.00000000007*np.cos(0.88436036706 + 81.7521332162*t)
	X1 += 0.00000000007*np.cos(0.62849516745 + 9384.8410080752*t)
	X1 += 0.00000000007*np.cos(3.37283868879 + 50696.93970908399*t)
	X1 += 0.00000000008*np.cos(2.95337805438 + 52595.29092702359*t)
	X1 += 0.00000000008*np.cos(2.09085109942 + 130446.62925487179*t)
	X1 += 0.00000000008*np.cos(4.12633327906 + 31.019488637*t)
	X1 += 0.00000000007*np.cos(1.73606122812 + 320.3240229197*t)
	X1 += 0.00000000007*np.cos(3.72377229422 + 30.0562807905*t)
	X1 += 0.00000000007*np.cos(1.42009283525 + 427.5613987225*t)
	X1 += 0.00000000009*np.cos(3.23441439127 + 130443.39704322898*t)
	X1 += 0.00000000008*np.cos(4.23722680471 + 26720.68688088739*t)
	X1 += 0.00000000008*np.cos(5.65039159250 + 1223.81784077861*t)
	X1 += 0.00000000007*np.cos(0.50663219979 + 2655.5683724738*t)
	X1 += 0.00000000007*np.cos(4.46046826267 + 69.3649725959*t)
	X1 += 0.00000000007*np.cos(2.30474556787 + 209812.60368468695*t)
	X1 += 0.00000000007*np.cos(3.64200504235 + 172402.03644480839*t)
	X1 += 0.00000000007*np.cos(3.15699312277 + 51013.33157874059*t)
	X1 += 0.00000000007*np.cos(2.34948998718 + 327.4375699205*t)
	X1 += 0.00000000008*np.cos(6.01739816809 + 1585.8915015461*t)
	X1 += 0.00000000007*np.cos(0.49384776945 + 20.6069278195*t)
	X1 += 0.00000000007*np.cos(3.04941872455 + 27044.1922975448*t)
	X1 += 0.00000000007*np.cos(2.00283015490 + 528.9402055692*t)
	X1 += 0.00000000007*np.cos(2.33785549347 + 530.44172462*t)
	X1 += 0.00000000007*np.cos(5.38166348747 + 2228.9701815978*t)
	X1 += 0.00000000008*np.cos(1.11506407502 + 144.1465711632*t)
	X1 += 0.00000000008*np.cos(0.93716006393 + 458.8415197904*t)
	X1 += 0.00000000007*np.cos(1.99337329060 + 150244.34299945379*t)
	X1 += 0.00000000009*np.cos(3.93059938713 + 26734.913974889*t)
	X1 += 0.00000000007*np.cos(4.75714960140 + 52325.36948028299*t)
	X1 += 0.00000000007*np.cos(6.10220034684 + 278.5194664497*t)
	X1 += 0.00000000007*np.cos(5.10226976956 + 13541.42120249119*t)
	X1 += 0.00000000007*np.cos(5.38424470913 + 80596.9058175946*t)
	X1 += 0.00000000008*np.cos(2.79730190848 + 454.9093665273*t)
	X1 += 0.00000000007*np.cos(1.89853865756 + 1048.3362299253*t)
	X1 += 0.00000000007*np.cos(4.41206005071 + 387.2413149608*t)
	X1 += 0.00000000007*np.cos(3.97484854685 + 425.6349830295*t)
	X1 += 0.00000000006*np.cos(3.78360025001 + 52278.89905736699*t)
	X1 += 0.00000000007*np.cos(1.42151002751 + 5.4166259714*t)
	X1 += 0.00000000007*np.cos(5.07915922145 + 431.264057322*t)
	X1 += 0.00000000008*np.cos(3.73990342667 + 129387.24732468258*t)
	X1 += 0.00000000007*np.cos(2.71768486617 + 106.2741679563*t)
	X1 += 0.00000000009*np.cos(3.42497309447 + 75930.51303185058*t)
	X1 += 0.00000000008*np.cos(2.75106262517 + 52169.17772424839*t)
	X1 += 0.00000000008*np.cos(1.50347216209 + 77726.90491262719*t)
	X1 += 0.00000000006*np.cos(1.00543740922 + 79330.20490191258*t)
	X1 += 0.00000000007*np.cos(5.56521824483 + 78378.14871340781*t)
	X1 += 0.00000000006*np.cos(4.29538257753 + 1158.5425511447*t)
	X1 += 0.00000000006*np.cos(6.11632456545 + 601.7642506762*t)
	X1 += 0.00000000008*np.cos(5.23426576880 + 228.276948965*t)
	X1 += 0.00000000007*np.cos(0.03631337685 + 558.0021407459*t)
	X1 += 0.00000000006*np.cos(4.20397273576 + 129373.02023068098*t)
	X1 += 0.00000000006*np.cos(5.40318267434 + 1159.2933106701*t)
	X1 += 0.00000000007*np.cos(1.62569971593 + 26162.6847401415*t)
	X1 += 0.00000000007*np.cos(5.97408505998 + 221.3758502853*t)
	X1 += 0.00000000007*np.cos(3.36399257591 + 953.1077622329*t)
	X1 += 0.00000000007*np.cos(3.53380092713 + 45.2465826386*t)
	X1 += 0.00000000006*np.cos(1.72178265563 + 241.7532834412*t)
	X1 += 0.00000000006*np.cos(4.50914445356 + 130652.81480330898*t)
	X1 += 0.00000000006*np.cos(1.09642732127 + 983.1158589136*t)
	X1 += 0.00000000007*np.cos(1.43696950392 + 77630.92568540938*t)
	X1 += 0.00000000006*np.cos(3.96501540302 + 1165.6560981455*t)
	X1 += 0.00000000006*np.cos(6.07126258740 + 186.2117600641*t)
	X1 += 0.00000000006*np.cos(0.25065144064 + 25508.2155545754*t)
	X1 += 0.00000000006*np.cos(5.41297359057 + 26667.590728573*t)
	X1 += 0.00000000006*np.cos(1.04635537302 + 39629.32434406539*t)
	X1 += 0.00000000006*np.cos(5.52124151783 + 40565.2543247742*t)
	X1 += 0.00000000007*np.cos(4.39225179954 + 421.93232443*t)
	X1 += 0.00000000007*np.cos(5.85352766815 + 8194.2753332086*t)
	X1 += 0.00000000006*np.cos(3.75147990976 + 103917.90082841998*t)
	X1 += 0.00000000008*np.cos(0.93245740025 + 157586.80077963437*t)
	X1 += 0.00000000006*np.cos(1.88152710036 + 313.2104759189*t)
	X1 += 0.00000000006*np.cos(2.36516103356 + 51653.22886505459*t)
	X1 += 0.00000000006*np.cos(3.62770311218 + 23.5758732361*t)
	X1 += 0.00000000007*np.cos(1.15740041561 + 154938.34595416138*t)
	X1 += 0.00000000006*np.cos(4.00716639365 + 26013.1215430069*t)
	X1 += 0.00000000007*np.cos(4.77970201762 + 214364.55718174578*t)
	X1 += 0.00000000006*np.cos(1.84888596079 + 6885.14988993081*t)
	X1 += 0.00000000007*np.cos(4.36588080270 + 25754.0472008048*t)
	X1 += 0.00000000007*np.cos(1.29774422851 + 26421.7590823436*t)
	X1 += 0.00000000007*np.cos(1.33257665947 + 230.7075831773*t)
	X1 += 0.00000000006*np.cos(5.21774017886 + 1166.4068576709*t)
	X1 += 0.00000000006*np.cos(6.00893693971 + 78149.27013603736*t)
	X1 += 0.00000000005*np.cos(0.89617169225 + 50064.15596977079*t)
	X1 += 0.00000000006*np.cos(2.09071241554 + 80.7194894005*t)
	X1 += 0.00000000006*np.cos(2.93345991787 + 2538.2485042536*t)
	X1 += 0.00000000006*np.cos(2.63212801251 + 128220.75860368418*t)
	X1 += 0.00000000006*np.cos(3.92931387452 + 107.0249274817*t)
	X1 += 0.00000000006*np.cos(3.52705318347 + 81.0013736908*t)
	X1 += 0.00000000006*np.cos(2.80934233604 + 66653.15746634839*t)
	X1 += 0.00000000006*np.cos(4.30034572218 + 426.6463749858*t)
	X1 += 0.00000000006*np.cos(5.86623781176 + 1891.2376709388*t)
	X1 += 0.00000000005*np.cos(6.05965648339 + 130226.21661243298*t)
	X1 += 0.00000000007*np.cos(0.54906813870 + 99.1606209555*t)
	X1 += 0.00000000005*np.cos(5.12395207497 + 494.2662424425*t)
	X1 += 0.00000000006*np.cos(3.21075948460 + 1041.2226829245*t)
	X1 += 0.00000000006*np.cos(0.06830775273 + 123668.80510662538*t)
	X1 += 0.00000000006*np.cos(1.75222718681 + 421.1815649046*t)
	X1 += 0.00000000006*np.cos(4.58966840558 + 188.9200730498*t)
	X1 += 0.00000000006*np.cos(4.31078821920 + 68.5618234438*t)
	X1 += 0.00000000006*np.cos(3.12401775256 + 35.212274331*t)
	X1 += 0.00000000005*np.cos(4.95793416059 + 44.070926471*t)
	X1 += 0.00000000006*np.cos(0.78943135240 + 89.7594520943*t)
	X1 += 0.00000000005*np.cos(1.17676147240 + 102769.65321801379*t)
	X1 += 0.00000000005*np.cos(0.05325753010 + 92.0470739547*t)
	X1 += 0.00000000006*np.cos(1.81840060185 + 161079.37234650398*t)
	X1 += 0.00000000006*np.cos(3.17893579358 + 103932.12792242158*t)
	X1 += 0.00000000005*np.cos(3.76241459004 + 46.2097904851*t)
	X1 += 0.00000000005*np.cos(3.89300636955 + 35472.7441496494*t)
	X1 += 0.00000000005*np.cos(6.03822128054 + 162.0933701068*t)
	X1 += 0.00000000005*np.cos(2.23177245413 + 205.4347889118*t)
	X1 += 0.00000000005*np.cos(0.49940419683 + 1593.0050485469*t)
	X1 += 0.00000000005*np.cos(5.74462559833 + 80382.47328510099*t)
	X1 += 0.00000000005*np.cos(0.40751082829 + 78213.71280281838*t)
	X1 += 0.00000000006*np.cos(0.47609620784 + 182085.63102592478*t)
	X1 += 0.00000000005*np.cos(1.32106578434 + 505.3119427064*t)
	X1 += 0.00000000005*np.cos(0.72763573757 + 102755.42612401219*t)
	X1 += 0.00000000007*np.cos(1.01041013974 + 64901.25971792339*t)
	X1 += 0.00000000005*np.cos(5.06606479586 + 75615.25459924959*t)
	X1 += 0.00000000005*np.cos(6.09989191383 + 6044.2285813754*t)
	X1 += 0.00000000005*np.cos(3.68449716556 + 19406.6782881746*t)
	X1 += 0.00000000005*np.cos(1.27162244422 + 128.9562693151*t)
	X1 += 0.00000000005*np.cos(6.02567132030 + 50.4025761791*t)
	X1 += 0.00000000005*np.cos(3.76864982971 + 916.9322800554*t)
	X1 += 0.00000000005*np.cos(5.98811310538 + 1251.3403846248*t)
	X1 += 0.00000000005*np.cos(5.08443772017 + 1080.7225711916*t)
	X1 += 0.00000000005*np.cos(4.35480199188 + 41.0537969446*t)
	X1 += 0.00000000005*np.cos(0.27144803161 + 14.0146456805*t)
	X1 += 0.00000000005*np.cos(2.21719938925 + 29.2049475286*t)
	X1 += 0.00000000005*np.cos(0.64236900268 + 312.4597163935*t)
	X1 += 0.00000000005*np.cos(0.55347836802 + 25654.19140369739*t)
	X1 += 0.00000000005*np.cos(5.65873857560 + 154.0166152595*t)
	X1 += 0.00000000005*np.cos(2.08957091919 + 88.7962442478*t)
	X1 += 0.00000000005*np.cos(1.21533954768 + 137678.19129947099*t)
	X1 += 0.00000000005*np.cos(1.16644086335 + 439.1283638482*t)
	X1 += 0.00000000005*np.cos(2.42117857215 + 53399.624123927*t)
	X1 += 0.00000000005*np.cos(3.99647174335 + 27780.06881107659*t)
	X1 += 0.00000000005*np.cos(0.51237606895 + 26402.0893214438*t)
	X1 += 0.00000000005*np.cos(5.15124896226 + 25773.71696170459*t)
	X1 += 0.00000000005*np.cos(1.58549672991 + 77616.69859140778*t)
	X1 += 0.00000000006*np.cos(0.18425926990 + 512.2824773553*t)
	X1 += 0.00000000005*np.cos(5.06579671013 + 778.4147831847*t)
	X1 += 0.00000000006*np.cos(0.18266035721 + 50049.92887576919*t)
	X1 += 0.00000000005*np.cos(3.56670679513 + 17893.6278083656*t)
	X1 += 0.00000000005*np.cos(4.03598888492 + 347.8844390456*t)
	X1 += 0.00000000005*np.cos(1.61430068646 + 54087.0057663656*t)
	X1 += 0.00000000006*np.cos(5.19947528170 + 696.5196376166*t)
	X1 += 0.00000000005*np.cos(0.59515032793 + 45892.73043315699*t)
	X1 += 0.00000000005*np.cos(4.83208640963 + 1069.6768709277*t)
	X1 += 0.00000000005*np.cos(0.32110795784 + 237.6781178262*t)
	X1 += 0.00000000005*np.cos(4.35949013333 + 24505.94379329119*t)
	X1 += 0.00000000004*np.cos(5.60132825306 + 54.1746707478*t)
	X1 += 0.00000000004*np.cos(2.54682197432 + 130432.40216087017*t)
	X1 += 0.00000000004*np.cos(1.97821363637 + 51852.30086649099*t)
	X1 += 0.00000000005*np.cos(5.02121943499 + 498.6714764576*t)
	X1 += 0.00000000004*np.cos(0.18629796423 + 611.4430983108*t)
	X1 += 0.00000000005*np.cos(2.92494499838 + 204151.27163553478*t)
	X1 += 0.00000000004*np.cos(2.42171570518 + 132658.27281205778*t)
	X1 += 0.00000000004*np.cos(6.10975670784 + 672.1406152284*t)
	X1 += 0.00000000006*np.cos(1.10181232960 + 426.5500067662*t)
	X1 += 0.00000000005*np.cos(4.14081422433 + 25938.3399444396*t)
	X1 += 0.00000000006*np.cos(3.44356759950 + 2751.5475996916*t)
	X1 += 0.00000000005*np.cos(4.31428427792 + 39450.3528483734*t)
	X1 += 0.00000000005*np.cos(4.64089847229 + 65717.22748563958*t)
	X1 += 0.00000000004*np.cos(4.65745435403 + 710.7467316182*t)
	X1 += 0.00000000004*np.cos(2.80245159203 + 51955.39364070959*t)
	X1 += 0.00000000004*np.cos(5.82103664757 + 68.8437077341*t)
	X1 += 0.00000000004*np.cos(5.66137471686 + 103498.41618454478*t)
	X1 += 0.00000000005*np.cos(1.63974900109 + 52396.2189255872*t)
	X1 += 0.00000000004*np.cos(0.38923128315 + 33.1371007917*t)
	X1 += 0.00000000005*np.cos(4.10075455899 + 295.0512286542*t)
	X1 += 0.00000000004*np.cos(6.13793028784 + 849.2642284889*t)
	X1 += 0.00000000005*np.cos(3.04296923489 + 166.828672522*t)
	X1 += 0.00000000004*np.cos(4.09060007695 + 679.2541622292*t)
	X1 += 0.00000000005*np.cos(0.43029706877 + 300.6108669775*t)
	X1 += 0.00000000004*np.cos(4.13434256469 + 104505.39137678158*t)
	X1 += 0.00000000005*np.cos(0.99790116577 + 123200.84011627098*t)
	X1 += 0.00000000005*np.cos(5.60265196005 + 560.7104537316*t)
	X1 += 0.00000000004*np.cos(5.71270004089 + 2317.8358618148*t)
	X1 += 0.00000000004*np.cos(2.16539647390 + 28791.5192962498*t)
	X1 += 0.00000000004*np.cos(3.49822855731 + 23384.2869868986*t)
	X1 += 0.00000000005*np.cos(6.09748705519 + 53029.0026649004*t)
	X1 += 0.00000000004*np.cos(0.03133309464 + 1070.4276304531*t)
	X1 += 0.00000000004*np.cos(2.20603900112 + 152.0108776894*t)
	X1 += 0.00000000004*np.cos(3.38348270644 + 26823.77965510599*t)
	X1 += 0.00000000004*np.cos(2.28014232477 + 25352.02662804239*t)
	X1 += 0.00000000004*np.cos(5.11054976948 + 133882.09065283638*t)
	X1 += 0.00000000005*np.cos(3.37195934008 + 600.5404103988*t)
	X1 += 0.00000000004*np.cos(4.79464066723 + 53771.99272543299*t)
	X1 += 0.00000000004*np.cos(3.58076228853 + 183570.92173262799*t)
	X1 += 0.00000000005*np.cos(0.57466690776 + 145204.75475114079*t)
	X1 += 0.00000000004*np.cos(5.08739935768 + 23439.44831610119*t)
	X1 += 0.00000000004*np.cos(2.91942328210 + 27170.98337386779*t)
	X1 += 0.00000000004*np.cos(2.74420174911 + 25004.8229092806*t)
	X1 += 0.00000000004*np.cos(5.70730765847 + 757.2171545342*t)
	X1 += 0.00000000004*np.cos(1.71297602638 + 78786.28684281638*t)
	X1 += 0.00000000004*np.cos(4.89642578031 + 746.9222137957*t)
	X1 += 0.00000000004*np.cos(2.01320988474 + 952.3570027075*t)
	X1 += 0.00000000004*np.cos(2.35947871248 + 32.2433289144*t)
	X1 += 0.00000000004*np.cos(5.16889446071 + 636.9962720242*t)
	X1 += 0.00000000005*np.cos(3.41506026848 + 26709.6469424134*t)
	X1 += 0.00000000005*np.cos(2.24856476273 + 25466.159340735*t)
	X1 += 0.00000000004*np.cos(5.84172747790 + 52065.59996192899*t)
	X1 += 0.00000000004*np.cos(4.55458054656 + 50483.640613646*t)
	X1 += 0.00000000004*np.cos(1.76727070040 + 196.0336200506*t)
	X1 += 0.00000000005*np.cos(3.76952781970 + 945.9942152321*t)
	X1 += 0.00000000004*np.cos(4.20593460992 + 312.1990839626*t)
	X1 += 0.00000000005*np.cos(2.46371613890 + 25234.70675982219*t)
	X1 += 0.00000000004*np.cos(4.73926385495 + 970.5162499722*t)
	X1 += 0.00000000004*np.cos(2.68517686010 + 78270.33798362259*t)
	X1 += 0.00000000004*np.cos(2.79716874555 + 1064.0477966352*t)
	X1 += 0.00000000004*np.cos(2.82246202066 + 221.1634019642*t)
	X1 += 0.00000000004*np.cos(2.12545244622 + 182.279606801*t)
	X1 += 0.00000000004*np.cos(1.43142376081 + 381.3516082374*t)
	X1 += 0.00000000005*np.cos(4.45815571512 + 432.2272651685*t)
	X1 += 0.00000000004*np.cos(2.85017144667 + 111.4301614968*t)
	X1 += 0.00000000004*np.cos(2.18178993259 + 429.5189521828*t)
	X1 += 0.00000000004*np.cos(1.79847863201 + 34282.1784747828*t)
	X1 += 0.00000000004*np.cos(0.54205020737 + 199599.31813847595*t)
	X1 += 0.00000000004*np.cos(0.19066423879 + 143005.66740785378*t)
	X1 += 0.00000000004*np.cos(3.27752582001 + 78800.51393681798*t)
	X1 += 0.00000000004*np.cos(2.02829629760 + 2324.9494088156*t)
	X1 += 0.00000000003*np.cos(0.36593642535 + 661.2379273164*t)
	X1 += 0.00000000003*np.cos(2.50436473789 + 227.3137411185*t)
	X1 += 0.00000000004*np.cos(5.02476065705 + 130459.18546877075*t)
	X1 += 0.00000000004*np.cos(4.77848701199 + 39.3568759152*t)
	X1 += 0.00000000004*np.cos(4.96500381777 + 52250.5878817157*t)
	X1 += 0.00000000003*np.cos(4.30211830006 + 78160.61665050399*t)
	X1 += 0.00000000004*np.cos(4.46181026998 + 87367.61641884019*t)
	X1 += 0.00000000004*np.cos(5.81440577111 + 60370.08161635699*t)
	X1 += 0.00000000003*np.cos(2.18678252584 + 554.8207470082*t)
	X1 += 0.00000000003*np.cos(0.76702918347 + 305.3461693927*t)
	X1 += 0.00000000004*np.cos(1.72859821695 + 130435.63437251298*t)
	X1 += 0.00000000004*np.cos(1.63790933088 + 26575.53789282839*t)
	X1 += 0.00000000004*np.cos(4.02571570033 + 25600.26839032*t)
	X1 += 0.00000000004*np.cos(5.34209380620 + 128320.75184749259*t)
	X1 += 0.00000000004*np.cos(0.93894074157 + 395.578702239*t)
	return X1*t




def Mercury_X2 (t):

	X2 = 0.
	X2 += 0.00001484185*np.cos(4.35401210269 + 52175.8062831484*t)
	X2 += 0.00001259780
	X2 += 0.00000907467*np.cos(1.13216343018 + 78263.70942472259*t)
	X2 += 0.00000368809*np.cos(4.18705944126 + 104351.61256629678*t)
	X2 += 0.00000254306*np.cos(4.12817377140 + 26087.9031415742*t)
	X2 += 0.00000160293*np.cos(4.40406062613 + 206.1855484372*t)
	X2 += 0.00000155633*np.cos(0.48183983171 + 220.4126424388*t)
	X2 += 0.00000130149*np.cos(0.95681684789 + 130439.51570787099*t)
	X2 += 0.00000118222*np.cos(0.99338493688 + 522.5774180938*t)
	X2 += 0.00000115842*np.cos(3.35337160144 + 536.8045120954*t)
	X2 += 0.00000096078*np.cos(5.56717820853 + 213.299095438*t)
	X2 += 0.00000065114*np.cos(5.63112398159 + 426.598190876*t)
	X2 += 0.00000074263*np.cos(2.15657144895 + 529.6909650946*t)
	X2 += 0.00000042868*np.cos(4.00892196726 + 156527.41884944518*t)
	X2 += 0.00000039449*np.cos(1.97733652493 + 1059.3819301892*t)
	X2 += 0.00000014232*np.cos(5.82837756444 + 433.7117378768*t)
	X2 += 0.00000013989*np.cos(1.76430781021 + 7.1135470008*t)
	X2 += 0.00000013566*np.cos(0.77740665693 + 182615.32199101939*t)
	X2 += 0.00000012711*np.cos(3.49149798770 + 419.4846438752*t)
	X2 += 0.00000009362*np.cos(4.71789202402 + 639.897286314*t)
	X2 += 0.00000007707*np.cos(0.35647823047 + 227.5261894396*t)
	X2 += 0.00000006797*np.cos(3.87387149561 + 1066.49547719*t)
	X2 += 0.00000005452*np.cos(0.48898137631 + 1052.2683831884*t)
	X2 += 0.00000005027*np.cos(1.12572622612 + 515.463871093*t)
	X2 += 0.00000003902*np.cos(2.39857684567 + 1589.0728952838*t)
	X2 += 0.00000003667*np.cos(4.56283602529 + 199.0720014364*t)
	X2 += 0.00000003523*np.cos(3.22103209546 + 543.9180590962*t)
	X2 += 0.00000004184*np.cos(3.82884210516 + 208703.22513259358*t)
	X2 += 0.00000002906*np.cos(1.33529655305 + 24978.5245894808*t)
	X2 += 0.00000002677*np.cos(4.31517647277 + 27197.2816936676*t)
	X2 += 0.00000001347*np.cos(2.19024470415 + 316.3918696566*t)
	X2 += 0.00000001405*np.cos(6.22622304401 + 216.4804891757*t)
	X2 += 0.00000001320*np.cos(4.96541286159 + 647.0108333148*t)
	X2 += 0.00000001365*np.cos(4.95810524231 + 210.1177017003*t)
	X2 += 0.00000001687*np.cos(1.62553064962 + 14.2270940016*t)
	X2 += 0.00000001268*np.cos(0.59695956916 + 234791.12827416777*t)
	X2 += 0.00000001093*np.cos(4.21067890946 + 103.0927742186*t)
	X2 += 0.00000001011*np.cos(4.40490230415 + 51066.427731055*t)
	X2 += 0.00000000987*np.cos(4.02683657703 + 853.196381752*t)
	X2 += 0.00000000938*np.cos(4.40679265580 + 632.7837393132*t)
	X2 += 0.00000000848*np.cos(1.52469724284 + 526.5095713569*t)
	X2 += 0.00000000826*np.cos(2.81425975210 + 532.8723588323*t)
	X2 += 0.00000000758*np.cos(0.02371551403 + 209.3669421749*t)
	X2 += 0.00000000733*np.cos(4.88186040762 + 217.2312487011*t)
	X2 += 0.00000000688*np.cos(5.79109380413 + 440.8252848776*t)
	X2 += 0.00000000603*np.cos(5.14215709084 + 323.5054166574*t)
	X2 += 0.00000000624*np.cos(0.96146126905 + 117.3198682202*t)
	X2 += 0.00000000549*np.cos(4.81966003612 + 949.1756089698*t)
	X2 += 0.00000000702*np.cos(0.69460527884 + 74.7815985673*t)
	X2 += 0.00000000546*np.cos(0.01597529774 + 1045.1548361876*t)
	X2 += 0.00000000499*np.cos(2.95394998140 + 110.2063212194*t)
	X2 += 0.00000000510*np.cos(2.48615954177 + 95.9792272178*t)
	X2 += 0.00000000604*np.cos(6.00696167862 + 735.8765135318*t)
	X2 += 0.00000000490*np.cos(2.82889535700 + 525.7588118315*t)
	X2 += 0.00000000488*np.cos(1.51375734651 + 533.6231183577*t)
	X2 += 0.00000000438*np.cos(4.38613869498 + 1596.1864422846*t)
	X2 += 0.00000000519*np.cos(6.10806295653 + 149.5631971346*t)
	X2 += 0.00000000379*np.cos(3.64772765617 + 260879.03141574195*t)
	X2 += 0.00000000354*np.cos(1.08917562345 + 53285.1848352418*t)
	X2 += 0.00000000350*np.cos(1.77280702796 + 1109.3785520934*t)
	X2 += 0.00000000337*np.cos(2.76484315037 + 2118.7638603784*t)
	X2 += 0.00000000352*np.cos(1.18170316153 + 77154.33087262919*t)
	X2 += 0.00000000353*np.cos(5.67450059858 + 63.7358983034*t)
	X2 += 0.00000000267*np.cos(6.09793545646 + 625.6701923124*t)
	X2 += 0.00000000270*np.cos(0.56801609869 + 1581.959348283*t)
	X2 += 0.00000000335*np.cos(3.28599535784 + 412.3710968744*t)
	X2 += 0.00000000230*np.cos(1.62446688541 + 70.8494453042*t)
	X2 += 0.00000000226*np.cos(0.21648774887 + 234.6397364404*t)
	X2 += 0.00000000257*np.cos(0.55141837710 + 956.2891559706*t)
	X2 += 0.00000000218*np.cos(6.18732888250 + 78.7137518304*t)
	X2 += 0.00000000216*np.cos(0.69406612425 + 11.0457002639*t)
	X2 += 0.00000000283*np.cos(2.17198423111 + 85.8272988312*t)
	X2 += 0.00000000210*np.cos(4.87169565788 + 942.062061969*t)
	X2 += 0.00000000227*np.cos(5.26494518266 + 73.297125859*t)
	X2 += 0.00000000235*np.cos(1.88541486477 + 36.6485629295*t)
	X2 += 0.00000000224*np.cos(5.59487510601 + 39.6175083461*t)
	X2 += 0.00000000228*np.cos(4.22772621951 + 202.2533951741*t)
	X2 += 0.00000000187*np.cos(2.86279402460 + 1169.5882514086*t)
	X2 += 0.00000000193*np.cos(4.15648107481 + 25132.3033999656*t)
	X2 += 0.00000000167*np.cos(3.64468986986 + 1073.6090241908*t)
	X2 += 0.00000000195*np.cos(0.93545523133 + 224.3447957019*t)
	X2 += 0.00000000171*np.cos(1.47490138738 + 27043.5028831828*t)
	X2 += 0.00000000158*np.cos(0.41813276311 + 1155.361157407*t)
	X2 += 0.00000000141*np.cos(2.05881354566 + 742.9900605326*t)
	X2 += 0.00000000140*np.cos(1.84983910496 + 21535.9496445154*t)
	X2 += 0.00000000135*np.cos(0.93601004324 + 138.5174968707*t)
	X2 += 0.00000000149*np.cos(3.11048959872 + 76.2660712756*t)
	X2 += 0.00000000133*np.cos(1.27948900541 + 508.3503240922*t)
	X2 += 0.00000000145*np.cos(4.08945624026 + 309.2783226558*t)
	X2 += 0.00000000126*np.cos(5.33539657707 + 330.6189636582*t)
	X2 += 0.00000000126*np.cos(4.18511285279 + 860.3099287528*t)
	X2 += 0.00000000138*np.cos(4.99278277428 + 20426.571092422*t)
	X2 += 0.00000000117*np.cos(5.88592772067 + 26617.5941066688*t)
	X2 += 0.00000000160*np.cos(3.76409728390 + 38.1330356378*t)
	X2 += 0.00000000115*np.cos(6.09306139752 + 25558.2121764796*t)
	X2 += 0.00000000112*np.cos(0.41587357894 + 286966.93455731616*t)
	X2 += 0.00000000116*np.cos(1.82846585957 + 46514.4742339962*t)
	X2 += 0.00000000107*np.cos(2.57772432456 + 14765.2390432698*t)
	X2 += 0.00000000115*np.cos(6.09545736763 + 223.5940361765*t)
	X2 += 0.00000000105*np.cos(2.94297794273 + 27147.28507176339*t)
	X2 += 0.00000000110*np.cos(0.21868987814 + 71.6002048296*t)
	X2 += 0.00000000124*np.cos(1.42405663717 + 23869.1460373874*t)
	X2 += 0.00000000115*np.cos(5.33896891891 + 429.7795846137*t)
	X2 += 0.00000000105*np.cos(1.31705960331 + 77.962992305*t)
	X2 += 0.00000000127*np.cos(6.12277131240 + 728.762966531*t)
	X2 += 0.00000000103*np.cos(3.78216777057 + 4551.9534970588*t)
	X2 += 0.00000000120*np.cos(4.23792109159 + 103242.23401420339*t)
	X2 += 0.00000000103*np.cos(4.21297257897 + 28306.66024576099*t)
	X2 += 0.00000000099*np.cos(0.66196730608 + 31749.2351907264*t)
	X2 += 0.00000000106*np.cos(1.49565452639 + 1162.4747044078*t)
	X2 += 0.00000000102*np.cos(5.20836098548 + 422.6660376129*t)
	X2 += 0.00000000085*np.cos(5.14492546566 + 19317.1925403286*t)
	X2 += 0.00000000084*np.cos(0.06183751259 + 124.433415221*t)
	X2 += 0.00000000074*np.cos(1.07138930276 + 1265.5674786264*t)
	X2 += 0.00000000076*np.cos(4.22098650571 + 423.4167971383*t)
	X2 += 0.00000000071*np.cos(3.05925118734 + 551.031606097*t)
	X2 += 0.00000000082*np.cos(1.68324374227 + 519.3960243561*t)
	X2 += 0.00000000068*np.cos(4.96510846230 + 654.1243803156*t)
	X2 += 0.00000000068*np.cos(0.11271966893 + 9103.9069941176*t)
	X2 += 0.00000000066*np.cos(2.46864705656 + 88.865680217*t)
	X2 += 0.00000000066*np.cos(3.92016503259 + 3442.5749449654*t)
	X2 += 0.00000000061*np.cos(4.53397757302 + 50586.73338786459*t)
	X2 += 0.00000000073*np.cos(1.49901280909 + 21.3406410024*t)
	X2 += 0.00000000059*np.cos(4.88869826613 + 72602.37737557039*t)
	X2 += 0.00000000058*np.cos(4.77256654994 + 191.9584544356*t)
	X2 += 0.00000000059*np.cos(3.10507163380 + 37410.5672398786*t)
	X2 += 0.00000000059*np.cos(2.56122053117 + 52705.49724824299*t)
	X2 += 0.00000000064*np.cos(0.59210224706 + 838.9692877504*t)
	X2 += 0.00000000065*np.cos(0.65463924387 + 51220.20654153979*t)
	X2 += 0.00000000057*np.cos(3.80644223882 + 30639.856638633*t)
	X2 += 0.00000000064*np.cos(2.62531230776 + 539.9859058331*t)
	X2 += 0.00000000070*np.cos(1.72021333432 + 22645.32819660879*t)
	X2 += 0.00000000064*np.cos(5.15957430521 + 203.0041546995*t)
	X2 += 0.00000000055*np.cos(5.61982417509 + 51116.4243529592*t)
	X2 += 0.00000000053*np.cos(0.46679718569 + 32858.61374281979*t)
	X2 += 0.00000000049*np.cos(4.02776993187 + 27676.976036858*t)
	X2 += 0.00000000045*np.cos(4.29961594202 + 846.0828347512*t)
	X2 += 0.00000000046*np.cos(3.88547191366 + 145.6310438715*t)
	X2 += 0.00000000045*np.cos(1.60026053734 + 25973.46385288896*t)
	X2 += 0.00000000044*np.cos(4.05810232577 + 26202.34243025941*t)
	X2 += 0.00000000045*np.cos(5.95361998059 + 53235.18821333759*t)
	X2 += 0.00000000047*np.cos(3.31818308830 + 1062.5633239269*t)
	X2 += 0.00000000053*np.cos(5.16526900470 + 955.5997416086*t)
	X2 += 0.00000000039*np.cos(2.65493111018 + 25874.6040461362*t)
	X2 += 0.00000000039*np.cos(5.64911272409 + 40853.142184844*t)
	X2 += 0.00000000038*np.cos(1.25489937051 + 1258.4539316256*t)
	X2 += 0.00000000038*np.cos(2.96694233358 + 26301.2022370122*t)
	X2 += 0.00000000035*np.cos(1.55855229745 + 1692.1656695024*t)
	X2 += 0.00000000044*np.cos(3.91987173876 + 29530.4780865396*t)
	X2 += 0.00000000038*np.cos(4.27891905126 + 53131.406024757*t)
	X2 += 0.00000000036*np.cos(5.46623211848 + 302.164775655*t)
	X2 += 0.00000000034*np.cos(5.64744481308 + 277.0349937414*t)
	X2 += 0.00000000033*np.cos(0.62515314785 + 56727.7597802072*t)
	X2 += 0.00000000040*np.cos(1.01193838180 + 129330.13715577759*t)
	X2 += 0.00000000033*np.cos(3.46947113137 + 313054.83769889036*t)
	X2 += 0.00000000031*np.cos(4.26713688144 + 6770.7106012456*t)
	X2 += 0.00000000030*np.cos(4.86335561218 + 2125.8774073792*t)
	X2 += 0.00000000038*np.cos(1.69042706019 + 2218.7571041868*t)
	X2 += 0.00000000035*np.cos(1.25631519996 + 1056.2005364515*t)
	X2 += 0.00000000032*np.cos(4.48774417428 + 49957.0491789616*t)
	X2 += 0.00000000039*np.cos(0.20293002946 + 1574.8458012822*t)
	X2 += 0.00000000036*np.cos(0.12982829645 + 437.6438911399*t)
	X2 += 0.00000000031*np.cos(3.39518273216 + 1272.6810256272*t)
	X2 += 0.00000000027*np.cos(3.47340764254 + 1055.4497769261*t)
	X2 += 0.00000000029*np.cos(1.32325847141 + 618.5566453116*t)
	X2 += 0.00000000028*np.cos(6.24637219690 + 1038.0412891868*t)
	X2 += 0.00000000027*np.cos(0.82567085480 + 415.5524906121*t)
	X2 += 0.00000000031*np.cos(1.93866033936 + 47623.8527860896*t)
	X2 += 0.00000000025*np.cos(5.55384551516 + 43071.8992890308*t)
	X2 += 0.00000000028*np.cos(1.64332966541 + 1485.9801210652*t)
	X2 += 0.00000000025*np.cos(1.66429605369 + 98690.28051714458*t)
	X2 += 0.00000000026*np.cos(5.05893496491 + 430.5303441391*t)
	X2 += 0.00000000024*np.cos(3.54369543262 + 18.1592472647*t)
	X2 += 0.00000000024*np.cos(0.77717557683 + 831.8557407496*t)
	X2 += 0.00000000023*np.cos(1.45497436681 + 231.4583427027*t)
	X2 += 0.00000000024*np.cos(5.51512603999 + 78793.40038981718*t)
	X2 += 0.00000000026*np.cos(3.18686355416 + 2648.454825473*t)
	X2 += 0.00000000025*np.cos(2.24207971146 + 1368.660252845*t)
	X2 += 0.00000000023*np.cos(3.56120112847 + 77308.10968311399*t)
	X2 += 0.00000000021*np.cos(5.72791145125 + 447.9388318784*t)
	X2 += 0.00000000027*np.cos(0.98357005483 + 54394.56338733519*t)
	X2 += 0.00000000020*np.cos(0.71402000433 + 3.1813937377*t)
	X2 += 0.00000000022*np.cos(5.33490739950 + 151.0476698429*t)
	X2 += 0.00000000019*np.cos(1.74528256840 + 1063.3140834523*t)
	X2 += 0.00000000020*np.cos(3.40302634906 + 1699.2792165032*t)
	X2 += 0.00000000022*np.cos(1.92756765233 + 45405.0956819028*t)
	X2 += 0.00000000020*np.cos(2.53484218621 + 35.1640902212*t)
	X2 += 0.00000000018*np.cos(1.08092680576 + 10.2949407385*t)
	X2 += 0.00000000021*np.cos(0.04948675860 + 72.3339180125*t)
	X2 += 0.00000000018*np.cos(3.61025694461 + 58946.51688439399*t)
	X2 += 0.00000000024*np.cos(0.61193595038 + 18849.2275499742*t)
	X2 += 0.00000000018*np.cos(1.73990981189 + 52156.1365222486*t)
	X2 += 0.00000000017*np.cos(2.72916234159 + 79323.09135491178*t)
	X2 += 0.00000000021*np.cos(2.11586070084 + 12566.1516999828*t)
	X2 += 0.00000000021*np.cos(2.68093863363 + 13655.8604911764*t)
	X2 += 0.00000000018*np.cos(4.11934903377 + 3.9321532631*t)
	X2 += 0.00000000018*np.cos(5.63577174804 + 1471.7530270636*t)
	X2 += 0.00000000018*np.cos(0.31168509807 + 51535.90899683439*t)
	X2 += 0.00000000017*np.cos(6.10620927353 + 52389.1053785864*t)
	X2 += 0.00000000016*np.cos(1.66583339325 + 23754.70674870219*t)
	X2 += 0.00000000016*np.cos(2.13005908431 + 22.0914005278*t)
	X2 += 0.00000000016*np.cos(5.22446000797 + 1478.8665740644*t)
	X2 += 0.00000000017*np.cos(2.07219008042 + 77.7505439839*t)
	X2 += 0.00000000017*np.cos(3.21787186790 + 51646.11531805379*t)
	X2 += 0.00000000016*np.cos(1.85663665448 + 48733.23133818299*t)
	X2 += 0.00000000015*np.cos(5.39822666802 + 38654.05484155699*t)
	X2 += 0.00000000015*np.cos(4.85349684848 + 1375.7737998458*t)
	X2 += 0.00000000016*np.cos(4.15133356060 + 79373.08797681599*t)
	X2 += 0.00000000016*np.cos(4.95896524219 + 41.1019810544*t)
	X2 += 0.00000000015*np.cos(5.03114029381 + 160.6088973985*t)
	X2 += 0.00000000014*np.cos(5.09664706361 + 52179.6876185064*t)
	X2 += 0.00000000014*np.cos(3.68991823488 + 82815.66292178139*t)
	X2 += 0.00000000014*np.cos(0.47915039682 + 195.1398481733*t)
	X2 += 0.00000000016*np.cos(2.16860864742 + 56.6223513026*t)
	X2 += 0.00000000017*np.cos(1.59080059391 + 77.2292791221*t)
	X2 += 0.00000000014*np.cos(2.42828725984 + 66941.04532641819*t)
	X2 += 0.00000000014*np.cos(5.69583373076 + 71.8126531507*t)
	X2 += 0.00000000014*np.cos(3.63538725359 + 110012.94461544899*t)
	X2 += 0.00000000014*np.cos(0.69791035823 + 53764.8791784322*t)
	X2 += 0.00000000015*np.cos(3.19537134319 + 65.2203710117*t)
	X2 += 0.00000000015*np.cos(0.66471022805 + 52195.47604404819*t)
	X2 += 0.00000000013*np.cos(1.07484706961 + 76674.63652943878*t)
	X2 += 0.00000000015*np.cos(4.95964145342 + 33326.5787331742*t)
	X2 += 0.00000000012*np.cos(3.86072810652 + 50057.04242277*t)
	X2 += 0.00000000016*np.cos(0.69576423227 + 55618.3812281138*t)
	X2 += 0.00000000013*np.cos(0.67881557905 + 83925.04147387479*t)
	X2 += 0.00000000013*np.cos(4.06012579136 + 155418.04029735178*t)
	X2 += 0.00000000012*np.cos(4.00107179066 + 28421.0995344462*t)
	X2 += 0.00000000012*np.cos(5.17033303670 + 337.732510659*t)
	X2 += 0.00000000013*np.cos(3.64691089977 + 131.4039498699*t)
	X2 += 0.00000000013*np.cos(3.59727069136 + 52171.9249477904*t)
	X2 += 0.00000000013*np.cos(3.14908318702 + 36301.18868778519*t)
	X2 += 0.00000000013*np.cos(3.14880532464 + 408.4389436113*t)
	X2 += 0.00000000011*np.cos(1.67250696064 + 24498.8302462904*t)
	X2 += 0.00000000014*np.cos(4.17248996684 + 5661.3320491522*t)
	X2 += 0.00000000012*np.cos(4.22650218163 + 963.4027029714*t)
	X2 += 0.00000000013*np.cos(2.13490029542 + 26727.8004278882*t)
	X2 += 0.00000000011*np.cos(0.02603069623 + 511.5317178299*t)
	X2 += 0.00000000013*np.cos(0.63715146770 + 11322.6640983044*t)
	X2 += 0.00000000010*np.cos(4.31465510142 + 547.8502123593*t)
	X2 += 0.00000000010*np.cos(6.18169621500 + 62389.09182935939*t)
	X2 += 0.00000000013*np.cos(0.73737685844 + 2111.6503133776*t)
	X2 += 0.00000000010*np.cos(0.83598356132 + 52290.24557183361*t)
	X2 += 0.00000000010*np.cos(4.67908297368 + 362.8622925726*t)
	X2 += 0.00000000010*np.cos(5.60218831936 + 127.4717966068*t)
	X2 += 0.00000000012*np.cos(0.78764611551 + 1685.0521225016*t)
	X2 += 0.00000000013*np.cos(4.91836873304 + 84.3428261229*t)
	X2 += 0.00000000012*np.cos(3.14290523608 + 26514.5013324502*t)
	X2 += 0.00000000010*np.cos(3.11126287173 + 35191.8101356918*t)
	X2 += 0.00000000009*np.cos(1.25757815859 + 76044.9523205358*t)
	X2 += 0.00000000010*np.cos(2.52278705670 + 15874.6175953632*t)
	X2 += 0.00000000010*np.cos(0.24410880924 + 339142.74084046457*t)
	X2 += 0.00000000010*np.cos(5.07263788261 + 934.9485149682*t)
	X2 += 0.00000000011*np.cos(3.00721890024 + 38519.945791972*t)
	X2 += 0.00000000012*np.cos(2.66109784913 + 148.0787244263*t)
	X2 += 0.00000000009*np.cos(2.44042399381 + 153.4953503977*t)
	X2 += 0.00000000009*np.cos(4.70984038054 + 124778.18365871879*t)
	X2 += 0.00000000010*np.cos(2.93539474520 + 25028.521211385*t)
	X2 += 0.00000000009*np.cos(4.78186604625 + 78244.0396638228*t)
	X2 += 0.00000000009*np.cos(4.66454207113 + 52061.36699446317*t)
	X2 += 0.00000000009*np.cos(0.14966079482 + 1382.8873468466*t)
	X2 += 0.00000000011*np.cos(3.37804748354 + 222.8603229936*t)
	X2 += 0.00000000008*np.cos(6.02198121081 + 92.940845832*t)
	X2 += 0.00000000009*np.cos(2.18518124277 + 269.9214467406*t)
	X2 += 0.00000000009*np.cos(3.23143026804 + 39609.6545831656*t)
	X2 += 0.00000000009*np.cos(3.55537703082 + 750.1036075334*t)
	X2 += 0.00000000008*np.cos(4.04549915755 + 2333.196392872*t)
	X2 += 0.00000000010*np.cos(5.30797415249 + 436.8931316145*t)
	X2 += 0.00000000010*np.cos(1.54068644361 + 203.7378678824*t)
	X2 += 0.00000000008*np.cos(4.74485412331 + 28206.6670019526*t)
	X2 += 0.00000000009*np.cos(2.19121952514 + 104881.30353139139*t)
	X2 += 0.00000000010*np.cos(4.52809483758 + 643.0786800517*t)
	X2 += 0.00000000010*np.cos(4.26753045931 + 635.9651330509*t)
	X2 += 0.00000000008*np.cos(0.23967004017 + 103396.01282468818*t)
	X2 += 0.00000000008*np.cos(0.37987106631 + 136100.84775702319*t)
	X2 += 0.00000000008*np.cos(3.50970266630 + 52.6901980395*t)
	X2 += 0.00000000008*np.cos(5.86771297817 + 131.5469622218*t)
	X2 += 0.00000000009*np.cos(4.91595161990 + 16983.9961474566*t)
	X2 += 0.00000000008*np.cos(0.60920060214 + 79219.30916633119*t)
	X2 += 0.00000000009*np.cos(0.20735942028 + 7994.5284420242*t)
	X2 += 0.00000000007*np.cos(4.10108572333 + 1603.2999892854*t)
	X2 += 0.00000000008*np.cos(0.45328868578 + 12432.0426503978*t)
	X2 += 0.00000000008*np.cos(2.09461474144 + 7238.67559160*t)
	X2 += 0.00000000007*np.cos(2.36547832832 + 69159.80243060499*t)
	X2 += 0.00000000007*np.cos(0.40212847913 + 6681.2248533996*t)
	X2 += 0.00000000009*np.cos(2.22913614898 + 1279.794572628*t)
	X2 += 0.00000000007*np.cos(4.71531871147 + 52168.69273614759*t)
	X2 += 0.00000000008*np.cos(6.19634687633 + 63498.47038145279*t)
	X2 += 0.00000000007*np.cos(1.45088892995 + 483.2205421786*t)
	X2 += 0.00000000007*np.cos(2.10610027970 + 64741.95798313119*t)
	X2 += 0.00000000009*np.cos(1.10868456658 + 87.3117715395*t)
	X2 += 0.00000000007*np.cos(1.85911354830 + 78267.59076008058*t)
	X2 += 0.00000000008*np.cos(6.28154480422 + 721.6494195302*t)
	X2 += 0.00000000007*np.cos(4.14213787767 + 867.4234757536*t)
	X2 += 0.00000000008*np.cos(2.28858892249 + 1361.5467058442*t)
	X2 += 0.00000000008*np.cos(4.00207680038 + 52182.9198301492*t)
	X2 += 0.00000000007*np.cos(5.23512171216 + 18207.81398823521*t)
	X2 += 0.00000000007*np.cos(0.31695892601 + 10213.285546211*t)
	X2 += 0.00000000006*np.cos(5.80443519678 + 105410.99449648599*t)
	X2 += 0.00000000006*np.cos(5.77664354435 + 12.5301729722*t)
	X2 += 0.00000000007*np.cos(6.15999622470 + 51962.5071877104*t)
	X2 += 0.00000000008*np.cos(3.36914220367 + 44937.1306915484*t)
	X2 += 0.00000000006*np.cos(4.05797292086 + 288.0806940053*t)
	X2 += 0.00000000006*np.cos(2.40284625703 + 129380.13377768178*t)
	X2 += 0.00000000006*np.cos(3.20129483122 + 35.685355083*t)
	X2 += 0.00000000006*np.cos(2.00935271481 + 2221.856634597*t)
	X2 += 0.00000000007*np.cos(3.03626865288 + 142.4496501338*t)
	X2 += 0.00000000005*np.cos(2.96155447733 + 88476.99497093359*t)
	X2 += 0.00000000006*np.cos(0.92070128524 + 113.3877149571*t)
	X2 += 0.00000000006*np.cos(1.32611782718 + 1795.258443721*t)
	X2 += 0.00000000005*np.cos(3.59127862190 + 25661.3049506982*t)
	X2 += 0.00000000005*np.cos(4.28095258999 + 40.5807161926*t)
	X2 += 0.00000000006*np.cos(6.23825391056 + 52602.4044740244*t)
	X2 += 0.00000000006*np.cos(2.93043859466 + 78477.00852016058*t)
	X2 += 0.00000000006*np.cos(0.46188986304 + 108903.56606335558*t)
	X2 += 0.00000000005*np.cos(0.49574606925 + 33967.99229491319*t)
	X2 += 0.00000000005*np.cos(3.75441675157 + 81706.28436968799*t)
	X2 += 0.00000000005*np.cos(5.53673433934 + 94138.32702008578*t)
	X2 += 0.00000000005*np.cos(5.89664568761 + 57837.1383323006*t)
	X2 += 0.00000000007*np.cos(5.58296785201 + 2.9689454166*t)
	X2 += 0.00000000005*np.cos(4.83027667513 + 74821.13447975718*t)
	X2 += 0.00000000007*np.cos(4.98545551601 + 71492.99882347698*t)
	X2 += 0.00000000007*np.cos(3.70894912583 + 78283.37918562238*t)
	X2 += 0.00000000005*np.cos(4.24493371796 + 416.3032501375*t)
	X2 += 0.00000000005*np.cos(1.29964111137 + 51322.60990139639*t)
	X2 += 0.00000000005*np.cos(2.49074669996 + 68050.42387851159*t)
	X2 += 0.00000000005*np.cos(3.82719391877 + 105460.99111839019*t)
	X2 += 0.00000000005*np.cos(2.97162380262 + 405.2575498736*t)
	X2 += 0.00000000005*np.cos(3.61271131032 + 628.8515860501*t)
	X2 += 0.00000000005*np.cos(5.24876798311 + 299.1263942692*t)
	X2 += 0.00000000005*np.cos(0.74450524979 + 1049.0869894507*t)
	X2 += 0.00000000005*np.cos(0.35178516619 + 78259.82808936459*t)
	X2 += 0.00000000005*np.cos(2.93410844815 + 344.7030453079*t)
	X2 += 0.00000000004*np.cos(1.30282358460 + 78256.59587772179*t)
	X2 += 0.00000000004*np.cos(4.27653048938 + 265.9892934775*t)
	X2 += 0.00000000006*np.cos(5.44757978079 + 103292.23063610759*t)
	X2 += 0.00000000004*np.cos(0.02464271840 + 241.7532834412*t)
	X2 += 0.00000000004*np.cos(0.08635272370 + 225.8292684102*t)
	X2 += 0.00000000006*np.cos(5.23548690619 + 200.7689224658*t)
	X2 += 0.00000000004*np.cos(5.16588074385 + 80.1982245387*t)
	X2 += 0.00000000005*np.cos(5.27636599134 + 51749.20809227239*t)
	X2 += 0.00000000004*np.cos(2.56938347762 + 81.7521332162*t)
	X2 += 0.00000000005*np.cos(0.22804238075 + 77734.01845962799*t)
	X2 += 0.00000000004*np.cos(6.06869194581 + 64607.84893354619*t)
	X2 += 0.00000000004*np.cos(4.12693153599 + 29416.03879785439*t)
	X2 += 0.00000000004*np.cos(1.53669349522 + 22759.76748529401*t)
	X2 += 0.00000000005*np.cos(1.44239228085 + 59414.4818747484*t)
	X2 += 0.00000000005*np.cos(5.48943391239 + 93028.94846799239*t)
	X2 += 0.00000000004*np.cos(4.01088906308 + 96.8729990951*t)
	X2 += 0.00000000004*np.cos(0.83479952169 + 181505.94343892598*t)
	X2 += 0.00000000004*np.cos(3.69264490004 + 79852.78232000639*t)
	X2 += 0.00000000004*np.cos(0.34140382701 + 76144.94556434419*t)
	X2 += 0.00000000005*np.cos(2.75224221162 + 146.3818033969*t)
	X2 += 0.00000000004*np.cos(5.28177641555 + 358.9301393095*t)
	X2 += 0.00000000004*np.cos(5.88554712812 + 67.6680515665*t)
	X2 += 0.00000000004*np.cos(2.88896913186 + 284.1485407422*t)
	X2 += 0.00000000004*np.cos(3.14472523304 + 1802.3719907218*t)
	X2 += 0.00000000005*np.cos(5.86843462535 + 340.7708920448*t)
	X2 += 0.00000000004*np.cos(0.75750831147 + 1148.2476104062*t)
	X2 += 0.00000000004*np.cos(4.00150046482 + 181.0557665236*t)
	X2 += 0.00000000004*np.cos(0.76148268878 + 77204.32749453338*t)
	X2 += 0.00000000004*np.cos(2.44238421546 + 490.3340891794*t)
	X2 += 0.00000000004*np.cos(5.73327501105 + 650.9429865779*t)
	X2 += 0.00000000004*np.cos(5.49142516376 + 155468.03691925599*t)
	X2 += 0.00000000004*np.cos(2.40110600466 + 32370.9789915656*t)
	X2 += 0.00000000004*np.cos(0.77482738791 + 54509.0026760204*t)
	X2 += 0.00000000003*np.cos(4.84446847204 + 9.5612275556*t)
	X2 += 0.00000000004*np.cos(0.61986604146 + 444.7574381407*t)
	X2 += 0.00000000003*np.cos(3.42320644167 + 162188.75089859738*t)
	X2 += 0.00000000003*np.cos(3.20404843433 + 424.1505103212*t)
	X2 += 0.00000000003*np.cos(3.74930692682 + 561.934294009*t)
	X2 += 0.00000000005*np.cos(5.60476147871 + 44181.27784112419*t)
	X2 += 0.00000000005*np.cos(0.45142513016 + 62.2514255951*t)
	X2 += 0.00000000003*np.cos(1.84477177776 + 81.8951455681*t)
	X2 += 0.00000000004*np.cos(0.72336948817 + 78270.82297172339*t)
	X2 += 0.00000000003*np.cos(1.52504306431 + 501.2367770914*t)
	X2 += 0.00000000003*np.cos(5.55946330424 + 107.0249274817*t)
	X2 += 0.00000000004*np.cos(0.82841475160 + 1788.1448967202*t)
	X2 += 0.00000000004*np.cos(4.12628804953 + 7880.08915333899*t)
	X2 += 0.00000000003*np.cos(6.02151068856 + 350.3321196004*t)
	X2 += 0.00000000004*np.cos(3.98922640345 + 80482.46652890938*t)
	X2 += 0.00000000004*np.cos(2.43169796555 + 191.2076949102*t)
	X2 += 0.00000000004*np.cos(5.74841518024 + 39743.7636327506*t)
	X2 += 0.00000000004*np.cos(5.69417470352 + 13521.7514415914*t)
	X2 += 0.00000000003*np.cos(1.92929191460 + 2.4476805548*t)
	X2 += 0.00000000004*np.cos(3.26891108104 + 99.9113804809*t)
	X2 += 0.00000000003*np.cos(1.56317795942 + 104331.94280539699*t)
	X2 += 0.00000000003*np.cos(0.87507671453 + 245.5424243524*t)
	X2 += 0.00000000003*np.cos(4.88795554029 + 125887.56221081219*t)
	X2 += 0.00000000003*np.cos(3.50991384903 + 33.6796175129*t)
	X2 += 0.00000000003*np.cos(0.41265687641 + 14.977853527*t)
	X2 += 0.00000000003*np.cos(2.54235804923 + 703.6331846174*t)
	X2 += 0.00000000003*np.cos(3.38935474258 + 77623.81213840858*t)
	X2 += 0.00000000003*np.cos(3.77971209044 + 25448.00585526019*t)
	X2 += 0.00000000004*np.cos(4.09930467385 + 27311.72098235281*t)
	X2 += 0.00000000004*np.cos(1.56432035736 + 24864.08530079559*t)
	X2 += 0.00000000003*np.cos(2.27664811174 + 120226.23016165999*t)
	X2 += 0.00000000003*np.cos(1.92640543576 + 99799.65906923798*t)
	X2 += 0.00000000003*np.cos(5.32912761349 + 58458.88213313979*t)
	X2 += 0.00000000003*np.cos(5.99165196975 + 73711.75592766379*t)
	X2 += 0.00000000003*np.cos(4.31843145830 + 102132.85546210999*t)
	X2 += 0.00000000003*np.cos(5.70821751092 + 152.7445908723*t)
	X2 += 0.00000000003*np.cos(3.24943700009 + 129483.91596626239*t)
	X2 += 0.00000000003*np.cos(1.49035567017 + 150866.08680029298*t)
	X2 += 0.00000000003*np.cos(4.19660457850 + 636.7158925763*t)
	X2 += 0.00000000003*np.cos(0.30901128223 + 2104.5367663768*t)
	X2 += 0.00000000003*np.cos(5.13470741781 + 90829.86112470538*t)
	X2 += 0.00000000003*np.cos(5.78301640092 + 295.0512286542*t)
	X2 += 0.00000000003*np.cos(2.71986865181 + 19804.8272915828*t)
	X2 += 0.00000000003*np.cos(1.95356715655 + 611.4430983108*t)
	X2 += 0.00000000003*np.cos(3.85793781437 + 351.8165923087*t)
	X2 += 0.00000000003*np.cos(2.81668831922 + 103821.92160120218*t)
	X2 += 0.00000000003*np.cos(3.04748693631 + 1069.6768709277*t)
	X2 += 0.00000000003*np.cos(5.20351790812 + 130969.20667296558*t)
	X2 += 0.00000000003*np.cos(2.45534643692 + 2015.6710861598*t)
	X2 += 0.00000000002*np.cos(1.11040820961 + 2008.557539159*t)
	X2 += 0.00000000002*np.cos(1.60034178501 + 3328.13565628019*t)
	X2 += 0.00000000003*np.cos(2.08626177083 + 235.3904959658*t)
	X2 += 0.00000000003*np.cos(3.31128356539 + 1080.7225711916*t)
	X2 += 0.00000000002*np.cos(4.89027491282 + 661.2379273164*t)
	X2 += 0.00000000003*np.cos(1.19742120401 + 26941.0995233262*t)
	X2 += 0.00000000002*np.cos(0.08750953819 + 629.6023455755*t)
	X2 += 0.00000000003*np.cos(3.76716252474 + 1592.2542890215*t)
	X2 += 0.00000000002*np.cos(1.36199631852 + 1251.3403846248*t)
	X2 += 0.00000000002*np.cos(4.46447256795 + 99.1606209555*t)
	X2 += 0.00000000003*np.cos(1.61169744064 + 1898.3512179396*t)
	X2 += 0.00000000003*np.cos(6.22248876679 + 71025.03383312259*t)
	X2 += 0.00000000002*np.cos(6.05228562355 + 114564.89811250778*t)
	X2 += 0.00000000002*np.cos(4.04823185356 + 565.1156877467*t)
	X2 += 0.00000000002*np.cos(3.89856574340 + 78378.14871340781*t)
	X2 += 0.00000000002*np.cos(0.39766202841 + 5849.3641121146*t)
	X2 += 0.00000000003*np.cos(4.92249999513 + 104355.49390165479*t)
	X2 += 0.00000000002*np.cos(1.00867539270 + 79.2350166922*t)
	X2 += 0.00000000002*np.cos(2.75544762010 + 5863.5912061162*t)
	X2 += 0.00000000002*np.cos(3.28730608507 + 365230.64398203876*t)
	X2 += 0.00000000003*np.cos(5.24274548309 + 52815.7035694624*t)
	X2 += 0.00000000002*np.cos(2.84424981131 + 77197.21394753258*t)
	X2 += 0.00000000002*np.cos(5.92578945602 + 404.5067903482*t)
	X2 += 0.00000000002*np.cos(3.05496732731 + 78690.30761559859*t)
	X2 += 0.00000000002*np.cos(1.82124178733 + 9779.5738083342*t)
	X2 += 0.00000000002*np.cos(4.88213175725 + 319.5732633943*t)
	X2 += 0.00000000002*np.cos(0.47881810383 + 104371.28232719658*t)
	X2 += 0.00000000002*np.cos(4.17903188614 + 9793.8009023358*t)
	X2 += 0.00000000002*np.cos(5.32635912320 + 2655.5683724738*t)
	X2 += 0.00000000002*np.cos(4.04031673296 + 42.5864537627*t)
	X2 += 0.00000000002*np.cos(0.80305623259 + 824.7421937488*t)
	X2 += 0.00000000002*np.cos(2.67706562881 + 121.2520214833*t)
	X2 += 0.00000000002*np.cos(1.00755310729 + 23969.1392811958*t)
	X2 += 0.00000000002*np.cos(0.52578577848 + 70.3281804424*t)
	X2 += 0.00000000002*np.cos(4.92704633158 + 1905.4647649404*t)
	X2 += 0.00000000002*np.cos(2.35946048456 + 77211.44104153418*t)
	X2 += 0.00000000002*np.cos(3.82376478290 + 208.633228992*t)
	X2 += 0.00000000002*np.cos(0.40927512393 + 10021.8372800994*t)
	X2 += 0.00000000002*np.cos(3.50337598721 + 313.2104759189*t)
	X2 += 0.00000000002*np.cos(4.20516065977 + 217.964961884*t)
	X2 += 0.00000000002*np.cos(4.29749936450 + 104344.49901929598*t)
	X2 += 0.00000000002*np.cos(2.20171652063 + 429.0458714308*t)
	X2 += 0.00000000002*np.cos(4.04146812069 + 757.2171545342*t)
	X2 += 0.00000000002*np.cos(4.57276707328 + 152.5321425512*t)
	X2 += 0.00000000002*np.cos(0.09271854750 + 41962.5207369374*t)
	X2 += 0.00000000002*np.cos(3.70310718037 + 78050.41032928458*t)
	X2 += 0.00000000002*np.cos(3.18110797568 + 25450.90686955*t)
	X2 += 0.00000000002*np.cos(2.48251705553 + 26724.8994135984*t)
	X2 += 0.00000000002*np.cos(3.68407924766 + 497.4476361802*t)
	X2 += 0.00000000002*np.cos(1.75589608164 + 97580.90196505119*t)
	X2 += 0.00000000002*np.cos(6.11482656755 + 61279.713277266*t)
	X2 += 0.00000000002*np.cos(2.56963368887 + 131498.89763806018*t)
	X2 += 0.00000000002*np.cos(3.40296904568 + 18093.37469954999*t)
	X2 += 0.00000000002*np.cos(3.12072684129 + 970.5162499722*t)
	X2 += 0.00000000002*np.cos(5.64039146960 + 31.019488637*t)
	X2 += 0.00000000002*np.cos(1.43340926720 + 78149.27013603736*t)
	X2 += 0.00000000002*np.cos(2.66449175860 + 621.7380390493*t)
	X2 += 0.00000000002*np.cos(0.50955931589 + 107794.18751126219*t)
	return X2*t*t




def Mercury_X3 (t):

	X3 = 0.
	X3 -= 0.00000044244
	X3 += 0.00000022035*np.cos(6.11822426048 + 206.1855484372*t)
	X3 += 0.00000021482*np.cos(5.03368299703 + 220.4126424388*t)
	X3 += 0.00000017461*np.cos(5.90570575226 + 78263.70942472259*t)
	X3 += 0.00000016291*np.cos(2.71940457791 + 522.5774180938*t)
	X3 += 0.00000015934*np.cos(1.63320186413 + 536.8045120954*t)
	X3 += 0.00000014855*np.cos(2.98081270061 + 52175.8062831484*t)
	X3 += 0.00000010499*np.cos(2.65555597352 + 104351.61256629678*t)
	X3 += 0.00000006474*np.cos(3.10442611992 + 26087.9031415742*t)
	X3 += 0.00000004906*np.cos(5.70235297811 + 130439.51570787099*t)
	X3 += 0.00000003063*np.cos(3.80201225520 + 426.598190876*t)
	X3 += 0.00000002563*np.cos(4.04702837579 + 433.7117378768*t)
	X3 += 0.00000002101*np.cos(4.92786996750 + 227.5261894396*t)
	X3 += 0.00000002012*np.cos(2.46917870918 + 156527.41884944518*t)
	X3 += 0.00000001706*np.cos(0.42316599671 + 1059.3819301892*t)
	X3 += 0.00000001375*np.cos(2.83821817426 + 515.463871093*t)
	X3 += 0.00000001266*np.cos(5.37509106080 + 419.4846438752*t)
	X3 += 0.00000001038*np.cos(2.26994057258 + 1066.49547719*t)
	X3 += 0.00000001000*np.cos(6.26567671131 + 199.0720014364*t)
	X3 += 0.00000000964*np.cos(1.50782014667 + 543.9180590962*t)
	X3 += 0.00000001275*np.cos(0.02482955002 + 7.1135470008*t)
	X3 += 0.00000000845*np.cos(2.83708264275 + 639.897286314*t)
	X3 += 0.00000000678*np.cos(2.36507413871 + 1052.2683831884*t)
	X3 += 0.00000000762*np.cos(5.52012723644 + 182615.32199101939*t)
	X3 += 0.00000000344*np.cos(1.24961127281 + 213.299095438*t)
	X3 += 0.00000000382*np.cos(6.20559320688 + 14.2270940016*t)
	X3 += 0.00000000291*np.cos(3.14472957178 + 647.0108333148*t)
	X3 += 0.00000000249*np.cos(1.14107482666 + 1589.0728952838*t)
	X3 += 0.00000000214*np.cos(4.03956747124 + 440.8252848776*t)
	X3 += 0.00000000274*np.cos(2.28815108376 + 208703.22513259358*t)
	X3 += 0.00000000230*np.cos(4.42377888159 + 216.4804891757*t)
	X3 += 0.00000000219*np.cos(0.47150010549 + 210.1177017003*t)
	X3 += 0.00000000129*np.cos(1.79919042809 + 1045.1548361876*t)
	X3 += 0.00000000123*np.cos(2.08253199617 + 853.196381752*t)
	X3 += 0.00000000092*np.cos(4.79503944157 + 234.6397364404*t)
	X3 += 0.00000000086*np.cos(6.10758245301 + 103.0927742186*t)
	X3 += 0.00000000095*np.cos(5.33930475465 + 234791.12827416777*t)
	X3 += 0.00000000091*np.cos(5.48002372488 + 117.3198682202*t)
	X3 += 0.00000000093*np.cos(5.08172811528 + 529.6909650946*t)
	X3 += 0.00000000075*np.cos(2.87101566525 + 1596.1864422846*t)
	X3 += 0.00000000069*np.cos(4.27897139677 + 95.9792272178*t)
	X3 += 0.00000000073*np.cos(6.02905465950 + 632.7837393132*t)
	X3 += 0.00000000077*np.cos(5.03142217150 + 412.3710968744*t)
	X3 += 0.00000000064*np.cos(3.94993325790 + 316.3918696566*t)
	X3 += 0.00000000056*np.cos(2.99558443348 + 508.3503240922*t)
	X3 += 0.00000000055*np.cos(3.29709092103 + 323.5054166574*t)
	X3 += 0.00000000048*np.cos(1.97191764285 + 1073.6090241908*t)
	X3 += 0.00000000056*np.cos(1.48325794833 + 735.8765135318*t)
	X3 += 0.00000000042*np.cos(1.41375480258 + 625.6701923124*t)
	X3 += 0.00000000039*np.cos(0.30611138474 + 942.062061969*t)
	X3 += 0.00000000036*np.cos(4.59308117276 + 209.3669421749*t)
	X3 += 0.00000000032*np.cos(2.10881559249 + 260879.03141574195*t)
	X3 += 0.00000000031*np.cos(2.46171091539 + 1581.959348283*t)
	X3 += 0.00000000031*np.cos(1.32072373030 + 551.031606097*t)
	X3 += 0.00000000032*np.cos(0.26519734656 + 217.2312487011*t)
	X3 += 0.00000000033*np.cos(2.32289510783 + 860.3099287528*t)
	X3 += 0.00000000028*np.cos(3.48885797103 + 330.6189636582*t)
	X3 += 0.00000000027*np.cos(3.92096513265 + 149.5631971346*t)
	X3 += 0.00000000029*np.cos(6.05526972992 + 70.8494453042*t)
	X3 += 0.00000000027*np.cos(1.63715408955 + 2118.7638603784*t)
	X3 += 0.00000000028*np.cos(1.74838965252 + 78.7137518304*t)
	X3 += 0.00000000029*np.cos(0.48147029137 + 949.1756089698*t)
	X3 += 0.00000000025*np.cos(4.58797131637 + 124.433415221*t)
	X3 += 0.00000000033*np.cos(4.30649710462 + 223.5940361765*t)
	X3 += 0.00000000032*np.cos(1.93089098387 + 110.2063212194*t)
	X3 += 0.00000000027*np.cos(6.02243954440 + 21.3406410024*t)
	X3 += 0.00000000025*np.cos(1.16107900100 + 1169.5882514086*t)
	X3 += 0.00000000024*np.cos(1.53395713354 + 63.7358983034*t)
	X3 += 0.00000000028*np.cos(1.56238914694 + 728.762966531*t)
	X3 += 0.00000000024*np.cos(3.16134826622 + 654.1243803156*t)
	X3 += 0.00000000023*np.cos(0.20728622886 + 191.9584544356*t)
	X3 += 0.00000000022*np.cos(2.15937343363 + 1155.361157407*t)
	X3 += 0.00000000022*np.cos(2.85958066164 + 51066.427731055*t)
	X3 += 0.00000000019*np.cos(0.03186061495 + 85.8272988312*t)
	X3 += 0.00000000019*np.cos(0.95260076413 + 73.297125859*t)
	X3 += 0.00000000022*np.cos(5.27304712373 + 956.2891559706*t)
	X3 += 0.00000000024*np.cos(5.89117970906 + 309.2783226558*t)
	X3 += 0.00000000025*np.cos(3.51115533622 + 429.7795846137*t)
	X3 += 0.00000000024*np.cos(3.53027023690 + 519.3960243561*t)
	X3 += 0.00000000020*np.cos(1.86650914141 + 71.6002048296*t)
	X3 += 0.00000000017*np.cos(4.13765972175 + 88.865680217*t)
	X3 += 0.00000000019*np.cos(5.95485140431 + 77.962992305*t)
	X3 += 0.00000000016*np.cos(0.00550329231 + 202.2533951741*t)
	X3 += 0.00000000020*np.cos(0.77024887951 + 539.9859058331*t)
	X3 += 0.00000000015*np.cos(5.02720184968 + 224.3447957019*t)
	X3 += 0.00000000013*np.cos(0.64071359315 + 76.2660712756*t)
	X3 += 0.00000000016*np.cos(0.70623098744 + 203.0041546995*t)
	X3 += 0.00000000013*np.cos(5.91413101289 + 77154.33087262919*t)
	X3 += 0.00000000012*np.cos(0.84507236712 + 302.164775655*t)
	X3 += 0.00000000011*np.cos(5.83933103010 + 53285.1848352418*t)
	X3 += 0.00000000010*np.cos(5.15754613710 + 286966.93455731616*t)
	X3 += 0.00000000010*np.cos(5.28489326618 + 11.0457002639*t)
	X3 += 0.00000000010*np.cos(3.98008913039 + 36.6485629295*t)
	X3 += 0.00000000012*np.cos(3.35651610375 + 422.6660376129*t)
	X3 += 0.00000000009*np.cos(3.50226842635 + 39.6175083461*t)
	X3 += 0.00000000009*np.cos(1.66650203128 + 1038.0412891868*t)
	X3 += 0.00000000009*np.cos(3.97946790815 + 447.9388318784*t)
	X3 += 0.00000000009*np.cos(3.09433206743 + 618.5566453116*t)
	X3 += 0.00000000008*np.cos(2.36406802666 + 838.9692877504*t)
	X3 += 0.00000000008*np.cos(0.38739265309 + 423.4167971383*t)
	X3 += 0.00000000009*np.cos(1.90795498674 + 1574.8458012822*t)
	X3 += 0.00000000007*np.cos(2.99983273700 + 1258.4539316256*t)
	X3 += 0.00000000007*np.cos(2.49966387854 + 831.8557407496*t)
	X3 += 0.00000000008*np.cos(3.95391486424 + 74.7815985673*t)
	X3 += 0.00000000006*np.cos(2.58853517839 + 138.5174968707*t)
	X3 += 0.00000000007*np.cos(0.08989351607 + 742.9900605326*t)
	X3 += 0.00000000006*np.cos(3.39896707822 + 2125.8774073792*t)
	X3 += 0.00000000005*np.cos(2.18119549382 + 145.6310438715*t)
	X3 += 0.00000000007*np.cos(0.58812910406 + 38.1330356378*t)
	X3 += 0.00000000005*np.cos(2.24425105188 + 195.1398481733*t)
	X3 += 0.00000000006*np.cos(2.68531623603 + 103242.23401420339*t)
	X3 += 0.00000000004*np.cos(2.85162994822 + 1265.5674786264*t)
	X3 += 0.00000000004*np.cos(3.42359216874 + 337.732510659*t)
	X3 += 0.00000000004*np.cos(2.02888732685 + 18.1592472647*t)
	X3 += 0.00000000004*np.cos(2.63984308882 + 79373.08797681599*t)
	X3 += 0.00000000005*np.cos(6.19237785082 + 3.9321532631*t)
	X3 += 0.00000000004*np.cos(0.27398248033 + 1485.9801210652*t)
	X3 += 0.00000000004*np.cos(4.28076500111 + 437.6438911399*t)
	X3 += 0.00000000003*np.cos(1.92882196964 + 313054.83769889036*t)
	X3 += 0.00000000003*np.cos(1.84730058943 + 1699.2792165032*t)
	X3 += 0.00000000004*np.cos(3.46019246895 + 3.1813937377*t)
	X3 += 0.00000000003*np.cos(0.37181135547 + 934.9485149682*t)
	X3 += 0.00000000003*np.cos(4.11129727244 + 131.5469622218*t)
	X3 += 0.00000000003*np.cos(0.39047321949 + 1162.4747044078*t)
	X3 += 0.00000000003*np.cos(3.46901444868 + 436.8931316145*t)
	X3 += 0.00000000003*np.cos(2.41437573614 + 1062.5633239269*t)
	X3 += 0.00000000002*np.cos(3.24274981940 + 611.4430983108*t)
	X3 += 0.00000000003*np.cos(1.10053303206 + 1471.7530270636*t)
	X3 += 0.00000000003*np.cos(1.79512864801 + 1272.6810256272*t)
	X3 += 0.00000000002*np.cos(5.52311410472 + 131.4039498699*t)
	X3 += 0.00000000002*np.cos(2.48371068324 + 1603.2999892854*t)
	X3 += 0.00000000002*np.cos(2.33183931476 + 867.4234757536*t)
	X3 += 0.00000000002*np.cos(2.19577030344 + 2648.454825473*t)
	X3 += 0.00000000003*np.cos(3.98168020133 + 56.6223513026*t)
	X3 += 0.00000000002*np.cos(5.45688610067 + 846.0828347512*t)
	X3 += 0.00000000002*np.cos(2.65700192125 + 643.0786800517*t)
	X3 += 0.00000000002*np.cos(1.84112643531 + 721.6494195302*t)
	X3 += 0.00000000002*np.cos(5.74038187507 + 129330.13715577759*t)
	X3 += 0.00000000002*np.cos(0.30227695595 + 46514.4742339962*t)
	X3 += 0.00000000002*np.cos(2.08476192747 + 750.1036075334*t)
	X3 += 0.00000000002*np.cos(2.42918053212 + 635.9651330509*t)
	X3 += 0.00000000002*np.cos(5.79217247184 + 231.4583427027*t)
	X3 += 0.00000000002*np.cos(4.02167835510 + 269.9214467406*t)
	X3 += 0.00000000002*np.cos(5.21252267104 + 408.4389436113*t)
	X3 += 0.00000000002*np.cos(2.50697839724 + 963.4027029714*t)
	X3 += 0.00000000002*np.cos(4.04816193043 + 1368.660252845*t)
	X3 += 0.00000000002*np.cos(3.20483541487 + 1685.0521225016*t)
	X3 += 0.00000000002*np.cos(6.08001443327 + 22.0914005278*t)
	X3 += 0.00000000002*np.cos(2.57522241240 + 1055.4497769261*t)
	X3 += 0.00000000002*np.cos(4.65923813596 + 241.7532834412*t)
	X3 += 0.00000000002*np.cos(3.01020812339 + 151.0476698429*t)
	X3 += 0.00000000001*np.cos(3.30055357539 + 72602.37737557039*t)
	X3 += 0.00000000002*np.cos(2.30328844097 + 415.5524906121*t)
	X3 += 0.00000000002*np.cos(3.33031033737 + 526.5095713569*t)
	X3 += 0.00000000002*np.cos(4.15196796459 + 532.8723588323*t)
	X3 += 0.00000000001*np.cos(0.85517205788 + 277.0349937414*t)
	X3 += 0.00000000002*np.cos(1.70893188663 + 430.5303441391*t)
	X3 += 0.00000000002*np.cos(4.15254535573 + 92.940845832*t)
	X3 += 0.00000000002*np.cos(3.92611152496 + 1361.5467058442*t)
	X3 += 0.00000000001*np.cos(2.09298651615 + 416.3032501375*t)
	X3 += 0.00000000002*np.cos(0.38432620826 + 1279.794572628*t)
	X3 += 0.00000000001*np.cos(0.44109528380 + 1478.8665740644*t)
	X3 += 0.00000000001*np.cos(2.98533044655 + 1109.3785520934*t)
	X3 += 0.00000000002*np.cos(2.44054024033 + 2111.6503133776*t)
	X3 += 0.00000000002*np.cos(1.02806088947 + 1056.2005364515*t)
	X3 += 0.00000000001*np.cos(4.33843290510 + 81.7521332162*t)
	X3 += 0.00000000001*np.cos(5.48949174205 + 51220.20654153979*t)
	X3 += 0.00000000001*np.cos(2.56904089278 + 160.6088973985*t)
	X3 += 0.00000000001*np.cos(3.19745338253 + 483.2205421786*t)
	X3 += 0.00000000001*np.cos(5.07229232557 + 35.1640902212*t)
	X3 += 0.00000000001*np.cos(0.01253715020 + 1692.1656695024*t)
	X3 += 0.00000000001*np.cos(4.69846613681 + 405.2575498736*t)
	X3 += 0.00000000001*np.cos(3.34457667490 + 184.8449074348*t)
	X3 += 0.00000000001*np.cos(1.28958525047 + 2420.9286360334*t)
	X3 += 0.00000000001*np.cos(0.50080361601 + 2097.423219376*t)
	X3 += 0.00000000001*np.cos(2.40988764568 + 41.1019810544*t)
	X3 += 0.00000000001*np.cos(3.12659159503 + 661.2379273164*t)
	X3 += 0.00000000001*np.cos(4.28786284652 + 153.4953503977*t)
	X3 += 0.00000000001*np.cos(4.41669314602 + 53235.18821333759*t)
	X3 += 0.00000000001*np.cos(1.27230121095 + 1069.6768709277*t)
	X3 += 0.00000000001*np.cos(0.83896009084 + 1141.1340634054*t)
	X3 += 0.00000000001*np.cos(4.62910391320 + 1677.9385755008*t)
	X3 += 0.00000000001*np.cos(1.33615111395 + 295.0512286542*t)
	X3 += 0.00000000001*np.cos(5.19392652959 + 2008.557539159*t)
	X3 += 0.00000000001*np.cos(0.98973080298 + 52705.49724824299*t)
	X3 += 0.00000000001*np.cos(1.70895997922 + 2524.021410252*t)
	X3 += 0.00000000001*np.cos(2.85145645242 + 1148.2476104062*t)
	return X3*t*t*t




def Mercury_X4 (t): # 95 terms of order 4

	X4 = 0.
	X4 += 0.00000002272*np.cos(1.56364838180 + 206.1855484372*t)
	X4 += 0.00000002236*np.cos(3.28143366276 + 220.4126424388*t)
	X4 += 0.00000001682*np.cos(4.46996330708 + 522.5774180938*t)
	X4 += 0.00000001638*np.cos(6.17513895178 + 536.8045120954*t)
	X4 += 0.00000000430*np.cos(3.20713267334 + 227.5261894396*t)
	X4 -= 0.00000000486
	X4 += 0.00000000348*np.cos(2.26681787351 + 433.7117378768*t)
	X4 += 0.00000000291*np.cos(4.56956279775 + 515.463871093*t)
	X4 += 0.00000000277*np.cos(4.46911521792 + 78263.70942472259*t)
	X4 += 0.00000000233*np.cos(1.15859255567 + 104351.61256629678*t)
	X4 += 0.00000000206*np.cos(6.05364860885 + 543.9180590962*t)
	X4 += 0.00000000202*np.cos(1.69320982304 + 199.0720014364*t)
	X4 += 0.00000000175*np.cos(1.69697731540 + 52175.8062831484*t)
	X4 += 0.00000000142*np.cos(4.18294832661 + 130439.51570787099*t)
	X4 += 0.00000000123*np.cos(0.67135155073 + 1066.49547719*t)
	X4 += 0.00000000099*np.cos(0.99265774704 + 419.4846438752*t)
	X4 += 0.00000000113*np.cos(1.85695441801 + 426.598190876*t)
	X4 += 0.00000000080*np.cos(4.55016686641 + 7.1135470008*t)
	X4 += 0.00000000072*np.cos(0.93996426089 + 156527.41884944518*t)
	X4 += 0.00000000062*np.cos(4.48609878362 + 14.2270940016*t)
	X4 += 0.00000000053*np.cos(4.95103975600 + 1059.3819301892*t)
	X4 += 0.00000000066*np.cos(4.20375595982 + 1052.2683831884*t)
	X4 += 0.00000000050*np.cos(2.28699829686 + 440.8252848776*t)
	X4 += 0.00000000060*np.cos(0.97558287548 + 639.897286314*t)
	X4 += 0.00000000049*np.cos(1.31593641965 + 647.0108333148*t)
	X4 += 0.00000000034*np.cos(2.12555294236 + 26087.9031415742*t)
	X4 += 0.00000000031*np.cos(6.26226050601 + 213.299095438*t)
	X4 += 0.00000000032*np.cos(3.98624643079 + 182615.32199101939*t)
	X4 += 0.00000000024*np.cos(3.05754167589 + 234.6397364404*t)
	X4 += 0.00000000023*np.cos(3.61004405073 + 1045.1548361876*t)
	X4 += 0.00000000014*np.cos(4.76472781912 + 508.3503240922*t)
	X4 += 0.00000000013*np.cos(6.04976474685 + 1589.0728952838*t)
	X4 += 0.00000000014*np.cos(0.75012775830 + 208703.22513259358*t)
	X4 += 0.00000000011*np.cos(0.54626079593 + 412.3710968744*t)
	X4 += 0.00000000012*np.cos(0.15818608564 + 853.196381752*t)
	X4 += 0.00000000010*np.cos(0.31907502124 + 1073.6090241908*t)
	X4 += 0.00000000010*np.cos(1.35560891851 + 1596.1864422846*t)
	X4 += 0.00000000009*np.cos(4.24672231397 + 21.3406410024*t)
	X4 += 0.00000000011*np.cos(3.71353247018 + 117.3198682202*t)
	X4 += 0.00000000008*np.cos(1.50012562224 + 103.0927742186*t)
	X4 += 0.00000000007*np.cos(6.08752157484 + 95.9792272178*t)
	X4 += 0.00000000007*np.cos(6.27374846424 + 529.6909650946*t)
	X4 += 0.00000000007*np.cos(5.71854398962 + 551.031606097*t)
	X4 += 0.00000000006*np.cos(1.40413206867 + 654.1243803156*t)
	X4 += 0.00000000005*np.cos(2.81686507397 + 124.433415221*t)
	X4 += 0.00000000005*np.cos(3.79721330106 + 234791.12827416777*t)
	X4 += 0.00000000005*np.cos(3.21271191075 + 625.6701923124*t)
	X4 += 0.00000000006*np.cos(0.43509868093 + 860.3099287528*t)
	X4 += 0.00000000004*np.cos(1.55213484100 + 632.7837393132*t)
	X4 += 0.00000000005*np.cos(3.17881881452 + 728.762966531*t)
	X4 += 0.00000000004*np.cos(1.76651819729 + 330.6189636582*t)
	X4 += 0.00000000005*np.cos(2.10225977593 + 942.062061969*t)
	X4 += 0.00000000004*np.cos(5.76705671645 + 88.865680217*t)
	X4 += 0.00000000004*np.cos(3.27648798915 + 735.8765135318*t)
	X4 += 0.00000000003*np.cos(4.78415680549 + 618.5566453116*t)
	X4 += 0.00000000003*np.cos(0.90449193126 + 110.2063212194*t)
	X4 += 0.00000000003*np.cos(2.17395214560 + 447.9388318784*t)
	X4 += 0.00000000003*np.cos(4.27605231904 + 1581.959348283*t)
	X4 += 0.00000000003*np.cos(1.69135933489 + 323.5054166574*t)
	X4 += 0.00000000002*np.cos(5.71553727369 + 1169.5882514086*t)
	X4 += 0.00000000003*np.cos(2.34507379864 + 191.9584544356*t)
	X4 += 0.00000000002*np.cos(3.94362184472 + 1155.361157407*t)
	X4 += 0.00000000002*np.cos(1.55420041399 + 429.7795846137*t)
	X4 += 0.00000000003*np.cos(2.59535343316 + 302.164775655*t)
	X4 += 0.00000000002*np.cos(5.59314231958 + 316.3918696566*t)
	X4 += 0.00000000002*np.cos(3.65310721758 + 831.8557407496*t)
	X4 += 0.00000000002*np.cos(0.56145150603 + 260879.03141574195*t)
	X4 += 0.00000000002*np.cos(1.87311938884 + 309.2783226558*t)
	X4 += 0.00000000002*np.cos(0.19771789728 + 2118.7638603784*t)
	X4 += 0.00000000001*np.cos(3.56862151179 + 63.7358983034*t)
	X4 += 0.00000000002*np.cos(5.35217786853 + 203.0041546995*t)
	X4 += 0.00000000002*np.cos(2.67875662282 + 223.5940361765*t)
	X4 += 0.00000000001*np.cos(2.20334472347 + 149.5631971346*t)
	X4 += 0.00000000001*np.cos(3.76725001228 + 742.9900605326*t)
	X4 += 0.00000000001*np.cos(4.25784375307 + 85.8272988312*t)
	X4 += 0.00000000001*np.cos(3.65033183467 + 1574.8458012822*t)
	X4 += 0.00000000001*np.cos(3.66978405000 + 956.2891559706*t)
	X4 += 0.00000000001*np.cos(4.05229848373 + 423.4167971383*t)
	X4 += 0.00000000001*np.cos(5.47495901718 + 210.1177017003*t)
	X4 += 0.00000000001*np.cos(1.24151950182 + 337.732510659*t)
	X4 += 0.00000000001*np.cos(3.54926161114 + 405.2575498736*t)
	X4 += 0.00000000001*np.cos(2.60896952082 + 216.4804891757*t)
	X4 += 0.00000000001*np.cos(2.42395684459 + 949.1756089698*t)
	X4 += 0.00000000001*np.cos(3.82101733440 + 1038.0412891868*t)
	X4 += 0.00000000001*np.cos(1.64419675533 + 422.6660376129*t)
	X4 += 0.00000000001*np.cos(0.48555445682 + 18.1592472647*t)
	X4 += 0.00000000001*np.cos(4.82540662391 + 1258.4539316256*t)
	X4 += 0.00000000001*np.cos(3.61220093194 + 286966.93455731616*t)
	X4 += 0.00000000001*np.cos(2.21769054640 + 131.5469622218*t)
	X4 += 0.00000000001*np.cos(4.37722467188 + 838.9692877504*t)
	X4 += 0.00000000001*np.cos(5.43667975947 + 1485.9801210652*t)
	X4 += 0.00000000001*np.cos(5.09123218327 + 184.8449074348*t)
	X4 += 0.00000000001*np.cos(2.93998663691 + 241.7532834412*t)
	X4 += 0.00000000000*np.cos(1.39622585652 + 611.4430983108*t)
	X4 += 0.00000000000*np.cos(3.75725614820 + 1471.7530270636*t)
	return X4*t*t*t*t




def Mercury_X5 (t): # 43 terms of order 5

	X5 = 0.
	X5 += 0.00000000168*np.cos(3.28069809842 + 206.1855484372*t)
	X5 += 0.00000000167*np.cos(1.52399958265 + 220.4126424388*t)
	X5 += 0.00000000126*np.cos(0.07122523863 + 522.5774180938*t)
	X5 += 0.00000000121*np.cos(4.30466267493 + 536.8045120954*t)
	X5 += 0.00000000064*np.cos(1.46493444949 + 227.5261894396*t)
	X5 += 0.00000000047*np.cos(0.05687052745 + 515.463871093*t)
	X5 += 0.00000000037*np.cos(0.48304760543 + 433.7117378768*t)
	X5 += 0.00000000032*np.cos(4.26961178617 + 543.9180590962*t)
	X5 += 0.00000000028*np.cos(3.41370273509 + 199.0720014364*t)
	X5 += 0.00000000011*np.cos(2.75798781903 + 14.2270940016*t)
	X5 += 0.00000000011*np.cos(5.33499883960 + 1066.49547719*t)
	X5 += 0.00000000010*np.cos(0.51443337467 + 440.8252848776*t)
	X5 += 0.00000000010
	X5 += 0.00000000007*np.cos(5.80467663011 + 647.0108333148*t)
	X5 += 0.00000000004*np.cos(5.91649200666 + 104351.61256629678*t)
	X5 += 0.00000000004*np.cos(2.83757947000 + 78263.70942472259*t)
	X5 += 0.00000000004*np.cos(0.20088280204 + 1052.2683831884*t)
	X5 += 0.00000000004*np.cos(3.59221465704 + 419.4846438752*t)
	X5 += 0.00000000003*np.cos(2.66817005051 + 130439.51570787099*t)
	X5 += 0.00000000003*np.cos(5.43212710597 + 639.897286314*t)
	X5 += 0.00000000003*np.cos(1.37528056638 + 234.6397364404*t)
	X5 += 0.00000000003*np.cos(5.15477008535 + 52175.8062831484*t)
	X5 += 0.00000000002*np.cos(0.38337547624 + 191.9584544356*t)
	X5 += 0.00000000002*np.cos(5.49829989028 + 426.598190876*t)
	X5 += 0.00000000002*np.cos(5.69794729891 + 156527.41884944518*t)
	X5 += 0.00000000002*np.cos(4.89397151114 + 1073.6090241908*t)
	X5 += 0.00000000002*np.cos(6.21263006019 + 1045.1548361876*t)
	X5 += 0.00000000002*np.cos(6.20347759900 + 26087.9031415742*t)
	X5 += 0.00000000001*np.cos(1.31653362066 + 88.865680217*t)
	X5 += 0.00000000001*np.cos(5.40855784676 + 405.2575498736*t)
	X5 += 0.00000000001*np.cos(5.90670816840 + 654.1243803156*t)
	X5 += 0.00000000001*np.cos(3.71891583567 + 302.164775655*t)
	X5 += 0.00000000001*np.cos(4.55685868846 + 853.196381752*t)
	X5 += 0.00000000001*np.cos(3.69401301909 + 213.299095438*t)
	X5 += 0.00000000001*np.cos(5.15663977426 + 7.1135470008*t)
	X5 += 0.00000000001*np.cos(2.45874789246 + 182615.32199101939*t)
	X5 += 0.00000000001*np.cos(0.75807081859 + 124.433415221*t)
	X5 += 0.00000000001*np.cos(0.11340000355 + 508.3503240922*t)
	X5 += 0.00000000001*np.cos(1.08569299123 + 551.031606097*t)
	X5 += 0.00000000001*np.cos(2.74702261476 + 110.2063212194*t)
	X5 += 0.00000000001*np.cos(4.89128041335 + 860.3099287528*t)
	X5 += 0.00000000001*np.cos(0.44519622714 + 447.9388318784*t)
	X5 += 0.00000000001*np.cos(5.48978296351 + 208703.22513259358*t)
	return X5*t*t*t*t*t




def Mercury_Y0 (t): # 1553 terms of order 0

	Y0 = 0.
	Y0 += 0.37953636588*np.cos(2.83780617821 + 26087.9031415742*t)
	Y0 -= 0.11592262295
	Y0 += 0.03854667576*np.cos(5.88780608961 + 52175.8062831484*t)
	Y0 += 0.00587711171*np.cos(2.65498896201 + 78263.70942472259*t)
	Y0 += 0.00495452148*np.cos(2.17050902176 + 529.6909650946*t)
	Y0 += 0.00272177927*np.cos(2.44442843667 + 213.299095438*t)
	Y0 += 0.00155444251*np.cos(0.59927014783 + 38.1330356378*t)
	Y0 += 0.00106235475*np.cos(5.70550616735 + 104351.61256629678*t)
	Y0 += 0.00083755636*np.cos(0.76879995697 + 74.7815985673*t)
	Y0 += 0.00021100825*np.cos(2.47291315849 + 130439.51570787099*t)
	Y0 += 0.00012216279*np.cos(2.48707059837 + 1059.3819301892*t)
	Y0 += 0.00007634888*np.cos(1.67192689093 + 426.598190876*t)
	Y0 += 0.00004450056*np.cos(5.52354907071 + 156527.41884944518*t)
	Y0 += 0.00001963685*np.cos(5.70771850410 + 206.1855484372*t)
	Y0 += 0.00001891507*np.cos(2.32099579498 + 220.4126424388*t)
	Y0 += 0.00001939835*np.cos(3.22826367093 + 149.5631971346*t)
	Y0 += 0.00001436593*np.cos(2.30163308407 + 522.5774180938*t)
	Y0 += 0.00001405828*np.cos(5.18871358903 + 536.8045120954*t)
	Y0 += 0.00001186503*np.cos(5.48857209638 + 76.2660712756*t)
	Y0 += 0.00000978286*np.cos(2.29102643026 + 182615.32199101939*t)
	Y0 += 0.00000707500*np.cos(2.89516591531 + 24978.5245894808*t)
	Y0 += 0.00000654742*np.cos(5.92892123881 + 27197.2816936676*t)
	Y0 += 0.00000813077*np.cos(1.68393442622 + 36.6485629295*t)
	Y0 += 0.00000767125*np.cos(2.65620459324 + 39.6175083461*t)
	Y0 += 0.00000628788*np.cos(4.99295631526 + 73.297125859*t)
	Y0 += 0.00000467640*np.cos(2.78708397181 + 1589.0728952838*t)
	Y0 += 0.00000381047*np.cos(3.57284787143 + 7.1135470008*t)
	Y0 += 0.00000402513*np.cos(0.30196132091 + 20426.571092422*t)
	Y0 += 0.00000318042*np.cos(4.53681244310 + 419.4846438752*t)
	Y0 += 0.00000315277*np.cos(0.92804620983 + 639.897286314*t)
	Y0 += 0.00000290604*np.cos(2.23645868392 + 31749.2351907264*t)
	Y0 += 0.00000287244*np.cos(3.36373633182 + 110.2063212194*t)
	Y0 += 0.00000269760*np.cos(0.29166414619 + 103.0927742186*t)
	Y0 += 0.00000277272*np.cos(3.32517791429 + 6283.0758499914*t)
	Y0 += 0.00000191358*np.cos(2.70792842547 + 53285.1848352418*t)
	Y0 += 0.00000213464*np.cos(4.22105742898 + 316.3918696566*t)
	Y0 += 0.00000181119*np.cos(0.23941291054 + 1109.3785520934*t)
	Y0 += 0.00000193372*np.cos(5.38698781997 + 4551.9534970588*t)
	Y0 += 0.00000221718*np.cos(5.34170676570 + 208703.22513259358*t)
	Y0 += 0.00000139514*np.cos(5.94698662319 + 51066.427731055*t)
	Y0 += 0.00000154924*np.cos(1.12201865761 + 51116.4243529592*t)
	Y0 += 0.00000177242*np.cos(2.78855813429 + 5661.3320491522*t)
	Y0 += 0.00000138577*np.cos(0.43043981485 + 1.4844727083*t)
	Y0 += 0.00000112452*np.cos(0.85362654725 + 632.7837393132*t)
	Y0 += 0.00000106237*np.cos(1.55383673431 + 433.7117378768*t)
	Y0 += 0.00000100485*np.cos(1.46186272396 + 1052.2683831884*t)
	Y0 += 0.00000116072*np.cos(5.28608170116 + 57837.1383323006*t)
	Y0 += 0.00000108972*np.cos(1.58469834239 + 1162.4747044078*t)
	Y0 += 0.00000081399*np.cos(3.50862797958 + 21535.9496445154*t)
	Y0 += 0.00000075457*np.cos(4.50396814445 + 27147.28507176339*t)
	Y0 += 0.00000075078*np.cos(3.36291170975 + 46514.4742339962*t)
	Y0 += 0.00000069045*np.cos(4.92160428335 + 25132.3033999656*t)
	Y0 += 0.00000093793*np.cos(4.75128985772 + 10213.285546211*t)
	Y0 += 0.00000070803*np.cos(5.50276852163 + 1066.49547719*t)
	Y0 += 0.00000063460*np.cos(3.91239075334 + 27043.5028831828*t)
	Y0 += 0.00000058160*np.cos(4.13677602210 + 14765.2390432698*t)
	Y0 += 0.00000056606*np.cos(6.03126433457 + 949.1756089698*t)
	Y0 += 0.00000061405*np.cos(3.43747372432 + 47623.8527860896*t)
	Y0 += 0.00000054050*np.cos(0.72631991357 + 26617.5941066688*t)
	Y0 += 0.00000066031*np.cos(4.98872440932 + 846.0828347512*t)
	Y0 += 0.00000057397*np.cos(3.72326644008 + 12566.1516999828*t)
	Y0 += 0.00000063116*np.cos(4.22263926021 + 148.0787244263*t)
	Y0 += 0.00000052556*np.cos(1.98636705426 + 25558.2121764796*t)
	Y0 += 0.00000063023*np.cos(5.44866846513 + 224.3447957019*t)
	Y0 += 0.00000047932*np.cos(5.76195364026 + 79373.08797681599*t)
	Y0 += 0.00000051435*np.cos(2.10921381130 + 234791.12827416777*t)
	Y0 += 0.00000049166*np.cos(4.17094551348 + 77204.32749453338*t)
	Y0 += 0.00000035132*np.cos(4.11987679873 + 51646.11531805379*t)
	Y0 += 0.00000048182*np.cos(1.49346784398 + 3340.6124266998*t)
	Y0 += 0.00000035814*np.cos(4.73966512079 + 37410.5672398786*t)
	Y0 += 0.00000032754*np.cos(4.57352694115 + 955.5997416086*t)
	Y0 += 0.00000045435*np.cos(0.91835136158 + 41962.5207369374*t)
	Y0 += 0.00000028903*np.cos(5.43932193184 + 30639.856638633*t)
	Y0 += 0.00000034784*np.cos(3.03113665420 + 35.1640902212*t)
	Y0 += 0.00000031572*np.cos(2.71470274369 + 77154.33087262919*t)
	Y0 += 0.00000030355*np.cos(2.65183017667 + 11.0457002639*t)
	Y0 += 0.00000032251*np.cos(2.05357225780 + 83925.04147387479*t)
	Y0 += 0.00000028206*np.cos(5.07338603494 + 39609.6545831656*t)
	Y0 += 0.00000028729*np.cos(2.14448984200 + 151.0476698429*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000026848*np.cos(5.25320670297 + 11322.6640983044*t)
	Y0 += 0.00000027077*np.cos(4.69298133865 + 36301.18868778519*t)
	Y0 += 0.00000022896*np.cos(0.71333836963 + 53131.406024757*t)
	Y0 += 0.00000027688*np.cos(5.44433605847 + 63.7358983034*t)
	Y0 += 0.00000021994*np.cos(3.09794017788 + 2118.7638603784*t)
	Y0 += 0.00000023815*np.cos(2.19051967809 + 227.5261894396*t)
	Y0 += 0.00000023457*np.cos(0.09576335036 + 71.8126531507*t)
	Y0 += 0.00000023256*np.cos(5.18050538435 + 85.8272988312*t)
	Y0 += 0.00000021009*np.cos(4.08684580221 + 15874.6175953632*t)
	Y0 += 0.00000022104*np.cos(2.36649230999 + 2.9689454166*t)
	Y0 += 0.00000016503*np.cos(0.13257325259 + 72602.37737557039*t)
	Y0 += 0.00000021977*np.cos(4.82554793096 + 77.7505439839*t)
	Y0 += 0.00000020052*np.cos(2.45637769313 + 209.3669421749*t)
	Y0 += 0.00000016125*np.cos(1.65667771920 + 9103.9069941176*t)
	Y0 += 0.00000019691*np.cos(5.58713076986 + 217.2312487011*t)
	Y0 += 0.00000015661*np.cos(3.70210331615 + 742.9900605326*t)
	Y0 += 0.00000021011*np.cos(5.65119092880 + 13521.7514415914*t)
	Y0 += 0.00000021301*np.cos(0.20534560769 + 73711.75592766379*t)
	Y0 += 0.00000015160*np.cos(1.25002488520 + 18849.2275499742*t)
	Y0 += 0.00000018552*np.cos(4.31061638297 + 202.2533951741*t)
	Y0 += 0.00000018271*np.cos(1.49936112467 + 323.5054166574*t)
	Y0 += 0.00000017492*np.cos(1.45131471586 + 138.5174968707*t)
	Y0 += 0.00000017483*np.cos(0.56186392439 + 51749.20809227239*t)
	Y0 += 0.00000015554*np.cos(1.06822434115 + 735.8765135318*t)
	Y0 += 0.00000017112*np.cos(0.55137156527 + 50586.73338786459*t)
	Y0 += 0.00000015544*np.cos(2.44244057835 + 515.463871093*t)
	Y0 += 0.00000013891*np.cos(1.29665748792 + 53235.18821333759*t)
	Y0 += 0.00000015079*np.cos(1.97879118551 + 7238.67559160*t)
	Y0 += 0.00000013631*np.cos(3.65214684654 + 52705.49724824299*t)
	Y0 += 0.00000016970*np.cos(0.26334436508 + 853.196381752*t)
	Y0 += 0.00000014545*np.cos(1.48385300876 + 63498.47038145279*t)
	Y0 += 0.00000012963*np.cos(4.18911929952 + 25028.521211385*t)
	Y0 += 0.00000013152*np.cos(0.21408490669 + 26068.2333806744*t)
	Y0 += 0.00000013131*np.cos(2.31994193470 + 26107.57290247399*t)
	Y0 += 0.00000013657*np.cos(1.69271280727 + 51220.20654153979*t)
	Y0 += 0.00000013598*np.cos(0.93759628331 + 103292.23063610759*t)
	Y0 += 0.00000011751*np.cos(1.43132876728 + 33326.5787331742*t)
	Y0 += 0.00000012154*np.cos(5.15990276384 + 260879.03141574195*t)
	Y0 += 0.00000011477*np.cos(0.41407124478 + 19317.1925403286*t)
	Y0 += 0.00000011595*np.cos(5.83451477433 + 199.0720014364*t)
	Y0 += 0.00000010236*np.cos(0.82838354702 + 77734.01845962799*t)
	Y0 += 0.00000012081*np.cos(3.96948779355 + 68050.42387851159*t)
	Y0 += 0.00000012108*np.cos(2.53182219980 + 105460.99111839019*t)
	Y0 += 0.00000010833*np.cos(5.05444668554 + 543.9180590962*t)
	Y0 += 0.00000011585*np.cos(5.32336141881 + 525.7588118315*t)
	Y0 += 0.00000009243*np.cos(0.91470178389 + 40853.142184844*t)
	Y0 += 0.00000011435*np.cos(2.15573411853 + 533.6231183577*t)
	Y0 += 0.00000009577*np.cos(0.54300980490 + 38654.05484155699*t)
	Y0 += 0.00000012617*np.cos(2.32903972631 + 45892.73043315699*t)
	Y0 += 0.00000009024*np.cos(3.62265462866 + 26091.7844769322*t)
	Y0 += 0.00000009026*np.cos(5.19456413590 + 26084.0218062162*t)
	Y0 += 0.00000012253*np.cos(1.84260347906 + 65697.55772473979*t)
	Y0 += 0.00000008921*np.cos(2.21279123795 + 32858.61374281979*t)
	Y0 += 0.00000008903*np.cos(5.05278309499 + 26514.5013324502*t)
	Y0 += 0.00000008904*np.cos(5.46086574052 + 3442.5749449654*t)
	Y0 += 0.00000008277*np.cos(0.97930362795 + 43071.8992890308*t)
	Y0 += 0.00000008532*np.cos(5.10423076286 + 110012.94461544899*t)
	Y0 += 0.00000008865*np.cos(3.30085475170 + 32370.9789915656*t)
	Y0 += 0.00000007700*np.cos(2.17157469442 + 56727.7597802072*t)
	Y0 += 0.00000008571*np.cos(1.89585514935 + 1692.1656695024*t)
	Y0 += 0.00000008182*np.cos(5.04279721089 + 27676.976036858*t)
	Y0 += 0.00000007846*np.cos(0.83840815072 + 1478.8665740644*t)
	Y0 += 0.00000007388*np.cos(2.71311941898 + 6770.7106012456*t)
	Y0 += 0.00000007196*np.cos(1.94802350337 + 216.4804891757*t)
	Y0 += 0.00000007036*np.cos(6.09743344991 + 210.1177017003*t)
	Y0 += 0.00000007141*np.cos(0.89077348233 + 415.5524906121*t)
	Y0 += 0.00000006896*np.cos(2.82603987370 + 117.3198682202*t)
	Y0 += 0.00000007216*np.cos(2.47707773179 + 1265.5674786264*t)
	Y0 += 0.00000006915*np.cos(1.25378199550 + 956.2891559706*t)
	Y0 += 0.00000006447*np.cos(1.30219534399 + 16983.9961474566*t)
	Y0 += 0.00000007552*np.cos(3.42776275753 + 14.2270940016*t)
	Y0 += 0.00000007687*np.cos(1.67077544033 + 1581.959348283*t)
	Y0 += 0.00000007443*np.cos(2.98224053647 + 23869.1460373874*t)
	Y0 += 0.00000006952*np.cos(3.42284499782 + 22645.32819660879*t)
	Y0 += 0.00000006731*np.cos(0.81031109878 + 647.0108333148*t)
	Y0 += 0.00000006607*np.cos(5.48986631078 + 19804.8272915828*t)
	Y0 += 0.00000006015*np.cos(1.47698341146 + 62389.09182935939*t)
	Y0 += 0.00000006309*np.cos(4.44334031620 + 59414.4818747484*t)
	Y0 += 0.00000005925*np.cos(3.77454325940 + 79219.30916633119*t)
	Y0 += 0.00000007571*np.cos(5.76555894291 + 103242.23401420339*t)
	Y0 += 0.00000007037*np.cos(0.48479200587 + 95.9792272178*t)
	Y0 += 0.00000006330*np.cos(3.87859376833 + 70.8494453042*t)
	Y0 += 0.00000006092*np.cos(3.25705731504 + 99799.65906923798*t)
	Y0 += 0.00000006562*np.cos(5.86248316518 + 28306.66024576099*t)
	Y0 += 0.00000005078*np.cos(2.67641304277 + 526.5095713569*t)
	Y0 += 0.00000004977*np.cos(4.80328860665 + 532.8723588323*t)
	Y0 += 0.00000005879*np.cos(0.79782511263 + 78.7137518304*t)
	Y0 += 0.00000005895*np.cos(3.66873787385 + 25874.6040461362*t)
	Y0 += 0.00000006103*np.cos(4.10884733063 + 111.4301614968*t)
	Y0 += 0.00000005168*np.cos(5.05804995902 + 26301.2022370122*t)
	Y0 += 0.00000004714*np.cos(2.54429045075 + 26095.016688575*t)
	Y0 += 0.00000004577*np.cos(0.02129879069 + 26080.78959457339*t)
	Y0 += 0.00000005517*np.cos(3.60620866320 + 76674.63652943878*t)
	Y0 += 0.00000004463*np.cos(5.28135997640 + 1375.7737998458*t)
	Y0 += 0.00000004024*np.cos(5.79905368181 + 1596.1864422846*t)
	Y0 += 0.00000003908*np.cos(3.18519537351 + 98690.28051714458*t)
	Y0 += 0.00000004740*np.cos(3.21268285320 + 114.3991069134*t)
	Y0 += 0.00000005385*np.cos(3.61083679851 + 77837.11123384659*t)
	Y0 += 0.00000004423*np.cos(6.24070525621 + 277.0349937414*t)
	Y0 += 0.00000005181*np.cos(0.28847978237 + 222.8603229936*t)
	Y0 += 0.00000004577*np.cos(5.47618219772 + 146.594251718*t)
	Y0 += 0.00000003644*np.cos(3.98783714230 + 129380.13377768178*t)
	Y0 += 0.00000003338*np.cos(0.38724993766 + 78793.40038981718*t)
	Y0 += 0.00000003316*np.cos(5.12183457548 + 58946.51688439399*t)
	Y0 += 0.00000003962*np.cos(5.48363213369 + 29530.4780865396*t)
	Y0 += 0.00000003629*np.cos(4.89385319464 + 91785.46086631398*t)
	Y0 += 0.00000003068*np.cos(4.35775545042 + 79323.09135491178*t)
	Y0 += 0.00000003499*np.cos(5.38046448626 + 71980.63357473118*t)
	Y0 += 0.00000003105*np.cos(0.73732898186 + 94138.32702008578*t)
	Y0 += 0.00000002915*np.cos(1.92745964306 + 286966.93455731616*t)
	Y0 += 0.00000003797*np.cos(4.52469688488 + 89586.37352302698*t)
	Y0 += 0.00000002828*np.cos(5.36762181193 + 309.2783226558*t)
	Y0 += 0.00000003761*np.cos(5.75801604585 + 490.3340891794*t)
	Y0 += 0.00000002737*np.cos(4.31987616717 + 44937.1306915484*t)
	Y0 += 0.00000002736*np.cos(3.85841365012 + 103821.92160120218*t)
	Y0 += 0.00000002692*np.cos(3.89664472121 + 69159.80243060499*t)
	Y0 += 0.00000002670*np.cos(3.26411796271 + 52156.1365222486*t)
	Y0 += 0.00000003234*np.cos(0.15700821776 + 2218.7571041868*t)
	Y0 += 0.00000002946*np.cos(3.91413787998 + 25661.3049506982*t)
	Y0 += 0.00000003275*np.cos(1.14799205324 + 25934.1243310894*t)
	Y0 += 0.00000002820*np.cos(1.87227903869 + 299.1263942692*t)
	Y0 += 0.00000003246*np.cos(1.38661008976 + 26241.681952059*t)
	Y0 += 0.00000002559*np.cos(3.49987927726 + 48733.23133818299*t)
	Y0 += 0.00000003425*np.cos(0.95244785238 + 351.8165923087*t)
	Y0 += 0.00000003095*np.cos(4.74440359796 + 77308.10968311399*t)
	Y0 += 0.00000003103*np.cos(5.58481290362 + 131548.89425996438*t)
	Y0 += 0.00000002690*np.cos(5.37064066297 + 52195.47604404819*t)
	Y0 += 0.00000002922*np.cos(5.30505468617 + 109.9456887885*t)
	Y0 += 0.00000002237*np.cos(1.87187835709 + 136100.84775702319*t)
	Y0 += 0.00000002471*np.cos(1.29713026645 + 625.6701923124*t)
	Y0 += 0.00000002366*np.cos(1.14290912045 + 6681.2248533996*t)
	Y0 += 0.00000002279*np.cos(5.79973413763 + 3.9321532631*t)
	Y0 += 0.00000001979*np.cos(3.60257646907 + 64741.95798313119*t)
	Y0 += 0.00000001955*np.cos(0.11915602691 + 58458.88213313979*t)
	Y0 += 0.00000002559*np.cos(4.75005290985 + 1169.5882514086*t)
	Y0 += 0.00000001882*np.cos(5.21113955797 + 82815.66292178139*t)
	Y0 += 0.00000001838*np.cos(0.38908718331 + 52179.6876185064*t)
	Y0 += 0.00000001842*np.cos(3.96594806805 + 66941.04532641819*t)
	Y0 += 0.00000002307*np.cos(1.22800330052 + 1045.1548361876*t)
	Y0 += 0.00000001788*np.cos(0.37792450541 + 25619.9381512198*t)
	Y0 += 0.00000001833*np.cos(1.96136353630 + 52171.9249477904*t)
	Y0 += 0.00000002202*np.cos(2.59644390666 + 54394.56338733519*t)
	Y0 += 0.00000001723*np.cos(2.15586269154 + 26555.8681319286*t)
	Y0 += 0.00000002138*np.cos(1.35105904779 + 51535.90899683439*t)
	Y0 += 0.00000001978*np.cos(3.47172854103 + 45405.0956819028*t)
	Y0 += 0.00000001647*np.cos(1.83531703242 + 52602.4044740244*t)
	Y0 += 0.00000001665*np.cos(2.25971262112 + 5327.4761083828*t)
	Y0 += 0.00000001935*np.cos(4.21959122354 + 13655.8604911764*t)
	Y0 += 0.00000001914*np.cos(1.75692625946 + 1155.361157407*t)
	Y0 += 0.00000001660*np.cos(0.02502133169 + 125887.56221081219*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000001658*np.cos(1.44645943456 + 440.8252848776*t)
	Y0 += 0.00000001521*np.cos(1.83104073509 + 53764.8791784322*t)
	Y0 += 0.00000001874*np.cos(2.53319058791 + 129330.13715577759*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001692*np.cos(2.75833415261 + 52168.69273614759*t)
	Y0 += 0.00000001454*np.cos(4.53754269661 + 88476.99497093359*t)
	Y0 += 0.00000001439*np.cos(6.16071128287 + 942.062061969*t)
	Y0 += 0.00000001487*np.cos(4.35858219478 + 412.3710968744*t)
	Y0 += 0.00000001539*np.cos(0.55256735058 + 105307.21230790539*t)
	Y0 += 0.00000001549*np.cos(0.39789620728 + 102762.53967101299*t)
	Y0 += 0.00000001408*np.cos(2.83687387786 + 26094.53170047421*t)
	Y0 += 0.00000001408*np.cos(5.98015898835 + 26081.27458267419*t)
	Y0 += 0.00000001420*np.cos(6.03495956591 + 49957.0491789616*t)
	Y0 += 0.00000001561*np.cos(1.18454524473 + 85502.38501632259*t)
	Y0 += 0.00000001272*np.cos(2.51538497151 + 51962.5071877104*t)
	Y0 += 0.00000001428*np.cos(4.17962469716 + 65.2203710117*t)
	Y0 += 0.00000001469*np.cos(0.37777284264 + 103925.01437542078*t)
	Y0 += 0.00000001264*np.cos(4.66222164975 + 35191.8101356918*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001342*np.cos(4.75750445244 + 38519.945791972*t)
	Y0 += 0.00000001441*np.cos(6.24581101364 + 50057.04242277*t)
	Y0 += 0.00000001556*np.cos(1.87102996187 + 52389.1053785864*t)
	Y0 += 0.00000001485*np.cos(6.11611294959 + 210.8514148832*t)
	Y0 += 0.00000001421*np.cos(4.42238486903 + 225.8292684102*t)
	Y0 += 0.00000001473*np.cos(1.91659379347 + 215.7467759928*t)
	Y0 += 0.00000001160*np.cos(3.43681328419 + 2648.454825473*t)
	Y0 += 0.00000001097*np.cos(1.26180167303 + 422.6660376129*t)
	Y0 += 0.00000001072*np.cos(1.65797287689 + 1795.258443721*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001106*np.cos(5.15222384273 + 12432.0426503978*t)
	Y0 += 0.00000001019*np.cos(5.67612773072 + 145.6310438715*t)
	Y0 += 0.00000001421*np.cos(0.83890525684 + 152.5321425512*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001243*np.cos(5.56004522021 + 52182.9198301492*t)
	Y0 += 0.00000001072*np.cos(4.25942542568 + 26727.8004278882*t)
	Y0 += 0.00000000967*np.cos(0.75487021033 + 155468.03691925599*t)
	Y0 += 0.00000000977*np.cos(0.76357046359 + 84.3428261229*t)
	Y0 += 0.00000000953*np.cos(4.58726046984 + 1272.6810256272*t)
	Y0 += 0.00000000997*np.cos(1.66157901963 + 117873.36400788819*t)
	Y0 += 0.00000001076*np.cos(5.29118995114 + 212.3358875915*t)
	Y0 += 0.00000000937*np.cos(2.00054583710 + 85034.42002596818*t)
	Y0 += 0.00000001071*np.cos(2.73962355675 + 214.2623032845*t)
	Y0 += 0.00000000960*np.cos(6.23663722276 + 124778.18365871879*t)
	Y0 += 0.00000001243*np.cos(1.30343744920 + 184.7272873558*t)
	Y0 += 0.00000000891*np.cos(2.41639607024 + 213.2509113282*t)
	Y0 += 0.00000000890*np.cos(5.61419511254 + 213.3472795478*t)
	Y0 += 0.00000000913*np.cos(2.14759141886 + 98068.53671630539*t)
	Y0 += 0.00000001041*np.cos(4.23685547840 + 137.0330241624*t)
	Y0 += 0.00000000837*np.cos(0.48875422450 + 46848.3301747656*t)
	Y0 += 0.00000000832*np.cos(3.42202735905 + 104881.30353139139*t)
	Y0 += 0.00000000974*np.cos(2.96306305136 + 437.6438911399*t)
	Y0 += 0.00000000812*np.cos(0.69907573293 + 288.0806940053*t)
	Y0 += 0.00000000819*np.cos(5.28403120371 + 529.6427809848*t)
	Y0 += 0.00000000819*np.cos(2.19867289777 + 529.7391492044*t)
	Y0 += 0.00000000864*np.cos(0.97123767041 + 51123.53789995999*t)
	Y0 += 0.00000000797*np.cos(3.78730285311 + 120226.23016165999*t)
	Y0 += 0.00000000923*np.cos(3.90587740343 + 52026.2430860138*t)
	Y0 += 0.00000001037*np.cos(2.70514798372 + 527.2432845398*t)
	Y0 += 0.00000001029*np.cos(4.77626567802 + 532.1386456494*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000938*np.cos(1.28285332683 + 115674.27666460119*t)
	Y0 += 0.00000000776*np.cos(2.50668810243 + 203.7378678824*t)
	Y0 += 0.00000000746*np.cos(0.02765328657 + 74821.13447975718*t)
	Y0 += 0.00000000734*np.cos(3.78800004602 + 112.9146342051*t)
	Y0 += 0.00000000716*np.cos(0.35378564614 + 628.8515860501*t)
	Y0 += 0.00000000936*np.cos(2.24023772681 + 55618.3812281138*t)
	Y0 += 0.00000000804*np.cos(2.35412750829 + 157636.79740153858*t)
	Y0 += 0.00000000708*np.cos(4.97835058075 + 313054.83769889036*t)
	Y0 += 0.00000000726*np.cos(1.13072864457 + 105410.99449648599*t)
	Y0 += 0.00000000669*np.cos(1.28980071984 + 2008.557539159*t)
	Y0 += 0.00000000875*np.cos(4.36192286909 + 51109.31080595839*t)
	Y0 += 0.00000000719*np.cos(0.61492825170 + 129909.82474277639*t)
	Y0 += 0.00000000659*np.cos(1.63180703015 + 2111.6503133776*t)
	Y0 += 0.00000000925*np.cos(1.39948133634 + 160.6088973985*t)
	Y0 += 0.00000000661*np.cos(3.47371034653 + 1368.660252845*t)
	Y0 += 0.00000000742*np.cos(1.23961445295 + 9.5612275556*t)
	Y0 += 0.00000000875*np.cos(3.77647530400 + 380.12776796*t)
	Y0 += 0.00000000675*np.cos(5.58413863440 + 28206.6670019526*t)
	Y0 += 0.00000000650*np.cos(0.63237258720 + 95247.70557217918*t)
	Y0 += 0.00000000610*np.cos(0.03146551062 + 78244.0396638228*t)
	Y0 += 0.00000000663*np.cos(4.19794322902 + 52022.0274726636*t)
	Y0 += 0.00000000609*np.cos(2.19394412467 + 2221.856634597*t)
	Y0 += 0.00000000627*np.cos(5.21603099679 + 430.5303441391*t)
	Y0 += 0.00000000602*np.cos(0.71110689228 + 20760.4270331914*t)
	Y0 += 0.00000000639*np.cos(5.76187724040 + 80482.46652890938*t)
	Y0 += 0.00000000743*np.cos(1.51241001220 + 103396.01282468818*t)
	Y0 += 0.00000000586*np.cos(4.92207524971 + 162188.75089859738*t)
	Y0 += 0.00000000664*np.cos(2.87714310103 + 1063.3140834523*t)
	Y0 += 0.00000000663*np.cos(2.12818812670 + 838.9692877504*t)
	Y0 += 0.00000000598*np.cos(5.09026310864 + 423.4167971383*t)
	Y0 += 0.00000000633*np.cos(1.58661078881 + 12.5301729722*t)
	Y0 += 0.00000000647*np.cos(1.86412144751 + 528.7277572481*t)
	Y0 += 0.00000000646*np.cos(5.61853780158 + 530.6541729411*t)
	Y0 += 0.00000000592*np.cos(1.09214531526 + 71025.03383312259*t)
	Y0 += 0.00000000551*np.cos(3.29395183970 + 23754.70674870219*t)
	Y0 += 0.00000000551*np.cos(5.59697085315 + 1055.4497769261*t)
	Y0 += 0.00000000677*np.cos(4.43410327506 + 52329.58509363319*t)
	Y0 += 0.00000000666*np.cos(4.40151837219 + 77623.81213840858*t)
	Y0 += 0.00000000559*np.cos(0.94897406723 + 10021.8372800994*t)
	Y0 += 0.00000000672*np.cos(1.51129840313 + 221.3758502853*t)
	Y0 += 0.00000000644*np.cos(2.58708081761 + 45494.58142974879*t)
	Y0 += 0.00000000490*np.cos(1.40385202337 + 71.6002048296*t)
	Y0 += 0.00000000473*np.cos(3.26277772078 + 77.962992305*t)
	Y0 += 0.00000000648*np.cos(6.03788509546 + 22.0914005278*t)
	Y0 += 0.00000000596*np.cos(1.74322610176 + 7994.5284420242*t)
	Y0 += 0.00000000626*np.cos(1.29178761399 + 330.6189636582*t)
	Y0 += 0.00000000558*np.cos(4.25198337310 + 52099.5402118728*t)
	Y0 += 0.00000000467*np.cos(3.18899512617 + 84546.78527471398*t)
	Y0 += 0.00000000474*np.cos(5.38752337681 + 1073.6090241908*t)
	Y0 += 0.00000000653*np.cos(1.15486761496 + 388.4651552382*t)
	Y0 += 0.00000000464*np.cos(3.48448266155 + 24498.8302462904*t)
	Y0 += 0.00000000471*np.cos(1.72510786190 + 26237.46633870879*t)
	Y0 += 0.00000000456*np.cos(0.37602833213 + 90829.86112470538*t)
	Y0 += 0.00000000532*np.cos(1.20297674206 + 728.762966531*t)
	Y0 += 0.00000000617*np.cos(2.13813397736 + 78283.37918562238*t)
	Y0 += 0.00000000574*np.cos(4.09850700417 + 87.3117715395*t)
	Y0 += 0.00000000442*np.cos(4.70125751809 + 27140.17152476259*t)
	Y0 += 0.00000000445*np.cos(3.07523267609 + 151975.46535238638*t)
	Y0 += 0.00000000604*np.cos(0.41299096165 + 984.6003316219*t)
	Y0 += 0.00000000541*np.cos(1.50869067477 + 72.3339180125*t)
	Y0 += 0.00000000473*np.cos(5.58382968969 + 155418.04029735178*t)
	Y0 += 0.00000000468*np.cos(3.76982493207 + 212.7778305762*t)
	Y0 += 0.00000000466*np.cos(4.26202338577 + 213.8203602998*t)
	Y0 += 0.00000000470*np.cos(1.97509785099 + 108903.56606335558*t)
	Y0 += 0.00000000449*np.cos(5.76009397500 + 78256.59587772179*t)
	Y0 += 0.00000000419*np.cos(1.18672277137 + 429.7795846137*t)
	Y0 += 0.00000000476*np.cos(0.09624293332 + 860.3099287528*t)
	Y0 += 0.00000000423*np.cos(5.23795043183 + 340.7708920448*t)
	Y0 += 0.00000000459*np.cos(0.44821212178 + 26037.90651966999*t)
	Y0 += 0.00000000439*np.cos(0.74557141998 + 29428.515568274*t)
	Y0 += 0.00000000459*np.cos(2.08602741390 + 26137.8997634784*t)
	Y0 += 0.00000000441*np.cos(5.55002400505 + 2333.196392872*t)
	Y0 += 0.00000000420*np.cos(3.46875832008 + 128850.44281258718*t)
	Y0 += 0.00000000406*np.cos(5.56438736356 + 28421.0995344462*t)
	Y0 += 0.00000000515*np.cos(5.53709511500 + 26720.68688088739*t)
	Y0 += 0.00000000420*np.cos(3.43880146473 + 78267.59076008058*t)
	Y0 += 0.00000000457*np.cos(4.25870257295 + 25984.8103673556*t)
	Y0 += 0.00000000409*np.cos(1.89235979066 + 22747.2907148744*t)
	Y0 += 0.00000000441*np.cos(5.74769719365 + 78050.41032928458*t)
	Y0 += 0.00000000460*np.cos(4.60455680282 + 26190.99591579279*t)
	Y0 += 0.00000000428*np.cos(1.26561734018 + 27154.3986187642*t)
	Y0 += 0.00000000533*np.cos(3.36410465544 + 25455.119402261*t)
	Y0 += 0.00000000422*np.cos(0.73875718620 + 93028.94846799239*t)
	Y0 += 0.00000000511*np.cos(3.34354440535 + 77.2292791221*t)
	Y0 += 0.00000000490*np.cos(3.02631541744 + 76144.94556434419*t)
	Y0 += 0.00000000390*np.cos(3.42688671619 + 130012.91751699499*t)
	Y0 += 0.00000000491*np.cos(3.39044076994 + 3.1813937377*t)
	Y0 += 0.00000000364*np.cos(4.89106808289 + 78690.30761559859*t)
	Y0 += 0.00000000361*np.cos(1.30246090918 + 114564.89811250778*t)
	Y0 += 0.00000000356*np.cos(5.20137348148 + 52643.7712735028*t)
	Y0 += 0.00000000419*np.cos(5.01120890083 + 78259.82808936459*t)
	Y0 += 0.00000000395*np.cos(4.93033073834 + 78477.00852016058*t)
	Y0 += 0.00000000413*np.cos(0.42041417925 + 145.1097790097*t)
	Y0 += 0.00000000337*np.cos(4.88969069715 + 79852.78232000639*t)
	Y0 += 0.00000000336*np.cos(5.60932577353 + 127.4717966068*t)
	Y0 += 0.00000000409*np.cos(0.70233676711 + 350.3321196004*t)
	Y0 += 0.00000000364*np.cos(4.51546243970 + 48835.19385644859*t)
	Y0 += 0.00000000383*np.cos(4.56297720194 + 909.8187330546*t)
	Y0 += 0.00000000336*np.cos(0.50294839757 + 18207.81398823521*t)
	Y0 += 0.00000000317*np.cos(2.80195601464 + 76044.9523205358*t)
	Y0 += 0.00000000309*np.cos(5.54462791884 + 1905.4647649404*t)
	Y0 += 0.00000000402*np.cos(3.61219119527 + 131395.11544947959*t)
	Y0 += 0.00000000375*np.cos(0.23620758788 + 108.4612160802*t)
	Y0 += 0.00000000302*np.cos(3.06677264697 + 25973.46385288896*t)
	Y0 += 0.00000000313*np.cos(2.04966851954 + 234.6397364404*t)
	Y0 += 0.00000000300*np.cos(5.73869132813 + 26202.34243025941*t)
	Y0 += 0.00000000382*np.cos(0.24418522119 + 186.2117600641*t)
	Y0 += 0.00000000418*np.cos(0.23893690129 + 71492.99882347698*t)
	Y0 += 0.00000000362*np.cos(4.00328511109 + 25565.3257234804*t)
	Y0 += 0.00000000287*np.cos(5.88293841172 + 52182.4348420484*t)
	Y0 += 0.00000000356*np.cos(1.08678100754 + 64607.84893354619*t)
	Y0 += 0.00000000304*np.cos(3.41461416241 + 51707.84129279399*t)
	Y0 += 0.00000000289*np.cos(1.38259428580 + 26164.1692128498*t)
	Y0 += 0.00000000331*np.cos(4.78176305377 + 26610.48055966799*t)
	Y0 += 0.00000000379*np.cos(2.01230891559 + 26162.6847401415*t)
	Y0 += 0.00000000310*np.cos(1.11933365669 + 362.8622925726*t)
	Y0 += 0.00000000369*np.cos(4.21106702409 + 111590.28815789679*t)
	Y0 += 0.00000000269*np.cos(4.70967571334 + 143961.26714946238*t)
	Y0 += 0.00000000268*np.cos(1.81712028026 + 42153.969003049*t)
	Y0 += 0.00000000311*np.cos(2.87485251647 + 297.6419215609*t)
	Y0 += 0.00000000289*np.cos(0.35271915498 + 529.1697002328*t)
	Y0 += 0.00000000289*np.cos(0.84527308658 + 530.2122299564*t)
	Y0 += 0.00000000366*np.cos(1.35412421660 + 604.4725636619*t)
	Y0 += 0.00000000282*np.cos(0.06832834990 + 62.2514255951*t)
	Y0 += 0.00000000304*np.cos(4.67005655250 + 25448.00585526019*t)
	Y0 += 0.00000000259*np.cos(2.08276322854 + 1485.9801210652*t)
	Y0 += 0.00000000263*np.cos(4.77643040513 + 52.6901980395*t)
	Y0 += 0.00000000361*np.cos(0.50112315849 + 26013.1215430069*t)
	Y0 += 0.00000000256*np.cos(3.80003583229 + 181555.94006083018*t)
	Y0 += 0.00000000257*np.cos(2.63966270921 + 1258.4539316256*t)
	Y0 += 0.00000000273*np.cos(5.09640213545 + 111122.32316754239*t)
	Y0 += 0.00000000324*np.cos(5.37496427957 + 200.7689224658*t)
	Y0 += 0.00000000326*np.cos(0.96777570631 + 44181.27784112419*t)
	Y0 += 0.00000000252*np.cos(6.11098851755 + 2125.8774073792*t)
	Y0 += 0.00000000275*np.cos(6.25194576299 + 565.1156877467*t)
	Y0 += 0.00000000246*np.cos(3.27375223453 + 51756.3216392732*t)
	Y0 += 0.00000000326*np.cos(5.03875217793 + 703.6331846174*t)
	Y0 += 0.00000000330*np.cos(0.00798707088 + 25771.5112719176*t)
	Y0 += 0.00000000269*np.cos(4.90534085198 + 140.001969579*t)
	Y0 += 0.00000000287*np.cos(2.74227004893 + 52169.17772424839*t)
	Y0 += 0.00000000249*np.cos(4.80534758404 + 210.3783341312*t)
	Y0 += 0.00000000248*np.cos(3.22187918056 + 216.2198567448*t)
	Y0 += 0.00000000243*np.cos(5.15609899738 + 1062.5633239269*t)
	Y0 += 0.00000000329*np.cos(2.52774260295 + 26404.2950112308*t)
	Y0 += 0.00000000336*np.cos(6.10975677385 + 454.9093665273*t)
	Y0 += 0.00000000240*np.cos(1.67381717935 + 37.611770776*t)
	Y0 += 0.00000000237*np.cos(2.15132956903 + 212.5483359126*t)
	Y0 += 0.00000000255*np.cos(3.33122871209 + 153.4953503977*t)
	Y0 += 0.00000000237*np.cos(5.19825257378 + 124156.43985787958*t)
	Y0 += 0.00000000270*np.cos(2.17478042507 + 33967.99229491319*t)
	Y0 += 0.00000000308*np.cos(2.31701247486 + 78270.82297172339*t)
	Y0 += 0.00000000236*np.cos(5.87788994285 + 214.0498549634*t)
	Y0 += 0.00000000252*np.cos(5.43206013202 + 25668.418497699*t)
	Y0 += 0.00000000236*np.cos(2.66792286959 + 38.6543004996*t)
	Y0 += 0.00000000252*np.cos(3.03988883560 + 209.106309744*t)
	Y0 += 0.00000000248*np.cos(4.98513016170 + 217.491881132*t)
	Y0 += 0.00000000225*np.cos(1.81041528541 + 223.5940361765*t)
	Y0 += 0.00000000276*np.cos(4.02093667465 + 77211.44104153418*t)
	Y0 += 0.00000000280*np.cos(1.12656118140 + 77197.21394753258*t)
	Y0 += 0.00000000261*np.cos(2.91718305686 + 32769.1279949738*t)
	Y0 += 0.00000000224*np.cos(3.94824411240 + 38.084851528*t)
	Y0 += 0.00000000223*np.cos(0.39234241482 + 38.1812197476*t)
	Y0 += 0.00000000282*np.cos(3.10618381920 + 26507.38778544939*t)
	Y0 += 0.00000000226*np.cos(3.21437416344 + 100909.03762133139*t)
	Y0 += 0.00000000244*np.cos(2.64604748092 + 173.9422195228*t)
	Y0 += 0.00000000285*np.cos(1.16645481114 + 18093.37469954999*t)
	Y0 += 0.00000000234*np.cos(5.26336192114 + 74.2603337055*t)
	Y0 += 0.00000000231*np.cos(4.32501953451 + 141762.17980617538*t)
	Y0 += 0.00000000233*np.cos(5.70130722395 + 75.3028634291*t)
	Y0 += 0.00000000208*np.cos(0.53974604249 + 146314.13330323418*t)
	Y0 += 0.00000000275*np.cos(2.92194964370 + 19406.6782881746*t)
	Y0 += 0.00000000215*np.cos(3.07194607878 + 72936.23331633979*t)
	Y0 += 0.00000000241*np.cos(3.00041465942 + 150866.08680029298*t)
	Y0 += 0.00000000247*np.cos(5.27605423414 + 252.6559713532*t)
	Y0 += 0.00000000210*np.cos(5.40180831849 + 183724.70054311278*t)
	Y0 += 0.00000000203*np.cos(5.54978754111 + 18.1592472647*t)
	Y0 += 0.00000000282*np.cos(6.12964546434 + 563.6312150384*t)
	Y0 += 0.00000000219*np.cos(5.01882320875 + 1699.2792165032*t)
	Y0 += 0.00000000280*np.cos(0.67080969267 + 78114.14622758799*t)
	Y0 += 0.00000000266*np.cos(0.99085054170 + 39743.7636327506*t)
	Y0 += 0.00000000211*np.cos(0.17681817187 + 130969.20667296558*t)
	Y0 += 0.00000000244*np.cos(5.94815635837 + 11610.5519583742*t)
	Y0 += 0.00000000224*np.cos(0.66388865647 + 88.865680217*t)
	Y0 += 0.00000000204*np.cos(3.19846374771 + 40565.2543247742*t)
	Y0 += 0.00000000223*np.cos(5.28159723194 + 81706.28436968799*t)
	Y0 += 0.00000000205*np.cos(4.98750840184 + 417.0369633204*t)
	Y0 += 0.00000000197*np.cos(1.04277639896 + 52815.7035694624*t)
	Y0 += 0.00000000211*np.cos(3.56508711838 + 37.1698277913*t)
	Y0 += 0.00000000249*np.cos(5.60231399902 + 71582.48457132299*t)
	Y0 += 0.00000000192*np.cos(2.70968461449 + 66.70484372*t)
	Y0 += 0.00000000188*np.cos(2.35059258101 + 1898.3512179396*t)
	Y0 += 0.00000000204*np.cos(0.78597046714 + 25881.717593137*t)
	Y0 += 0.00000000248*np.cos(0.67786738916 + 51742.09454527159*t)
	Y0 += 0.00000000204*np.cos(2.47411750627 + 207.6700211455*t)
	Y0 += 0.00000000228*np.cos(3.58367417249 + 207.8824694666*t)
	Y0 += 0.00000000203*np.cos(0.77682463263 + 39.0962434843*t)
	Y0 += 0.00000000201*np.cos(1.71510524072 + 26294.08869001139*t)
	Y0 += 0.00000000186*np.cos(2.14393493086 + 16066.0658614748*t)
	Y0 += 0.00000000233*np.cos(2.62533762305 + 7880.08915333899*t)
	Y0 += 0.00000000220*np.cos(4.46432405157 + 218.7157214094*t)
	Y0 += 0.00000000186*np.cos(2.59788381829 + 508.3503240922*t)
	Y0 += 0.00000000195*np.cos(5.53819155539 + 218.9281697305*t)
	Y0 += 0.00000000181*np.cos(3.52971486811 + 14477.35118320*t)
	Y0 += 0.00000000178*np.cos(4.08297672654 + 211.8146227297*t)
	Y0 += 0.00000000224*np.cos(2.49436555659 + 1056.2005364515*t)
	Y0 += 0.00000000175*np.cos(5.68870918967 + 51543.0225438352*t)
	Y0 += 0.00000000195*np.cos(0.90841744066 + 28.5718080822*t)
	Y0 += 0.00000000174*np.cos(1.73818712188 + 339142.74084046457*t)
	Y0 += 0.00000000190*np.cos(4.35107066119 + 142.4496501338*t)
	Y0 += 0.00000000184*np.cos(4.55500539385 + 129483.91596626239*t)
	Y0 += 0.00000000171*np.cos(1.38853028989 + 526.7702037878*t)
	Y0 += 0.00000000192*np.cos(1.49036655542 + 1574.8458012822*t)
	Y0 += 0.00000000184*np.cos(1.16335036072 + 103711.71527998279*t)
	Y0 += 0.00000000186*np.cos(5.42678326989 + 554.0699874828*t)
	Y0 += 0.00000000169*np.cos(6.09402587013 + 532.6117264014*t)
	Y0 += 0.00000000217*np.cos(2.01707572818 + 124.433415221*t)
	Y0 += 0.00000000175*np.cos(5.92248308601 + 525.4981794006*t)
	Y0 += 0.00000000195*np.cos(1.69401523663 + 50483.640613646*t)
	Y0 += 0.00000000191*np.cos(3.65375892828 + 155997.72788435058*t)
	Y0 += 0.00000000169*np.cos(0.91653907112 + 1471.7530270636*t)
	Y0 += 0.00000000158*np.cos(5.04734034343 + 528.9402055692*t)
	Y0 += 0.00000000156*np.cos(4.67130228846 + 90695.75207512038*t)
	Y0 += 0.00000000157*np.cos(2.43465536306 + 530.44172462*t)
	Y0 += 0.00000000188*np.cos(1.87050370857 + 569.0478410098*t)
	Y0 += 0.00000000194*np.cos(2.55166855580 + 183.2428146475*t)
	Y0 += 0.00000000174*np.cos(0.99979811068 + 25938.3399444396*t)
	Y0 += 0.00000000178*np.cos(6.20228633181 + 5.9378908332*t)
	Y0 += 0.00000000201*np.cos(2.24559215395 + 1685.0521225016*t)
	Y0 += 0.00000000153*np.cos(0.95690434145 + 78109.93061423779*t)
	Y0 += 0.00000000207*np.cos(0.24572465192 + 73.8183907208*t)
	Y0 += 0.00000000185*np.cos(3.34815986923 + 265.9892934775*t)
	Y0 += 0.00000000175*np.cos(5.99371438486 + 217.964961884*t)
	Y0 += 0.00000000155*np.cos(1.68645428840 + 188276.65404017158*t)
	Y0 += 0.00000000148*np.cos(2.83101653780 + 519.3960243561*t)
	Y0 += 0.00000000178*np.cos(4.17805845892 + 131498.89763806018*t)
	Y0 += 0.00000000146*np.cos(2.06659470489 + 82.8583534146*t)
	Y0 += 0.00000000157*np.cos(1.36959583051 + 61279.713277266*t)
	Y0 += 0.00000000165*np.cos(2.17592149563 + 467.9649903544*t)
	Y0 += 0.00000000192*np.cos(4.39395898967 + 425.1137181677*t)
	Y0 += 0.00000000201*np.cos(2.16052573018 + 51322.60990139639*t)
	Y0 += 0.00000000177*np.cos(3.62256077196 + 26624.70765366959*t)
	Y0 += 0.00000000149*np.cos(1.96157392100 + 414.0680179038*t)
	Y0 += 0.00000000165*np.cos(3.65136085639 + 231.4583427027*t)
	Y0 += 0.00000000201*np.cos(4.11002299299 + 453.424893819*t)
	Y0 += 0.00000000169*np.cos(3.68765594503 + 121335.60871375339*t)
	Y0 += 0.00000000200*np.cos(4.96476307548 + 1439.5096981492*t)
	Y0 += 0.00000000154*np.cos(3.71172436062 + 52101.02468458109*t)
	Y0 += 0.00000000148*np.cos(3.07726125475 + 104331.94280539699*t)
	Y0 += 0.00000000141*np.cos(1.50870150844 + 50593.84693486539*t)
	Y0 += 0.00000000158*np.cos(1.19202527109 + 78417.48823520739*t)
	Y0 += 0.00000000140*np.cos(4.10887314023 + 408.4389436113*t)
	Y0 += 0.00000000191*np.cos(4.47590456732 + 75.7448064138*t)
	Y0 += 0.00000000144*np.cos(2.36390617422 + 106570.36967048359*t)
	Y0 += 0.00000000149*np.cos(1.58541955295 + 533.8837507886*t)
	Y0 += 0.00000000141*np.cos(0.89841562130 + 52278.89905736699*t)
	Y0 += 0.00000000158*np.cos(2.03821572977 + 208.633228992*t)
	Y0 += 0.00000000163*np.cos(5.63284948646 + 25780.3455206046*t)
	Y0 += 0.00000000153*np.cos(3.42669369028 + 47.6942631934*t)
	Y0 += 0.00000000131*np.cos(6.22770537067 + 203.0041546995*t)
	Y0 += 0.00000000134*np.cos(3.07482380747 + 22759.76748529401*t)
	Y0 += 0.00000000183*np.cos(0.59231255504 + 1021.2488945514*t)
	Y0 += 0.00000000161*np.cos(3.16796063002 + 26395.46076254379*t)
	Y0 += 0.00000000157*np.cos(1.45063371619 + 13362.4497067992*t)
	Y0 += 0.00000000139*np.cos(4.27354999851 + 373.9079928365*t)
	Y0 += 0.00000000139*np.cos(4.04425486837 + 214.7835681463*t)
	Y0 += 0.00000000150*np.cos(5.18410766275 + 104371.28232719658*t)
	Y0 += 0.00000000140*np.cos(6.13152525193 + 102232.84870591838*t)
	Y0 += 0.00000000147*np.cos(2.51789010019 + 23888.81579828719*t)
	Y0 += 0.00000000127*np.cos(2.36011326038 + 54294.57014352679*t)
	Y0 += 0.00000000141*np.cos(2.25597418479 + 52808.59002246159*t)
	Y0 += 0.00000000166*np.cos(1.38695682715 + 305.3461693927*t)
	Y0 += 0.00000000173*np.cos(1.01540755996 + 78187.44335344699*t)
	Y0 += 0.00000000130*np.cos(0.69748880175 + 654.1243803156*t)
	Y0 += 0.00000000144*np.cos(6.26381421560 + 4.192785694*t)
	Y0 += 0.00000000139*np.cos(5.93780077355 + 251.4321310758*t)
	Y0 += 0.00000000121*np.cos(3.73123340759 + 479.2883889155*t)
	Y0 += 0.00000000119*np.cos(6.12399199517 + 178063.36849396059*t)
	Y0 += 0.00000000122*np.cos(2.34676419834 + 181505.94343892598*t)
	Y0 += 0.00000000119*np.cos(5.90821338773 + 114.1384744825*t)
	Y0 += 0.00000000157*np.cos(5.28735408136 + 25551.09862947879*t)
	Y0 += 0.00000000123*np.cos(0.96970788409 + 52072.71350892979*t)
	Y0 += 0.00000000139*np.cos(4.14216887691 + 97112.93697469679*t)
	Y0 += 0.00000000128*np.cos(4.93461808532 + 26521.614879451*t)
	Y0 += 0.00000000115*np.cos(4.65379442884 + 539.9859058331*t)
	Y0 += 0.00000000116*np.cos(2.49690552706 + 104344.49901929598*t)
	Y0 += 0.00000000114*np.cos(0.24802201171 + 154938.34595416138*t)
	Y0 += 0.00000000115*np.cos(5.79810804423 + 29416.03879785439*t)
	Y0 += 0.00000000115*np.cos(6.24514589647 + 110634.68841628819*t)
	Y0 += 0.00000000110*np.cos(4.82546925433 + 68241.87214462319*t)
	Y0 += 0.00000000112*np.cos(0.79767917933 + 24176.703658357*t)
	Y0 += 0.00000000115*np.cos(5.52737393321 + 25754.0472008048*t)
	Y0 += 0.00000000114*np.cos(3.22069040111 + 213.4109700226*t)
	Y0 += 0.00000000114*np.cos(4.81084790265 + 213.1872208534*t)
	Y0 += 0.00000000129*np.cos(6.17361043988 + 302.164775655*t)
	Y0 += 0.00000000113*np.cos(3.27781553156 + 26421.7590823436*t)
	Y0 += 0.00000000116*np.cos(5.36019004356 + 524.0618908021*t)
	Y0 += 0.00000000115*np.cos(2.12419003336 + 535.3200393871*t)
	Y0 += 0.00000000145*np.cos(3.81995922658 + 50579.61984086379*t)
	Y0 += 0.00000000105*np.cos(0.18392017096 + 156100.82065856918*t)
	Y0 += 0.00000000104*np.cos(2.59023526043 + 26198.1094627936*t)
	Y0 += 0.00000000122*np.cos(6.27846196005 + 28286.9904848612*t)
	Y0 += 0.00000000111*np.cos(3.42525009396 + 116917.76426627958*t)
	Y0 += 0.00000000126*np.cos(5.34406107671 + 540.7366653585*t)
	Y0 += 0.00000000119*np.cos(4.95824095217 + 983.1158589136*t)
	Y0 += 0.00000000115*np.cos(0.35603129387 + 98.8999885246*t)
	Y0 += 0.00000000115*np.cos(1.34072654703 + 26011.6370702986*t)
	Y0 += 0.00000000118*np.cos(4.91950265277 + 525.0250986486*t)
	Y0 += 0.00000000105*np.cos(6.00609954043 + 963.4027029714*t)
	Y0 += 0.00000000112*np.cos(1.57964254375 + 51639.00177105299*t)
	Y0 += 0.00000000103*np.cos(1.26476363927 + 74923.09699802278*t)
	Y0 += 0.00000000102*np.cos(1.89629804705 + 56.6223513026*t)
	Y0 += 0.00000000100*np.cos(2.14566059864 + 529.851023789*t)
	Y0 += 0.00000000100*np.cos(5.33661471676 + 529.5309064002*t)
	Y0 += 0.00000000099*np.cos(0.29530316101 + 198.321241911*t)
	Y0 += 0.00000000100*np.cos(3.81573971334 + 25035.6347583858*t)
	Y0 += 0.00000000101*np.cos(1.80630451732 + 27999.1026247914*t)
	Y0 += 0.00000000109*np.cos(2.17221801259 + 175.1660598002*t)
	Y0 += 0.00000000119*np.cos(1.83793946194 + 2324.9494088156*t)
	Y0 += 0.00000000111*np.cos(6.01414242152 + 80.1982245387*t)
	Y0 += 0.00000000100*np.cos(1.69912254726 + 104564.91166173479*t)
	Y0 += 0.00000000096*np.cos(5.43048994495 + 213.0866471169*t)
	Y0 += 0.00000000096*np.cos(2.60104835880 + 213.5115437591*t)
	Y0 += 0.00000000129*np.cos(2.55737037120 + 104138.31347085879*t)
	Y0 += 0.00000000099*np.cos(5.11520176982 + 31415.379249957*t)
	Y0 += 0.00000000099*np.cos(4.90758830995 + 551.031606097*t)
	Y0 += 0.00000000119*np.cos(5.01902877668 + 134991.46920492979*t)
	Y0 += 0.00000000110*np.cos(4.87500455770 + 24356.7807886416*t)
	Y0 += 0.00000000111*np.cos(2.56844286864 + 534.3568315406*t)
	Y0 += 0.00000000117*np.cos(0.19396627342 + 524.2743391232*t)
	Y0 += 0.00000000107*np.cos(3.72516243793 + 55516.4187098482*t)
	Y0 += 0.00000000095*np.cos(3.70643398698 + 327.4375699205*t)
	Y0 += 0.00000000104*np.cos(5.47404374073 + 32.1951448046*t)
	Y0 += 0.00000000127*np.cos(3.26672162678 + 21.3406410024*t)
	Y0 += 0.00000000094*np.cos(2.32320888992 + 54509.0026760204*t)
	Y0 += 0.00000000096*np.cos(4.74148517797 + 1802.3719907218*t)
	Y0 += 0.00000000115*np.cos(1.00365590687 + 535.107591066*t)
	Y0 += 0.00000000094*np.cos(3.49259349841 + 52125.80966124419*t)
	Y0 += 0.00000000096*np.cos(4.77567549605 + 35.685355083*t)
	Y0 += 0.00000000103*np.cos(1.50774531093 + 51951.46148744649*t)
	Y0 += 0.00000000103*np.cos(2.84917048342 + 219.891377577*t)
	Y0 += 0.00000000103*np.cos(3.43765189240 + 26941.0995233262*t)
	Y0 += 0.00000000094*np.cos(3.91518615306 + 27780.06881107659*t)
	Y0 += 0.00000000093*np.cos(4.20565309570 + 99.1606209555*t)
	Y0 += 0.00000000102*np.cos(0.20220739054 + 104355.49390165479*t)
	Y0 += 0.00000000108*np.cos(5.64358884743 + 49527.35145767539*t)
	Y0 += 0.00000000089*np.cos(1.57056354900 + 1382.8873468466*t)
	Y0 += 0.00000000087*np.cos(4.80227955082 + 52325.36948028299*t)
	Y0 += 0.00000000097*np.cos(2.98258829049 + 51219.51712717779*t)
	Y0 += 0.00000000102*np.cos(5.09206185737 + 52250.5878817157*t)
	Y0 += 0.00000000087*np.cos(1.28166497839 + 228.276948965*t)
	Y0 += 0.00000000092*np.cos(4.35841484859 + 140652.80125408198*t)
	Y0 += 0.00000000107*np.cos(0.38517739982 + 157483.01859105378*t)
	Y0 += 0.00000000090*np.cos(3.67394196940 + 36109.7404216736*t)
	Y0 += 0.00000000100*np.cos(1.82319423846 + 96.8729990951*t)
	Y0 += 0.00000000100*np.cos(3.93901407412 + 27819.0254945068*t)
	Y0 += 0.00000000086*np.cos(1.50847151211 + 53228.07466633679*t)
	Y0 += 0.00000000088*np.cos(3.14925830025 + 52065.59996192899*t)
	Y0 += 0.00000000085*np.cos(3.63689104790 + 74.8297826771*t)
	Y0 += 0.00000000085*np.cos(1.04303023325 + 74.7334144575*t)
	Y0 += 0.00000000113*np.cos(5.85548952542 + 177.8743727859*t)
	Y0 += 0.00000000099*np.cos(3.28990595710 + 97580.90196505119*t)
	Y0 += 0.00000000102*np.cos(5.08658507796 + 52225.8029050526*t)
	Y0 += 0.00000000085*np.cos(5.99437376237 + 191.9584544356*t)
	Y0 += 0.00000000087*np.cos(5.84639583938 + 40.5807161926*t)
	Y0 += 0.00000000087*np.cos(1.65916392662 + 104778.21075717278*t)
	Y0 += 0.00000000096*np.cos(1.03224594955 + 38813.3565763492*t)
	Y0 += 0.00000000081*np.cos(6.20215025642 + 25977.69682035479*t)
	Y0 += 0.00000000083*np.cos(1.97230419758 + 78731.674415077*t)
	Y0 += 0.00000000102*np.cos(4.67254721576 + 131.4039498699*t)
	Y0 += 0.00000000093*np.cos(5.77977069690 + 74.5209661364*t)
	Y0 += 0.00000000100*np.cos(3.78538237499 + 119116.85160956658*t)
	Y0 += 0.00000000093*np.cos(5.18093640996 + 75.0422309982*t)
	Y0 += 0.00000000080*np.cos(2.87647086515 + 278.5194664497*t)
	Y0 += 0.00000000089*np.cos(1.46011729281 + 191.2076949102*t)
	Y0 += 0.00000000094*np.cos(3.01992291922 + 51859.41441349179*t)
	Y0 += 0.00000000081*np.cos(4.33788649947 + 53242.3017603384*t)
	Y0 += 0.00000000079*np.cos(2.74811848231 + 38.0211610532*t)
	Y0 += 0.00000000079*np.cos(1.59253269036 + 38.2449102224*t)
	Y0 += 0.00000000083*np.cos(0.78518936484 + 300.6108669775*t)
	Y0 += 0.00000000078*np.cos(5.64618149774 + 30.0562807905*t)
	Y0 += 0.00000000097*np.cos(3.75597837361 + 259.5088859231*t)
	Y0 += 0.00000000081*np.cos(1.65998131052 + 105940.68546158058*t)
	Y0 += 0.00000000077*np.cos(5.85420580120 + 102132.85546210999*t)
	Y0 += 0.00000000091*np.cos(2.66548595290 + 51013.33157874059*t)
	Y0 += 0.00000000089*np.cos(0.95977221728 + 137678.19129947099*t)
	Y0 += 0.00000000085*np.cos(5.14758347117 + 44.070926471*t)
	Y0 += 0.00000000076*np.cos(0.07242308044 + 3328.13565628019*t)
	Y0 += 0.00000000089*np.cos(2.25592202290 + 835.0371344873*t)
	Y0 += 0.00000000076*np.cos(3.13724740029 + 106.2741679563*t)
	Y0 += 0.00000000091*np.cos(2.31009109472 + 80.7194894005*t)
	Y0 += 0.00000000078*np.cos(4.80022000976 + 60055.89543648739*t)
	Y0 += 0.00000000075*np.cos(0.93284040810 + 205.2223405907*t)
	Y0 += 0.00000000085*np.cos(1.29757029645 + 12725.453434775*t)
	Y0 += 0.00000000079*np.cos(1.02058994543 + 74.6215398729*t)
	Y0 += 0.00000000090*np.cos(5.56852789130 + 52492.19815280499*t)
	Y0 += 0.00000000078*np.cos(3.65920759701 + 74.9416572617*t)
	Y0 += 0.00000000089*np.cos(2.43562167097 + 1911.1994832172*t)
	Y0 += 0.00000000073*np.cos(3.57598233076 + 50696.93970908399*t)
	Y0 += 0.00000000076*np.cos(6.27731427042 + 52595.29092702359*t)
	Y0 += 0.00000000102*np.cos(1.77465769367 + 104347.73123093879*t)
	Y0 += 0.00000000077*np.cos(1.39895481144 + 195.1398481733*t)
	Y0 += 0.00000000072*np.cos(4.78502700351 + 213.0384630071*t)
	Y0 += 0.00000000072*np.cos(3.24651089369 + 213.5597278689*t)
	Y0 += 0.00000000072*np.cos(1.47416335611 + 170049.17029103659*t)
	Y0 += 0.00000000096*np.cos(2.67801150530 + 483.2205421786*t)
	Y0 += 0.00000000086*np.cos(2.73735833770 + 2.4476805548*t)
	Y0 += 0.00000000079*np.cos(4.16366799640 + 103285.11708910679*t)
	Y0 += 0.00000000076*np.cos(0.08688140800 + 77844.22478084739*t)
	Y0 += 0.00000000095*np.cos(1.56604928496 + 52698.38370124219*t)
	Y0 += 0.00000000073*np.cos(1.11932970193 + 25021.4076643842*t)
	Y0 += 0.00000000078*np.cos(5.36472752861 + 104358.72611329758*t)
	Y0 += 0.00000000095*np.cos(2.11170756015 + 248.7238180901*t)
	Y0 += 0.00000000069*np.cos(1.88886878891 + 529.4785167735*t)
	Y0 += 0.00000000069*np.cos(5.59340951305 + 529.9034134157*t)
	Y0 += 0.00000000072*np.cos(2.40806201062 + 24998.19435038059*t)
	Y0 += 0.00000000071*np.cos(4.11293729141 + 27669.86248985719*t)
	Y0 += 0.00000000076*np.cos(1.98904461594 + 518.6452648307*t)
	Y0 += 0.00000000074*np.cos(5.08891807794 + 26222.0121911592*t)
	Y0 += 0.00000000067*np.cos(1.93554373786 + 2214.7430875962*t)
	Y0 += 0.00000000079*np.cos(3.71784757916 + 104202.04936916218*t)
	Y0 += 0.00000000067*np.cos(2.65457842453 + 78270.33798362259*t)
	Y0 += 0.00000000066*np.cos(0.44946982323 + 635.9651330509*t)
	Y0 += 0.00000000080*np.cos(6.13936658892 + 8194.2753332086*t)
	Y0 += 0.00000000073*np.cos(3.70705736171 + 25953.79409198919*t)
	Y0 += 0.00000000074*np.cos(2.34582989695 + 97670.38771289718*t)
	Y0 += 0.00000000074*np.cos(2.48641792134 + 68.8437077341*t)
	Y0 += 0.00000000069*np.cos(0.57091762082 + 207643.84320240439*t)
	Y0 += 0.00000000065*np.cos(4.30219875903 + 12546.481939083*t)
	Y0 += 0.00000000071*np.cos(0.07238150577 + 126996.94076290558*t)
	Y0 += 0.00000000066*np.cos(3.25393240581 + 70269.18098269838*t)
	Y0 += 0.00000000084*np.cos(5.41269775901 + 424.1505103212*t)
	Y0 += 0.00000000071*np.cos(1.03137133715 + 275.5505210331*t)
	Y0 += 0.00000000066*np.cos(4.46930207827 + 33.9402499438*t)
	Y0 += 0.00000000079*np.cos(2.22876948108 + 25446.4895798352*t)
	Y0 += 0.00000000063*np.cos(1.65767004610 + 20.6069278195*t)
	Y0 += 0.00000000063*np.cos(1.94299439248 + 150244.34299945379*t)
	Y0 += 0.00000000083*np.cos(5.09775374255 + 404.5067903482*t)
	Y0 += 0.00000000063*np.cos(2.94014383007 + 8.0767548473*t)
	Y0 += 0.00000000068*np.cos(2.22365421702 + 831.8557407496*t)
	Y0 += 0.00000000082*np.cos(5.88510225867 + 154.0166152595*t)
	Y0 += 0.00000000081*np.cos(2.12955581519 + 37.8724032069*t)
	Y0 += 0.00000000078*np.cos(3.71442447350 + 77829.99768684579*t)
	Y0 += 0.00000000073*np.cos(5.60150844280 + 115.8835796217*t)
	Y0 += 0.00000000080*np.cos(2.21108404080 + 38.3936680687*t)
	Y0 += 0.00000000081*np.cos(3.57966030338 + 49842.60989027639*t)
	Y0 += 0.00000000064*np.cos(4.44827566878 + 284.1485407422*t)
	Y0 += 0.00000000071*np.cos(1.76878466162 + 27684.0895838588*t)
	Y0 += 0.00000000065*np.cos(0.10862838701 + 27177.6119327678*t)
	Y0 += 0.00000000077*np.cos(0.29329825954 + 26729.31670331319*t)
	Y0 += 0.00000000082*np.cos(4.87562280261 + 26089.38761428249*t)
	Y0 += 0.00000000070*np.cos(0.48885804664 + 107.0249274817*t)
	Y0 += 0.00000000076*np.cos(1.87316011759 + 137210.22630911658*t)
	Y0 += 0.00000000071*np.cos(3.36184821357 + 17893.6278083656*t)
	Y0 += 0.00000000063*np.cos(2.50604307758 + 52290.24557183361*t)
	Y0 += 0.00000000060*np.cos(6.11673834767 + 52061.36699446317*t)
	Y0 += 0.00000000069*np.cos(0.94467164100 + 511.5317178299*t)
	Y0 += 0.00000000081*np.cos(3.95123901433 + 26086.4186688659*t)
	Y0 += 0.00000000072*np.cos(4.57323993670 + 50800.03248330259*t)
	Y0 += 0.00000000058*np.cos(4.95419870669 + 46.2097904851*t)
	Y0 += 0.00000000077*np.cos(0.77427822658 + 103299.34418310839*t)
	Y0 += 0.00000000079*np.cos(4.15336422499 + 531.1754378029*t)
	Y0 += 0.00000000067*np.cos(5.81376296368 + 643.8294395771*t)
	Y0 += 0.00000000058*np.cos(1.07510302489 + 167850.08294774959*t)
	Y0 += 0.00000000071*np.cos(5.75558240346 + 34282.1784747828*t)
	Y0 += 0.00000000056*np.cos(3.55494344576 + 44295.7171298094*t)
	Y0 += 0.00000000056*np.cos(6.15449621937 + 842.1506814881*t)
	Y0 += 0.00000000065*np.cos(0.26869494906 + 547.8502123593*t)
	Y0 += 0.00000000055*np.cos(5.96851303023 + 23969.1392811958*t)
	Y0 += 0.00000000055*np.cos(2.16330884790 + 209812.60368468695*t)
	Y0 += 0.00000000065*np.cos(5.22228985131 + 77410.51304297059*t)
	Y0 += 0.00000000058*np.cos(6.25432646821 + 25508.2155545754*t)
	Y0 += 0.00000000065*np.cos(3.80914914376 + 3178.1457905676*t)
	Y0 += 0.00000000069*np.cos(3.21235031019 + 269.9214467406*t)
	Y0 += 0.00000000056*np.cos(3.84165768987 + 22625.658435709*t)
	Y0 += 0.00000000075*np.cos(3.14349504273 + 227.3137411185*t)
	Y0 += 0.00000000054*np.cos(4.44808157827 + 52252.07235442399*t)
	Y0 += 0.00000000058*np.cos(1.80561279339 + 2641.3412784722*t)
	Y0 += 0.00000000061*np.cos(4.72931440223 + 121.2520214833*t)
	Y0 += 0.00000000055*np.cos(2.05172474251 + 107794.18751126219*t)
	Y0 += 0.00000000066*np.cos(0.18130668165 + 77795.74443436819*t)
	Y0 += 0.00000000068*np.cos(2.93375218430 + 19.66976089979*t)
	Y0 += 0.00000000061*np.cos(1.41008037643 + 429.0458714308*t)
	Y0 += 0.00000000064*np.cos(2.72423324964 + 159.1244246902*t)
	Y0 += 0.00000000061*np.cos(2.23944425679 + 650.9429865779*t)
	Y0 += 0.00000000055*np.cos(3.59336928200 + 172402.03644480839*t)
	Y0 += 0.00000000052*np.cos(1.67890984864 + 2538.2485042536*t)
	Y0 += 0.00000000056*np.cos(3.42328370031 + 24448.8336243862*t)
	Y0 += 0.00000000073*np.cos(3.31073272937 + 528.2064923863*t)
	Y0 += 0.00000000073*np.cos(3.18180022689 + 24864.08530079559*t)
	Y0 += 0.00000000057*np.cos(1.89137287758 + 92.940845832*t)
	Y0 += 0.00000000052*np.cos(4.91273220472 + 66653.15746634839*t)
	Y0 += 0.00000000068*np.cos(5.14472869299 + 219.4494345923*t)
	Y0 += 0.00000000053*np.cos(4.10843855595 + 26312.2479372761*t)
	Y0 += 0.00000000054*np.cos(2.57050838382 + 26667.590728573*t)
	Y0 += 0.00000000051*np.cos(3.53345258541 + 1048.3362299253*t)
	Y0 += 0.00000000062*np.cos(4.52301275304 + 425.6349830295*t)
	Y0 += 0.00000000065*np.cos(1.17174840770 + 14.977853527*t)
	Y0 += 0.00000000058*np.cos(4.32481237367 + 72.0732855816*t)
	Y0 += 0.00000000050*np.cos(6.18510990638 + 960.2213092337*t)
	Y0 += 0.00000000055*np.cos(0.04281344157 + 42.3258213318*t)
	Y0 += 0.00000000050*np.cos(4.83446941002 + 426.6463749858*t)
	Y0 += 0.00000000049*np.cos(3.21271029936 + 514.7131115676*t)
	Y0 += 0.00000000068*np.cos(0.06574276360 + 2199.087343287*t)
	Y0 += 0.00000000065*np.cos(2.41337358880 + 494.2662424425*t)
	Y0 += 0.00000000067*np.cos(2.57317423197 + 618.5566453116*t)
	Y0 += 0.00000000049*np.cos(1.03606235160 + 96357.08412427259*t)
	Y0 += 0.00000000051*np.cos(5.94534572630 + 58857.03113654799*t)
	Y0 += 0.00000000068*np.cos(5.79687331046 + 78257.08086582259*t)
	Y0 += 0.00000000062*np.cos(6.11167050077 + 750.1036075334*t)
	Y0 += 0.00000000050*np.cos(4.20409547221 + 129799.61842155698*t)
	Y0 += 0.00000000049*np.cos(2.61342795296 + 27044.1922975448*t)
	Y0 += 0.00000000053*np.cos(0.86945819735 + 2428.0421830342*t)
	Y0 += 0.00000000051*np.cos(5.36138555309 + 27726.9726587622*t)
	Y0 += 0.00000000050*np.cos(1.63663518288 + 426.5500067662*t)
	Y0 += 0.00000000048*np.cos(6.03611290368 + 99024.13645791399*t)
	Y0 += 0.00000000047*np.cos(4.26489760399 + 544.6688186216*t)
	Y0 += 0.00000000047*np.cos(4.10470299674 + 51969.62073471119*t)
	Y0 += 0.00000000047*np.cos(4.45256678947 + 387.2413149608*t)
	Y0 += 0.00000000055*np.cos(3.70101890767 + 81.8951455681*t)
	Y0 += 0.00000000049*np.cos(2.30004526739 + 77630.92568540938*t)
	Y0 += 0.00000000056*np.cos(4.95742185541 + 27037.07875054399*t)
	Y0 += 0.00000000060*np.cos(0.53980789709 + 488.8496164711*t)
	Y0 += 0.00000000064*np.cos(2.60081517768 + 1364.7280995819*t)
	Y0 += 0.00000000065*np.cos(5.63247484940 + 27311.72098235281*t)
	Y0 += 0.00000000055*np.cos(3.21960099803 + 157057.10981453978*t)
	Y0 += 0.00000000064*np.cos(4.73090166157 + 76571.54375522019*t)
	Y0 += 0.00000000055*np.cos(4.21524098893 + 23919.1426592916*t)
	Y0 += 0.00000000047*np.cos(4.96233788191 + 29550.14784743939*t)
	Y0 += 0.00000000047*np.cos(1.33048751622 + 155571.81910783658*t)
	Y0 += 0.00000000048*np.cos(4.68524066713 + 39629.32434406539*t)
	Y0 += 0.00000000049*np.cos(2.26366790917 + 86143.79857806159*t)
	Y0 += 0.00000000052*np.cos(2.81764658144 + 210.5907824523*t)
	Y0 += 0.00000000052*np.cos(6.11102279257 + 28736.3579670472*t)
	Y0 += 0.00000000053*np.cos(2.05896623723 + 427.5613987225*t)
	Y0 += 0.00000000046*np.cos(4.52836499361 + 76681.75007643958*t)
	Y0 += 0.00000000051*np.cos(5.21356444643 + 216.0074084237*t)
	Y0 += 0.00000000050*np.cos(3.05458837611 + 1056.9342496344*t)
	Y0 += 0.00000000049*np.cos(6.03922030861 + 501.3797894433*t)
	Y0 += 0.00000000063*np.cos(6.05525919705 + 176953.98994186718*t)
	Y0 += 0.00000000052*np.cos(3.90556632585 + 25138.7275326044*t)
	Y0 += 0.00000000044*np.cos(2.11826208004 + 16703.062133499*t)
	Y0 += 0.00000000044*np.cos(3.59534331356 + 74.0308390419*t)
	Y0 += 0.00000000044*np.cos(2.54428216341 + 2751.5475996916*t)
	Y0 += 0.00000000044*np.cos(4.09373605789 + 78903.60671103658*t)
	Y0 += 0.00000000050*np.cos(4.96516261929 + 1279.794572628*t)
	Y0 += 0.00000000050*np.cos(5.77173682772 + 355.7487455718*t)
	Y0 += 0.00000000044*np.cos(1.08481523531 + 75.5323580927*t)
	Y0 += 0.00000000043*np.cos(5.70834575414 + 213.4591541324*t)
	Y0 += 0.00000000043*np.cos(2.32287306604 + 213.1390367436*t)
	Y0 += 0.00000000043*np.cos(5.47593276555 + 220.4608265486*t)
	Y0 += 0.00000000056*np.cos(1.59993474661 + 491.8185618877*t)
	Y0 += 0.00000000054*np.cos(5.39695767554 + 187.6962327724*t)
	Y0 += 0.00000000050*np.cos(3.99260483640 + 296.1574488526*t)
	Y0 += 0.00000000057*np.cos(5.35044527046 + 1061.829610744*t)
	Y0 += 0.00000000043*np.cos(3.24179066608 + 128.9562693151*t)
	Y0 += 0.00000000054*np.cos(4.84794812605 + 52381.99183158559*t)
	Y0 += 0.00000000042*np.cos(0.51072992828 + 78188.92782615528*t)
	Y0 += 0.00000000048*np.cos(4.03364140605 + 65831.6667743248*t)
	Y0 += 0.00000000054*np.cos(2.89069416534 + 207.1487562837*t)
	Y0 += 0.00000000048*np.cos(1.44348407688 + 106.9767433719*t)
	Y0 += 0.00000000056*np.cos(3.88391523095 + 1057.8974574809*t)
	Y0 += 0.00000000047*np.cos(3.45990384746 + 679.2541622292*t)
	Y0 += 0.00000000053*np.cos(0.36365795711 + 601.7642506762*t)
	Y0 += 0.00000000047*np.cos(4.06325102883 + 104275.34649502118*t)
	Y0 += 0.00000000040*np.cos(2.54799612698 + 1059.430114299*t)
	Y0 += 0.00000000048*np.cos(5.22216564191 + 25466.159340735*t)
	Y0 += 0.00000000045*np.cos(3.08256873858 + 10.2949407385*t)
	Y0 += 0.00000000051*np.cos(4.18413102003 + 344.7030453079*t)
	Y0 += 0.00000000042*np.cos(2.30009534060 + 220.364458329*t)
	Y0 += 0.00000000039*np.cos(2.42252858155 + 55503.94193942859*t)
	Y0 += 0.00000000055*np.cos(5.75395220831 + 188.9200730498*t)
	Y0 += 0.00000000048*np.cos(0.55204010547 + 76667.52298243798*t)
	Y0 += 0.00000000041*np.cos(4.68645736183 + 54087.0057663656*t)
	Y0 += 0.00000000053*np.cos(0.70077978084 + 67.6680515665*t)
	Y0 += 0.00000000047*np.cos(3.57377527690 + 26709.6469424134*t)
	Y0 += 0.00000000046*np.cos(4.58966952379 + 28256.66362385679*t)
	Y0 += 0.00000000039*np.cos(1.93706467599 + 1788.1448967202*t)
	Y0 += 0.00000000040*np.cos(2.43593735104 + 25352.02662804239*t)
	Y0 += 0.00000000044*np.cos(0.28326275745 + 52712.61079524379*t)
	Y0 += 0.00000000040*np.cos(0.06426607172 + 26823.77965510599*t)
	Y0 += 0.00000000044*np.cos(4.99425187685 + 179.3588454942*t)
	Y0 += 0.00000000043*np.cos(4.78359780736 + 365230.64398203876*t)
	Y0 += 0.00000000051*np.cos(0.42322753564 + 182085.63102592478*t)
	Y0 += 0.00000000044*np.cos(0.26434468297 + 289.5651667136*t)
	Y0 += 0.00000000040*np.cos(4.73960650797 + 436.1594184316*t)
	Y0 += 0.00000000045*np.cos(3.69056749350 + 25867.49049913539*t)
	Y0 += 0.00000000038*np.cos(2.95265152123 + 128320.75184749259*t)
	Y0 += 0.00000000040*np.cos(3.26413558741 + 149.45132255*t)
	Y0 += 0.00000000047*np.cos(1.24067371450 + 1038.0412891868*t)
	Y0 += 0.00000000038*np.cos(4.24964079407 + 104505.39137678158*t)
	Y0 += 0.00000000037*np.cos(5.45870103761 + 132658.27281205778*t)
	Y0 += 0.00000000044*np.cos(0.82332847780 + 358.9301393095*t)
	Y0 += 0.00000000036*np.cos(4.01505056763 + 104197.83375581198*t)
	Y0 += 0.00000000042*np.cos(4.73645882503 + 214364.55718174578*t)
	Y0 += 0.00000000042*np.cos(3.62652817335 + 25169.9728555924*t)
	Y0 += 0.00000000038*np.cos(5.05414542008 + 13541.42120249119*t)
	Y0 += 0.00000000036*np.cos(1.35884346175 + 68.1893164283*t)
	Y0 += 0.00000000036*np.cos(1.25304159965 + 116783.65521669458*t)
	Y0 += 0.00000000047*np.cos(5.73121342219 + 523.5406259403*t)
	Y0 += 0.00000000036*np.cos(1.89385828446 + 59.8037450403*t)
	Y0 += 0.00000000040*np.cos(5.63337030653 + 1059.3337460794*t)
	Y0 += 0.00000000037*np.cos(0.15651744362 + 26073.67604757259*t)
	Y0 += 0.00000000037*np.cos(1.95429510696 + 130459.18546877075*t)
	Y0 += 0.00000000038*np.cos(4.07163115574 + 212.0270710508*t)
	Y0 += 0.00000000037*np.cos(3.95930414230 + 214.5711198252*t)
	Y0 += 0.00000000037*np.cos(0.10010579661 + 24203.0019781568*t)
	Y0 += 0.00000000047*np.cos(0.89434277888 + 50.4025761791*t)
	Y0 += 0.00000000036*np.cos(1.07961540756 + 26057.57628056979*t)
	Y0 += 0.00000000036*np.cos(2.35351546150 + 26102.1302355758*t)
	Y0 += 0.00000000039*np.cos(0.73367000632 + 1514.2912967165*t)
	Y0 += 0.00000000040*np.cos(5.57904418434 + 497.4476361802*t)
	Y0 += 0.00000000035*np.cos(2.73744180385 + 672.1406152284*t)
	Y0 += 0.00000000040*np.cos(1.63699678518 + 143.6253063014*t)
	Y0 += 0.00000000035*np.cos(1.43330630555 + 26118.2300025786*t)
	Y0 += 0.00000000036*np.cos(5.28457918668 + 78896.49316403578*t)
	Y0 += 0.00000000036*np.cos(3.56130087049 + 1361.5467058442*t)
	Y0 += 0.00000000047*np.cos(0.46836410864 + 147423.51185532758*t)
	Y0 += 0.00000000037*np.cos(3.86488170615 + 78366.80219894118*t)
	Y0 += 0.00000000034*np.cos(1.99586823431 + 27566.76971563859*t)
	Y0 += 0.00000000035*np.cos(3.08830623607 + 89.7594520943*t)
	Y0 += 0.00000000039*np.cos(5.16595018555 + 27005.83342755599*t)
	Y0 += 0.00000000045*np.cos(1.86629837439 + 153.7788104848*t)
	Y0 += 0.00000000037*np.cos(2.43731961667 + 25773.71696170459*t)
	Y0 += 0.00000000040*np.cos(0.01680612963 + 149.6750717192*t)
	Y0 += 0.00000000043*np.cos(1.35224903493 + 312.4597163935*t)
	Y0 += 0.00000000044*np.cos(5.23291381444 + 26308.315784013*t)
	Y0 += 0.00000000035*np.cos(1.05320110634 + 27463.67694142*t)
	Y0 += 0.00000000042*np.cos(1.76079418628 + 535.8413042489*t)
	Y0 += 0.00000000040*np.cos(4.02382647386 + 25654.19140369739*t)
	Y0 += 0.00000000037*np.cos(0.07560209645 + 26402.0893214438*t)
	Y0 += 0.00000000036*np.cos(1.61232862223 + 51653.22886505459*t)
	Y0 += 0.00000000033*np.cos(0.42458452244 + 26189.8656598398*t)
	Y0 += 0.00000000035*np.cos(0.17606718200 + 529.9515975255*t)
	Y0 += 0.00000000035*np.cos(1.02336134569 + 529.4303326637*t)
	Y0 += 0.00000000032*np.cos(5.23283983463 + 51852.30086649099*t)
	Y0 += 0.00000000032*np.cos(2.54476552980 + 206.1373643274*t)
	Y0 += 0.00000000042*np.cos(2.44221903170 + 75615.25459924959*t)
	Y0 += 0.00000000045*np.cos(5.30626896435 + 1512.8068240082*t)
	Y0 += 0.00000000043*np.cos(2.21665582542 + 237.6781178262*t)
	Y0 += 0.00000000033*np.cos(2.42762603478 + 2001.4439921582*t)
	Y0 += 0.00000000033*np.cos(2.88930013582 + 204151.27163553478*t)
	Y0 += 0.00000000036*np.cos(6.12428536735 + 130419.8459469712*t)
	Y0 += 0.00000000035*np.cos(0.40523188780 + 9384.8410080752*t)
	Y0 += 0.00000000032*np.cos(2.08833719067 + 25985.94062330859*t)
	Y0 += 0.00000000034*np.cos(2.34445071844 + 522.6256022036*t)
	Y0 += 0.00000000033*np.cos(0.23168510760 + 35472.7441496494*t)
	Y0 += 0.00000000031*np.cos(3.37478583123 + 81.3738807063*t)
	Y0 += 0.00000000031*np.cos(5.42920592130 + 522.529233984*t)
	Y0 += 0.00000000033*np.cos(2.40916004743 + 27972.80430499159*t)
	Y0 += 0.00000000040*np.cos(3.30306819298 + 1593.0050485469*t)
	Y0 += 0.00000000032*np.cos(3.35243256009 + 767.3690829208*t)
	Y0 += 0.00000000043*np.cos(0.94126409897 + 157586.80077963437*t)
	Y0 += 0.00000000034*np.cos(2.40767650115 + 51868.2486621788*t)
	Y0 += 0.00000000044*np.cos(1.43873271021 + 51528.79544983359*t)
	Y0 += 0.00000000038*np.cos(5.10282384073 + 92.0470739547*t)
	Y0 += 0.00000000031*np.cos(6.06589927522 + 35.212274331*t)
	Y0 += 0.00000000031*np.cos(4.01862366233 + 78160.61665050399*t)
	Y0 += 0.00000000033*np.cos(6.06643896212 + 1060.3451380357*t)
	Y0 += 0.00000000031*np.cos(5.39381686645 + 207593.84658050018*t)
	Y0 += 0.00000000031*np.cos(1.63565043557 + 94329.77528619739*t)
	Y0 += 0.00000000030*np.cos(5.90282820835 + 1585.1407420207*t)
	Y0 += 0.00000000030*np.cos(5.53920573257 + 130432.40216087017*t)
	Y0 += 0.00000000033*np.cos(4.63488708885 + 5.4166259714*t)
	Y0 += 0.00000000030*np.cos(3.30348567737 + 181026.24909573558*t)
	Y0 += 0.00000000036*np.cos(5.94088407657 + 181.0557665236*t)
	Y0 += 0.00000000031*np.cos(0.58465350275 + 51432.81622261579*t)
	Y0 += 0.00000000035*np.cos(5.63323743373 + 130226.21661243298*t)
	Y0 += 0.00000000031*np.cos(5.71228872293 + 206.233732547*t)
	Y0 += 0.00000000041*np.cos(4.10893149085 + 64901.25971792339*t)
	Y0 += 0.00000000038*np.cos(2.74077466350 + 37698.4550999484*t)
	Y0 += 0.00000000028*np.cos(5.42226462076 + 80382.47328510099*t)
	Y0 += 0.00000000028*np.cos(3.23530343392 + 182188.72380014337*t)
	Y0 += 0.00000000030*np.cos(5.69753597308 + 77101.23472031478*t)
	Y0 += 0.00000000032*np.cos(1.03692995892 + 49953.94964855139*t)
	Y0 += 0.00000000027*np.cos(4.34958892371 + 101011.00013959699*t)
	Y0 += 0.00000000029*np.cos(2.97395589358 + 426.0769260142*t)
	Y0 += 0.00000000029*np.cos(2.60689456510 + 26083.97098831109*t)
	Y0 += 0.00000000027*np.cos(0.05549126696 + 52509.6622239178*t)
	Y0 += 0.00000000027*np.cos(0.43069996566 + 643.0786800517*t)
	Y0 += 0.00000000034*np.cos(2.04440145216 + 245.5424243524*t)
	Y0 += 0.00000000029*np.cos(6.19291069275 + 26091.83529483729*t)
	Y0 += 0.00000000029*np.cos(3.97759672159 + 458.8415197904*t)
	Y0 += 0.00000000027*np.cos(2.79321900732 + 113.3877149571*t)
	Y0 += 0.00000000029*np.cos(5.12998256913 + 536.7563279856*t)
	Y0 += 0.00000000026*np.cos(2.06190087041 + 536.8526962052*t)
	Y0 += 0.00000000030*np.cos(2.98025809633 + 247.2393453818*t)
	Y0 += 0.00000000032*np.cos(2.62281532990 + 24925.4284371664*t)
	Y0 += 0.00000000034*np.cos(5.96614879093 + 22003.9146348698*t)
	Y0 += 0.00000000035*np.cos(6.21900169182 + 52483.36390411799*t)
	Y0 += 0.00000000029*np.cos(3.02582488582 + 136722.59155786238*t)
	Y0 += 0.00000000031*np.cos(4.43970588456 + 87367.61641884019*t)
	Y0 += 0.00000000031*np.cos(1.37524160449 + 567.8240007324*t)
	Y0 += 0.00000000033*np.cos(4.64183110644 + 77726.90491262719*t)
	Y0 += 0.00000000027*np.cos(2.98857169783 + 558.0021407459*t)
	Y0 += 0.00000000026*np.cos(4.27544189057 + 26049.7701059364*t)
	Y0 += 0.00000000033*np.cos(1.49583126452 + 885.4397106664*t)
	Y0 += 0.00000000026*np.cos(0.62593148485 + 528.4189407074*t)
	Y0 += 0.00000000025*np.cos(4.75010185308 + 130652.81480330898*t)
	Y0 += 0.00000000033*np.cos(4.03510285925 + 68.5618234438*t)
	Y0 += 0.00000000026*np.cos(0.57312068081 + 530.9629894818*t)
	Y0 += 0.00000000026*np.cos(3.04611137889 + 54374.8936264354*t)
	Y0 += 0.00000000028*np.cos(0.48396088623 + 51226.63067417859*t)
	Y0 += 0.00000000033*np.cos(4.54904645879 + 78039.36462902068*t)
	Y0 += 0.00000000025*np.cos(1.86315259104 + 144.1465711632*t)
	Y0 += 0.00000000030*np.cos(4.12682460945 + 69.1525242748*t)
	Y0 += 0.00000000027*np.cos(3.40789619643 + 183570.92173262799*t)
	Y0 += 0.00000000033*np.cos(0.91422316489 + 123200.84011627098*t)
	Y0 += 0.00000000025*np.cos(1.86918416559 + 78338.49102328988*t)
	Y0 += 0.00000000027*np.cos(5.63520290926 + 1223.81784077861*t)
	Y0 += 0.00000000024*np.cos(1.09879284413 + 24824.745778996*t)
	Y0 += 0.00000000031*np.cos(5.38346601432 + 235.3904959658*t)
	Y0 += 0.00000000030*np.cos(6.02578053535 + 77307.42026875199*t)
	Y0 += 0.00000000026*np.cos(4.88440379376 + 69.3649725959*t)
	Y0 += 0.00000000024*np.cos(4.58671428072 + 41.0537969446*t)
	Y0 += 0.00000000026*np.cos(4.40497747181 + 39450.3528483734*t)
	Y0 += 0.00000000024*np.cos(6.27647996519 + 934.9485149682*t)
	Y0 += 0.00000000029*np.cos(4.01431074745 + 25600.26839032*t)
	Y0 += 0.00000000027*np.cos(5.45015263034 + 27170.98337386779*t)
	Y0 += 0.00000000027*np.cos(3.35506505446 + 25004.8229092806*t)
	Y0 += 0.00000000026*np.cos(1.01956540442 + 746.9222137957*t)
	Y0 += 0.00000000027*np.cos(2.81184546014 + 88.7962442478*t)
	Y0 += 0.00000000024*np.cos(2.04291264310 + 54.1746707478*t)
	Y0 += 0.00000000024*np.cos(1.70570280621 + 52609.51802102519*t)
	Y0 += 0.00000000024*np.cos(0.92190112786 + 129373.02023068098*t)
	Y0 += 0.00000000026*np.cos(5.16330947382 + 206.706813299*t)
	Y0 += 0.00000000026*np.cos(3.48718560303 + 427.1194557378*t)
	Y0 += 0.00000000027*np.cos(0.19476264674 + 143005.66740785378*t)
	Y0 += 0.00000000027*np.cos(6.01076879125 + 24072.9214697764*t)
	Y0 += 0.00000000023*np.cos(3.87311020164 + 146.3818033969*t)
	Y0 += 0.00000000024*np.cos(5.68395366955 + 52286.01260436779*t)
	Y0 += 0.00000000028*np.cos(4.77908913093 + 26575.53789282839*t)
	Y0 += 0.00000000024*np.cos(1.35152561667 + 447.9388318784*t)
	Y0 += 0.00000000023*np.cos(4.31374933960 + 31.5407534988*t)
	Y0 += 0.00000000030*np.cos(1.77580150574 + 161079.37234650398*t)
	Y0 += 0.00000000025*np.cos(3.28511315405 + 92741.06060792258*t)
	Y0 += 0.00000000031*np.cos(2.21418055348 + 1058.4187223427*t)
	Y0 += 0.00000000023*np.cos(1.28923152263 + 60370.08161635699*t)
	Y0 += 0.00000000023*np.cos(0.30769835394 + 76784.84285065818*t)
	Y0 += 0.00000000025*np.cos(6.12372098057 + 48847.6706268682*t)
	Y0 += 0.00000000029*np.cos(4.96198802688 + 23.5758732361*t)
	Y0 += 0.00000000026*np.cos(6.21853790794 + 78153.50310350319*t)
	Y0 += 0.00000000023*np.cos(0.96856236499 + 523.0986829556*t)
	Y0 += 0.00000000025*np.cos(2.35513367075 + 39.3568759152*t)
	Y0 += 0.00000000023*np.cos(6.03986636871 + 77947.31755506598*t)
	Y0 += 0.00000000023*np.cos(0.06005390957 + 123668.80510662538*t)
	Y0 += 0.00000000023*np.cos(0.25207950257 + 14.0146456805*t)
	Y0 += 0.00000000022*np.cos(0.26166099168 + 78213.71280281838*t)
	Y0 += 0.00000000025*np.cos(4.36791869246 + 26724.8994135984*t)
	Y0 += 0.00000000025*np.cos(4.43729899234 + 25450.90686955*t)
	Y0 += 0.00000000022*np.cos(1.41483604412 + 27351.06050415239*t)
	Y0 += 0.00000000028*np.cos(2.82763549527 + 30171.8916482786*t)
	Y0 += 0.00000000029*np.cos(6.28195292509 + 1023.9572075371*t)
	Y0 += 0.00000000022*np.cos(3.84824366233 + 50264.6067999312*t)
	Y0 += 0.00000000026*np.cos(5.41642995127 + 25234.70675982219*t)
	Y0 += 0.00000000027*np.cos(1.49068438865 + 258.0244132148*t)
	Y0 += 0.00000000030*np.cos(0.70937754307 + 53906.92863608099*t)
	Y0 += 0.00000000021*np.cos(1.44135675848 + 420.9691165835*t)
	Y0 += 0.00000000024*np.cos(3.38673660916 + 342.2553647531*t)
	Y0 += 0.00000000028*np.cos(0.32194633183 + 162.0933701068*t)
	Y0 += 0.00000000024*np.cos(4.62065948726 + 78786.28684281638*t)
	Y0 += 0.00000000022*np.cos(1.83211095898 + 6885.14988993081*t)
	Y0 += 0.00000000022*np.cos(1.19881833941 + 50064.15596977079*t)
	Y0 += 0.00000000025*np.cos(4.82521606002 + 130435.63437251298*t)
	Y0 += 0.00000000022*np.cos(1.64262163906 + 50444.6839302158*t)
	Y0 += 0.00000000026*np.cos(5.47900878960 + 152.0108776894*t)
	Y0 += 0.00000000022*np.cos(4.68575585219 + 320.3240229197*t)
	Y0 += 0.00000000027*np.cos(0.60945244318 + 81.0013736908*t)
	Y0 += 0.00000000026*np.cos(4.75752764914 + 1158.5425511447*t)
	Y0 += 0.00000000023*np.cos(0.48284788906 + 103917.90082841998*t)
	Y0 += 0.00000000025*np.cos(0.72627176075 + 52174.32181044009*t)
	Y0 += 0.00000000022*np.cos(2.31815942379 + 78580.10129437919*t)
	Y0 += 0.00000000022*np.cos(5.37072237928 + 80596.9058175946*t)
	Y0 += 0.00000000024*np.cos(2.29466576857 + 51841.950342379*t)
	Y0 += 0.00000000024*np.cos(2.71292041287 + 260.9933586314*t)
	Y0 += 0.00000000022*np.cos(3.98563117453 + 163766.09444104518*t)
	Y0 += 0.00000000022*np.cos(0.96530934897 + 337.732510659*t)
	Y0 += 0.00000000024*np.cos(2.77938448215 + 28102.884813372*t)
	Y0 += 0.00000000028*np.cos(4.67187139230 + 6129.2970395066*t)
	Y0 += 0.00000000028*np.cos(4.50423924612 + 1731.1223529326*t)
	Y0 += 0.00000000024*np.cos(1.73470580103 + 1134.1635287565*t)
	Y0 += 0.00000000023*np.cos(0.91598037938 + 4.665866446*t)
	Y0 += 0.00000000023*np.cos(3.83483940099 + 129387.24732468258*t)
	Y0 += 0.00000000020*np.cos(1.57021274170 + 2104.5367663768*t)
	Y0 += 0.00000000021*np.cos(0.23251071113 + 536.2832472336*t)
	Y0 += 0.00000000021*np.cos(2.06391569985 + 521.6142102473*t)
	Y0 += 0.00000000023*np.cos(3.92597486873 + 391.1734682239*t)
	Y0 += 0.00000000025*np.cos(0.44167057897 + 81604.32185142238*t)
	Y0 += 0.00000000020*np.cos(5.66294891654 + 1603.2999892854*t)
	Y0 += 0.00000000020*np.cos(1.26511552629 + 212.0752551606*t)
	Y0 += 0.00000000020*np.cos(0.48291798671 + 214.5229357154*t)
	Y0 += 0.00000000020*np.cos(0.82904675049 + 99.9113804809*t)
	Y0 += 0.00000000022*np.cos(3.97512645943 + 621.7380390493*t)
	Y0 += 0.00000000024*np.cos(0.37655000500 + 31.019488637*t)
	Y0 += 0.00000000020*np.cos(3.96183227004 + 630.3360587584*t)
	Y0 += 0.00000000020*np.cos(1.51439029768 + 692.5874843535*t)
	Y0 += 0.00000000020*np.cos(5.63766440403 + 51955.39364070959*t)
	Y0 += 0.00000000020*np.cos(4.83495758164 + 230.5645708254*t)
	Y0 += 0.00000000023*np.cos(1.56251814290 + 495.7507151508*t)
	Y0 += 0.00000000023*np.cos(3.81105398957 + 181.7583419392*t)
	Y0 += 0.00000000019*np.cos(0.14811705167 + 1089.7087911936*t)
	Y0 += 0.00000000021*np.cos(0.48382399190 + 130289.95251073639*t)
	Y0 += 0.00000000026*np.cos(5.38965597987 + 776.9303104764*t)
	Y0 += 0.00000000020*np.cos(6.06263628388 + 86457.98475793119*t)
	Y0 += 0.00000000020*np.cos(5.37392483479 + 123758.29085447139*t)
	Y0 += 0.00000000021*np.cos(1.23628963571 + 60.7669528868*t)
	Y0 += 0.00000000019*np.cos(5.99896464484 + 51329.7234483972*t)
	Y0 += 0.00000000020*np.cos(4.52823506105 + 196137.07343261078*t)
	Y0 += 0.00000000023*np.cos(1.12690816744 + 166740.70439565618*t)
	Y0 += 0.00000000019*np.cos(3.91126145868 + 423.6774295692*t)
	Y0 += 0.00000000022*np.cos(3.39965156778 + 16342.5825857176*t)
	Y0 += 0.00000000022*np.cos(5.57412323033 + 3462.2447058652*t)
	Y0 += 0.00000000023*np.cos(3.16482764080 + 353.301065017*t)
	Y0 += 0.00000000023*np.cos(2.31183970817 + 50167.24874398939*t)
	Y0 += 0.00000000022*np.cos(4.76145913299 + 26126.036177212*t)
	Y0 += 0.00000000022*np.cos(4.14425825536 + 26734.913974889*t)
	Y0 += 0.00000000019*np.cos(3.09805264388 + 78683.19406859778*t)
	Y0 += 0.00000000019*np.cos(1.57754212699 + 78413.27262185719*t)
	Y0 += 0.00000000024*np.cos(0.55755098688 + 145204.75475114079*t)
	Y0 += 0.00000000019*np.cos(3.56013605744 + 102018.41617342478*t)
	Y0 += 0.00000000021*np.cos(1.90244085454 + 73.4090004436*t)
	Y0 += 0.00000000019*np.cos(1.66681958500 + 2531.1349572528*t)
	Y0 += 0.00000000019*np.cos(2.12244186746 + 130446.62925487179*t)
	Y0 += 0.00000000020*np.cos(1.47362321872 + 211.6021744086*t)
	Y0 += 0.00000000019*np.cos(0.10308351886 + 6.1503391543*t)
	Y0 += 0.00000000024*np.cos(1.47596121866 + 52177.29075585669*t)
	Y0 += 0.00000000020*np.cos(5.35567175214 + 372.4235201282*t)
	Y0 += 0.00000000025*np.cos(3.25287024656 + 130443.39704322898*t)
	Y0 += 0.00000000023*np.cos(4.95211633898 + 561.934294009*t)
	Y0 += 0.00000000020*np.cos(4.03436943213 + 157.6399519819*t)
	Y0 += 0.00000000022*np.cos(5.54888786998 + 24952.226269681*t)
	Y0 += 0.00000000020*np.cos(5.01791562590 + 104819.57755665119*t)
	Y0 += 0.00000000019*np.cos(0.22114816361 + 53029.0026649004*t)
	Y0 += 0.00000000019*np.cos(4.66235459384 + 26248.310510959*t)
	Y0 += 0.00000000019*np.cos(4.14286309096 + 25927.49577218939*t)
	Y0 += 0.00000000018*np.cos(2.61853732084 + 128220.75860368418*t)
	Y0 += 0.00000000020*np.cos(4.36521030279 + 25907.8260112896*t)
	Y0 += 0.00000000020*np.cos(4.44000738201 + 26267.9802718588*t)
	Y0 += 0.00000000018*np.cos(6.19626793608 + 953.1077622329*t)
	Y0 += 0.00000000019*np.cos(3.36352476280 + 52817.21984488739*t)
	Y0 += 0.00000000018*np.cos(0.30828612349 + 26411.4085582316*t)
	Y0 += 0.00000000022*np.cos(3.17973512175 + 103932.12792242158*t)
	Y0 += 0.00000000018*np.cos(5.78685842485 + 75930.51303185058*t)
	Y0 += 0.00000000020*np.cos(5.09591693073 + 12412.372889498*t)
	Y0 += 0.00000000025*np.cos(1.79028039602 + 78313.70604662679*t)
	Y0 += 0.00000000020*np.cos(3.61265389901 + 233731.74634397858*t)
	Y0 += 0.00000000021*np.cos(3.24219932966 + 27223.5800134674*t)
	Y0 += 0.00000000017*np.cos(0.72171071986 + 53867.97195265079*t)
	Y0 += 0.00000000019*np.cos(3.47582025777 + 1098.7388061044*t)
	Y0 += 0.00000000019*np.cos(4.86189338108 + 25863.55834587229*t)
	Y0 += 0.00000000018*np.cos(4.43520040650 + 6.592282139*t)
	Y0 += 0.00000000017*np.cos(0.00246430284 + 44.7253177768*t)
	Y0 += 0.00000000017*np.cos(5.48277957945 + 24602.61243487099*t)
	Y0 += 0.00000000023*np.cos(4.43878616883 + 916.9322800554*t)
	Y0 += 0.00000000017*np.cos(4.51884922337 + 636.7158925763*t)
	Y0 += 0.00000000017*np.cos(1.69909042950 + 184.9879197867*t)
	Y0 += 0.00000000016*np.cos(4.01284635822 + 3.881335358*t)
	Y0 += 0.00000000019*np.cos(4.99623549098 + 7.4223635415*t)
	Y0 += 0.00000000018*np.cos(2.31152779617 + 32.2433289144*t)
	Y0 += 0.00000000017*np.cos(1.25157436898 + 152.7445908723*t)
	Y0 += 0.00000000016*np.cos(1.12213372181 + 79330.20490191258*t)
	Y0 += 0.00000000020*np.cos(1.75617954135 + 696.5196376166*t)
	Y0 += 0.00000000017*np.cos(5.49705406575 + 526.9826521089*t)
	Y0 += 0.00000000018*np.cos(4.58738050642 + 79315.97780791098*t)
	Y0 += 0.00000000016*np.cos(1.56945304094 + 267.4737661858*t)
	Y0 += 0.00000000017*np.cos(3.55351176831 + 600.5404103988*t)
	Y0 += 0.00000000017*np.cos(2.31154641456 + 182.279606801*t)
	Y0 += 0.00000000022*np.cos(1.53237346528 + 6.2197751235*t)
	Y0 += 0.00000000021*np.cos(2.71350199726 + 286.596221297*t)
	Y0 += 0.00000000022*np.cos(1.30917900414 + 76887.93562487679*t)
	Y0 += 0.00000000017*np.cos(5.42837245904 + 537.7677199419*t)
	Y0 += 0.00000000020*np.cos(1.57340365568 + 1166.4068576709*t)
	Y0 += 0.00000000016*np.cos(3.30777698968 + 27573.1938482774*t)
	Y0 += 0.00000000021*np.cos(3.15503951358 + 153084.84390447979*t)
	Y0 += 0.00000000017*np.cos(0.68412522074 + 2744.4340526908*t)
	Y0 += 0.00000000019*np.cos(4.13175891930 + 220.9339073006*t)
	Y0 += 0.00000000017*np.cos(5.50445239257 + 52137.67324751059*t)
	Y0 += 0.00000000018*np.cos(0.43707176640 + 62197.64356324779*t)
	Y0 += 0.00000000019*np.cos(5.65622064409 + 778.4147831847*t)
	Y0 += 0.00000000016*np.cos(5.80893325127 + 2435.155730035*t)
	Y0 += 0.00000000019*np.cos(4.71487615393 + 130866.11389874699*t)
	Y0 += 0.00000000021*np.cos(4.02549892208 + 141.4864422873*t)
	Y0 += 0.00000000016*np.cos(1.06850165415 + 436.8931316145*t)
	Y0 += 0.00000000016*np.cos(0.62904330584 + 319.5732633943*t)
	Y0 += 0.00000000016*np.cos(0.38882783166 + 5.6290742925*t)
	Y0 += 0.00000000016*np.cos(4.53135096192 + 28309.75977617119*t)
	Y0 += 0.00000000019*np.cos(4.97195581426 + 163298.12945069079*t)
	Y0 += 0.00000000017*np.cos(0.26609772175 + 214.9960164674*t)
	Y0 += 0.00000000015*np.cos(6.01544571455 + 50903.1252575212*t)
	Y0 += 0.00000000015*np.cos(1.77611950715 + 1049.0869894507*t)
	Y0 += 0.00000000015*np.cos(0.94947396087 + 155887.52156313117*t)
	Y0 += 0.00000000016*np.cos(5.41922843655 + 2228.9701815978*t)
	Y0 += 0.00000000016*np.cos(1.95850844074 + 103498.41618454478*t)
	Y0 += 0.00000000015*np.cos(1.44946241177 + 627.3671133418*t)
	Y0 += 0.00000000018*np.cos(6.18538776686 + 576.1613880106*t)
	Y0 += 0.00000000016*np.cos(2.01756151519 + 312.1990839626*t)
	Y0 += 0.00000000015*np.cos(3.36560803567 + 61560.64729122359*t)
	Y0 += 0.00000000020*np.cos(2.43269100690 + 505.3119427064*t)
	Y0 += 0.00000000017*np.cos(1.75781825802 + 55638.05098901359*t)
	Y0 += 0.00000000018*np.cos(4.71857780098 + 132028.58860315479*t)
	Y0 += 0.00000000016*np.cos(5.70225976379 + 104358.2411251968*t)
	Y0 += 0.00000000017*np.cos(2.29578624620 + 273.1028404783*t)
	Y0 += 0.00000000018*np.cos(5.32449106801 + 1969.2006632438*t)
	Y0 += 0.00000000019*np.cos(6.09825025640 + 760.25553592*t)
	Y0 += 0.00000000016*np.cos(5.00130427149 + 176332.24614102798*t)
	Y0 += 0.00000000015*np.cos(5.61342452402 + 491.5579294568*t)
	Y0 += 0.00000000017*np.cos(2.00762224529 + 80174.90890793978*t)
	Y0 += 0.00000000016*np.cos(3.55570458351 + 95.3885263868*t)
	Y0 += 0.00000000015*np.cos(1.85651180492 + 52309.9153327334*t)
	Y0 += 0.00000000017*np.cos(3.94668990411 + 0.9632078465*t)
	Y0 += 0.00000000017*np.cos(0.27209841055 + 221.1634019642*t)
	Y0 += 0.00000000015*np.cos(5.85519527755 + 6044.2285813754*t)
	Y0 += 0.00000000015*np.cos(2.00349398121 + 532.3992780803*t)
	Y0 += 0.00000000017*np.cos(4.97483387876 + 416.3032501375*t)
	Y0 += 0.00000000015*np.cos(2.54331959767 + 988.532484885*t)
	Y0 += 0.00000000017*np.cos(1.48305732410 + 102659.44689679438*t)
	Y0 += 0.00000000015*np.cos(3.69020943763 + 731.9443602687*t)
	Y0 += 0.00000000015*np.cos(2.05223117625 + 50689.82616208319*t)
	Y0 += 0.00000000015*np.cos(5.20562567296 + 235900.50682626116*t)
	Y0 += 0.00000000016*np.cos(4.67719181508 + 2.9207613068*t)
	Y0 += 0.00000000014*np.cos(4.13325462242 + 193937.98608932378*t)
	Y0 += 0.00000000018*np.cos(1.00894858228 + 421.93232443*t)
	Y0 += 0.00000000015*np.cos(0.98715474942 + 292.0128472684*t)
	Y0 += 0.00000000014*np.cos(3.48141058348 + 7.065362891*t)
	Y0 += 0.00000000014*np.cos(0.44059222370 + 211.8628068395*t)
	Y0 += 0.00000000014*np.cos(1.30744128930 + 214.7353840365*t)
	Y0 += 0.00000000016*np.cos(5.04374358810 + 73.1852512744*t)
	Y0 += 0.00000000014*np.cos(6.14971506999 + 241.6102710893*t)
	Y0 += 0.00000000015*np.cos(1.04578298609 + 50007.0458008658*t)
	Y0 += 0.00000000015*np.cos(4.77605690111 + 26830.8932021068*t)
	Y0 += 0.00000000015*np.cos(2.86446650235 + 444.7574381407*t)
	Y0 += 0.00000000014*np.cos(5.09441703249 + 133882.09065283638*t)
	Y0 += 0.00000000014*np.cos(0.73264409160 + 50380.54783942739*t)
	Y0 += 0.00000000014*np.cos(2.42647496893 + 2317.8358618148*t)
	Y0 += 0.00000000014*np.cos(0.70147362527 + 1058.8606653274*t)
	Y0 += 0.00000000016*np.cos(5.83322656205 + 81591.84508100279*t)
	Y0 += 0.00000000014*np.cos(5.66142782541 + 282.4516197128*t)
	Y0 += 0.00000000014*np.cos(0.14477892919 + 1070.4276304531*t)
	Y0 += 0.00000000018*np.cos(2.31049190433 + 523.4711899711*t)
	Y0 += 0.00000000014*np.cos(3.08712252242 + 135.5485514541*t)
	Y0 += 0.00000000016*np.cos(2.56012166691 + 104344.98400739678*t)
	Y0 += 0.00000000014*np.cos(0.38043611029 + 26247.2048763664*t)
	Y0 += 0.00000000014*np.cos(2.14159626733 + 25928.601406782*t)
	Y0 += 0.00000000018*np.cos(5.17633752146 + 535.9107402181*t)
	Y0 += 0.00000000014*np.cos(1.96375670227 + 219.6618829134*t)
	Y0 += 0.00000000016*np.cos(4.11900515617 + 418.5214360287*t)
	Y0 += 0.00000000017*np.cos(1.90617951181 + 439.1283638482*t)
	Y0 += 0.00000000013*np.cos(1.61003658474 + 27.0873353739*t)
	Y0 += 0.00000000016*np.cos(2.29540093320 + 50910.238804522*t)
	Y0 += 0.00000000018*np.cos(3.71589155069 + 45.2465826386*t)
	Y0 += 0.00000000014*np.cos(4.21557167873 + 430.79097657*t)
	Y0 += 0.00000000015*np.cos(0.23112413456 + 2655.5683724738*t)
	Y0 += 0.00000000018*np.cos(0.25726617504 + 1151.4290041439*t)
	Y0 += 0.00000000013*np.cos(1.39924383122 + 425.8474313506*t)
	Y0 += 0.00000000016*np.cos(2.14443787663 + 53814.87580033639*t)
	Y0 += 0.00000000014*np.cos(2.88257919019 + 78149.27013603736*t)
	Y0 += 0.00000000016*np.cos(2.81982401926 + 203041.89308344138*t)
	Y0 += 0.00000000014*np.cos(2.43371472113 + 429.5189521828*t)
	Y0 += 0.00000000015*np.cos(4.50854313896 + 77616.69859140778*t)
	Y0 += 0.00000000017*np.cos(4.36239429201 + 347.8844390456*t)
	Y0 += 0.00000000013*np.cos(2.95502641054 + 125112.03959948818*t)
	Y0 += 0.00000000013*np.cos(5.06401541079 + 617.8058857862*t)
	Y0 += 0.00000000013*np.cos(0.04661077494 + 339.2864193365*t)
	Y0 += 0.00000000014*np.cos(2.46383671446 + 35.4247226521*t)
	Y0 += 0.00000000013*np.cos(2.63747376701 + 1585.8915015461*t)
	Y0 += 0.00000000015*np.cos(0.38582816164 + 199.2844497575*t)
	Y0 += 0.00000000014*np.cos(2.82070907634 + 52161.57918914679*t)
	Y0 += 0.00000000016*np.cos(3.65694985324 + 638.4128136057*t)
	Y0 += 0.00000000014*np.cos(6.00616793883 + 192.6921676185*t)
	Y0 += 0.00000000012*np.cos(1.09784520065 + 19202.75325164339*t)
	Y0 += 0.00000000014*np.cos(5.55450230200 + 78378.14871340781*t)
	Y0 += 0.00000000014*np.cos(0.09396317091 + 166.828672522*t)
	Y0 += 0.00000000014*np.cos(1.64692338972 + 26076.8574413103*t)
	Y0 += 0.00000000014*np.cos(0.87510898790 + 26098.9488418381*t)
	Y0 += 0.00000000012*np.cos(0.84912804767 + 45290.65639321759*t)
	Y0 += 0.00000000013*np.cos(5.17736473658 + 498.6714764576*t)
	Y0 += 0.00000000016*np.cos(5.27893423231 + 51534.3927214094*t)
	Y0 += 0.00000000013*np.cos(5.50576363446 + 1592.2542890215*t)
	Y0 += 0.00000000014*np.cos(2.87981573153 + 20043.6745601988*t)
	Y0 += 0.00000000015*np.cos(2.64799753677 + 945.2434557067*t)
	Y0 += 0.00000000012*np.cos(2.17299880235 + 421.1815649046*t)
	Y0 += 0.00000000014*np.cos(4.87931858618 + 36.7604375141*t)
	Y0 += 0.00000000012*np.cos(5.35625751365 + 23439.44831610119*t)
	Y0 += 0.00000000014*np.cos(0.36434746971 + 198489.93958638258*t)
	Y0 += 0.00000000012*np.cos(2.38062047657 + 598.8434893694*t)
	Y0 += 0.00000000013*np.cos(5.25472472921 + 103718.82882698359*t)
	Y0 += 0.00000000014*np.cos(0.37482179977 + 7.1617311106*t)
	Y0 += 0.00000000015*np.cos(5.02501370640 + 2168.7604822826*t)
	Y0 += 0.00000000014*np.cos(0.92860467846 + 1550.939859646*t)
	Y0 += 0.00000000012*np.cos(1.77909600497 + 46.470422916*t)
	Y0 += 0.00000000013*np.cos(5.68468150971 + 32132.1317229496*t)
	Y0 += 0.00000000013*np.cos(5.38865614891 + 35833.2236974308*t)
	Y0 += 0.00000000015*np.cos(1.32940629775 + 205.4347889118*t)
	Y0 += 0.00000000012*np.cos(5.97483232665 + 25984.1209529936*t)
	Y0 += 0.00000000012*np.cos(2.83038535815 + 26191.68533015479*t)
	Y0 += 0.00000000014*np.cos(3.16931627704 + 53265.515074342*t)
	Y0 += 0.00000000012*np.cos(4.77187228430 + 938.1299087059*t)
	Y0 += 0.00000000012*np.cos(4.37902547397 + 181659.72224941078*t)
	Y0 += 0.00000000014*np.cos(2.41044769584 + 53399.624123927*t)
	Y0 += 0.00000000014*np.cos(3.94138074971 + 147.1155165798*t)
	Y0 += 0.00000000014*np.cos(5.69803666962 + 39.5056337615*t)
	Y0 += 0.00000000015*np.cos(0.22782971575 + 1289.9465010146*t)
	Y0 += 0.00000000012*np.cos(4.85232249551 + 53771.99272543299*t)
	Y0 += 0.00000000012*np.cos(0.15450821256 + 43981.5309499398*t)
	Y0 += 0.00000000012*np.cos(3.63916581155 + 24.3790223882*t)
	Y0 += 0.00000000013*np.cos(3.53629828268 + 102755.42612401219*t)
	Y0 += 0.00000000012*np.cos(4.35406626992 + 28199.55345495179*t)
	Y0 += 0.00000000016*np.cos(4.42924935277 + 34082.4315835984*t)
	Y0 += 0.00000000012*np.cos(2.47711415015 + 597.3590166611*t)
	Y0 += 0.00000000012*np.cos(3.02030436898 + 51596.1186961496*t)
	Y0 += 0.00000000013*np.cos(4.97119141190 + 52024.75861330549*t)
	Y0 += 0.00000000013*np.cos(3.53530203976 + 173511.41499690177*t)
	Y0 += 0.00000000011*np.cos(3.07690283750 + 52911.68279668019*t)
	Y0 += 0.00000000011*np.cos(0.32804624048 + 70383.6202713836*t)
	Y0 += 0.00000000015*np.cos(3.18025181635 + 50049.92887576919*t)
	Y0 += 0.00000000015*np.cos(3.22392612987 + 103883.64757594238*t)
	Y0 += 0.00000000012*np.cos(4.38568792647 + 527.9940440652*t)
	Y0 += 0.00000000012*np.cos(3.09659037549 + 531.387886124*t)
	Y0 += 0.00000000012*np.cos(2.33536001070 + 560.7104537316*t)
	Y0 += 0.00000000013*np.cos(3.44611140023 + 208173.53416749898*t)
	Y0 += 0.00000000011*np.cos(0.60906260336 + 48713.5615772832*t)
	Y0 += 0.00000000015*np.cos(6.03373462236 + 1639.069517188*t)
	Y0 += 0.00000000014*np.cos(5.51224524188 + 25241.820306823*t)
	Y0 += 0.00000000014*np.cos(5.72095344070 + 52755.49387014719*t)
	Y0 += 0.00000000011*np.cos(5.60694561960 + 244.318584075*t)
	Y0 += 0.00000000014*np.cos(0.48193051968 + 52041.69723356339*t)
	Y0 += 0.00000000012*np.cos(0.83151252253 + 130363.24963659538*t)
	Y0 += 0.00000000013*np.cos(3.89614170159 + 205.6642835754*t)
	Y0 += 0.00000000011*np.cos(1.80047192955 + 33.1371007917*t)
	Y0 += 0.00000000014*np.cos(1.19670750106 + 1059.903195051*t)
	Y0 += 0.00000000011*np.cos(3.57268529306 + 104276.83096772949*t)
	Y0 += 0.00000000012*np.cos(5.63836365571 + 101703.15774082378*t)
	Y0 += 0.00000000012*np.cos(1.06185654246 + 90989.16285949759*t)
	Y0 += 0.00000000015*np.cos(0.46435508259 + 150.5264049811*t)
	Y0 += 0.00000000011*np.cos(1.25165027664 + 102769.65321801379*t)
	Y0 += 0.00000000013*np.cos(4.66605634483 + 432.2272651685*t)
	Y0 += 0.00000000011*np.cos(1.61020488121 + 57503.2823915312*t)
	Y0 += 0.00000000011*np.cos(3.00609153228 + 2015.6710861598*t)
	Y0 += 0.00000000013*np.cos(5.96769060739 + 52027.72755872209*t)
	Y0 += 0.00000000013*np.cos(1.63784016727 + 78469.89497315978*t)
	Y0 += 0.00000000011*np.cos(5.60057273842 + 210.3301500214*t)
	Y0 += 0.00000000011*np.cos(3.81513615951 + 608.404716925*t)
	Y0 += 0.00000000012*np.cos(0.73222820933 + 120.9913890524*t)
	Y0 += 0.00000000011*np.cos(3.19330091388 + 528.2546764961*t)
	Y0 += 0.00000000011*np.cos(4.28897738808 + 531.1272536931*t)
	Y0 += 0.00000000011*np.cos(5.96339220303 + 20894.5360827764*t)
	Y0 += 0.00000000013*np.cos(2.71291064284 + 27250.37784598199*t)
	Y0 += 0.00000000012*np.cos(5.42728450538 + 51439.92976961659*t)
	Y0 += 0.00000000012*np.cos(2.65321755374 + 52179.73843641149*t)
	Y0 += 0.00000000011*np.cos(6.07804682582 + 206.9363079626*t)
	Y0 += 0.00000000011*np.cos(2.46888718235 + 1148.2476104062*t)
	Y0 += 0.00000000011*np.cos(5.94501754776 + 51.2057253312*t)
	Y0 += 0.00000000010*np.cos(5.23866808164 + 427.3489504014*t)
	Y0 += 0.00000000011*np.cos(1.86995093557 + 150.0844619964*t)
	Y0 += 0.00000000011*np.cos(0.13380048704 + 50536.73676596039*t)
	Y0 += 0.00000000014*np.cos(4.86804065893 + 378.6432952517*t)
	Y0 += 0.00000000012*np.cos(0.94217302733 + 53757.76563143139*t)
	Y0 += 0.00000000010*np.cos(1.22621171910 + 78339.97549599818*t)
	Y0 += 0.00000000011*np.cos(3.31326356407 + 78800.51393681798*t)
	Y0 += 0.00000000013*np.cos(3.59748191688 + 428.0826635843*t)
	Y0 += 0.00000000011*np.cos(1.28291000987 + 209.1544938538*t)
	Y0 += 0.00000000010*np.cos(2.68789421408 + 84944.93427812219*t)
	Y0 += 0.00000000014*np.cos(6.24613692649 + 183145.01295611398*t)
	Y0 += 0.00000000010*np.cos(6.18871346175 + 154408.65498906678*t)
	Y0 += 0.00000000011*np.cos(5.44812833329 + 636.9962720242*t)
	Y0 += 0.00000000010*np.cos(1.98851340448 + 53093.73656913019*t)
	Y0 += 0.00000000010*np.cos(1.36138347225 + 629.6023455755*t)
	Y0 += 0.00000000010*np.cos(0.40978579418 + 125.9873238985*t)
	Y0 += 0.00000000014*np.cos(1.36870962052 + 54344.56676543099*t)
	Y0 += 0.00000000010*np.cos(3.90840385729 + 333.8559407694*t)
	Y0 += 0.00000000010*np.cos(0.94586399547 + 641.41356173899*t)
	Y0 += 0.00000000010*np.cos(5.79679358031 + 415.2918581812*t)
	Y0 += 0.00000000011*np.cos(0.96041649146 + 78057.52387628538*t)
	Y0 += 0.00000000014*np.cos(6.15362111420 + 1173.5204046717*t)
	Y0 += 0.00000000012*np.cos(6.03701341811 + 26149.62911631439*t)
	Y0 += 0.00000000012*np.cos(2.76820426669 + 26026.177166834*t)
	Y0 += 0.00000000011*np.cos(2.43168682439 + 158746.17595363196*t)
	Y0 += 0.00000000013*np.cos(2.40937624104 + 212.4053235607*t)
	Y0 += 0.00000000013*np.cos(5.62184257913 + 214.1928673153*t)
	Y0 += 0.00000000010*np.cos(2.80479558635 + 605.9570363702*t)
	Y0 += 0.00000000011*np.cos(4.83636793377 + 91805.13062721379*t)
	Y0 += 0.00000000010*np.cos(2.61011872081 + 6751.0408403458*t)
	Y0 += 0.00000000010*np.cos(2.56668543311 + 1891.2376709388*t)
	Y0 += 0.00000000010*np.cos(0.79218036562 + 91919.56991589899*t)
	Y0 += 0.00000000010*np.cos(6.22635612142 + 867.4234757536*t)
	Y0 += 0.00000000014*np.cos(1.69865910615 + 53124.98189211819*t)
	Y0 += 0.00000000013*np.cos(5.94179661012 + 1041.2226829245*t)
	Y0 += 0.00000000010*np.cos(0.45068933139 + 217.4436970222*t)
	Y0 += 0.00000000010*np.cos(1.99206585078 + 77940.20400806518*t)
	Y0 += 0.00000000013*np.cos(4.08389676067 + 50270.341518208*t)
	Y0 += 0.00000000011*np.cos(3.68044220158 + 77520.71936418998*t)
	Y0 += 0.00000000010*np.cos(3.15383743619 + 181.806526049*t)
	Y0 += 0.00000000011*np.cos(3.70781443358 + 39763.43339365039*t)
	Y0 += 0.00000000010*np.cos(5.75274329860 + 114.43928868521*t)
	Y0 += 0.00000000010*np.cos(4.07002674149 + 405.2575498736*t)
	Y0 += 0.00000000009*np.cos(1.01216637956 + 130593.29451835579*t)
	Y0 += 0.00000000009*np.cos(0.36490625518 + 26513.8119180882*t)
	Y0 += 0.00000000009*np.cos(2.15712612244 + 25661.9943650602*t)
	Y0 += 0.00000000013*np.cos(3.18899327846 + 26161.20026743319*t)
	Y0 += 0.00000000013*np.cos(5.61622440634 + 26014.60601571519*t)
	Y0 += 0.00000000010*np.cos(0.86888264917 + 104991.50985261079*t)
	Y0 += 0.00000000010*np.cos(5.95581190338 + 52061.40717623499*t)
	Y0 += 0.00000000010*np.cos(4.42035362502 + 4371.8763667742*t)
	Y0 += 0.00000000011*np.cos(4.00644107438 + 183674.70392120858*t)
	Y0 += 0.00000000010*np.cos(3.59637305781 + 23384.2869868986*t)
	Y0 += 0.00000000012*np.cos(5.84786866785 + 381.6122406683*t)
	Y0 += 0.00000000009*np.cos(2.09284564023 + 1159.2933106701*t)
	Y0 += 0.00000000010*np.cos(2.22671529337 + 333.657345044*t)
	Y0 += 0.00000000010*np.cos(2.31187236025 + 546.956440482*t)
	Y0 += 0.00000000012*np.cos(1.90077351195 + 52396.2189255872*t)
	Y0 += 0.00000000009*np.cos(2.39902771912 + 103189.13786188899*t)
	Y0 += 0.00000000013*np.cos(4.08385124235 + 76041.85279012559*t)
	Y0 += 0.00000000010*np.cos(5.25684077542 + 431.264057322*t)
	Y0 += 0.00000000009*np.cos(4.93035759424 + 156547.08861034496*t)
	Y0 += 0.00000000009*np.cos(5.19425764887 + 28791.5192962498*t)
	Y0 += 0.00000000012*np.cos(1.61460398653 + 738.7972748386*t)
	Y0 += 0.00000000010*np.cos(5.40123990345 + 460.5384408198*t)
	Y0 += 0.00000000009*np.cos(0.77711516175 + 130285.73689738619*t)
	Y0 += 0.00000000009*np.cos(6.13900158212 + 25131.61398560359*t)
	Y0 += 0.00000000011*np.cos(5.98671337291 + 4022.2625319642*t)
	Y0 += 0.00000000011*np.cos(1.81020647842 + 19367.1891622328*t)
	Y0 += 0.00000000009*np.cos(2.04038725108 + 104984.39630560997*t)
	Y0 += 0.00000000009*np.cos(5.45614765496 + 76255.15188556358*t)
	Y0 += 0.00000000010*np.cos(0.14404716850 + 155.7829722581*t)
	Y0 += 0.00000000012*np.cos(3.14924236088 + 450.9772132642*t)
	Y0 += 0.00000000009*np.cos(2.84521042237 + 31281.270200372*t)
	Y0 += 0.00000000009*np.cos(4.03213133235 + 528.4671248172*t)
	Y0 += 0.00000000009*np.cos(0.84632922145 + 51130.65144696079*t)
	Y0 += 0.00000000010*np.cos(4.24458785082 + 19958.6061020676*t)
	Y0 += 0.00000000011*np.cos(2.88621334050 + 28.3111756513*t)
	Y0 += 0.00000000009*np.cos(0.39890242427 + 52797.55008398759*t)
	Y0 += 0.00000000009*np.cos(4.19555404950 + 1165.6560981455*t)
	Y0 += 0.00000000009*np.cos(5.81793329193 + 27360.58416720139*t)
	Y0 += 0.00000000009*np.cos(3.81505771377 + 24844.41553989579*t)
	Y0 += 0.00000000009*np.cos(4.99015997103 + 27331.3907432526*t)
	Y0 += 0.00000000010*np.cos(5.97140853581 + 230239.17477710896*t)
	Y0 += 0.00000000009*np.cos(2.46893459204 + 156314.11975400719*t)
	Y0 += 0.00000000008*np.cos(3.46097740255 + 530.914805372*t)
	Y0 += 0.00000000009*np.cos(0.04637931204 + 69.6737891366*t)
	Y0 += 0.00000000009*np.cos(5.40753282752 + 754.0357607965*t)
	Y0 += 0.00000000012*np.cos(1.38537383177 + 721.6494195302*t)
	Y0 += 0.00000000009*np.cos(4.19100388815 + 0.5212648618*t)
	Y0 += 0.00000000012*np.cos(3.43831701560 + 134.5853436076*t)
	Y0 += 0.00000000009*np.cos(4.72240285304 + 465.9550667912*t)
	Y0 += 0.00000000009*np.cos(3.70709245487 + 280.9671470045*t)
	Y0 += 0.00000000008*np.cos(1.08719749627 + 38634.3850806572*t)
	Y0 += 0.00000000008*np.cos(1.46946168036 + 131.5469622218*t)
	Y0 += 0.00000000011*np.cos(4.12126538369 + 46046.5092436418*t)
	Y0 += 0.00000000008*np.cos(1.73516019806 + 1056.4611688824*t)
	Y0 += 0.00000000009*np.cos(5.45527892151 + 52190.03337714999*t)
	Y0 += 0.00000000010*np.cos(0.06865542606 + 448.6895914038*t)
	Y0 += 0.00000000008*np.cos(1.72917243692 + 192.8522263129*t)
	Y0 += 0.00000000008*np.cos(4.46770744193 + 361.3778198643*t)
	Y0 += 0.00000000008*np.cos(3.26923868189 + 405.9912630565*t)
	Y0 += 0.00000000011*np.cos(0.11612223196 + 1020.025054274*t)
	Y0 += 0.00000000010*np.cos(1.53707512245 + 391318.54712361297*t)
	Y0 += 0.00000000008*np.cos(4.92087563189 + 313.2104759189*t)
	Y0 += 0.00000000008*np.cos(3.81834546623 + 26933.9859763254*t)
	Y0 += 0.00000000010*np.cos(5.47822459894 + 54060.70744656579*t)
	Y0 += 0.00000000010*np.cos(4.32768014997 + 189.1807054807*t)
	Y0 += 0.00000000008*np.cos(4.67907344342 + 79.889407998*t)
	Y0 += 0.00000000008*np.cos(5.04946311938 + 464.7312265138*t)
	Y0 += 0.00000000009*np.cos(1.71810953684 + 36.5366883449*t)
	Y0 += 0.00000000009*np.cos(0.39954966213 + 65717.22748563958*t)
	Y0 += 0.00000000009*np.cos(2.05541857581 + 2854.6403739102*t)
	Y0 += 0.00000000008*np.cos(5.66324066149 + 53132.09543911899*t)
	Y0 += 0.00000000009*np.cos(2.26575649117 + 22595.33157470459*t)
	Y0 += 0.00000000008*np.cos(4.84240352586 + 244.791664827*t)
	Y0 += 0.00000000010*np.cos(4.41832107849 + 381.3516082374*t)
	Y0 += 0.00000000009*np.cos(4.01881898285 + 1485.2907067032*t)
	Y0 += 0.00000000008*np.cos(0.89598602983 + 10681.2505365654*t)
	Y0 += 0.00000000009*np.cos(5.61147436738 + 52171.87412988529*t)
	Y0 += 0.00000000010*np.cos(2.20742015711 + 530.5847369719*t)
	Y0 += 0.00000000010*np.cos(5.27485814485 + 528.7971932173*t)
	Y0 += 0.00000000008*np.cos(5.37389235751 + 51876.67988887919*t)
	Y0 += 0.00000000010*np.cos(2.64362358554 + 49.9966219042*t)
	Y0 += 0.00000000011*np.cos(3.21752719962 + 28096.46068073319*t)
	Y0 += 0.00000000010*np.cos(0.03803981577 + 118828.96374949679*t)
	Y0 += 0.00000000008*np.cos(5.45338504662 + 77956.15180375299*t)
	Y0 += 0.00000000008*np.cos(0.89135797231 + 52400.1510788503*t)
	Y0 += 0.00000000008*np.cos(5.39721379669 + 1058.6311706638*t)
	Y0 += 0.00000000008*np.cos(2.89181901651 + 54824.2611086214*t)
	Y0 += 0.00000000009*np.cos(2.73227763941 + 29.2049475286*t)
	Y0 += 0.00000000010*np.cos(1.50538632513 + 240452.46032331996*t)
	Y0 += 0.00000000008*np.cos(4.63518203907 + 411.620337349*t)
	Y0 += 0.00000000008*np.cos(5.27009439447 + 77741.13200662879*t)
	Y0 += 0.00000000008*np.cos(5.13763418673 + 42790.9652750732*t)
	Y0 += 0.00000000009*np.cos(2.19295323979 + 103.3534066495*t)
	Y0 += 0.00000000008*np.cos(5.18381379645 + 462.0229135281*t)
	Y0 += 0.00000000008*np.cos(2.79749742555 + 422.405405182*t)
	Y0 += 0.00000000008*np.cos(3.13545736715 + 52489.992463018*t)
	Y0 += 0.00000000008*np.cos(2.29664532419 + 156520.30530244438*t)
	Y0 += 0.00000000008*np.cos(0.58781443842 + 17098.43543614181*t)
	Y0 += 0.00000000007*np.cos(4.49316157626 + 52206.1331441528*t)
	Y0 += 0.00000000008*np.cos(3.32979544985 + 533.8355666788*t)
	Y0 += 0.00000000009*np.cos(2.69655297859 + 39.7293829307*t)
	Y0 += 0.00000000007*np.cos(3.15085715061 + 50290.905119731*t)
	Y0 += 0.00000000010*np.cos(2.92673152753 + 22065.64060961*t)
	Y0 += 0.00000000007*np.cos(3.32680253166 + 521.8266585684*t)
	Y0 += 0.00000000008*np.cos(1.07948674297 + 51112.49219969609*t)
	Y0 += 0.00000000009*np.cos(0.57156355893 + 104454.70534051539*t)
	Y0 += 0.00000000009*np.cos(1.06248243670 + 395.578702239*t)
	Y0 += 0.00000000008*np.cos(2.09479344301 + 35077.37084700659*t)
	Y0 += 0.00000000009*np.cos(4.89300038136 + 710.7467316182*t)
	Y0 += 0.00000000008*np.cos(4.18600288174 + 525.5463635104*t)
	Y0 += 0.00000000010*np.cos(1.91529997720 + 259.769518354*t)
	Y0 += 0.00000000007*np.cos(4.15570065598 + 537.5552716208*t)
	Y0 += 0.00000000008*np.cos(4.70706722263 + 120417.67842777158*t)
	Y0 += 0.00000000007*np.cos(0.01886158971 + 233.7459645631*t)
	Y0 += 0.00000000008*np.cos(4.83062968915 + 187167.27548807819*t)
	Y0 += 0.00000000009*np.cos(2.82365374916 + 156507.74908854539*t)
	Y0 += 0.00000000009*np.cos(3.91753991774 + 218.4069048687*t)
	Y0 += 0.00000000008*np.cos(0.15958851658 + 1062.302691496*t)
	Y0 += 0.00000000009*np.cos(3.13387610584 + 556.5176680376*t)
	Y0 += 0.00000000007*np.cos(1.95813917019 + 1064.7985561606*t)
	Y0 += 0.00000000007*np.cos(5.45465770137 + 51086.09749195479*t)
	Y0 += 0.00000000008*np.cos(3.96538887746 + 149288.74325784518*t)
	Y0 += 0.00000000008*np.cos(3.32202684341 + 112231.70171963578*t)
	Y0 += 0.00000000009*np.cos(4.41737021309 + 76152.05911134499*t)
	Y0 += 0.00000000007*np.cos(1.93378768698 + 1063.5747158832*t)
	Y0 += 0.00000000007*np.cos(2.13361844991 + 233681.74972207438*t)
	Y0 += 0.00000000007*np.cos(0.76923088178 + 104248.51979207818*t)
	Y0 += 0.00000000008*np.cos(3.46520766649 + 77314.53381575279*t)
	Y0 += 0.00000000007*np.cos(0.02649996061 + 29396.3690369546*t)
	Y0 += 0.00000000007*np.cos(2.49553241701 + 22779.4372461938*t)
	Y0 += 0.00000000007*np.cos(3.27297531111 + 412.5835451955*t)
	Y0 += 0.00000000007*np.cos(4.38534662923 + 26290.15653674829*t)
	Y0 += 0.00000000007*np.cos(4.41987105557 + 25885.64974640009*t)
	Y0 += 0.00000000009*np.cos(1.25976113938 + 2957.7331481288*t)
	Y0 += 0.00000000009*np.cos(2.68780752055 + 148.5999892881*t)
	Y0 += 0.00000000008*np.cos(2.78415263682 + 1060.1326897146*t)
	Y0 += 0.00000000007*np.cos(2.61068773535 + 216.2680408546*t)
	Y0 += 0.00000000010*np.cos(4.95742849118 + 456.3938392356*t)
	Y0 += 0.00000000009*np.cos(5.00120036070 + 2703.6161546756*t)
	Y0 += 0.00000000008*np.cos(3.05834752866 + 329.7251917809*t)
	Y0 += 0.00000000007*np.cos(1.46712503162 + 156740.71794488319*t)
	Y0 += 0.00000000007*np.cos(1.74393304100 + 420.4478517217*t)
	Y0 += 0.00000000007*np.cos(3.06771631981 + 19.1224551112*t)
	Y0 += 0.00000000008*np.cos(2.98540358627 + 78571.26704569219*t)
	Y0 += 0.00000000008*np.cos(3.46227249114 + 2014.9816717978*t)
	Y0 += 0.00000000009*np.cos(3.60323244194 + 24395.7374720718*t)
	Y0 += 0.00000000007*np.cos(1.57299130322 + 52663.44103440259*t)
	Y0 += 0.00000000008*np.cos(3.34291932325 + 102872.74599223239*t)
	Y0 += 0.00000000009*np.cos(4.15307297121 + 24505.94379329119*t)
	Y0 += 0.00000000007*np.cos(5.14819246138 + 52073.84376488279*t)
	Y0 += 0.00000000007*np.cos(2.10644528980 + 149846.19399604558*t)
	Y0 += 0.00000000008*np.cos(0.32773950650 + 214.9436268407*t)
	Y0 += 0.00000000008*np.cos(1.42029400650 + 211.6545640353*t)
	Y0 += 0.00000000008*np.cos(1.46996458441 + 149.0419322728*t)
	Y0 += 0.00000000008*np.cos(3.84046364591 + 116.4260963429*t)
	Y0 += 0.00000000007*np.cos(2.73815653722 + 77417.62658997139*t)
	Y0 += 0.00000000007*np.cos(3.99043202484 + 1135.6768718932*t)
	Y0 += 0.00000000007*np.cos(5.43372978042 + 229.9738699944*t)
	Y0 += 0.00000000009*np.cos(4.16665868672 + 1201.831580323*t)
	Y0 += 0.00000000009*np.cos(5.86657971342 + 56259.79478985279*t)
	Y0 += 0.00000000007*np.cos(1.97658084158 + 212.4959462859*t)
	Y0 += 0.00000000007*np.cos(6.05463797860 + 214.1022445901*t)
	Y0 += 0.00000000008*np.cos(0.85401055465 + 73.88782669*t)
	Y0 += 0.00000000008*np.cos(3.82539188135 + 75.6753704446*t)
	Y0 += 0.00000000008*np.cos(0.16231496773 + 207114.15223730978*t)
	Y0 += 0.00000000008*np.cos(0.71218709319 + 32808.6171209156*t)
	Y0 += 0.00000000008*np.cos(2.15142736957 + 49.1787359017*t)
	return Y0




def Mercury_Y1 (t): # 946 terms of order 1

	Y1 = 0.
	Y1 += 0.00107803834*np.cos(4.34964793883 + 52175.8062831484*t)
	Y1 -= 0.00080645427
	Y1 += 0.00032715349*np.cos(1.11763734425 + 78263.70942472259*t)
	Y1 += 0.00008858156*np.cos(4.16852401867 + 104351.61256629678*t)
	Y1 += 0.00011914707*np.cos(1.22139986340 + 26087.9031415742*t)
	Y1 += 0.00002344469*np.cos(0.93615372641 + 130439.51570787099*t)
	Y1 += 0.00000899581*np.cos(5.84186105603 + 426.598190876*t)
	Y1 += 0.00000781374*np.cos(1.12961379685 + 206.1855484372*t)
	Y1 += 0.00000754896*np.cos(0.61971063691 + 220.4126424388*t)
	Y1 += 0.00000617838*np.cos(3.98693992284 + 156527.41884944518*t)
	Y1 += 0.00000602337*np.cos(1.65727937950 + 1059.3819301892*t)
	Y1 += 0.00000573209*np.cos(4.00090226715 + 522.5774180938*t)
	Y1 += 0.00000561260*np.cos(3.48683327339 + 536.8045120954*t)
	Y1 += 0.00000162955*np.cos(0.75452718043 + 182615.32199101939*t)
	Y1 += 0.00000102544*np.cos(1.87754373592 + 7.1135470008*t)
	Y1 += 0.00000073556*np.cos(5.08183519453 + 639.897286314*t)
	Y1 += 0.00000070135*np.cos(1.35447664024 + 24978.5245894808*t)
	Y1 += 0.00000087475*np.cos(0.09179540875 + 419.4846438752*t)
	Y1 += 0.00000063991*np.cos(1.18000294070 + 27197.2816936676*t)
	Y1 += 0.00000053968*np.cos(6.04113158324 + 433.7117378768*t)
	Y1 += 0.00000047430*np.cos(2.15360371550 + 213.299095438*t)
	Y1 += 0.00000045623*np.cos(5.05685537615 + 529.6909650946*t)
	Y1 += 0.00000045570*np.cos(1.94681756713 + 1589.0728952838*t)
	Y1 += 0.00000031681*np.cos(3.31608856533 + 1052.2683831884*t)
	Y1 += 0.00000043082*np.cos(3.80528844384 + 208703.22513259358*t)
	Y1 += 0.00000030502*np.cos(3.88955460744 + 1066.49547719*t)
	Y1 += 0.00000032033*np.cos(1.27787218108 + 149.5631971346*t)
	Y1 += 0.00000021415*np.cos(5.30131509744 + 316.3918696566*t)
	Y1 += 0.00000019019*np.cos(0.48946385175 + 227.5261894396*t)
	Y1 += 0.00000017706*np.cos(4.40634127417 + 51066.427731055*t)
	Y1 += 0.00000016126*np.cos(2.45017960628 + 110.2063212194*t)
	Y1 += 0.00000013279*np.cos(4.22577566721 + 53285.1848352418*t)
	Y1 += 0.00000015892*np.cos(4.20644835200 + 76.2660712756*t)
	Y1 += 0.00000012413*np.cos(4.14057132118 + 515.463871093*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000011682*np.cos(1.76404497924 + 1109.3785520934*t)
	Y1 += 0.00000011796*np.cos(1.50171409080 + 632.7837393132*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000011615*np.cos(5.06524241164 + 20426.571092422*t)
	Y1 += 0.00000011421*np.cos(0.57284937520 + 234791.12827416777*t)
	Y1 += 0.00000010164*np.cos(0.62992310390 + 73.297125859*t)
	Y1 += 0.00000009222*np.cos(1.25927718333 + 199.0720014364*t)
	Y1 += 0.00000008663*np.cos(3.35360012494 + 543.9180590962*t)
	Y1 += 0.00000007754*np.cos(1.44809853148 + 949.1756089698*t)
	Y1 += 0.00000007691*np.cos(1.12086563927 + 103.0927742186*t)
	Y1 += 0.00000008018*np.cos(3.73528031615 + 31749.2351907264*t)
	Y1 += 0.00000005645*np.cos(4.44389731414 + 853.196381752*t)
	Y1 += 0.00000006099*np.cos(3.87856029780 + 4551.9534970588*t)
	Y1 += 0.00000005170*np.cos(0.37516758388 + 209.3669421749*t)
	Y1 += 0.00000005081*np.cos(1.39059455730 + 217.2312487011*t)
	Y1 += 0.00000004738*np.cos(4.97800929323 + 21535.9496445154*t)
	Y1 += 0.00000004660*np.cos(0.15626149972 + 216.4804891757*t)
	Y1 += 0.00000004553*np.cos(1.60431626596 + 210.1177017003*t)
	Y1 += 0.00000004434*np.cos(5.48127294730 + 323.5054166574*t)
	Y1 += 0.00000004881*np.cos(1.17454074876 + 77154.33087262919*t)
	Y1 += 0.00000004307*np.cos(1.83017640372 + 46514.4742339962*t)
	Y1 += 0.00000004146*np.cos(5.23355330351 + 647.0108333148*t)
	Y1 += 0.00000004151*np.cos(1.93098926861 + 63.7358983034*t)
	Y1 += 0.00000004460*np.cos(3.53571937802 + 25132.3033999656*t)
	Y1 += 0.00000005058*np.cos(1.73136117173 + 14.2270940016*t)
	Y1 += 0.00000004293*np.cos(2.71452907477 + 735.8765135318*t)
	Y1 += 0.00000004037*np.cos(2.84879735121 + 27147.28507176339*t)
	Y1 += 0.00000003784*np.cos(2.61021114752 + 14765.2390432698*t)
	Y1 += 0.00000003952*np.cos(5.27139824600 + 27043.5028831828*t)
	Y1 += 0.00000004218*np.cos(2.70289062748 + 51116.4243529592*t)
	Y1 += 0.00000003443*np.cos(2.77873462243 + 85.8272988312*t)
	Y1 += 0.00000003299*np.cos(5.80945771947 + 26617.5941066688*t)
	Y1 += 0.00000003302*np.cos(0.78944659795 + 11.0457002639*t)
	Y1 += 0.00000003246*np.cos(4.47251198694 + 526.5095713569*t)
	Y1 += 0.00000003180*np.cos(3.00772018402 + 532.8723588323*t)
	Y1 += 0.00000003022*np.cos(3.11389766991 + 25558.2121764796*t)
	Y1 += 0.00000002903*np.cos(3.22514351914 + 525.7588118315*t)
	Y1 += 0.00000002896*np.cos(1.12069020939 + 117.3198682202*t)
	Y1 += 0.00000003036*np.cos(3.62362220555 + 260879.03141574195*t)
	Y1 += 0.00000002863*np.cos(4.25448918131 + 533.6231183577*t)
	Y1 += 0.00000002928*np.cos(4.94900975921 + 26068.2333806744*t)
	Y1 += 0.00000002838*np.cos(0.45959307618 + 202.2533951741*t)
	Y1 += 0.00000002916*np.cos(3.86813577657 + 26107.57290247399*t)
	Y1 += 0.00000003214*np.cos(2.23836425545 + 2118.7638603784*t)
	Y1 += 0.00000002863*np.cos(2.16989496338 + 95.9792272178*t)
	Y1 += 0.00000002398*np.cos(2.02069419116 + 26091.7844769322*t)
	Y1 += 0.00000002392*np.cos(0.51342544634 + 26084.0218062162*t)
	Y1 += 0.00000002070*np.cos(3.88639207621 + 30639.856638633*t)
	Y1 += 0.00000002070*np.cos(6.19899610943 + 37410.5672398786*t)
	Y1 += 0.00000002044*np.cos(3.86812530423 + 138.5174968707*t)
	Y1 += 0.00000001977*np.cos(2.19636388255 + 742.9900605326*t)
	Y1 += 0.00000001993*np.cos(0.93804934862 + 79373.08797681599*t)
	Y1 += 0.00000001852*np.cos(4.27634730838 + 1596.1864422846*t)
	Y1 += 0.00000001900*np.cos(0.38313133060 + 956.2891559706*t)
	Y1 += 0.00000001699*np.cos(1.87566644469 + 70.8494453042*t)
	Y1 += 0.00000001864*np.cos(4.94267930925 + 47623.8527860896*t)
	Y1 += 0.00000001583*np.cos(0.12078429237 + 9103.9069941176*t)
	Y1 += 0.00000001574*np.cos(5.88839166356 + 955.5997416086*t)
	Y1 += 0.00000001570*np.cos(2.80724611689 + 78.7137518304*t)
	Y1 += 0.00000001493*np.cos(5.97213767442 + 440.8252848776*t)
	Y1 += 0.00000001889*np.cos(3.40831424577 + 1581.959348283*t)
	Y1 += 0.00000001517*np.cos(5.15214768135 + 19317.1925403286*t)
	Y1 += 0.00000001406*np.cos(4.88025959589 + 72602.37737557039*t)
	Y1 += 0.00000001467*np.cos(1.19005978960 + 74.7815985673*t)
	Y1 += 0.00000001559*np.cos(2.97028792257 + 1045.1548361876*t)
	Y1 += 0.00000001612*np.cos(2.13607398502 + 12566.1516999828*t)
	Y1 += 0.00000001366*np.cos(1.71840454751 + 50586.73338786459*t)
	Y1 += 0.00000001634*np.cos(2.40372122588 + 224.3447957019*t)
	Y1 += 0.00000001228*np.cos(2.36966134706 + 52705.49724824299*t)
	Y1 += 0.00000001329*np.cos(0.91947275142 + 26095.016688575*t)
	Y1 += 0.00000001297*np.cos(1.64793153920 + 26080.78959457339*t)
	Y1 += 0.00000001485*np.cos(1.42812285205 + 23869.1460373874*t)
	Y1 += 0.00000001109*np.cos(5.93496425650 + 53235.18821333759*t)
	Y1 += 0.00000001170*np.cos(3.92015942653 + 3442.5749449654*t)
	Y1 += 0.00000001084*np.cos(3.70940677149 + 32858.61374281979*t)
	Y1 += 0.00000001288*np.cos(1.12226805319 + 28306.66024576099*t)
	Y1 += 0.00000001252*np.cos(0.25878403718 + 51220.20654153979*t)
	Y1 += 0.00000001381*np.cos(4.22593487926 + 103242.23401420339*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001057*np.cos(0.79522639484 + 309.2783226558*t)
	Y1 += 0.00000001112*np.cos(2.89652371372 + 625.6701923124*t)
	Y1 += 0.00000000997*np.cos(4.09313565437 + 1265.5674786264*t)
	Y1 += 0.00000000964*np.cos(2.00174932268 + 53131.406024757*t)
	Y1 += 0.00000001106*np.cos(4.94616537059 + 22645.32819660879*t)
	Y1 += 0.00000000864*np.cos(5.66060639309 + 40853.142184844*t)
	Y1 += 0.00000000858*np.cos(3.76385932364 + 27676.976036858*t)
	Y1 += 0.00000000989*np.cos(6.14826697847 + 412.3710968744*t)
	Y1 += 0.00000000858*np.cos(5.73806224669 + 25874.6040461362*t)
	Y1 += 0.00000000824*np.cos(3.08049270116 + 26301.2022370122*t)
	Y1 += 0.00000000883*np.cos(0.45084463736 + 11322.6640983044*t)
	Y1 += 0.00000000809*np.cos(0.39136440746 + 286966.93455731616*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000000936*np.cos(2.99521995909 + 1169.5882514086*t)
	Y1 += 0.00000000890*np.cos(0.56532726320 + 83925.04147387479*t)
	Y1 += 0.00000000943*np.cos(0.21048093986 + 151.0476698429*t)
	Y1 += 0.00000000771*np.cos(1.58200018736 + 942.062061969*t)
	Y1 += 0.00000000838*np.cos(3.20685394363 + 36301.18868778519*t)
	Y1 += 0.00000000745*np.cos(0.63676880132 + 56727.7597802072*t)
	Y1 += 0.00000000726*np.cos(4.24035820533 + 6770.7106012456*t)
	Y1 += 0.00000000732*np.cos(6.22212904751 + 18849.2275499742*t)
	Y1 += 0.00000000715*np.cos(2.44570090401 + 43071.8992890308*t)
	Y1 += 0.00000000762*np.cos(3.43418344370 + 1155.361157407*t)
	Y1 += 0.00000000668*np.cos(1.71704627521 + 52156.1365222486*t)
	Y1 += 0.00000000712*np.cos(1.82235727085 + 71.8126531507*t)
	Y1 += 0.00000000733*np.cos(0.31521674193 + 39609.6545831656*t)
	Y1 += 0.00000000702*np.cos(5.58423906419 + 15874.6175953632*t)
	Y1 += 0.00000000718*np.cos(2.94974266304 + 77.7505439839*t)
	Y1 += 0.00000000576*np.cos(0.68273915307 + 5661.3320491522*t)
	Y1 += 0.00000000729*np.cos(1.68793748931 + 1162.4747044078*t)
	Y1 += 0.00000000598*np.cos(5.40710232495 + 51646.11531805379*t)
	Y1 += 0.00000000540*np.cos(2.73251678283 + 16983.9961474566*t)
	Y1 += 0.00000000538*np.cos(5.07690787025 + 52179.6876185064*t)
	Y1 += 0.00000000619*np.cos(6.13858968874 + 25028.521211385*t)
	Y1 += 0.00000000665*np.cos(3.93109197005 + 29530.4780865396*t)
	Y1 += 0.00000000504*np.cos(2.36012441072 + 277.0349937414*t)
	Y1 += 0.00000000506*np.cos(5.24159135308 + 38654.05484155699*t)
	Y1 += 0.00000000530*np.cos(3.36422519322 + 26514.5013324502*t)
	Y1 += 0.00000000486*np.cos(5.53252452947 + 422.6660376129*t)
	Y1 += 0.00000000473*np.cos(3.59055175449 + 110012.94461544899*t)
	Y1 += 0.00000000487*np.cos(2.93506686309 + 63498.47038145279*t)
	Y1 += 0.00000000522*np.cos(0.62912353695 + 52195.47604404819*t)
	Y1 += 0.00000000454*np.cos(1.16197279913 + 1692.1656695024*t)
	Y1 += 0.00000000441*np.cos(1.64790874543 + 98690.28051714458*t)
	Y1 += 0.00000000534*np.cos(1.70054963408 + 2218.7571041868*t)
	Y1 += 0.00000000435*np.cos(2.54548425009 + 33326.5787331742*t)
	Y1 += 0.00000000476*np.cos(2.07918702570 + 51749.20809227239*t)
	Y1 += 0.00000000435*np.cos(3.56264869714 + 52171.9249477904*t)
	Y1 += 0.00000000401*np.cos(3.23464522849 + 7238.67559160*t)
	Y1 += 0.00000000391*np.cos(3.73837604066 + 1073.6090241908*t)
	Y1 += 0.00000000392*np.cos(5.33365190740 + 78793.40038981718*t)
	Y1 += 0.00000000407*np.cos(4.44476287637 + 52168.69273614759*t)
	Y1 += 0.00000000375*np.cos(0.35041804232 + 234.6397364404*t)
	Y1 += 0.00000000368*np.cos(5.89753379700 + 846.0828347512*t)
	Y1 += 0.00000000373*np.cos(3.98254461376 + 415.5524906121*t)
	Y1 += 0.00000000362*np.cos(0.42873204406 + 58946.51688439399*t)
	Y1 += 0.00000000384*np.cos(5.64976516740 + 330.6189636582*t)
	Y1 += 0.00000000359*np.cos(6.23300670520 + 62389.09182935939*t)
	Y1 += 0.00000000343*np.cos(4.48711302652 + 860.3099287528*t)
	Y1 += 0.00000000379*np.cos(5.70187484299 + 103292.23063610759*t)
	Y1 += 0.00000000337*np.cos(3.18444650009 + 71.6002048296*t)
	Y1 += 0.00000000327*np.cos(2.73153219856 + 79323.09135491178*t)
	Y1 += 0.00000000394*np.cos(0.99378340812 + 129330.13715577759*t)
	Y1 += 0.00000000324*np.cos(0.71684229879 + 423.4167971383*t)
	Y1 += 0.00000000433*np.cos(1.36147512776 + 3.9321532631*t)
	Y1 += 0.00000000387*np.cos(3.94846766008 + 52182.9198301492*t)
	Y1 += 0.00000000326*np.cos(1.48465704932 + 77.962992305*t)
	Y1 += 0.00000000398*np.cos(1.46527983526 + 1478.8665740644*t)
	Y1 += 0.00000000315*np.cos(4.54497673319 + 76674.63652943878*t)
	Y1 += 0.00000000316*np.cos(5.62533566974 + 429.7795846137*t)
	Y1 += 0.00000000304*np.cos(3.98761648250 + 145.6310438715*t)
	Y1 += 0.00000000324*np.cos(4.48254226320 + 49957.0491789616*t)
	Y1 += 0.00000000352*np.cos(0.64575728139 + 2.9689454166*t)
	Y1 += 0.00000000334*np.cos(2.48260797685 + 68050.42387851159*t)
	Y1 += 0.00000000298*np.cos(4.99631840995 + 48733.23133818299*t)
	Y1 += 0.00000000379*np.cos(4.15724883772 + 54394.56338733519*t)
	Y1 += 0.00000000384*np.cos(4.55881127062 + 210.8514148832*t)
	Y1 += 0.00000000380*np.cos(3.47993786173 + 215.7467759928*t)
	Y1 += 0.00000000315*np.cos(3.35778860471 + 51535.90899683439*t)
	Y1 += 0.00000000360*np.cos(2.88459167183 + 728.762966531*t)
	Y1 += 0.00000000369*np.cos(3.28585153276 + 77308.10968311399*t)
	Y1 += 0.00000000317*np.cos(1.92463402354 + 45405.0956819028*t)
	Y1 += 0.00000000321*np.cos(2.67304207488 + 13655.8604911764*t)
	Y1 += 0.00000000338*np.cos(4.31589716519 + 148.0787244263*t)
	Y1 += 0.00000000255*np.cos(0.68716361250 + 437.6438911399*t)
	Y1 += 0.00000000284*np.cos(3.67849455855 + 838.9692877504*t)
	Y1 += 0.00000000263*np.cos(6.20975408266 + 52389.1053785864*t)
	Y1 += 0.00000000235*np.cos(5.56250286661 + 51123.53789995999*t)
	Y1 += 0.00000000234*np.cos(0.03317726903 + 223.5940361765*t)
	Y1 += 0.00000000232*np.cos(3.67747292832 + 82815.66292178139*t)
	Y1 += 0.00000000222*np.cos(4.29914928209 + 508.3503240922*t)
	Y1 += 0.00000000223*np.cos(2.42466836013 + 66941.04532641819*t)
	Y1 += 0.00000000216*np.cos(3.44223471965 + 313054.83769889036*t)
	Y1 += 0.00000000227*np.cos(2.56475729469 + 2648.454825473*t)
	Y1 += 0.00000000233*np.cos(3.30440847719 + 1272.6810256272*t)
	Y1 += 0.00000000265*np.cos(1.64615612331 + 3.1813937377*t)
	Y1 += 0.00000000226*np.cos(1.80631316423 + 32370.9789915656*t)
	Y1 += 0.00000000278*np.cos(6.04510796667 + 51109.31080595839*t)
	Y1 += 0.00000000198*np.cos(0.48439148557 + 53764.8791784322*t)
	Y1 += 0.00000000198*np.cos(5.45868421930 + 69159.80243060499*t)
	Y1 += 0.00000000198*np.cos(1.05088517434 + 50057.04242277*t)
	Y1 += 0.00000000204*np.cos(2.45848643380 + 129380.13377768178*t)
	Y1 += 0.00000000202*np.cos(2.90008957782 + 44937.1306915484*t)
	Y1 += 0.00000000201*np.cos(4.46138168832 + 1375.7737998458*t)
	Y1 += 0.00000000186*np.cos(0.34501313169 + 136100.84775702319*t)
	Y1 += 0.00000000179*np.cos(2.18135449870 + 51962.5071877104*t)
	Y1 += 0.00000000198*np.cos(6.24548788507 + 38519.945791972*t)
	Y1 += 0.00000000175*np.cos(3.70186890404 + 105460.99111839019*t)
	Y1 += 0.00000000181*np.cos(2.37018594067 + 88.865680217*t)
	Y1 += 0.00000000170*np.cos(4.76480820754 + 78244.0396638228*t)
	Y1 += 0.00000000174*np.cos(5.50628514595 + 94138.32702008578*t)
	Y1 += 0.00000000199*np.cos(1.40110998613 + 430.5303441391*t)
	Y1 += 0.00000000189*np.cos(0.25718944825 + 124.433415221*t)
	Y1 += 0.00000000174*np.cos(5.22081710422 + 1368.660252845*t)
	Y1 += 0.00000000167*np.cos(3.42353804022 + 1062.5633239269*t)
	Y1 += 0.00000000158*np.cos(2.02200752968 + 64741.95798313119*t)
	Y1 += 0.00000000152*np.cos(5.50666765279 + 160.6088973985*t)
	Y1 += 0.00000000154*np.cos(3.11106938682 + 35191.8101356918*t)
	Y1 += 0.00000000149*np.cos(5.55768086104 + 59414.4818747484*t)
	Y1 += 0.00000000172*np.cos(0.02323350795 + 65.2203710117*t)
	Y1 += 0.00000000154*np.cos(4.59717983879 + 519.3960243561*t)
	Y1 += 0.00000000147*np.cos(0.13708317947 + 52602.4044740244*t)
	Y1 += 0.00000000144*np.cos(4.84328699315 + 23754.70674870219*t)
	Y1 += 0.00000000182*np.cos(0.69098340435 + 55618.3812281138*t)
	Y1 += 0.00000000160*np.cos(0.13656742888 + 6681.2248533996*t)
	Y1 += 0.00000000181*np.cos(5.38091227869 + 57837.1383323006*t)
	Y1 += 0.00000000141*np.cos(0.43737121379 + 19804.8272915828*t)
	Y1 += 0.00000000154*np.cos(1.82260394090 + 99799.65906923798*t)
	Y1 += 0.00000000139*np.cos(3.64890818066 + 1055.4497769261*t)
	Y1 += 0.00000000139*np.cos(4.62954456179 + 25973.46385288896*t)
	Y1 += 0.00000000139*np.cos(4.17648511776 + 26202.34243025941*t)
	Y1 += 0.00000000138*np.cos(4.30414447043 + 1258.4539316256*t)
	Y1 += 0.00000000150*np.cos(0.38751874779 + 12432.0426503978*t)
	Y1 += 0.00000000191*np.cos(2.30641502359 + 26727.8004278882*t)
	Y1 += 0.00000000146*np.cos(5.94769996528 + 77734.01845962799*t)
	Y1 += 0.00000000132*np.cos(5.18037129096 + 654.1243803156*t)
	Y1 += 0.00000000136*np.cos(1.73632400099 + 203.0041546995*t)
	Y1 += 0.00000000135*np.cos(1.84579237766 + 78267.59076008058*t)
	Y1 += 0.00000000129*np.cos(3.00023369224 + 88476.99497093359*t)
	Y1 += 0.00000000149*np.cos(5.86186493808 + 27154.3986187642*t)
	Y1 += 0.00000000135*np.cos(4.69551709590 + 124778.18365871879*t)
	Y1 += 0.00000000121*np.cos(4.88476463619 + 1063.3140834523*t)
	Y1 += 0.00000000121*np.cos(4.65791065493 + 2125.8774073792*t)
	Y1 += 0.00000000118*np.cos(3.20236689438 + 551.031606097*t)
	Y1 += 0.00000000120*np.cos(2.88381733148 + 539.9859058331*t)
	Y1 += 0.00000000121*np.cos(2.04673401184 + 104881.30353139139*t)
	Y1 += 0.00000000117*np.cos(5.62340094017 + 26241.681952059*t)
	Y1 += 0.00000000140*np.cos(4.29359662977 + 1056.2005364515*t)
	Y1 += 0.00000000114*np.cos(3.20229489909 + 25934.1243310894*t)
	Y1 += 0.00000000111*np.cos(4.11806246187 + 222.8603229936*t)
	Y1 += 0.00000000111*np.cos(4.43341533070 + 28206.6670019526*t)
	Y1 += 0.00000000133*np.cos(3.06193509061 + 22.0914005278*t)
	Y1 += 0.00000000108*np.cos(0.12055562317 + 27140.17152476259*t)
	Y1 += 0.00000000108*np.cos(4.00300903450 + 28421.0995344462*t)
	Y1 += 0.00000000115*np.cos(2.44069966013 + 103821.92160120218*t)
	Y1 += 0.00000000147*np.cos(5.78118598550 + 25661.3049506982*t)
	Y1 += 0.00000000136*np.cos(1.56582531149 + 21.3406410024*t)
	Y1 += 0.00000000144*np.cos(6.19128577365 + 299.1263942692*t)
	Y1 += 0.00000000112*np.cos(4.03628252899 + 155418.04029735178*t)
	Y1 += 0.00000000108*np.cos(1.67634660643 + 302.164775655*t)
	Y1 += 0.00000000113*np.cos(0.89323533784 + 5327.4761083828*t)
	Y1 += 0.00000000109*np.cos(3.54608692634 + 2111.6503133776*t)
	Y1 += 0.00000000101*np.cos(1.41448120448 + 191.9584544356*t)
	Y1 += 0.00000000101*np.cos(1.94624186930 + 25619.9381512198*t)
	Y1 += 0.00000000136*np.cos(1.35835243002 + 1485.9801210652*t)
	Y1 += 0.00000000103*np.cos(3.99533045688 + 2333.196392872*t)
	Y1 += 0.00000000098*np.cos(0.58109085915 + 26555.8681319286*t)
	Y1 += 0.00000000095*np.cos(3.83184038977 + 18.1592472647*t)
	Y1 += 0.00000000118*np.cos(0.18946350402 + 7994.5284420242*t)
	Y1 += 0.00000000094*np.cos(1.74801590640 + 87.3117715395*t)
	Y1 += 0.00000000109*np.cos(0.03546800856 + 103396.01282468818*t)
	Y1 += 0.00000000096*np.cos(4.82412903185 + 58458.88213313979*t)
	Y1 += 0.00000000095*np.cos(1.17322458014 + 78256.59587772179*t)
	Y1 += 0.00000000108*np.cos(4.55255767260 + 79219.30916633119*t)
	Y1 += 0.00000000119*np.cos(3.20779882655 + 1574.8458012822*t)
	Y1 += 0.00000000097*np.cos(5.79799018982 + 105410.99449648599*t)
	Y1 += 0.00000000104*np.cos(3.38377920613 + 91785.46086631398*t)
	Y1 += 0.00000000122*np.cos(4.95627332740 + 84.3428261229*t)
	Y1 += 0.00000000097*np.cos(4.30891602532 + 217.964961884*t)
	Y1 += 0.00000000093*np.cos(6.00441441624 + 33.6796175129*t)
	Y1 += 0.00000000090*np.cos(4.81615242206 + 125887.56221081219*t)
	Y1 += 0.00000000087*np.cos(1.75505290273 + 231.4583427027*t)
	Y1 += 0.00000000097*np.cos(0.07381843439 + 72.3339180125*t)
	Y1 += 0.00000000090*np.cos(3.89285886336 + 628.8515860501*t)
	Y1 += 0.00000000084*np.cos(1.63978190741 + 74821.13447975718*t)
	Y1 += 0.00000000083*np.cos(5.10540266957 + 24498.8302462904*t)
	Y1 += 0.00000000083*np.cos(0.21041749661 + 77623.81213840858*t)
	Y1 += 0.00000000089*np.cos(3.43002043997 + 1699.2792165032*t)
	Y1 += 0.00000000098*np.cos(3.79443655655 + 71980.63357473118*t)
	Y1 += 0.00000000080*np.cos(5.50123915378 + 155468.03691925599*t)
	Y1 += 0.00000000081*np.cos(1.24471501739 + 76044.9523205358*t)
	Y1 += 0.00000000080*np.cos(5.99267916099 + 12.5301729722*t)
	Y1 += 0.00000000081*np.cos(3.47273729856 + 26137.8997634784*t)
	Y1 += 0.00000000087*np.cos(0.96769986532 + 80482.46652890938*t)
	Y1 += 0.00000000081*np.cos(5.32947215471 + 26037.90651966999*t)
	Y1 += 0.00000000078*np.cos(0.98498478741 + 73711.75592766379*t)
	Y1 += 0.00000000086*np.cos(3.72646183478 + 208.633228992*t)
	Y1 += 0.00000000105*np.cos(0.71334145620 + 78270.82297172339*t)
	Y1 += 0.00000000076*np.cos(4.88733161640 + 9.5612275556*t)
	Y1 += 0.00000000077*np.cos(4.73669756226 + 38.1330356378*t)
	Y1 += 0.00000000104*np.cos(3.66342015283 + 78283.37918562238*t)
	Y1 += 0.00000000076*np.cos(4.18947022170 + 288.0806940053*t)
	Y1 += 0.00000000083*np.cos(1.92598112123 + 10213.285546211*t)
	Y1 += 0.00000000089*np.cos(0.32104107901 + 78259.82808936459*t)
	Y1 += 0.00000000077*np.cos(5.22885086883 + 18207.81398823521*t)
	Y1 += 0.00000000096*np.cos(4.64169775712 + 203.7378678824*t)
	Y1 += 0.00000000081*np.cos(2.33694388762 + 77211.44104153418*t)
	Y1 += 0.00000000076*np.cos(5.12453730610 + 362.8622925726*t)
	Y1 += 0.00000000082*np.cos(2.81119087789 + 77197.21394753258*t)
	Y1 += 0.00000000076*np.cos(2.48257518078 + 1471.7530270636*t)
	Y1 += 0.00000000075*np.cos(0.38132378506 + 525.0250986486*t)
	Y1 += 0.00000000069*np.cos(2.64295754993 + 114.3991069134*t)
	Y1 += 0.00000000068*np.cos(5.35287430069 + 153.4953503977*t)
	Y1 += 0.00000000068*np.cos(5.70841220182 + 73.8183907208*t)
	Y1 += 0.00000000067*np.cos(3.45611920251 + 85034.42002596818*t)
	Y1 += 0.00000000071*np.cos(0.81628722181 + 534.3568315406*t)
	Y1 += 0.00000000066*np.cos(2.25341317524 + 120226.23016165999*t)
	Y1 += 0.00000000066*np.cos(3.38335740927 + 162188.75089859738*t)
	Y1 += 0.00000000064*np.cos(5.24500232218 + 75.7448064138*t)
	Y1 += 0.00000000071*np.cos(0.43788427177 + 108903.56606335558*t)
	Y1 += 0.00000000064*np.cos(1.72668339565 + 51756.3216392732*t)
	Y1 += 0.00000000066*np.cos(4.60699109440 + 42.5864537627*t)
	Y1 += 0.00000000061*np.cos(1.32159131349 + 207.8824694666*t)
	Y1 += 0.00000000061*np.cos(0.85156750769 + 102762.53967101299*t)
	Y1 += 0.00000000059*np.cos(0.45173742414 + 218.7157214094*t)
	Y1 += 0.00000000059*np.cos(5.95742231142 + 408.4389436113*t)
	Y1 += 0.00000000080*np.cos(0.95243616639 + 41962.5207369374*t)
	Y1 += 0.00000000067*np.cos(5.29778871808 + 152.5321425512*t)
	Y1 += 0.00000000076*np.cos(4.82056450443 + 77.2292791221*t)
	Y1 += 0.00000000063*np.cos(1.72943225747 + 79.2350166922*t)
	Y1 += 0.00000000076*np.cos(3.02910585186 + 78477.00852016058*t)
	Y1 += 0.00000000063*np.cos(5.48151873299 + 93028.94846799239*t)
	Y1 += 0.00000000078*np.cos(4.97215052079 + 71492.99882347698*t)
	Y1 += 0.00000000077*np.cos(2.34940739586 + 51742.09454527159*t)
	Y1 += 0.00000000077*np.cos(2.23039388415 + 25565.3257234804*t)
	Y1 += 0.00000000058*np.cos(0.20188459959 + 339142.74084046457*t)
	Y1 += 0.00000000055*np.cos(1.48510731583 + 200.7689224658*t)
	Y1 += 0.00000000055*np.cos(2.03729558857 + 340.7708920448*t)
	Y1 += 0.00000000076*np.cos(0.68351123517 + 146.594251718*t)
	Y1 += 0.00000000055*np.cos(3.39931628865 + 13521.7514415914*t)
	Y1 += 0.00000000055*np.cos(3.95248458913 + 76144.94556434419*t)
	Y1 += 0.00000000060*np.cos(3.68878783807 + 33967.99229491319*t)
	Y1 += 0.00000000072*np.cos(1.86379528122 + 127.4717966068*t)
	Y1 += 0.00000000060*np.cos(5.91873713879 + 71025.03383312259*t)
	Y1 += 0.00000000056*np.cos(0.12827895263 + 117873.36400788819*t)
	Y1 += 0.00000000055*np.cos(4.21946130925 + 51322.60990139639*t)
	Y1 += 0.00000000055*np.cos(3.89290884441 + 831.8557407496*t)
	Y1 += 0.00000000052*np.cos(1.07800540558 + 2008.557539159*t)
	Y1 += 0.00000000053*np.cos(3.50270077624 + 79852.78232000639*t)
	Y1 += 0.00000000051*np.cos(1.99163070525 + 225.8292684102*t)
	Y1 += 0.00000000057*np.cos(5.68632410752 + 4.4534181249*t)
	Y1 += 0.00000000054*np.cos(4.92792314090 + 78050.41032928458*t)
	Y1 += 0.00000000058*np.cos(2.81154337799 + 64607.84893354619*t)
	Y1 += 0.00000000059*np.cos(4.32589692662 + 618.5566453116*t)
	Y1 += 0.00000000053*np.cos(0.59571673904 + 98068.53671630539*t)
	Y1 += 0.00000000064*np.cos(3.86347940489 + 1685.0521225016*t)
	Y1 += 0.00000000053*np.cos(3.04286367857 + 70.3281804424*t)
	Y1 += 0.00000000059*np.cos(1.46294017673 + 2221.856634597*t)
	Y1 += 0.00000000068*np.cos(0.28167911102 + 26610.48055966799*t)
	Y1 += 0.00000000049*np.cos(5.08570479388 + 90829.86112470538*t)
	Y1 += 0.00000000055*np.cos(5.75839561261 + 10021.8372800994*t)
	Y1 += 0.00000000048*np.cos(2.75851599881 + 350.3321196004*t)
	Y1 += 0.00000000050*np.cos(4.43499705514 + 131548.89425996438*t)
	Y1 += 0.00000000051*np.cos(0.22846885309 + 210.3783341312*t)
	Y1 += 0.00000000051*np.cos(1.50810894489 + 216.2198567448*t)
	Y1 += 0.00000000062*np.cos(4.16798181151 + 1795.258443721*t)
	Y1 += 0.00000000049*np.cos(4.34430964617 + 963.4027029714*t)
	Y1 += 0.00000000050*np.cos(3.73696798374 + 81706.28436968799*t)
	Y1 += 0.00000000057*np.cos(1.99845655428 + 26624.70765366959*t)
	Y1 += 0.00000000048*np.cos(1.72165289468 + 46848.3301747656*t)
	Y1 += 0.00000000052*np.cos(5.97532002180 + 142.4496501338*t)
	Y1 += 0.00000000051*np.cos(5.44789453960 + 129909.82474277639*t)
	Y1 += 0.00000000045*np.cos(3.23715580244 + 37.611770776*t)
	Y1 += 0.00000000044*np.cos(2.92943406327 + 62.2514255951*t)
	Y1 += 0.00000000050*np.cos(2.96247842378 + 1038.0412891868*t)
	Y1 += 0.00000000044*np.cos(4.06912509984 + 524.2743391232*t)
	Y1 += 0.00000000055*np.cos(2.67037457843 + 18093.37469954999*t)
	Y1 += 0.00000000044*np.cos(1.10360628000 + 38.6543004996*t)
	Y1 += 0.00000000045*np.cos(1.53256570325 + 104331.94280539699*t)
	Y1 += 0.00000000044*np.cos(3.41315318980 + 535.107591066*t)
	Y1 += 0.00000000043*np.cos(3.21375486020 + 78690.30761559859*t)
	Y1 += 0.00000000060*np.cos(2.46786657303 + 44181.27784112419*t)
	Y1 += 0.00000000042*np.cos(3.26999492630 + 195.1398481733*t)
	Y1 += 0.00000000042*np.cos(6.05032686000 + 114564.89811250778*t)
	Y1 += 0.00000000043*np.cos(2.09042966596 + 74.8934731519*t)
	Y1 += 0.00000000043*np.cos(2.58927275174 + 74.6697239827*t)
	Y1 += 0.00000000050*np.cos(0.24741236723 + 131.4039498699*t)
	Y1 += 0.00000000049*np.cos(4.20329151784 + 207.6700211455*t)
	Y1 += 0.00000000048*np.cos(0.71033320787 + 109.9456887885*t)
	Y1 += 0.00000000050*np.cos(0.35287690462 + 25448.00585526019*t)
	Y1 += 0.00000000052*np.cos(5.71954387859 + 39743.7636327506*t)
	Y1 += 0.00000000043*np.cos(5.20907523109 + 103925.01437542078*t)
	Y1 += 0.00000000039*np.cos(0.11315588432 + 1382.8873468466*t)
	Y1 += 0.00000000039*np.cos(1.52015918184 + 22759.76748529401*t)
	Y1 += 0.00000000038*np.cos(2.82768070464 + 703.6331846174*t)
	Y1 += 0.00000000040*np.cos(1.29300189092 + 10.2949407385*t)
	Y1 += 0.00000000047*np.cos(4.16294922404 + 7880.08915333899*t)
	Y1 += 0.00000000046*np.cos(3.79813773531 + 218.9281697305*t)
	Y1 += 0.00000000051*np.cos(0.64336380499 + 25551.09862947879*t)
	Y1 += 0.00000000037*np.cos(1.54306065932 + 151975.46535238638*t)
	Y1 += 0.00000000044*np.cos(3.24253086773 + 26521.614879451*t)
	Y1 += 0.00000000050*np.cos(5.41249272242 + 50579.61984086379*t)
	Y1 += 0.00000000037*np.cos(2.83593964107 + 511.5317178299*t)
	Y1 += 0.00000000041*np.cos(5.42065925757 + 52815.7035694624*t)
	Y1 += 0.00000000036*np.cos(1.60823257348 + 84546.78527471398*t)
	Y1 += 0.00000000035*np.cos(4.28290669029 + 565.1156877467*t)
	Y1 += 0.00000000035*np.cos(3.16352925954 + 25984.8103673556*t)
	Y1 += 0.00000000042*np.cos(5.31330734899 + 25881.717593137*t)
	Y1 += 0.00000000038*np.cos(1.94461159801 + 20760.4270331914*t)
	Y1 += 0.00000000040*np.cos(3.45207563685 + 26294.08869001139*t)
	Y1 += 0.00000000035*np.cos(4.65527976927 + 547.8502123593*t)
	Y1 += 0.00000000041*np.cos(1.46373068876 + 150866.08680029298*t)
	Y1 += 0.00000000039*np.cos(2.38629347866 + 490.3340891794*t)
	Y1 += 0.00000000041*np.cos(2.59929301074 + 52329.58509363319*t)
	Y1 += 0.00000000042*np.cos(3.87683640837 + 56.6223513026*t)
	Y1 += 0.00000000033*np.cos(3.96639362427 + 750.1036075334*t)
	Y1 += 0.00000000037*np.cos(4.69414299267 + 635.9651330509*t)
	Y1 += 0.00000000033*np.cos(5.65242255825 + 26190.99591579279*t)
	Y1 += 0.00000000043*np.cos(4.45960439238 + 26507.38778544939*t)
	Y1 += 0.00000000035*np.cos(0.94458988495 + 157636.79740153858*t)
	Y1 += 0.00000000038*np.cos(4.43072611572 + 483.2205421786*t)
	Y1 += 0.00000000033*np.cos(5.49712174212 + 89586.37352302698*t)
	Y1 += 0.00000000035*np.cos(3.11075553675 + 526.7702037878*t)
	Y1 += 0.00000000033*np.cos(1.02557119665 + 29416.03879785439*t)
	Y1 += 0.00000000037*np.cos(5.05612012470 + 130969.20667296558*t)
	Y1 += 0.00000000035*np.cos(4.37175047624 + 532.6117264014*t)
	Y1 += 0.00000000032*np.cos(0.81223636394 + 181505.94343892598*t)
	Y1 += 0.00000000036*np.cos(4.90396980927 + 104355.49390165479*t)
	Y1 += 0.00000000033*np.cos(2.20907300044 + 95247.70557217918*t)
	Y1 += 0.00000000037*np.cos(0.13743210410 + 265.9892934775*t)
	Y1 += 0.00000000031*np.cos(5.89336305342 + 447.9388318784*t)
	Y1 += 0.00000000030*np.cos(3.64034430247 + 52643.7712735028*t)
	Y1 += 0.00000000032*np.cos(3.07834718000 + 129483.91596626239*t)
	Y1 += 0.00000000032*np.cos(5.92360692203 + 50593.84693486539*t)
	Y1 += 0.00000000030*np.cos(5.15245353060 + 209.106309744*t)
	Y1 += 0.00000000030*np.cos(2.87235713038 + 217.491881132*t)
	Y1 += 0.00000000030*np.cos(0.02207663615 + 92.940845832*t)
	Y1 += 0.00000000030*np.cos(2.26774333910 + 181555.94006083018*t)
	Y1 += 0.00000000039*np.cos(5.08202984393 + 1.4844727083*t)
	Y1 += 0.00000000038*np.cos(0.97224853307 + 52.6901980395*t)
	Y1 += 0.00000000031*np.cos(0.94422467729 + 52290.24557183361*t)
	Y1 += 0.00000000030*np.cos(6.02102768353 + 105307.21230790539*t)
	Y1 += 0.00000000028*np.cos(1.77462370325 + 80.1982245387*t)
	Y1 += 0.00000000032*np.cos(3.17587486064 + 51639.00177105299*t)
	Y1 += 0.00000000030*np.cos(2.65307578652 + 53242.3017603384*t)
	Y1 += 0.00000000034*np.cos(5.07299879866 + 269.9214467406*t)
	Y1 += 0.00000000030*np.cos(3.80765804617 + 77204.32749453338*t)
	Y1 += 0.00000000028*np.cos(2.45238897056 + 107.0249274817*t)
	Y1 += 0.00000000028*np.cos(1.18666538399 + 106.2741679563*t)
	Y1 += 0.00000000028*np.cos(0.76476883745 + 54509.0026760204*t)
	Y1 += 0.00000000031*np.cos(3.61860838672 + 424.1505103212*t)
	Y1 += 0.00000000027*np.cos(2.79364979031 + 1279.794572628*t)
	Y1 += 0.00000000030*np.cos(3.96649414762 + 25668.418497699*t)
	Y1 += 0.00000000026*np.cos(1.39174885866 + 52061.36699446317*t)
	Y1 += 0.00000000027*np.cos(3.23525952036 + 1802.3719907218*t)
	Y1 += 0.00000000026*np.cos(5.17584348971 + 29428.515568274*t)
	Y1 += 0.00000000031*np.cos(1.42512028038 + 26941.0995233262*t)
	Y1 += 0.00000000027*np.cos(4.24057714278 + 1898.3512179396*t)
	Y1 += 0.00000000025*np.cos(3.82482687733 + 22747.2907148744*t)
	Y1 += 0.00000000026*np.cos(0.12161666654 + 26237.46633870879*t)
	Y1 += 0.00000000029*np.cos(3.76445788944 + 104358.72611329758*t)
	Y1 += 0.00000000029*np.cos(2.57759749899 + 131498.89763806018*t)
	Y1 += 0.00000000024*np.cos(1.15377636817 + 54294.57014352679*t)
	Y1 += 0.00000000023*np.cos(5.31248405128 + 146314.13330323418*t)
	Y1 += 0.00000000024*np.cos(2.14828351418 + 25035.6347583858*t)
	Y1 += 0.00000000023*np.cos(6.28082090370 + 650.9429865779*t)
	Y1 += 0.00000000023*np.cos(4.99790910102 + 137.0330241624*t)
	Y1 += 0.00000000023*np.cos(3.28519702781 + 35.685355083*t)
	Y1 += 0.00000000023*np.cos(3.51522402665 + 42153.969003049*t)
	Y1 += 0.00000000025*np.cos(2.81295161547 + 25021.4076643842*t)
	Y1 += 0.00000000023*np.cos(3.16185186674 + 143961.26714946238*t)
	Y1 += 0.00000000023*np.cos(3.28897425519 + 28.5718080822*t)
	Y1 += 0.00000000022*np.cos(5.43332862700 + 337.732510659*t)
	Y1 += 0.00000000026*np.cos(0.16015479279 + 27684.0895838588*t)
	Y1 += 0.00000000023*np.cos(0.76234430512 + 85502.38501632259*t)
	Y1 += 0.00000000023*np.cos(1.93214715353 + 130012.91751699499*t)
	Y1 += 0.00000000023*np.cos(5.16035150168 + 2.4476805548*t)
	Y1 += 0.00000000023*np.cos(4.82793901796 + 643.0786800517*t)
	Y1 += 0.00000000024*np.cos(5.25759177705 + 1361.5467058442*t)
	Y1 += 0.00000000021*np.cos(4.22606773111 + 104344.49901929598*t)
	Y1 += 0.00000000022*np.cos(1.70327289493 + 934.9485149682*t)
	Y1 += 0.00000000021*np.cos(4.30403088752 + 102132.85546210999*t)
	Y1 += 0.00000000023*np.cos(2.98215154259 + 284.1485407422*t)
	Y1 += 0.00000000023*np.cos(4.82095240983 + 77844.22478084739*t)
	Y1 += 0.00000000023*np.cos(6.09848080953 + 61279.713277266*t)
	Y1 += 0.00000000024*np.cos(5.43301943304 + 52026.2430860138*t)
	Y1 += 0.00000000026*np.cos(6.08383182078 + 13362.4497067992*t)
	Y1 += 0.00000000028*np.cos(5.39827333268 + 103299.34418310839*t)
	Y1 += 0.00000000024*np.cos(4.50083076815 + 191.2076949102*t)
	Y1 += 0.00000000021*np.cos(3.65808766486 + 124156.43985787958*t)
	Y1 += 0.00000000021*np.cos(1.05341004601 + 40.5807161926*t)
	Y1 += 0.00000000023*np.cos(5.40550001829 + 77829.99768684579*t)
	Y1 += 0.00000000021*np.cos(0.15049062299 + 188276.65404017158*t)
	Y1 += 0.00000000021*np.cos(1.35819574535 + 525.4981794006*t)
	Y1 += 0.00000000024*np.cos(3.37809061150 + 540.7366653585*t)
	Y1 += 0.00000000025*np.cos(5.09676204562 + 96.8729990951*t)
	Y1 += 0.00000000020*np.cos(3.97670500643 + 251.4321310758*t)
	Y1 += 0.00000000027*np.cos(4.63548485210 + 1905.4647649404*t)
	Y1 += 0.00000000024*np.cos(3.34248986355 + 219.4494345923*t)
	Y1 += 0.00000000019*np.cos(2.08327707784 + 52125.80966124419*t)
	Y1 += 0.00000000019*np.cos(0.39572623459 + 49527.35145767539*t)
	Y1 += 0.00000000020*np.cos(5.86539829358 + 103285.11708910679*t)
	Y1 += 0.00000000019*np.cos(3.38049497890 + 103711.71527998279*t)
	Y1 += 0.00000000019*np.cos(1.29742572058 + 99.1606209555*t)
	Y1 += 0.00000000019*np.cos(1.62343185954 + 3328.13565628019*t)
	Y1 += 0.00000000020*np.cos(1.96622391594 + 81.8951455681*t)
	Y1 += 0.00000000022*np.cos(6.13349712417 + 104564.91166173479*t)
	Y1 += 0.00000000025*np.cos(4.72474160158 + 24864.08530079559*t)
	Y1 += 0.00000000022*np.cos(2.04754590576 + 114.1384744825*t)
	Y1 += 0.00000000021*np.cos(1.75089409332 + 97580.90196505119*t)
	Y1 += 0.00000000019*np.cos(3.21617188609 + 53228.07466633679*t)
	Y1 += 0.00000000021*np.cos(5.89651875201 + 344.7030453079*t)
	Y1 += 0.00000000018*np.cos(0.41312927370 + 479.2883889155*t)
	Y1 += 0.00000000024*np.cos(4.07017150249 + 27311.72098235281*t)
	Y1 += 0.00000000019*np.cos(0.01409672971 + 115674.27666460119*t)
	Y1 += 0.00000000018*np.cos(1.05659266627 + 47.6942631934*t)
	Y1 += 0.00000000021*np.cos(0.42232709112 + 104371.28232719658*t)
	Y1 += 0.00000000019*np.cos(1.03948249798 + 113.3877149571*t)
	Y1 += 0.00000000018*np.cos(3.95444821177 + 106570.36967048359*t)
	Y1 += 0.00000000018*np.cos(5.36139144851 + 66.70484372*t)
	Y1 += 0.00000000017*np.cos(2.91822171111 + 235.3904959658*t)
	Y1 += 0.00000000022*np.cos(3.48072739991 + 134991.46920492979*t)
	Y1 += 0.00000000018*np.cos(5.53310135976 + 436.8931316145*t)
	Y1 += 0.00000000016*np.cos(1.01452476805 + 77410.51304297059*t)
	Y1 += 0.00000000019*np.cos(3.35287626013 + 52698.38370124219*t)
	Y1 += 0.00000000016*np.cos(4.13205563870 + 1603.2999892854*t)
	Y1 += 0.00000000017*np.cos(5.48950262612 + 909.8187330546*t)
	Y1 += 0.00000000017*np.cos(1.53003869474 + 104138.31347085879*t)
	Y1 += 0.00000000018*np.cos(5.39681560820 + 358.9301393095*t)
	Y1 += 0.00000000017*np.cos(6.15299165414 + 533.8837507886*t)
	Y1 += 0.00000000016*np.cos(2.76299512297 + 12546.481939083*t)
	Y1 += 0.00000000016*np.cos(3.68087340604 + 1788.1448967202*t)
	Y1 += 0.00000000019*np.cos(4.72886285917 + 207.1487562837*t)
	Y1 += 0.00000000015*np.cos(4.67333162818 + 100909.03762133139*t)
	Y1 += 0.00000000018*np.cos(2.57871349196 + 67.6680515665*t)
	Y1 += 0.00000000017*np.cos(3.83900403821 + 497.4476361802*t)
	Y1 += 0.00000000017*np.cos(5.84159114613 + 417.0369633204*t)
	Y1 += 0.00000000018*np.cos(2.36207795372 + 131395.11544947959*t)
	Y1 += 0.00000000016*np.cos(5.51525513218 + 25867.49049913539*t)
	Y1 += 0.00000000016*np.cos(0.14257422390 + 60055.89543648739*t)
	Y1 += 0.00000000015*np.cos(1.22870448460 + 65697.55772473979*t)
	Y1 += 0.00000000016*np.cos(3.31067179278 + 26308.315784013*t)
	Y1 += 0.00000000021*np.cos(4.56372121432 + 11610.5519583742*t)
	Y1 += 0.00000000020*np.cos(3.01802641783 + 51543.0225438352*t)
	Y1 += 0.00000000017*np.cos(3.21776480838 + 51528.79544983359*t)
	Y1 += 0.00000000014*np.cos(4.20789843971 + 175.1660598002*t)
	Y1 += 0.00000000015*np.cos(6.06025379954 + 26164.1692128498*t)
	Y1 += 0.00000000020*np.cos(4.28247273571 + 45494.58142974879*t)
	Y1 += 0.00000000015*np.cos(3.58225207772 + 220.4608265486*t)
	Y1 += 0.00000000014*np.cos(2.95737593819 + 3178.1457905676*t)
	Y1 += 0.00000000019*np.cos(2.18136203189 + 155997.72788435058*t)
	Y1 += 0.00000000017*np.cos(2.13417847261 + 76667.52298243798*t)
	Y1 += 0.00000000014*np.cos(0.57687637914 + 416.3032501375*t)
	Y1 += 0.00000000017*np.cos(4.45257505087 + 3340.6124266998*t)
	Y1 += 0.00000000015*np.cos(5.66819746086 + 146.3818033969*t)
	Y1 += 0.00000000018*np.cos(2.25020745189 + 119116.85160956658*t)
	Y1 += 0.00000000019*np.cos(1.98725402688 + 554.0699874828*t)
	Y1 += 0.00000000016*np.cos(4.97934330897 + 52712.61079524379*t)
	Y1 += 0.00000000017*np.cos(5.06532306406 + 49842.60989027639*t)
	Y1 += 0.00000000014*np.cos(6.04847951703 + 90695.75207512038*t)
	Y1 += 0.00000000014*np.cos(2.61946078132 + 99.9113804809*t)
	Y1 += 0.00000000014*np.cos(3.43836595760 + 518.6452648307*t)
	Y1 += 0.00000000014*np.cos(2.00566016514 + 44295.7171298094*t)
	Y1 += 0.00000000014*np.cos(3.89737183526 + 183724.70054311278*t)
	Y1 += 0.00000000014*np.cos(3.18665999637 + 27999.1026247914*t)
	Y1 += 0.00000000019*np.cos(3.37998775559 + 104347.73123093879*t)
	Y1 += 0.00000000015*np.cos(0.17179065008 + 52225.8029050526*t)
	Y1 += 0.00000000018*np.cos(2.68126129305 + 97112.93697469679*t)
	Y1 += 0.00000000015*np.cos(3.20359726329 + 128850.44281258718*t)
	Y1 += 0.00000000016*np.cos(5.81395988324 + 52099.5402118728*t)
	Y1 += 0.00000000014*np.cos(3.65383778432 + 1049.0869894507*t)
	Y1 += 0.00000000014*np.cos(1.85956386315 + 116917.76426627958*t)
	Y1 += 0.00000000015*np.cos(3.25430509963 + 365230.64398203876*t)
	Y1 += 0.00000000013*np.cos(5.63989609373 + 24176.703658357*t)
	Y1 += 0.00000000014*np.cos(3.14536047801 + 111590.28815789679*t)
	Y1 += 0.00000000014*np.cos(5.20815151417 + 25953.79409198919*t)
	Y1 += 0.00000000014*np.cos(3.58473930386 + 351.8165923087*t)
	Y1 += 0.00000000013*np.cos(4.58713099926 + 178063.36849396059*t)
	Y1 += 0.00000000014*np.cos(3.09174780856 + 429.0458714308*t)
	Y1 += 0.00000000014*np.cos(0.49361194238 + 107794.18751126219*t)
	Y1 += 0.00000000015*np.cos(0.24966144265 + 105940.68546158058*t)
	Y1 += 0.00000000014*np.cos(3.58612114877 + 26222.0121911592*t)
	Y1 += 0.00000000016*np.cos(1.89603210492 + 404.5067903482*t)
	Y1 += 0.00000000014*np.cos(4.23117767971 + 181.0557665236*t)
	Y1 += 0.00000000015*np.cos(4.47532653098 + 40565.2543247742*t)
	Y1 += 0.00000000015*np.cos(5.51517239045 + 4.665866446*t)
	Y1 += 0.00000000013*np.cos(0.38270943937 + 636.7158925763*t)
	Y1 += 0.00000000015*np.cos(6.00200377172 + 27669.86248985719*t)
	Y1 += 0.00000000013*np.cos(4.88852328329 + 14477.35118320*t)
	Y1 += 0.00000000014*np.cos(3.79902684902 + 245.5424243524*t)
	Y1 += 0.00000000013*np.cos(5.65675422016 + 82.8583534146*t)
	Y1 += 0.00000000012*np.cos(2.67513147421 + 76681.75007643958*t)
	Y1 += 0.00000000012*np.cos(4.62759446539 + 72936.23331633979*t)
	Y1 += 0.00000000012*np.cos(3.92223202416 + 16066.0658614748*t)
	Y1 += 0.00000000013*np.cos(2.82189216105 + 140652.80125408198*t)
	Y1 += 0.00000000012*np.cos(6.06250888369 + 52072.71350892979*t)
	Y1 += 0.00000000015*np.cos(3.45337214515 + 77837.11123384659*t)
	Y1 += 0.00000000013*np.cos(3.69737120977 + 501.3797894433*t)
	Y1 += 0.00000000013*np.cos(3.82545867862 + 205.2223405907*t)
	Y1 += 0.00000000012*np.cos(4.39382701202 + 867.4234757536*t)
	Y1 += 0.00000000014*np.cos(2.72526558025 + 38813.3565763492*t)
	Y1 += 0.00000000013*np.cos(2.07858336172 + 145.1097790097*t)
	Y1 += 0.00000000012*np.cos(4.67458570991 + 110634.68841628819*t)
	Y1 += 0.00000000012*np.cos(0.55371302918 + 102232.84870591838*t)
	Y1 += 0.00000000011*np.cos(2.00033237383 + 36109.7404216736*t)
	Y1 += 0.00000000011*np.cos(6.02905899204 + 131.5469622218*t)
	Y1 += 0.00000000011*np.cos(3.70434496261 + 2214.7430875962*t)
	Y1 += 0.00000000011*np.cos(1.10539607022 + 26198.1094627936*t)
	Y1 += 0.00000000014*np.cos(5.75250501205 + 78417.48823520739*t)
	Y1 += 0.00000000012*np.cos(0.46344500005 + 45892.73043315699*t)
	Y1 += 0.00000000012*np.cos(3.18799737238 + 14.977853527*t)
	Y1 += 0.00000000012*np.cos(3.62733339243 + 31415.379249957*t)
	Y1 += 0.00000000011*np.cos(0.14540231257 + 111122.32316754239*t)
	Y1 += 0.00000000011*np.cos(6.27463466728 + 104778.21075717278*t)
	Y1 += 0.00000000011*np.cos(0.88747625993 + 211.8146227297*t)
	Y1 += 0.00000000011*np.cos(1.42069515516 + 25977.69682035479*t)
	Y1 += 0.00000000011*np.cos(6.17305766602 + 39629.32434406539*t)
	Y1 += 0.00000000011*np.cos(2.54959001341 + 51969.62073471119*t)
	Y1 += 0.00000000015*np.cos(1.08931229419 + 32769.1279949738*t)
	Y1 += 0.00000000010*np.cos(4.00452085532 + 55503.94193942859*t)
	Y1 += 0.00000000012*np.cos(4.58411493514 + 130419.8459469712*t)
	Y1 += 0.00000000010*np.cos(2.67518472775 + 121.2520214833*t)
	Y1 += 0.00000000010*np.cos(4.32081630166 + 214.0498549634*t)
	Y1 += 0.00000000011*np.cos(2.95045626847 + 141762.17980617538*t)
	Y1 += 0.00000000012*np.cos(4.08903506366 + 198.321241911*t)
	Y1 += 0.00000000010*np.cos(3.21317176695 + 2104.5367663768*t)
	Y1 += 0.00000000013*np.cos(5.16720446526 + 70269.18098269838*t)
	Y1 += 0.00000000010*np.cos(5.01492480888 + 28736.3579670472*t)
	Y1 += 0.00000000013*np.cos(3.04628805544 + 721.6494195302*t)
	Y1 += 0.00000000010*np.cos(5.85525484044 + 405.2575498736*t)
	Y1 += 0.00000000013*np.cos(5.70406073241 + 25654.19140369739*t)
	Y1 += 0.00000000010*np.cos(0.95353223766 + 444.7574381407*t)
	Y1 += 0.00000000010*np.cos(4.44991640752 + 289.5651667136*t)
	Y1 += 0.00000000011*np.cos(1.96513444262 + 108.4612160802*t)
	Y1 += 0.00000000010*np.cos(2.23466649370 + 78903.60671103658*t)
	Y1 += 0.00000000011*np.cos(4.54905670073 + 206.1373643274*t)
	Y1 += 0.00000000010*np.cos(6.22843606515 + 170049.17029103659*t)
	Y1 += 0.00000000010*np.cos(1.45962507451 + 643.8294395771*t)
	Y1 += 0.00000000010*np.cos(5.31334628497 + 207643.84320240439*t)
	Y1 += 0.00000000009*np.cos(5.82248345678 + 152.7445908723*t)
	Y1 += 0.00000000012*np.cos(4.98783133373 + 26395.46076254379*t)
	Y1 += 0.00000000012*np.cos(3.81738635107 + 25780.3455206046*t)
	Y1 += 0.00000000009*np.cos(3.76555090929 + 212.5483359126*t)
	Y1 += 0.00000000012*np.cos(2.61068546931 + 26724.8994135984*t)
	Y1 += 0.00000000012*np.cos(6.19453221549 + 25450.90686955*t)
	Y1 += 0.00000000009*np.cos(4.05684885963 + 51219.51712717779*t)
	Y1 += 0.00000000009*np.cos(6.12208983529 + 155571.81910783658*t)
	Y1 += 0.00000000009*np.cos(0.52740652256 + 177.8743727859*t)
	Y1 += 0.00000000009*np.cos(0.41261244956 + 78731.674415077*t)
	Y1 += 0.00000000009*np.cos(3.37901002476 + 275.5505210331*t)
	Y1 += 0.00000000012*np.cos(0.71134314907 + 25446.4895798352*t)
	Y1 += 0.00000000012*np.cos(1.81068922855 + 26729.31670331319*t)
	Y1 += 0.00000000009*np.cos(6.22383357370 + 140.001969579*t)
	Y1 += 0.00000000010*np.cos(2.47468110683 + 65831.6667743248*t)
	Y1 += 0.00000000009*np.cos(0.40952403441 + 16703.062133499*t)
	Y1 += 0.00000000010*np.cos(0.04924916522 + 604.4725636619*t)
	Y1 += 0.00000000009*np.cos(0.89636070253 + 112.9146342051*t)
	Y1 += 0.00000000009*np.cos(4.90697568305 + 51707.84129279399*t)
	Y1 += 0.00000000009*np.cos(3.85732708279 + 207593.84658050018*t)
	Y1 += 0.00000000010*np.cos(5.90599957866 + 33.9402499438*t)
	Y1 += 0.00000000009*np.cos(4.96561807224 + 156100.82065856918*t)
	Y1 += 0.00000000010*np.cos(5.00030882649 + 319.5732633943*t)
	Y1 += 0.00000000010*np.cos(5.60951690643 + 69.1525242748*t)
	Y1 += 0.00000000011*np.cos(2.14229269933 + 2015.6710861598*t)
	Y1 += 0.00000000009*np.cos(3.75776745639 + 1911.1994832172*t)
	Y1 += 0.00000000012*np.cos(3.62719609541 + 842.1506814881*t)
	Y1 += 0.00000000012*np.cos(4.51598356731 + 176953.98994186718*t)
	Y1 += 0.00000000011*np.cos(3.03748956531 + 12725.453434775*t)
	Y1 += 0.00000000010*np.cos(3.83093061667 + 1592.2542890215*t)
	Y1 += 0.00000000010*np.cos(2.06240666657 + 373.9079928365*t)
	Y1 += 0.00000000009*np.cos(0.04073004429 + 52609.51802102519*t)
	Y1 += 0.00000000009*np.cos(1.91710703544 + 55516.4187098482*t)
	Y1 += 0.00000000010*np.cos(0.81972980160 + 52022.0274726636*t)
	Y1 += 0.00000000008*np.cos(4.36451680511 + 52182.4348420484*t)
	Y1 += 0.00000000011*np.cos(1.79573927984 + 157057.10981453978*t)
	Y1 += 0.00000000010*np.cos(0.38285944104 + 52381.99183158559*t)
	Y1 += 0.00000000008*np.cos(4.10335886056 + 1148.2476104062*t)
	Y1 += 0.00000000009*np.cos(0.42800870352 + 561.934294009*t)
	Y1 += 0.00000000009*np.cos(4.83864149352 + 19.66976089979*t)
	Y1 += 0.00000000008*np.cos(0.94852393070 + 32.1951448046*t)
	Y1 += 0.00000000008*np.cos(4.13055580345 + 1585.1407420207*t)
	Y1 += 0.00000000008*np.cos(2.55201196235 + 81.7521332162*t)
	Y1 += 0.00000000008*np.cos(4.79233550623 + 27177.6119327678*t)
	Y1 += 0.00000000008*np.cos(4.01288217857 + 24998.19435038059*t)
	Y1 += 0.00000000008*np.cos(3.03880062155 + 629.6023455755*t)
	Y1 += 0.00000000008*np.cos(1.18973384884 + 248.7238180901*t)
	Y1 += 0.00000000008*np.cos(2.85801662646 + 26720.68688088739*t)
	Y1 += 0.00000000008*np.cos(4.45302946532 + 5.9378908332*t)
	Y1 += 0.00000000009*np.cos(4.79269618550 + 414.0680179038*t)
	Y1 += 0.00000000010*np.cos(2.61596011042 + 436.1594184316*t)
	Y1 += 0.00000000008*np.cos(0.94778655827 + 214.7835681463*t)
	Y1 += 0.00000000010*np.cos(1.31103197356 + 454.9093665273*t)
	Y1 += 0.00000000008*np.cos(4.56240457496 + 48847.6706268682*t)
	Y1 += 0.00000000008*np.cos(4.61033798635 + 42.3258213318*t)
	Y1 += 0.00000000008*np.cos(2.75059975447 + 98.8999885246*t)
	Y1 += 0.00000000010*np.cos(1.02582111721 + 297.6419215609*t)
	Y1 += 0.00000000008*np.cos(0.38701534981 + 13541.42120249119*t)
	Y1 += 0.00000000009*np.cos(5.65248521015 + 621.7380390493*t)
	Y1 += 0.00000000008*np.cos(0.64686923791 + 159.1244246902*t)
	Y1 += 0.00000000007*np.cos(4.05705631944 + 576.1613880106*t)
	Y1 += 0.00000000008*np.cos(4.10511816483 + 1223.81784077861*t)
	Y1 += 0.00000000008*np.cos(3.92242352986 + 2001.4439921582*t)
	Y1 += 0.00000000007*np.cos(0.36409349149 + 68241.87214462319*t)
	Y1 += 0.00000000007*np.cos(0.25912882540 + 320.3240229197*t)
	Y1 += 0.00000000008*np.cos(1.38258172759 + 52595.29092702359*t)
	Y1 += 0.00000000008*np.cos(0.52005477263 + 130446.62925487179*t)
	Y1 += 0.00000000007*np.cos(1.77349206529 + 50696.93970908399*t)
	Y1 += 0.00000000008*np.cos(1.14800859952 + 355.7487455718*t)
	Y1 += 0.00000000007*np.cos(2.15288626818 + 30.0562807905*t)
	Y1 += 0.00000000007*np.cos(6.13248181563 + 427.5613987225*t)
	Y1 += 0.00000000009*np.cos(1.66361806448 + 130443.39704322898*t)
	Y1 += 0.00000000007*np.cos(3.90217030714 + 2228.9701815978*t)
	Y1 += 0.00000000007*np.cos(5.21901491319 + 2655.5683724738*t)
	Y1 += 0.00000000007*np.cos(0.73615049600 + 209812.60368468695*t)
	Y1 += 0.00000000009*np.cos(1.23134600870 + 52169.17772424839*t)
	Y1 += 0.00000000007*np.cos(2.07118222069 + 172402.03644480839*t)
	Y1 += 0.00000000008*np.cos(0.79426105202 + 327.4375699205*t)
	Y1 += 0.00000000007*np.cos(4.59822415945 + 278.5194664497*t)
	Y1 += 0.00000000008*np.cos(5.63930068564 + 458.8415197904*t)
	Y1 += 0.00000000007*np.cos(0.43203382811 + 528.9402055692*t)
	Y1 += 0.00000000007*np.cos(0.76705916667 + 530.44172462*t)
	Y1 += 0.00000000008*np.cos(4.46099447090 + 1585.8915015461*t)
	Y1 += 0.00000000007*np.cos(1.93763204899 + 35472.7441496494*t)
	Y1 += 0.00000000007*np.cos(1.48249068512 + 27044.1922975448*t)
	Y1 += 0.00000000009*np.cos(2.20436298259 + 31.019488637*t)
	Y1 += 0.00000000007*np.cos(0.42254434487 + 150244.34299945379*t)
	Y1 += 0.00000000009*np.cos(2.36048752326 + 26734.913974889*t)
	Y1 += 0.00000000007*np.cos(3.18648827109 + 52325.36948028299*t)
	Y1 += 0.00000000007*np.cos(2.71750635954 + 1158.5425511447*t)
	Y1 += 0.00000000007*np.cos(2.24046065624 + 9384.8410080752*t)
	Y1 += 0.00000000007*np.cos(5.25570024840 + 20.6069278195*t)
	Y1 += 0.00000000007*np.cos(3.81340646490 + 80596.9058175946*t)
	Y1 += 0.00000000007*np.cos(2.40405222005 + 425.6349830295*t)
	Y1 += 0.00000000006*np.cos(2.21280392322 + 52278.89905736699*t)
	Y1 += 0.00000000007*np.cos(3.50836604374 + 431.264057322*t)
	Y1 += 0.00000000008*np.cos(2.16932671663 + 129387.24732468258*t)
	Y1 += 0.00000000008*np.cos(1.13965005489 + 25234.70675982219*t)
	Y1 += 0.00000000008*np.cos(6.21586114247 + 77726.90491262719*t)
	Y1 += 0.00000000007*np.cos(1.75300700374 + 953.1077622329*t)
	Y1 += 0.00000000006*np.cos(5.71782638960 + 79330.20490191258*t)
	Y1 += 0.00000000006*np.cos(0.33314344280 + 1048.3362299253*t)
	Y1 += 0.00000000007*np.cos(3.99442191803 + 78378.14871340781*t)
	Y1 += 0.00000000006*np.cos(4.54559452887 + 601.7642506762*t)
	Y1 += 0.00000000006*np.cos(2.89252113944 + 69.3649725959*t)
	Y1 += 0.00000000007*np.cos(4.76015023992 + 558.0021407459*t)
	Y1 += 0.00000000008*np.cos(3.66343793703 + 228.276948965*t)
	Y1 += 0.00000000006*np.cos(2.63385868818 + 129373.02023068098*t)
	Y1 += 0.00000000007*np.cos(0.06529608191 + 26162.6847401415*t)
	Y1 += 0.00000000007*np.cos(4.41204133594 + 221.3758502853*t)
	Y1 += 0.00000000006*np.cos(2.40738361691 + 1165.6560981455*t)
	Y1 += 0.00000000006*np.cos(0.01573246447 + 8.0767548473*t)
	Y1 += 0.00000000006*np.cos(1.55390090257 + 51013.33157874059*t)
	Y1 += 0.00000000006*np.cos(3.29219308990 + 75615.25459924959*t)
	Y1 += 0.00000000007*np.cos(5.23140732853 + 157483.01859105378*t)
	Y1 += 0.00000000006*np.cos(1.96764604578 + 295.0512286542*t)
	Y1 += 0.00000000006*np.cos(2.46763974875 + 26013.1215430069*t)
	Y1 += 0.00000000007*np.cos(1.96227011480 + 45.2465826386*t)
	Y1 += 0.00000000006*np.cos(6.03059495880 + 137678.19129947099*t)
	Y1 += 0.00000000006*np.cos(0.15099417807 + 241.7532834412*t)
	Y1 += 0.00000000006*np.cos(2.93834812676 + 130652.81480330898*t)
	Y1 += 0.00000000006*np.cos(0.41129479661 + 313.2104759189*t)
	Y1 += 0.00000000007*np.cos(6.14935848430 + 77630.92568540938*t)
	Y1 += 0.00000000006*np.cos(3.95802571920 + 1159.2933106701*t)
	Y1 += 0.00000000006*np.cos(4.96304042103 + 25508.2155545754*t)
	Y1 += 0.00000000006*np.cos(3.84217726377 + 26667.590728573*t)
	Y1 += 0.00000000006*np.cos(4.49803481526 + 186.2117600641*t)
	Y1 += 0.00000000006*np.cos(0.29225742955 + 6885.14988993081*t)
	Y1 += 0.00000000006*np.cos(5.79072032919 + 983.1158589136*t)
	Y1 += 0.00000000006*np.cos(6.01412605038 + 128.9562693151*t)
	Y1 += 0.00000000006*np.cos(2.18079162130 + 103917.90082841998*t)
	Y1 += 0.00000000008*np.cos(5.64484638063 + 157586.80077963437*t)
	Y1 += 0.00000000007*np.cos(2.79563557161 + 421.93232443*t)
	Y1 += 0.00000000006*np.cos(4.16879920974 + 80382.47328510099*t)
	Y1 += 0.00000000006*np.cos(0.66117422106 + 34282.1784747828*t)
	Y1 += 0.00000000006*np.cos(2.07270670843 + 23.5758732361*t)
	Y1 += 0.00000000007*np.cos(3.20892469724 + 214364.55718174578*t)
	Y1 += 0.00000000007*np.cos(2.79508447590 + 25754.0472008048*t)
	Y1 += 0.00000000007*np.cos(6.01013320890 + 26421.7590823436*t)
	Y1 += 0.00000000007*np.cos(6.04497108744 + 230.7075831773*t)
	Y1 += 0.00000000006*np.cos(4.43814061291 + 78149.27013603736*t)
	Y1 += 0.00000000005*np.cos(5.60856067263 + 50064.15596977079*t)
	Y1 += 0.00000000006*np.cos(0.51992227470 + 80.7194894005*t)
	Y1 += 0.00000000006*np.cos(1.06133168572 + 128220.75860368418*t)
	Y1 += 0.00000000005*np.cos(3.16289590584 + 387.2413149608*t)
	Y1 += 0.00000000007*np.cos(3.26944287136 + 6283.0758499914*t)
	Y1 += 0.00000000006*np.cos(1.37475809876 + 2538.2485042536*t)
	Y1 += 0.00000000006*np.cos(2.72954939538 + 426.6463749858*t)
	Y1 += 0.00000000006*np.cos(3.54269187319 + 494.2662424425*t)
	Y1 += 0.00000000005*np.cos(4.48886015660 + 130226.21661243298*t)
	Y1 += 0.00000000006*np.cos(0.16815043613 + 421.1815649046*t)
	Y1 += 0.00000000005*np.cos(1.19100214631 + 92.0470739547*t)
	Y1 += 0.00000000005*np.cos(4.53664008849 + 1251.3403846248*t)
	Y1 += 0.00000000006*np.cos(4.78075047395 + 123668.80510662538*t)
	Y1 += 0.00000000006*np.cos(2.73998495017 + 68.5618234438*t)
	Y1 += 0.00000000005*np.cos(3.64390526925 + 1166.4068576709*t)
	Y1 += 0.00000000006*np.cos(1.55322241284 + 35.212274331*t)
	Y1 += 0.00000000005*np.cos(1.80435428469 + 1041.2226829245*t)
	Y1 += 0.00000000006*np.cos(5.50205577201 + 89.7594520943*t)
	Y1 += 0.00000000005*np.cos(3.38712516669 + 44.070926471*t)
	Y1 += 0.00000000006*np.cos(3.05256935232 + 188.9200730498*t)
	Y1 += 0.00000000005*np.cos(5.89140407331 + 102769.65321801379*t)
	Y1 += 0.00000000006*np.cos(4.23283059947 + 1891.2376709388*t)
	Y1 += 0.00000000005*np.cos(2.50213086189 + 19406.6782881746*t)
	Y1 += 0.00000000006*np.cos(1.60825783072 + 103932.12792242158*t)
	Y1 += 0.00000000006*np.cos(0.24754368045 + 161079.37234650398*t)
	Y1 += 0.00000000005*np.cos(2.18932379818 + 46.2097904851*t)
	Y1 += 0.00000000006*np.cos(3.54848918635 + 86143.79857806159*t)
	Y1 += 0.00000000005*np.cos(4.46609874857 + 162.0933701068*t)
	Y1 += 0.00000000005*np.cos(0.66097382878 + 205.4347889118*t)
	Y1 += 0.00000000007*np.cos(5.68676720253 + 64901.25971792339*t)
	Y1 += 0.00000000005*np.cos(5.21179771886 + 1593.0050485469*t)
	Y1 += 0.00000000006*np.cos(6.23379482805 + 5.4166259714*t)
	Y1 += 0.00000000005*np.cos(5.11989980868 + 78213.71280281838*t)
	Y1 += 0.00000000006*np.cos(5.18848518823 + 182085.63102592478*t)
	Y1 += 0.00000000006*np.cos(0.59952467665 + 51653.22886505459*t)
	Y1 += 0.00000000005*np.cos(5.44401843923 + 102755.42612401219*t)
	Y1 += 0.00000000005*np.cos(6.03346324760 + 505.3119427064*t)
	Y1 += 0.00000000006*np.cos(1.15772089340 + 8194.2753332086*t)
	Y1 += 0.00000000005*np.cos(2.17367426894 + 916.9322800554*t)
	Y1 += 0.00000000005*np.cos(0.64013502451 + 29.2049475286*t)
	Y1 += 0.00000000005*np.cos(3.51363623564 + 1080.7225711916*t)
	Y1 += 0.00000000005*np.cos(4.97953496675 + 14.0146456805*t)
	Y1 += 0.00000000005*np.cos(0.51698818497 + 88.7962442478*t)
	Y1 += 0.00000000005*np.cos(4.08794365187 + 154.0166152595*t)
	Y1 += 0.00000000005*np.cos(2.79015937613 + 41.0537969446*t)
	Y1 += 0.00000000005*np.cos(5.87885246993 + 439.1283638482*t)
	Y1 += 0.00000000005*np.cos(0.85038224536 + 53399.624123927*t)
	Y1 += 0.00000000005*np.cos(2.42671724536 + 27780.06881107659*t)
	Y1 += 0.00000000006*np.cos(2.51299128730 + 347.8844390456*t)
	Y1 += 0.00000000005*np.cos(5.22476504934 + 26402.0893214438*t)
	Y1 += 0.00000000005*np.cos(3.58045263546 + 25773.71696170459*t)
	Y1 += 0.00000000005*np.cos(2.42996301937 + 25938.3399444396*t)
	Y1 += 0.00000000005*np.cos(0.01470040312 + 77616.69859140778*t)
	Y1 += 0.00000000006*np.cos(4.89665330264 + 512.2824773553*t)
	Y1 += 0.00000000005*np.cos(3.49486880744 + 778.4147831847*t)
	Y1 += 0.00000000006*np.cos(4.89504933760 + 50049.92887576919*t)
	Y1 += 0.00000000006*np.cos(1.89186725600 + 2751.5475996916*t)
	Y1 += 0.00000000005*np.cos(1.40593163243 + 134.5853436076*t)
	Y1 += 0.00000000005*np.cos(1.99586214710 + 17893.6278083656*t)
	Y1 += 0.00000000005*np.cos(4.97045994829 + 237.6781178262*t)
	Y1 += 0.00000000004*np.cos(6.00566134496 + 167850.08294774959*t)
	Y1 += 0.00000000006*np.cos(5.77707621428 + 154938.34595416138*t)
	Y1 += 0.00000000004*np.cos(4.40910062645 + 672.1406152284*t)
	Y1 += 0.00000000005*np.cos(4.30539423988 + 50.4025761791*t)
	Y1 += 0.00000000004*np.cos(5.19254582564 + 312.4597163935*t)
	Y1 += 0.00000000005*np.cos(3.26128860166 + 1069.6768709277*t)
	Y1 += 0.00000000004*np.cos(0.97602564752 + 130432.40216087017*t)
	Y1 += 0.00000000004*np.cos(0.40741730958 + 51852.30086649099*t)
	Y1 += 0.00000000006*np.cos(3.60171276442 + 696.5196376166*t)
	Y1 += 0.00000000005*np.cos(3.45043381496 + 498.6714764576*t)
	Y1 += 0.00000000005*np.cos(1.35488481256 + 204151.27163553478*t)
	Y1 += 0.00000000006*np.cos(5.81420130998 + 426.5500067662*t)
	Y1 += 0.00000000004*np.cos(3.67345614971 + 636.9962720242*t)
	Y1 += 0.00000000004*np.cos(2.74223078461 + 116783.65521669458*t)
	Y1 += 0.00000000004*np.cos(4.24223135959 + 68.8437077341*t)
	Y1 += 0.00000000005*np.cos(1.92308153633 + 945.9942152321*t)
	Y1 += 0.00000000005*np.cos(2.74366605427 + 39450.3528483734*t)
	Y1 += 0.00000000005*np.cos(4.39801286539 + 54.1746707478*t)
	Y1 += 0.00000000004*np.cos(1.23165526523 + 51955.39364070959*t)
	Y1 += 0.00000000004*np.cos(4.09127907081 + 103498.41618454478*t)
	Y1 += 0.00000000004*np.cos(5.10290768552 + 33.1371007917*t)
	Y1 += 0.00000000004*np.cos(3.11218759329 + 710.7467316182*t)
	Y1 += 0.00000000004*np.cos(2.37045324906 + 45290.65639321759*t)
	Y1 += 0.00000000005*np.cos(0.06895267430 + 52396.2189255872*t)
	Y1 += 0.00000000004*np.cos(2.51922309877 + 679.2541622292*t)
	Y1 += 0.00000000005*np.cos(5.14267536259 + 300.6108669775*t)
	Y1 += 0.00000000004*np.cos(2.56354623790 + 104505.39137678158*t)
	Y1 += 0.00000000005*np.cos(5.71032452100 + 123200.84011627098*t)
	Y1 += 0.00000000005*np.cos(4.03184405759 + 560.7104537316*t)
	Y1 += 0.00000000004*np.cos(0.59460014711 + 28791.5192962498*t)
	Y1 += 0.00000000004*np.cos(1.92743223051 + 23384.2869868986*t)
	Y1 += 0.00000000005*np.cos(4.52669072840 + 53029.0026649004*t)
	Y1 += 0.00000000005*np.cos(4.52503825820 + 305.3461693927*t)
	Y1 += 0.00000000004*np.cos(4.74372430470 + 1070.4276304531*t)
	Y1 += 0.00000000004*np.cos(0.63523381995 + 152.0108776894*t)
	Y1 += 0.00000000004*np.cos(1.81268637965 + 26823.77965510599*t)
	Y1 += 0.00000000004*np.cos(0.70934599797 + 25352.02662804239*t)
	Y1 += 0.00000000004*np.cos(3.53975344268 + 133882.09065283638*t)
	Y1 += 0.00000000005*np.cos(1.80112800270 + 600.5404103988*t)
	Y1 += 0.00000000004*np.cos(4.57704452507 + 849.2642284889*t)
	Y1 += 0.00000000004*np.cos(3.01935498774 + 50483.640613646*t)
	Y1 += 0.00000000004*np.cos(1.91608807989 + 81.0013736908*t)
	Y1 += 0.00000000004*np.cos(2.01334717451 + 183570.92173262799*t)
	Y1 += 0.00000000004*np.cos(3.22384434044 + 53771.99272543299*t)
	Y1 += 0.00000000004*np.cos(3.39351596474 + 746.9222137957*t)
	Y1 += 0.00000000004*np.cos(5.13064710784 + 611.4430983108*t)
	Y1 += 0.00000000005*np.cos(0.54073458961 + 182.279606801*t)
	Y1 += 0.00000000005*np.cos(5.28711139263 + 145204.75475114079*t)
	Y1 += 0.00000000004*np.cos(1.34862695530 + 27170.98337386779*t)
	Y1 += 0.00000000004*np.cos(1.17340542232 + 25004.8229092806*t)
	Y1 += 0.00000000004*np.cos(4.13404557998 + 757.2171545342*t)
	Y1 += 0.00000000004*np.cos(2.62733309764 + 312.1990839626*t)
	Y1 += 0.00000000004*np.cos(0.14217969958 + 78786.28684281638*t)
	Y1 += 0.00000000004*np.cos(4.12169541877 + 2317.8358618148*t)
	Y1 += 0.00000000004*np.cos(0.47183936992 + 2324.9494088156*t)
	Y1 += 0.00000000005*np.cos(1.84426394169 + 26709.6469424134*t)
	Y1 += 0.00000000005*np.cos(0.67776843593 + 25466.159340735*t)
	Y1 += 0.00000000005*np.cos(3.75152504592 + 835.0371344873*t)
	Y1 += 0.00000000005*np.cos(1.25657099336 + 32132.1317229496*t)
	Y1 += 0.00000000004*np.cos(4.27093115110 + 52065.59996192899*t)
	Y1 += 0.00000000004*np.cos(0.19646748056 + 196.0336200506*t)
	Y1 += 0.00000000004*np.cos(3.22264415537 + 739.8086667949*t)
	Y1 += 0.00000000004*np.cos(1.51249981586 + 166.828672522*t)
	Y1 += 0.00000000005*np.cos(4.16544589772 + 32.2433289144*t)
	Y1 += 0.00000000004*np.cos(3.16847102979 + 970.5162499722*t)
	Y1 += 0.00000000004*np.cos(1.11438053331 + 78270.33798362259*t)
	Y1 += 0.00000000004*np.cos(1.22637241875 + 1064.0477966352*t)
	Y1 += 0.00000000004*np.cos(1.25167189753 + 221.1634019642*t)
	Y1 += 0.00000000004*np.cos(0.47247654290 + 952.3570027075*t)
	Y1 += 0.00000000004*np.cos(2.21736054801 + 96357.08412427259*t)
	Y1 += 0.00000000005*np.cos(2.88741075556 + 432.2272651685*t)
	Y1 += 0.00000000004*np.cos(1.34025094893 + 6044.2285813754*t)
	Y1 += 0.00000000004*np.cos(0.61099360580 + 429.5189521828*t)
	Y1 += 0.00000000004*np.cos(4.90309780700 + 143005.66740785378*t)
	Y1 += 0.00000000004*np.cos(1.70672949321 + 78800.51393681798*t)
	Y1 += 0.00000000004*np.cos(0.90136038469 + 132658.27281205778*t)
	Y1 += 0.00000000004*np.cos(6.04765404465 + 54087.0057663656*t)
	Y1 += 0.00000000003*np.cos(5.07832575262 + 661.2379273164*t)
	Y1 += 0.00000000004*np.cos(6.09425485756 + 381.3516082374*t)
	Y1 += 0.00000000004*np.cos(5.63426885292 + 395.578702239*t)
	Y1 += 0.00000000003*np.cos(0.93359542515 + 227.3137411185*t)
	Y1 += 0.00000000004*np.cos(3.45396433025 + 130459.18546877075*t)
	Y1 += 0.00000000004*np.cos(4.89804621575 + 1677.9385755008*t)
	Y1 += 0.00000000004*np.cos(3.39420749098 + 52250.5878817157*t)
	Y1 += 0.00000000004*np.cos(2.89280023626 + 87367.61641884019*t)
	Y1 += 0.00000000003*np.cos(2.73132197327 + 78160.61665050399*t)
	Y1 += 0.00000000003*np.cos(1.67414862418 + 230.5645708254*t)
	Y1 += 0.00000000003*np.cos(4.14416998165 + 114.43928868521*t)
	Y1 += 0.00000000003*np.cos(0.61597689295 + 554.8207470082*t)
	Y1 += 0.00000000004*np.cos(0.15780189015 + 130435.63437251298*t)
	Y1 += 0.00000000004*np.cos(0.06711300408 + 26575.53789282839*t)
	Y1 += 0.00000000004*np.cos(2.45491937354 + 25600.26839032*t)
	return Y1*t




def Mercury_Y2 (t): # 478 terms of order 2

	Y2 = 0.
	Y2 += 0.00004556343
	Y2 += 0.00001575670*np.cos(2.81172733349 + 52175.8062831484*t)
	Y2 += 0.00000927896*np.cos(5.85368769122 + 78263.70942472259*t)
	Y2 += 0.00000670255*np.cos(0.90964509090 + 26087.9031415742*t)
	Y2 += 0.00000373744*np.cos(2.62279275699 + 104351.61256629678*t)
	Y2 += 0.00000160849*np.cos(2.83104666823 + 206.1855484372*t)
	Y2 += 0.00000155973*np.cos(5.19309730583 + 220.4126424388*t)
	Y2 += 0.00000131389*np.cos(5.67519052208 + 130439.51570787099*t)
	Y2 += 0.00000118316*np.cos(5.70681506981 + 522.5774180938*t)
	Y2 += 0.00000115781*np.cos(1.78259431361 + 536.8045120954*t)
	Y2 += 0.00000103379*np.cos(4.03676510280 + 213.299095438*t)
	Y2 += 0.00000065396*np.cos(4.05849415864 + 426.598190876*t)
	Y2 += 0.00000073067*np.cos(0.61703763627 + 529.6909650946*t)
	Y2 += 0.00000043188*np.cos(2.44402631830 + 156527.41884944518*t)
	Y2 += 0.00000039392*np.cos(0.40700037789 + 1059.3819301892*t)
	Y2 += 0.00000014254*np.cos(4.25680464915 + 433.7117378768*t)
	Y2 += 0.00000014479*np.cos(0.14336346755 + 7.1135470008*t)
	Y2 += 0.00000013650*np.cos(5.49573569359 + 182615.32199101939*t)
	Y2 += 0.00000012723*np.cos(1.91903810105 + 419.4846438752*t)
	Y2 += 0.00000009385*np.cos(3.14715736590 + 639.897286314*t)
	Y2 += 0.00000007720*np.cos(5.06798604557 + 227.5261894396*t)
	Y2 += 0.00000006795*np.cos(2.30303656447 + 1066.49547719*t)
	Y2 += 0.00000005452*np.cos(5.20193437243 + 1052.2683831884*t)
	Y2 += 0.00000005040*np.cos(5.84239832938 + 515.463871093*t)
	Y2 += 0.00000003901*np.cos(0.82763757344 + 1589.0728952838*t)
	Y2 += 0.00000003729*np.cos(2.96611895542 + 199.0720014364*t)
	Y2 += 0.00000003521*np.cos(1.65043749771 + 543.9180590962*t)
	Y2 += 0.00000004206*np.cos(2.26403437926 + 208703.22513259358*t)
	Y2 += 0.00000002984*np.cos(6.06067837128 + 24978.5245894808*t)
	Y2 += 0.00000002686*np.cos(2.76365562250 + 27197.2816936676*t)
	Y2 += 0.00000001351*np.cos(0.59351678849 + 316.3918696566*t)
	Y2 += 0.00000001409*np.cos(4.65471130275 + 216.4804891757*t)
	Y2 += 0.00000001321*np.cos(3.39383854482 + 647.0108333148*t)
	Y2 += 0.00000001368*np.cos(3.38543777835 + 210.1177017003*t)
	Y2 += 0.00000001717*np.cos(0.02861328541 + 14.2270940016*t)
	Y2 += 0.00000001274*np.cos(5.31539852523 + 234791.12827416777*t)
	Y2 += 0.00000001027*np.cos(2.84300614786 + 51066.427731055*t)
	Y2 += 0.00000000988*np.cos(2.45506323491 + 853.196381752*t)
	Y2 += 0.00000000950*np.cos(2.81842708673 + 632.7837393132*t)
	Y2 += 0.00000000848*np.cos(6.23917434526 + 526.5095713569*t)
	Y2 += 0.00000000806*np.cos(2.96434145307 + 103.0927742186*t)
	Y2 += 0.00000000825*np.cos(1.24361863355 + 532.8723588323*t)
	Y2 += 0.00000000761*np.cos(4.73161044526 + 209.3669421749*t)
	Y2 += 0.00000000733*np.cos(3.30972792259 + 217.2312487011*t)
	Y2 += 0.00000000885*np.cos(0.58376168802 + 110.2063212194*t)
	Y2 += 0.00000000689*np.cos(4.21955395780 + 440.8252848776*t)
	Y2 += 0.00000000631*np.cos(5.67308971270 + 117.3198682202*t)
	Y2 += 0.00000000600*np.cos(3.56706010534 + 323.5054166574*t)
	Y2 += 0.00000000549*np.cos(3.24495575230 + 949.1756089698*t)
	Y2 += 0.00000000606*np.cos(3.86357846284 + 95.9792272178*t)
	Y2 += 0.00000000726*np.cos(5.43722942949 + 74.7815985673*t)
	Y2 += 0.00000000545*np.cos(4.73162468373 + 1045.1548361876*t)
	Y2 += 0.00000000599*np.cos(4.43359462367 + 735.8765135318*t)
	Y2 += 0.00000000490*np.cos(1.25898273127 + 525.7588118315*t)
	Y2 += 0.00000000488*np.cos(6.22654201321 + 533.6231183577*t)
	Y2 += 0.00000000437*np.cos(2.81553406247 + 1596.1864422846*t)
	Y2 += 0.00000000519*np.cos(4.53503189245 + 149.5631971346*t)
	Y2 += 0.00000000381*np.cos(2.08333719811 + 260879.03141574195*t)
	Y2 += 0.00000000352*np.cos(5.82507812341 + 53285.1848352418*t)
	Y2 += 0.00000000335*np.cos(3.37537319389 + 1109.3785520934*t)
	Y2 += 0.00000000337*np.cos(1.19361584892 + 2118.7638603784*t)
	Y2 += 0.00000000356*np.cos(5.90144515856 + 77154.33087262919*t)
	Y2 += 0.00000000349*np.cos(4.12933332026 + 63.7358983034*t)
	Y2 += 0.00000000337*np.cos(1.63942541135 + 412.3710968744*t)
	Y2 += 0.00000000270*np.cos(5.28007746957 + 1581.959348283*t)
	Y2 += 0.00000000260*np.cos(4.50952770985 + 625.6701923124*t)
	Y2 += 0.00000000237*np.cos(0.07292901465 + 70.8494453042*t)
	Y2 += 0.00000000227*np.cos(4.92862031663 + 234.6397364404*t)
	Y2 += 0.00000000219*np.cos(5.43349299793 + 11.0457002639*t)
	Y2 += 0.00000000256*np.cos(5.25900695618 + 956.2891559706*t)
	Y2 += 0.00000000218*np.cos(4.61617873387 + 78.7137518304*t)
	Y2 += 0.00000000283*np.cos(0.60090092021 + 85.8272988312*t)
	Y2 += 0.00000000211*np.cos(3.29348428114 + 942.062061969*t)
	Y2 += 0.00000000226*np.cos(3.69462756239 + 73.297125859*t)
	Y2 += 0.00000000235*np.cos(0.31453942563 + 36.6485629295*t)
	Y2 += 0.00000000213*np.cos(2.54349021425 + 309.2783226558*t)
	Y2 += 0.00000000224*np.cos(4.02383631251 + 39.6175083461*t)
	Y2 += 0.00000000231*np.cos(2.66318410477 + 202.2533951741*t)
	Y2 += 0.00000000197*np.cos(2.58901447921 + 25132.3033999656*t)
	Y2 += 0.00000000187*np.cos(1.29115653830 + 1169.5882514086*t)
	Y2 += 0.00000000167*np.cos(2.07259165182 + 1073.6090241908*t)
	Y2 += 0.00000000196*np.cos(5.64541899687 + 224.3447957019*t)
	Y2 += 0.00000000174*np.cos(6.19970518794 + 27043.5028831828*t)
	Y2 += 0.00000000158*np.cos(5.13689612572 + 1155.361157407*t)
	Y2 += 0.00000000137*np.cos(0.50600690701 + 742.9900605326*t)
	Y2 += 0.00000000135*np.cos(5.63458486706 + 138.5174968707*t)
	Y2 += 0.00000000148*np.cos(1.53909219281 + 76.2660712756*t)
	Y2 += 0.00000000138*np.cos(0.32050955420 + 21535.9496445154*t)
	Y2 += 0.00000000133*np.cos(6.00639174435 + 508.3503240922*t)
	Y2 += 0.00000000150*np.cos(3.46698256017 + 20426.571092422*t)
	Y2 += 0.00000000126*np.cos(3.76226961231 + 330.6189636582*t)
	Y2 += 0.00000000126*np.cos(2.61435997717 + 860.3099287528*t)
	Y2 += 0.00000000125*np.cos(4.32480488747 + 26617.5941066688*t)
	Y2 += 0.00000000117*np.cos(4.51608581878 + 25558.2121764796*t)
	Y2 += 0.00000000119*np.cos(0.26940576275 + 46514.4742339962*t)
	Y2 += 0.00000000158*np.cos(2.17797348306 + 38.1330356378*t)
	Y2 += 0.00000000113*np.cos(5.13479506099 + 286966.93455731616*t)
	Y2 += 0.00000000108*np.cos(1.00337547207 + 14765.2390432698*t)
	Y2 += 0.00000000126*np.cos(6.14682046798 + 23869.1460373874*t)
	Y2 += 0.00000000106*np.cos(1.37019536118 + 27147.28507176339*t)
	Y2 += 0.00000000115*np.cos(4.52412782775 + 223.5940361765*t)
	Y2 += 0.00000000110*np.cos(4.93056089704 + 71.6002048296*t)
	Y2 += 0.00000000115*np.cos(3.76754615650 + 429.7795846137*t)
	Y2 += 0.00000000106*np.cos(6.02834271847 + 77.962992305*t)
	Y2 += 0.00000000123*np.cos(4.57966985938 + 728.762966531*t)
	Y2 += 0.00000000121*np.cos(2.67342689025 + 103242.23401420339*t)
	Y2 += 0.00000000107*np.cos(2.67501768515 + 28306.66024576099*t)
	Y2 += 0.00000000105*np.cos(6.21526366678 + 1162.4747044078*t)
	Y2 += 0.00000000102*np.cos(3.63292130858 + 422.6660376129*t)
	Y2 += 0.00000000103*np.cos(5.45719542646 + 31749.2351907264*t)
	Y2 += 0.00000000086*np.cos(3.58192012664 + 19317.1925403286*t)
	Y2 += 0.00000000084*np.cos(4.77208861984 + 124.433415221*t)
	Y2 += 0.00000000095*np.cos(2.17047827218 + 4551.9534970588*t)
	Y2 += 0.00000000074*np.cos(4.08123538694 + 88.865680217*t)
	Y2 += 0.00000000076*np.cos(2.63432357020 + 423.4167971383*t)
	Y2 += 0.00000000073*np.cos(5.78330657332 + 1265.5674786264*t)
	Y2 += 0.00000000071*np.cos(1.48891806144 + 551.031606097*t)
	Y2 += 0.00000000081*np.cos(0.13371582190 + 519.3960243561*t)
	Y2 += 0.00000000068*np.cos(3.39472444791 + 654.1243803156*t)
	Y2 += 0.00000000067*np.cos(4.81636058177 + 9103.9069941176*t)
	Y2 += 0.00000000077*np.cos(0.22294716973 + 22645.32819660879*t)
	Y2 += 0.00000000066*np.cos(2.34654801419 + 3442.5749449654*t)
	Y2 += 0.00000000072*np.cos(6.15951862716 + 21.3406410024*t)
	Y2 += 0.00000000060*np.cos(3.13717737901 + 191.9584544356*t)
	Y2 += 0.00000000059*np.cos(3.32463299177 + 72602.37737557039*t)
	Y2 += 0.00000000060*np.cos(2.26631911660 + 30639.856638633*t)
	Y2 += 0.00000000059*np.cos(2.98425907470 + 50586.73338786459*t)
	Y2 += 0.00000000060*np.cos(0.99475775846 + 52705.49724824299*t)
	Y2 += 0.00000000059*np.cos(1.55381311926 + 37410.5672398786*t)
	Y2 += 0.00000000066*np.cos(5.36962395931 + 51220.20654153979*t)
	Y2 += 0.00000000065*np.cos(3.55971117777 + 203.0041546995*t)
	Y2 += 0.00000000058*np.cos(5.26315302410 + 32858.61374281979*t)
	Y2 += 0.00000000064*np.cos(1.05451249819 + 539.9859058331*t)
	Y2 += 0.00000000061*np.cos(5.33630384952 + 838.9692877504*t)
	Y2 += 0.00000000061*np.cos(0.00617004446 + 3.1813937377*t)
	Y2 += 0.00000000049*np.cos(2.45936277850 + 27676.976036858*t)
	Y2 += 0.00000000051*np.cos(4.08715478685 + 51116.4243529592*t)
	Y2 += 0.00000000047*np.cos(3.46367064388 + 302.164775655*t)
	Y2 += 0.00000000045*np.cos(2.48850621100 + 26202.34243025941*t)
	Y2 += 0.00000000045*np.cos(0.02918998649 + 25973.46385288896*t)
	Y2 += 0.00000000045*np.cos(2.73683504159 + 846.0828347512*t)
	Y2 += 0.00000000045*np.cos(2.31642282675 + 145.6310438715*t)
	Y2 += 0.00000000045*np.cos(4.38367721547 + 53235.18821333759*t)
	Y2 += 0.00000000047*np.cos(1.74738635330 + 1062.5633239269*t)
	Y2 += 0.00000000040*np.cos(1.42851453913 + 26301.2022370122*t)
	Y2 += 0.00000000052*np.cos(0.46087243356 + 955.5997416086*t)
	Y2 += 0.00000000039*np.cos(1.10147216023 + 25874.6040461362*t)
	Y2 += 0.00000000039*np.cos(4.08449976646 + 40853.142184844*t)
	Y2 += 0.00000000046*np.cos(3.14760491945 + 3.9321532631*t)
	Y2 += 0.00000000038*np.cos(5.98916947033 + 1258.4539316256*t)
	Y2 += 0.00000000046*np.cos(2.36226611879 + 29530.4780865396*t)
	Y2 += 0.00000000035*np.cos(6.26763450664 + 1692.1656695024*t)
	Y2 += 0.00000000039*np.cos(2.71510286457 + 53131.406024757*t)
	Y2 += 0.00000000034*np.cos(5.34770943540 + 56727.7597802072*t)
	Y2 += 0.00000000040*np.cos(5.72538622894 + 129330.13715577759*t)
	Y2 += 0.00000000033*np.cos(4.03936498647 + 277.0349937414*t)
	Y2 += 0.00000000033*np.cos(1.89317335643 + 313054.83769889036*t)
	Y2 += 0.00000000032*np.cos(5.81428165747 + 6770.7106012456*t)
	Y2 += 0.00000000038*np.cos(3.26185757209 + 2218.7571041868*t)
	Y2 += 0.00000000030*np.cos(3.29256356524 + 2125.8774073792*t)
	Y2 += 0.00000000030*np.cos(4.05437615641 + 43071.8992890308*t)
	Y2 += 0.00000000033*np.cos(2.92004182064 + 49957.0491789616*t)
	Y2 += 0.00000000035*np.cos(5.96755475967 + 1056.2005364515*t)
	Y2 += 0.00000000039*np.cos(4.91039224856 + 1574.8458012822*t)
	Y2 += 0.00000000036*np.cos(4.84158532799 + 437.6438911399*t)
	Y2 += 0.00000000028*np.cos(1.90040914464 + 1055.4497769261*t)
	Y2 += 0.00000000031*np.cos(1.82502538910 + 1272.6810256272*t)
	Y2 += 0.00000000027*np.cos(4.68673408301 + 1038.0412891868*t)
	Y2 += 0.00000000029*np.cos(0.08375583590 + 1485.9801210652*t)
	Y2 += 0.00000000027*np.cos(6.07872663556 + 618.5566453116*t)
	Y2 += 0.00000000026*np.cos(5.52380000200 + 415.5524906121*t)
	Y2 += 0.00000000025*np.cos(0.09705599716 + 98690.28051714458*t)
	Y2 += 0.00000000026*np.cos(3.49078871449 + 430.5303441391*t)
	Y2 += 0.00000000030*np.cos(0.44155155116 + 47623.8527860896*t)
	Y2 += 0.00000000024*np.cos(1.99820614050 + 18.1592472647*t)
	Y2 += 0.00000000023*np.cos(4.22922851538 + 16983.9961474566*t)
	Y2 += 0.00000000024*np.cos(3.94664051894 + 78793.40038981718*t)
	Y2 += 0.00000000023*np.cos(6.16563076611 + 231.4583427027*t)
	Y2 += 0.00000000023*np.cos(5.58098323545 + 831.8557407496*t)
	Y2 += 0.00000000027*np.cos(1.61293276234 + 2648.454825473*t)
	Y2 += 0.00000000024*np.cos(1.99165646805 + 77308.10968311399*t)
	Y2 += 0.00000000028*np.cos(5.72914844642 + 54394.56338733519*t)
	Y2 += 0.00000000021*np.cos(4.15712645283 + 447.9388318784*t)
	Y2 += 0.00000000024*np.cos(0.66675947895 + 1368.660252845*t)
	Y2 += 0.00000000020*np.cos(5.70175704295 + 10.2949407385*t)
	Y2 += 0.00000000022*np.cos(3.76535003503 + 151.0476698429*t)
	Y2 += 0.00000000020*np.cos(1.82615991897 + 1699.2792165032*t)
	Y2 += 0.00000000019*np.cos(0.17448576187 + 1063.3140834523*t)
	Y2 += 0.00000000022*np.cos(0.35963548929 + 45405.0956819028*t)
	Y2 += 0.00000000020*np.cos(0.96756200367 + 35.1640902212*t)
	Y2 += 0.00000000024*np.cos(5.32858635997 + 18849.2275499742*t)
	Y2 += 0.00000000021*np.cos(4.76218572464 + 72.3339180125*t)
	Y2 += 0.00000000022*np.cos(0.54872291567 + 12566.1516999828*t)
	Y2 += 0.00000000018*np.cos(0.17787797764 + 52156.1365222486*t)
	Y2 += 0.00000000018*np.cos(1.16105857213 + 79323.09135491178*t)
	Y2 += 0.00000000022*np.cos(1.11933727537 + 13655.8604911764*t)
	Y2 += 0.00000000018*np.cos(4.04819585578 + 1471.7530270636*t)
	Y2 += 0.00000000018*np.cos(4.54633317296 + 52389.1053785864*t)
	Y2 += 0.00000000018*np.cos(5.02672541458 + 51535.90899683439*t)
	Y2 += 0.00000000016*np.cos(3.64206691792 + 1478.8665740644*t)
	Y2 += 0.00000000018*np.cos(1.65595798708 + 51646.11531805379*t)
	Y2 += 0.00000000016*np.cos(0.09513192311 + 23754.70674870219*t)
	Y2 += 0.00000000016*np.cos(0.58395212576 + 22.0914005278*t)
	Y2 += 0.00000000017*np.cos(0.49891545478 + 77.7505439839*t)
	Y2 += 0.00000000016*np.cos(1.99438250231 + 58946.51688439399*t)
	Y2 += 0.00000000015*np.cos(3.83660842048 + 38654.05484155699*t)
	Y2 += 0.00000000015*np.cos(2.03096195084 + 5661.3320491522*t)
	Y2 += 0.00000000015*np.cos(0.22694790547 + 48733.23133818299*t)
	Y2 += 0.00000000016*np.cos(2.08963950452 + 11322.6640983044*t)
	Y2 += 0.00000000016*np.cos(3.38818988576 + 41.1019810544*t)
	Y2 += 0.00000000014*np.cos(3.27141245862 + 1375.7737998458*t)
	Y2 += 0.00000000015*np.cos(2.10902101239 + 82815.66292178139*t)
	Y2 += 0.00000000015*np.cos(3.46067246830 + 160.6088973985*t)
	Y2 += 0.00000000014*np.cos(3.52261302721 + 52179.6876185064*t)
	Y2 += 0.00000000015*np.cos(2.61226501657 + 79373.08797681599*t)
	Y2 += 0.00000000017*np.cos(0.01999942730 + 77.2292791221*t)
	Y2 += 0.00000000014*np.cos(0.87917385569 + 66941.04532641819*t)
	Y2 += 0.00000000014*np.cos(5.41787560745 + 53764.8791784322*t)
	Y2 += 0.00000000014*np.cos(2.07377604640 + 110012.94461544899*t)
	Y2 += 0.00000000014*np.cos(4.11314424872 + 71.8126531507*t)
	Y2 += 0.00000000015*np.cos(1.62123638185 + 65.2203710117*t)
	Y2 += 0.00000000014*np.cos(1.61288448694 + 36301.18868778519*t)
	Y2 += 0.00000000013*np.cos(2.42169327872 + 28421.0995344462*t)
	Y2 += 0.00000000013*np.cos(5.77387844338 + 76674.63652943878*t)
	Y2 += 0.00000000015*np.cos(5.36990490192 + 52195.47604404819*t)
	Y2 += 0.00000000016*np.cos(3.41100376315 + 33326.5787331742*t)
	Y2 += 0.00000000013*np.cos(5.40167186911 + 83925.04147387479*t)
	Y2 += 0.00000000016*np.cos(5.39991081548 + 55618.3812281138*t)
	Y2 += 0.00000000013*np.cos(2.49786568147 + 155418.04029735178*t)
	Y2 += 0.00000000013*np.cos(2.10315959516 + 131.4039498699*t)
	Y2 += 0.00000000012*np.cos(2.28713351757 + 50057.04242277*t)
	Y2 += 0.00000000012*np.cos(3.60070147194 + 337.732510659*t)
	Y2 += 0.00000000012*np.cos(5.16899217088 + 195.1398481733*t)
	Y2 += 0.00000000013*np.cos(2.01707000795 + 52171.9249477904*t)
	Y2 += 0.00000000013*np.cos(1.57968548593 + 408.4389436113*t)
	Y2 += 0.00000000014*np.cos(0.57769767887 + 26727.8004278882*t)
	Y2 += 0.00000000014*np.cos(5.41918866932 + 2111.6503133776*t)
	Y2 += 0.00000000011*np.cos(4.73842604358 + 511.5317178299*t)
	Y2 += 0.00000000012*np.cos(2.63845374146 + 963.4027029714*t)
	Y2 += 0.00000000011*np.cos(4.62449766576 + 62389.09182935939*t)
	Y2 += 0.00000000010*np.cos(2.74385211018 + 547.8502123593*t)
	Y2 += 0.00000000010*np.cos(5.55718728874 + 52290.24557183361*t)
	Y2 += 0.00000000010*np.cos(4.24006763767 + 127.4717966068*t)
	Y2 += 0.00000000010*np.cos(3.10795031986 + 362.8622925726*t)
	Y2 += 0.00000000012*np.cos(5.50291077360 + 1685.0521225016*t)
	Y2 += 0.00000000010*np.cos(3.38695373136 + 934.9485149682*t)
	Y2 += 0.00000000013*np.cos(3.34698985021 + 84.3428261229*t)
	Y2 += 0.00000000012*np.cos(1.55438318082 + 26514.5013324502*t)
	Y2 += 0.00000000009*np.cos(5.97731076392 + 76044.9523205358*t)
	Y2 += 0.00000000009*np.cos(1.52608730668 + 35191.8101356918*t)
	Y2 += 0.00000000009*np.cos(4.89802068656 + 1382.8873468466*t)
	Y2 += 0.00000000012*np.cos(1.08976567704 + 148.0787244263*t)
	Y2 += 0.00000000009*np.cos(0.86970882362 + 153.4953503977*t)
	Y2 += 0.00000000010*np.cos(3.15434437042 + 124778.18365871879*t)
	Y2 += 0.00000000010*np.cos(5.98112560726 + 56.6223513026*t)
	Y2 += 0.00000000009*np.cos(4.94399763372 + 339142.74084046457*t)
	Y2 += 0.00000000009*np.cos(3.23297814751 + 78244.0396638228*t)
	Y2 += 0.00000000011*np.cos(1.37012220080 + 38519.945791972*t)
	Y2 += 0.00000000011*np.cos(1.80725352207 + 222.8603229936*t)
	Y2 += 0.00000000008*np.cos(4.44940554836 + 92.940845832*t)
	Y2 += 0.00000000009*np.cos(1.65178893035 + 39609.6545831656*t)
	Y2 += 0.00000000008*np.cos(3.08406781779 + 52061.36699446317*t)
	Y2 += 0.00000000011*np.cos(2.71165214295 + 635.9651330509*t)
	Y2 += 0.00000000010*np.cos(1.78007560053 + 25028.521211385*t)
	Y2 += 0.00000000011*np.cos(6.25031686000 + 203.7378678824*t)
	Y2 += 0.00000000009*np.cos(1.99370375699 + 12432.0426503978*t)
	Y2 += 0.00000000008*np.cos(1.97062836873 + 750.1036075334*t)
	Y2 += 0.00000000010*np.cos(3.73718799858 + 436.8931316145*t)
	Y2 += 0.00000000009*np.cos(0.64203429747 + 104881.30353139139*t)
	Y2 += 0.00000000008*np.cos(2.46909335815 + 2333.196392872*t)
	Y2 += 0.00000000008*np.cos(0.62172049419 + 269.9214467406*t)
	Y2 += 0.00000000008*np.cos(5.09160593281 + 136100.84775702319*t)
	Y2 += 0.00000000010*np.cos(2.95730289498 + 643.0786800517*t)
	Y2 += 0.00000000008*np.cos(4.95977806392 + 103396.01282468818*t)
	Y2 += 0.00000000008*np.cos(3.17511222783 + 28206.6670019526*t)
	Y2 += 0.00000000008*np.cos(4.28675667624 + 131.5469622218*t)
	Y2 += 0.00000000008*np.cos(5.30797759703 + 79219.30916633119*t)
	Y2 += 0.00000000009*np.cos(4.93174852989 + 7994.5284420242*t)
	Y2 += 0.00000000009*np.cos(4.69826318545 + 63498.47038145279*t)
	Y2 += 0.00000000009*np.cos(1.06973985086 + 15874.6175953632*t)
	Y2 += 0.00000000007*np.cos(3.14954677340 + 52168.69273614759*t)
	Y2 += 0.00000000007*np.cos(2.53028727253 + 1603.2999892854*t)
	Y2 += 0.00000000007*np.cos(0.55559122998 + 64741.95798313119*t)
	Y2 += 0.00000000007*np.cos(5.10450860305 + 6681.2248533996*t)
	Y2 += 0.00000000009*np.cos(0.64587598578 + 1279.794572628*t)
	Y2 += 0.00000000007*np.cos(6.16053809700 + 483.2205421786*t)
	Y2 += 0.00000000007*np.cos(0.76613463585 + 69159.80243060499*t)
	Y2 += 0.00000000007*np.cos(0.31047071847 + 78267.59076008058*t)
	Y2 += 0.00000000009*np.cos(5.81958505267 + 87.3117715395*t)
	Y2 += 0.00000000007*np.cos(2.57134529838 + 867.4234757536*t)
	Y2 += 0.00000000008*np.cos(0.69696747390 + 1361.5467058442*t)
	Y2 += 0.00000000009*np.cos(1.78142262939 + 44937.1306915484*t)
	Y2 += 0.00000000007*np.cos(3.66488715060 + 18207.81398823521*t)
	Y2 += 0.00000000008*np.cos(2.43253154916 + 52182.9198301492*t)
	Y2 += 0.00000000006*np.cos(4.24193398289 + 107.0249274817*t)
	Y2 += 0.00000000006*np.cos(3.25108918094 + 9.5612275556*t)
	Y2 += 0.00000000007*np.cos(4.78448266738 + 721.6494195302*t)
	Y2 += 0.00000000006*np.cos(5.72007706352 + 106.2741679563*t)
	Y2 += 0.00000000006*np.cos(4.20186212149 + 105410.99449648599*t)
	Y2 += 0.00000000006*np.cos(4.36194061397 + 12.5301729722*t)
	Y2 += 0.00000000006*np.cos(3.00522390508 + 52.6901980395*t)
	Y2 += 0.00000000006*np.cos(0.31871061944 + 2221.856634597*t)
	Y2 += 0.00000000006*np.cos(1.43352275284 + 88476.99497093359*t)
	Y2 += 0.00000000007*np.cos(4.55836386142 + 51962.5071877104*t)
	Y2 += 0.00000000006*np.cos(2.49037028744 + 288.0806940053*t)
	Y2 += 0.00000000006*np.cos(0.82384473987 + 129380.13377768178*t)
	Y2 += 0.00000000006*np.cos(1.63049926151 + 35.685355083*t)
	Y2 += 0.00000000007*np.cos(1.46168801536 + 142.4496501338*t)
	Y2 += 0.00000000006*np.cos(1.28923147875 + 405.2575498736*t)
	Y2 += 0.00000000006*np.cos(4.69107663948 + 52602.4044740244*t)
	Y2 += 0.00000000006*np.cos(0.95309123619 + 68050.42387851159*t)
	Y2 += 0.00000000006*np.cos(5.62733178540 + 113.3877149571*t)
	Y2 += 0.00000000007*np.cos(3.94256114885 + 7238.67559160*t)
	Y2 += 0.00000000005*np.cos(4.22538197267 + 57837.1383323006*t)
	Y2 += 0.00000000005*np.cos(2.71015544529 + 40.5807161926*t)
	Y2 += 0.00000000005*np.cos(2.54250601710 + 416.3032501375*t)
	Y2 += 0.00000000006*np.cos(1.35964226786 + 78477.00852016058*t)
	Y2 += 0.00000000005*np.cos(3.27748453006 + 74821.13447975718*t)
	Y2 += 0.00000000005*np.cos(4.79928508484 + 13521.7514415914*t)
	Y2 += 0.00000000007*np.cos(2.15262985645 + 78283.37918562238*t)
	Y2 += 0.00000000007*np.cos(3.41483534504 + 71492.99882347698*t)
	Y2 += 0.00000000005*np.cos(2.00252804083 + 25661.3049506982*t)
	Y2 += 0.00000000005*np.cos(2.30423096631 + 105460.99111839019*t)
	Y2 += 0.00000000005*np.cos(3.95725794199 + 94138.32702008578*t)
	Y2 += 0.00000000006*np.cos(5.93990081718 + 1795.258443721*t)
	Y2 += 0.00000000005*np.cos(6.01203009176 + 51322.60990139639*t)
	Y2 += 0.00000000005*np.cos(2.05453158249 + 628.8515860501*t)
	Y2 += 0.00000000006*np.cos(4.90832237060 + 77734.01845962799*t)
	Y2 += 0.00000000006*np.cos(5.09323451879 + 78259.82808936459*t)
	Y2 += 0.00000000005*np.cos(5.15754800675 + 108903.56606335558*t)
	Y2 += 0.00000000005*np.cos(2.16962219454 + 81706.28436968799*t)
	Y2 += 0.00000000005*np.cos(3.67826495011 + 299.1263942692*t)
	Y2 += 0.00000000005*np.cos(6.03160576908 + 78256.59587772179*t)
	Y2 += 0.00000000004*np.cos(4.28304952979 + 81.7521332162*t)
	Y2 += 0.00000000005*np.cos(4.41481024230 + 99.9113804809*t)
	Y2 += 0.00000000004*np.cos(2.63096828553 + 265.9892934775*t)
	Y2 += 0.00000000005*np.cos(2.37794711687 + 1.4844727083*t)
	Y2 += 0.00000000006*np.cos(3.64636080185 + 200.7689224658*t)
	Y2 += 0.00000000004*np.cos(4.73704179984 + 241.7532834412*t)
	Y2 += 0.00000000004*np.cos(4.79876284125 + 225.8292684102*t)
	Y2 += 0.00000000005*np.cos(1.33638591879 + 344.7030453079*t)
	Y2 += 0.00000000006*np.cos(3.87273262792 + 103292.23063610759*t)
	Y2 += 0.00000000006*np.cos(3.95183892541 + 2.9689454166*t)
	Y2 += 0.00000000004*np.cos(3.59509349235 + 80.1982245387*t)
	Y2 += 0.00000000004*np.cos(0.83457275877 + 32370.9789915656*t)
	Y2 += 0.00000000004*np.cos(5.01761361986 + 33967.99229491319*t)
	Y2 += 0.00000000006*np.cos(5.63297540234 + 1049.0869894507*t)
	Y2 += 0.00000000004*np.cos(2.55613520919 + 29416.03879785439*t)
	Y2 += 0.00000000004*np.cos(6.24908247561 + 22759.76748529401*t)
	Y2 += 0.00000000005*np.cos(3.91889103336 + 93028.94846799239*t)
	Y2 += 0.00000000004*np.cos(3.71597820582 + 295.0512286542*t)
	Y2 += 0.00000000004*np.cos(2.43954742926 + 96.8729990951*t)
	Y2 += 0.00000000004*np.cos(5.09314307859 + 76144.94556434419*t)
	Y2 += 0.00000000004*np.cos(5.54718850207 + 181505.94343892598*t)
	Y2 += 0.00000000004*np.cos(3.66591555169 + 51749.20809227239*t)
	Y2 += 0.00000000004*np.cos(5.43535832308 + 77204.32749453338*t)
	Y2 += 0.00000000005*np.cos(1.18144370768 + 146.3818033969*t)
	Y2 += 0.00000000005*np.cos(4.32438666743 + 340.7708920448*t)
	Y2 += 0.00000000004*np.cos(3.65979462851 + 358.9301393095*t)
	Y2 += 0.00000000004*np.cos(1.53439242952 + 1802.3719907218*t)
	Y2 += 0.00000000005*np.cos(6.24450165084 + 59414.4818747484*t)
	Y2 += 0.00000000005*np.cos(5.47240472132 + 78270.82297172339*t)
	Y2 += 0.00000000004*np.cos(4.33674716223 + 67.6680515665*t)
	Y2 += 0.00000000004*np.cos(0.88741176946 + 490.3340891794*t)
	Y2 += 0.00000000004*np.cos(1.47636301964 + 284.1485407422*t)
	Y2 += 0.00000000004*np.cos(2.43069407838 + 181.0557665236*t)
	Y2 += 0.00000000004*np.cos(3.89916025123 + 44181.27784112419*t)
	Y2 += 0.00000000004*np.cos(4.16249740193 + 650.9429865779*t)
	Y2 += 0.00000000004*np.cos(6.22902554255 + 24498.8302462904*t)
	Y2 += 0.00000000004*np.cos(3.92116783578 + 155468.03691925599*t)
	Y2 += 0.00000000004*np.cos(5.48712842142 + 54509.0026760204*t)
	Y2 += 0.00000000004*np.cos(5.33225362650 + 444.7574381407*t)
	Y2 += 0.00000000004*np.cos(4.27463598779 + 18093.37469954999*t)
	Y2 += 0.00000000004*np.cos(5.87289976350 + 10213.285546211*t)
	Y2 += 0.00000000003*np.cos(1.85244465361 + 162188.75089859738*t)
	Y2 += 0.00000000003*np.cos(1.63325210753 + 424.1505103212*t)
	Y2 += 0.00000000003*np.cos(2.17849854835 + 561.934294009*t)
	Y2 += 0.00000000003*np.cos(4.77836422656 + 41962.5207369374*t)
	Y2 += 0.00000000003*np.cos(0.28442912913 + 81.8951455681*t)
	Y2 += 0.00000000004*np.cos(2.12335410594 + 79852.78232000639*t)
	Y2 += 0.00000000003*np.cos(6.23743929416 + 501.2367770914*t)
	Y2 += 0.00000000004*np.cos(5.46844304994 + 1788.1448967202*t)
	Y2 += 0.00000000003*np.cos(4.39999749193 + 350.3321196004*t)
	Y2 += 0.00000000004*np.cos(4.17801375091 + 39743.7636327506*t)
	Y2 += 0.00000000004*np.cos(5.19094501525 + 62.2514255951*t)
	Y2 += 0.00000000004*np.cos(5.70840309627 + 7880.08915333899*t)
	Y2 += 0.00000000003*np.cos(0.39806541191 + 99799.65906923798*t)
	Y2 += 0.00000000004*np.cos(2.38564459509 + 80482.46652890938*t)
	Y2 += 0.00000000004*np.cos(0.92232764086 + 191.2076949102*t)
	Y2 += 0.00000000003*np.cos(5.84603699432 + 1148.2476104062*t)
	Y2 += 0.00000000003*np.cos(6.27556693980 + 104331.94280539699*t)
	Y2 += 0.00000000003*np.cos(1.35069678358 + 19804.8272915828*t)
	Y2 += 0.00000000003*np.cos(5.12901924955 + 14.977853527*t)
	Y2 += 0.00000000003*np.cos(5.61442182281 + 245.5424243524*t)
	Y2 += 0.00000000003*np.cos(0.96877732576 + 703.6331846174*t)
	Y2 += 0.00000000003*np.cos(1.81855841579 + 77623.81213840858*t)
	Y2 += 0.00000000004*np.cos(2.52850834706 + 27311.72098235281*t)
	Y2 += 0.00000000004*np.cos(6.27670933774 + 24864.08530079559*t)
	Y2 += 0.00000000003*np.cos(0.70573582046 + 120226.23016165999*t)
	Y2 += 0.00000000003*np.cos(3.32514993267 + 125887.56221081219*t)
	Y2 += 0.00000000003*np.cos(0.98185914685 + 2015.6710861598*t)
	Y2 += 0.00000000003*np.cos(3.75830218405 + 58458.88213313979*t)
	Y2 += 0.00000000003*np.cos(2.74763513151 + 102132.85546210999*t)
	Y2 += 0.00000000003*np.cos(4.13284762562 + 152.7445908723*t)
	Y2 += 0.00000000003*np.cos(0.36290468467 + 2.4476805548*t)
	Y2 += 0.00000000003*np.cos(2.38051469960 + 351.8165923087*t)
	Y2 += 0.00000000003*np.cos(1.67864067330 + 129483.91596626239*t)
	Y2 += 0.00000000003*np.cos(6.20277750460 + 150866.08680029298*t)
	Y2 += 0.00000000004*np.cos(1.26893874193 + 103821.92160120218*t)
	Y2 += 0.00000000003*np.cos(3.56406791266 + 90829.86112470538*t)
	Y2 += 0.00000000003*np.cos(1.89123873675 + 6283.0758499914*t)
	Y2 += 0.00000000003*np.cos(4.95099113946 + 2104.5367663768*t)
	Y2 += 0.00000000003*np.cos(1.47669060951 + 1069.6768709277*t)
	Y2 += 0.00000000003*np.cos(1.82747855775 + 33.6796175129*t)
	Y2 += 0.00000000003*np.cos(2.54140657037 + 636.7158925763*t)
	Y2 += 0.00000000003*np.cos(3.63272158132 + 130969.20667296558*t)
	Y2 += 0.00000000002*np.cos(3.23610336539 + 3328.13565628019*t)
	Y2 += 0.00000000003*np.cos(0.51639260266 + 235.3904959658*t)
	Y2 += 0.00000000003*np.cos(1.74048283842 + 1080.7225711916*t)
	Y2 += 0.00000000002*np.cos(3.31947858603 + 661.2379273164*t)
	Y2 += 0.00000000003*np.cos(5.91047728379 + 26941.0995233262*t)
	Y2 += 0.00000000003*np.cos(2.19636619794 + 1592.2542890215*t)
	Y2 += 0.00000000002*np.cos(0.48948862546 + 611.4430983108*t)
	Y2 += 0.00000000003*np.cos(0.11884474556 + 1898.3512179396*t)
	Y2 += 0.00000000003*np.cos(4.65184843181 + 71025.03383312259*t)
	Y2 += 0.00000000002*np.cos(4.48148929675 + 114564.89811250778*t)
	Y2 += 0.00000000002*np.cos(2.47771838961 + 565.1156877467*t)
	Y2 += 0.00000000002*np.cos(2.32776941660 + 78378.14871340781*t)
	Y2 += 0.00000000002*np.cos(5.72650908152 + 2008.557539159*t)
	Y2 += 0.00000000002*np.cos(1.96886682971 + 5849.3641121146*t)
	Y2 += 0.00000000003*np.cos(3.35170366833 + 104355.49390165479*t)
	Y2 += 0.00000000002*np.cos(4.33824833645 + 404.5067903482*t)
	Y2 += 0.00000000002*np.cos(5.72106936632 + 79.2350166922*t)
	Y2 += 0.00000000003*np.cos(4.22691038602 + 64607.84893354619*t)
	Y2 += 0.00000000002*np.cos(4.33074956694 + 5863.5912061162*t)
	Y2 += 0.00000000002*np.cos(1.71650975828 + 365230.64398203876*t)
	Y2 += 0.00000000003*np.cos(3.67194915630 + 52815.7035694624*t)
	Y2 += 0.00000000002*np.cos(1.27345348451 + 77197.21394753258*t)
	Y2 += 0.00000000002*np.cos(1.48417100051 + 78690.30761559859*t)
	Y2 += 0.00000000002*np.cos(3.39244631760 + 9779.5738083342*t)
	Y2 += 0.00000000003*np.cos(3.22473672245 + 319.5732633943*t)
	Y2 += 0.00000000002*np.cos(6.12303826586 + 26080.78959457339*t)
	Y2 += 0.00000000002*np.cos(0.08755117660 + 1251.3403846248*t)
	Y2 += 0.00000000002*np.cos(5.75433263256 + 9793.8009023358*t)
	Y2 += 0.00000000002*np.cos(5.19120708421 + 104371.28232719658*t)
	Y2 += 0.00000000002*np.cos(3.75555673654 + 2655.5683724738*t)
	Y2 += 0.00000000002*np.cos(4.73000748906 + 629.6023455755*t)
	Y2 += 0.00000000002*np.cos(2.46951852139 + 42.5864537627*t)
	Y2 += 0.00000000002*np.cos(0.36359574780 + 137.0330241624*t)
	Y2 += 0.00000000002*np.cos(2.35083792212 + 313.2104759189*t)
	Y2 += 0.00000000002*np.cos(0.78853413649 + 77211.44104153418*t)
	Y2 += 0.00000000002*np.cos(2.25297552783 + 208.633228992*t)
	Y2 += 0.00000000002*np.cos(3.54076915127 + 1905.4647649404*t)
	Y2 += 0.00000000002*np.cos(5.23123120810 + 70.3281804424*t)
	Y2 += 0.00000000002*np.cos(5.11741765544 + 10021.8372800994*t)
	Y2 += 0.00000000002*np.cos(2.63436119239 + 217.964961884*t)
	Y2 += 0.00000000002*np.cos(2.72670303771 + 104344.49901929598*t)
	Y2 += 0.00000000002*np.cos(0.63092019383 + 429.0458714308*t)
	Y2 += 0.00000000002*np.cos(4.67739374144 + 73711.75592766379*t)
	Y2 += 0.00000000002*np.cos(3.00197118340 + 152.5321425512*t)
	Y2 += 0.00000000002*np.cos(1.53237872748 + 25021.4076643842*t)
	Y2 += 0.00000000002*np.cos(2.13231085358 + 78050.41032928458*t)
	Y2 += 0.00000000002*np.cos(0.91172072873 + 26724.8994135984*t)
	Y2 += 0.00000000002*np.cos(1.61031164889 + 25450.90686955*t)
	Y2 += 0.00000000002*np.cos(2.46824302833 + 757.2171545342*t)
	Y2 += 0.00000000002*np.cos(2.10730094512 + 497.4476361802*t)
	Y2 += 0.00000000002*np.cos(6.01446832325 + 824.7421937488*t)
	Y2 += 0.00000000002*np.cos(0.18515603002 + 97580.90196505119*t)
	Y2 += 0.00000000002*np.cos(1.24467307746 + 25035.6347583858*t)
	Y2 += 0.00000000002*np.cos(4.54718046119 + 61279.713277266*t)
	Y2 += 0.00000000002*np.cos(0.99883736208 + 131498.89763806018*t)
	Y2 += 0.00000000002*np.cos(1.08622053153 + 621.7380390493*t)
	Y2 += 0.00000000002*np.cos(1.54993622536 + 970.5162499722*t)
	Y2 += 0.00000000002*np.cos(4.07396574578 + 31.019488637*t)
	Y2 += 0.00000000002*np.cos(5.56159898916 + 2428.0421830342*t)
	Y2 += 0.00000000002*np.cos(6.14579824758 + 78149.27013603736*t)
	Y2 += 0.00000000002*np.cos(3.99712167326 + 114.1384744825*t)
	Y2 += 0.00000000002*np.cos(5.22194829628 + 107794.18751126219*t)
	return Y2*t*t




def Mercury_Y3 (t): # 186 terms of order 3

	Y3 = 0.
	Y3 += 0.00000022088*np.cos(4.54598360855 + 206.1855484372*t)
	Y3 += 0.00000021546*np.cos(3.46116671016 + 220.4126424388*t)
	Y3 += 0.00000018231*np.cos(4.35141183918 + 78263.70942472259*t)
	Y3 += 0.00000017840*np.cos(1.45419068020 + 52175.8062831484*t)
	Y3 += 0.00000016300*np.cos(1.14934178921 + 522.5774180938*t)
	Y3 += 0.00000015923*np.cos(0.06221071687 + 536.8045120954*t)
	Y3 += 0.00000018361
	Y3 += 0.00000010723*np.cos(1.09353490107 + 104351.61256629678*t)
	Y3 += 0.00000008835*np.cos(4.62739214222 + 26087.9031415742*t)
	Y3 += 0.00000004973*np.cos(4.13805648872 + 130439.51570787099*t)
	Y3 += 0.00000003093*np.cos(2.22514436528 + 426.598190876*t)
	Y3 += 0.00000002568*np.cos(2.47493921494 + 433.7117378768*t)
	Y3 += 0.00000002105*np.cos(3.35595521974 + 227.5261894396*t)
	Y3 += 0.00000002032*np.cos(0.90409186617 + 156527.41884944518*t)
	Y3 += 0.00000001700*np.cos(5.13510489936 + 1059.3819301892*t)
	Y3 += 0.00000001378*np.cos(1.27086042787 + 515.463871093*t)
	Y3 += 0.00000001266*np.cos(3.80209162712 + 419.4846438752*t)
	Y3 += 0.00000001363*np.cos(4.63636570705 + 7.1135470008*t)
	Y3 += 0.00000001013*np.cos(4.67704889552 + 199.0720014364*t)
	Y3 += 0.00000001037*np.cos(0.69915801725 + 1066.49547719*t)
	Y3 += 0.00000000964*np.cos(6.22045145850 + 543.9180590962*t)
	Y3 += 0.00000000849*np.cos(1.26670686968 + 639.897286314*t)
	Y3 += 0.00000000768*np.cos(3.95481408065 + 182615.32199101939*t)
	Y3 += 0.00000000678*np.cos(0.79554783130 + 1052.2683831884*t)
	Y3 += 0.00000000392*np.cos(4.59101411052 + 14.2270940016*t)
	Y3 += 0.00000000291*np.cos(1.57357745396 + 647.0108333148*t)
	Y3 += 0.00000000248*np.cos(5.85725743749 + 1589.0728952838*t)
	Y3 += 0.00000000214*np.cos(2.46865385667 + 440.8252848776*t)
	Y3 += 0.00000000275*np.cos(0.72281686312 + 208703.22513259358*t)
	Y3 += 0.00000000231*np.cos(2.85226310193 + 216.4804891757*t)
	Y3 += 0.00000000220*np.cos(5.18394074276 + 210.1177017003*t)
	Y3 += 0.00000000129*np.cos(0.22762324749 + 1045.1548361876*t)
	Y3 += 0.00000000123*np.cos(0.51351773704 + 853.196381752*t)
	Y3 += 0.00000000137*np.cos(2.15435863260 + 529.6909650946*t)
	Y3 += 0.00000000092*np.cos(3.22442461302 + 234.6397364404*t)
	Y3 += 0.00000000087*np.cos(4.52965482365 + 103.0927742186*t)
	Y3 += 0.00000000095*np.cos(3.77357857159 + 234791.12827416777*t)
	Y3 += 0.00000000092*np.cos(3.90819414656 + 117.3198682202*t)
	Y3 += 0.00000000085*np.cos(5.57189606315 + 95.9792272178*t)
	Y3 += 0.00000000094*np.cos(2.25651891145 + 213.299095438*t)
	Y3 += 0.00000000075*np.cos(1.30082808866 + 1596.1864422846*t)
	Y3 += 0.00000000078*np.cos(4.96547279129 + 110.2063212194*t)
	Y3 += 0.00000000071*np.cos(4.48281367743 + 632.7837393132*t)
	Y3 += 0.00000000076*np.cos(3.40988387446 + 412.3710968744*t)
	Y3 += 0.00000000064*np.cos(2.39566214965 + 316.3918696566*t)
	Y3 += 0.00000000056*np.cos(1.44254805098 + 508.3503240922*t)
	Y3 += 0.00000000055*np.cos(1.71252125469 + 323.5054166574*t)
	Y3 += 0.00000000048*np.cos(0.40111970766 + 1073.6090241908*t)
	Y3 += 0.00000000056*np.cos(6.19540120033 + 735.8765135318*t)
	Y3 += 0.00000000042*np.cos(6.13276553266 + 625.6701923124*t)
	Y3 += 0.00000000039*np.cos(5.02961841371 + 942.062061969*t)
	Y3 += 0.00000000036*np.cos(3.01279484364 + 209.3669421749*t)
	Y3 += 0.00000000031*np.cos(0.88356246900 + 1581.959348283*t)
	Y3 += 0.00000000032*np.cos(0.53816590044 + 260879.03141574195*t)
	Y3 += 0.00000000031*np.cos(6.03310463140 + 551.031606097*t)
	Y3 += 0.00000000032*np.cos(4.98300318004 + 217.2312487011*t)
	Y3 += 0.00000000033*np.cos(0.75212348383 + 860.3099287528*t)
	Y3 += 0.00000000030*np.cos(4.51763020093 + 70.8494453042*t)
	Y3 += 0.00000000027*np.cos(2.35184788494 + 149.5631971346*t)
	Y3 += 0.00000000028*np.cos(1.91930691377 + 330.6189636582*t)
	Y3 += 0.00000000027*np.cos(0.05305218851 + 2118.7638603784*t)
	Y3 += 0.00000000028*np.cos(0.17790568355 + 78.7137518304*t)
	Y3 += 0.00000000027*np.cos(4.37487614145 + 21.3406410024*t)
	Y3 += 0.00000000029*np.cos(5.17540731322 + 949.1756089698*t)
	Y3 += 0.00000000025*np.cos(3.02081007506 + 124.433415221*t)
	Y3 += 0.00000000033*np.cos(2.73570572399 + 223.5940361765*t)
	Y3 += 0.00000000025*np.cos(5.88306502494 + 1169.5882514086*t)
	Y3 += 0.00000000024*np.cos(6.25389986741 + 63.7358983034*t)
	Y3 += 0.00000000024*np.cos(4.81432332838 + 191.9584544356*t)
	Y3 += 0.00000000028*np.cos(0.01012773075 + 728.762966531*t)
	Y3 += 0.00000000024*np.cos(1.59054971444 + 654.1243803156*t)
	Y3 += 0.00000000030*np.cos(4.35202882411 + 309.2783226558*t)
	Y3 += 0.00000000023*np.cos(1.30039835479 + 51066.427731055*t)
	Y3 += 0.00000000022*np.cos(0.58430377684 + 1155.361157407*t)
	Y3 += 0.00000000020*np.cos(5.79574932921 + 88.865680217*t)
	Y3 += 0.00000000023*np.cos(3.64404039148 + 956.2891559706*t)
	Y3 += 0.00000000019*np.cos(4.74503190924 + 85.8272988312*t)
	Y3 += 0.00000000019*np.cos(5.66498805054 + 73.297125859*t)
	Y3 += 0.00000000025*np.cos(1.94036276937 + 429.7795846137*t)
	Y3 += 0.00000000024*np.cos(1.95947716237 + 519.3960243561*t)
	Y3 += 0.00000000020*np.cos(0.29570924626 + 71.6002048296*t)
	Y3 += 0.00000000018*np.cos(4.38365354248 + 77.962992305*t)
	Y3 += 0.00000000016*np.cos(4.70914310164 + 202.2533951741*t)
	Y3 += 0.00000000020*np.cos(5.48263393467 + 539.9859058331*t)
	Y3 += 0.00000000016*np.cos(3.45867068386 + 224.3447957019*t)
	Y3 += 0.00000000015*np.cos(5.26771574252 + 302.164775655*t)
	Y3 += 0.00000000014*np.cos(5.35318240788 + 76.2660712756*t)
	Y3 += 0.00000000017*np.cos(5.40518600219 + 203.0041546995*t)
	Y3 += 0.00000000013*np.cos(4.35126170071 + 77154.33087262919*t)
	Y3 += 0.00000000011*np.cos(3.87206824630 + 11.0457002639*t)
	Y3 += 0.00000000011*np.cos(4.27058573849 + 53285.1848352418*t)
	Y3 += 0.00000000010*np.cos(3.58474125179 + 286966.93455731616*t)
	Y3 += 0.00000000010*np.cos(2.40929335654 + 36.6485629295*t)
	Y3 += 0.00000000012*np.cos(1.79980409055 + 422.6660376129*t)
	Y3 += 0.00000000009*np.cos(1.93147151515 + 39.6175083461*t)
	Y3 += 0.00000000009*np.cos(0.16500567398 + 1038.0412891868*t)
	Y3 += 0.00000000009*np.cos(0.79081879948 + 838.9692877504*t)
	Y3 += 0.00000000009*np.cos(2.40868380460 + 447.9388318784*t)
	Y3 += 0.00000000008*np.cos(1.59402806626 + 618.5566453116*t)
	Y3 += 0.00000000009*np.cos(2.51756026677 + 74.7815985673*t)
	Y3 += 0.00000000008*np.cos(5.09979031312 + 423.4167971383*t)
	Y3 += 0.00000000009*np.cos(0.33848481291 + 1574.8458012822*t)
	Y3 += 0.00000000007*np.cos(1.37888755215 + 1258.4539316256*t)
	Y3 += 0.00000000006*np.cos(1.09195739886 + 831.8557407496*t)
	Y3 += 0.00000000006*np.cos(1.00867247429 + 138.5174968707*t)
	Y3 += 0.00000000006*np.cos(4.91543048225 + 742.9900605326*t)
	Y3 += 0.00000000006*np.cos(1.82818120946 + 2125.8774073792*t)
	Y3 += 0.00000000005*np.cos(0.60506372351 + 145.6310438715*t)
	Y3 += 0.00000000007*np.cos(5.32328426995 + 38.1330356378*t)
	Y3 += 0.00000000005*np.cos(0.66965342943 + 195.1398481733*t)
	Y3 += 0.00000000006*np.cos(1.11939414362 + 103242.23401420339*t)
	Y3 += 0.00000000004*np.cos(0.41274254704 + 18.1592472647*t)
	Y3 += 0.00000000004*np.cos(1.83690246048 + 337.732510659*t)
	Y3 += 0.00000000004*np.cos(1.32611242407 + 1265.5674786264*t)
	Y3 += 0.00000000004*np.cos(1.06911580934 + 79373.08797681599*t)
	Y3 += 0.00000000004*np.cos(2.71001820282 + 437.6438911399*t)
	Y3 += 0.00000000003*np.cos(5.02306065714 + 1485.9801210652*t)
	Y3 += 0.00000000004*np.cos(4.61647130206 + 3.9321532631*t)
	Y3 += 0.00000000003*np.cos(0.35802564284 + 313054.83769889036*t)
	Y3 += 0.00000000004*np.cos(4.86205883099 + 3.1813937377*t)
	Y3 += 0.00000000003*np.cos(0.24146698930 + 1699.2792165032*t)
	Y3 += 0.00000000003*np.cos(2.54047104670 + 131.5469622218*t)
	Y3 += 0.00000000003*np.cos(5.19663268688 + 934.9485149682*t)
	Y3 += 0.00000000003*np.cos(1.89821812188 + 436.8931316145*t)
	Y3 += 0.00000000003*np.cos(4.05827327245 + 846.0828347512*t)
	Y3 += 0.00000000003*np.cos(0.84357940935 + 1062.5633239269*t)
	Y3 += 0.00000000003*np.cos(0.21598966041 + 721.6494195302*t)
	Y3 += 0.00000000002*np.cos(0.53670508526 + 2648.454825473*t)
	Y3 += 0.00000000003*np.cos(4.97694448000 + 24978.5245894808*t)
	Y3 += 0.00000000002*np.cos(3.92186370454 + 131.4039498699*t)
	Y3 += 0.00000000002*np.cos(0.91291435645 + 1603.2999892854*t)
	Y3 += 0.00000000002*np.cos(0.76104298796 + 867.4234757536*t)
	Y3 += 0.00000000002*np.cos(1.08620559446 + 643.0786800517*t)
	Y3 += 0.00000000003*np.cos(6.03930177407 + 1471.7530270636*t)
	Y3 += 0.00000000002*np.cos(4.16958554828 + 129330.13715577759*t)
	Y3 += 0.00000000002*np.cos(0.85856016250 + 635.9651330509*t)
	Y3 += 0.00000000002*np.cos(4.22140945210 + 231.4583427027*t)
	Y3 += 0.00000000002*np.cos(4.98034080151 + 46514.4742339962*t)
	Y3 += 0.00000000002*np.cos(0.75178980879 + 27197.2816936676*t)
	Y3 += 0.00000000002*np.cos(1.66761053003 + 56.6223513026*t)
	Y3 += 0.00000000002*np.cos(1.79735462475 + 72602.37737557039*t)
	Y3 += 0.00000000002*np.cos(2.40289635523 + 1368.660252845*t)
	Y3 += 0.00000000002*np.cos(2.45646924027 + 269.9214467406*t)
	Y3 += 0.00000000002*np.cos(0.51395931456 + 1272.6810256272*t)
	Y3 += 0.00000000002*np.cos(3.61461152227 + 408.4389436113*t)
	Y3 += 0.00000000002*np.cos(0.93616194604 + 963.4027029714*t)
	Y3 += 0.00000000002*np.cos(1.58523848820 + 1685.0521225016*t)
	Y3 += 0.00000000002*np.cos(5.51445164570 + 295.0512286542*t)
	Y3 += 0.00000000002*np.cos(1.00442608560 + 1055.4497769261*t)
	Y3 += 0.00000000002*np.cos(4.49509966736 + 22.0914005278*t)
	Y3 += 0.00000000002*np.cos(3.08845244449 + 241.7532834412*t)
	Y3 += 0.00000000002*np.cos(1.43941179659 + 151.0476698429*t)
	Y3 += 0.00000000001*np.cos(3.44704587186 + 1382.8873468466*t)
	Y3 += 0.00000000002*np.cos(0.57010178031 + 1788.1448967202*t)
	Y3 += 0.00000000002*np.cos(0.42335354864 + 416.3032501375*t)
	Y3 += 0.00000000002*np.cos(1.75951401058 + 526.5095713569*t)
	Y3 += 0.00000000002*np.cos(2.58117163779 + 532.8723588323*t)
	Y3 += 0.00000000002*np.cos(3.97020440960 + 51220.20654153979*t)
	Y3 += 0.00000000001*np.cos(5.48681505441 + 277.0349937414*t)
	Y3 += 0.00000000002*np.cos(0.13809144454 + 430.5303441391*t)
	Y3 += 0.00000000002*np.cos(2.58174480747 + 92.940845832*t)
	Y3 += 0.00000000001*np.cos(6.06441593546 + 81.7521332162*t)
	Y3 += 0.00000000001*np.cos(0.71058040619 + 415.5524906121*t)
	Y3 += 0.00000000002*np.cos(5.06827598270 + 1279.794572628*t)
	Y3 += 0.00000000001*np.cos(5.87510766420 + 1162.4747044078*t)
	Y3 += 0.00000000001*np.cos(3.29813464894 + 611.4430983108*t)
	Y3 += 0.00000000001*np.cos(0.09891059453 + 2104.5367663768*t)
	Y3 += 0.00000000002*np.cos(2.46195810488 + 1361.5467058442*t)
	Y3 += 0.00000000002*np.cos(5.74044986985 + 1056.2005364515*t)
	Y3 += 0.00000000001*np.cos(0.99824910705 + 160.6088973985*t)
	Y3 += 0.00000000001*np.cos(1.62638790866 + 483.2205421786*t)
	Y3 += 0.00000000001*np.cos(3.50149700133 + 35.1640902212*t)
	Y3 += 0.00000000001*np.cos(5.79259488047 + 52705.49724824299*t)
	Y3 += 0.00000000001*np.cos(5.76299413440 + 2420.9286360334*t)
	Y3 += 0.00000000001*np.cos(0.83909020657 + 41.1019810544*t)
	Y3 += 0.00000000001*np.cos(1.85607665951 + 184.8449074348*t)
	Y3 += 0.00000000001*np.cos(6.01210640761 + 2008.557539159*t)
	Y3 += 0.00000000001*np.cos(1.55579526823 + 661.2379273164*t)
	Y3 += 0.00000000001*np.cos(3.18610098524 + 1141.1340634054*t)
	Y3 += 0.00000000001*np.cos(2.71706778222 + 153.4953503977*t)
	Y3 += 0.00000000001*np.cos(5.56272445862 + 1478.8665740644*t)
	Y3 += 0.00000000001*np.cos(3.16336664316 + 405.2575498736*t)
	Y3 += 0.00000000001*np.cos(5.98469019133 + 1069.6768709277*t)
	Y3 += 0.00000000001*np.cos(2.34179341386 + 824.7421937488*t)
	Y3 += 0.00000000001*np.cos(1.98918668419 + 2097.423219376*t)
	Y3 += 0.00000000001*np.cos(3.14828548619 + 1884.124123938*t)
	return Y3*t*t*t




def Mercury_Y4 (t): # 98 terms of order 4

	Y4 = 0.
	Y4 += 0.00000002278*np.cos(6.27388903010 + 206.1855484372*t)
	Y4 += 0.00000002245*np.cos(1.70782913671 + 220.4126424388*t)
	Y4 += 0.00000001682*np.cos(2.89988955370 + 522.5774180938*t)
	Y4 += 0.00000001636*np.cos(4.60365551069 + 536.8045120954*t)
	Y4 += 0.00000000431*np.cos(1.63508563664 + 227.5261894396*t)
	Y4 += 0.00000000349*np.cos(0.69586528581 + 433.7117378768*t)
	Y4 += 0.00000000299*np.cos(2.91725329579 + 78263.70942472259*t)
	Y4 += 0.00000000291*np.cos(3.00165310731 + 515.463871093*t)
	Y4 -= 0.00000000384
	Y4 += 0.00000000241*np.cos(5.88233684971 + 104351.61256629678*t)
	Y4 += 0.00000000234*np.cos(0.11142561910 + 52175.8062831484*t)
	Y4 += 0.00000000206*np.cos(4.48461122025 + 543.9180590962*t)
	Y4 += 0.00000000204*np.cos(0.11049991144 + 199.0720014364*t)
	Y4 += 0.00000000145*np.cos(2.62003969568 + 130439.51570787099*t)
	Y4 += 0.00000000123*np.cos(5.38340390628 + 1066.49547719*t)
	Y4 += 0.00000000099*np.cos(5.70623543947 + 419.4846438752*t)
	Y4 += 0.00000000117*np.cos(0.28020890432 + 426.598190876*t)
	Y4 += 0.00000000096*np.cos(2.80306869168 + 7.1135470008*t)
	Y4 += 0.00000000073*np.cos(5.65860776108 + 156527.41884944518*t)
	Y4 += 0.00000000061*np.cos(2.82818345895 + 14.2270940016*t)
	Y4 += 0.00000000052*np.cos(3.37268534533 + 1059.3819301892*t)
	Y4 += 0.00000000066*np.cos(2.63263056615 + 1052.2683831884*t)
	Y4 += 0.00000000056*np.cos(3.19455986519 + 26087.9031415742*t)
	Y4 += 0.00000000050*np.cos(0.71576934216 + 440.8252848776*t)
	Y4 += 0.00000000059*np.cos(5.69532892910 + 639.897286314*t)
	Y4 += 0.00000000049*np.cos(6.02940323662 + 647.0108333148*t)
	Y4 += 0.00000000028*np.cos(0.26064157330 + 213.299095438*t)
	Y4 += 0.00000000033*np.cos(2.42044304883 + 182615.32199101939*t)
	Y4 += 0.00000000024*np.cos(1.48209397973 + 234.6397364404*t)
	Y4 += 0.00000000023*np.cos(2.06131193005 + 1045.1548361876*t)
	Y4 += 0.00000000014*np.cos(3.25423631036 + 508.3503240922*t)
	Y4 += 0.00000000013*np.cos(4.48491117264 + 1589.0728952838*t)
	Y4 += 0.00000000014*np.cos(5.46300124767 + 208703.22513259358*t)
	Y4 += 0.00000000011*np.cos(5.24080280774 + 412.3710968744*t)
	Y4 += 0.00000000012*np.cos(4.87116288717 + 853.196381752*t)
	Y4 += 0.00000000010*np.cos(5.03146150255 + 1073.6090241908*t)
	Y4 += 0.00000000010*np.cos(1.05727005468 + 95.9792272178*t)
	Y4 += 0.00000000010*np.cos(6.06799555020 + 1596.1864422846*t)
	Y4 += 0.00000000010*np.cos(5.71091802020 + 529.6909650946*t)
	Y4 += 0.00000000009*np.cos(2.76384051230 + 21.3406410024*t)
	Y4 += 0.00000000008*np.cos(6.23072779166 + 103.0927742186*t)
	Y4 += 0.00000000010*np.cos(2.05522879011 + 117.3198682202*t)
	Y4 += 0.00000000007*np.cos(3.08813888762 + 110.2063212194*t)
	Y4 += 0.00000000007*np.cos(4.14773765350 + 551.031606097*t)
	Y4 += 0.00000000006*np.cos(6.11652071967 + 654.1243803156*t)
	Y4 += 0.00000000005*np.cos(1.24583749139 + 124.433415221*t)
	Y4 += 0.00000000005*np.cos(2.23239849027 + 234791.12827416777*t)
	Y4 += 0.00000000005*np.cos(0.40108066581 + 942.062061969*t)
	Y4 += 0.00000000006*np.cos(5.14748397921 + 860.3099287528*t)
	Y4 += 0.00000000005*np.cos(1.40699621378 + 88.865680217*t)
	Y4 += 0.00000000004*np.cos(6.24919197648 + 632.7837393132*t)
	Y4 += 0.00000000005*np.cos(1.37080964211 + 625.6701923124*t)
	Y4 += 0.00000000004*np.cos(0.18776272435 + 330.6189636582*t)
	Y4 += 0.00000000004*np.cos(1.88093591443 + 728.762966531*t)
	Y4 += 0.00000000004*np.cos(0.14204776620 + 309.2783226558*t)
	Y4 += 0.00000000003*np.cos(0.28739337099 + 191.9584544356*t)
	Y4 += 0.00000000004*np.cos(1.69042467345 + 735.8765135318*t)
	Y4 += 0.00000000003*np.cos(0.60316005015 + 447.9388318784*t)
	Y4 += 0.00000000003*np.cos(0.87226207854 + 302.164775655*t)
	Y4 += 0.00000000003*np.cos(2.70524481937 + 1581.959348283*t)
	Y4 += 0.00000000002*np.cos(4.14482411178 + 1169.5882514086*t)
	Y4 += 0.00000000003*np.cos(0.15041780827 + 323.5054166574*t)
	Y4 += 0.00000000002*np.cos(2.35344419082 + 1155.361157407*t)
	Y4 += 0.00000000002*np.cos(6.26658939437 + 429.7795846137*t)
	Y4 += 0.00000000003*np.cos(4.51313719193 + 316.3918696566*t)
	Y4 += 0.00000000002*np.cos(5.28061358621 + 260879.03141574195*t)
	Y4 += 0.00000000002*np.cos(4.91016885399 + 2118.7638603784*t)
	Y4 += 0.00000000001*np.cos(1.99781026892 + 63.7358983034*t)
	Y4 += 0.00000000002*np.cos(3.78135920108 + 203.0041546995*t)
	Y4 += 0.00000000002*np.cos(1.10796316689 + 223.5940361765*t)
	Y4 += 0.00000000001*np.cos(4.06879161823 + 831.8557407496*t)
	Y4 += 0.00000000001*np.cos(2.20650566797 + 1574.8458012822*t)
	Y4 += 0.00000000001*np.cos(5.87060797450 + 742.9900605326*t)
	Y4 += 0.00000000001*np.cos(0.63254839667 + 149.5631971346*t)
	Y4 += 0.00000000001*np.cos(0.94220550086 + 216.4804891757*t)
	Y4 += 0.00000000001*np.cos(2.68706304185 + 85.8272988312*t)
	Y4 += 0.00000000001*np.cos(2.48150215693 + 423.4167971383*t)
	Y4 += 0.00000000001*np.cos(4.27355998947 + 618.5566453116*t)
	Y4 += 0.00000000001*np.cos(3.90416269039 + 210.1177017003*t)
	Y4 += 0.00000000001*np.cos(5.95376541263 + 337.732510659*t)
	Y4 += 0.00000000001*np.cos(1.98203543124 + 405.2575498736*t)
	Y4 += 0.00000000001*np.cos(3.07160685109 + 1258.4539316256*t)
	Y4 += 0.00000000001*np.cos(0.85310461685 + 949.1756089698*t)
	Y4 += 0.00000000001*np.cos(2.10284025716 + 956.2891559706*t)
	Y4 += 0.00000000001*np.cos(2.25015975765 + 1038.0412891868*t)
	Y4 += 0.00000000001*np.cos(0.07340042854 + 422.6660376129*t)
	Y4 += 0.00000000001*np.cos(5.19829003041 + 18.1592472647*t)
	Y4 += 0.00000000001*np.cos(0.74799227200 + 295.0512286542*t)
	Y4 += 0.00000000001*np.cos(2.74786174307 + 838.9692877504*t)
	Y4 += 0.00000000001*np.cos(2.04140460514 + 286966.93455731616*t)
	Y4 += 0.00000000001*np.cos(0.64687171783 + 131.5469622218*t)
	Y4 += 0.00000000001*np.cos(3.86612290643 + 1485.9801210652*t)
	Y4 += 0.00000000001*np.cos(3.52043585648 + 184.8449074348*t)
	Y4 += 0.00000000001*np.cos(1.36919031011 + 241.7532834412*t)
	Y4 += 0.00000000000*np.cos(5.69629039994 + 1251.3403846248*t)
	Y4 += 0.00000000000*np.cos(2.96705876683 + 611.4430983108*t)
	Y4 += 0.00000000001*np.cos(0.96127473040 + 1361.5467058442*t)
	Y4 += 0.00000000000*np.cos(2.18676531283 + 1471.7530270636*t)
	return Y4*t*t*t*t




def Mercury_Y5 (t): # 43 terms of order 5

	Y5 = 0.
	Y5 += 0.00000000168*np.cos(1.70751121627 + 206.1855484372*t)
	Y5 += 0.00000000168*np.cos(6.23113008656 + 220.4126424388*t)
	Y5 += 0.00000000126*np.cos(4.78360062168 + 522.5774180938*t)
	Y5 += 0.00000000121*np.cos(2.73213408225 + 536.8045120954*t)
	Y5 += 0.00000000065*np.cos(6.17991345652 + 227.5261894396*t)
	Y5 += 0.00000000047*np.cos(4.76645839063 + 515.463871093*t)
	Y5 += 0.00000000038*np.cos(5.19126826175 + 433.7117378768*t)
	Y5 += 0.00000000032*np.cos(2.69880941648 + 543.9180590962*t)
	Y5 += 0.00000000027*np.cos(1.88223142168 + 199.0720014364*t)
	Y5 += 0.00000000011*np.cos(1.18187733048 + 14.2270940016*t)
	Y5 += 0.00000000011*np.cos(3.76420251280 + 1066.49547719*t)
	Y5 += 0.00000000010*np.cos(5.22684912304 + 440.8252848776*t)
	Y5 += 0.00000000007*np.cos(4.23388483049 + 647.0108333148*t)
	Y5 += 0.00000000005*np.cos(4.36366479961 + 104351.61256629678*t)
	Y5 += 0.00000000004*np.cos(1.29818204726 + 78263.70942472259*t)
	Y5 += 0.00000000004*np.cos(4.91327178242 + 1052.2683831884*t)
	Y5 += 0.00000000003*np.cos(1.10210039292 + 130439.51570787099*t)
	Y5 += 0.00000000004*np.cos(2.02140363828 + 419.4846438752*t)
	Y5 += 0.00000000003*np.cos(2.32804418834 + 26087.9031415742*t)
	Y5 += 0.00000000004
	Y5 += 0.00000000003*np.cos(3.88823715659 + 639.897286314*t)
	Y5 += 0.00000000003*np.cos(6.08770400766 + 234.6397364404*t)
	Y5 += 0.00000000003*np.cos(3.92465699188 + 52175.8062831484*t)
	Y5 += 0.00000000002*np.cos(5.07541839899 + 191.9584544356*t)
	Y5 += 0.00000000002*np.cos(4.00021439308 + 426.598190876*t)
	Y5 += 0.00000000002*np.cos(4.13335263836 + 156527.41884944518*t)
	Y5 += 0.00000000002*np.cos(3.32317518434 + 1073.6090241908*t)
	Y5 += 0.00000000002*np.cos(4.64180795349 + 1045.1548361876*t)
	Y5 += 0.00000000001*np.cos(3.09946039705 + 88.865680217*t)
	Y5 += 0.00000000001*np.cos(0.32868254087 + 7.1135470008*t)
	Y5 += 0.00000000001*np.cos(3.90945727398 + 405.2575498736*t)
	Y5 += 0.00000000001*np.cos(5.35212670493 + 213.299095438*t)
	Y5 += 0.00000000001*np.cos(4.33591184160 + 654.1243803156*t)
	Y5 += 0.00000000001*np.cos(2.98586613188 + 853.196381752*t)
	Y5 += 0.00000000001*np.cos(0.88060083637 + 182615.32199101939*t)
	Y5 += 0.00000000001*np.cos(5.47044078046 + 124.433415221*t)
	Y5 += 0.00000000001*np.cos(4.82578898393 + 508.3503240922*t)
	Y5 += 0.00000000001*np.cos(5.79808197162 + 551.031606097*t)
	Y5 += 0.00000000001*np.cos(4.34409570572 + 110.2063212194*t)
	Y5 += 0.00000000001*np.cos(3.32048408656 + 860.3099287528*t)
	Y5 += 0.00000000001*np.cos(5.15758520752 + 447.9388318784*t)
	Y5 += 0.00000000000*np.cos(3.53521969532 + 302.164775655*t)
	Y5 += 0.00000000001*np.cos(3.91898663672 + 208703.22513259358*t)
	return Y5*t*t*t*t*t




def Mercury_Z0 (t): # 625 terms of order 0

	Z0 = 0.
	Z0 += 0.04607664562*np.cos(1.99295081967 + 26087.9031415742*t)
	Z0 -= 0.00709887021
	Z0 += 0.00469171540*np.cos(5.04215742764 + 52175.8062831484*t)
	Z0 += 0.00071626383*np.cos(1.80894256071 + 78263.70942472259*t)
	Z0 += 0.00011810801*np.cos(0.46073218799 + 213.299095438*t)
	Z0 += 0.00012957444*np.cos(4.85922032010 + 104351.61256629678*t)
	Z0 += 0.00011268745*np.cos(0.41669991860 + 529.6909650946*t)
	Z0 += 0.00004802047*np.cos(4.58264625090 + 38.1330356378*t)
	Z0 += 0.00002575002*np.cos(1.62646731545 + 130439.51570787099*t)
	Z0 += 0.00001131032*np.cos(5.75872803701 + 74.7815985673*t)
	Z0 += 0.00000543259*np.cos(4.67698860167 + 156527.41884944518*t)
	Z0 += 0.00000331010*np.cos(5.99413995809 + 426.598190876*t)
	Z0 += 0.00000316945*np.cos(0.73299217892 + 1059.3819301892*t)
	Z0 += 0.00000119462*np.cos(1.44437994097 + 182615.32199101939*t)
	Z0 += 0.00000094261*np.cos(3.71011866926 + 206.1855484372*t)
	Z0 += 0.00000081856*np.cos(0.33912763990 + 220.4126424388*t)
	Z0 += 0.00000079477*np.cos(4.94442849343 + 27197.2816936676*t)
	Z0 += 0.00000082635*np.cos(2.03127961938 + 24978.5245894808*t)
	Z0 += 0.00000043138*np.cos(5.66841713930 + 20426.571092422*t)
	Z0 += 0.00000034677*np.cos(2.36736170874 + 25028.521211385*t)
	Z0 += 0.00000040804*np.cos(0.45468727848 + 522.5774180938*t)
	Z0 += 0.00000032337*np.cos(1.29099631099 + 31749.2351907264*t)
	Z0 += 0.00000031665*np.cos(3.44561891342 + 536.8045120954*t)
	Z0 += 0.00000027465*np.cos(3.57680072404 + 5661.3320491522*t)
	Z0 += 0.00000027081*np.cos(4.49499356963 + 208703.22513259358*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000025914*np.cos(1.94082999599 + 149.5631971346*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000020978*np.cos(4.46131555233 + 4551.9534970588*t)
	Z0 += 0.00000020602*np.cos(1.12768557199 + 1109.3785520934*t)
	Z0 += 0.00000020252*np.cos(0.11722157720 + 51116.4243529592*t)
	Z0 += 0.00000019875*np.cos(3.17169650892 + 76.2660712756*t)
	Z0 += 0.00000023561*np.cos(1.82361021215 + 53285.1848352418*t)
	Z0 += 0.00000021200*np.cos(1.53474687063 + 7.1135470008*t)
	Z0 += 0.00000014791*np.cos(1.09514648778 + 1589.0728952838*t)
	Z0 += 0.00000014150*np.cos(4.42485698284 + 57837.1383323006*t)
	Z0 += 0.00000016632*np.cos(5.09118864825 + 51066.427731055*t)
	Z0 += 0.00000014485*np.cos(1.58357220045 + 110.2063212194*t)
	Z0 += 0.00000013765*np.cos(5.28505135033 + 639.897286314*t)
	Z0 += 0.00000011609*np.cos(3.48812792468 + 21535.9496445154*t)
	Z0 += 0.00000010488*np.cos(2.26900204003 + 316.3918696566*t)
	Z0 += 0.00000010476*np.cos(2.71906856694 + 419.4846438752*t)
	Z0 += 0.00000009897*np.cos(2.80940292918 + 27043.5028831828*t)
	Z0 += 0.00000008380*np.cos(2.46820093103 + 46514.4742339962*t)
	Z0 += 0.00000008040*np.cos(3.77010741170 + 73.297125859*t)
	Z0 += 0.00000007834*np.cos(4.08006285427 + 25132.3033999656*t)
	Z0 += 0.00000007169*np.cos(2.43861625280 + 47623.8527860896*t)
	Z0 += 0.00000006283*np.cos(1.26244592145 + 234791.12827416777*t)
	Z0 += 0.00000006189*np.cos(3.24598311063 + 77204.32749453338*t)
	Z0 += 0.00000006312*np.cos(3.60156222051 + 27147.28507176339*t)
	Z0 += 0.00000005874*np.cos(3.18517530495 + 14765.2390432698*t)
	Z0 += 0.00000005464*np.cos(0.18067146403 + 13521.7514415914*t)
	Z0 += 0.00000005844*np.cos(4.88684915394 + 79373.08797681599*t)
	Z0 += 0.00000005408*np.cos(2.41481746465 + 103.0927742186*t)
	Z0 += 0.00000005084*np.cos(2.88826076001 + 12566.1516999828*t)
	Z0 += 0.00000004626*np.cos(5.87430676751 + 433.7117378768*t)
	Z0 += 0.00000005778*np.cos(4.74518603718 + 30639.856638633*t)
	Z0 += 0.00000004470*np.cos(5.94243776120 + 11322.6640983044*t)
	Z0 += 0.00000004084*np.cos(6.10730721947 + 41962.5207369374*t)
	Z0 += 0.00000003921*np.cos(1.19592374632 + 83925.04147387479*t)
	Z0 += 0.00000003933*np.cos(1.60795544806 + 25661.3049506982*t)
	Z0 += 0.00000004046*np.cos(3.08469176646 + 51646.11531805379*t)
	Z0 += 0.00000003739*np.cos(2.04428825509 + 15874.6175953632*t)
	Z0 += 0.00000003728*np.cos(1.74332154184 + 24498.8302462904*t)
	Z0 += 0.00000003797*np.cos(1.86233694539 + 77154.33087262919*t)
	Z0 += 0.00000003417*np.cos(4.10830949198 + 39609.6545831656*t)
	Z0 += 0.00000003952*np.cos(0.33515918045 + 1.4844727083*t)
	Z0 += 0.00000003691*np.cos(3.50893180252 + 37410.5672398786*t)
	Z0 += 0.00000002644*np.cos(5.60089521868 + 73711.75592766379*t)
	Z0 += 0.00000003021*np.cos(2.91624815440 + 10213.285546211*t)
	Z0 += 0.00000003230*np.cos(5.39015797984 + 955.5997416086*t)
	Z0 += 0.00000002653*np.cos(5.52156950287 + 26617.5941066688*t)
	Z0 += 0.00000002526*np.cos(5.49112478707 + 6283.0758499914*t)
	Z0 += 0.00000003017*np.cos(6.08863660917 + 53131.406024757*t)
	Z0 += 0.00000003020*np.cos(5.46768108443 + 25558.2121764796*t)
	Z0 += 0.00000002574*np.cos(5.41501596147 + 632.7837393132*t)
	Z0 += 0.00000002540*np.cos(6.13336079937 + 1052.2683831884*t)
	Z0 += 0.00000002473*np.cos(6.11219356479 + 1162.4747044078*t)
	Z0 += 0.00000002169*np.cos(5.85843688724 + 50586.73338786459*t)
	Z0 += 0.00000002217*np.cos(5.81930894103 + 51749.20809227239*t)
	Z0 += 0.00000002036*np.cos(2.79411907992 + 7238.67559160*t)
	Z0 += 0.00000001845*np.cos(3.75394848469 + 1066.49547719*t)
	Z0 += 0.00000001904*np.cos(0.02429449494 + 33326.5787331742*t)
	Z0 += 0.00000001841*np.cos(3.31987542265 + 36301.18868778519*t)
	Z0 += 0.00000001693*np.cos(0.04022611885 + 103292.23063610759*t)
	Z0 += 0.00000001814*np.cos(0.58414302882 + 63498.47038145279*t)
	Z0 += 0.00000001786*np.cos(3.14233644575 + 846.0828347512*t)
	Z0 += 0.00000001910*np.cos(5.54302892735 + 72602.37737557039*t)
	Z0 += 0.00000001560*np.cos(0.96215455240 + 65697.55772473979*t)
	Z0 += 0.00000001566*np.cos(1.99768150464 + 202.2533951741*t)
	Z0 += 0.00000001605*np.cos(0.84854708960 + 51220.20654153979*t)
	Z0 += 0.00000001504*np.cos(0.65181450250 + 3340.6124266998*t)
	Z0 += 0.00000001595*np.cos(5.65216619091 + 26068.2333806744*t)
	Z0 += 0.00000001487*np.cos(1.66950376778 + 105460.99111839019*t)
	Z0 += 0.00000001595*np.cos(1.47238921630 + 26107.57290247399*t)
	Z0 += 0.00000001485*np.cos(4.31307667056 + 260879.03141574195*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001344*np.cos(3.05188579262 + 68050.42387851159*t)
	Z0 += 0.00000001601*np.cos(0.69333064931 + 9103.9069941176*t)
	Z0 += 0.00000001323*np.cos(4.33247461424 + 949.1756089698*t)
	Z0 += 0.00000001224*np.cos(3.56543079781 + 19804.8272915828*t)
	Z0 += 0.00000001258*np.cos(2.62817126488 + 52705.49724824299*t)
	Z0 += 0.00000001386*np.cos(0.42909271065 + 53235.18821333759*t)
	Z0 += 0.00000001137*np.cos(6.15183461939 + 2.9689454166*t)
	Z0 += 0.00000001392*np.cos(0.41896396083 + 18849.2275499742*t)
	Z0 += 0.00000001104*np.cos(1.37365365216 + 45892.73043315699*t)
	Z0 += 0.00000001028*np.cos(0.21025596115 + 227.5261894396*t)
	Z0 += 0.00000001191*np.cos(5.76715631957 + 19317.1925403286*t)
	Z0 += 0.00000001218*np.cos(6.16642870453 + 77734.01845962799*t)
	Z0 += 0.00000000991*np.cos(0.77508695125 + 32858.61374281979*t)
	Z0 += 0.00000001039*np.cos(4.25003847002 + 110012.94461544899*t)
	Z0 += 0.00000001155*np.cos(1.83291524170 + 16983.9961474566*t)
	Z0 += 0.00000000913*np.cos(4.91386835375 + 103242.23401420339*t)
	Z0 += 0.00000001096*np.cos(2.77782845562 + 26091.7844769322*t)
	Z0 += 0.00000000882*np.cos(0.48413591726 + 209.3669421749*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000000843*np.cos(2.10283893013 + 23869.1460373874*t)
	Z0 += 0.00000001147*np.cos(1.40069226758 + 56727.7597802072*t)
	Z0 += 0.00000001096*np.cos(4.34969785012 + 26084.0218062162*t)
	Z0 += 0.00000000832*np.cos(1.52051620701 + 2118.7638603784*t)
	Z0 += 0.00000000888*np.cos(5.96405172933 + 38654.05484155699*t)
	Z0 += 0.00000000798*np.cos(5.90979724117 + 43071.8992890308*t)
	Z0 += 0.00000000894*np.cos(6.20891949330 + 40853.142184844*t)
	Z0 += 0.00000000751*np.cos(2.38280961577 + 99799.65906923798*t)
	Z0 += 0.00000000867*np.cos(2.91658316884 + 148.0787244263*t)
	Z0 += 0.00000000858*np.cos(3.48194203031 + 59414.4818747484*t)
	Z0 += 0.00000000903*np.cos(4.51539427543 + 3442.5749449654*t)
	Z0 += 0.00000000846*np.cos(3.60649450344 + 217.2312487011*t)
	Z0 += 0.00000000816*np.cos(4.68549846425 + 28306.66024576099*t)
	Z0 += 0.00000000739*np.cos(4.03898100455 + 26514.5013324502*t)
	Z0 += 0.00000000874*np.cos(3.33462533468 + 22645.32819660879*t)
	Z0 += 0.00000000685*np.cos(2.68994541603 + 76674.63652943878*t)
	Z0 += 0.00000000779*np.cos(3.77257775192 + 63.7358983034*t)
	Z0 += 0.00000000718*np.cos(4.62346837191 + 853.196381752*t)
	Z0 += 0.00000000933*np.cos(3.52008984237 + 6770.7106012456*t)
	Z0 += 0.00000000822*np.cos(6.20394897991 + 323.5054166574*t)
	Z0 += 0.00000000668*np.cos(2.67447570603 + 77837.11123384659*t)
	Z0 += 0.00000000688*np.cos(4.13735845510 + 27676.976036858*t)
	Z0 += 0.00000000747*np.cos(2.88413728742 + 79219.30916633119*t)
	Z0 += 0.00000000594*np.cos(4.72204801083 + 29530.4780865396*t)
	Z0 += 0.00000000687*np.cos(2.88181717922 + 71.8126531507*t)
	Z0 += 0.00000000580*np.cos(0.49131159361 + 62389.09182935939*t)
	Z0 += 0.00000000560*np.cos(0.58980434738 + 26080.78959457339*t)
	Z0 += 0.00000000566*np.cos(1.76588678024 + 742.9900605326*t)
	Z0 += 0.00000000459*np.cos(3.95268976842 + 77.7505439839*t)
	Z0 += 0.00000000460*np.cos(2.41008353609 + 25448.00585526019*t)
	Z0 += 0.00000000453*np.cos(4.02646064195 + 91785.46086631398*t)
	Z0 += 0.00000000575*np.cos(3.85836565065 + 199.0720014364*t)
	Z0 += 0.00000000441*np.cos(3.60120922804 + 89586.37352302698*t)
	Z0 += 0.00000000473*np.cos(3.19147656788 + 25874.6040461362*t)
	Z0 += 0.00000000452*np.cos(3.10205575226 + 129380.13377768178*t)
	Z0 += 0.00000000421*np.cos(5.42036909165 + 11.0457002639*t)
	Z0 += 0.00000000495*np.cos(4.35094686160 + 58946.51688439399*t)
	Z0 += 0.00000000395*np.cos(0.29737033271 + 25934.1243310894*t)
	Z0 += 0.00000000392*np.cos(0.53546585935 + 26241.681952059*t)
	Z0 += 0.00000000382*np.cos(4.72731471129 + 131548.89425996438*t)
	Z0 += 0.00000000382*np.cos(4.49198737842 + 71980.63357473118*t)
	Z0 += 0.00000000534*np.cos(0.54255389653 + 515.463871093*t)
	Z0 += 0.00000000391*np.cos(3.41883762677 + 224.3447957019*t)
	Z0 += 0.00000000383*np.cos(0.89770484162 + 151.0476698429*t)
	Z0 += 0.00000000368*np.cos(3.89892172772 + 77308.10968311399*t)
	Z0 += 0.00000000427*np.cos(1.40024993586 + 14.2270940016*t)
	Z0 += 0.00000000351*np.cos(1.04745682138 + 2218.7571041868*t)
	Z0 += 0.00000000356*np.cos(6.12309999532 + 94138.32702008578*t)
	Z0 += 0.00000000458*np.cos(2.31746139528 + 98690.28051714458*t)
	Z0 += 0.00000000327*np.cos(4.52406643775 + 52195.47604404819*t)
	Z0 += 0.00000000393*np.cos(3.09725258397 + 69159.80243060499*t)
	Z0 += 0.00000000319*np.cos(1.05944718196 + 117.3198682202*t)
	Z0 += 0.00000000310*np.cos(1.10653094623 + 23969.1392811958*t)
	Z0 += 0.00000000356*np.cos(1.08062840940 + 286966.93455731616*t)
	Z0 += 0.00000000312*np.cos(6.24838646568 + 216.4804891757*t)
	Z0 += 0.00000000345*np.cos(5.71957868514 + 78793.40038981718*t)
	Z0 += 0.00000000293*np.cos(1.74897333943 + 54394.56338733519*t)
	Z0 += 0.00000000293*np.cos(5.16317925344 + 647.0108333148*t)
	Z0 += 0.00000000314*np.cos(4.10256974515 + 210.1177017003*t)
	Z0 += 0.00000000325*np.cos(2.41844865673 + 52156.1365222486*t)
	Z0 += 0.00000000296*np.cos(1.59458223926 + 309.2783226558*t)
	Z0 += 0.00000000273*np.cos(0.34374545554 + 51535.90899683439*t)
	Z0 += 0.00000000298*np.cos(5.25958947836 + 415.5524906121*t)
	Z0 += 0.00000000252*np.cos(2.07789295059 + 48733.23133818299*t)
	Z0 += 0.00000000276*np.cos(3.54425558449 + 525.7588118315*t)
	Z0 += 0.00000000326*np.cos(3.49941746899 + 79323.09135491178*t)
	Z0 += 0.00000000327*np.cos(2.94651885500 + 103821.92160120218*t)
	Z0 += 0.00000000300*np.cos(3.53612598449 + 26301.2022370122*t)
	Z0 += 0.00000000317*np.cos(3.85456671343 + 85.8272988312*t)
	Z0 += 0.00000000244*np.cos(0.14590577298 + 1692.1656695024*t)
	Z0 += 0.00000000277*np.cos(0.31958662741 + 138.5174968707*t)
	Z0 += 0.00000000241*np.cos(3.32660302434 + 543.9180590962*t)
	Z0 += 0.00000000274*np.cos(1.02128544399 + 136100.84775702319*t)
	Z0 += 0.00000000227*np.cos(1.68291413296 + 129330.13715577759*t)
	Z0 += 0.00000000264*np.cos(4.42527687575 + 82815.66292178139*t)
	Z0 += 0.00000000280*np.cos(3.47711681992 + 44937.1306915484*t)
	Z0 += 0.00000000207*np.cos(5.26698515692 + 25938.3399444396*t)
	Z0 += 0.00000000233*np.cos(1.58956295605 + 26095.016688575*t)
	Z0 += 0.00000000211*np.cos(2.55179422569 + 45405.0956819028*t)
	Z0 += 0.00000000223*np.cos(1.11566460119 + 52171.9249477904*t)
	Z0 += 0.00000000195*np.cos(5.61180266071 + 25021.4076643842*t)
	Z0 += 0.00000000204*np.cos(5.44212122344 + 125887.56221081219*t)
	Z0 += 0.00000000198*np.cos(2.49240240273 + 95.9792272178*t)
	Z0 += 0.00000000193*np.cos(2.20507758963 + 25035.6347583858*t)
	Z0 += 0.00000000187*np.cos(5.29895224815 + 1478.8665740644*t)
	Z0 += 0.00000000189*np.cos(5.78823648500 + 102762.53967101299*t)
	Z0 += 0.00000000213*np.cos(1.31985764486 + 26555.8681319286*t)
	Z0 += 0.00000000191*np.cos(0.24359410467 + 85502.38501632259*t)
	Z0 += 0.00000000195*np.cos(5.97596513107 + 105307.21230790539*t)
	Z0 += 0.00000000218*np.cos(5.85009667782 + 25619.9381512198*t)
	Z0 += 0.00000000181*np.cos(5.75215140812 + 103925.01437542078*t)
	Z0 += 0.00000000186*np.cos(4.39437140248 + 277.0349937414*t)
	Z0 += 0.00000000190*np.cos(3.25444605074 + 13655.8604911764*t)
	Z0 += 0.00000000213*np.cos(0.01481073233 + 1581.959348283*t)
	Z0 += 0.00000000242*np.cos(0.43270824867 + 533.6231183577*t)
	Z0 += 0.00000000177*np.cos(5.31586012519 + 50057.04242277*t)
	Z0 += 0.00000000199*np.cos(5.68974720641 + 956.2891559706*t)
	Z0 += 0.00000000207*np.cos(2.75433176036 + 64741.95798313119*t)
	Z0 += 0.00000000224*np.cos(5.82663546732 + 52179.6876185064*t)
	Z0 += 0.00000000166*np.cos(5.16708694657 + 49957.0491789616*t)
	Z0 += 0.00000000171*np.cos(1.99193197138 + 26094.53170047421*t)
	Z0 += 0.00000000159*np.cos(2.10978774324 + 32370.9789915656*t)
	Z0 += 0.00000000164*np.cos(5.82981713266 + 12432.0426503978*t)
	Z0 += 0.00000000199*np.cos(3.05926705479 + 66941.04532641819*t)
	Z0 += 0.00000000161*np.cos(3.79231132145 + 490.3340891794*t)
	Z0 += 0.00000000171*np.cos(5.13520423660 + 26081.27458267419*t)
	Z0 += 0.00000000150*np.cos(0.90885651206 + 52389.1053785864*t)
	Z0 += 0.00000000146*np.cos(0.92939894424 + 114.3991069134*t)
	Z0 += 0.00000000184*np.cos(1.74487163243 + 51962.5071877104*t)
	Z0 += 0.00000000158*np.cos(0.75767760137 + 1265.5674786264*t)
	Z0 += 0.00000000164*np.cos(0.91431121775 + 52602.4044740244*t)
	Z0 += 0.00000000138*np.cos(5.40226519416 + 26011.6370702986*t)
	Z0 += 0.00000000149*np.cos(2.17444239275 + 52168.69273614759*t)
	Z0 += 0.00000000184*np.cos(1.61828580097 + 20760.4270331914*t)
	Z0 += 0.00000000152*np.cos(5.88161397387 + 6681.2248533996*t)
	Z0 += 0.00000000129*np.cos(4.11253826151 + 1596.1864422846*t)
	Z0 += 0.00000000152*np.cos(0.96120452018 + 53764.8791784322*t)
	Z0 += 0.00000000146*np.cos(5.57207251195 + 58458.88213313979*t)
	Z0 += 0.00000000150*np.cos(3.58807734183 + 88476.99497093359*t)
	Z0 += 0.00000000128*np.cos(3.49556203334 + 1375.7737998458*t)
	Z0 += 0.00000000124*np.cos(1.42633058836 + 55618.3812281138*t)
	Z0 += 0.00000000154*np.cos(0.00941929392 + 735.8765135318*t)
	Z0 += 0.00000000129*np.cos(5.30043284887 + 351.8165923087*t)
	Z0 += 0.00000000141*np.cos(1.44033578815 + 5327.4761083828*t)
	Z0 += 0.00000000126*np.cos(0.80278847447 + 117873.36400788819*t)
	Z0 += 0.00000000117*np.cos(4.81725910872 + 625.6701923124*t)
	Z0 += 0.00000000118*np.cos(3.91167705851 + 19406.6782881746*t)
	Z0 += 0.00000000117*np.cos(4.68118162480 + 52182.9198301492*t)
	Z0 += 0.00000000130*np.cos(3.12963980623 + 38519.945791972*t)
	Z0 += 0.00000000113*np.cos(3.04973288935 + 532.8723588323*t)
	Z0 += 0.00000000123*np.cos(2.90959272560 + 52026.2430860138*t)
	Z0 += 0.00000000116*np.cos(0.92093201468 + 526.5095713569*t)
	Z0 += 0.00000000129*np.cos(1.11079063120 + 33.6796175129*t)
	Z0 += 0.00000000114*np.cos(3.34729061863 + 51109.31080595839*t)
	Z0 += 0.00000000109*np.cos(0.37062017000 + 115674.27666460119*t)
	Z0 += 0.00000000108*np.cos(5.35523619654 + 46848.3301747656*t)
	Z0 += 0.00000000120*np.cos(6.15890498480 + 155468.03691925599*t)
	Z0 += 0.00000000105*np.cos(1.26949313866 + 98068.53671630539*t)
	Z0 += 0.00000000124*np.cos(5.59073645014 + 74821.13447975718*t)
	Z0 += 0.00000000113*np.cos(5.37283602123 + 124778.18365871879*t)
	Z0 += 0.00000000101*np.cos(1.50859657746 + 157636.79740153858*t)
	Z0 += 0.00000000112*np.cos(6.24044765899 + 51123.53789995999*t)
	Z0 += 0.00000000095*np.cos(4.92440852569 + 4.4534181249*t)
	Z0 += 0.00000000089*np.cos(0.66689996363 + 103396.01282468818*t)
	Z0 += 0.00000000106*np.cos(2.29924580245 + 111.4301614968*t)
	Z0 += 0.00000000088*np.cos(3.24234443321 + 26727.8004278882*t)
	Z0 += 0.00000000103*np.cos(3.99294762314 + 70.3281804424*t)
	Z0 += 0.00000000083*np.cos(3.46887356727 + 77623.81213840858*t)
	Z0 += 0.00000000082*np.cos(3.58489505049 + 52329.58509363319*t)
	Z0 += 0.00000000082*np.cos(2.76598729250 + 35191.8101356918*t)
	Z0 += 0.00000000085*np.cos(6.03717451925 + 127.4717966068*t)
	Z0 += 0.00000000092*np.cos(2.89919284588 + 120226.23016165999*t)
	Z0 += 0.00000000081*np.cos(3.34888362248 + 52022.0274726636*t)
	Z0 += 0.00000000080*np.cos(1.61800826930 + 45494.58142974879*t)
	Z0 += 0.00000000087*np.cos(5.99930110618 + 129909.82474277639*t)
	Z0 += 0.00000000081*np.cos(5.75718254218 + 78.7137518304*t)
	Z0 += 0.00000000075*np.cos(1.29165560989 + 78283.37918562238*t)
	Z0 += 0.00000000097*np.cos(0.94285631414 + 85034.42002596818*t)
	Z0 += 0.00000000076*np.cos(4.37868021510 + 146.594251718*t)
	Z0 += 0.00000000073*np.cos(5.74180456867 + 440.8252848776*t)
	Z0 += 0.00000000080*np.cos(0.27627260080 + 105410.99449648599*t)
	Z0 += 0.00000000094*np.cos(2.55599744292 + 70.8494453042*t)
	Z0 += 0.00000000079*np.cos(5.99645052852 + 95247.70557217918*t)
	Z0 += 0.00000000074*np.cos(0.63932580906 + 64607.84893354619*t)
	Z0 += 0.00000000066*np.cos(4.71152255697 + 80482.46652890938*t)
	Z0 += 0.00000000073*np.cos(3.21815072307 + 52099.5402118728*t)
	Z0 += 0.00000000066*np.cos(2.98683203711 + 23754.70674870219*t)
	Z0 += 0.00000000091*np.cos(2.50052149852 + 104881.30353139139*t)
	Z0 += 0.00000000074*np.cos(6.17414394369 + 137.0330241624*t)
	Z0 += 0.00000000065*np.cos(4.13140277621 + 210.8514148832*t)
	Z0 += 0.00000000086*np.cos(4.13151425024 + 313054.83769889036*t)
	Z0 += 0.00000000064*np.cos(1.17129038283 + 108903.56606335558*t)
	Z0 += 0.00000000059*np.cos(0.79111914848 + 7994.5284420242*t)
	Z0 += 0.00000000065*np.cos(0.25068571900 + 71025.03383312259*t)
	Z0 += 0.00000000064*np.cos(6.21657611750 + 215.7467759928*t)
	Z0 += 0.00000000057*np.cos(4.67121384993 + 28206.6670019526*t)
	Z0 += 0.00000000059*np.cos(4.92822158961 + 78050.41032928458*t)
	Z0 += 0.00000000056*np.cos(2.09215892689 + 76144.94556434419*t)
	Z0 += 0.00000000056*np.cos(1.73304008242 + 25654.19140369739*t)
	Z0 += 0.00000000057*np.cos(4.73385475413 + 155418.04029735178*t)
	Z0 += 0.00000000056*np.cos(5.88720785632 + 26037.90651966999*t)
	Z0 += 0.00000000074*np.cos(5.46823409002 + 78244.0396638228*t)
	Z0 += 0.00000000061*np.cos(4.50066150046 + 25668.418497699*t)
	Z0 += 0.00000000071*np.cos(4.06855895670 + 162188.75089859738*t)
	Z0 += 0.00000000052*np.cos(2.74630211595 + 131395.11544947959*t)
	Z0 += 0.00000000066*np.cos(4.90503958113 + 222.8603229936*t)
	Z0 += 0.00000000055*np.cos(1.23376269855 + 26137.8997634784*t)
	Z0 += 0.00000000051*np.cos(1.98568003824 + 2648.454825473*t)
	Z0 += 0.00000000050*np.cos(0.81093625490 + 3.9321532631*t)
	Z0 += 0.00000000051*np.cos(4.16406216247 + 78259.82808936459*t)
	Z0 += 0.00000000048*np.cos(5.64584502444 + 71492.99882347698*t)
	Z0 += 0.00000000056*np.cos(2.21556357721 + 151975.46535238638*t)
	Z0 += 0.00000000052*np.cos(2.58403290426 + 128850.44281258718*t)
	Z0 += 0.00000000055*np.cos(2.96642314550 + 1169.5882514086*t)
	Z0 += 0.00000000046*np.cos(0.75603425226 + 214.2623032845*t)
	Z0 += 0.00000000047*np.cos(5.59856718264 + 422.6660376129*t)
	Z0 += 0.00000000048*np.cos(2.53427528158 + 130012.91751699499*t)
	Z0 += 0.00000000045*np.cos(3.30208209778 + 111590.28815789679*t)
	Z0 += 0.00000000051*np.cos(2.59172476683 + 78267.59076008058*t)
	Z0 += 0.00000000047*np.cos(1.65481269433 + 18093.37469954999*t)
	Z0 += 0.00000000045*np.cos(4.61275436981 + 2333.196392872*t)
	Z0 += 0.00000000054*np.cos(6.17296259646 + 10021.8372800994*t)
	Z0 += 0.00000000043*np.cos(0.99886063885 + 437.6438911399*t)
	Z0 += 0.00000000042*np.cos(2.94276331302 + 24395.7374720718*t)
	Z0 += 0.00000000042*np.cos(4.02117925826 + 78477.00852016058*t)
	Z0 += 0.00000000042*np.cos(4.06841238442 + 42.5864537627*t)
	Z0 += 0.00000000056*np.cos(4.77237421864 + 28421.0995344462*t)
	Z0 += 0.00000000047*np.cos(6.11377086686 + 93028.94846799239*t)
	Z0 += 0.00000000047*np.cos(3.95753360395 + 109.9456887885*t)
	Z0 += 0.00000000040*np.cos(3.23768263734 + 25234.70675982219*t)
	Z0 += 0.00000000055*np.cos(5.81384971899 + 1045.1548361876*t)
	Z0 += 0.00000000045*np.cos(5.03235979949 + 78256.59587772179*t)
	Z0 += 0.00000000050*np.cos(5.81013134251 + 90829.86112470538*t)
	Z0 += 0.00000000039*np.cos(4.38780950886 + 942.062061969*t)
	Z0 += 0.00000000047*np.cos(3.30738241951 + 212.3358875915*t)
	Z0 += 0.00000000039*np.cos(3.63042667673 + 213.3472795478*t)
	Z0 += 0.00000000038*np.cos(0.54320017724 + 299.1263942692*t)
	Z0 += 0.00000000039*np.cos(5.79384191199 + 380.12776796*t)
	Z0 += 0.00000000036*np.cos(6.02764042024 + 78114.14622758799*t)
	Z0 += 0.00000000035*np.cos(0.19483010119 + 77197.21394753258*t)
	Z0 += 0.00000000038*np.cos(0.85372328004 + 26237.46633870879*t)
	Z0 += 0.00000000036*np.cos(3.61160802929 + 48835.19385644859*t)
	Z0 += 0.00000000036*np.cos(0.36428632576 + 27154.3986187642*t)
	Z0 += 0.00000000037*np.cos(2.58618864774 + 51707.84129279399*t)
	Z0 += 0.00000000047*np.cos(3.11077813997 + 16066.0658614748*t)
	Z0 += 0.00000000035*np.cos(1.89948168639 + 52169.17772424839*t)
	Z0 += 0.00000000035*np.cos(3.09037355598 + 77211.44104153418*t)
	Z0 += 0.00000000035*np.cos(5.86095139046 + 18207.81398823521*t)
	Z0 += 0.00000000038*np.cos(1.94104879109 + 76044.9523205358*t)
	Z0 += 0.00000000032*np.cos(1.45277855585 + 78270.82297172339*t)
	Z0 += 0.00000000044*np.cos(4.36195482299 + 52643.7712735028*t)
	Z0 += 0.00000000032*np.cos(4.70833495807 + 71582.48457132299*t)
	Z0 += 0.00000000037*np.cos(3.75248447021 + 27140.17152476259*t)
	Z0 += 0.00000000039*np.cos(0.43264760342 + 213.2509113282*t)
	Z0 += 0.00000000042*np.cos(2.34341217670 + 84546.78527471398*t)
	Z0 += 0.00000000033*np.cos(4.22087782315 + 111122.32316754239*t)
	Z0 += 0.00000000030*np.cos(2.75112354254 + 838.9692877504*t)
	Z0 += 0.00000000032*np.cos(5.93849066304 + 51742.09454527159*t)
	Z0 += 0.00000000030*np.cos(3.04343823849 + 200.7689224658*t)
	Z0 += 0.00000000040*np.cos(6.23354889167 + 1155.361157407*t)
	Z0 += 0.00000000037*np.cos(2.22778724531 + 25973.46385288896*t)
	Z0 += 0.00000000032*np.cos(4.71988612983 + 628.8515860501*t)
	Z0 += 0.00000000030*np.cos(4.46570213013 + 81706.28436968799*t)
	Z0 += 0.00000000029*np.cos(4.99680928394 + 24491.71669928959*t)
	Z0 += 0.00000000031*np.cos(0.58732919927 + 9.5612275556*t)
	Z0 += 0.00000000035*np.cos(5.04036468235 + 52182.4348420484*t)
	Z0 += 0.00000000033*np.cos(4.30956969733 + 14477.35118320*t)
	Z0 += 0.00000000039*np.cos(3.99296635763 + 78690.30761559859*t)
	Z0 += 0.00000000028*np.cos(3.41723065188 + 7880.08915333899*t)
	Z0 += 0.00000000039*np.cos(0.38970280197 + 114564.89811250778*t)
	Z0 += 0.00000000033*np.cos(3.85407359005 + 143961.26714946238*t)
	Z0 += 0.00000000029*np.cos(2.14304937049 + 150866.08680029298*t)
	Z0 += 0.00000000036*np.cos(4.89757043872 + 26202.34243025941*t)
	Z0 += 0.00000000030*np.cos(0.55025093927 + 33967.99229491319*t)
	Z0 += 0.00000000028*np.cos(1.52043005918 + 40565.2543247742*t)
	Z0 += 0.00000000028*np.cos(2.51169186668 + 1272.6810256272*t)
	Z0 += 0.00000000027*np.cos(3.44440418351 + 141762.17980617538*t)
	Z0 += 0.00000000035*np.cos(2.50821332798 + 72936.23331633979*t)
	Z0 += 0.00000000028*np.cos(5.43761306842 + 388.4651552382*t)
	Z0 += 0.00000000028*np.cos(0.83354394743 + 42153.969003049*t)
	Z0 += 0.00000000036*np.cos(4.02142487381 + 79852.78232000639*t)
	Z0 += 0.00000000026*np.cos(1.15352991801 + 51322.60990139639*t)
	Z0 += 0.00000000026*np.cos(1.28059116172 + 3.1813937377*t)
	Z0 += 0.00000000026*np.cos(0.13577439886 + 22747.2907148744*t)
	Z0 += 0.00000000024*np.cos(0.10065799272 + 1795.258443721*t)
	Z0 += 0.00000000025*np.cos(2.59359350223 + 79.2350166922*t)
	Z0 += 0.00000000025*np.cos(0.71097564554 + 50483.640613646*t)
	Z0 += 0.00000000024*np.cos(2.92248010137 + 121335.60871375339*t)
	Z0 += 0.00000000026*np.cos(4.56151347419 + 183724.70054311278*t)
	Z0 += 0.00000000024*np.cos(2.16545180970 + 32769.1279949738*t)
	Z0 += 0.00000000024*np.cos(5.82405443219 + 108.4612160802*t)
	Z0 += 0.00000000031*np.cos(2.33336639968 + 51756.3216392732*t)
	Z0 += 0.00000000032*np.cos(2.93016714121 + 181555.94006083018*t)
	Z0 += 0.00000000027*np.cos(4.32935860229 + 124156.43985787958*t)
	Z0 += 0.00000000023*np.cos(6.16949223424 + 39743.7636327506*t)
	Z0 += 0.00000000023*np.cos(2.77333133719 + 155997.72788435058*t)
	Z0 += 0.00000000022*np.cos(2.90047805068 + 25863.55834587229*t)
	Z0 += 0.00000000023*np.cos(0.26296960044 + 103711.71527998279*t)
	Z0 += 0.00000000022*np.cos(0.49237419293 + 23439.44831610119*t)
	Z0 += 0.00000000028*np.cos(3.25606570751 + 430.5303441391*t)
	Z0 += 0.00000000022*np.cos(5.77543856958 + 2008.557539159*t)
	Z0 += 0.00000000022*np.cos(0.50346164344 + 2221.856634597*t)
	Z0 += 0.00000000022*np.cos(1.93497630901 + 112.9146342051*t)
	Z0 += 0.00000000027*np.cos(2.77269830479 + 24505.94379329119*t)
	Z0 += 0.00000000022*np.cos(0.39938514656 + 26164.1692128498*t)
	Z0 += 0.00000000022*np.cos(0.07820939757 + 78187.44335344699*t)
	Z0 += 0.00000000022*np.cos(3.71330627735 + 129483.91596626239*t)
	Z0 += 0.00000000027*np.cos(5.97682655989 + 330.6189636582*t)
	Z0 += 0.00000000029*np.cos(5.62929042847 + 44181.27784112419*t)
	Z0 += 0.00000000022*np.cos(4.35422573947 + 26720.68688088739*t)
	Z0 += 0.00000000020*np.cos(1.78582040688 + 212.7778305762*t)
	Z0 += 0.00000000021*np.cos(5.12497732226 + 11610.5519583742*t)
	Z0 += 0.00000000024*np.cos(0.95152270008 + 527.2432845398*t)
	Z0 += 0.00000000020*np.cos(0.12988532533 + 2111.6503133776*t)
	Z0 += 0.00000000025*np.cos(5.36835518856 + 26013.1215430069*t)
	Z0 += 0.00000000024*np.cos(5.55813303813 + 130969.20667296558*t)
	Z0 += 0.00000000020*np.cos(4.79424075731 + 25780.3455206046*t)
	Z0 += 0.00000000020*np.cos(3.82740705898 + 24925.4284371664*t)
	Z0 += 0.00000000020*np.cos(4.26878389727 + 25131.61398560359*t)
	Z0 += 0.00000000021*np.cos(5.10505150441 + 25977.69682035479*t)
	Z0 += 0.00000000020*np.cos(3.32855955978 + 131498.89763806018*t)
	Z0 += 0.00000000020*np.cos(1.29805086237 + 467.9649903544*t)
	Z0 += 0.00000000023*np.cos(2.06377601353 + 100909.03762133139*t)
	Z0 += 0.00000000019*np.cos(2.33132135274 + 26395.46076254379*t)
	Z0 += 0.00000000019*np.cos(4.36776418254 + 860.3099287528*t)
	Z0 += 0.00000000019*np.cos(0.35229627877 + 78417.48823520739*t)
	Z0 += 0.00000000026*np.cos(3.14039215361 + 423.4167971383*t)
	Z0 += 0.00000000019*np.cos(0.44526121834 + 529.7391492044*t)
	Z0 += 0.00000000023*np.cos(3.02283149606 + 532.1386456494*t)
	Z0 += 0.00000000019*np.cos(2.86176933014 + 50579.61984086379*t)
	Z0 += 0.00000000018*np.cos(4.33826105585 + 104371.28232719658*t)
	Z0 += 0.00000000022*np.cos(1.69381062404 + 106570.36967048359*t)
	Z0 += 0.00000000021*np.cos(0.89581658307 + 339142.74084046457*t)
	Z0 += 0.00000000018*np.cos(1.83971917997 + 1368.660252845*t)
	Z0 += 0.00000000025*np.cos(5.95532312645 + 146314.13330323418*t)
	Z0 += 0.00000000020*np.cos(5.86174074496 + 152.5321425512*t)
	Z0 += 0.00000000020*np.cos(0.11725114676 + 52815.7035694624*t)
	Z0 += 0.00000000018*np.cos(1.66756826028 + 23888.81579828719*t)
	Z0 += 0.00000000019*np.cos(3.53063536661 + 529.6427809848*t)
	Z0 += 0.00000000018*np.cos(5.51118637621 + 429.7795846137*t)
	Z0 += 0.00000000017*np.cos(4.39063105551 + 60055.89543648739*t)
	Z0 += 0.00000000017*np.cos(3.17668084118 + 70269.18098269838*t)
	Z0 += 0.00000000017*np.cos(1.74029229152 + 104138.31347085879*t)
	Z0 += 0.00000000017*np.cos(5.24411288462 + 102232.84870591838*t)
	Z0 += 0.00000000023*np.cos(5.85045041991 + 191.2076949102*t)
	Z0 += 0.00000000019*np.cos(0.11691865573 + 78109.93061423779*t)
	Z0 += 0.00000000017*np.cos(3.28697052824 + 25565.3257234804*t)
	Z0 += 0.00000000019*np.cos(0.84289230962 + 188276.65404017158*t)
	Z0 += 0.00000000018*np.cos(4.95715442948 + 350.3321196004*t)
	Z0 += 0.00000000017*np.cos(5.31530503909 + 288.0806940053*t)
	Z0 += 0.00000000018*np.cos(0.47252163890 + 27999.1026247914*t)
	Z0 += 0.00000000016*np.cos(2.81320924670 + 52101.02468458109*t)
	Z0 += 0.00000000017*np.cos(0.12434288249 + 184.7272873558*t)
	Z0 += 0.00000000016*np.cos(4.20710393311 + 134991.46920492979*t)
	Z0 += 0.00000000019*np.cos(0.54267379272 + 50593.84693486539*t)
	Z0 += 0.00000000015*np.cos(5.78613478653 + 24712.1293417284*t)
	Z0 += 0.00000000018*np.cos(2.23136091809 + 104331.94280539699*t)
	Z0 += 0.00000000016*np.cos(3.30957717580 + 97112.93697469679*t)
	Z0 += 0.00000000016*np.cos(1.02655918243 + 26162.6847401415*t)
	Z0 += 0.00000000020*np.cos(2.27820678920 + 213.8203602998*t)
	Z0 += 0.00000000015*np.cos(0.51501957594 + 13362.4497067992*t)
	Z0 += 0.00000000015*np.cos(5.44457668379 + 28286.9904848612*t)
	Z0 += 0.00000000015*np.cos(3.09319808895 + 25984.8103673556*t)
	Z0 += 0.00000000019*np.cos(5.95214817336 + 29428.515568274*t)
	Z0 += 0.00000000015*np.cos(5.13468114097 + 195.1398481733*t)
	Z0 += 0.00000000017*np.cos(1.60411390680 + 26507.38778544939*t)
	Z0 += 0.00000000015*np.cos(0.30526718104 + 203.7378678824*t)
	Z0 += 0.00000000015*np.cos(3.86419292499 + 530.6541729411*t)
	Z0 += 0.00000000016*np.cos(3.62113927445 + 26610.48055966799*t)
	Z0 += 0.00000000014*np.cos(0.06812069189 + 234.6397364404*t)
	Z0 += 0.00000000018*np.cos(4.55509949626 + 51543.0225438352*t)
	Z0 += 0.00000000016*np.cos(4.95762784074 + 25771.5112719176*t)
	Z0 += 0.00000000014*np.cos(3.04648891279 + 703.6331846174*t)
	Z0 += 0.00000000013*np.cos(5.67578126072 + 84.3428261229*t)
	Z0 += 0.00000000016*np.cos(3.53658275362 + 25551.09862947879*t)
	Z0 += 0.00000000013*np.cos(2.28786159405 + 12725.453434775*t)
	Z0 += 0.00000000016*np.cos(3.05451392033 + 26190.99591579279*t)
	Z0 += 0.00000000013*np.cos(5.81922389967 + 157483.01859105378*t)
	Z0 += 0.00000000013*np.cos(0.65559035913 + 173.9422195228*t)
	Z0 += 0.00000000013*np.cos(4.03160498458 + 24356.7807886416*t)
	Z0 += 0.00000000013*np.cos(4.49878848868 + 29416.03879785439*t)
	Z0 += 0.00000000016*np.cos(1.14380482430 + 26404.2950112308*t)
	Z0 += 0.00000000016*np.cos(4.77704247519 + 24609.0365675098*t)
	Z0 += 0.00000000013*np.cos(1.33944288754 + 52808.59002246159*t)
	Z0 += 0.00000000015*np.cos(1.50513017421 + 181505.94343892598*t)
	Z0 += 0.00000000014*np.cos(4.51668225775 + 145.6310438715*t)
	Z0 += 0.00000000013*np.cos(3.86846352248 + 1055.4497769261*t)
	Z0 += 0.00000000012*np.cos(0.92918175452 + 104347.73123093879*t)
	Z0 += 0.00000000014*np.cos(2.44451494167 + 26421.7590823436*t)
	Z0 += 0.00000000012*np.cos(1.66798607577 + 51013.33157874059*t)
	Z0 += 0.00000000012*np.cos(4.24892890325 + 52225.8029050526*t)
	Z0 += 0.00000000014*np.cos(4.68967753702 + 25754.0472008048*t)
	Z0 += 0.00000000013*np.cos(0.63063491269 + 51639.00177105299*t)
	Z0 += 0.00000000013*np.cos(0.51980975221 + 51951.46148744649*t)
	Z0 += 0.00000000015*np.cos(1.17798794037 + 1063.3140834523*t)
	Z0 += 0.00000000013*np.cos(0.11999669275 + 26294.08869001139*t)
	Z0 += 0.00000000012*np.cos(5.63990253843 + 104355.49390165479*t)
	Z0 += 0.00000000013*np.cos(0.37271479520 + 74923.09699802278*t)
	Z0 += 0.00000000015*np.cos(2.19958896111 + 22759.76748529401*t)
	Z0 += 0.00000000014*np.cos(0.82164896652 + 52.6901980395*t)
	Z0 += 0.00000000012*np.cos(5.81331949760 + 74.6697239827*t)
	Z0 += 0.00000000013*np.cos(1.47842980598 + 54294.57014352679*t)
	Z0 += 0.00000000012*np.cos(3.10508217703 + 27819.0254945068*t)
	Z0 += 0.00000000013*np.cos(4.43466163358 + 453.424893819*t)
	Z0 += 0.00000000011*np.cos(2.42209220629 + 97580.90196505119*t)
	Z0 += 0.00000000011*np.cos(3.65812718259 + 1073.6090241908*t)
	Z0 += 0.00000000013*np.cos(2.58513127775 + 116917.76426627958*t)
	Z0 += 0.00000000011*np.cos(4.51381934850 + 265.9892934775*t)
	Z0 += 0.00000000011*np.cos(4.38170902192 + 565.1156877467*t)
	Z0 += 0.00000000011*np.cos(4.76885794954 + 49527.35145767539*t)
	Z0 += 0.00000000011*np.cos(3.92593978045 + 26521.614879451*t)
	Z0 += 0.00000000011*np.cos(2.89444277066 + 119116.85160956658*t)
	Z0 += 0.00000000015*np.cos(0.11132517079 + 528.7277572481*t)
	Z0 += 0.00000000012*np.cos(4.19270486844 + 563.6312150384*t)
	Z0 += 0.00000000012*np.cos(5.58737020094 + 25881.717593137*t)
	Z0 += 0.00000000013*np.cos(5.59537220560 + 156100.82065856918*t)
	Z0 += 0.00000000011*np.cos(3.00019809243 + 217.491881132*t)
	Z0 += 0.00000000012*np.cos(2.01299993075 + 51219.51712717779*t)
	Z0 += 0.00000000012*np.cos(3.25432749571 + 252.6559713532*t)
	Z0 += 0.00000000011*np.cos(2.82174388634 + 210.3783341312*t)
	Z0 += 0.00000000011*np.cos(0.99253734697 + 25455.119402261*t)
	Z0 += 0.00000000014*np.cos(5.68122574937 + 154938.34595416138*t)
	Z0 += 0.00000000012*np.cos(1.52824474801 + 302.164775655*t)
	Z0 += 0.00000000011*np.cos(5.84037285819 + 145.1097790097*t)
	Z0 += 0.00000000013*np.cos(4.98231508398 + 984.6003316219*t)
	Z0 += 0.00000000015*np.cos(5.27886514517 + 178063.36849396059*t)
	Z0 += 0.00000000014*np.cos(6.12654802167 + 52278.89905736699*t)
	Z0 += 0.00000000011*np.cos(0.06908636848 + 52072.71350892979*t)
	Z0 += 0.00000000011*np.cos(0.80982228740 + 104564.91166173479*t)
	Z0 += 0.00000000010*np.cos(4.57790249516 + 2125.8774073792*t)
	Z0 += 0.00000000013*np.cos(3.96505351243 + 68241.87214462319*t)
	Z0 += 0.00000000012*np.cos(2.22934356868 + 32.1951448046*t)
	Z0 += 0.00000000011*np.cos(2.65559265085 + 52125.80966124419*t)
	Z0 += 0.00000000012*np.cos(6.26057108211 + 24176.703658357*t)
	Z0 += 0.00000000012*np.cos(1.73021765373 + 104344.49901929598*t)
	Z0 += 0.00000000010*np.cos(2.77364193598 + 77829.99768684579*t)
	Z0 += 0.00000000010*np.cos(0.58421334028 + 160.6088973985*t)
	Z0 += 0.00000000010*np.cos(0.16740688394 + 212.5483359126*t)
	Z0 += 0.00000000010*np.cos(1.61286239287 + 207.8824694666*t)
	Z0 += 0.00000000010*np.cos(2.83314383566 + 104202.04936916218*t)
	Z0 += 0.00000000010*np.cos(4.05963464737 + 26089.38761428249*t)
	Z0 += 0.00000000012*np.cos(5.40316858194 + 110634.68841628819*t)
	Z0 += 0.00000000010*np.cos(6.17247219966 + 103299.34418310839*t)
	Z0 += 0.00000000010*np.cos(0.02153234343 + 137678.19129947099*t)
	Z0 += 0.00000000012*np.cos(2.25188175428 + 52065.59996192899*t)
	Z0 += 0.00000000010*np.cos(3.11650831039 + 26086.4186688659*t)
	Z0 += 0.00000000012*np.cos(5.37679401763 + 362.8622925726*t)
	Z0 += 0.00000000010*np.cos(3.27287049435 + 103285.11708910679*t)
	Z0 += 0.00000000012*np.cos(5.18451722763 + 68.8437077341*t)
	Z0 += 0.00000000010*np.cos(1.38532261128 + 25446.4895798352*t)
	Z0 += 0.00000000012*np.cos(1.52019007531 + 54509.0026760204*t)
	Z0 += 0.00000000011*np.cos(6.21574870463 + 61279.713277266*t)
	Z0 += 0.00000000009*np.cos(2.88821691711 + 90695.75207512038*t)
	Z0 += 0.00000000009*np.cos(3.00647036484 + 417.0369633204*t)
	Z0 += 0.00000000011*np.cos(2.16522629249 + 26624.70765366959*t)
	Z0 += 0.00000000009*np.cos(4.80391342687 + 27311.72098235281*t)
	Z0 += 0.00000000009*np.cos(4.23373474411 + 52250.5878817157*t)
	Z0 += 0.00000000009*np.cos(5.74437259170 + 26729.31670331319*t)
	Z0 += 0.00000000010*np.cos(3.47517485960 + 140652.80125408198*t)
	Z0 += 0.00000000010*np.cos(5.21528526304 + 412.3710968744*t)
	Z0 += 0.00000000010*np.cos(2.80299508279 + 55516.4187098482*t)
	Z0 += 0.00000000013*np.cos(4.07250716348 + 34282.1784747828*t)
	Z0 += 0.00000000009*np.cos(0.66918270135 + 52698.38370124219*t)
	Z0 += 0.00000000010*np.cos(5.43273059228 + 126996.94076290558*t)
	Z0 += 0.00000000009*np.cos(1.51413989531 + 97670.38771289718*t)
	Z0 += 0.00000000010*np.cos(0.08817228351 + 1485.9801210652*t)
	Z0 += 0.00000000009*np.cos(3.33909678408 + 1911.1994832172*t)
	Z0 += 0.00000000009*np.cos(6.28167845492 + 147423.51185532758*t)
	Z0 += 0.00000000009*np.cos(0.50158036935 + 207.6700211455*t)
	Z0 += 0.00000000010*np.cos(3.89389777532 + 214.0498549634*t)
	Z0 += 0.00000000010*np.cos(0.71259250113 + 137210.22630911658*t)
	Z0 += 0.00000000009*np.cos(4.22285311504 + 12.5301729722*t)
	Z0 += 0.00000000009*np.cos(3.57005441415 + 50800.03248330259*t)
	Z0 += 0.00000000009*np.cos(5.50160718751 + 2199.087343287*t)
	Z0 += 0.00000000010*np.cos(6.10994422833 + 223.5940361765*t)
	Z0 += 0.00000000009*np.cos(2.08845571909 + 51859.41441349179*t)
	Z0 += 0.00000000009*np.cos(4.25308230419 + 26222.0121911592*t)
	Z0 += 0.00000000012*np.cos(2.56562021906 + 74.8934731519*t)
	Z0 += 0.00000000009*np.cos(2.50157520492 + 24864.08530079559*t)
	Z0 += 0.00000000008*np.cos(2.47794653703 + 25440.89230825939*t)
	Z0 += 0.00000000009*np.cos(0.17310329267 + 124.433415221*t)
	Z0 += 0.00000000011*np.cos(1.23818152928 + 216.2198567448*t)
	Z0 += 0.00000000010*np.cos(0.11060519587 + 221.3758502853*t)
	Z0 += 0.00000000009*np.cos(2.85482376043 + 25953.79409198919*t)
	Z0 += 0.00000000008*np.cos(2.29776576843 + 23866.04650697719*t)
	Z0 += 0.00000000009*np.cos(0.78685007135 + 104778.21075717278*t)
	Z0 += 0.00000000008*np.cos(2.67369883765 + 88.865680217*t)
	Z0 += 0.00000000008*np.cos(4.62944551319 + 52492.19815280499*t)
	Z0 += 0.00000000009*np.cos(3.73069830414 + 5.9378908332*t)
	Z0 += 0.00000000009*np.cos(5.48506768547 + 77844.22478084739*t)
	Z0 += 0.00000000010*np.cos(1.12934836943 + 78731.674415077*t)
	Z0 += 0.00000000008*np.cos(2.59549267900 + 26941.0995233262*t)
	Z0 += 0.00000000008*np.cos(4.95780242181 + 78257.08086582259*t)
	Z0 += 0.00000000008*np.cos(2.55696609752 + 17893.6278083656*t)
	Z0 += 0.00000000008*np.cos(4.52002369897 + 104358.72611329758*t)
	Z0 += 0.00000000010*np.cos(2.48242357336 + 218.7157214094*t)
	Z0 += 0.00000000011*np.cos(1.05838551520 + 209.106309744*t)
	Z0 += 0.00000000008*np.cos(3.82529998469 + 76571.54375522019*t)
	Z0 += 0.00000000009*np.cos(1.57363188943 + 24998.19435038059*t)
	Z0 += 0.00000000008*np.cos(0.65301230309 + 8194.2753332086*t)
	Z0 += 0.00000000008*np.cos(4.30691637723 + 77410.51304297059*t)
	Z0 += 0.00000000008*np.cos(5.61648727808 + 77795.74443436819*t)
	Z0 += 0.00000000009*np.cos(2.56370604921 + 50696.93970908399*t)
	Z0 += 0.00000000008*np.cos(2.44699715379 + 425.1137181677*t)
	Z0 += 0.00000000009*np.cos(0.81310827208 + 105940.68546158058*t)
	Z0 += 0.00000000008*np.cos(3.03053180726 + 27780.06881107659*t)
	Z0 += 0.00000000008*np.cos(5.21537078773 + 176953.98994186718*t)
	Z0 += 0.00000000010*np.cos(2.92834886255 + 65.2203710117*t)
	Z0 += 0.00000000008*np.cos(4.00825868583 + 217.964961884*t)
	Z0 += 0.00000000008*np.cos(2.88040588282 + 36109.7404216736*t)
	Z0 += 0.00000000008*np.cos(3.90879186991 + 54087.0057663656*t)
	Z0 += 0.00000000007*np.cos(2.09304055777 + 25344.9130810416*t)
	Z0 += 0.00000000007*np.cos(3.77982679537 + 19.66976089979*t)
	Z0 += 0.00000000007*np.cos(1.66055890695 + 231.4583427027*t)
	Z0 += 0.00000000010*np.cos(2.73461620208 + 225.8292684102*t)
	Z0 += 0.00000000008*np.cos(2.01169539344 + 31415.379249957*t)
	Z0 += 0.00000000008*np.cos(4.90600221547 + 62.2514255951*t)
	Z0 += 0.00000000008*np.cos(6.01136820214 + 207643.84320240439*t)
	Z0 += 0.00000000008*np.cos(1.19554688546 + 21.3406410024*t)
	Z0 += 0.00000000007*np.cos(4.87306863016 + 28.5718080822*t)
	Z0 += 0.00000000008*np.cos(3.29730720599 + 305.3461693927*t)
	Z0 += 0.00000000008*np.cos(6.24227744862 + 38813.3565763492*t)
	Z0 += 0.00000000008*np.cos(1.33108336808 + 55503.94193942859*t)
	Z0 += 0.00000000007*np.cos(3.30804741677 + 23919.1426592916*t)
	Z0 += 0.00000000008*np.cos(3.48746520229 + 53242.3017603384*t)
	Z0 += 0.00000000008*np.cos(5.56477337187 + 27177.6119327678*t)
	Z0 += 0.00000000007*np.cos(0.23049597733 + 72.3339180125*t)
	Z0 += 0.00000000009*np.cos(5.00034866965 + 102132.85546210999*t)
	Z0 += 0.00000000008*np.cos(1.66471235682 + 52290.24557183361*t)
	return Z0




def Mercury_Z1 (t): # 363 terms of order 1

	Z1 = 0.
	Z1 += 0.00108722159*np.cos(3.91134750825 + 26087.9031415742*t)
	Z1 -= 0.00057693223
	Z1 += 0.00004297352*np.cos(2.56373047177 + 52175.8062831484*t)
	Z1 += 0.00002435833*np.cos(0.05112640506 + 78263.70942472259*t)
	Z1 += 0.00000795699*np.cos(3.20041081922 + 104351.61256629678*t)
	Z1 += 0.00000544284*np.cos(1.80380684048 + 213.299095438*t)
	Z1 += 0.00000388127*np.cos(4.66945083146 + 529.6909650946*t)
	Z1 += 0.00000229251*np.cos(0.00558431110 + 130439.51570787099*t)
	Z1 += 0.00000063404*np.cos(3.07612843684 + 156527.41884944518*t)
	Z1 += 0.00000037297*np.cos(5.40131521403 + 206.1855484372*t)
	Z1 += 0.00000028944*np.cos(4.93245710560 + 220.4126424388*t)
	Z1 += 0.00000028635*np.cos(3.15447649004 + 74.7815985673*t)
	Z1 += 0.00000024993*np.cos(3.65901124814 + 426.598190876*t)
	Z1 += 0.00000017253*np.cos(6.13908634954 + 182615.32199101939*t)
	Z1 += 0.00000019440*np.cos(5.71111050710 + 1059.3819301892*t)
	Z1 += 0.00000013738*np.cos(1.71307370446 + 536.8045120954*t)
	Z1 += 0.00000012167*np.cos(2.31153996241 + 522.5774180938*t)
	Z1 += 0.00000009622*np.cos(0.37621894804 + 27197.2816936676*t)
	Z1 += 0.00000008010*np.cos(5.28413417446 + 38.1330356378*t)
	Z1 += 0.00000004973*np.cos(4.30231965334 + 419.4846438752*t)
	Z1 += 0.00000006297*np.cos(0.39728882750 + 24978.5245894808*t)
	Z1 += 0.00000004662*np.cos(2.91492698307 + 208703.22513259358*t)
	Z1 += 0.00000004265*np.cos(6.14782704660 + 7.1135470008*t)
	Z1 += 0.00000002601*np.cos(3.05161174193 + 639.897286314*t)
	Z1 += 0.00000002134*np.cos(4.07059678394 + 433.7117378768*t)
	Z1 += 0.00000002148*np.cos(3.48577221863 + 53285.1848352418*t)
	Z1 += 0.00000001752*np.cos(3.07246871620 + 31749.2351907264*t)
	Z1 += 0.00000001560*np.cos(3.28261094599 + 316.3918696566*t)
	Z1 += 0.00000001734*np.cos(3.48012770286 + 51066.427731055*t)
	Z1 += 0.00000001455*np.cos(6.26535145349 + 1589.0728952838*t)
	Z1 += 0.00000001256*np.cos(5.97163248139 + 234791.12827416777*t)
	Z1 += 0.00000001028*np.cos(5.86909257705 + 149.5631971346*t)
	Z1 += 0.00000000919*np.cos(2.20247811299 + 51116.4243529592*t)
	Z1 += 0.00000000893*np.cos(2.83549644335 + 1109.3785520934*t)
	Z1 += 0.00000000834*np.cos(0.65008044610 + 25028.521211385*t)
	Z1 += 0.00000000813*np.cos(2.10068878826 + 1066.49547719*t)
	Z1 += 0.00000000775*np.cos(4.79688880139 + 227.5261894396*t)
	Z1 += 0.00000000700*np.cos(1.69972966052 + 1052.2683831884*t)
	Z1 += 0.00000000706*np.cos(4.09989437475 + 21535.9496445154*t)
	Z1 += 0.00000000662*np.cos(0.35584811573 + 6283.0758499914*t)
	Z1 += 0.00000000542*np.cos(1.44488755125 + 110.2063212194*t)
	Z1 += 0.00000000549*np.cos(4.55772827645 + 27043.5028831828*t)
	Z1 += 0.00000000534*np.cos(2.34212997128 + 76.2660712756*t)
	Z1 += 0.00000000599*np.cos(1.30707878411 + 5661.3320491522*t)
	Z1 += 0.00000000503*np.cos(0.26513156342 + 77154.33087262919*t)
	Z1 += 0.00000000395*np.cos(4.32073156427 + 47623.8527860896*t)
	Z1 += 0.00000000403*np.cos(1.25691345472 + 36.6485629295*t)
	Z1 += 0.00000000390*np.cos(3.05829239675 + 26107.57290247399*t)
	Z1 += 0.00000000352*np.cos(4.79823464785 + 39.6175083461*t)
	Z1 += 0.00000000370*np.cos(0.26188837520 + 79373.08797681599*t)
	Z1 += 0.00000000342*np.cos(0.06201621683 + 57837.1383323006*t)
	Z1 += 0.00000000446*np.cos(5.55248874462 + 199.0720014364*t)
	Z1 += 0.00000000338*np.cos(2.74361031332 + 260879.03141574195*t)
	Z1 += 0.00000000386*np.cos(4.58193816882 + 10213.285546211*t)
	Z1 += 0.00000000310*np.cos(5.14811665075 + 632.7837393132*t)
	Z1 += 0.00000000367*np.cos(5.32342045882 + 103.0927742186*t)
	Z1 += 0.00000000319*np.cos(4.06638794904 + 26068.2333806744*t)
	Z1 += 0.00000000347*np.cos(5.42940711986 + 37410.5672398786*t)
	Z1 += 0.00000000343*np.cos(2.32388226037 + 515.463871093*t)
	Z1 += 0.00000000329*np.cos(2.57908142670 + 25132.3033999656*t)
	Z1 += 0.00000000282*np.cos(0.72426739653 + 46514.4742339962*t)
	Z1 += 0.00000000303*np.cos(2.97597780334 + 30639.856638633*t)
	Z1 += 0.00000000323*np.cos(3.09339172608 + 20426.571092422*t)
	Z1 += 0.00000000315*np.cos(5.97732845019 + 26084.0218062162*t)
	Z1 += 0.00000000267*np.cos(3.50170128183 + 25558.2121764796*t)
	Z1 += 0.00000000236*np.cos(1.57642784422 + 27147.28507176339*t)
	Z1 += 0.00000000258*np.cos(5.99544147559 + 14.2270940016*t)
	Z1 += 0.00000000267*np.cos(1.13990449748 + 26091.7844769322*t)
	Z1 += 0.00000000235*np.cos(1.49701289406 + 14765.2390432698*t)
	Z1 += 0.00000000266*np.cos(0.49468027720 + 73.297125859*t)
	Z1 += 0.00000000251*np.cos(5.58497774438 + 217.2312487011*t)
	Z1 += 0.00000000211*np.cos(2.45573232741 + 853.196381752*t)
	Z1 += 0.00000000236*np.cos(2.22525353065 + 4551.9534970588*t)
	Z1 += 0.00000000210*np.cos(5.87638250776 + 210.1177017003*t)
	Z1 += 0.00000000200*np.cos(1.60953815793 + 543.9180590962*t)
	Z1 += 0.00000000186*np.cos(4.63128120913 + 209.3669421749*t)
	Z1 += 0.00000000194*np.cos(1.02173542846 + 50586.73338786459*t)
	Z1 += 0.00000000175*np.cos(0.12964063811 + 28306.66024576099*t)
	Z1 += 0.00000000167*np.cos(3.29086340027 + 647.0108333148*t)
	Z1 += 0.00000000188*np.cos(4.45601446980 + 216.4804891757*t)
	Z1 += 0.00000000158*np.cos(4.72011691978 + 13521.7514415914*t)
	Z1 += 0.00000000148*np.cos(0.50941562343 + 23869.1460373874*t)
	Z1 += 0.00000000147*np.cos(4.91154015633 + 202.2533951741*t)
	Z1 += 0.00000000146*np.cos(3.32809085248 + 103242.23401420339*t)
	Z1 += 0.00000000148*np.cos(2.67606270632 + 32858.61374281979*t)
	Z1 += 0.00000000148*np.cos(3.97558333546 + 26617.5941066688*t)
	Z1 += 0.00000000148*np.cos(6.00943832296 + 949.1756089698*t)
	Z1 += 0.00000000144*np.cos(6.17471854034 + 39609.6545831656*t)
	Z1 += 0.00000000143*np.cos(3.70203142149 + 323.5054166574*t)
	Z1 += 0.00000000140*np.cos(0.83132381305 + 735.8765135318*t)
	Z1 += 0.00000000135*np.cos(5.29023702746 + 15874.6175953632*t)
	Z1 += 0.00000000127*np.cos(1.74708107452 + 41962.5207369374*t)
	Z1 += 0.00000000167*np.cos(1.41845890576 + 53131.406024757*t)
	Z1 += 0.00000000142*np.cos(5.51538705616 + 77204.32749453338*t)
	Z1 += 0.00000000143*np.cos(5.60549263164 + 25661.3049506982*t)
	Z1 += 0.00000000135*np.cos(4.51294119590 + 22645.32819660879*t)
	Z1 += 0.00000000122*np.cos(5.67146512225 + 117.3198682202*t)
	Z1 += 0.00000000114*np.cos(1.61571061542 + 51749.20809227239*t)
	Z1 += 0.00000000136*np.cos(2.44803626803 + 24498.8302462904*t)
	Z1 += 0.00000000119*np.cos(0.48505510402 + 2118.7638603784*t)
	Z1 += 0.00000000111*np.cos(5.61693406682 + 51220.20654153979*t)
	Z1 += 0.00000000128*np.cos(4.16885336182 + 19317.1925403286*t)
	Z1 += 0.00000000119*np.cos(3.89351050712 + 72602.37737557039*t)
	Z1 += 0.00000000105*np.cos(2.35643129018 + 63498.47038145279*t)
	Z1 += 0.00000000100*np.cos(2.78745027781 + 1.4844727083*t)
	Z1 += 0.00000000108*np.cos(2.29989754953 + 19804.8272915828*t)
	Z1 += 0.00000000118*np.cos(5.34899821984 + 9103.9069941176*t)
	Z1 += 0.00000000131*np.cos(5.10396827386 + 51646.11531805379*t)
	Z1 += 0.00000000090*np.cos(3.10411714137 + 29530.4780865396*t)
	Z1 += 0.00000000104*np.cos(2.90747009733 + 3340.6124266998*t)
	Z1 += 0.00000000102*np.cos(1.51408473952 + 43071.8992890308*t)
	Z1 += 0.00000000099*np.cos(2.91528801994 + 3442.5749449654*t)
	Z1 += 0.00000000083*np.cos(4.86155505530 + 53235.18821333759*t)
	Z1 += 0.00000000082*np.cos(4.31181501840 + 1162.4747044078*t)
	Z1 += 0.00000000077*np.cos(4.22942639128 + 95.9792272178*t)
	Z1 += 0.00000000091*np.cos(5.79825387142 + 286966.93455731616*t)
	Z1 += 0.00000000079*np.cos(0.36636125409 + 11.0457002639*t)
	Z1 += 0.00000000086*np.cos(1.26853285597 + 52705.49724824299*t)
	Z1 += 0.00000000075*np.cos(1.47982807612 + 525.7588118315*t)
	Z1 += 0.00000000087*np.cos(0.72759501705 + 955.5997416086*t)
	Z1 += 0.00000000076*np.cos(1.24245643745 + 532.8723588323*t)
	Z1 += 0.00000000096*np.cos(0.86129378681 + 63.7358983034*t)
	Z1 += 0.00000000071*np.cos(2.75365102566 + 526.5095713569*t)
	Z1 += 0.00000000071*np.cos(6.10725384639 + 52195.47604404819*t)
	Z1 += 0.00000000069*np.cos(1.67616660064 + 11322.6640983044*t)
	Z1 += 0.00000000087*np.cos(0.48536991993 + 12566.1516999828*t)
	Z1 += 0.00000000070*np.cos(1.30207069777 + 73711.75592766379*t)
	Z1 += 0.00000000087*np.cos(6.02618346605 + 56727.7597802072*t)
	Z1 += 0.00000000074*np.cos(0.83774903676 + 52156.1365222486*t)
	Z1 += 0.00000000063*np.cos(3.98868546710 + 440.8252848776*t)
	Z1 += 0.00000000061*np.cos(2.62473045895 + 533.6231183577*t)
	Z1 += 0.00000000062*np.cos(0.53772034528 + 25035.6347583858*t)
	Z1 += 0.00000000057*np.cos(2.53337210703 + 1596.1864422846*t)
	Z1 += 0.00000000055*np.cos(3.37388306274 + 54394.56338733519*t)
	Z1 += 0.00000000054*np.cos(1.42941204449 + 85.8272988312*t)
	Z1 += 0.00000000057*np.cos(3.98493436395 + 309.2783226558*t)
	Z1 += 0.00000000072*np.cos(5.15200652842 + 6770.7106012456*t)
	Z1 += 0.00000000058*np.cos(2.74579734777 + 52171.9249477904*t)
	Z1 += 0.00000000053*np.cos(3.37195010831 + 105460.99111839019*t)
	Z1 += 0.00000000054*np.cos(3.13274907598 + 16983.9961474566*t)
	Z1 += 0.00000000057*np.cos(4.55150471829 + 40853.142184844*t)
	Z1 += 0.00000000052*np.cos(1.08065292487 + 25021.4076643842*t)
	Z1 += 0.00000000057*np.cos(2.75679326163 + 27676.976036858*t)
	Z1 += 0.00000000050*np.cos(4.80760680648 + 956.2891559706*t)
	Z1 += 0.00000000051*np.cos(0.39392917326 + 742.9900605326*t)
	Z1 += 0.00000000050*np.cos(2.66709856718 + 2218.7571041868*t)
	Z1 += 0.00000000048*np.cos(2.42991055784 + 51535.90899683439*t)
	Z1 += 0.00000000044*np.cos(3.39778429468 + 52168.69273614759*t)
	Z1 += 0.00000000061*np.cos(4.19872301893 + 52179.6876185064*t)
	Z1 += 0.00000000055*np.cos(4.79861662627 + 25448.00585526019*t)
	Z1 += 0.00000000057*np.cos(5.98485072073 + 58946.51688439399*t)
	Z1 += 0.00000000043*np.cos(0.10468670721 + 129330.13715577759*t)
	Z1 += 0.00000000046*np.cos(3.95713790204 + 76674.63652943878*t)
	Z1 += 0.00000000054*np.cos(6.03589506827 + 26080.78959457339*t)
	Z1 += 0.00000000052*np.cos(5.90025920123 + 26095.016688575*t)
	Z1 += 0.00000000047*np.cos(3.30474983516 + 25874.6040461362*t)
	Z1 += 0.00000000039*np.cos(1.38925724838 + 26301.2022370122*t)
	Z1 += 0.00000000038*np.cos(5.10867352468 + 51109.31080595839*t)
	Z1 += 0.00000000039*np.cos(3.92764341118 + 48733.23133818299*t)
	Z1 += 0.00000000037*np.cos(4.06335565460 + 38654.05484155699*t)
	Z1 += 0.00000000036*np.cos(2.58651261399 + 33326.5787331742*t)
	Z1 += 0.00000000036*np.cos(2.37849808537 + 77308.10968311399*t)
	Z1 += 0.00000000035*np.cos(2.51199649101 + 110012.94461544899*t)
	Z1 += 0.00000000047*np.cos(1.79496279487 + 1581.959348283*t)
	Z1 += 0.00000000036*np.cos(0.55224025396 + 625.6701923124*t)
	Z1 += 0.00000000042*np.cos(5.12550293524 + 18849.2275499742*t)
	Z1 += 0.00000000036*np.cos(3.01544789695 + 65697.55772473979*t)
	Z1 += 0.00000000034*np.cos(3.58250413994 + 49957.0491789616*t)
	Z1 += 0.00000000033*np.cos(2.98998399815 + 52182.9198301492*t)
	Z1 += 0.00000000035*np.cos(4.81500543604 + 69159.80243060499*t)
	Z1 += 0.00000000039*np.cos(2.77790342477 + 35.1640902212*t)
	Z1 += 0.00000000030*np.cos(2.26689961718 + 26514.5013324502*t)
	Z1 += 0.00000000041*np.cos(0.69895535280 + 98690.28051714458*t)
	Z1 += 0.00000000030*np.cos(4.35442775962 + 412.3710968744*t)
	Z1 += 0.00000000030*np.cos(5.32057648028 + 59414.4818747484*t)
	Z1 += 0.00000000038*np.cos(5.38040433295 + 224.3447957019*t)
	Z1 += 0.00000000035*np.cos(1.26816443678 + 1045.1548361876*t)
	Z1 += 0.00000000031*np.cos(0.64597904023 + 70.8494453042*t)
	Z1 += 0.00000000028*np.cos(1.68266249602 + 13655.8604911764*t)
	Z1 += 0.00000000028*np.cos(0.94446303339 + 45405.0956819028*t)
	Z1 += 0.00000000027*np.cos(4.36683104110 + 45892.73043315699*t)
	Z1 += 0.00000000026*np.cos(3.58372397053 + 41.1019810544*t)
	Z1 += 0.00000000029*np.cos(0.10950522744 + 32370.9789915656*t)
	Z1 += 0.00000000033*np.cos(4.33155420786 + 78793.40038981718*t)
	Z1 += 0.00000000034*np.cos(4.98037524090 + 83925.04147387479*t)
	Z1 += 0.00000000023*np.cos(5.02100001952 + 38519.945791972*t)
	Z1 += 0.00000000030*np.cos(3.31574729193 + 138.5174968707*t)
	Z1 += 0.00000000027*np.cos(2.80994919073 + 82815.66292178139*t)
	Z1 += 0.00000000028*np.cos(1.74282790985 + 79323.09135491178*t)
	Z1 += 0.00000000027*np.cos(0.28076690940 + 50057.04242277*t)
	Z1 += 0.00000000024*np.cos(1.14783906654 + 71.8126531507*t)
	Z1 += 0.00000000022*np.cos(1.56359401952 + 78.7137518304*t)
	Z1 += 0.00000000030*np.cos(4.47636450035 + 51123.53789995999*t)
	Z1 += 0.00000000022*np.cos(1.22800274368 + 1169.5882514086*t)
	Z1 += 0.00000000023*np.cos(2.29729212380 + 25934.1243310894*t)
	Z1 += 0.00000000021*np.cos(6.12545300745 + 55618.3812281138*t)
	Z1 += 0.00000000028*np.cos(1.99718125621 + 23969.1392811958*t)
	Z1 += 0.00000000020*np.cos(5.02045625760 + 62389.09182935939*t)
	Z1 += 0.00000000027*np.cos(5.94991611742 + 36301.18868778519*t)
	Z1 += 0.00000000024*np.cos(0.09566124749 + 277.0349937414*t)
	Z1 += 0.00000000025*np.cos(3.81085583999 + 103292.23063610759*t)
	Z1 += 0.00000000019*np.cos(1.46315634551 + 215.7467759928*t)
	Z1 += 0.00000000018*np.cos(6.15872883408 + 942.062061969*t)
	Z1 += 0.00000000022*np.cos(5.11742565391 + 52389.1053785864*t)
	Z1 += 0.00000000021*np.cos(4.93349279148 + 151.0476698429*t)
	Z1 += 0.00000000024*np.cos(2.56844167585 + 313054.83769889036*t)
	Z1 += 0.00000000018*np.cos(1.14666568569 + 12432.0426503978*t)
	Z1 += 0.00000000017*np.cos(0.45299038457 + 148.0787244263*t)
	Z1 += 0.00000000021*np.cos(4.43914073078 + 79219.30916633119*t)
	Z1 += 0.00000000017*np.cos(1.26846398958 + 129380.13377768178*t)
	Z1 += 0.00000000017*np.cos(1.01231551874 + 415.5524906121*t)
	Z1 += 0.00000000018*np.cos(4.35450426346 + 23754.70674870219*t)
	Z1 += 0.00000000016*np.cos(3.43674109707 + 25654.19140369739*t)
	Z1 += 0.00000000017*np.cos(2.42309662009 + 1265.5674786264*t)
	Z1 += 0.00000000016*np.cos(4.65513429214 + 234.6397364404*t)
	Z1 += 0.00000000017*np.cos(1.21295214728 + 25619.9381512198*t)
	Z1 += 0.00000000017*np.cos(4.88341452559 + 77837.11123384659*t)
	Z1 += 0.00000000017*np.cos(5.64525452444 + 136100.84775702319*t)
	Z1 += 0.00000000020*np.cos(1.45417843599 + 66941.04532641819*t)
	Z1 += 0.00000000014*np.cos(5.44182921160 + 89586.37352302698*t)
	Z1 += 0.00000000018*np.cos(2.83938591200 + 25668.418497699*t)
	Z1 += 0.00000000018*np.cos(3.80808950852 + 25973.46385288896*t)
	Z1 += 0.00000000014*np.cos(2.87427500051 + 78283.37918562238*t)
	Z1 += 0.00000000019*np.cos(3.54990981323 + 422.6660376129*t)
	Z1 += 0.00000000015*np.cos(1.23233013937 + 26727.8004278882*t)
	Z1 += 0.00000000015*np.cos(4.05286495428 + 330.6189636582*t)
	Z1 += 0.00000000019*np.cos(3.89131231180 + 78244.0396638228*t)
	Z1 += 0.00000000017*np.cos(1.47291446860 + 77.7505439839*t)
	Z1 += 0.00000000015*np.cos(4.99910482431 + 423.4167971383*t)
	Z1 += 0.00000000014*np.cos(2.62615297219 + 210.8514148832*t)
	Z1 += 0.00000000015*np.cos(0.97248576911 + 78267.59076008058*t)
	Z1 += 0.00000000016*np.cos(1.68091549808 + 1155.361157407*t)
	Z1 += 0.00000000013*np.cos(2.45853344415 + 860.3099287528*t)
	Z1 += 0.00000000013*np.cos(4.95074075966 + 27154.3986187642*t)
	Z1 += 0.00000000013*np.cos(2.99861766415 + 846.0828347512*t)
	Z1 += 0.00000000017*np.cos(5.83556508068 + 53764.8791784322*t)
	Z1 += 0.00000000012*np.cos(3.15781754753 + 155418.04029735178*t)
	Z1 += 0.00000000015*np.cos(1.91063402672 + 44937.1306915484*t)
	Z1 += 0.00000000016*np.cos(3.31784437154 + 26202.34243025941*t)
	Z1 += 0.00000000012*np.cos(5.65589126671 + 3.1813937377*t)
	Z1 += 0.00000000012*np.cos(5.79880666801 + 78259.82808936459*t)
	Z1 += 0.00000000012*np.cos(0.78485262110 + 51962.5071877104*t)
	Z1 += 0.00000000015*np.cos(1.11484431483 + 74821.13447975718*t)
	Z1 += 0.00000000014*np.cos(3.77122510089 + 124778.18365871879*t)
	Z1 += 0.00000000012*np.cos(4.34152068071 + 94138.32702008578*t)
	Z1 += 0.00000000013*np.cos(0.98498982943 + 64741.95798313119*t)
	Z1 += 0.00000000014*np.cos(5.19944091841 + 1692.1656695024*t)
	Z1 += 0.00000000011*np.cos(0.01126157685 + 80482.46652890938*t)
	Z1 += 0.00000000012*np.cos(5.38061503044 + 52602.4044740244*t)
	Z1 += 0.00000000011*np.cos(5.42471517163 + 103396.01282468818*t)
	Z1 += 0.00000000011*np.cos(1.92091833374 + 77197.21394753258*t)
	Z1 += 0.00000000011*np.cos(2.51043583674 + 77734.01845962799*t)
	Z1 += 0.00000000012*np.cos(5.59878501315 + 77623.81213840858*t)
	Z1 += 0.00000000012*np.cos(0.20589141568 + 78256.59587772179*t)
	Z1 += 0.00000000013*np.cos(3.66006461043 + 429.7795846137*t)
	Z1 += 0.00000000013*np.cos(3.17586650226 + 28421.0995344462*t)
	Z1 += 0.00000000010*np.cos(4.05322231768 + 26241.681952059*t)
	Z1 += 0.00000000010*np.cos(1.39265587740 + 51742.09454527159*t)
	Z1 += 0.00000000010*np.cos(6.08175105796 + 78270.82297172339*t)
	Z1 += 0.00000000011*np.cos(4.40128024814 + 2.9689454166*t)
	Z1 += 0.00000000011*np.cos(1.10505354081 + 3.9321532631*t)
	Z1 += 0.00000000011*np.cos(2.69589922169 + 26137.8997634784*t)
	Z1 += 0.00000000010*np.cos(3.07928279036 + 2333.196392872*t)
	Z1 += 0.00000000010*np.cos(1.95569420228 + 1073.6090241908*t)
	Z1 += 0.00000000010*np.cos(5.59867007444 + 430.5303441391*t)
	Z1 += 0.00000000011*np.cos(0.30468128561 + 68050.42387851159*t)
	Z1 += 0.00000000010*np.cos(1.04892015032 + 2648.454825473*t)
	Z1 += 0.00000000009*np.cos(5.53388738438 + 7994.5284420242*t)
	Z1 += 0.00000000011*np.cos(1.08579591854 + 104881.30353139139*t)
	Z1 += 0.00000000009*np.cos(0.40604041041 + 24491.71669928959*t)
	Z1 += 0.00000000010*np.cos(1.36389391290 + 77211.44104153418*t)
	Z1 += 0.00000000011*np.cos(2.39071740763 + 64607.84893354619*t)
	Z1 += 0.00000000009*np.cos(1.91392780093 + 88476.99497093359*t)
	Z1 += 0.00000000009*np.cos(0.35558235819 + 76044.9523205358*t)
	Z1 += 0.00000000009*np.cos(4.46490542313 + 26037.90651966999*t)
	Z1 += 0.00000000008*np.cos(0.49047863023 + 102762.53967101299*t)
	Z1 += 0.00000000008*np.cos(5.85483327203 + 108903.56606335558*t)
	Z1 += 0.00000000010*np.cos(4.88911638894 + 437.6438911399*t)
	Z1 += 0.00000000008*np.cos(4.03785547628 + 71492.99882347698*t)
	Z1 += 0.00000000009*np.cos(4.85229479056 + 105410.99449648599*t)
	Z1 += 0.00000000008*np.cos(5.78717497024 + 21.3406410024*t)
	Z1 += 0.00000000010*np.cos(4.33333704289 + 223.5940361765*t)
	Z1 += 0.00000000009*np.cos(2.51175483230 + 85034.42002596818*t)
	Z1 += 0.00000000008*np.cos(0.01221598580 + 5327.4761083828*t)
	Z1 += 0.00000000007*np.cos(5.78988808042 + 26555.8681319286*t)
	Z1 += 0.00000000007*np.cos(4.27853212968 + 18207.81398823521*t)
	Z1 += 0.00000000007*np.cos(2.02962199178 + 78477.00852016058*t)
	Z1 += 0.00000000007*np.cos(5.50068715356 + 1478.8665740644*t)
	Z1 += 0.00000000007*np.cos(3.20780787297 + 18093.37469954999*t)
	Z1 += 0.00000000007*np.cos(3.29917452925 + 51322.60990139639*t)
	Z1 += 0.00000000008*np.cos(4.46683241624 + 155468.03691925599*t)
	Z1 += 0.00000000007*np.cos(5.35409000250 + 490.3340891794*t)
	Z1 += 0.00000000007*np.cos(4.04442368573 + 25455.119402261*t)
	Z1 += 0.00000000007*np.cos(0.70887703358 + 24505.94379329119*t)
	Z1 += 0.00000000007*np.cos(4.34819824133 + 88.865680217*t)
	Z1 += 0.00000000007*np.cos(4.70532379473 + 124.433415221*t)
	Z1 += 0.00000000008*np.cos(3.50499122731 + 28206.6670019526*t)
	Z1 += 0.00000000009*np.cos(5.55849714525 + 27140.17152476259*t)
	Z1 += 0.00000000007*np.cos(3.67689450101 + 125887.56221081219*t)
	Z1 += 0.00000000008*np.cos(3.21701385277 + 76144.94556434419*t)
	Z1 += 0.00000000007*np.cos(4.49386341300 + 50579.61984086379*t)
	Z1 += 0.00000000007*np.cos(3.33858090062 + 58458.88213313979*t)
	Z1 += 0.00000000008*np.cos(1.14310455995 + 103821.92160120218*t)
	Z1 += 0.00000000008*np.cos(5.48340707498 + 25234.70675982219*t)
	Z1 += 0.00000000008*np.cos(0.66014034660 + 51756.3216392732*t)
	Z1 += 0.00000000007*np.cos(0.91622586929 + 46848.3301747656*t)
	Z1 += 0.00000000007*np.cos(1.14440533228 + 728.762966531*t)
	Z1 += 0.00000000007*np.cos(3.68649801447 + 127.4717966068*t)
	Z1 += 0.00000000006*np.cos(2.84816755580 + 81706.28436968799*t)
	Z1 += 0.00000000008*np.cos(0.54081102339 + 35191.8101356918*t)
	Z1 += 0.00000000007*np.cos(5.97950952528 + 99799.65906923798*t)
	Z1 += 0.00000000006*np.cos(6.04907029839 + 203.0041546995*t)
	Z1 += 0.00000000007*np.cos(5.59806550392 + 339142.74084046457*t)
	Z1 += 0.00000000006*np.cos(4.95034875779 + 137.0330241624*t)
	Z1 += 0.00000000008*np.cos(2.06065598813 + 71980.63357473118*t)
	Z1 += 0.00000000006*np.cos(0.30570108881 + 351.8165923087*t)
	Z1 += 0.00000000007*np.cos(2.35899025407 + 33967.99229491319*t)
	Z1 += 0.00000000006*np.cos(3.20318007478 + 654.1243803156*t)
	Z1 += 0.00000000006*np.cos(4.54497734613 + 93028.94846799239*t)
	Z1 += 0.00000000005*np.cos(4.96809690798 + 52026.2430860138*t)
	Z1 += 0.00000000005*np.cos(1.42127686013 + 1272.6810256272*t)
	Z1 += 0.00000000006*np.cos(1.23723826618 + 44181.27784112419*t)
	Z1 += 0.00000000005*np.cos(2.44842875080 + 203.7378678824*t)
	Z1 += 0.00000000006*np.cos(1.22067313314 + 120226.23016165999*t)
	Z1 += 0.00000000006*np.cos(2.41904485988 + 508.3503240922*t)
	Z1 += 0.00000000005*np.cos(3.28690720493 + 25938.3399444396*t)
	Z1 += 0.00000000006*np.cos(2.36270756836 + 1375.7737998458*t)
	Z1 += 0.00000000005*np.cos(4.99695296239 + 71025.03383312259*t)
	Z1 += 0.00000000005*np.cos(3.80540207824 + 78050.41032928458*t)
	Z1 += 0.00000000006*np.cos(2.46355111951 + 162188.75089859738*t)
	Z1 += 0.00000000005*np.cos(5.46272081654 + 26610.48055966799*t)
	Z1 += 0.00000000004*np.cos(0.17343495362 + 77.962992305*t)
	Z1 += 0.00000000005*np.cos(0.63510871716 + 104331.94280539699*t)
	Z1 += 0.00000000004*np.cos(5.71678194245 + 98068.53671630539*t)
	Z1 += 0.00000000004*np.cos(3.52099164933 + 26507.38778544939*t)
	Z1 += 0.00000000004*np.cos(5.31353397656 + 117873.36400788819*t)
	Z1 += 0.00000000004*np.cos(3.45025275060 + 302.164775655*t)
	Z1 += 0.00000000004*np.cos(5.13194743371 + 7880.08915333899*t)
	Z1 += 0.00000000005*np.cos(1.63217415397 + 91785.46086631398*t)
	Z1 += 0.00000000004*np.cos(4.85259057218 + 50593.84693486539*t)
	Z1 += 0.00000000004*np.cos(2.71504785765 + 145.6310438715*t)
	Z1 += 0.00000000004*np.cos(3.58205868095 + 45494.58142974879*t)
	Z1 += 0.00000000004*np.cos(0.56456514853 + 150866.08680029298*t)
	Z1 += 0.00000000004*np.cos(4.05482156113 + 104355.49390165479*t)
	Z1 += 0.00000000005*np.cos(4.31294151281 + 10021.8372800994*t)
	Z1 += 0.00000000004*np.cos(0.78297474988 + 26081.27458267419*t)
	Z1 += 0.00000000005*np.cos(2.59888164869 + 79852.78232000639*t)
	Z1 += 0.00000000004*np.cos(4.42615122275 + 52815.7035694624*t)
	Z1 += 0.00000000004*np.cos(2.33499481674 + 217.964961884*t)
	Z1 += 0.00000000005*np.cos(1.92784340899 + 71.6002048296*t)
	Z1 += 0.00000000004*np.cos(4.38434908977 + 129909.82474277639*t)
	Z1 += 0.00000000005*np.cos(1.79793964328 + 838.9692877504*t)
	Z1 += 0.00000000004*np.cos(4.52782207994 + 39743.7636327506*t)
	Z1 += 0.00000000004*np.cos(2.20941190445 + 26521.614879451*t)
	Z1 += 0.00000000005*np.cos(5.32700006988 + 25551.09862947879*t)
	Z1 += 0.00000000004*np.cos(0.64407233905 + 22759.76748529401*t)
	Z1 += 0.00000000004*np.cos(0.87584552144 + 95247.70557217918*t)
	Z1 += 0.00000000004*np.cos(1.85326390850 + 1062.5633239269*t)
	Z1 += 0.00000000004*np.cos(6.03119287364 + 231.4583427027*t)
	Z1 += 0.00000000004*np.cos(2.22216873998 + 51639.00177105299*t)
	Z1 += 0.00000000003*np.cos(5.36514246733 + 52099.5402118728*t)
	Z1 += 0.00000000003*np.cos(4.57090150345 + 103299.34418310839*t)
	Z1 += 0.00000000004*np.cos(4.07559367157 + 130969.20667296558*t)
	return Z1*t




def Mercury_Z2 (t): # 178 terms of order 2

	Z2 = 0.
	Z2 += 0.00001053118*np.cos(5.37979214357 + 26087.9031415742*t)
	Z2 += 0.00001183345
	Z2 += 0.00000087113*np.cos(0.42206932430 + 52175.8062831484*t)
	Z2 += 0.00000049534*np.cos(4.38054039769 + 78263.70942472259*t)
	Z2 += 0.00000037483*np.cos(3.23017504217 + 213.299095438*t)
	Z2 += 0.00000027331*np.cos(6.15464105987 + 529.6909650946*t)
	Z2 += 0.00000025685*np.cos(1.45827443162 + 104351.61256629678*t)
	Z2 += 0.00000010457*np.cos(4.62224691737 + 130439.51570787099*t)
	Z2 += 0.00000008616*np.cos(0.77209239310 + 206.1855484372*t)
	Z2 += 0.00000005511*np.cos(3.23377546695 + 220.4126424388*t)
	Z2 += 0.00000003757*np.cos(1.44589954776 + 156527.41884944518*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	Z2 += 0.00000002272*np.cos(4.09618627765 + 522.5774180938*t)
	Z2 += 0.00000001984*np.cos(2.34258882229 + 426.598190876*t)
	Z2 += 0.00000001248*np.cos(5.19570553454 + 1059.3819301892*t)
	Z2 += 0.00000001259*np.cos(4.52974728932 + 182615.32199101939*t)
	Z2 += 0.00000000743*np.cos(6.08844686068 + 419.4846438752*t)
	Z2 += 0.00000000641*np.cos(4.89317483950 + 74.7815985673*t)
	Z2 += 0.00000000527*np.cos(2.28325191846 + 433.7117378768*t)
	Z2 += 0.00000000519*np.cos(4.43974772353 + 7.1135470008*t)
	Z2 += 0.00000000405*np.cos(1.31903942108 + 208703.22513259358*t)
	Z2 += 0.00000000510*np.cos(2.02741559889 + 27197.2816936676*t)
	Z2 += 0.00000000300*np.cos(3.09602587558 + 227.5261894396*t)
	Z2 += 0.00000000295*np.cos(1.19469019983 + 639.897286314*t)
	Z2 += 0.00000000194*np.cos(4.84656399029 + 24978.5245894808*t)
	Z2 += 0.00000000170*np.cos(0.49444781792 + 1066.49547719*t)
	Z2 += 0.00000000184*np.cos(0.95286916137 + 199.0720014364*t)
	Z2 += 0.00000000149*np.cos(4.90906266305 + 316.3918696566*t)
	Z2 += 0.00000000126*np.cos(4.38484918485 + 234791.12827416777*t)
	Z2 += 0.00000000119*np.cos(4.09508225076 + 515.463871093*t)
	Z2 += 0.00000000120*np.cos(5.32663334557 + 1589.0728952838*t)
	Z2 += 0.00000000108*np.cos(3.67107493632 + 1052.2683831884*t)
	Z2 += 0.00000000085*np.cos(6.16812793384 + 543.9180590962*t)
	Z2 += 0.00000000079*np.cos(4.29766380692 + 14.2270940016*t)
	Z2 += 0.00000000084*np.cos(5.13112206401 + 53285.1848352418*t)
	Z2 += 0.00000000068*np.cos(1.33776656115 + 210.1177017003*t)
	Z2 += 0.00000000081*np.cos(1.77991669334 + 51066.427731055*t)
	Z2 += 0.00000000065*np.cos(5.05560764351 + 38.1330356378*t)
	Z2 += 0.00000000058*np.cos(1.55728577024 + 103.0927742186*t)
	Z2 += 0.00000000050*np.cos(1.42158496561 + 647.0108333148*t)
	Z2 += 0.00000000042*np.cos(1.14028846687 + 217.2312487011*t)
	Z2 += 0.00000000053*np.cos(2.67570413760 + 216.4804891757*t)
	Z2 += 0.00000000041*np.cos(5.92878165673 + 21535.9496445154*t)
	Z2 += 0.00000000038*np.cos(4.59494089680 + 31749.2351907264*t)
	Z2 += 0.00000000039*np.cos(1.16389533568 + 260879.03141574195*t)
	Z2 += 0.00000000031*np.cos(5.70517746266 + 27043.5028831828*t)
	Z2 += 0.00000000031*np.cos(4.21025720942 + 110.2063212194*t)
	Z2 += 0.00000000031*np.cos(4.90092982476 + 77154.33087262919*t)
	Z2 += 0.00000000032*np.cos(2.03738734507 + 6283.0758499914*t)
	Z2 += 0.00000000029*np.cos(6.18539185721 + 632.7837393132*t)
	Z2 += 0.00000000034*np.cos(0.46254363839 + 853.196381752*t)
	Z2 += 0.00000000028*np.cos(2.23145809257 + 440.8252848776*t)
	Z2 += 0.00000000025*np.cos(3.42051368965 + 51116.4243529592*t)
	Z2 += 0.00000000025*np.cos(3.95236444346 + 117.3198682202*t)
	Z2 += 0.00000000023*np.cos(5.12888703467 + 1109.3785520934*t)
	Z2 += 0.00000000025*np.cos(2.78460430400 + 209.3669421749*t)
	Z2 += 0.00000000021*np.cos(5.74317740279 + 532.8723588323*t)
	Z2 += 0.00000000018*np.cos(1.87060868220 + 323.5054166574*t)
	Z2 += 0.00000000017*np.cos(4.58615737180 + 526.5095713569*t)
	Z2 += 0.00000000017*np.cos(6.02623550832 + 95.9792272178*t)
	Z2 += 0.00000000016*np.cos(1.90390313968 + 28306.66024576099*t)
	Z2 += 0.00000000020*np.cos(0.17917379064 + 25028.521211385*t)
	Z2 += 0.00000000018*np.cos(0.25993978648 + 10213.285546211*t)
	Z2 += 0.00000000016*np.cos(6.02211293999 + 412.3710968744*t)
	Z2 += 0.00000000015*np.cos(1.05701795325 + 20426.571092422*t)
	Z2 += 0.00000000015*np.cos(0.00767394500 + 202.2533951741*t)
	Z2 += 0.00000000013*np.cos(1.81822077884 + 25132.3033999656*t)
	Z2 += 0.00000000012*np.cos(2.50603952514 + 149.5631971346*t)
	Z2 += 0.00000000012*np.cos(5.73430455559 + 22645.32819660879*t)
	Z2 += 0.00000000011*np.cos(5.17414328474 + 23869.1460373874*t)
	Z2 += 0.00000000013*np.cos(5.75707842894 + 525.7588118315*t)
	Z2 += 0.00000000011*np.cos(2.77607629936 + 73.297125859*t)
	Z2 += 0.00000000011*np.cos(0.99969948118 + 1596.1864422846*t)
	Z2 += 0.00000000012*np.cos(0.83014470454 + 37410.5672398786*t)
	Z2 += 0.00000000011*np.cos(1.70573481806 + 103242.23401420339*t)
	Z2 += 0.00000000012*np.cos(3.07376705363 + 1045.1548361876*t)
	Z2 += 0.00000000012*np.cos(4.22252353447 + 286966.93455731616*t)
	Z2 += 0.00000000011*np.cos(0.01879438470 + 309.2783226558*t)
	Z2 += 0.00000000010*np.cos(5.89719716922 + 47623.8527860896*t)
	Z2 += 0.00000000010*np.cos(6.25321109518 + 4551.9534970588*t)
	Z2 += 0.00000000011*np.cos(5.71700814956 + 2118.7638603784*t)
	Z2 += 0.00000000010*np.cos(4.70919553736 + 533.6231183577*t)
	Z2 += 0.00000000011*np.cos(2.38969901037 + 50586.73338786459*t)
	Z2 += 0.00000000009*np.cos(4.94664962083 + 26107.57290247399*t)
	Z2 += 0.00000000009*np.cos(2.95298668799 + 234.6397364404*t)
	Z2 += 0.00000000009*np.cos(1.94242243150 + 79373.08797681599*t)
	Z2 += 0.00000000009*np.cos(4.50823985532 + 32858.61374281979*t)
	Z2 += 0.00000000010*np.cos(3.66489496424 + 25558.2121764796*t)
	Z2 += 0.00000000008*np.cos(5.32804606956 + 1162.4747044078*t)
	Z2 += 0.00000000010*np.cos(2.94983110269 + 735.8765135318*t)
	Z2 += 0.00000000007*np.cos(2.38751237733 + 53131.406024757*t)
	Z2 += 0.00000000008*np.cos(4.77323220031 + 46514.4742339962*t)
	Z2 += 0.00000000008*np.cos(2.26838540542 + 625.6701923124*t)
	Z2 += 0.00000000009*np.cos(2.32555299082 + 949.1756089698*t)
	Z2 += 0.00000000007*np.cos(1.59120637282 + 26084.0218062162*t)
	Z2 += 0.00000000007*np.cos(4.26888098753 + 36.6485629295*t)
	Z2 += 0.00000000007*np.cos(3.46601151480 + 956.2891559706*t)
	Z2 += 0.00000000007*np.cos(1.63081873969 + 39.6175083461*t)
	Z2 += 0.00000000007*np.cos(5.50461749703 + 14765.2390432698*t)
	Z2 += 0.00000000006*np.cos(2.44506021688 + 26617.5941066688*t)
	Z2 += 0.00000000008*np.cos(6.04439838452 + 26068.2333806744*t)
	Z2 += 0.00000000006*np.cos(5.86363603201 + 25874.6040461362*t)
	Z2 += 0.00000000007*np.cos(3.11235514306 + 26091.7844769322*t)
	Z2 += 0.00000000007*np.cos(2.52359174803 + 19317.1925403286*t)
	Z2 += 0.00000000005*np.cos(3.78134955861 + 1581.959348283*t)
	Z2 += 0.00000000005*np.cos(5.79930116461 + 1169.5882514086*t)
	Z2 += 0.00000000005*np.cos(4.50577216714 + 51220.20654153979*t)
	Z2 += 0.00000000005*np.cos(2.33387808307 + 330.6189636582*t)
	Z2 += 0.00000000006*np.cos(5.49024917012 + 25973.46385288896*t)
	Z2 += 0.00000000005*np.cos(3.55135533961 + 224.3447957019*t)
	Z2 += 0.00000000004*np.cos(4.99984592617 + 54394.56338733519*t)
	Z2 += 0.00000000004*np.cos(4.18372117957 + 3340.6124266998*t)
	Z2 += 0.00000000004*np.cos(3.56822908434 + 9103.9069941176*t)
	Z2 += 0.00000000005*np.cos(3.36356474475 + 43071.8992890308*t)
	Z2 += 0.00000000004*np.cos(3.41104929582 + 25661.3049506982*t)
	Z2 += 0.00000000005*np.cos(1.61564484968 + 26202.34243025941*t)
	Z2 += 0.00000000004*np.cos(4.10663814883 + 21.3406410024*t)
	Z2 += 0.00000000005*np.cos(0.57738242740 + 860.3099287528*t)
	Z2 += 0.00000000004*np.cos(2.04986993982 + 72602.37737557039*t)
	Z2 += 0.00000000004*np.cos(0.44270397791 + 1073.6090241908*t)
	Z2 += 0.00000000004*np.cos(4.78586478582 + 129330.13715577759*t)
	Z2 += 0.00000000004*np.cos(1.23285415070 + 39609.6545831656*t)
	Z2 += 0.00000000005*np.cos(5.42524693917 + 85.8272988312*t)
	Z2 += 0.00000000004*np.cos(0.59720671044 + 423.4167971383*t)
	Z2 += 0.00000000004*np.cos(1.99566356802 + 26095.016688575*t)
	Z2 += 0.00000000004*np.cos(4.95079393388 + 70.8494453042*t)
	Z2 += 0.00000000004*np.cos(1.70877653176 + 942.062061969*t)
	Z2 += 0.00000000005*np.cos(2.54022722440 + 223.5940361765*t)
	Z2 += 0.00000000004*np.cos(1.35380519898 + 29530.4780865396*t)
	Z2 += 0.00000000005*np.cos(1.23150173506 + 3442.5749449654*t)
	Z2 += 0.00000000004*np.cos(1.79684320381 + 429.7795846137*t)
	Z2 += 0.00000000004*np.cos(0.26585418784 + 51646.11531805379*t)
	Z2 += 0.00000000004*np.cos(2.77782586170 + 41962.5207369374*t)
	Z2 += 0.00000000004*np.cos(1.09650929108 + 5661.3320491522*t)
	Z2 += 0.00000000004*np.cos(6.22298149928 + 76.2660712756*t)
	Z2 += 0.00000000004*np.cos(1.66020203630 + 422.6660376129*t)
	Z2 += 0.00000000003*np.cos(1.97577379834 + 49957.0491789616*t)
	Z2 += 0.00000000003*np.cos(1.55704409970 + 203.0041546995*t)
	Z2 += 0.00000000003*np.cos(4.44130584150 + 508.3503240922*t)
	Z2 += 0.00000000003*np.cos(6.02171816863 + 52705.49724824299*t)
	Z2 += 0.00000000004*np.cos(1.66969189830 + 30639.856638633*t)
	Z2 += 0.00000000003*np.cos(2.94487074403 + 124.433415221*t)
	Z2 += 0.00000000003*np.cos(3.32056352021 + 11.0457002639*t)
	Z2 += 0.00000000003*np.cos(2.81673969588 + 63.7358983034*t)
	Z2 += 0.00000000003*np.cos(1.24157422567 + 57837.1383323006*t)
	Z2 += 0.00000000004*np.cos(3.08638029988 + 3.9321532631*t)
	Z2 += 0.00000000003*np.cos(4.24139247807 + 51535.90899683439*t)
	Z2 += 0.00000000003*np.cos(4.31183095451 + 2218.7571041868*t)
	Z2 += 0.00000000003*np.cos(3.54543066660 + 1155.361157407*t)
	Z2 += 0.00000000003*np.cos(2.71716318847 + 26080.78959457339*t)
	Z2 += 0.00000000003*np.cos(6.06819480018 + 88.865680217*t)
	Z2 += 0.00000000003*np.cos(3.08295372453 + 33326.5787331742*t)
	Z2 += 0.00000000003*np.cos(2.90469145846 + 728.762966531*t)
	Z2 += 0.00000000003*np.cos(2.83124529131 + 40853.142184844*t)
	Z2 += 0.00000000003*np.cos(3.98094106813 + 63498.47038145279*t)
	Z2 += 0.00000000003*np.cos(6.11998019073 + 36301.18868778519*t)
	Z2 += 0.00000000003*np.cos(0.99287952932 + 313054.83769889036*t)
	Z2 += 0.00000000003*np.cos(1.40705858439 + 654.1243803156*t)
	Z2 += 0.00000000003*np.cos(4.47232610391 + 24498.8302462904*t)
	Z2 += 0.00000000003*np.cos(3.50771998464 + 78.7137518304*t)
	Z2 += 0.00000000003*np.cos(4.39447085694 + 56727.7597802072*t)
	Z2 += 0.00000000002*np.cos(3.14629176189 + 53235.18821333759*t)
	Z2 += 0.00000000003*np.cos(1.29496956788 + 58946.51688439399*t)
	Z2 += 0.00000000003*np.cos(5.78518537876 + 48733.23133818299*t)
	Z2 += 0.00000000002*np.cos(5.85755018741 + 26301.2022370122*t)
	Z2 += 0.00000000002*np.cos(3.05223400181 + 415.5524906121*t)
	Z2 += 0.00000000002*np.cos(0.74752177962 + 955.5997416086*t)
	Z2 += 0.00000000003*np.cos(5.78326807846 + 77204.32749453338*t)
	Z2 += 0.00000000002*np.cos(4.55871260975 + 1.4844727083*t)
	Z2 += 0.00000000003*np.cos(1.74563621629 + 277.0349937414*t)
	Z2 += 0.00000000002*np.cos(3.23521381372 + 16983.9961474566*t)
	Z2 += 0.00000000002*np.cos(0.60194942543 + 38519.945791972*t)
	Z2 += 0.00000000002*np.cos(5.22827823253 + 76674.63652943878*t)
	Z2 += 0.00000000002*np.cos(1.29217914825 + 191.9584544356*t)
	Z2 += 0.00000000002*np.cos(1.10676834844 + 77308.10968311399*t)
	Z2 += 0.00000000002*np.cos(5.59153557926 + 23754.70674870219*t)
	Z2 += 0.00000000002*np.cos(3.65769145122 + 3.1813937377*t)
	Z2 += 0.00000000002*np.cos(0.11046591263 + 13655.8604911764*t)
	return Z2*t*t




def Mercury_Z3 (t): # 63 terms of order 3

	Z3 = 0.
	Z3 += 0.00000021392*np.cos(2.12804278460 + 26087.9031415742*t)
	Z3 += 0.00000016634
	Z3 += 0.00000002919*np.cos(5.41085836184 + 52175.8062831484*t)
	Z3 += 0.00000001302*np.cos(4.84806136860 + 213.299095438*t)
	Z3 += 0.00000001364*np.cos(2.43564490971 + 206.1855484372*t)
	Z3 += 0.00000001164*np.cos(2.43324966912 + 78263.70942472259*t)
	Z3 += 0.00000000920*np.cos(1.65069146673 + 529.6909650946*t)
	Z3 += 0.00000000716*np.cos(1.50799790954 + 220.4126424388*t)
	Z3 += 0.00000000649*np.cos(5.91828820019 + 104351.61256629678*t)
	Z3 += 0.00000000423*np.cos(4.54129218357 + 536.8045120954*t)
	Z3 += 0.00000000338*np.cos(2.90727188863 + 130439.51570787099*t)
	Z3 += 0.00000000282*np.cos(5.95440671732 + 522.5774180938*t)
	Z3 += 0.00000000153*np.cos(6.06902785421 + 156527.41884944518*t)
	Z3 += 0.00000000090*np.cos(0.51819099535 + 433.7117378768*t)
	Z3 += 0.00000000094*np.cos(1.55249614896 + 419.4846438752*t)
	Z3 += 0.00000000079*np.cos(1.38892285542 + 227.5261894396*t)
	Z3 += 0.00000000094*np.cos(0.17438010106 + 426.598190876*t)
	Z3 += 0.00000000063*np.cos(2.90040506590 + 182615.32199101939*t)
	Z3 += 0.00000000048*np.cos(3.11752034640 + 1059.3819301892*t)
	Z3 += 0.00000000050*np.cos(2.64433369691 + 199.0720014364*t)
	Z3 += 0.00000000042*np.cos(2.65785543548 + 7.1135470008*t)
	Z3 += 0.00000000028*np.cos(5.89394518040 + 515.463871093*t)
	Z3 += 0.00000000027*np.cos(5.17159300173 + 1066.49547719*t)
	Z3 += 0.00000000024*np.cos(4.43334493389 + 543.9180590962*t)
	Z3 += 0.00000000024*np.cos(5.99412433164 + 208703.22513259358*t)
	Z3 += 0.00000000026*np.cos(5.61220088462 + 639.897286314*t)
	Z3 += 0.00000000018*np.cos(0.02154769101 + 74.7815985673*t)
	Z3 += 0.00000000017*np.cos(2.57902262762 + 14.2270940016*t)
	Z3 += 0.00000000013*np.cos(3.07320748125 + 210.1177017003*t)
	Z3 += 0.00000000012*np.cos(5.68952008926 + 1052.2683831884*t)
	Z3 += 0.00000000011*np.cos(0.06567554803 + 316.3918696566*t)
	Z3 += 0.00000000009*np.cos(2.78985700920 + 234791.12827416777*t)
	Z3 += 0.00000000011*np.cos(5.88691938543 + 647.0108333148*t)
	Z3 += 0.00000000009*np.cos(3.85014410427 + 27197.2816936676*t)
	Z3 += 0.00000000009*np.cos(0.49541679064 + 440.8252848776*t)
	Z3 += 0.00000000008*np.cos(0.88032790118 + 216.4804891757*t)
	Z3 += 0.00000000006*np.cos(6.21088176821 + 38.1330356378*t)
	Z3 += 0.00000000006*np.cos(3.98184268899 + 1589.0728952838*t)
	Z3 += 0.00000000007*np.cos(0.94845759850 + 24978.5245894808*t)
	Z3 += 0.00000000007*np.cos(3.28974856542 + 103.0927742186*t)
	Z3 += 0.00000000004*np.cos(4.75446574078 + 853.196381752*t)
	Z3 += 0.00000000004*np.cos(1.59186789207 + 632.7837393132*t)
	Z3 += 0.00000000004*np.cos(1.52800084237 + 412.3710968744*t)
	Z3 += 0.00000000003*np.cos(2.72859893423 + 217.2312487011*t)
	Z3 += 0.00000000004*np.cos(1.24971088361 + 234.6397364404*t)
	Z3 += 0.00000000004*np.cos(2.23695164343 + 117.3198682202*t)
	Z3 += 0.00000000003*np.cos(5.03266763204 + 1045.1548361876*t)
	Z3 += 0.00000000003*np.cos(5.85227323245 + 260879.03141574195*t)
	Z3 += 0.00000000002*np.cos(1.54692325590 + 95.9792272178*t)
	Z3 += 0.00000000002*np.cos(2.47873978537 + 21.3406410024*t)
	Z3 += 0.00000000002*np.cos(5.89071888876 + 1596.1864422846*t)
	Z3 += 0.00000000001*np.cos(2.39068115930 + 309.2783226558*t)
	Z3 += 0.00000000001*np.cos(4.51750108995 + 110.2063212194*t)
	Z3 += 0.00000000001*np.cos(0.22878957149 + 323.5054166574*t)
	Z3 += 0.00000000001*np.cos(6.15405801099 + 508.3503240922*t)
	Z3 += 0.00000000001*np.cos(2.20057567411 + 202.2533951741*t)
	Z3 += 0.00000000001*np.cos(1.46066971079 + 1109.3785520934*t)
	Z3 += 0.00000000001*np.cos(0.75305469601 + 223.5940361765*t)
	Z3 += 0.00000000001*np.cos(4.90745082069 + 735.8765135318*t)
	Z3 += 0.00000000001*np.cos(5.63330817461 + 51066.427731055*t)
	Z3 += 0.00000000001*np.cos(5.14951363778 + 1073.6090241908*t)
	Z3 += 0.00000000001*np.cos(2.94450371786 + 191.9584544356*t)
	Z3 += 0.00000000001*np.cos(4.98822441421 + 860.3099287528*t)
	return Z3*t*t*t




def Mercury_Z4 (t): # 34 terms of order 4

	Z4 = 0.
	Z4 += 0.00000000587*np.cos(4.86442699315 + 26087.9031415742*t)
	Z4 -= 0.00000000273
	Z4 += 0.00000000164*np.cos(4.10546661445 + 206.1855484372*t)
	Z4 += 0.00000000072*np.cos(6.04348211714 + 220.4126424388*t)
	Z4 += 0.00000000070*np.cos(6.10651561968 + 213.299095438*t)
	Z4 += 0.00000000055*np.cos(3.04082107246 + 52175.8062831484*t)
	Z4 += 0.00000000044*np.cos(2.79536133222 + 536.8045120954*t)
	Z4 += 0.00000000026*np.cos(1.66128176108 + 522.5774180938*t)
	Z4 += 0.00000000026*np.cos(0.53815113361 + 78263.70942472259*t)
	Z4 += 0.00000000015*np.cos(4.06065320707 + 104351.61256629678*t)
	Z4 += 0.00000000016*np.cos(5.95724279756 + 227.5261894396*t)
	Z4 += 0.00000000011*np.cos(4.33140895473 + 199.0720014364*t)
	Z4 += 0.00000000012*np.cos(5.02489197754 + 433.7117378768*t)
	Z4 += 0.00000000009*np.cos(1.14893791529 + 130439.51570787099*t)
	Z4 += 0.00000000008*np.cos(3.36029048603 + 419.4846438752*t)
	Z4 += 0.00000000006*np.cos(1.39462759175 + 515.463871093*t)
	Z4 += 0.00000000005*np.cos(2.67511593664 + 543.9180590962*t)
	Z4 += 0.00000000004*np.cos(4.65054077397 + 529.6909650946*t)
	Z4 += 0.00000000005*np.cos(4.38565359175 + 156527.41884944518*t)
	Z4 += 0.00000000005*np.cos(4.82245392155 + 426.598190876*t)
	Z4 += 0.00000000003*np.cos(0.96348403857 + 7.1135470008*t)
	Z4 += 0.00000000003*np.cos(0.80949781331 + 14.2270940016*t)
	Z4 += 0.00000000003*np.cos(3.63118822382 + 1066.49547719*t)
	Z4 += 0.00000000002*np.cos(1.25002341217 + 182615.32199101939*t)
	Z4 += 0.00000000002*np.cos(3.76452892490 + 639.897286314*t)
	Z4 += 0.00000000002*np.cos(5.03281213584 + 440.8252848776*t)
	Z4 += 0.00000000002*np.cos(4.07799495792 + 647.0108333148*t)
	Z4 += 0.00000000001*np.cos(1.44530794356 + 1059.3819301892*t)
	Z4 += 0.00000000001*np.cos(1.37231576384 + 1052.2683831884*t)
	Z4 += 0.00000000001*np.cos(4.38192942162 + 208703.22513259358*t)
	Z4 += 0.00000000001*np.cos(5.80470544513 + 234.6397364404*t)
	Z4 += 0.00000000001*np.cos(1.63696733565 + 117.3198682202*t)
	Z4 += 0.00000000001*np.cos(3.60628665626 + 853.196381752*t)
	Z4 += 0.00000000000*np.cos(2.65796643505 + 110.2063212194*t)
	return Z4*t*t*t*t




def Mercury_Z5 (t): # 14 terms of order 5

	Z5 = 0.
	Z5 += 0.00000000015*np.cos(5.75563126750 + 206.1855484372*t)
	Z5 += 0.00000000007
	Z5 += 0.00000000005*np.cos(4.29978807671 + 220.4126424388*t)
	Z5 += 0.00000000003*np.cos(0.96254361103 + 536.8045120954*t)
	Z5 += 0.00000000002*np.cos(5.42849777894 + 26087.9031415742*t)
	Z5 += 0.00000000002*np.cos(3.96773929080 + 522.5774180938*t)
	Z5 += 0.00000000002*np.cos(4.22112932205 + 227.5261894396*t)
	Z5 += 0.00000000002*np.cos(6.02426931559 + 199.0720014364*t)
	Z5 += 0.00000000002*np.cos(1.19011087498 + 52175.8062831484*t)
	Z5 += 0.00000000001*np.cos(3.19657723128 + 515.463871093*t)
	Z5 += 0.00000000001*np.cos(3.25850463040 + 433.7117378768*t)
	Z5 += 0.00000000001*np.cos(4.84147977903 + 78263.70942472259*t)
	Z5 += 0.00000000000*np.cos(2.14343331955 + 104351.61256629678*t)
	Z5 += 0.00000000000*np.cos(5.61950230485 + 130439.51570787099*t)
	return Z5*t*t*t*t*t




def Venus_X0 (t): # 956 terms of order 0

	X0 = 0.
	X0 += 0.72211104628*np.cos(3.17575836361 + 10213.285546211*t)
	X0 += 0.00515822267
	X0 += 0.00494908458*np.cos(3.74108234732 + 529.6909650946*t)
	X0 += 0.00244499876*np.cos(4.05566613867 + 20426.571092422*t)
	X0 += 0.00271754748*np.cos(4.01601261142 + 213.299095438*t)
	X0 += 0.00155435209*np.cos(2.17052052050 + 38.1330356378*t)
	X0 += 0.00083791771*np.cos(2.33967946884 + 74.7815985673*t)
	X0 += 0.00011914665*np.cos(4.08456666781 + 1059.3819301892*t)
	X0 += 0.00007580097*np.cos(3.24082423116 + 426.598190876*t)
	X0 += 0.00002800281*np.cos(0.33147492492 + 2352.8661537718*t)
	X0 += 0.00001941046*np.cos(1.01223495801 + 206.1855484372*t)
	X0 += 0.00001940890*np.cos(4.79784874503 + 149.5631971346*t)
	X0 += 0.00001888495*np.cos(3.89252933583 + 220.4126424388*t)
	X0 += 0.00001949669*np.cos(4.23196016801 + 1577.3435424478*t)
	X0 += 0.00001432104*np.cos(3.86896784957 + 522.5774180938*t)
	X0 += 0.00001404162*np.cos(0.47599536907 + 536.8045120954*t)
	X0 += 0.00001185750*np.cos(0.77749524757 + 76.2660712756*t)
	X0 += 0.00001241717*np.cos(4.93573787058 + 30639.856638633*t)
	X0 += 0.00001162258*np.cos(2.87958246189 + 18073.7049386502*t)
	X0 += 0.00000813685*np.cos(3.25483611884 + 36.6485629295*t)
	X0 += 0.00000767074*np.cos(4.22743731914 + 39.6175083461*t)
	X0 += 0.00000742696*np.cos(1.75470261934 + 6283.0758499914*t)
	X0 += 0.00000669461*np.cos(1.45721228842 + 14143.4952424306*t)
	X0 += 0.00000657195*np.cos(0.50086450258 + 8635.9420037632*t)
	X0 += 0.00000624814*np.cos(0.27936466811 + 73.297125859*t)
	X0 += 0.00000476445*np.cos(5.84309782840 + 10186.9872264112*t)
	X0 += 0.00000474466*np.cos(3.64991163504 + 10239.5838660108*t)
	X0 += 0.00000427363*np.cos(4.41998188509 + 1589.0728952838*t)
	X0 += 0.00000559074*np.cos(1.16554783301 + 22003.9146348698*t)
	X0 += 0.00000546778*np.cos(2.71490884128 + 11790.6290886588*t)
	X0 += 0.00000360342*np.cos(5.15561630805 + 7.1135470008*t)
	X0 += 0.00000408988*np.cos(3.92725431993 + 775.522611324*t)
	X0 += 0.00000315366*np.cos(6.15704318462 + 419.4846438752*t)
	X0 += 0.00000309388*np.cos(2.49212046755 + 639.897286314*t)
	X0 += 0.00000287059*np.cos(2.79578956958 + 9683.5945811164*t)
	X0 += 0.00000278686*np.cos(4.93240664943 + 110.2063212194*t)
	X0 += 0.00000268822*np.cos(0.42000307859 + 10742.9765113056*t)
	X0 += 0.00000297742*np.cos(5.65655811166 + 5507.5532386674*t)
	X0 += 0.00000213991*np.cos(0.74895353268 + 10021.8372800994*t)
	X0 += 0.00000241103*np.cos(5.80627627098 + 10988.808157535*t)
	X0 += 0.00000209303*np.cos(2.47129919435 + 10404.7338123226*t)
	X0 += 0.00000271022*np.cos(2.62377780320 + 19896.8801273274*t)
	X0 += 0.00000254480*np.cos(5.09961413241 + 9153.9036160218*t)
	X0 += 0.00000216123*np.cos(5.80296794588 + 316.3918696566*t)
	X0 += 0.00000225228*np.cos(5.27984972093 + 103.0927742186*t)
	X0 += 0.00000174985*np.cos(6.12704911391 + 191.4482661116*t)
	X0 += 0.00000175040*np.cos(3.53163977560 + 9437.762934887*t)
	X0 += 0.00000154379*np.cos(5.35607704390 + 4705.7323075436*t)
	X0 += 0.00000147455*np.cos(5.55780022641 + 19651.048481098*t)
	X0 += 0.00000135844*np.cos(2.00150822188 + 1.4844727083*t)
	X0 += 0.00000116732*np.cos(2.42480907692 + 632.7837393132*t)
	X0 += 0.00000105436*np.cos(3.12292269117 + 433.7117378768*t)
	X0 += 0.00000097809*np.cos(3.02261304158 + 1052.2683831884*t)
	X0 += 0.00000108440*np.cos(3.15757463328 + 1162.4747044078*t)
	X0 += 0.00000069504*np.cos(0.09284153982 + 9103.9069941176*t)
	X0 += 0.00000069037*np.cos(0.81599319827 + 1066.49547719*t)
	X0 += 0.00000082633*np.cos(4.14038372098 + 15720.8387848784*t)
	X0 += 0.00000057905*np.cos(3.09112177798 + 11322.6640983044*t)
	X0 += 0.00000056654*np.cos(1.32307194439 + 949.1756089698*t)
	X0 += 0.00000058863*np.cos(3.05825416735 + 20618.0193585336*t)
	X0 += 0.00000060672*np.cos(3.78380568336 + 4551.9534970588*t)
	X0 += 0.00000065924*np.cos(0.27645948450 + 846.0828347512*t)
	X0 += 0.00000063189*np.cos(5.79436684832 + 148.0787244263*t)
	X0 += 0.00000046372*np.cos(0.52050501625 + 10192.5101507186*t)
	X0 += 0.00000046247*np.cos(2.68940900983 + 10234.0609417034*t)
	X0 += 0.00000063153*np.cos(0.73249733087 + 224.3447957019*t)
	X0 += 0.00000062363*np.cos(2.59167610929 + 25934.1243310894*t)
	X0 += 0.00000049846*np.cos(4.74559004636 + 8624.2126509272*t)
	X0 += 0.00000057244*np.cos(0.64178511675 + 3154.6870848956*t)
	X0 += 0.00000044352*np.cos(1.62905355389 + 19367.1891622328*t)
	X0 += 0.00000040142*np.cos(3.21137282665 + 9411.4646150872*t)
	X0 += 0.00000039831*np.cos(1.63910906528 + 801.8209311238*t)
	X0 += 0.00000045105*np.cos(2.05062276794 + 29580.4747084438*t)
	X0 += 0.00000036963*np.cos(4.39471796609 + 7058.5984613154*t)
	X0 += 0.00000037824*np.cos(4.58891701161 + 35.1640902212*t)
	X0 += 0.00000031150*np.cos(1.37429681895 + 63.7358983034*t)
	X0 += 0.00000030677*np.cos(4.22148127763 + 11.0457002639*t)
	X0 += 0.00000029387*np.cos(6.20012003310 + 11015.1064773348*t)
	X0 += 0.00000031396*np.cos(5.70560306421 + 15874.6175953632*t)
	X0 += 0.00000035988*np.cos(3.91661388674 + 9999.986450773*t)
	X0 += 0.00000037367*np.cos(3.06495275533 + 3340.6124266998*t)
	X0 += 0.00000027030*np.cos(1.82255608984 + 1109.3785520934*t)
	X0 += 0.00000035335*np.cos(5.58257679416 + 10426.584641649*t)
	X0 += 0.00000024532*np.cos(5.47009748867 + 7860.4193924392*t)
	X0 += 0.00000028741*np.cos(3.71398829023 + 151.0476698429*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000023782*np.cos(3.76207354349 + 227.5261894396*t)
	X0 += 0.00000020348*np.cos(0.50298205801 + 10206.1719992102*t)
	X0 += 0.00000020289*np.cos(2.70241661509 + 10220.3990932118*t)
	X0 += 0.00000021702*np.cos(2.51229307210 + 13367.9726311066*t)
	X0 += 0.00000023267*np.cos(0.46827104623 + 85.8272988312*t)
	X0 += 0.00000022744*np.cos(1.67012539714 + 71.8126531507*t)
	X0 += 0.00000023556*np.cos(4.96219726942 + 21228.3920235458*t)
	X0 += 0.00000021314*np.cos(2.94962042107 + 3128.3887650958*t)
	X0 += 0.00000018028*np.cos(4.74595269728 + 2118.7638603784*t)
	X0 += 0.00000018918*np.cos(5.32707832336 + 26.2983197998*t)
	X0 += 0.00000022286*np.cos(3.93734569173 + 2.9689454166*t)
	X0 += 0.00000021992*np.cos(0.11232184552 + 77.7505439839*t)
	X0 += 0.00000020026*np.cos(4.02923197304 + 209.3669421749*t)
	X0 += 0.00000019681*np.cos(0.87544248531 + 217.2312487011*t)
	X0 += 0.00000019075*np.cos(5.91973929854 + 202.2533951741*t)
	X0 += 0.00000016571*np.cos(2.54911337935 + 735.8765135318*t)
	X0 += 0.00000015738*np.cos(5.27754524439 + 742.9900605326*t)
	X0 += 0.00000018319*np.cos(3.06472848621 + 323.5054166574*t)
	X0 += 0.00000020165*np.cos(3.03418313848 + 3930.2096962196*t)
	X0 += 0.00000017360*np.cos(3.01137661271 + 138.5174968707*t)
	X0 += 0.00000015488*np.cos(4.00542220967 + 515.463871093*t)
	X0 += 0.00000017623*np.cos(1.34615692033 + 18837.49819713819*t)
	X0 += 0.00000016427*np.cos(1.82670359355 + 853.196381752*t)
	X0 += 0.00000015237*np.cos(4.38451593035 + 9830.3890139878*t)
	X0 += 0.00000017193*np.cos(0.21214926890 + 3532.0606928114*t)
	X0 += 0.00000014675*np.cos(5.12159442035 + 10596.1820784342*t)
	X0 += 0.00000016092*np.cos(2.35712884119 + 20213.271996984*t)
	X0 += 0.00000014921*np.cos(4.07229277194 + 29864.334027309*t)
	X0 += 0.00000011103*np.cos(3.77017026259 + 28286.9904848612*t)
	X0 += 0.00000014633*np.cos(2.10306620243 + 7084.8967811152*t)
	X0 += 0.00000012815*np.cos(3.81478671364 + 17298.1823273262*t)
	X0 += 0.00000014040*np.cos(3.86381640402 + 23581.2581773176*t)
	X0 += 0.00000011229*np.cos(1.18029367551 + 199.0720014364*t)
	X0 += 0.00000010836*np.cos(0.34161370756 + 543.9180590962*t)
	X0 += 0.00000009882*np.cos(5.05468665271 + 21535.9496445154*t)
	X0 += 0.00000011587*np.cos(0.61075744193 + 525.7588118315*t)
	X0 += 0.00000009391*np.cos(0.62349717207 + 11272.6674764002*t)
	X0 += 0.00000011447*np.cos(3.72704255770 + 533.6231183577*t)
	X0 += 0.00000012650*np.cos(4.58629724985 + 9786.687355335*t)
	X0 += 0.00000010763*np.cos(1.23302426124 + 9929.4262273458*t)
	X0 += 0.00000008934*np.cos(1.67849943453 + 29050.7837433492*t)
	X0 += 0.00000008747*np.cos(3.75682134819 + 12566.1516999828*t)
	X0 += 0.00000007866*np.cos(2.43422413260 + 1478.8665740644*t)
	X0 += 0.00000010378*np.cos(1.97768668783 + 10497.1448650762*t)
	X0 += 0.00000007498*np.cos(5.81621256989 + 40853.142184844*t)
	X0 += 0.00000007361*np.cos(0.80024676602 + 16496.3613962024*t)
	X0 += 0.00000008792*np.cos(0.46879154923 + 10207.7626219036*t)
	X0 += 0.00000008786*np.cos(2.74189609908 + 10218.8084705184*t)
	X0 += 0.00000007185*np.cos(3.51955509534 + 216.4804891757*t)
	X0 += 0.00000008158*np.cos(3.51188242820 + 1692.1656695024*t)
	X0 += 0.00000007015*np.cos(1.38855213071 + 210.1177017003*t)
	X0 += 0.00000007120*np.cos(2.46055859947 + 415.5524906121*t)
	X0 += 0.00000007423*np.cos(4.16147582473 + 10175.2578735752*t)
	X0 += 0.00000006867*np.cos(4.39735582882 + 117.3198682202*t)
	X0 += 0.00000007386*np.cos(5.33241731471 + 10251.3132188468*t)
	X0 += 0.00000007187*np.cos(4.04201071614 + 1265.5674786264*t)
	X0 += 0.00000006879*np.cos(2.86415622306 + 956.2891559706*t)
	X0 += 0.00000006656*np.cos(4.38046352226 + 8094.5216858326*t)
	X0 += 0.00000007322*np.cos(5.01386468985 + 14.2270940016*t)
	X0 += 0.00000006531*np.cos(1.17040611406 + 20419.45754542119*t)
	X0 += 0.00000005871*np.cos(2.02826795819 + 32217.2001810808*t)
	X0 += 0.00000006597*np.cos(2.37676813421 + 647.0108333148*t)
	X0 += 0.00000005864*np.cos(0.20073358491 + 5661.3320491522*t)
	X0 += 0.00000005717*np.cos(2.30775630611 + 24356.7807886416*t)
	X0 += 0.00000007299*np.cos(3.26142746195 + 1581.959348283*t)
	X0 += 0.00000006401*np.cos(5.30226825802 + 95.9792272178*t)
	X0 += 0.00000007242*np.cos(0.18019941143 + 25158.6017197654*t)
	X0 += 0.00000006244*np.cos(5.44473078234 + 70.8494453042*t)
	X0 += 0.00000005074*np.cos(4.24610777191 + 526.5095713569*t)
	X0 += 0.00000004978*np.cos(0.09070559075 + 532.8723588323*t)
	X0 += 0.00000004940*np.cos(3.65883501045 + 3149.1641605882*t)
	X0 += 0.00000005875*np.cos(2.36907113150 + 78.7137518304*t)
	X0 += 0.00000005637*np.cos(2.38025391336 + 382.8965322232*t)
	X0 += 0.00000004570*np.cos(2.63257803672 + 14765.2390432698*t)
	X0 += 0.00000006109*np.cos(5.67990095410 + 111.4301614968*t)
	X0 += 0.00000004684*np.cos(0.26862385218 + 18849.2275499742*t)
	X0 += 0.00000005081*np.cos(2.77574657924 + 20452.8694122218*t)
	X0 += 0.00000005495*np.cos(3.29347843305 + 17085.9586657222*t)
	X0 += 0.00000004359*np.cos(0.60967414268 + 1375.7737998458*t)
	X0 += 0.00000005436*np.cos(5.41859714400 + 33794.5437235286*t)
	X0 += 0.00000004712*np.cos(4.78612693635 + 114.3991069134*t)
	X0 += 0.00000005185*np.cos(1.85847454376 + 222.8603229936*t)
	X0 += 0.00000003866*np.cos(2.86208012723 + 13745.3462390224*t)
	X0 += 0.00000004288*np.cos(1.51938558324 + 277.0349937414*t)
	X0 += 0.00000003686*np.cos(1.14856079524 + 1596.1864422846*t)
	X0 += 0.00000003685*np.cos(0.38223917752 + 6681.2248533996*t)
	X0 += 0.00000004598*np.cos(0.76405567220 + 146.594251718*t)
	X0 += 0.00000003943*np.cos(3.08912453167 + 4732.0306273434*t)
	X0 += 0.00000003635*np.cos(0.35356507493 + 1551.045222648*t)
	X0 += 0.00000003772*np.cos(1.01689124687 + 18307.8072320436*t)
	X0 += 0.00000004327*np.cos(3.40429598827 + 23958.6317852334*t)
	X0 += 0.00000003885*np.cos(1.61513228322 + 29088.811415985*t)
	X0 += 0.00000003754*np.cos(1.04640420137 + 490.3340891794*t)
	X0 += 0.00000002949*np.cos(2.82363129759 + 10198.033075026*t)
	X0 += 0.00000002944*np.cos(0.38707317908 + 10228.538017396*t)
	X0 += 0.00000003221*np.cos(0.43638422742 + 20400.2727726222*t)
	X0 += 0.00000002821*np.cos(3.43414737256 + 299.1263942692*t)
	X0 += 0.00000002493*np.cos(5.95440151056 + 17277.4069318338*t)
	X0 += 0.00000003418*np.cos(2.52366884638 + 351.8165923087*t)
	X0 += 0.00000002747*np.cos(1.78150237025 + 5481.2549188676*t)
	X0 += 0.00000002655*np.cos(2.90453219642 + 625.6701923124*t)
	X0 += 0.00000002549*np.cos(2.85980700621 + 6872.6731195112*t)
	X0 += 0.00000002982*np.cos(0.59289983624 + 109.9456887885*t)
	X0 += 0.00000002431*np.cos(3.85585401608 + 30110.1656735384*t)
	X0 += 0.00000002294*np.cos(3.89566278246 + 3442.5749449654*t)
	X0 += 0.00000002424*np.cos(0.96902079851 + 20956.2620575166*t)
	X0 += 0.00000002742*np.cos(5.30280142666 + 27511.4678735372*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000002212*np.cos(5.16572775524 + 14945.3161735544*t)
	X0 += 0.00000002649*np.cos(3.69610044860 + 9580.5018068978*t)
	X0 += 0.00000002549*np.cos(0.03994924305 + 1169.5882514086*t)
	X0 += 0.00000002021*np.cos(1.06602786364 + 19999.97290154599*t)
	X0 += 0.00000002372*np.cos(5.35791881546 + 9573.388259897*t)
	X0 += 0.00000002011*np.cos(0.56822837266 + 21202.093703746*t)
	X0 += 0.00000002471*np.cos(5.74724422420 + 10846.0692855242*t)
	X0 += 0.00000002289*np.cos(2.78836600930 + 1045.1548361876*t)
	X0 += 0.00000001827*np.cos(3.06851083486 + 7064.1213856228*t)
	X0 += 0.00000002188*np.cos(5.98208928052 + 9967.4538999816*t)
	X0 += 0.00000001812*np.cos(4.00455436862 + 22779.4372461938*t)
	X0 += 0.00000002278*np.cos(5.10198662047 + 10316.3783204296*t)
	X0 += 0.00000002278*np.cos(4.39189942690 + 10110.1927719924*t)
	X0 += 0.00000002118*np.cos(3.51159941917 + 10459.1171924404*t)
	X0 += 0.00000001753*np.cos(0.39882451630 + 13553.8979729108*t)
	X0 += 0.00000002246*np.cos(3.03979815042 + 33019.0211122046*t)
	X0 += 0.00000002050*np.cos(4.25748513060 + 9690.7081281172*t)
	X0 += 0.00000001832*np.cos(5.56224262077 + 20809.4676246452*t)
	X0 += 0.00000001945*np.cos(3.29102485680 + 1155.361157407*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001646*np.cos(3.01660183388 + 440.8252848776*t)
	X0 += 0.00000001962*np.cos(5.23480186630 + 10735.8629643048*t)
	X0 += 0.00000001484*np.cos(2.74088797191 + 3723.508958923*t)
	X0 += 0.00000001539*np.cos(5.57331447211 + 65.2203710117*t)
	X0 += 0.00000002057*np.cos(0.56837576346 + 37724.7534197482*t)
	X0 += 0.00000001433*np.cos(1.48123692595 + 942.062061969*t)
	X0 += 0.00000001659*np.cos(1.57309692340 + 20235.1228263104*t)
	X0 += 0.00000001553*np.cos(4.88459995586 + 9161.0171630226*t)
	X0 += 0.00000001873*np.cos(1.50261813839 + 30213.258447757*t)
	X0 += 0.00000001541*np.cos(4.02220022796 + 6489.776587288*t)
	X0 += 0.00000001360*np.cos(5.79998899684 + 10232.95530711079*t)
	X0 += 0.00000001360*np.cos(3.69389705053 + 10193.61578531121*t)
	X0 += 0.00000001592*np.cos(2.48951212353 + 10288.0671447783*t)
	X0 += 0.00000001592*np.cos(0.72118861666 + 10138.5039476437*t)
	X0 += 0.00000001271*np.cos(5.70934511266 + 13936.794505134*t)
	X0 += 0.00000001390*np.cos(6.12238564495 + 412.3710968744*t)
	X0 += 0.00000001238*np.cos(3.79102501998 + 20.7753954924*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001560*np.cos(2.84665742236 + 10529.6774158676*t)
	X0 += 0.00000001560*np.cos(0.36404331783 + 9896.8936765544*t)
	X0 += 0.00000001179*np.cos(6.00538975341 + 14919.0178537546*t)
	X0 += 0.00000001466*np.cos(2.04239320632 + 9146.790069021*t)
	X0 += 0.00000001158*np.cos(3.85902457723 + 10632.7701900862*t)
	X0 += 0.00000001483*np.cos(1.40459440941 + 210.8514148832*t)
	X0 += 0.00000001423*np.cos(5.98922157377 + 225.8292684102*t)
	X0 += 0.00000001472*np.cos(3.48774945967 + 215.7467759928*t)
	X0 += 0.00000001259*np.cos(4.23560000055 + 2379.1644735716*t)
	X0 += 0.00000001493*np.cos(1.40653635325 + 22805.7355659936*t)
	X0 += 0.00000001090*np.cos(2.83082031323 + 422.6660376129*t)
	X0 += 0.00000001402*np.cos(5.00430127066 + 10639.883737087*t)
	X0 += 0.00000001047*np.cos(0.50899510052 + 309.2783226558*t)
	X0 += 0.00000001129*np.cos(5.77658236271 + 9793.8009023358*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001022*np.cos(0.96352485877 + 145.6310438715*t)
	X0 += 0.00000001422*np.cos(2.40975714524 + 152.5321425512*t)
	X0 += 0.00000001034*np.cos(3.22353796512 + 1795.258443721*t)
	X0 += 0.00000000979*np.cos(2.33360006154 + 84.3428261229*t)
	X0 += 0.00000001342*np.cos(4.46625072671 + 36949.2308084242*t)
	X0 += 0.00000000966*np.cos(6.19909761751 + 1272.6810256272*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000001075*np.cos(0.57961253778 + 212.3358875915*t)
	X0 += 0.00000001070*np.cos(4.31120526838 + 214.2623032845*t)
	X0 += 0.00000001190*np.cos(4.52803152244 + 39264.0692895602*t)
	X0 += 0.00000001013*np.cos(2.10885792626 + 10419.4710946482*t)
	X0 += 0.00000001010*np.cos(1.09565332862 + 10007.0999977738*t)
	X0 += 0.00000001244*np.cos(2.87441597074 + 184.7272873558*t)
	X0 += 0.00000001098*np.cos(2.95983802473 + 137.0330241624*t)
	X0 += 0.00000000889*np.cos(3.98790631605 + 213.2509113282*t)
	X0 += 0.00000000889*np.cos(0.90251570889 + 213.3472795478*t)
	X0 += 0.00000000996*np.cos(4.53849426210 + 13341.6743113068*t)
	X0 += 0.00000001126*np.cos(1.83484274734 + 245.8316462294*t)
	X0 += 0.00000000846*np.cos(0.63826672604 + 18875.525869774*t)
	X0 += 0.00000000967*np.cos(4.53246389020 + 437.6438911399*t)
	X0 += 0.00000000937*np.cos(1.00137410835 + 26087.9031415742*t)
	X0 += 0.00000000819*np.cos(0.57163728715 + 529.6427809848*t)
	X0 += 0.00000000819*np.cos(3.76946397274 + 529.7391492044*t)
	X0 += 0.00000000811*np.cos(2.26915207928 + 288.0806940053*t)
	X0 += 0.00000000826*np.cos(5.05488603368 + 2648.454825473*t)
	X0 += 0.00000000845*np.cos(6.08176877562 + 9676.4810341156*t)
	X0 += 0.00000001037*np.cos(4.27554240329 + 527.2432845398*t)
	X0 += 0.00000001031*np.cos(0.06363683037 + 532.1386456494*t)
	X0 += 0.00000000797*np.cos(4.06306935733 + 203.7378678824*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000000760*np.cos(4.01810781408 + 7564.830720738*t)
	X0 += 0.00000000786*np.cos(2.08323238184 + 11764.330768859*t)
	X0 += 0.00000000734*np.cos(5.35841388096 + 112.9146342051*t)
	X0 += 0.00000000795*np.cos(3.42432291896 + 10750.0900583064*t)
	X0 += 0.00000000770*np.cos(0.68487491199 + 7834.1210726394*t)
	X0 += 0.00000000709*np.cos(1.92302056629 + 628.8515860501*t)
	X0 += 0.00000000698*np.cos(3.40358510787 + 36147.4098773004*t)
	X0 += 0.00000000906*np.cos(0.29625818951 + 31441.6775697568*t)
	X0 += 0.00000000926*np.cos(2.97025862788 + 160.6088973985*t)
	X0 += 0.00000000826*np.cos(3.32684274495 + 838.9692877504*t)
	X0 += 0.00000000787*np.cos(5.89002463165 + 19889.76658032659*t)
	X0 += 0.00000000648*np.cos(2.95455543165 + 2008.557539159*t)
	X0 += 0.00000000788*np.cos(0.18032696972 + 7994.5284420242*t)
	X0 += 0.00000000624*np.cos(2.84767789659 + 39793.7602546548*t)
	X0 += 0.00000000865*np.cos(1.99609335238 + 41654.9631159678*t)
	X0 += 0.00000000692*np.cos(2.83117936839 + 9.5612275556*t)
	X0 += 0.00000000624*np.cos(0.50120316917 + 430.5303441391*t)
	X0 += 0.00000000599*np.cos(3.24438777522 + 2111.6503133776*t)
	X0 += 0.00000000832*np.cos(2.20242516999 + 380.12776796*t)
	X0 += 0.00000000744*np.cos(2.51526632902 + 19903.99367432819*t)
	X0 += 0.00000000662*np.cos(4.47978464665 + 1063.3140834523*t)
	X0 += 0.00000000616*np.cos(5.14603483362 + 1368.660252845*t)
	X0 += 0.00000000823*np.cos(5.88974834586 + 40879.4405046438*t)
	X0 += 0.00000000592*np.cos(0.65691971752 + 17778.11626694899*t)
	X0 += 0.00000000639*np.cos(3.15793381912 + 12.5301729722*t)
	X0 += 0.00000000599*np.cos(0.38463092695 + 423.4167971383*t)
	X0 += 0.00000000770*np.cos(2.88484885613 + 26735.9452622132*t)
	X0 += 0.00000000648*np.cos(3.43475812975 + 528.7277572481*t)
	X0 += 0.00000000715*np.cos(5.24194846626 + 16983.9961474566*t)
	X0 += 0.00000000646*np.cos(0.90574398043 + 530.6541729411*t)
	X0 += 0.00000000569*np.cos(1.11632920377 + 19786.67380610799*t)
	X0 += 0.00000000547*np.cos(3.88827567459 + 2221.856634597*t)
	X0 += 0.00000000538*np.cos(6.04102038970 + 127.4717966068*t)
	X0 += 0.00000000548*np.cos(1.60570553727 + 27197.2816936676*t)
	X0 += 0.00000000542*np.cos(0.91953382373 + 1055.4497769261*t)
	X0 += 0.00000000672*np.cos(3.08200615608 + 221.3758502853*t)
	X0 += 0.00000000566*np.cos(2.70414246898 + 728.762966531*t)
	X0 += 0.00000000490*np.cos(2.97472409276 + 71.6002048296*t)
	X0 += 0.00000000605*np.cos(4.63445753926 + 10059.5067357262*t)
	X0 += 0.00000000552*np.cos(2.14941738098 + 28521.0927782546*t)
	X0 += 0.00000000676*np.cos(5.20222552429 + 20529.66386664059*t)
	X0 += 0.00000000593*np.cos(4.85950564308 + 10367.0643566958*t)
	X0 += 0.00000000649*np.cos(1.32346646305 + 22.0914005278*t)
	X0 += 0.00000000514*np.cos(5.06894525071 + 8662.240323563*t)
	X0 += 0.00000000471*np.cos(4.83320292258 + 77.962992305*t)
	X0 += 0.00000000623*np.cos(2.85969660852 + 330.6189636582*t)
	X0 += 0.00000000652*np.cos(2.72637797985 + 388.4651552382*t)
	X0 += 0.00000000469*np.cos(5.48839305777 + 8631.326197928*t)
	X0 += 0.00000000468*np.cos(0.69788003422 + 1073.6090241908*t)
	X0 += 0.00000000454*np.cos(0.79241873074 + 10042.6126755918*t)
	X0 += 0.00000000574*np.cos(5.66932742997 + 87.3117715395*t)
	X0 += 0.00000000515*np.cos(2.92229144851 + 12432.0426503978*t)
	X0 += 0.00000000444*np.cos(2.41828206903 + 10383.9584168302*t)
	X0 += 0.00000000605*np.cos(1.98317483331 + 984.6003316219*t)
	X0 += 0.00000000541*np.cos(3.08246188636 + 72.3339180125*t)
	X0 += 0.00000000460*np.cos(0.69107495802 + 11802.3584414948*t)
	X0 += 0.00000000467*np.cos(5.34128135139 + 212.7778305762*t)
	X0 += 0.00000000466*np.cos(5.83324087524 + 213.8203602998*t)
	X0 += 0.00000000436*np.cos(1.85693485685 + 9638.9407478762*t)
	X0 += 0.00000000418*np.cos(2.75937640828 + 429.7795846137*t)
	X0 += 0.00000000422*np.cos(1.39991487980 + 10787.6303445458*t)
	X0 += 0.00000000416*np.cos(1.72605691131 + 10225.014899047*t)
	X0 += 0.00000000416*np.cos(1.48464382888 + 10201.556193375*t)
	X0 += 0.00000000462*np.cos(1.66174622090 + 860.3099287528*t)
	X0 += 0.00000000431*np.cos(1.72994989473 + 8617.0991039264*t)
	X0 += 0.00000000548*np.cos(5.68904924324 + 8521.1198767086*t)
	X0 += 0.00000000381*np.cos(0.22534351229 + 19317.1925403286*t)
	X0 += 0.00000000511*np.cos(4.91405448075 + 77.2292791221*t)
	X0 += 0.00000000466*np.cos(5.23261301624 + 6770.7106012456*t)
	X0 += 0.00000000384*np.cos(0.64251152112 + 340.7708920448*t)
	X0 += 0.00000000444*np.cos(1.73410494666 + 2218.7571041868*t)
	X0 += 0.00000000511*np.cos(1.02944887408 + 44809.6502008634*t)
	X0 += 0.00000000363*np.cos(4.26514474189 + 30831.3049047446*t)
	X0 += 0.00000000489*np.cos(4.26102629725 + 30666.1549584328*t)
	X0 += 0.00000000354*np.cos(0.36763636808 + 10103.0792249916*t)
	X0 += 0.00000000354*np.cos(2.84306437211 + 10323.4918674304*t)
	X0 += 0.00000000427*np.cos(2.66965454095 + 13655.8604911764*t)
	X0 += 0.00000000354*np.cos(2.54868316520 + 62.2514255951*t)
	X0 += 0.00000000395*np.cos(3.93999186550 + 52.6901980395*t)
	X0 += 0.00000000406*np.cos(2.27584736071 + 350.3321196004*t)
	X0 += 0.00000000359*np.cos(0.09178138960 + 27490.6924780448*t)
	X0 += 0.00000000366*np.cos(3.21039535060 + 283.8593188652*t)
	X0 += 0.00000000396*np.cos(1.99989177453 + 145.1097790097*t)
	X0 += 0.00000000385*np.cos(6.13244198192 + 909.8187330546*t)
	X0 += 0.00000000315*np.cos(0.01870495544 + 20639.87018786*t)
	X0 += 0.00000000364*np.cos(4.22573825928 + 38734.3783244656*t)
	X0 += 0.00000000399*np.cos(4.24912842655 + 10211.8010735027*t)
	X0 += 0.00000000399*np.cos(5.24475762082 + 10214.7700189193*t)
	X0 += 0.00000000313*np.cos(3.62090724113 + 234.6397364404*t)
	X0 += 0.00000000382*np.cos(1.81523910449 + 186.2117600641*t)
	X0 += 0.00000000388*np.cos(2.28168065953 + 29999.959352319*t)
	X0 += 0.00000000398*np.cos(3.64836729223 + 9835.9119382952*t)
	X0 += 0.00000000404*np.cos(3.98593080979 + 20351.7894938547*t)
	X0 += 0.00000000385*np.cos(1.36867886553 + 20180.7394461926*t)
	X0 += 0.00000000400*np.cos(1.38752434540 + 454.9093665273*t)
	X0 += 0.00000000372*np.cos(4.82853244691 + 3.1813937377*t)
	X0 += 0.00000000288*np.cos(0.91857388482 + 1905.4647649404*t)
	X0 += 0.00000000379*np.cos(5.84551887726 + 10590.6591541268*t)
	X0 += 0.00000000300*np.cos(5.68088059375 + 24150.080051345*t)
	X0 += 0.00000000283*np.cos(5.59475061655 + 26709.6469424134*t)
	X0 += 0.00000000390*np.cos(3.42415946376 + 45585.1728121874*t)
	X0 += 0.00000000365*np.cos(1.42467845102 + 10348.910871221*t)
	X0 += 0.00000000365*np.cos(1.78602228917 + 10077.660221201*t)
	X0 += 0.00000000308*np.cos(2.68902321898 + 362.8622925726*t)
	X0 += 0.00000000309*np.cos(5.67052430501 + 6309.3741697912*t)
	X0 += 0.00000000283*np.cos(5.53469245500 + 3903.9113764198*t)
	X0 += 0.00000000335*np.cos(0.71030115582 + 200.7689224658*t)
	X0 += 0.00000000271*np.cos(3.85648668964 + 9745.3205558566*t)
	X0 += 0.00000000311*np.cos(4.44573637765 + 297.6419215609*t)
	X0 += 0.00000000327*np.cos(6.11774154244 + 9360.089164459*t)
	X0 += 0.00000000264*np.cos(3.81456195150 + 1485.9801210652*t)
	X0 += 0.00000000289*np.cos(1.92464337356 + 529.1697002328*t)
	X0 += 0.00000000366*np.cos(2.92406939426 + 604.4725636619*t)
	X0 += 0.00000000288*np.cos(2.41719522186 + 530.2122299564*t)
	X0 += 0.00000000314*np.cos(1.84357518690 + 108.4612160802*t)
	X0 += 0.00000000262*np.cos(4.15566435137 + 1258.4539316256*t)
	X0 += 0.00000000314*np.cos(1.40080599663 + 20405.7956969296*t)
	X0 += 0.00000000306*np.cos(1.12587272451 + 2957.7158944766*t)
	X0 += 0.00000000254*np.cos(5.63745223648 + 10681.2505365654*t)
	X0 += 0.00000000343*np.cos(4.64296056111 + 8106.2510386686*t)
	X0 += 0.00000000274*np.cos(1.54026728979 + 565.1156877467*t)
	X0 += 0.00000000268*np.cos(0.19545433539 + 140.001969579*t)
	X0 += 0.00000000320*np.cos(0.32229958420 + 703.6331846174*t)
	X0 += 0.00000000243*np.cos(0.44342371962 + 1062.5633239269*t)
	X0 += 0.00000000248*np.cos(0.09445957496 + 210.3783341312*t)
	X0 += 0.00000000248*np.cos(4.79327801971 + 216.2198567448*t)
	X0 += 0.00000000324*np.cos(3.98782911883 + 31749.2351907264*t)
	X0 += 0.00000000241*np.cos(3.24545153339 + 37.611770776*t)
	X0 += 0.00000000255*np.cos(4.90697050745 + 153.4953503977*t)
	X0 += 0.00000000237*np.cos(3.72326482255 + 212.5483359126*t)
	X0 += 0.00000000236*np.cos(1.16575065097 + 214.0498549634*t)
	X0 += 0.00000000234*np.cos(3.82015244739 + 19624.7501612982*t)
	X0 += 0.00000000236*np.cos(4.23871934676 + 38.6543004996*t)
	X0 += 0.00000000252*np.cos(4.61065643475 + 209.106309744*t)
	X0 += 0.00000000281*np.cos(0.78332222978 + 9399.7352622512*t)
	X0 += 0.00000000322*np.cos(2.45576489589 + 48739.859897083*t)
	X0 += 0.00000000308*np.cos(0.46119280399 + 37410.5672398786*t)
	X0 += 0.00000000247*np.cos(0.27272991614 + 217.491881132*t)
	X0 += 0.00000000230*np.cos(4.91404068561 + 574.3447983348*t)
	X0 += 0.00000000225*np.cos(3.38119852586 + 223.5940361765*t)
	X0 += 0.00000000224*np.cos(5.51904045547 + 38.084851528*t)
	X0 += 0.00000000223*np.cos(1.96313876697 + 38.1812197476*t)
	X0 += 0.00000000295*np.cos(5.75145374701 + 34596.3646546524*t)
	X0 += 0.00000000245*np.cos(4.21060733239 + 173.9422195228*t)
	X0 += 0.00000000217*np.cos(1.51605950497 + 2125.8774073792*t)
	X0 += 0.00000000214*np.cos(0.59816494895 + 12592.4500197826*t)
	X0 += 0.00000000233*np.cos(4.35078533465 + 9264.1099372412*t)
	X0 += 0.00000000255*np.cos(4.03464641753 + 9992.8729037722*t)
	X0 += 0.00000000255*np.cos(5.45923962984 + 10433.6981886498*t)
	X0 += 0.00000000234*np.cos(0.55106604784 + 74.2603337055*t)
	X0 += 0.00000000233*np.cos(0.98887023825 + 75.3028634291*t)
	X0 += 0.00000000211*np.cos(0.18276464350 + 10249.3134128884*t)
	X0 += 0.00000000211*np.cos(3.02793609669 + 10177.2576795336*t)
	X0 += 0.00000000255*np.cos(2.42745817670 + 11026.8358301708*t)
	X0 += 0.00000000288*np.cos(1.80083466219 + 35371.8872659764*t)
	X0 += 0.00000000221*np.cos(0.56282855969 + 38.0276726358*t)
	X0 += 0.00000000247*np.cos(0.56642494969 + 252.6559713532*t)
	X0 += 0.00000000224*np.cos(4.78244233129 + 19360.07561523199*t)
	X0 += 0.00000000247*np.cos(1.90808707769 + 29587.5882554446*t)
	X0 += 0.00000000204*np.cos(0.84533704687 + 18.1592472647*t)
	X0 += 0.00000000206*np.cos(3.37469119852 + 30426.557543195*t)
	X0 += 0.00000000282*np.cos(1.41766310537 + 563.6312150384*t)
	X0 += 0.00000000263*np.cos(3.16130275876 + 20433.6846394228*t)
	X0 += 0.00000000212*np.cos(3.16045353079 + 10206.65698731099*t)
	X0 += 0.00000000212*np.cos(0.05024720940 + 10219.91410511101*t)
	X0 += 0.00000000200*np.cos(0.56723215810 + 3.9321532631*t)
	X0 += 0.00000000202*np.cos(0.82731831247 + 16894.5103996106*t)
	X0 += 0.00000000207*np.cos(5.75479453376 + 142.4496501338*t)
	X0 += 0.00000000272*np.cos(4.85092274037 + 12320.3200537534*t)
	X0 += 0.00000000258*np.cos(5.22999934273 + 29573.361161443*t)
	X0 += 0.00000000204*np.cos(0.27721513871 + 417.0369633204*t)
	X0 += 0.00000000195*np.cos(4.23402090499 + 66.70484372*t)
	X0 += 0.00000000211*np.cos(5.11529334983 + 11162.4611551808*t)
	X0 += 0.00000000210*np.cos(5.15156975899 + 22645.32819660879*t)
	X0 += 0.00000000211*np.cos(5.13588313603 + 37.1698277913*t)
	X0 += 0.00000000215*np.cos(0.35886038032 + 1699.2792165032*t)
	X0 += 0.00000000267*np.cos(4.30118423273 + 377.3736079158*t)
	X0 += 0.00000000186*np.cos(4.53704574212 + 10251.4185818488*t)
	X0 += 0.00000000186*np.cos(4.95684030525 + 10175.1525105732*t)
	X0 += 0.00000000258*np.cos(2.52339488384 + 9864.361125763*t)
	X0 += 0.00000000186*np.cos(4.87586761272 + 17271.8840075264*t)
	X0 += 0.00000000227*np.cos(5.15751336106 + 207.8824694666*t)
	X0 += 0.00000000203*np.cos(2.35104519506 + 39.0962434843*t)
	X0 += 0.00000000202*np.cos(4.05217682796 + 207.6700211455*t)
	X0 += 0.00000000182*np.cos(3.89203001563 + 1898.3512179396*t)
	X0 += 0.00000000219*np.cos(6.03807342488 + 218.7157214094*t)
	X0 += 0.00000000206*np.cos(5.35930784504 + 88.865680217*t)
	X0 += 0.00000000254*np.cos(3.15931084747 + 19264.0963880142*t)
	X0 += 0.00000000188*np.cos(2.43290559306 + 1471.7530270636*t)
	X0 += 0.00000000240*np.cos(1.30869138812 + 16522.6597160022*t)
	X0 += 0.00000000185*np.cos(4.15018423748 + 508.3503240922*t)
	X0 += 0.00000000246*np.cos(0.68740438301 + 10562.209966659*t)
	X0 += 0.00000000195*np.cos(0.82662766477 + 218.9281697305*t)
	X0 += 0.00000000211*np.cos(6.16254771086 + 11375.7602506188*t)
	X0 += 0.00000000178*np.cos(0.50910605505 + 10949.1620597428*t)
	X0 += 0.00000000178*np.cos(2.70159468514 + 9477.4090326792*t)
	X0 += 0.00000000174*np.cos(4.78535633940 + 40077.61957352*t)
	X0 += 0.00000000224*np.cos(4.06529944699 + 1056.2005364515*t)
	X0 += 0.00000000177*np.cos(0.12290786955 + 20316.36477120259*t)
	X0 += 0.00000000172*np.cos(2.96155542160 + 526.7702037878*t)
	X0 += 0.00000000173*np.cos(1.33272334806 + 8734.4189721466*t)
	X0 += 0.00000000186*np.cos(0.73069210814 + 554.0699874828*t)
	X0 += 0.00000000194*np.cos(2.50663265946 + 28.5718080822*t)
	X0 += 0.00000000169*np.cos(1.38093325803 + 532.6117264014*t)
	X0 += 0.00000000192*np.cos(3.08542976535 + 1574.8458012822*t)
	X0 += 0.00000000217*np.cos(3.59114151623 + 124.433415221*t)
	X0 += 0.00000000176*np.cos(1.20681960915 + 525.4981794006*t)
	X0 += 0.00000000172*np.cos(5.60194767636 + 211.8146227297*t)
	X0 += 0.00000000196*np.cos(4.69372863801 + 9779.5738083342*t)
	X0 += 0.00000000188*np.cos(3.44598602635 + 569.0478410098*t)
	X0 += 0.00000000158*np.cos(0.33551046271 + 528.9402055692*t)
	X0 += 0.00000000157*np.cos(4.00545168863 + 530.44172462*t)
	X0 += 0.00000000198*np.cos(3.27402275626 + 27991.40181316*t)
	X0 += 0.00000000154*np.cos(0.72358681867 + 10199.0584522094*t)
	X0 += 0.00000000154*np.cos(2.48711392152 + 10227.5126402126*t)
	X0 += 0.00000000189*np.cos(0.66769513206 + 9256.9963902404*t)
	X0 += 0.00000000193*np.cos(2.39642315228 + 17468.8551979454*t)
	X0 += 0.00000000177*np.cos(0.70756419313 + 32.1951448046*t)
	X0 += 0.00000000191*np.cos(4.12314886390 + 183.2428146475*t)
	X0 += 0.00000000179*np.cos(1.49110102879 + 5.9378908332*t)
	X0 += 0.00000000170*np.cos(5.83704197169 + 305.3461693927*t)
	X0 += 0.00000000207*np.cos(1.81656116060 + 73.8183907208*t)
	X0 += 0.00000000205*np.cos(3.90575045563 + 52670.0695933026*t)
	X0 += 0.00000000175*np.cos(1.28027815287 + 217.964961884*t)
	X0 += 0.00000000148*np.cos(4.39633643688 + 519.3960243561*t)
	X0 += 0.00000000166*np.cos(3.75162140471 + 10263.0425716828*t)
	X0 += 0.00000000166*np.cos(5.74226464266 + 10163.5285207392*t)
	X0 += 0.00000000147*np.cos(3.63497942528 + 82.8583534146*t)
	X0 += 0.00000000168*np.cos(5.33584294691 + 7991.428911614*t)
	X0 += 0.00000000194*np.cos(0.90820651456 + 38526.574350872*t)
	X0 += 0.00000000196*np.cos(4.87499369677 + 49515.382508407*t)
	X0 += 0.00000000203*np.cos(2.54569209930 + 453.424893819*t)
	X0 += 0.00000000191*np.cos(5.96603240618 + 425.1137181677*t)
	X0 += 0.00000000148*np.cos(3.53096991388 + 414.0680179038*t)
	X0 += 0.00000000200*np.cos(0.25134097583 + 1439.5096981492*t)
	X0 += 0.00000000165*np.cos(5.22234420384 + 231.4583427027*t)
	X0 += 0.00000000169*np.cos(5.71918201676 + 11265.5539293994*t)
	X0 += 0.00000000141*np.cos(5.69421526925 + 408.4389436113*t)
	X0 += 0.00000000194*np.cos(2.26711785239 + 8837.5117463652*t)
	X0 += 0.00000000140*np.cos(0.33029139370 + 10191.4347168846*t)
	X0 += 0.00000000140*np.cos(2.88040934649 + 10235.1363755374*t)
	X0 += 0.00000000196*np.cos(2.27333422690 + 1293.4842235826*t)
	X0 += 0.00000000191*np.cos(6.04625942487 + 75.7448064138*t)
	X0 += 0.00000000162*np.cos(5.59199233193 + 7255.5696517344*t)
	X0 += 0.00000000178*np.cos(3.84899225076 + 1685.0521225016*t)
	X0 += 0.00000000149*np.cos(3.15621899577 + 533.8837507886*t)
	X0 += 0.00000000138*np.cos(0.38495137130 + 10217.2176994741*t)
	X0 += 0.00000000138*np.cos(2.82574936889 + 10209.3533929479*t)
	X0 += 0.00000000157*np.cos(3.61532012746 + 208.633228992*t)
	X0 += 0.00000000153*np.cos(4.99836680146 + 47.6942631934*t)
	X0 += 0.00000000184*np.cos(2.16301573772 + 1021.2488945514*t)
	X0 += 0.00000000139*np.cos(5.84452648935 + 373.9079928365*t)
	X0 += 0.00000000138*np.cos(5.61172177506 + 214.7835681463*t)
	X0 += 0.00000000149*np.cos(2.28858934145 + 19374.3027092336*t)
	X0 += 0.00000000129*np.cos(1.54390762080 + 203.0041546995*t)
	X0 += 0.00000000128*np.cos(5.24161490581 + 479.2883889155*t)
	X0 += 0.00000000143*np.cos(1.40332876782 + 20447.3464879144*t)
	X0 += 0.00000000126*np.cos(3.82073811345 + 20277.0078952874*t)
	X0 += 0.00000000130*np.cos(2.26702486739 + 654.1243803156*t)
	X0 += 0.00000000162*np.cos(1.69374604806 + 10063.7223490764*t)
	X0 += 0.00000000144*np.cos(1.54442458059 + 4.192785694*t)
	X0 += 0.00000000139*np.cos(1.22510407970 + 251.4321310758*t)
	X0 += 0.00000000160*np.cos(5.11540883899 + 265.9892934775*t)
	X0 += 0.00000000149*np.cos(2.18564631641 + 10135.611775783*t)
	X0 += 0.00000000149*np.cos(1.02505442378 + 10290.959316639*t)
	X0 += 0.00000000121*np.cos(5.05113331022 + 56.6223513026*t)
	X0 += 0.00000000151*np.cos(0.84241735172 + 10245.8180970024*t)
	X0 += 0.00000000151*np.cos(2.36828338847 + 10180.7529954196*t)
	X0 += 0.00000000152*np.cos(4.60730376543 + 18830.38465013739*t)
	X0 += 0.00000000115*np.cos(6.22459411775 + 539.9859058331*t)
	X0 += 0.00000000144*np.cos(3.98382443588 + 24383.0791084414*t)
	X0 += 0.00000000114*np.cos(4.16184056386 + 32858.61374281979*t)
	X0 += 0.00000000144*np.cos(3.82694942167 + 9985.809413422*t)
	X0 += 0.00000000144*np.cos(5.66693662570 + 10440.76167900*t)
	X0 += 0.00000000143*np.cos(1.56048542507 + 18844.61174413899*t)
	X0 += 0.00000000130*np.cos(5.57171941495 + 10236.0607476618*t)
	X0 += 0.00000000130*np.cos(3.92216663242 + 10190.5103447602*t)
	X0 += 0.00000000156*np.cos(4.19081128787 + 20388.4380567842*t)
	X0 += 0.00000000155*np.cos(0.85940335797 + 8237.793000355*t)
	X0 += 0.00000000114*np.cos(0.09813992796 + 213.1872208534*t)
	X0 += 0.00000000114*np.cos(4.79116773360 + 213.4109700226*t)
	X0 += 0.00000000123*np.cos(5.10501021239 + 98.8999885246*t)
	X0 += 0.00000000116*np.cos(0.64506154486 + 524.0618908021*t)
	X0 += 0.00000000115*np.cos(3.69498632982 + 535.3200393871*t)
	X0 += 0.00000000127*np.cos(0.63003020942 + 540.7366653585*t)
	X0 += 0.00000000131*np.cos(5.39530111218 + 8101.6352328334*t)
	X0 += 0.00000000118*np.cos(0.24752969879 + 983.1158589136*t)
	X0 += 0.00000000118*np.cos(0.19804778544 + 525.0250986486*t)
	X0 += 0.00000000111*np.cos(2.93356769076 + 43071.8992890308*t)
	X0 += 0.00000000100*np.cos(3.71645704441 + 529.851023789*t)
	X0 += 0.00000000100*np.cos(0.62422783083 + 529.5309064002*t)
	X0 += 0.00000000099*np.cos(4.32745781002 + 24978.5245894808*t)
	X0 += 0.00000000102*np.cos(1.31527898088 + 963.4027029714*t)
	X0 += 0.00000000099*np.cos(1.87542989608 + 198.321241911*t)
	X0 += 0.00000000101*np.cos(5.26437713251 + 20043.6745601988*t)
	X0 += 0.00000000111*np.cos(1.30109743855 + 80.1982245387*t)
	X0 += 0.00000000132*np.cos(5.33260115213 + 56600.2792895222*t)
	X0 += 0.00000000136*np.cos(6.07742370370 + 5999.2165311262*t)
	X0 += 0.00000000096*np.cos(4.17152569130 + 213.5115437591*t)
	X0 += 0.00000000096*np.cos(0.71778197027 + 213.0866471169*t)
	X0 += 0.00000000127*np.cos(2.33491999261 + 42456.7840470916*t)
	X0 += 0.00000000099*np.cos(0.19873228449 + 551.031606097*t)
	X0 += 0.00000000112*np.cos(3.45345978303 + 2324.9494088156*t)
	X0 += 0.00000000111*np.cos(4.13924061941 + 534.3568315406*t)
	X0 += 0.00000000117*np.cos(1.76475239313 + 524.2743391232*t)
	X0 += 0.00000000131*np.cos(3.21869975863 + 4176.041342449*t)
	X0 += 0.00000000106*np.cos(1.57523662131 + 19573.37471066999*t)
	X0 += 0.00000000125*np.cos(4.85236761160 + 21.3406410024*t)
	X0 += 0.00000000095*np.cos(5.28465176922 + 327.4375699205*t)
	X0 += 0.00000000115*np.cos(2.57406093768 + 535.107591066*t)
	X0 += 0.00000000100*np.cos(2.94090698274 + 195.1398481733*t)
	X0 += 0.00000000112*np.cos(2.47056814408 + 20206.15844998319*t)
	X0 += 0.00000000093*np.cos(0.23284844018 + 8204.728007052*t)
	X0 += 0.00000000096*np.cos(0.06385619665 + 35.685355083*t)
	X0 += 0.00000000113*np.cos(1.72263005108 + 114.1384744825*t)
	X0 += 0.00000000098*np.cos(3.12531862236 + 11059.3683809622*t)
	X0 += 0.00000000090*np.cos(2.40621950932 + 29057.89729034999*t)
	X0 += 0.00000000091*np.cos(0.08598161680 + 1802.3719907218*t)
	X0 += 0.00000000103*np.cos(5.15240336003 + 10244.199671846*t)
	X0 += 0.00000000103*np.cos(4.34148268734 + 10182.371420576*t)
	X0 += 0.00000000089*np.cos(3.16908258340 + 1382.8873468466*t)
	X0 += 0.00000000125*np.cos(2.35130047125 + 12188.778092067*t)
	X0 += 0.00000000102*np.cos(4.42228976166 + 219.891377577*t)
	X0 += 0.00000000088*np.cos(4.33292988106 + 20350.3050211464*t)
	X0 += 0.00000000105*np.cos(3.96512076229 + 19793.7873531088*t)
	X0 += 0.00000000122*np.cos(5.43246799719 + 2636.725472637*t)
	X0 += 0.00000000086*np.cos(2.85915032438 + 228.276948965*t)
	X0 += 0.00000000095*np.cos(3.90711906214 + 2333.196392872*t)
	X0 += 0.00000000087*np.cos(1.36045970674 + 8087.4081388318*t)
	X0 += 0.00000000086*np.cos(3.64749231964 + 7035.1397556434*t)
	X0 += 0.00000000100*np.cos(3.39323367399 + 96.8729990951*t)
	X0 += 0.00000000084*np.cos(2.61330768505 + 74.7334144575*t)
	X0 += 0.00000000084*np.cos(5.20716850754 + 74.8297826771*t)
	X0 += 0.00000000095*np.cos(2.03086124785 + 10202.2398459471*t)
	X0 += 0.00000000095*np.cos(1.17983949234 + 10224.3312464749*t)
	X0 += 0.00000000114*np.cos(1.15232105885 + 177.8743727859*t)
	X0 += 0.00000000084*np.cos(1.22799614537 + 10401.2106939736*t)
	X0 += 0.00000000084*np.cos(1.98270459482 + 10025.3603984484*t)
	X0 += 0.00000000085*np.cos(5.03727591626 + 19477.39548345219*t)
	X0 += 0.00000000087*np.cos(1.13401038923 + 40.5807161926*t)
	X0 += 0.00000000087*np.cos(4.97431232996 + 29043.67019634839*t)
	X0 += 0.00000000082*np.cos(6.17390445678 + 44007.8292697396*t)
	X0 += 0.00000000081*np.cos(3.33902328234 + 191.2076949102*t)
	X0 += 0.00000000093*np.cos(1.06738164563 + 74.5209661364*t)
	X0 += 0.00000000093*np.cos(4.35602536763 + 5.5229243074*t)
	X0 += 0.00000000093*np.cos(0.46802035326 + 75.0422309982*t)
	X0 += 0.00000000079*np.cos(4.31891477024 + 38.0211610532*t)
	X0 += 0.00000000079*np.cos(3.16332905605 + 38.2449102224*t)
	X0 += 0.00000000080*np.cos(1.40233563562 + 191.9584544356*t)
	X0 += 0.00000000079*np.cos(4.46070108071 + 278.5194664497*t)
	X0 += 0.00000000080*np.cos(3.95392779576 + 175.1660598002*t)
	X0 += 0.00000000083*np.cos(2.35608099285 + 300.6108669775*t)
	X0 += 0.00000000098*np.cos(5.37191506696 + 20220.3855439848*t)
	X0 += 0.00000000078*np.cos(0.92843223712 + 30.0562807905*t)
	X0 += 0.00000000097*np.cos(5.32653372215 + 259.5088859231*t)
	X0 += 0.00000000095*np.cos(3.35136515938 + 29477.3819342252*t)
	X0 += 0.00000000096*np.cos(1.62154996582 + 30206.14490075619*t)
	X0 += 0.00000000095*np.cos(4.51772320117 + 30220.3719947578*t)
	X0 += 0.00000000077*np.cos(2.50991636518 + 205.2223405907*t)
	X0 += 0.00000000089*np.cos(3.13112055622 + 29786.660256881*t)
	X0 += 0.00000000107*np.cos(4.65459265447 + 2069.0068349066*t)
	X0 += 0.00000000100*np.cos(4.44047000599 + 38500.2760310722*t)
	X0 += 0.00000000077*np.cos(3.58586905737 + 10853.182832525*t)
	X0 += 0.00000000085*np.cos(0.43515691954 + 44.070926471*t)
	X0 += 0.00000000076*np.cos(4.87466102622 + 10243.1069843598*t)
	X0 += 0.00000000076*np.cos(4.61922502115 + 10183.4641080622*t)
	X0 += 0.00000000096*np.cos(6.24127646307 + 131.4039498699*t)
	X0 += 0.00000000101*np.cos(0.03242064905 + 53445.5922046266*t)
	X0 += 0.00000000091*np.cos(3.88112259566 + 80.7194894005*t)
	X0 += 0.00000000086*np.cos(2.29756841695 + 18734.4054229196*t)
	X0 += 0.00000000100*np.cos(2.64031933351 + 28947.6909691306*t)
	X0 += 0.00000000078*np.cos(2.59112277976 + 74.6215398729*t)
	X0 += 0.00000000078*np.cos(5.22948432343 + 74.9416572617*t)
	X0 += 0.00000000073*np.cos(1.68280932827 + 21000.9158907568*t)
	X0 += 0.00000000075*np.cos(2.21732650708 + 302.164775655*t)
	X0 += 0.00000000073*np.cos(0.32333160897 + 17248.4253018544*t)
	X0 += 0.00000000094*np.cos(5.44157645789 + 28313.288804661*t)
	X0 += 0.00000000072*np.cos(4.81698863150 + 213.5597278689*t)
	X0 += 0.00000000072*np.cos(0.07231943414 + 213.0384630071*t)
	X0 += 0.00000000096*np.cos(4.24511131293 + 483.2205421786*t)
	X0 += 0.00000000085*np.cos(5.27335453034 + 3914.9572250346*t)
	X0 += 0.00000000074*np.cos(1.92420739215 + 8827.3902698748*t)
	X0 += 0.00000000070*np.cos(1.49155244201 + 6298.3283211764*t)
	X0 += 0.00000000069*np.cos(2.29681555948 + 34570.0663348526*t)
	X0 += 0.00000000071*np.cos(3.95871098581 + 34171.9173314444*t)
	X0 += 0.00000000079*np.cos(2.65919074354 + 10018.3141617504*t)
	X0 += 0.00000000079*np.cos(0.55150999665 + 10408.2569306716*t)
	X0 += 0.00000000069*np.cos(3.45966511571 + 529.4785167735*t)
	X0 += 0.00000000069*np.cos(0.88102053266 + 529.9034134157*t)
	X0 += 0.00000000094*np.cos(3.68180477512 + 248.7238180901*t)
	X0 += 0.00000000080*np.cos(2.11794073365 + 14128.2427712456*t)
	X0 += 0.00000000077*np.cos(3.59376629306 + 518.6452648307*t)
	X0 += 0.00000000087*np.cos(3.78428652532 + 46386.9937433112*t)
	X0 += 0.00000000069*np.cos(0.90460126437 + 41044.5904509556*t)
	X0 += 0.00000000069*np.cos(2.25427054035 + 9644.4636721836*t)
	X0 += 0.00000000069*np.cos(0.95643019984 + 10782.1074202384*t)
	X0 += 0.00000000066*np.cos(2.02327672376 + 635.9651330509*t)
	X0 += 0.00000000083*np.cos(5.79338403589 + 9721.6222537522*t)
	X0 += 0.00000000083*np.cos(3.70050201148 + 10704.9488386698*t)
	X0 += 0.00000000090*np.cos(5.18770728347 + 20049.1974845062*t)
	X0 += 0.00000000076*np.cos(1.05201678798 + 21485.95302261119*t)
	X0 += 0.00000000064*np.cos(1.61066481633 + 18314.9207790444*t)
	X0 += 0.00000000064*np.cos(3.46792160676 + 2214.7430875962*t)
	X0 += 0.00000000063*np.cos(3.22324471895 + 20.6069278195*t)
	X0 += 0.00000000084*np.cos(0.70408445885 + 424.1505103212*t)
	X0 += 0.00000000071*np.cos(6.14408943769 + 1573.8204240988*t)
	X0 += 0.00000000071*np.cos(5.46198489134 + 1580.8666607968*t)
	X0 += 0.00000000082*np.cos(1.17323562782 + 154.0166152595*t)
	X0 += 0.00000000067*np.cos(0.48620096430 + 3956.5080160194*t)
	X0 += 0.00000000065*np.cos(5.99619164093 + 284.1485407422*t)
	X0 += 0.00000000085*np.cos(0.47649339021 + 60530.4889857418*t)
	X0 += 0.00000000076*np.cos(3.59374291647 + 831.8557407496*t)
	X0 += 0.00000000081*np.cos(3.70025004502 + 37.8724032069*t)
	X0 += 0.00000000087*np.cos(5.47908592763 + 29264.0828387872*t)
	X0 += 0.00000000069*np.cos(2.58402361347 + 275.5505210331*t)
	X0 += 0.00000000071*np.cos(3.88813675038 + 835.0371344873*t)
	X0 += 0.00000000080*np.cos(3.78188046031 + 38.3936680687*t)
	X0 += 0.00000000073*np.cos(0.88865626886 + 115.8835796217*t)
	X0 += 0.00000000060*np.cos(1.34871003737 + 20421.0481681146*t)
	X0 += 0.00000000064*np.cos(4.29919445052 + 18300.69368504279*t)
	X0 += 0.00000000076*np.cos(3.93987139141 + 29683.56748266239*t)
	X0 += 0.00000000069*np.cos(2.49762583501 + 511.5317178299*t)
	X0 += 0.00000000062*np.cos(1.28649389372 + 11599.1808225472*t)
	X0 += 0.00000000058*np.cos(3.08212047215 + 7576.560073574*t)
	X0 += 0.00000000057*np.cos(3.67915137516 + 11279.781023401*t)
	X0 += 0.00000000058*np.cos(0.25471831888 + 46.2097904851*t)
	X0 += 0.00000000068*np.cos(1.09479629612 + 643.8294395771*t)
	X0 += 0.00000000079*np.cos(5.72688311333 + 531.1754378029*t)
	X0 += 0.00000000066*np.cos(3.67579379885 + 18100.00325845*t)
	X0 += 0.00000000059*np.cos(1.26040809465 + 10254.8363371958*t)
	X0 += 0.00000000059*np.cos(1.95029264554 + 10171.7347552262*t)
	X0 += 0.00000000057*np.cos(4.06263183264 + 20464.5987650578*t)
	X0 += 0.00000000079*np.cos(0.46444983025 + 404.5067903482*t)
	X0 += 0.00000000077*np.cos(4.08353330283 + 618.5566453116*t)
	X0 += 0.00000000079*np.cos(1.97795760115 + 10137.0194749354*t)
	X0 += 0.00000000056*np.cos(1.44522132533 + 842.1506814881*t)
	X0 += 0.00000000062*np.cos(0.88771657360 + 99.1606209555*t)
	X0 += 0.00000000065*np.cos(1.84460485390 + 547.8502123593*t)
	X0 += 0.00000000062*np.cos(4.06674027154 + 68.8437077341*t)
	X0 += 0.00000000061*np.cos(0.01100073598 + 121.2520214833*t)
	X0 += 0.00000000076*np.cos(4.86986651697 + 528.2064923863*t)
	X0 += 0.00000000075*np.cos(4.71498755910 + 227.3137411185*t)
	X0 += 0.00000000064*np.cos(5.57155754500 + 30007.0728993198*t)
	X0 += 0.00000000061*np.cos(3.81064825215 + 650.9429865779*t)
	X0 += 0.00000000064*np.cos(4.29409388919 + 159.1244246902*t)
	X0 += 0.00000000058*np.cos(3.05734136153 + 75449.50683949639*t)
	X0 += 0.00000000061*np.cos(2.96999279527 + 429.0458714308*t)
	X0 += 0.00000000073*np.cos(3.85067893410 + 51449.3242632782*t)
	X0 += 0.00000000074*np.cos(5.48466882213 + 21720.0553160046*t)
	X0 += 0.00000000072*np.cos(3.24619558125 + 39302.096962196*t)
	X0 += 0.00000000072*np.cos(4.47140920987 + 100608.10855926179*t)
	X0 += 0.00000000057*np.cos(3.46227126270 + 92.940845832*t)
	X0 += 0.00000000070*np.cos(5.15360777942 + 50317.2034395308*t)
	X0 += 0.00000000068*np.cos(0.43233787470 + 219.4494345923*t)
	X0 += 0.00000000052*np.cos(2.09263469212 + 40426.543993968*t)
	X0 += 0.00000000059*np.cos(5.80351575464 + 33.9402499438*t)
	X0 += 0.00000000062*np.cos(5.86330508473 + 2.4476805548*t)
	X0 += 0.00000000062*np.cos(6.09623774456 + 425.6349830295*t)
	X0 += 0.00000000058*np.cos(1.31187367842 + 20412.34399842039*t)
	X0 += 0.00000000051*np.cos(5.10012533555 + 1048.3362299253*t)
	X0 += 0.00000000054*np.cos(3.07019079387 + 59.8037450403*t)
	X0 += 0.00000000050*np.cos(1.48104982763 + 960.2213092337*t)
	X0 += 0.00000000059*np.cos(5.90527689512 + 72.0732855816*t)
	X0 += 0.00000000050*np.cos(0.12167728428 + 426.6463749858*t)
	X0 += 0.00000000064*np.cos(4.78297114148 + 269.9214467406*t)
	X0 += 0.00000000050*np.cos(4.78368432558 + 514.7131115676*t)
	X0 += 0.00000000051*np.cos(5.96112457648 + 387.2413149608*t)
	X0 += 0.00000000055*np.cos(1.61378048542 + 42.3258213318*t)
	X0 += 0.00000000057*np.cos(1.89761311531 + 8307.8207812706*t)
	X0 += 0.00000000051*np.cos(3.43355246408 + 2641.3412784722*t)
	X0 += 0.00000000063*np.cos(1.40789341724 + 750.1036075334*t)
	X0 += 0.00000000065*np.cos(1.67946533112 + 53285.1848352418*t)
	X0 += 0.00000000050*np.cos(4.69707035274 + 8418.02710249*t)
	X0 += 0.00000000050*np.cos(3.20702872042 + 426.5500067662*t)
	X0 += 0.00000000063*np.cos(3.98505374586 + 494.2662424425*t)
	X0 += 0.00000000053*np.cos(2.43583780027 + 2428.0421830342*t)
	X0 += 0.00000000066*np.cos(6.05166710265 + 19580.4882576708*t)
	X0 += 0.00000000047*np.cos(5.83569926578 + 544.6688186216*t)
	X0 += 0.00000000048*np.cos(2.00982466333 + 39.3568759152*t)
	X0 += 0.00000000047*np.cos(4.81853147221 + 38741.4918714664*t)
	X0 += 0.00000000055*np.cos(5.26856872787 + 81.8951455681*t)
	X0 += 0.00000000059*np.cos(2.11187321665 + 488.8496164711*t)
	X0 += 0.00000000050*np.cos(1.33990099082 + 59160.9494168876*t)
	X0 += 0.00000000063*np.cos(4.17349551052 + 1364.7280995819*t)
	X0 += 0.00000000054*np.cos(3.62421804697 + 427.5613987225*t)
	X0 += 0.00000000056*np.cos(3.53833578370 + 34363.365597556*t)
	X0 += 0.00000000054*np.cos(0.68665384144 + 48947.6638706766*t)
	X0 += 0.00000000052*np.cos(4.38844382678 + 210.5907824523*t)
	X0 += 0.00000000045*np.cos(4.21526527082 + 194.9713844606*t)
	X0 += 0.00000000056*np.cos(1.07866938616 + 9936.5397743466*t)
	X0 += 0.00000000056*np.cos(2.13203135403 + 10490.0313180754*t)
	X0 += 0.00000000051*np.cos(0.50117453824 + 216.0074084237*t)
	X0 += 0.00000000046*np.cos(4.79961635192 + 106.2741679563*t)
	X0 += 0.00000000050*np.cos(4.62538441124 + 1056.9342496344*t)
	X0 += 0.00000000048*np.cos(1.32358795195 + 501.3797894433*t)
	X0 += 0.00000000054*np.cos(4.49664827025 + 9922.312680345*t)
	X0 += 0.00000000054*np.cos(4.99723777712 + 10504.258412077*t)
	X0 += 0.00000000060*np.cos(2.00609002833 + 18204.71445782499*t)
	X0 += 0.00000000050*np.cos(1.09462754777 + 355.7487455718*t)
	X0 += 0.00000000044*np.cos(5.16479782395 + 74.0308390419*t)
	X0 += 0.00000000044*np.cos(3.40081468635 + 2538.2485042536*t)
	X0 += 0.00000000055*np.cos(2.70454523909 + 14.977853527*t)
	X0 += 0.00000000048*np.cos(1.22735240928 + 38727.2647774648*t)
	X0 += 0.00000000044*np.cos(5.84040951995 + 38204.687359371*t)
	X0 += 0.00000000061*np.cos(3.50723881080 + 10286.58267207*t)
	X0 += 0.00000000061*np.cos(5.98664723657 + 10139.988420352*t)
	X0 += 0.00000000061*np.cos(0.57175309158 + 6566.9351688566*t)
	X0 += 0.00000000057*np.cos(3.17248775727 + 491.8185618877*t)
	X0 += 0.00000000043*np.cos(0.99595677376 + 213.4591541324*t)
	X0 += 0.00000000043*np.cos(3.89366939283 + 213.1390367436*t)
	X0 += 0.00000000043*np.cos(2.65544175682 + 75.5323580927*t)
	X0 += 0.00000000043*np.cos(0.76354191371 + 220.4608265486*t)
	X0 += 0.00000000060*np.cos(2.76944336702 + 3684.3780499902*t)
	X0 += 0.00000000048*np.cos(3.35196570960 + 9246.3146687754*t)
	X0 += 0.00000000049*np.cos(2.38104573869 + 47623.8527860896*t)
	X0 += 0.00000000060*np.cos(3.41701626624 + 14427.3545612958*t)
	X0 += 0.00000000051*np.cos(5.43117183762 + 9566.2747128962*t)
	X0 += 0.00000000054*np.cos(0.68459749075 + 187.6962327724*t)
	X0 += 0.00000000052*np.cos(0.06129028276 + 8727.3054251458*t)
	X0 += 0.00000000057*np.cos(0.63863230611 + 1061.829610744*t)
	X0 += 0.00000000050*np.cos(5.56308110598 + 296.1574488526*t)
	X0 += 0.00000000045*np.cos(5.52086086974 + 10263.2821681152*t)
	X0 += 0.00000000045*np.cos(3.97302517763 + 10163.2889243068*t)
	X0 += 0.00000000049*np.cos(1.65627933457 + 9794.3611473104*t)
	X0 += 0.00000000049*np.cos(1.55442140562 + 10632.2099451116*t)
	X0 += 0.00000000054*np.cos(1.47632908603 + 57375.8019008462*t)
	X0 += 0.00000000047*np.cos(0.24841658475 + 1279.794572628*t)
	X0 += 0.00000000058*np.cos(6.19295972616 + 1861.202861313*t)
	X0 += 0.00000000047*np.cos(1.50917280490 + 20142.7117735568*t)
	X0 += 0.00000000056*np.cos(1.90382257572 + 64460.6986819614*t)
	X0 += 0.00000000042*np.cos(2.81747931977 + 25132.3033999656*t)
	X0 += 0.00000000046*np.cos(5.38584594180 + 2349.3430354228*t)
	X0 += 0.00000000041*np.cos(4.51930257295 + 128.9562693151*t)
	X0 += 0.00000000046*np.cos(4.70373951682 + 2356.3892721208*t)
	X0 += 0.00000000044*np.cos(2.04804189558 + 30632.74309163219*t)
	X0 += 0.00000000044*np.cos(3.19618376464 + 27461.7108480654*t)
	X0 += 0.00000000041*np.cos(0.12857964444 + 12850.011018848*t)
	X0 += 0.00000000056*np.cos(5.45458264580 + 1057.8974574809*t)
	X0 += 0.00000000053*np.cos(1.93518633525 + 601.7642506762*t)
	X0 += 0.00000000045*np.cos(5.49394122920 + 3178.1457905676*t)
	X0 += 0.00000000042*np.cos(5.08305246551 + 77802.37299326819*t)
	X0 += 0.00000000047*np.cos(5.03443210464 + 679.2541622292*t)
	X0 += 0.00000000050*np.cos(3.02284234315 + 36301.18868778519*t)
	X0 += 0.00000000044*np.cos(0.04275677189 + 9367.2027114598*t)
	X0 += 0.00000000054*np.cos(4.48267339963 + 207.1487562837*t)
	X0 += 0.00000000040*np.cos(4.11879245377 + 1059.430114299*t)
	X0 += 0.00000000044*np.cos(4.46864162759 + 79379.716535716*t)
	X0 += 0.00000000042*np.cos(3.87088947499 + 220.364458329*t)
	X0 += 0.00000000046*np.cos(4.69192941021 + 10.2949407385*t)
	X0 += 0.00000000051*np.cos(5.74770428324 + 344.7030453079*t)
	X0 += 0.00000000054*np.cos(4.54758275119 + 66038.04222440919*t)
	X0 += 0.00000000040*np.cos(1.16488473080 + 31022.7531708562*t)
	X0 += 0.00000000052*np.cos(2.92722662671 + 90394.82301305079*t)
	X0 += 0.00000000054*np.cos(1.04857075083 + 188.9200730498*t)
	X0 += 0.00000000040*np.cos(0.23497278107 + 38519.945791972*t)
	X0 += 0.00000000041*np.cos(2.70677059989 + 67.6680515665*t)
	X0 += 0.00000000039*np.cos(3.44427209717 + 28631.29909947399*t)
	X0 += 0.00000000052*np.cos(5.20963747195 + 38631.285550247*t)
	X0 += 0.00000000044*np.cos(0.29252718625 + 179.3588454942*t)
	X0 += 0.00000000043*np.cos(6.14192019965 + 11180.2564236466*t)
	X0 += 0.00000000038*np.cos(1.29716058654 + 47938.0389659592*t)
	X0 += 0.00000000044*np.cos(1.83547130154 + 289.5651667136*t)
	X0 += 0.00000000040*np.cos(4.83551999164 + 149.45132255*t)
	X0 += 0.00000000040*np.cos(0.02735864866 + 436.1594184316*t)
	X0 += 0.00000000039*np.cos(0.47445767706 + 54981.3849560896*t)
	X0 += 0.00000000047*np.cos(2.80270200743 + 1038.0412891868*t)
	X0 += 0.00000000044*np.cos(1.17091466926 + 10168.1443265744*t)
	X0 += 0.00000000044*np.cos(2.03978607093 + 10258.4267658476*t)
	X0 += 0.00000000037*np.cos(3.31019033964 + 1788.1448967202*t)
	X0 += 0.00000000047*np.cos(4.89732365161 + 187.9251477626*t)
	X0 += 0.00000000045*np.cos(2.39073394193 + 358.9301393095*t)
	X0 += 0.00000000047*np.cos(1.00325671943 + 523.5406259403*t)
	X0 += 0.00000000043*np.cos(5.12210246822 + 22030.2129546696*t)
	X0 += 0.00000000051*np.cos(5.89313829453 + 104538.3182554814*t)
	X0 += 0.00000000051*np.cos(6.27593798552 + 16250.529749973*t)
	X0 += 0.00000000036*np.cos(2.92998162283 + 68.1893164283*t)
	X0 += 0.00000000037*np.cos(4.48691474448 + 29160.9900645686*t)
	X0 += 0.00000000043*np.cos(4.92338640427 + 10362.8487433456*t)
	X0 += 0.00000000038*np.cos(4.13589617678 + 47917.2635704668*t)
	X0 += 0.00000000036*np.cos(4.28412749882 + 2751.5475996916*t)
	X0 += 0.00000000037*np.cos(4.41298184434 + 6256.7775301916*t)
	X0 += 0.00000000036*np.cos(2.97028388691 + 8673.969676399*t)
	X0 += 0.00000000040*np.cos(0.92098132614 + 1059.3337460794*t)
	X0 += 0.00000000049*np.cos(1.96336022300 + 491.6632924588*t)
	X0 += 0.00000000035*np.cos(4.23887120976 + 55798.4583583984*t)
	X0 += 0.00000000035*np.cos(2.75316618128 + 12546.481939083*t)
	X0 += 0.00000000038*np.cos(5.64242804993 + 212.0270710508*t)
	X0 += 0.00000000049*np.cos(0.68713949784 + 32243.4985008806*t)
	X0 += 0.00000000037*np.cos(5.53010012107 + 214.5711198252*t)
	X0 += 0.00000000039*np.cos(2.30481475888 + 1514.2912967165*t)
	X0 += 0.00000000040*np.cos(0.87236752974 + 497.4476361802*t)
	X0 += 0.00000000035*np.cos(1.54030603995 + 80482.46652890938*t)
	X0 += 0.00000000044*np.cos(4.30648713686 + 9697.821675118*t)
	X0 += 0.00000000044*np.cos(5.18739891051 + 10728.749417304*t)
	X0 += 0.00000000036*np.cos(2.23669262946 + 69941.95360082899*t)
	X0 += 0.00000000035*np.cos(4.30307025009 + 672.1406152284*t)
	X0 += 0.00000000047*np.cos(2.48361583884 + 50.4025761791*t)
	X0 += 0.00000000037*np.cos(3.25220014102 + 35191.8101356918*t)
	X0 += 0.00000000040*np.cos(2.23416725118 + 28418.000004036*t)
	X0 += 0.00000000035*np.cos(4.65523345776 + 89.7594520943*t)
	X0 += 0.00000000035*np.cos(5.32328344021 + 69.1525242748*t)
	X0 += 0.00000000035*np.cos(4.70173672118 + 10415.5389413851*t)
	X0 += 0.00000000035*np.cos(4.79214932619 + 10011.0321510369*t)
	X0 += 0.00000000034*np.cos(5.41644307615 + 48733.23133818299*t)
	X0 += 0.00000000043*np.cos(2.91924315729 + 312.4597163935*t)
	X0 += 0.00000000040*np.cos(1.58760278423 + 149.6750717192*t)
	X0 += 0.00000000033*np.cos(5.38015255564 + 49477.35483577119*t)
	X0 += 0.00000000042*np.cos(3.33159283750 + 535.8413042489*t)
	X0 += 0.00000000036*np.cos(3.18170063426 + 144.1465711632*t)
	X0 += 0.00000000033*np.cos(2.37919979646 + 54.1746707478*t)
	X0 += 0.00000000033*np.cos(3.74889730790 + 10117.3063189932*t)
	X0 += 0.00000000033*np.cos(5.74498873947 + 10309.2647734288*t)
	X0 += 0.00000000034*np.cos(4.93633143876 + 7461.7379465194*t)
	X0 += 0.00000000044*np.cos(3.78834210571 + 237.6781178262*t)
	X0 += 0.00000000035*np.cos(1.74685819003 + 529.9515975255*t)
	X0 += 0.00000000035*np.cos(2.59415719377 + 529.4303326637*t)
	X0 += 0.00000000032*np.cos(4.82073066675 + 100909.03762133139*t)
	X0 += 0.00000000032*np.cos(4.15757729853 + 206.1373643274*t)
	X0 += 0.00000000040*np.cos(4.91765336511 + 1593.0050485469*t)
	X0 += 0.00000000042*np.cos(2.02575996826 + 36173.7081971002*t)
	X0 += 0.00000000032*np.cos(0.69603648293 + 522.529233984*t)
	X0 += 0.00000000044*np.cos(0.60569420427 + 1512.8068240082*t)
	X0 += 0.00000000034*np.cos(3.91727152081 + 522.6256022036*t)
	X0 += 0.00000000032*np.cos(4.94879963135 + 81.3738807063*t)
	X0 += 0.00000000036*np.cos(3.21789957686 + 143.6253063014*t)
	X0 += 0.00000000038*np.cos(2.89788933077 + 115674.27666460119*t)
	X0 += 0.00000000031*np.cos(3.44788323640 + 30103.05212653759*t)
	X0 += 0.00000000034*np.cos(5.20057828474 + 1361.5467058442*t)
	X0 += 0.00000000032*np.cos(4.93095676351 + 767.3690829208*t)
	X0 += 0.00000000036*np.cos(3.05228952146 + 106.9767433719*t)
	X0 += 0.00000000032*np.cos(3.76438941047 + 21977.61631507*t)
	X0 += 0.00000000036*np.cos(1.22867623820 + 20430.50324568509*t)
	X0 += 0.00000000031*np.cos(1.35404435495 + 35.212274331*t)
	X0 += 0.00000000033*np.cos(1.35404998174 + 1060.3451380357*t)
	X0 += 0.00000000031*np.cos(1.46724432126 + 50290.905119731*t)
	X0 += 0.00000000032*np.cos(0.22257491587 + 81732.5826894878*t)
	X0 += 0.00000000042*np.cos(2.48755696559 + 14169.7935622304*t)
	X0 += 0.00000000034*np.cos(4.16441980838 + 58946.51688439399*t)
	X0 += 0.00000000030*np.cos(0.22687369463 + 51640.7725293898*t)
	X0 += 0.00000000033*np.cos(5.88115236046 + 83309.92623193559*t)
	X0 += 0.00000000029*np.cos(0.24041707519 + 11752.601416023*t)
	X0 += 0.00000000029*np.cos(5.51688017902 + 9800.9144493366*t)
	X0 += 0.00000000029*np.cos(3.97700586835 + 10625.6566430854*t)
	X0 += 0.00000000036*np.cos(1.23021540997 + 181.0557665236*t)
	X0 += 0.00000000029*np.cos(1.24410667204 + 1585.1407420207*t)
	X0 += 0.00000000030*np.cos(3.62180540908 + 20432.0940167294*t)
	X0 += 0.00000000029*np.cos(4.40925784627 + 9889.7801295536*t)
	X0 += 0.00000000030*np.cos(5.47125895037 + 458.8415197904*t)
	X0 += 0.00000000030*np.cos(1.04324019127 + 206.233732547*t)
	X0 += 0.00000000039*np.cos(5.97000692581 + 69968.2519206288*t)
	X0 += 0.00000000028*np.cos(0.27335698936 + 10098.84625752579*t)
	X0 += 0.00000000028*np.cos(2.93734375083 + 10327.72483489621*t)
	X0 += 0.00000000031*np.cos(3.65358279415 + 63498.47038145279*t)
	X0 += 0.00000000034*np.cos(4.23088120025 + 1539.315869812*t)
	X0 += 0.00000000028*np.cos(5.43510977873 + 1179.1945390396*t)
	X0 += 0.00000000033*np.cos(3.71848916507 + 245.5424243524*t)
	X0 += 0.00000000039*np.cos(5.18936615352 + 30563.5905673574*t)
	X0 += 0.00000000039*np.cos(1.33255333737 + 5791.4125575326*t)
	X0 += 0.00000000037*np.cos(0.01420012860 + 47964.337285759*t)
	X0 += 0.00000000034*np.cos(3.47970683246 + 37703.9780242558*t)
	X0 += 0.00000000031*np.cos(5.46651444566 + 39786.646707654*t)
	X0 += 0.00000000028*np.cos(3.65950618561 + 73872.1632970486*t)
	X0 += 0.00000000034*np.cos(3.84184270652 + 92.0470739547*t)
	X0 += 0.00000000029*np.cos(4.54475250390 + 426.0769260142*t)
	X0 += 0.00000000028*np.cos(1.94950811352 + 28528.2063252554*t)
	X0 += 0.00000000037*np.cos(3.33141664712 + 68390.90837818099*t)
	X0 += 0.00000000028*np.cos(0.41915165036 + 15694.5404650786*t)
	X0 += 0.00000000034*np.cos(3.67871414535 + 40213.24489853*t)
	X0 += 0.00000000027*np.cos(2.00149954913 + 643.0786800517*t)
	X0 += 0.00000000031*np.cos(4.76909835895 + 106570.36967048359*t)
	X0 += 0.00000000029*np.cos(0.41759634551 + 536.7563279856*t)
	X0 += 0.00000000027*np.cos(4.36788488657 + 113.3877149571*t)
	X0 += 0.00000000031*np.cos(0.95396015997 + 27682.1407441564*t)
	X0 += 0.00000000026*np.cos(3.63270001708 + 536.8526962052*t)
	X0 += 0.00000000037*np.cos(2.63889593800 + 13859.6359235654*t)
	X0 += 0.00000000030*np.cos(4.55790675044 + 247.2393453818*t)
	X0 += 0.00000000028*np.cos(1.92419873752 + 7886.717712239*t)
	X0 += 0.00000000031*np.cos(2.95281812365 + 567.8240007324*t)
	return X0




def Venus_X1 (t): # 583 terms of order 1

	X1 = 0.
	X1 -= 0.00035158710
	X1 += 0.00017234950*np.cos(0.92721124604 + 20426.571092422*t)
	X1 += 0.00006510400*np.cos(2.19289888883 + 10213.285546211*t)
	X1 += 0.00000896886*np.cos(1.12825521507 + 426.598190876*t)
	X1 += 0.00000776820*np.cos(2.70601709408 + 206.1855484372*t)
	X1 += 0.00000753540*np.cos(2.19131801801 + 220.4126424388*t)
	X1 += 0.00000600909*np.cos(3.25727135452 + 1059.3819301892*t)
	X1 += 0.00000571950*np.cos(5.56997288971 + 522.5774180938*t)
	X1 += 0.00000560873*np.cos(5.05742420267 + 536.8045120954*t)
	X1 += 0.00000175153*np.cos(1.80662375856 + 30639.856638633*t)
	X1 += 0.00000097244*np.cos(3.47387164112 + 7.1135470008*t)
	X1 += 0.00000072601*np.cos(0.36313560559 + 639.897286314*t)
	X1 += 0.00000087530*np.cos(1.66279295561 + 419.4846438752*t)
	X1 += 0.00000060308*np.cos(4.92818504243 + 8635.9420037632*t)
	X1 += 0.00000053691*np.cos(1.32771189808 + 433.7117378768*t)
	X1 += 0.00000057444*np.cos(4.24894038266 + 213.299095438*t)
	X1 += 0.00000062875*np.cos(2.09139376733 + 10186.9872264112*t)
	X1 += 0.00000062673*np.cos(1.11931770829 + 10239.5838660108*t)
	X1 += 0.00000049288*np.cos(4.57672399872 + 11790.6290886588*t)
	X1 += 0.00000042980*np.cos(3.60320031727 + 1589.0728952838*t)
	X1 += 0.00000036778*np.cos(2.06851242251 + 775.522611324*t)
	X1 += 0.00000030995*np.cos(4.88465315830 + 1052.2683831884*t)
	X1 += 0.00000030080*np.cos(5.32711374724 + 10021.8372800994*t)
	X1 += 0.00000032246*np.cos(0.98724061820 + 529.6909650946*t)
	X1 += 0.00000029274*np.cos(4.16540644255 + 10404.7338123226*t)
	X1 += 0.00000029956*np.cos(5.48094443840 + 1066.49547719*t)
	X1 += 0.00000032092*np.cos(2.84692417916 + 149.5631971346*t)
	X1 += 0.00000021371*np.cos(0.56918433581 + 316.3918696566*t)
	X1 += 0.00000019967*np.cos(1.16604774963 + 9437.762934887*t)
	X1 += 0.00000018990*np.cos(2.06104675595 + 227.5261894396*t)
	X1 += 0.00000017823*np.cos(2.07836542600 + 10988.808157535*t)
	X1 += 0.00000013962*np.cos(4.17631168541 + 110.2063212194*t)
	X1 += 0.00000013944*np.cos(3.69080302800 + 9683.5945811164*t)
	X1 += 0.00000013302*np.cos(1.34684482109 + 191.4482661116*t)
	X1 += 0.00000013514*np.cos(5.77326513156 + 10742.9765113056*t)
	X1 += 0.00000015885*np.cos(5.78017661291 + 76.2660712756*t)
	X1 += 0.00000014023*np.cos(3.49827896956 + 4705.7323075436*t)
	X1 += 0.00000013305*np.cos(1.15252179423 + 19651.048481098*t)
	X1 += 0.00000012374*np.cos(5.70562636316 + 515.463871093*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000011847*np.cos(3.05476901979 + 632.7837393132*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000010223*np.cos(2.19747174258 + 73.297125859*t)
	X1 += 0.00000009014*np.cos(2.86872754290 + 199.0720014364*t)
	X1 += 0.00000008667*np.cos(4.92419711400 + 543.9180590962*t)
	X1 += 0.00000007754*np.cos(3.01431732345 + 949.1756089698*t)
	X1 += 0.00000007535*np.cos(2.70484475866 + 103.0927742186*t)
	X1 += 0.00000006878*np.cos(4.83643789894 + 9103.9069941176*t)
	X1 += 0.00000007314*np.cos(6.00715030461 + 15720.8387848784*t)
	X1 += 0.00000005893*np.cos(4.65079788415 + 11322.6640983044*t)
	X1 += 0.00000005966*np.cos(2.10338851243 + 10206.1719992102*t)
	X1 += 0.00000005966*np.cos(1.10731222776 + 10220.3990932118*t)
	X1 += 0.00000005483*np.cos(6.01106223961 + 853.196381752*t)
	X1 += 0.00000005158*np.cos(1.94900517603 + 209.3669421749*t)
	X1 += 0.00000005079*np.cos(2.96229494906 + 217.2312487011*t)
	X1 += 0.00000004653*np.cos(1.72782369127 + 216.4804891757*t)
	X1 += 0.00000005146*np.cos(2.49797078266 + 3154.6870848956*t)
	X1 += 0.00000004541*np.cos(3.17727011849 + 210.1177017003*t)
	X1 += 0.00000004456*np.cos(0.76977956324 + 323.5054166574*t)
	X1 += 0.00000004570*np.cos(4.59128591402 + 20618.0193585336*t)
	X1 += 0.00000004253*np.cos(6.04441888042 + 9999.986450773*t)
	X1 += 0.00000004233*np.cos(3.49063898076 + 63.7358983034*t)
	X1 += 0.00000004157*np.cos(3.43980473612 + 10426.584641649*t)
	X1 += 0.00000004095*np.cos(0.51793431422 + 647.0108333148*t)
	X1 += 0.00000004649*np.cos(2.86570782502 + 9830.3890139878*t)
	X1 += 0.00000004989*np.cos(3.32377727482 + 14.2270940016*t)
	X1 += 0.00000004320*np.cos(4.28845188920 + 735.8765135318*t)
	X1 += 0.00000004457*np.cos(0.35149067415 + 10596.1820784342*t)
	X1 += 0.00000003445*np.cos(4.34972240938 + 85.8272988312*t)
	X1 += 0.00000003338*np.cos(2.34738225115 + 11.0457002639*t)
	X1 += 0.00000003244*np.cos(6.04240714038 + 526.5095713569*t)
	X1 += 0.00000003181*np.cos(4.57837074085 + 532.8723588323*t)
	X1 += 0.00000003220*np.cos(2.31596557655 + 7860.4193924392*t)
	X1 += 0.00000002903*np.cos(4.79566936964 + 525.7588118315*t)
	X1 += 0.00000002864*np.cos(5.82538312855 + 533.6231183577*t)
	X1 += 0.00000002876*np.cos(2.69265723530 + 117.3198682202*t)
	X1 += 0.00000002833*np.cos(2.05576755359 + 202.2533951741*t)
	X1 += 0.00000002790*np.cos(3.91140503058 + 19367.1891622328*t)
	X1 += 0.00000002701*np.cos(0.65622385382 + 7058.5984613154*t)
	X1 += 0.00000002426*np.cos(5.63707111420 + 8624.2126509272*t)
	X1 += 0.00000002514*np.cos(0.74093420826 + 95.9792272178*t)
	X1 += 0.00000002055*np.cos(5.42893438245 + 138.5174968707*t)
	X1 += 0.00000002228*np.cos(3.80476415463 + 11015.1064773348*t)
	X1 += 0.00000001996*np.cos(3.76028525032 + 742.9900605326*t)
	X1 += 0.00000002742*np.cos(4.97112619529 + 801.8209311238*t)
	X1 += 0.00000002701*np.cos(3.93865719128 + 2118.7638603784*t)
	X1 += 0.00000002539*np.cos(5.96953643859 + 9411.4646150872*t)
	X1 += 0.00000001910*np.cos(1.96850101416 + 956.2891559706*t)
	X1 += 0.00000001768*np.cos(5.91092694669 + 1596.1864422846*t)
	X1 += 0.00000001733*np.cos(3.35882285196 + 1109.3785520934*t)
	X1 += 0.00000001668*np.cos(3.43481125656 + 70.8494453042*t)
	X1 += 0.00000001820*np.cos(2.53309413889 + 13367.9726311066*t)
	X1 += 0.00000001586*np.cos(2.69305924778 + 40853.142184844*t)
	X1 += 0.00000001570*np.cos(4.37765395011 + 78.7137518304*t)
	X1 += 0.00000002007*np.cos(2.52717557705 + 26.2983197998*t)
	X1 += 0.00000001740*np.cos(2.26366858618 + 4551.9534970588*t)
	X1 += 0.00000001695*np.cos(4.86384593057 + 3930.2096962196*t)
	X1 += 0.00000001491*np.cos(1.26055544534 + 440.8252848776*t)
	X1 += 0.00000001809*np.cos(5.00719339450 + 1581.959348283*t)
	X1 += 0.00000001561*np.cos(4.53702050944 + 1045.1548361876*t)
	X1 += 0.00000001447*np.cos(1.95238298727 + 74.7815985673*t)
	X1 += 0.00000001401*np.cos(0.72534820656 + 12566.1516999828*t)
	X1 += 0.00000001645*np.cos(3.97870726126 + 224.3447957019*t)
	X1 += 0.00000001400*np.cos(6.24739539057 + 11272.6674764002*t)
	X1 += 0.00000001282*np.cos(4.66310117053 + 10218.8084705184*t)
	X1 += 0.00000001282*np.cos(4.83078487684 + 10207.7626219036*t)
	X1 += 0.00000001424*np.cos(3.84877764517 + 7084.8967811152*t)
	X1 += 0.00000001480*np.cos(5.68175195919 + 3128.3887650958*t)
	X1 += 0.00000001352*np.cos(2.86394052328 + 20419.45754542119*t)
	X1 += 0.00000001331*np.cos(5.67740813364 + 23581.2581773176*t)
	X1 += 0.00000001165*np.cos(1.86912148528 + 1577.3435424478*t)
	X1 += 0.00000001217*np.cos(3.13914848069 + 9153.9036160218*t)
	X1 += 0.00000001283*np.cos(3.88489184697 + 382.8965322232*t)
	X1 += 0.00000001161*np.cos(4.49256510074 + 625.6701923124*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000000999*np.cos(5.67443465200 + 1265.5674786264*t)
	X1 += 0.00000001084*np.cos(4.35524384671 + 10198.033075026*t)
	X1 += 0.00000001084*np.cos(5.13864220066 + 10228.538017396*t)
	X1 += 0.00000000935*np.cos(2.69155510108 + 2352.8661537718*t)
	X1 += 0.00000001204*np.cos(4.96311045584 + 16496.3613962024*t)
	X1 += 0.00000000927*np.cos(0.95159471682 + 15874.6175953632*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000000938*np.cos(4.56608679745 + 1169.5882514086*t)
	X1 += 0.00000000943*np.cos(1.78153635749 + 151.0476698429*t)
	X1 += 0.00000000965*np.cos(1.55576378944 + 412.3710968744*t)
	X1 += 0.00000000769*np.cos(3.16951506066 + 942.062061969*t)
	X1 += 0.00000000745*np.cos(2.15244210116 + 3149.1641605882*t)
	X1 += 0.00000000727*np.cos(0.71047310572 + 28286.9904848612*t)
	X1 += 0.00000000768*np.cos(4.99147918103 + 1155.361157407*t)
	X1 += 0.00000000711*np.cos(3.39057215594 + 71.8126531507*t)
	X1 += 0.00000000630*np.cos(4.10205616470 + 6283.0758499914*t)
	X1 += 0.00000000719*np.cos(4.52061983489 + 77.7505439839*t)
	X1 += 0.00000000625*np.cos(3.18531726606 + 20400.2727726222*t)
	X1 += 0.00000000613*np.cos(0.22192928894 + 21535.9496445154*t)
	X1 += 0.00000000844*np.cos(1.91525540918 + 21228.3920235458*t)
	X1 += 0.00000000673*np.cos(5.27601179416 + 8094.5216858326*t)
	X1 += 0.00000000632*np.cos(0.25150164023 + 18849.2275499742*t)
	X1 += 0.00000000572*np.cos(2.30412060804 + 309.2783226558*t)
	X1 += 0.00000000659*np.cos(3.85074823650 + 17298.1823273262*t)
	X1 += 0.00000000558*np.cos(2.17212279619 + 5661.3320491522*t)
	X1 += 0.00000000724*np.cos(3.25902076369 + 1162.4747044078*t)
	X1 += 0.00000000504*np.cos(0.50752256282 + 20452.8694122218*t)
	X1 += 0.00000000510*np.cos(3.90147691268 + 277.0349937414*t)
	X1 += 0.00000000471*np.cos(5.08849959119 + 32217.2001810808*t)
	X1 += 0.00000000486*np.cos(0.82245463791 + 422.6660376129*t)
	X1 += 0.00000000456*np.cos(2.75853729890 + 1692.1656695024*t)
	X1 += 0.00000000449*np.cos(3.23050669378 + 9161.0171630226*t)
	X1 += 0.00000000406*np.cos(5.47199309176 + 24356.7807886416*t)
	X1 += 0.00000000421*np.cos(2.57695843451 + 29050.7837433492*t)
	X1 += 0.00000000391*np.cos(5.30832534377 + 1073.6090241908*t)
	X1 += 0.00000000374*np.cos(1.92168872074 + 234.6397364404*t)
	X1 += 0.00000000433*np.cos(3.74326536161 + 9146.790069021*t)
	X1 += 0.00000000432*np.cos(0.83861429466 + 20809.4676246452*t)
	X1 += 0.00000000368*np.cos(0.50948592294 + 9786.687355335*t)
	X1 += 0.00000000364*np.cos(2.71580018519 + 10639.883737087*t)
	X1 += 0.00000000384*np.cos(0.93539249733 + 330.6189636582*t)
	X1 += 0.00000000371*np.cos(5.54353838421 + 415.5524906121*t)
	X1 += 0.00000000353*np.cos(1.18721605495 + 846.0828347512*t)
	X1 += 0.00000000440*np.cos(0.73691128332 + 10735.8629643048*t)
	X1 += 0.00000000442*np.cos(2.47960767723 + 9690.7081281172*t)
	X1 += 0.00000000335*np.cos(6.05401158140 + 860.3099287528*t)
	X1 += 0.00000000372*np.cos(0.50265145827 + 10251.3132188468*t)
	X1 += 0.00000000372*np.cos(2.70804928192 + 10175.2578735752*t)
	X1 += 0.00000000337*np.cos(4.75525977824 + 71.6002048296*t)
	X1 += 0.00000000324*np.cos(2.28921417158 + 423.4167971383*t)
	X1 += 0.00000000417*np.cos(5.95567969898 + 22003.9146348698*t)
	X1 += 0.00000000319*np.cos(1.05799141125 + 17277.4069318338*t)
	X1 += 0.00000000430*np.cos(2.94467829658 + 18837.49819713819*t)
	X1 += 0.00000000324*np.cos(3.05393333292 + 77.962992305*t)
	X1 += 0.00000000384*np.cos(3.06685995823 + 1478.8665740644*t)
	X1 += 0.00000000316*np.cos(0.91375113764 + 429.7795846137*t)
	X1 += 0.00000000361*np.cos(2.21089537404 + 2.9689454166*t)
	X1 += 0.00000000305*np.cos(5.55791649320 + 145.6310438715*t)
	X1 += 0.00000000305*np.cos(1.07705608500 + 14765.2390432698*t)
	X1 += 0.00000000374*np.cos(4.41343415577 + 728.762966531*t)
	X1 += 0.00000000299*np.cos(1.17049327210 + 9573.388259897*t)
	X1 += 0.00000000351*np.cos(2.50782509682 + 6489.776587288*t)
	X1 += 0.00000000383*np.cos(6.13188528401 + 210.8514148832*t)
	X1 += 0.00000000380*np.cos(5.05058792236 + 215.7467759928*t)
	X1 += 0.00000000297*np.cos(1.06831804424 + 10232.95530711079*t)
	X1 += 0.00000000297*np.cos(2.14238269595 + 10193.61578531121*t)
	X1 += 0.00000000283*np.cos(1.43375599031 + 9676.4810341156*t)
	X1 += 0.00000000282*np.cos(2.35469083120 + 3442.5749449654*t)
	X1 += 0.00000000262*np.cos(3.22424298845 + 21202.093703746*t)
	X1 += 0.00000000280*np.cos(4.54909343150 + 13745.3462390224*t)
	X1 += 0.00000000303*np.cos(0.76647154703 + 27511.4678735372*t)
	X1 += 0.00000000265*np.cos(5.63411986393 + 22779.4372461938*t)
	X1 += 0.00000000289*np.cos(5.78612488740 + 20235.1228263104*t)
	X1 += 0.00000000338*np.cos(5.87862918623 + 148.0787244263*t)
	X1 += 0.00000000255*np.cos(2.25536828287 + 437.6438911399*t)
	X1 += 0.00000000280*np.cos(5.08975182162 + 14919.0178537546*t)
	X1 += 0.00000000262*np.cos(1.80492967584 + 10750.0900583064*t)
	X1 += 0.00000000311*np.cos(5.13228886176 + 838.9692877504*t)
	X1 += 0.00000000256*np.cos(4.41502652709 + 10234.0609417034*t)
	X1 += 0.00000000256*np.cos(5.07885952028 + 10192.5101507186*t)
	X1 += 0.00000000237*np.cos(2.28726007142 + 3.9321532631*t)
	X1 += 0.00000000281*np.cos(6.24023878472 + 4732.0306273434*t)
	X1 += 0.00000000273*np.cos(4.38798616028 + 19999.97290154599*t)
	X1 += 0.00000000231*np.cos(4.24584068448 + 3723.508958923*t)
	X1 += 0.00000000285*np.cos(5.52678721077 + 20956.2620575166*t)
	X1 += 0.00000000266*np.cos(5.06649873732 + 38.1330356378*t)
	X1 += 0.00000000234*np.cos(1.60395818860 + 223.5940361765*t)
	X1 += 0.00000000248*np.cos(0.80860047227 + 13936.794505134*t)
	X1 += 0.00000000221*np.cos(5.85413979591 + 508.3503240922*t)
	X1 += 0.00000000303*np.cos(0.16166252665 + 14945.3161735544*t)
	X1 += 0.00000000234*np.cos(4.87225306441 + 1272.6810256272*t)
	X1 += 0.00000000229*np.cos(2.00393082027 + 18307.8072320436*t)
	X1 += 0.00000000243*np.cos(4.78651508733 + 6681.2248533996*t)
	X1 += 0.00000000232*np.cos(1.29928665498 + 19889.76658032659*t)
	X1 += 0.00000000199*np.cos(0.33116594460 + 9638.9407478762*t)
	X1 += 0.00000000218*np.cos(0.81835340957 + 19903.99367432819*t)
	X1 += 0.00000000200*np.cos(6.03453757404 + 1375.7737998458*t)
	X1 += 0.00000000236*np.cos(3.29779198483 + 1551.045222648*t)
	X1 += 0.00000000182*np.cos(4.19683782346 + 6872.6731195112*t)
	X1 += 0.00000000179*np.cos(0.13299783559 + 30110.1656735384*t)
	X1 += 0.00000000183*np.cos(2.86361582264 + 10787.6303445458*t)
	X1 += 0.00000000208*np.cos(5.61842788521 + 10007.0999977738*t)
	X1 += 0.00000000208*np.cos(3.87545816216 + 10419.4710946482*t)
	X1 += 0.00000000199*np.cos(2.97222353917 + 430.5303441391*t)
	X1 += 0.00000000188*np.cos(1.83168099087 + 124.433415221*t)
	X1 += 0.00000000184*np.cos(1.66108291395 + 9967.4538999816*t)
	X1 += 0.00000000173*np.cos(0.50653444879 + 1368.660252845*t)
	X1 += 0.00000000166*np.cos(4.99522557947 + 1062.5633239269*t)
	X1 += 0.00000000181*np.cos(4.29985084119 + 2648.454825473*t)
	X1 += 0.00000000157*np.cos(4.86147676477 + 5507.5532386674*t)
	X1 += 0.00000000163*np.cos(4.95974146969 + 10225.014899047*t)
	X1 += 0.00000000163*np.cos(4.53414457768 + 10201.556193375*t)
	X1 += 0.00000000156*np.cos(6.06699266861 + 10316.3783204296*t)
	X1 += 0.00000000156*np.cos(3.42689337876 + 10110.1927719924*t)
	X1 += 0.00000000178*np.cos(1.54946213545 + 10459.1171924404*t)
	X1 += 0.00000000164*np.cos(2.91444613296 + 3.1813937377*t)
	X1 += 0.00000000163*np.cos(3.33666234638 + 8617.0991039264*t)
	X1 += 0.00000000174*np.cos(1.61176269489 + 65.2203710117*t)
	X1 += 0.00000000163*np.cos(0.77052245905 + 88.865680217*t)
	X1 += 0.00000000157*np.cos(5.15568499427 + 13553.8979729108*t)
	X1 += 0.00000000153*np.cos(0.79359507111 + 160.6088973985*t)
	X1 += 0.00000000153*np.cos(4.56991285435 + 7064.1213856228*t)
	X1 += 0.00000000154*np.cos(6.16274455061 + 519.3960243561*t)
	X1 += 0.00000000140*np.cos(3.74168278014 + 8631.326197928*t)
	X1 += 0.00000000140*np.cos(5.84592048082 + 1258.4539316256*t)
	X1 += 0.00000000138*np.cos(5.22139410630 + 1055.4497769261*t)
	X1 += 0.00000000162*np.cos(1.41066050496 + 18875.525869774*t)
	X1 += 0.00000000132*np.cos(0.46806671232 + 654.1243803156*t)
	X1 += 0.00000000134*np.cos(3.33556330332 + 203.0041546995*t)
	X1 += 0.00000000177*np.cos(4.60803620012 + 5481.2549188676*t)
	X1 += 0.00000000128*np.cos(5.46982761491 + 10632.7701900862*t)
	X1 += 0.00000000120*np.cos(0.17691589754 + 1063.3140834523*t)
	X1 += 0.00000000122*np.cos(3.52963783211 + 22805.7355659936*t)
	X1 += 0.00000000118*np.cos(4.77280443966 + 551.031606097*t)
	X1 += 0.00000000131*np.cos(2.25810592292 + 31441.6775697568*t)
	X1 += 0.00000000151*np.cos(2.51506129756 + 29864.334027309*t)
	X1 += 0.00000000120*np.cos(4.45697558744 + 539.9859058331*t)
	X1 += 0.00000000143*np.cos(4.89084173973 + 7994.5284420242*t)
	X1 += 0.00000000140*np.cos(5.86589845886 + 1056.2005364515*t)
	X1 += 0.00000000111*np.cos(5.69390808885 + 222.8603229936*t)
	X1 += 0.00000000111*np.cos(0.03988488946 + 2125.8774073792*t)
	X1 += 0.00000000133*np.cos(4.62837772547 + 22.0914005278*t)
	X1 += 0.00000000128*np.cos(4.83324965266 + 14143.4952424306*t)
	X1 += 0.00000000144*np.cos(1.47900802038 + 299.1263942692*t)
	X1 += 0.00000000119*np.cos(2.18817672539 + 28521.0927782546*t)
	X1 += 0.00000000134*np.cos(3.16966777445 + 21.3406410024*t)
	X1 += 0.00000000133*np.cos(4.66569043351 + 12432.0426503978*t)
	X1 += 0.00000000126*np.cos(4.47692677637 + 9793.8009023358*t)
	X1 += 0.00000000099*np.cos(2.30761648841 + 20.7753954924*t)
	X1 += 0.00000000139*np.cos(2.94662252756 + 1485.9801210652*t)
	X1 += 0.00000000104*np.cos(6.17531547106 + 36147.4098773004*t)
	X1 += 0.00000000097*np.cos(5.41467539027 + 18.1592472647*t)
	X1 += 0.00000000096*np.cos(3.08170402360 + 191.9584544356*t)
	X1 += 0.00000000120*np.cos(4.77545420807 + 1574.8458012822*t)
	X1 += 0.00000000094*np.cos(3.31739742370 + 87.3117715395*t)
	X1 += 0.00000000101*np.cos(1.27086316315 + 33.6796175129*t)
	X1 += 0.00000000093*np.cos(0.14711850987 + 574.3447983348*t)
	X1 += 0.00000000129*np.cos(4.90463216286 + 7564.830720738*t)
	X1 += 0.00000000092*np.cos(1.92693800199 + 9360.089164459*t)
	X1 += 0.00000000105*np.cos(0.69367524807 + 16983.9961474566*t)
	X1 += 0.00000000122*np.cos(0.24302263595 + 84.3428261229*t)
	X1 += 0.00000000095*np.cos(3.66782801204 + 10433.6981886498*t)
	X1 += 0.00000000095*np.cos(5.82605803532 + 9992.8729037722*t)
	X1 += 0.00000000096*np.cos(5.16231260208 + 2111.6503133776*t)
	X1 += 0.00000000097*np.cos(5.87982327909 + 217.964961884*t)
	X1 += 0.00000000087*np.cos(3.32576161903 + 231.4583427027*t)
	X1 += 0.00000000097*np.cos(1.64179644592 + 72.3339180125*t)
	X1 += 0.00000000089*np.cos(5.45720829907 + 628.8515860501*t)
	X1 += 0.00000000088*np.cos(5.00348782624 + 1699.2792165032*t)
	X1 += 0.00000000081*np.cos(0.17273168667 + 19896.8801273274*t)
	X1 += 0.00000000110*np.cos(0.30263518591 + 11802.3584414948*t)
	X1 += 0.00000000108*np.cos(5.13400660338 + 29580.4747084438*t)
	X1 += 0.00000000081*np.cos(1.26377078095 + 12.5301729722*t)
	X1 += 0.00000000093*np.cos(5.89270070063 + 2957.7158944766*t)
	X1 += 0.00000000086*np.cos(3.03921945697 + 127.4717966068*t)
	X1 += 0.00000000094*np.cos(1.47978763830 + 20433.6846394228*t)
	X1 += 0.00000000085*np.cos(5.30523639998 + 208.633228992*t)
	X1 += 0.00000000084*np.cos(3.01528050439 + 25158.6017197654*t)
	X1 += 0.00000000080*np.cos(4.03019573108 + 1471.7530270636*t)
	X1 += 0.00000000076*np.cos(5.75771357218 + 288.0806940053*t)
	X1 += 0.00000000077*np.cos(4.50520624769 + 10177.2576795336*t)
	X1 += 0.00000000077*np.cos(4.98867979968 + 10249.3134128884*t)
	X1 += 0.00000000088*np.cos(1.15956894470 + 2379.1644735716*t)
	X1 += 0.00000000096*np.cos(6.22255663987 + 203.7378678824*t)
	X1 += 0.00000000076*np.cos(0.40948960322 + 362.8622925726*t)
	X1 += 0.00000000072*np.cos(3.81559276845 + 302.164775655*t)
	X1 += 0.00000000071*np.cos(1.17266418386 + 24150.080051345*t)
	X1 += 0.00000000075*np.cos(1.95113506965 + 525.0250986486*t)
	X1 += 0.00000000069*np.cos(4.21368560293 + 114.3991069134*t)
	X1 += 0.00000000068*np.cos(0.64071253014 + 153.4953503977*t)
	X1 += 0.00000000068*np.cos(0.16388050208 + 9.5612275556*t)
	X1 += 0.00000000068*np.cos(0.99582401938 + 73.8183907208*t)
	X1 += 0.00000000071*np.cos(0.26608127921 + 29043.67019634839*t)
	X1 += 0.00000000091*np.cos(0.45051499731 + 19360.07561523199*t)
	X1 += 0.00000000071*np.cos(2.38708525663 + 534.3568315406*t)
	X1 += 0.00000000068*np.cos(3.96046123295 + 10383.9584168302*t)
	X1 += 0.00000000068*np.cos(5.53342481442 + 10042.6126755918*t)
	X1 += 0.00000000077*np.cos(0.65927841966 + 29573.361161443*t)
	X1 += 0.00000000069*np.cos(4.86964064866 + 26735.9452622132*t)
	X1 += 0.00000000073*np.cos(0.21800067624 + 29587.5882554446*t)
	X1 += 0.00000000065*np.cos(5.46497273946 + 39302.096962196*t)
	X1 += 0.00000000064*np.cos(0.53528518109 + 75.7448064138*t)
	X1 += 0.00000000066*np.cos(3.87839547247 + 3532.0606928114*t)
	X1 += 0.00000000066*np.cos(6.17786477200 + 42.5864537627*t)
	X1 += 0.00000000061*np.cos(2.88776849923 + 207.8824694666*t)
	X1 += 0.00000000061*np.cos(0.66096812913 + 29057.89729034999*t)
	X1 += 0.00000000081*np.cos(4.74585575332 + 11764.330768859*t)
	X1 += 0.00000000060*np.cos(2.02282855033 + 218.7157214094*t)
	X1 += 0.00000000070*np.cos(0.83559773197 + 52.6901980395*t)
	X1 += 0.00000000059*np.cos(1.24623136375 + 408.4389436113*t)
	X1 += 0.00000000067*np.cos(1.15918883443 + 40077.61957352*t)
	X1 += 0.00000000077*np.cos(0.71010883429 + 20213.271996984*t)
	X1 += 0.00000000067*np.cos(0.58534149028 + 152.5321425512*t)
	X1 += 0.00000000077*np.cos(3.31402395838 + 7834.1210726394*t)
	X1 += 0.00000000076*np.cos(0.10784891475 + 77.2292791221*t)
	X1 += 0.00000000064*np.cos(3.30054842989 + 79.2350166922*t)
	X1 += 0.00000000061*np.cos(0.45486168004 + 56.6223513026*t)
	X1 += 0.00000000067*np.cos(1.57099488677 + 17778.11626694899*t)
	X1 += 0.00000000060*np.cos(6.21424049877 + 30831.3049047446*t)
	X1 += 0.00000000055*np.cos(3.57207397234 + 340.7708920448*t)
	X1 += 0.00000000063*np.cos(0.10245962772 + 9779.5738083342*t)
	X1 += 0.00000000055*np.cos(1.10439423420 + 6770.7106012456*t)
	X1 += 0.00000000055*np.cos(3.08168513239 + 200.7689224658*t)
	X1 += 0.00000000076*np.cos(2.25541605095 + 146.594251718*t)
	X1 += 0.00000000060*np.cos(5.32793915897 + 831.8557407496*t)
	X1 += 0.00000000054*np.cos(2.83216128661 + 1.4844727083*t)
	X1 += 0.00000000054*np.cos(4.90109549879 + 19317.1925403286*t)
	X1 += 0.00000000066*np.cos(5.83578469159 + 618.5566453116*t)
	X1 += 0.00000000055*np.cos(1.55888979134 + 27490.6924780448*t)
	X1 += 0.00000000058*np.cos(0.97037460116 + 4.4534181249*t)
	X1 += 0.00000000051*np.cos(3.56752380688 + 225.8292684102*t)
	X1 += 0.00000000058*np.cos(3.10263152972 + 2221.856634597*t)
	X1 += 0.00000000051*np.cos(4.54732927101 + 62.2514255951*t)
	X1 += 0.00000000059*np.cos(3.60960317836 + 35371.8872659764*t)
	X1 += 0.00000000064*np.cos(5.43530311047 + 1685.0521225016*t)
	X1 += 0.00000000050*np.cos(4.84629478021 + 195.1398481733*t)
	X1 += 0.00000000050*np.cos(1.75539922827 + 10103.0792249916*t)
	X1 += 0.00000000050*np.cos(1.45530151192 + 10323.4918674304*t)
	X1 += 0.00000000050*np.cos(6.20989838059 + 39793.7602546548*t)
	X1 += 0.00000000049*np.cos(2.64059175393 + 2008.557539159*t)
	X1 += 0.00000000052*np.cos(4.61821041475 + 70.3281804424*t)
	X1 += 0.00000000049*np.cos(4.31351627712 + 350.3321196004*t)
	X1 += 0.00000000052*np.cos(0.61784659161 + 26709.6469424134*t)
	X1 += 0.00000000050*np.cos(3.88430063812 + 16522.6597160022*t)
	X1 += 0.00000000051*np.cos(1.79926614465 + 210.3783341312*t)
	X1 += 0.00000000051*np.cos(3.07938265367 + 216.2198567448*t)
	X1 += 0.00000000048*np.cos(3.03978445690 + 27197.2816936676*t)
	X1 += 0.00000000049*np.cos(5.92307582908 + 963.4027029714*t)
	X1 += 0.00000000053*np.cos(1.27341801656 + 142.4496501338*t)
	X1 += 0.00000000047*np.cos(3.62423252693 + 20639.87018786*t)
	X1 += 0.00000000046*np.cos(4.31718940500 + 19786.67380610799*t)
	X1 += 0.00000000045*np.cos(4.37583121590 + 29999.959352319*t)
	X1 += 0.00000000047*np.cos(2.61829720304 + 57837.1383323006*t)
	X1 += 0.00000000045*np.cos(0.64539022706 + 43232.3066584156*t)
	X1 += 0.00000000055*np.cos(3.28045715106 + 2218.7571041868*t)
	X1 += 0.00000000045*np.cos(4.80760215190 + 37.611770776*t)
	X1 += 0.00000000050*np.cos(4.51633294079 + 1038.0412891868*t)
	X1 += 0.00000000044*np.cos(5.63991949724 + 524.2743391232*t)
	X1 += 0.00000000044*np.cos(2.67440279390 + 38.6543004996*t)
	X1 += 0.00000000043*np.cos(5.13872092014 + 29786.660256881*t)
	X1 += 0.00000000046*np.cos(4.36312032216 + 29088.811415985*t)
	X1 += 0.00000000044*np.cos(4.98395147244 + 535.107591066*t)
	X1 += 0.00000000051*np.cos(2.50513032627 + 44007.8292697396*t)
	X1 += 0.00000000045*np.cos(0.02215975970 + 30666.1549584328*t)
	X1 += 0.00000000058*np.cos(5.77065508757 + 1795.258443721*t)
	X1 += 0.00000000043*np.cos(4.16006907854 + 74.6697239827*t)
	X1 += 0.00000000043*np.cos(3.66062507509 + 74.8934731519*t)
	X1 += 0.00000000056*np.cos(3.87309891223 + 17468.8551979454*t)
	X1 += 0.00000000054*np.cos(0.93200345594 + 25934.1243310894*t)
	X1 += 0.00000000049*np.cos(5.77857770467 + 207.6700211455*t)
	X1 += 0.00000000051*np.cos(1.29476626427 + 13341.6743113068*t)
	X1 += 0.00000000049*np.cos(1.81278199589 + 131.4039498699*t)
	X1 += 0.00000000051*np.cos(1.12825933915 + 13655.8604911764*t)
	X1 += 0.00000000047*np.cos(2.28831256912 + 109.9456887885*t)
	X1 += 0.00000000039*np.cos(1.67338261788 + 1382.8873468466*t)
	X1 += 0.00000000039*np.cos(5.77845089286 + 20447.3464879144*t)
	X1 += 0.00000000041*np.cos(2.93602685311 + 10.2949407385*t)
	X1 += 0.00000000038*np.cos(4.40087475081 + 703.6331846174*t)
	X1 += 0.00000000046*np.cos(5.36914408518 + 218.9281697305*t)
	X1 += 0.00000000038*np.cos(3.46632011895 + 21000.9158907568*t)
	X1 += 0.00000000038*np.cos(5.73479924178 + 33019.0211122046*t)
	X1 += 0.00000000037*np.cos(4.39032344034 + 511.5317178299*t)
	X1 += 0.00000000042*np.cos(0.50159500441 + 3914.9572250346*t)
	X1 += 0.00000000042*np.cos(4.77757016347 + 38204.687359371*t)
	X1 += 0.00000000041*np.cos(0.07265138638 + 18830.38465013739*t)
	X1 += 0.00000000036*np.cos(5.95301096335 + 10077.660221201*t)
	X1 += 0.00000000036*np.cos(3.54087508402 + 10348.910871221*t)
	X1 += 0.00000000047*np.cos(6.22385797527 + 8662.240323563*t)
	X1 += 0.00000000040*np.cos(5.87480727345 + 18844.61174413899*t)
	X1 += 0.00000000035*np.cos(5.85809750059 + 565.1156877467*t)
	X1 += 0.00000000035*np.cos(6.22608295766 + 547.8502123593*t)
	X1 += 0.00000000038*np.cos(3.93290315553 + 490.3340891794*t)
	X1 += 0.00000000034*np.cos(5.54907603693 + 750.1036075334*t)
	X1 += 0.00000000037*np.cos(6.26293750649 + 635.9651330509*t)
	X1 += 0.00000000038*np.cos(5.99103573925 + 483.2205421786*t)
	X1 += 0.00000000035*np.cos(4.68155089578 + 526.7702037878*t)
	X1 += 0.00000000040*np.cos(3.88666957401 + 47938.0389659592*t)
	X1 += 0.00000000036*np.cos(1.01249884206 + 33794.5437235286*t)
	X1 += 0.00000000035*np.cos(5.94254789616 + 532.6117264014*t)
	X1 += 0.00000000032*np.cos(5.49940747482 + 16894.5103996106*t)
	X1 += 0.00000000034*np.cos(0.08271536061 + 19374.3027092336*t)
	X1 += 0.00000000032*np.cos(1.98563978946 + 47162.5163546352*t)
	X1 += 0.00000000042*np.cos(0.37006972783 + 55798.4583583984*t)
	X1 += 0.00000000031*np.cos(3.51648880247 + 20043.6745601988*t)
	X1 += 0.00000000033*np.cos(1.44340083609 + 48417.97290558199*t)
	X1 += 0.00000000031*np.cos(1.18565768932 + 447.9388318784*t)
	X1 += 0.00000000034*np.cos(5.27191255343 + 54247.4131357504*t)
	X1 += 0.00000000032*np.cos(2.12080485438 + 10191.4347168846*t)
	X1 += 0.00000000032*np.cos(1.08989588582 + 10235.1363755374*t)
	X1 += 0.00000000038*np.cos(0.78775617354 + 7255.5696517344*t)
	X1 += 0.00000000031*np.cos(2.88646250826 + 8087.4081388318*t)
	X1 += 0.00000000030*np.cos(0.44298905817 + 209.106309744*t)
	X1 += 0.00000000030*np.cos(1.59264152747 + 92.940845832*t)
	X1 += 0.00000000030*np.cos(1.96661961760 + 10853.182832525*t)
	X1 += 0.00000000030*np.cos(4.44526322933 + 217.491881132*t)
	X1 += 0.00000000030*np.cos(0.79959461257 + 36949.2308084242*t)
	X1 += 0.00000000035*np.cos(1.72609608211 + 265.9892934775*t)
	X1 += 0.00000000033*np.cos(1.13583992722 + 12592.4500197826*t)
	X1 += 0.00000000029*np.cos(5.21162982204 + 10290.959316639*t)
	X1 += 0.00000000029*np.cos(4.28225622533 + 10135.611775783*t)
	X1 += 0.00000000028*np.cos(5.74069736147 + 104351.61256629678*t)
	X1 += 0.00000000028*np.cos(3.34466525843 + 80.1982245387*t)
	X1 += 0.00000000032*np.cos(4.16582591800 + 20206.15844998319*t)
	X1 += 0.00000000029*np.cos(1.47368482939 + 34596.3646546524*t)
	X1 += 0.00000000027*np.cos(4.35707854664 + 1279.794572628*t)
	X1 += 0.00000000031*np.cos(5.18940920282 + 424.1505103212*t)
	X1 += 0.00000000032*np.cos(5.37255836333 + 9835.9119382952*t)
	X1 += 0.00000000032*np.cos(4.12132768404 + 10590.6591541268*t)
	X1 += 0.00000000027*np.cos(6.25293404514 + 6298.3283211764*t)
	X1 += 0.00000000033*np.cos(0.34449594524 + 269.9214467406*t)
	X1 += 0.00000000035*np.cos(5.35069959846 + 9985.809413422*t)
	X1 += 0.00000000035*np.cos(4.14318644891 + 10440.76167900*t)
	X1 += 0.00000000028*np.cos(4.67032066017 + 55022.9357470744*t)
	X1 += 0.00000000027*np.cos(4.81466818286 + 1802.3719907218*t)
	X1 += 0.00000000033*np.cos(1.09348944613 + 27461.7108480654*t)
	X1 += 0.00000000026*np.cos(4.77604676579 + 34363.365597556*t)
	X1 += 0.00000000032*np.cos(1.06669637529 + 11265.5539293994*t)
	X1 += 0.00000000027*np.cos(5.82028492837 + 1898.3512179396*t)
	X1 += 0.00000000029*np.cos(3.31180384238 + 30206.14490075619*t)
	X1 += 0.00000000032*np.cos(5.28519921901 + 51868.2486621788*t)
	X1 += 0.00000000033*np.cos(1.79088538074 + 59728.668054618*t)
	X1 += 0.00000000029*np.cos(3.70229059266 + 20220.3855439848*t)
	X1 += 0.00000000024*np.cos(5.85539151209 + 8734.4189721466*t)
	X1 += 0.00000000024*np.cos(1.21351947969 + 36173.7081971002*t)
	X1 += 0.00000000024*np.cos(4.42282986398 + 31022.7531708562*t)
	X1 += 0.00000000024*np.cos(2.16102096842 + 40879.4405046438*t)
	X1 += 0.00000000027*np.cos(2.40070719103 + 37724.7534197482*t)
	X1 += 0.00000000027*np.cos(2.82758334354 + 30220.3719947578*t)
	X1 += 0.00000000023*np.cos(0.26922480404 + 24383.0791084414*t)
	X1 += 0.00000000023*np.cos(3.40993702222 + 51092.7260508548*t)
	X1 += 0.00000000023*np.cos(1.56475852877 + 650.9429865779*t)
	X1 += 0.00000000023*np.cos(2.71148449796 + 10367.0643566958*t)
	X1 += 0.00000000023*np.cos(0.49921624223 + 10059.5067357262*t)
	X1 += 0.00000000029*np.cos(2.93595097785 + 26087.9031415742*t)
	X1 += 0.00000000026*np.cos(2.79749713332 + 39271.182836561*t)
	X1 += 0.00000000026*np.cos(3.27997889051 + 39256.95574255939*t)
	X1 += 0.00000000023*np.cos(4.85605613315 + 35.685355083*t)
	X1 += 0.00000000025*np.cos(5.61288176999 + 46386.9937433112*t)
	X1 += 0.00000000023*np.cos(3.93905950844 + 49515.382508407*t)
	X1 += 0.00000000023*np.cos(4.85338065767 + 28.5718080822*t)
	X1 += 0.00000000022*np.cos(0.71803323367 + 337.732510659*t)
	X1 += 0.00000000026*np.cos(3.68291120913 + 8101.6352328334*t)
	X1 += 0.00000000022*np.cos(2.92851543538 + 24978.5245894808*t)
	X1 += 0.00000000023*np.cos(0.11555144192 + 643.0786800517*t)
	X1 += 0.00000000030*np.cos(4.35689646676 + 17248.4253018544*t)
	X1 += 0.00000000023*np.cos(4.51155345742 + 284.1485407422*t)
	X1 += 0.00000000022*np.cos(0.61619120317 + 22645.32819660879*t)
	X1 += 0.00000000022*np.cos(1.75420132293 + 30426.557543195*t)
	X1 += 0.00000000023*np.cos(6.22294900930 + 191.2076949102*t)
	X1 += 0.00000000021*np.cos(0.34726135597 + 137.0330241624*t)
	X1 += 0.00000000022*np.cos(2.56035448587 + 66813.5648357332*t)
	X1 += 0.00000000021*np.cos(2.62420739411 + 40.5807161926*t)
	X1 += 0.00000000022*np.cos(0.93565021177 + 9566.2747128962*t)
	X1 += 0.00000000021*np.cos(3.37519693925 + 934.9485149682*t)
	X1 += 0.00000000023*np.cos(2.47790916174 + 6309.3741697912*t)
	X1 += 0.00000000021*np.cos(2.93989832001 + 525.4981794006*t)
	X1 += 0.00000000021*np.cos(2.05775290145 + 10949.1620597428*t)
	X1 += 0.00000000021*np.cos(1.15294783874 + 9477.4090326792*t)
	X1 += 0.00000000028*np.cos(0.54837105379 + 9580.5018068978*t)
	X1 += 0.00000000024*np.cos(0.56697771725 + 10288.0671447783*t)
	X1 += 0.00000000024*np.cos(2.64372302294 + 10138.5039476437*t)
	X1 += 0.00000000020*np.cos(2.21258610934 + 11279.781023401*t)
	X1 += 0.00000000023*np.cos(4.92629143648 + 540.7366653585*t)
	X1 += 0.00000000023*np.cos(0.59531277141 + 1361.5467058442*t)
	X1 += 0.00000000020*np.cos(3.68816505309 + 18073.7049386502*t)
	X1 += 0.00000000025*np.cos(0.38304523465 + 96.8729990951*t)
	X1 += 0.00000000021*np.cos(6.08866841317 + 58953.145443294*t)
	X1 += 0.00000000023*np.cos(5.24359027210 + 45585.1728121874*t)
	X1 += 0.00000000027*np.cos(6.21242304915 + 1905.4647649404*t)
	X1 += 0.00000000020*np.cos(5.54734924390 + 251.4321310758*t)
	X1 += 0.00000000024*np.cos(4.91328411886 + 219.4494345923*t)
	X1 += 0.00000000023*np.cos(2.67526294292 + 10263.0425716828*t)
	X1 += 0.00000000023*np.cos(0.53543779727 + 10163.5285207392*t)
	X1 += 0.00000000027*np.cos(3.93215204936 + 24341.5283174566*t)
	X1 += 0.00000000021*np.cos(5.90887195268 + 18300.69368504279*t)
	X1 += 0.00000000026*np.cos(3.21325564576 + 63658.8777508376*t)
	X1 += 0.00000000019*np.cos(1.80883011026 + 20316.36477120259*t)
	X1 += 0.00000000020*np.cos(2.90910269310 + 38526.574350872*t)
	X1 += 0.00000000019*np.cos(3.53288056554 + 44809.6502008634*t)
	X1 += 0.00000000020*np.cos(0.92201968088 + 62081.5342083898*t)
	X1 += 0.00000000020*np.cos(3.55117744188 + 81.8951455681*t)
	X1 += 0.00000000020*np.cos(4.23941240591 + 42456.7840470916*t)
	X1 += 0.00000000020*np.cos(2.70819091080 + 49477.35483577119*t)
	X1 += 0.00000000019*np.cos(6.01601338494 + 28513.97923125379*t)
	X1 += 0.00000000021*np.cos(1.17914689008 + 344.7030453079*t)
	X1 += 0.00000000018*np.cos(5.40437078778 + 9050.8108418032*t)
	X1 += 0.00000000019*np.cos(0.08422406558 + 47623.8527860896*t)
	X1 += 0.00000000017*np.cos(1.99727427214 + 479.2883889155*t)
	X1 += 0.00000000018*np.cos(2.62651922515 + 47.6942631934*t)
	X1 += 0.00000000017*np.cos(4.46941749243 + 10497.1448650762*t)
	X1 += 0.00000000017*np.cos(5.02446855494 + 9929.4262273458*t)
	X1 += 0.00000000018*np.cos(2.61349776359 + 113.3877149571*t)
	X1 += 0.00000000017*np.cos(1.63590437693 + 28313.288804661*t)
	X1 += 0.00000000018*np.cos(4.34354168525 + 27682.1407441564*t)
	X1 += 0.00000000017*np.cos(4.48959133859 + 235.3904959658*t)
	X1 += 0.00000000018*np.cos(0.65002779822 + 66.70484372*t)
	X1 += 0.00000000017*np.cos(0.77261247444 + 19624.7501612982*t)
	X1 += 0.00000000020*np.cos(1.53858484384 + 43071.8992890308*t)
	X1 += 0.00000000017*np.cos(6.13245058546 + 18314.9207790444*t)
	X1 += 0.00000000018*np.cos(0.82070318043 + 436.8931316145*t)
	X1 += 0.00000000018*np.cos(0.75283830224 + 50317.2034395308*t)
	X1 += 0.00000000016*np.cos(5.70285177091 + 1603.2999892854*t)
	X1 += 0.00000000018*np.cos(0.02898286217 + 42430.4857272918*t)
	X1 += 0.00000000017*np.cos(0.76245918828 + 909.8187330546*t)
	X1 += 0.00000000018*np.cos(0.68490378171 + 358.9301393095*t)
	X1 += 0.00000000016*np.cos(5.43519924864 + 9745.3205558566*t)
	X1 += 0.00000000016*np.cos(4.05868679873 + 10681.2505365654*t)
	X1 += 0.00000000017*np.cos(1.44060402818 + 533.8837507886*t)
	X1 += 0.00000000019*np.cos(0.01647605955 + 207.1487562837*t)
	X1 += 0.00000000017*np.cos(1.09605096689 + 417.0369633204*t)
	X1 += 0.00000000016*np.cos(5.18072747317 + 1788.1448967202*t)
	X1 += 0.00000000017*np.cos(5.41405900055 + 497.4476361802*t)
	X1 += 0.00000000016*np.cos(4.40841499018 + 41654.9631159678*t)
	X1 += 0.00000000015*np.cos(5.40287159543 + 10199.0584522094*t)
	X1 += 0.00000000015*np.cos(4.09101445194 + 10227.5126402126*t)
	X1 += 0.00000000017*np.cos(0.59320479310 + 2.4476805548*t)
	X1 += 0.00000000017*np.cos(3.98136429313 + 70743.77453195279*t)
	X1 += 0.00000000016*np.cos(5.49478140063 + 175.1660598002*t)
	X1 += 0.00000000015*np.cos(4.91286509923 + 48739.859897083*t)
	X1 += 0.00000000015*np.cos(4.83495777746 + 38734.3783244656*t)
	X1 += 0.00000000016*np.cos(4.29457970004 + 67.6680515665*t)
	X1 += 0.00000000015*np.cos(1.22362311631 + 62883.3551395136*t)
	X1 += 0.00000000015*np.cos(2.70406994167 + 53285.1848352418*t)
	X1 += 0.00000000015*np.cos(2.34568905276 + 66011.74390460939*t)
	X1 += 0.00000000015*np.cos(5.15304621208 + 220.4608265486*t)
	X1 += 0.00000000015*np.cos(2.83729246953 + 38727.2647774648*t)
	X1 += 0.00000000015*np.cos(1.51873359040 + 46360.6954235114*t)
	X1 += 0.00000000015*np.cos(4.99636225149 + 518.6452648307*t)
	X1 += 0.00000000015*np.cos(0.95581113217 + 146.3818033969*t)
	X1 += 0.00000000019*np.cos(4.60380196538 + 67589.08744705719*t)
	X1 += 0.00000000014*np.cos(0.37440982130 + 39999.945803092*t)
	X1 += 0.00000000014*np.cos(1.52734358006 + 11026.8358301708*t)
	X1 += 0.00000000014*np.cos(1.68335716013 + 9399.7352622512*t)
	X1 += 0.00000000014*np.cos(2.27264864715 + 416.3032501375*t)
	X1 += 0.00000000019*np.cos(3.55838458417 + 554.0699874828*t)
	X1 += 0.00000000014*np.cos(5.18725769632 + 1049.0869894507*t)
	X1 += 0.00000000014*np.cos(0.04043838791 + 28528.2063252554*t)
	X1 += 0.00000000014*np.cos(1.39515112241 + 37895.4262903674*t)
	X1 += 0.00000000014*np.cos(5.07734306466 + 351.8165923087*t)
	X1 += 0.00000000014*np.cos(1.44889652645 + 37410.5672398786*t)
	X1 += 0.00000000014*np.cos(2.77974606905 + 14128.2427712456*t)
	X1 += 0.00000000014*np.cos(2.94217443085 + 50290.905119731*t)
	X1 += 0.00000000014*np.cos(4.66254689609 + 429.0458714308*t)
	X1 += 0.00000000015*np.cos(6.22361957178 + 21485.95302261119*t)
	X1 += 0.00000000013*np.cos(6.14132798035 + 52670.0695933026*t)
	X1 += 0.00000000015*np.cos(0.87904326630 + 4.665866446*t)
	X1 += 0.00000000015*np.cos(5.80214824265 + 181.0557665236*t)
	X1 += 0.00000000015*np.cos(3.18753797236 + 27991.40181316*t)
	return X1*t




def Venus_X2 (t): # 266 terms of order 2

	X2 = 0.
	X2 += 0.00000704792*np.cos(5.09874399916 + 20426.571092422*t)
	X2 += 0.00000624474*np.cos(3.86836508673 + 10213.285546211*t)
	X2 -= 0.00000604225
	X2 += 0.00000160293*np.cos(4.40406062613 + 206.1855484372*t)
	X2 += 0.00000155633*np.cos(0.48183983171 + 220.4126424388*t)
	X2 += 0.00000118222*np.cos(0.99338493688 + 522.5774180938*t)
	X2 += 0.00000115842*np.cos(3.35337160144 + 536.8045120954*t)
	X2 += 0.00000096063*np.cos(5.56707571020 + 213.299095438*t)
	X2 += 0.00000065107*np.cos(5.63089478188 + 426.598190876*t)
	X2 += 0.00000074211*np.cos(2.15619420586 + 529.6909650946*t)
	X2 += 0.00000039494*np.cos(1.98598560810 + 1059.3819301892*t)
	X2 += 0.00000014232*np.cos(5.82837756444 + 433.7117378768*t)
	X2 += 0.00000011644*np.cos(5.50982814990 + 30639.856638633*t)
	X2 += 0.00000013989*np.cos(1.76434060619 + 7.1135470008*t)
	X2 += 0.00000012711*np.cos(3.49149798770 + 419.4846438752*t)
	X2 += 0.00000009321*np.cos(4.71464865506 + 639.897286314*t)
	X2 += 0.00000008620*np.cos(2.69988723020 + 10186.9872264112*t)
	X2 += 0.00000008590*np.cos(0.50870967404 + 10239.5838660108*t)
	X2 += 0.00000007707*np.cos(0.35647823047 + 227.5261894396*t)
	X2 += 0.00000006797*np.cos(3.87383015136 + 1066.49547719*t)
	X2 += 0.00000005452*np.cos(0.48898137631 + 1052.2683831884*t)
	X2 += 0.00000005027*np.cos(1.12572622612 + 515.463871093*t)
	X2 += 0.00000003854*np.cos(2.44255859575 + 1589.0728952838*t)
	X2 += 0.00000003667*np.cos(4.56283602529 + 199.0720014364*t)
	X2 += 0.00000003523*np.cos(3.22103209546 + 543.9180590962*t)
	X2 += 0.00000003815*np.cos(0.77119888833 + 9437.762934887*t)
	X2 += 0.00000002806*np.cos(3.22770970899 + 8635.9420037632*t)
	X2 += 0.00000003408*np.cos(2.43107046634 + 10988.808157535*t)
	X2 += 0.00000002198*np.cos(3.74762936451 + 10021.8372800994*t)
	X2 += 0.00000002279*np.cos(6.27047209584 + 11790.6290886588*t)
	X2 += 0.00000002142*np.cos(5.74529785137 + 10404.7338123226*t)
	X2 += 0.00000001697*np.cos(0.37726443109 + 775.522611324*t)
	X2 += 0.00000001347*np.cos(2.19024470415 + 316.3918696566*t)
	X2 += 0.00000001405*np.cos(6.22622304401 + 216.4804891757*t)
	X2 += 0.00000001320*np.cos(4.96541286159 + 647.0108333148*t)
	X2 += 0.00000001365*np.cos(4.95810524231 + 210.1177017003*t)
	X2 += 0.00000001687*np.cos(1.62553064962 + 14.2270940016*t)
	X2 += 0.00000001093*np.cos(4.21067890946 + 103.0927742186*t)
	X2 += 0.00000000973*np.cos(4.02172041169 + 853.196381752*t)
	X2 += 0.00000000938*np.cos(4.40679265580 + 632.7837393132*t)
	X2 += 0.00000000848*np.cos(1.52469724284 + 526.5095713569*t)
	X2 += 0.00000000826*np.cos(2.81425975210 + 532.8723588323*t)
	X2 += 0.00000000758*np.cos(0.02371551403 + 209.3669421749*t)
	X2 += 0.00000000733*np.cos(4.88186040762 + 217.2312487011*t)
	X2 += 0.00000000688*np.cos(5.79109380413 + 440.8252848776*t)
	X2 += 0.00000000716*np.cos(1.35432613135 + 9830.3890139878*t)
	X2 += 0.00000000645*np.cos(1.80158579035 + 4705.7323075436*t)
	X2 += 0.00000000682*np.cos(1.85637661737 + 10596.1820784342*t)
	X2 += 0.00000000603*np.cos(5.14215709084 + 323.5054166574*t)
	X2 += 0.00000000624*np.cos(0.96146126905 + 117.3198682202*t)
	X2 += 0.00000000594*np.cos(2.81614157236 + 19651.048481098*t)
	X2 += 0.00000000549*np.cos(4.81966003612 + 949.1756089698*t)
	X2 += 0.00000000702*np.cos(0.69460527884 + 74.7815985673*t)
	X2 += 0.00000000527*np.cos(4.51723747327 + 10742.9765113056*t)
	X2 += 0.00000000527*np.cos(4.96386147132 + 9683.5945811164*t)
	X2 += 0.00000000546*np.cos(0.01597529774 + 1045.1548361876*t)
	X2 += 0.00000000532*np.cos(2.93260463288 + 191.4482661116*t)
	X2 += 0.00000000499*np.cos(2.95394998140 + 110.2063212194*t)
	X2 += 0.00000000510*np.cos(2.48615954177 + 95.9792272178*t)
	X2 += 0.00000000604*np.cos(6.00696167862 + 735.8765135318*t)
	X2 += 0.00000000490*np.cos(2.82889535700 + 525.7588118315*t)
	X2 += 0.00000000488*np.cos(1.51375734651 + 533.6231183577*t)
	X2 += 0.00000000438*np.cos(4.38613869498 + 1596.1864422846*t)
	X2 += 0.00000000570*np.cos(5.05711649193 + 801.8209311238*t)
	X2 += 0.00000000519*np.cos(6.10806295653 + 149.5631971346*t)
	X2 += 0.00000000526*np.cos(1.01160968834 + 7058.5984613154*t)
	X2 += 0.00000000329*np.cos(1.41548628066 + 15720.8387848784*t)
	X2 += 0.00000000317*np.cos(2.85849486793 + 2118.7638603784*t)
	X2 += 0.00000000286*np.cos(3.25503239085 + 9103.9069941176*t)
	X2 += 0.00000000362*np.cos(5.91786685439 + 9411.4646150872*t)
	X2 += 0.00000000301*np.cos(2.27011866705 + 26.2983197998*t)
	X2 += 0.00000000353*np.cos(5.67450059858 + 63.7358983034*t)
	X2 += 0.00000000359*np.cos(2.19075630034 + 13367.9726311066*t)
	X2 += 0.00000000250*np.cos(6.23903308413 + 11322.6640983044*t)
	X2 += 0.00000000267*np.cos(6.09793545646 + 625.6701923124*t)
	X2 += 0.00000000270*np.cos(0.56801609869 + 1581.959348283*t)
	X2 += 0.00000000335*np.cos(3.28599535784 + 412.3710968744*t)
	X2 += 0.00000000230*np.cos(1.62446688541 + 70.8494453042*t)
	X2 += 0.00000000298*np.cos(3.54353073631 + 11015.1064773348*t)
	X2 += 0.00000000226*np.cos(0.21648774887 + 234.6397364404*t)
	X2 += 0.00000000239*np.cos(4.19538799331 + 3154.6870848956*t)
	X2 += 0.00000000257*np.cos(0.55141837710 + 956.2891559706*t)
	X2 += 0.00000000302*np.cos(5.83564279638 + 3128.3887650958*t)
	X2 += 0.00000000218*np.cos(6.18732888250 + 78.7137518304*t)
	X2 += 0.00000000216*np.cos(0.69406612425 + 11.0457002639*t)
	X2 += 0.00000000283*np.cos(2.17198423111 + 85.8272988312*t)
	X2 += 0.00000000210*np.cos(4.87169565788 + 942.062061969*t)
	X2 += 0.00000000227*np.cos(5.26494518266 + 73.297125859*t)
	X2 += 0.00000000190*np.cos(1.78329501671 + 10426.584641649*t)
	X2 += 0.00000000190*np.cos(1.42740572348 + 9999.986450773*t)
	X2 += 0.00000000235*np.cos(1.88541486477 + 36.6485629295*t)
	X2 += 0.00000000187*np.cos(0.38219508219 + 1577.3435424478*t)
	X2 += 0.00000000192*np.cos(6.19395381253 + 20618.0193585336*t)
	X2 += 0.00000000224*np.cos(5.59487510601 + 39.6175083461*t)
	X2 += 0.00000000228*np.cos(4.22772621951 + 202.2533951741*t)
	X2 += 0.00000000187*np.cos(2.86279402460 + 1169.5882514086*t)
	X2 += 0.00000000167*np.cos(3.64468986986 + 1073.6090241908*t)
	X2 += 0.00000000195*np.cos(0.93545523133 + 224.3447957019*t)
	X2 += 0.00000000158*np.cos(0.41813276311 + 1155.361157407*t)
	X2 += 0.00000000146*np.cos(4.41425613950 + 2352.8661537718*t)
	X2 += 0.00000000141*np.cos(2.05881354566 + 742.9900605326*t)
	X2 += 0.00000000179*np.cos(1.99989531828 + 21228.3920235458*t)
	X2 += 0.00000000135*np.cos(0.93601004324 + 138.5174968707*t)
	X2 += 0.00000000149*np.cos(3.11048959872 + 76.2660712756*t)
	X2 += 0.00000000133*np.cos(1.27948900541 + 508.3503240922*t)
	X2 += 0.00000000156*np.cos(6.20080955726 + 40853.142184844*t)
	X2 += 0.00000000145*np.cos(4.08945624026 + 309.2783226558*t)
	X2 += 0.00000000158*np.cos(5.43294450699 + 382.8965322232*t)
	X2 += 0.00000000126*np.cos(5.33539657707 + 330.6189636582*t)
	X2 += 0.00000000126*np.cos(4.18511285279 + 860.3099287528*t)
	X2 += 0.00000000161*np.cos(4.51005276896 + 7860.4193924392*t)
	X2 += 0.00000000125*np.cos(2.64197102629 + 18849.2275499742*t)
	X2 += 0.00000000132*np.cos(0.16898152725 + 3930.2096962196*t)
	X2 += 0.00000000160*np.cos(3.76409728390 + 38.1330356378*t)
	X2 += 0.00000000110*np.cos(0.59245910440 + 8624.2126509272*t)
	X2 += 0.00000000115*np.cos(6.09545736763 + 223.5940361765*t)
	X2 += 0.00000000110*np.cos(0.21868987814 + 71.6002048296*t)
	X2 += 0.00000000115*np.cos(5.33896891891 + 429.7795846137*t)
	X2 += 0.00000000105*np.cos(1.31705960331 + 77.962992305*t)
	X2 += 0.00000000134*np.cos(3.64312166787 + 17298.1823273262*t)
	X2 += 0.00000000127*np.cos(6.12277131240 + 728.762966531*t)
	X2 += 0.00000000106*np.cos(1.49565452639 + 1162.4747044078*t)
	X2 += 0.00000000102*np.cos(5.20836098548 + 422.6660376129*t)
	X2 += 0.00000000084*np.cos(0.06183751259 + 124.433415221*t)
	X2 += 0.00000000107*np.cos(5.82966879256 + 20452.8694122218*t)
	X2 += 0.00000000074*np.cos(1.07138930276 + 1265.5674786264*t)
	X2 += 0.00000000076*np.cos(4.22098650571 + 423.4167971383*t)
	X2 += 0.00000000071*np.cos(3.05925118734 + 551.031606097*t)
	X2 += 0.00000000082*np.cos(1.68324374227 + 519.3960243561*t)
	X2 += 0.00000000068*np.cos(4.96510846230 + 654.1243803156*t)
	X2 += 0.00000000068*np.cos(5.84598202962 + 19367.1891622328*t)
	X2 += 0.00000000072*np.cos(1.10778150127 + 23581.2581773176*t)
	X2 += 0.00000000070*np.cos(5.63299061783 + 7084.8967811152*t)
	X2 += 0.00000000066*np.cos(2.46864705656 + 88.865680217*t)
	X2 += 0.00000000074*np.cos(3.16178470541 + 16496.3613962024*t)
	X2 += 0.00000000073*np.cos(1.49901280909 + 21.3406410024*t)
	X2 += 0.00000000058*np.cos(4.77256654994 + 191.9584544356*t)
	X2 += 0.00000000064*np.cos(0.59210224706 + 838.9692877504*t)
	X2 += 0.00000000057*np.cos(4.96237460299 + 1109.3785520934*t)
	X2 += 0.00000000064*np.cos(2.62531230776 + 539.9859058331*t)
	X2 += 0.00000000064*np.cos(5.15957430521 + 203.0041546995*t)
	X2 += 0.00000000053*np.cos(2.36605837917 + 22003.9146348698*t)
	X2 += 0.00000000048*np.cos(4.93562349382 + 18073.7049386502*t)
	X2 += 0.00000000045*np.cos(4.29961594202 + 846.0828347512*t)
	X2 += 0.00000000046*np.cos(3.88547191366 + 145.6310438715*t)
	X2 += 0.00000000054*np.cos(2.36466233604 + 20809.4676246452*t)
	X2 += 0.00000000043*np.cos(3.78706374371 + 29050.7837433492*t)
	X2 += 0.00000000055*np.cos(0.22978754207 + 4732.0306273434*t)
	X2 += 0.00000000047*np.cos(3.31818308830 + 1062.5633239269*t)
	X2 += 0.00000000043*np.cos(0.15185271000 + 8094.5216858326*t)
	X2 += 0.00000000044*np.cos(4.38854627107 + 10787.6303445458*t)
	X2 += 0.00000000044*np.cos(5.10533977629 + 9638.9407478762*t)
	X2 += 0.00000000038*np.cos(1.25489937051 + 1258.4539316256*t)
	X2 += 0.00000000040*np.cos(5.32074711484 + 6283.0758499914*t)
	X2 += 0.00000000035*np.cos(1.55855229745 + 1692.1656695024*t)
	X2 += 0.00000000036*np.cos(5.46623211848 + 302.164775655*t)
	X2 += 0.00000000034*np.cos(5.64744481308 + 277.0349937414*t)
	X2 += 0.00000000030*np.cos(4.86335561218 + 2125.8774073792*t)
	X2 += 0.00000000035*np.cos(1.25631519996 + 1056.2005364515*t)
	X2 += 0.00000000033*np.cos(1.04174898368 + 14919.0178537546*t)
	X2 += 0.00000000039*np.cos(0.20293002946 + 1574.8458012822*t)
	X2 += 0.00000000028*np.cos(3.85390317672 + 20235.1228263104*t)
	X2 += 0.00000000036*np.cos(0.12982829645 + 437.6438911399*t)
	X2 += 0.00000000038*np.cos(5.08548479688 + 12566.1516999828*t)
	X2 += 0.00000000031*np.cos(3.39518273216 + 1272.6810256272*t)
	X2 += 0.00000000033*np.cos(0.99530602494 + 6489.776587288*t)
	X2 += 0.00000000037*np.cos(5.11045310809 + 9153.9036160218*t)
	X2 += 0.00000000027*np.cos(3.47340764254 + 1055.4497769261*t)
	X2 += 0.00000000027*np.cos(0.81625295039 + 10639.883737087*t)
	X2 += 0.00000000027*np.cos(2.39444778980 + 9786.687355335*t)
	X2 += 0.00000000029*np.cos(4.87032618379 + 28286.9904848612*t)
	X2 += 0.00000000030*np.cos(3.37471697119 + 24356.7807886416*t)
	X2 += 0.00000000029*np.cos(1.32325847141 + 618.5566453116*t)
	X2 += 0.00000000028*np.cos(6.24637219690 + 1038.0412891868*t)
	X2 += 0.00000000027*np.cos(0.82567085480 + 415.5524906121*t)
	X2 += 0.00000000026*np.cos(0.63216688286 + 3149.1641605882*t)
	X2 += 0.00000000027*np.cos(5.00859316582 + 14143.4952424306*t)
	X2 += 0.00000000028*np.cos(1.64332966541 + 1485.9801210652*t)
	X2 += 0.00000000031*np.cos(0.82947045576 + 5507.5532386674*t)
	X2 += 0.00000000030*np.cos(3.88005298578 + 20400.2727726222*t)
	X2 += 0.00000000026*np.cos(0.46698874540 + 18875.525869774*t)
	X2 += 0.00000000024*np.cos(5.30704569197 + 11272.6674764002*t)
	X2 += 0.00000000026*np.cos(5.05893496491 + 430.5303441391*t)
	X2 += 0.00000000026*np.cos(2.47001707887 + 27511.4678735372*t)
	X2 += 0.00000000024*np.cos(3.54369543262 + 18.1592472647*t)
	X2 += 0.00000000024*np.cos(1.86048219684 + 21535.9496445154*t)
	X2 += 0.00000000024*np.cos(0.77717557683 + 831.8557407496*t)
	X2 += 0.00000000023*np.cos(1.45497436681 + 231.4583427027*t)
	X2 += 0.00000000022*np.cos(0.00126624686 + 18307.8072320436*t)
	X2 += 0.00000000025*np.cos(2.24207971146 + 1368.660252845*t)
	X2 += 0.00000000024*np.cos(3.24916661957 + 2648.454825473*t)
	X2 += 0.00000000021*np.cos(5.72791145125 + 447.9388318784*t)
	X2 += 0.00000000020*np.cos(0.71402000433 + 3.1813937377*t)
	X2 += 0.00000000022*np.cos(5.33490739950 + 151.0476698429*t)
	X2 += 0.00000000019*np.cos(1.74528256840 + 1063.3140834523*t)
	X2 += 0.00000000020*np.cos(3.40302634906 + 1699.2792165032*t)
	X2 += 0.00000000020*np.cos(2.53484218621 + 35.1640902212*t)
	X2 += 0.00000000023*np.cos(2.21622723743 + 13936.794505134*t)
	X2 += 0.00000000018*np.cos(1.08092680576 + 10.2949407385*t)
	X2 += 0.00000000021*np.cos(0.04948675860 + 72.3339180125*t)
	X2 += 0.00000000018*np.cos(3.36089889556 + 28521.0927782546*t)
	X2 += 0.00000000018*np.cos(4.11934903377 + 3.9321532631*t)
	X2 += 0.00000000018*np.cos(5.63577174804 + 1471.7530270636*t)
	X2 += 0.00000000016*np.cos(2.13005908431 + 22.0914005278*t)
	X2 += 0.00000000016*np.cos(5.22446000797 + 1478.8665740644*t)
	X2 += 0.00000000017*np.cos(2.07219008042 + 77.7505439839*t)
	X2 += 0.00000000015*np.cos(2.23535668841 + 8662.240323563*t)
	X2 += 0.00000000016*np.cos(2.19972601182 + 14945.3161735544*t)
	X2 += 0.00000000015*np.cos(4.85349684848 + 1375.7737998458*t)
	X2 += 0.00000000016*np.cos(4.95896524219 + 41.1019810544*t)
	X2 += 0.00000000015*np.cos(5.03114029381 + 160.6088973985*t)
	X2 += 0.00000000014*np.cos(3.19729711687 + 21202.093703746*t)
	X2 += 0.00000000014*np.cos(2.58068667661 + 17277.4069318338*t)
	X2 += 0.00000000014*np.cos(0.47915039682 + 195.1398481733*t)
	X2 += 0.00000000016*np.cos(2.16860864742 + 56.6223513026*t)
	X2 += 0.00000000017*np.cos(1.59080059391 + 77.2292791221*t)
	X2 += 0.00000000014*np.cos(5.26463032742 + 11764.330768859*t)
	X2 += 0.00000000014*np.cos(5.69583373076 + 71.8126531507*t)
	X2 += 0.00000000015*np.cos(3.19537134319 + 65.2203710117*t)
	X2 += 0.00000000016*np.cos(2.92030002382 + 32217.2001810808*t)
	X2 += 0.00000000013*np.cos(1.93488220322 + 34570.0663348526*t)
	X2 += 0.00000000012*np.cos(5.17033303670 + 337.732510659*t)
	X2 += 0.00000000013*np.cos(3.64691089977 + 131.4039498699*t)
	X2 += 0.00000000013*np.cos(3.14880532464 + 408.4389436113*t)
	X2 += 0.00000000013*np.cos(0.68541371817 + 22779.4372461938*t)
	X2 += 0.00000000012*np.cos(3.89742961770 + 31441.6775697568*t)
	X2 += 0.00000000015*np.cos(3.60443851725 + 29580.4747084438*t)
	X2 += 0.00000000012*np.cos(4.22650218163 + 963.4027029714*t)
	X2 += 0.00000000013*np.cos(3.99248913141 + 25934.1243310894*t)
	X2 += 0.00000000011*np.cos(0.02603069623 + 511.5317178299*t)
	X2 += 0.00000000010*np.cos(4.31465510142 + 547.8502123593*t)
	X2 += 0.00000000012*np.cos(3.50566249225 + 25158.6017197654*t)
	X2 += 0.00000000013*np.cos(0.73737685844 + 2111.6503133776*t)
	X2 += 0.00000000010*np.cos(4.67908297368 + 362.8622925726*t)
	X2 += 0.00000000010*np.cos(5.60218831936 + 127.4717966068*t)
	X2 += 0.00000000012*np.cos(0.78764611551 + 1685.0521225016*t)
	X2 += 0.00000000013*np.cos(4.91836873304 + 84.3428261229*t)
	X2 += 0.00000000010*np.cos(5.07263788261 + 934.9485149682*t)
	X2 += 0.00000000012*np.cos(2.66109784913 + 148.0787244263*t)
	X2 += 0.00000000009*np.cos(2.44042399381 + 153.4953503977*t)
	X2 += 0.00000000009*np.cos(0.14966079482 + 1382.8873468466*t)
	X2 += 0.00000000009*np.cos(3.35947600276 + 38500.2760310722*t)
	X2 += 0.00000000011*np.cos(3.37804748354 + 222.8603229936*t)
	X2 += 0.00000000008*np.cos(6.02198121081 + 92.940845832*t)
	X2 += 0.00000000009*np.cos(2.18518124277 + 269.9214467406*t)
	X2 += 0.00000000009*np.cos(3.55537703082 + 750.1036075334*t)
	X2 += 0.00000000010*np.cos(5.30797415249 + 436.8931316145*t)
	X2 += 0.00000000010*np.cos(1.54068644361 + 203.7378678824*t)
	X2 += 0.00000000010*np.cos(4.52809483758 + 643.0786800517*t)
	X2 += 0.00000000010*np.cos(4.26753045931 + 635.9651330509*t)
	X2 += 0.00000000009*np.cos(4.96082633163 + 29088.811415985*t)
	X2 += 0.00000000008*np.cos(3.50970266630 + 52.6901980395*t)
	X2 += 0.00000000008*np.cos(5.86771297817 + 131.5469622218*t)
	X2 += 0.00000000007*np.cos(4.10108572333 + 1603.2999892854*t)
	X2 += 0.00000000007*np.cos(1.94868342879 + 43232.3066584156*t)
	X2 += 0.00000000007*np.cos(1.87956392812 + 22805.7355659936*t)
	X2 += 0.00000000007*np.cos(6.01401596195 + 29999.959352319*t)
	X2 += 0.00000000007*np.cos(5.94489646128 + 9573.388259897*t)
	X2 += 0.00000000007*np.cos(0.40212847913 + 6681.2248533996*t)
	X2 += 0.00000000009*np.cos(2.22913614898 + 1279.794572628*t)
	X2 += 0.00000000007*np.cos(3.40501345577 + 30110.1656735384*t)
	X2 += 0.00000000007*np.cos(1.45088892995 + 483.2205421786*t)
	X2 += 0.00000000009*np.cos(1.10868456658 + 87.3117715395*t)
	X2 += 0.00000000008*np.cos(6.28154480422 + 721.6494195302*t)
	X2 += 0.00000000007*np.cos(4.14213787767 + 867.4234757536*t)
	X2 += 0.00000000008*np.cos(2.28858892249 + 1361.5467058442*t)
	return X2*t*t




def Venus_X3 (t): # 106 terms of order 3

	X3 = 0.
	X3 += 0.00000075614
	X3 += 0.00000022035*np.cos(6.11822426048 + 206.1855484372*t)
	X3 += 0.00000021482*np.cos(5.03368299703 + 220.4126424388*t)
	X3 += 0.00000019386*np.cos(5.23038243202 + 10213.285546211*t)
	X3 += 0.00000024718*np.cos(3.25340548805 + 20426.571092422*t)
	X3 += 0.00000016291*np.cos(2.71940457791 + 522.5774180938*t)
	X3 += 0.00000015934*np.cos(1.63320186413 + 536.8045120954*t)
	X3 += 0.00000003063*np.cos(3.80201225520 + 426.598190876*t)
	X3 += 0.00000002563*np.cos(4.04702837579 + 433.7117378768*t)
	X3 += 0.00000002101*np.cos(4.92786996750 + 227.5261894396*t)
	X3 += 0.00000001706*np.cos(0.42316599671 + 1059.3819301892*t)
	X3 += 0.00000001375*np.cos(2.83821817426 + 515.463871093*t)
	X3 += 0.00000001266*np.cos(5.37509106080 + 419.4846438752*t)
	X3 += 0.00000001038*np.cos(2.26994057258 + 1066.49547719*t)
	X3 += 0.00000001000*np.cos(6.26567671131 + 199.0720014364*t)
	X3 += 0.00000000964*np.cos(1.50782014667 + 543.9180590962*t)
	X3 += 0.00000001275*np.cos(0.02482955002 + 7.1135470008*t)
	X3 += 0.00000000845*np.cos(2.83708264275 + 639.897286314*t)
	X3 += 0.00000000678*np.cos(2.36507413871 + 1052.2683831884*t)
	X3 += 0.00000000623*np.cos(3.24709806895 + 30639.856638633*t)
	X3 += 0.00000000344*np.cos(1.24961127281 + 213.299095438*t)
	X3 += 0.00000000382*np.cos(6.20559320688 + 14.2270940016*t)
	X3 += 0.00000000291*np.cos(3.14472957178 + 647.0108333148*t)
	X3 += 0.00000000249*np.cos(1.14107482666 + 1589.0728952838*t)
	X3 += 0.00000000214*np.cos(4.03956747124 + 440.8252848776*t)
	X3 += 0.00000000230*np.cos(4.42377888159 + 216.4804891757*t)
	X3 += 0.00000000219*np.cos(0.47150010549 + 210.1177017003*t)
	X3 += 0.00000000129*np.cos(1.79919042809 + 1045.1548361876*t)
	X3 += 0.00000000123*np.cos(2.08253199617 + 853.196381752*t)
	X3 += 0.00000000092*np.cos(4.79503944157 + 234.6397364404*t)
	X3 += 0.00000000086*np.cos(6.10758245301 + 103.0927742186*t)
	X3 += 0.00000000091*np.cos(5.48002372488 + 117.3198682202*t)
	X3 += 0.00000000093*np.cos(5.08172811528 + 529.6909650946*t)
	X3 += 0.00000000075*np.cos(2.87101566525 + 1596.1864422846*t)
	X3 += 0.00000000069*np.cos(4.27897139677 + 95.9792272178*t)
	X3 += 0.00000000073*np.cos(6.02905465950 + 632.7837393132*t)
	X3 += 0.00000000077*np.cos(5.03142217150 + 412.3710968744*t)
	X3 += 0.00000000064*np.cos(3.94993325790 + 316.3918696566*t)
	X3 += 0.00000000056*np.cos(2.99558443348 + 508.3503240922*t)
	X3 += 0.00000000055*np.cos(3.29709092103 + 323.5054166574*t)
	X3 += 0.00000000048*np.cos(1.97191764285 + 1073.6090241908*t)
	X3 += 0.00000000056*np.cos(1.48325794833 + 735.8765135318*t)
	X3 += 0.00000000042*np.cos(1.41375480258 + 625.6701923124*t)
	X3 += 0.00000000039*np.cos(0.30611138474 + 942.062061969*t)
	X3 += 0.00000000036*np.cos(4.59308117276 + 209.3669421749*t)
	X3 += 0.00000000031*np.cos(2.46171091539 + 1581.959348283*t)
	X3 += 0.00000000031*np.cos(1.32072373030 + 551.031606097*t)
	X3 += 0.00000000032*np.cos(0.26519734656 + 217.2312487011*t)
	X3 += 0.00000000033*np.cos(2.32289510783 + 860.3099287528*t)
	X3 += 0.00000000028*np.cos(3.48885797103 + 330.6189636582*t)
	X3 += 0.00000000027*np.cos(3.92096513265 + 149.5631971346*t)
	X3 += 0.00000000029*np.cos(6.05526972992 + 70.8494453042*t)
	X3 += 0.00000000027*np.cos(1.63715408955 + 2118.7638603784*t)
	X3 += 0.00000000028*np.cos(1.74838965252 + 78.7137518304*t)
	X3 += 0.00000000029*np.cos(0.48147029137 + 949.1756089698*t)
	X3 += 0.00000000025*np.cos(4.58797131637 + 124.433415221*t)
	X3 += 0.00000000033*np.cos(4.30649710462 + 223.5940361765*t)
	X3 += 0.00000000032*np.cos(1.93089098387 + 110.2063212194*t)
	X3 += 0.00000000027*np.cos(6.02243954440 + 21.3406410024*t)
	X3 += 0.00000000025*np.cos(1.16107900100 + 1169.5882514086*t)
	X3 += 0.00000000024*np.cos(1.53395713354 + 63.7358983034*t)
	X3 += 0.00000000028*np.cos(1.56238914694 + 728.762966531*t)
	X3 += 0.00000000024*np.cos(3.16134826622 + 654.1243803156*t)
	X3 += 0.00000000023*np.cos(0.20728622886 + 191.9584544356*t)
	X3 += 0.00000000022*np.cos(2.15937343363 + 1155.361157407*t)
	X3 += 0.00000000019*np.cos(0.03186061495 + 85.8272988312*t)
	X3 += 0.00000000019*np.cos(0.95260076413 + 73.297125859*t)
	X3 += 0.00000000022*np.cos(5.27304712373 + 956.2891559706*t)
	X3 += 0.00000000024*np.cos(5.89117970906 + 309.2783226558*t)
	X3 += 0.00000000025*np.cos(3.51115533622 + 429.7795846137*t)
	X3 += 0.00000000024*np.cos(3.53027023690 + 519.3960243561*t)
	X3 += 0.00000000020*np.cos(1.86650914141 + 71.6002048296*t)
	X3 += 0.00000000017*np.cos(4.13765972175 + 88.865680217*t)
	X3 += 0.00000000019*np.cos(5.95485140431 + 77.962992305*t)
	X3 += 0.00000000016*np.cos(0.00550329231 + 202.2533951741*t)
	X3 += 0.00000000020*np.cos(0.77024887951 + 539.9859058331*t)
	X3 += 0.00000000015*np.cos(5.02720184968 + 224.3447957019*t)
	X3 += 0.00000000013*np.cos(0.64071359315 + 76.2660712756*t)
	X3 += 0.00000000016*np.cos(0.70623098744 + 203.0041546995*t)
	X3 += 0.00000000012*np.cos(0.84507236712 + 302.164775655*t)
	X3 += 0.00000000010*np.cos(5.28489326618 + 11.0457002639*t)
	X3 += 0.00000000010*np.cos(3.98008913039 + 36.6485629295*t)
	X3 += 0.00000000012*np.cos(3.35651610375 + 422.6660376129*t)
	X3 += 0.00000000009*np.cos(3.50226842635 + 39.6175083461*t)
	X3 += 0.00000000009*np.cos(3.72367923110 + 40853.142184844*t)
	X3 += 0.00000000009*np.cos(1.66650203128 + 1038.0412891868*t)
	X3 += 0.00000000009*np.cos(3.97946790815 + 447.9388318784*t)
	X3 += 0.00000000009*np.cos(3.09433206743 + 618.5566453116*t)
	X3 += 0.00000000008*np.cos(2.36406802666 + 838.9692877504*t)
	X3 += 0.00000000008*np.cos(0.38739265309 + 423.4167971383*t)
	X3 += 0.00000000009*np.cos(1.90795498674 + 1574.8458012822*t)
	X3 += 0.00000000007*np.cos(2.99983273700 + 1258.4539316256*t)
	X3 += 0.00000000007*np.cos(2.49966387854 + 831.8557407496*t)
	X3 += 0.00000000008*np.cos(3.95391486424 + 74.7815985673*t)
	X3 += 0.00000000006*np.cos(2.58853517839 + 138.5174968707*t)
	X3 += 0.00000000007*np.cos(0.08989351607 + 742.9900605326*t)
	X3 += 0.00000000006*np.cos(3.39896707822 + 2125.8774073792*t)
	X3 += 0.00000000005*np.cos(2.18119549382 + 145.6310438715*t)
	X3 += 0.00000000007*np.cos(0.58812910406 + 38.1330356378*t)
	X3 += 0.00000000005*np.cos(2.24425105188 + 195.1398481733*t)
	X3 += 0.00000000004*np.cos(2.85162994822 + 1265.5674786264*t)
	X3 += 0.00000000004*np.cos(3.42359216874 + 337.732510659*t)
	X3 += 0.00000000004*np.cos(2.02888732685 + 18.1592472647*t)
	X3 += 0.00000000005*np.cos(6.19237785082 + 3.9321532631*t)
	X3 += 0.00000000004*np.cos(0.27398248033 + 1485.9801210652*t)
	X3 += 0.00000000004*np.cos(4.28076500111 + 437.6438911399*t)
	return X3*t*t*t




def Venus_X4 (t): # 61 terms of order 4

	X4 = 0.
	X4 += 0.00000002272*np.cos(1.56364838180 + 206.1855484372*t)
	X4 += 0.00000002236*np.cos(3.28143366276 + 220.4126424388*t)
	X4 += 0.00000001682*np.cos(4.46996330708 + 522.5774180938*t)
	X4 += 0.00000001638*np.cos(6.17513895178 + 536.8045120954*t)
	X4 += 0.00000000946*np.cos(0.39076344760 + 10213.285546211*t)
	X4 -= 0.00000000636
	X4 += 0.00000000430*np.cos(3.20713267334 + 227.5261894396*t)
	X4 += 0.00000000348*np.cos(2.26681787351 + 433.7117378768*t)
	X4 += 0.00000000291*np.cos(4.56956279775 + 515.463871093*t)
	X4 += 0.00000000289*np.cos(0.95993858755 + 20426.571092422*t)
	X4 += 0.00000000206*np.cos(6.05364860885 + 543.9180590962*t)
	X4 += 0.00000000202*np.cos(1.69320982304 + 199.0720014364*t)
	X4 += 0.00000000123*np.cos(0.67135155073 + 1066.49547719*t)
	X4 += 0.00000000099*np.cos(0.99265774704 + 419.4846438752*t)
	X4 += 0.00000000113*np.cos(1.85695441801 + 426.598190876*t)
	X4 += 0.00000000080*np.cos(4.55016686641 + 7.1135470008*t)
	X4 += 0.00000000062*np.cos(4.48609878362 + 14.2270940016*t)
	X4 += 0.00000000053*np.cos(4.95103975600 + 1059.3819301892*t)
	X4 += 0.00000000066*np.cos(4.20375595982 + 1052.2683831884*t)
	X4 += 0.00000000050*np.cos(2.28699829686 + 440.8252848776*t)
	X4 += 0.00000000060*np.cos(0.97558287548 + 639.897286314*t)
	X4 += 0.00000000049*np.cos(1.31593641965 + 647.0108333148*t)
	X4 += 0.00000000031*np.cos(6.26226050601 + 213.299095438*t)
	X4 += 0.00000000030*np.cos(0.98741714872 + 30639.856638633*t)
	X4 += 0.00000000024*np.cos(3.05754167589 + 234.6397364404*t)
	X4 += 0.00000000023*np.cos(3.61004405073 + 1045.1548361876*t)
	X4 += 0.00000000014*np.cos(4.76472781912 + 508.3503240922*t)
	X4 += 0.00000000013*np.cos(6.04976474685 + 1589.0728952838*t)
	X4 += 0.00000000011*np.cos(0.54626079593 + 412.3710968744*t)
	X4 += 0.00000000012*np.cos(0.15818608564 + 853.196381752*t)
	X4 += 0.00000000010*np.cos(0.31907502124 + 1073.6090241908*t)
	X4 += 0.00000000010*np.cos(1.35560891851 + 1596.1864422846*t)
	X4 += 0.00000000009*np.cos(4.24672231397 + 21.3406410024*t)
	X4 += 0.00000000011*np.cos(3.71353247018 + 117.3198682202*t)
	X4 += 0.00000000008*np.cos(1.50012562224 + 103.0927742186*t)
	X4 += 0.00000000007*np.cos(6.08752157484 + 95.9792272178*t)
	X4 += 0.00000000007*np.cos(6.27374846424 + 529.6909650946*t)
	X4 += 0.00000000007*np.cos(5.71854398962 + 551.031606097*t)
	X4 += 0.00000000006*np.cos(1.40413206867 + 654.1243803156*t)
	X4 += 0.00000000005*np.cos(2.81686507397 + 124.433415221*t)
	X4 += 0.00000000005*np.cos(3.21271191075 + 625.6701923124*t)
	X4 += 0.00000000006*np.cos(0.43509868093 + 860.3099287528*t)
	X4 += 0.00000000004*np.cos(1.55213484100 + 632.7837393132*t)
	X4 += 0.00000000005*np.cos(3.17881881452 + 728.762966531*t)
	X4 += 0.00000000004*np.cos(1.76651819729 + 330.6189636582*t)
	X4 += 0.00000000005*np.cos(2.10225977593 + 942.062061969*t)
	X4 += 0.00000000004*np.cos(5.76705671645 + 88.865680217*t)
	X4 += 0.00000000004*np.cos(3.27648798915 + 735.8765135318*t)
	X4 += 0.00000000003*np.cos(4.78415680549 + 618.5566453116*t)
	X4 += 0.00000000003*np.cos(0.90449193126 + 110.2063212194*t)
	X4 += 0.00000000003*np.cos(2.17395214560 + 447.9388318784*t)
	X4 += 0.00000000003*np.cos(4.27605231904 + 1581.959348283*t)
	X4 += 0.00000000003*np.cos(1.69135933489 + 323.5054166574*t)
	X4 += 0.00000000002*np.cos(5.71553727369 + 1169.5882514086*t)
	X4 += 0.00000000003*np.cos(2.34507379864 + 191.9584544356*t)
	X4 += 0.00000000002*np.cos(3.94362184472 + 1155.361157407*t)
	X4 += 0.00000000002*np.cos(1.55420041399 + 429.7795846137*t)
	X4 += 0.00000000003*np.cos(2.59535343316 + 302.164775655*t)
	X4 += 0.00000000002*np.cos(5.59314231958 + 316.3918696566*t)
	X4 += 0.00000000002*np.cos(3.65310721758 + 831.8557407496*t)
	X4 += 0.00000000002*np.cos(1.87311938884 + 309.2783226558*t)
	return X4*t*t*t*t




def Venus_X5 (t): # 32 terms of order 5

	X5 = 0.
	X5 += 0.00000000168*np.cos(3.28069809842 + 206.1855484372*t)
	X5 += 0.00000000167*np.cos(1.52399958265 + 220.4126424388*t)
	X5 += 0.00000000126*np.cos(0.07122523863 + 522.5774180938*t)
	X5 += 0.00000000121*np.cos(4.30466267493 + 536.8045120954*t)
	X5 += 0.00000000064*np.cos(1.46493444949 + 227.5261894396*t)
	X5 -= 0.00000000063
	X5 += 0.00000000047*np.cos(0.05687052745 + 515.463871093*t)
	X5 += 0.00000000037*np.cos(0.48304760543 + 433.7117378768*t)
	X5 += 0.00000000032*np.cos(4.26961178617 + 543.9180590962*t)
	X5 += 0.00000000028*np.cos(3.41370273509 + 199.0720014364*t)
	X5 += 0.00000000029*np.cos(1.94730457757 + 10213.285546211*t)
	X5 += 0.00000000022*np.cos(0.34341584207 + 20426.571092422*t)
	X5 += 0.00000000011*np.cos(2.75798781903 + 14.2270940016*t)
	X5 += 0.00000000011*np.cos(5.33499883960 + 1066.49547719*t)
	X5 += 0.00000000010*np.cos(0.51443337467 + 440.8252848776*t)
	X5 += 0.00000000007*np.cos(5.80467663011 + 647.0108333148*t)
	X5 += 0.00000000004*np.cos(0.20088280204 + 1052.2683831884*t)
	X5 += 0.00000000004*np.cos(3.59221465704 + 419.4846438752*t)
	X5 += 0.00000000003*np.cos(5.43212710597 + 639.897286314*t)
	X5 += 0.00000000003*np.cos(1.37528056638 + 234.6397364404*t)
	X5 += 0.00000000002*np.cos(0.38337547624 + 191.9584544356*t)
	X5 += 0.00000000002*np.cos(5.49829989028 + 426.598190876*t)
	X5 += 0.00000000002*np.cos(4.89397151114 + 1073.6090241908*t)
	X5 += 0.00000000002*np.cos(6.21263006019 + 1045.1548361876*t)
	X5 += 0.00000000001*np.cos(1.31653362066 + 88.865680217*t)
	X5 += 0.00000000001*np.cos(5.40855784676 + 405.2575498736*t)
	X5 += 0.00000000001*np.cos(5.90670816840 + 654.1243803156*t)
	X5 += 0.00000000001*np.cos(3.71891583567 + 302.164775655*t)
	X5 += 0.00000000001*np.cos(4.55685868846 + 853.196381752*t)
	X5 += 0.00000000001*np.cos(3.69401301909 + 213.299095438*t)
	X5 += 0.00000000001*np.cos(5.15663977426 + 7.1135470008*t)
	X5 += 0.00000000001*np.cos(0.75807081859 + 124.433415221*t)
	return X5*t*t*t*t*t




def Venus_Y0 (t): # 972 terms of order 0

	Y0 = 0.
	Y0 += 0.72324643689*np.cos(1.60573808356 + 10213.285546211*t)
	Y0 -= 0.00515636737
	Y0 += 0.00494765697*np.cos(2.17048019743 + 529.6909650946*t)
	Y0 += 0.00244884190*np.cos(2.48564953999 + 20426.571092422*t)
	Y0 += 0.00272138024*np.cos(2.44443638845 + 213.299095438*t)
	Y0 += 0.00155443844*np.cos(0.59927014146 + 38.1330356378*t)
	Y0 += 0.00083754576*np.cos(0.76880143132 + 74.7815985673*t)
	Y0 += 0.00011913202*np.cos(2.51387064934 + 1059.3819301892*t)
	Y0 += 0.00007588666*np.cos(1.66926320091 + 426.598190876*t)
	Y0 += 0.00002789807*np.cos(5.04214523606 + 2352.8661537718*t)
	Y0 += 0.00001963479*np.cos(5.70770249220 + 206.1855484372*t)
	Y0 += 0.00001891167*np.cos(2.32097062559 + 220.4126424388*t)
	Y0 += 0.00001940366*np.cos(3.22701063208 + 149.5631971346*t)
	Y0 += 0.00001933868*np.cos(5.80597990261 + 1577.3435424478*t)
	Y0 += 0.00001434763*np.cos(2.30169867665 + 522.5774180938*t)
	Y0 += 0.00001403769*np.cos(5.18861278314 + 536.8045120954*t)
	Y0 += 0.00001185430*np.cos(5.48948269493 + 76.2660712756*t)
	Y0 += 0.00001243658*np.cos(3.36573697344 + 30639.856638633*t)
	Y0 += 0.00001164480*np.cos(1.30970620277 + 18073.7049386502*t)
	Y0 += 0.00000813077*np.cos(1.68393442622 + 36.6485629295*t)
	Y0 += 0.00000767125*np.cos(2.65620459324 + 39.6175083461*t)
	Y0 += 0.00000737860*np.cos(0.18072791294 + 6283.0758499914*t)
	Y0 += 0.00000670527*np.cos(6.17032430376 + 14143.4952424306*t)
	Y0 += 0.00000657675*np.cos(5.21360427049 + 8635.9420037632*t)
	Y0 += 0.00000628788*np.cos(4.99295631526 + 73.297125859*t)
	Y0 += 0.00000477182*np.cos(4.27309387857 + 10186.9872264112*t)
	Y0 += 0.00000475690*np.cos(2.08026660779 + 10239.5838660108*t)
	Y0 += 0.00000427334*np.cos(2.84919088443 + 1589.0728952838*t)
	Y0 += 0.00000559632*np.cos(5.87842445808 + 22003.9146348698*t)
	Y0 += 0.00000542381*np.cos(1.15040078193 + 11790.6290886588*t)
	Y0 += 0.00000363333*np.cos(3.56904503253 + 7.1135470008*t)
	Y0 += 0.00000367778*np.cos(2.17623939625 + 9437.762934887*t)
	Y0 += 0.00000407052*np.cos(2.35411923107 + 775.522611324*t)
	Y0 += 0.00000317467*np.cos(4.53507429606 + 419.4846438752*t)
	Y0 += 0.00000309795*np.cos(0.92057667546 + 639.897286314*t)
	Y0 += 0.00000287191*np.cos(3.36143652299 + 110.2063212194*t)
	Y0 += 0.00000275646*np.cos(1.23968348521 + 9683.5945811164*t)
	Y0 += 0.00000268898*np.cos(5.13218653673 + 10742.9765113056*t)
	Y0 += 0.00000302219*np.cos(0.94310085463 + 5507.5532386674*t)
	Y0 += 0.00000267816*np.cos(0.29070003895 + 103.0927742186*t)
	Y0 += 0.00000214308*np.cos(5.46213453424 + 10021.8372800994*t)
	Y0 += 0.00000241591*np.cos(4.23657289457 + 10988.808157535*t)
	Y0 += 0.00000207456*np.cos(0.88354754907 + 10404.7338123226*t)
	Y0 += 0.00000274181*np.cos(0.42777141449 + 9153.9036160218*t)
	Y0 += 0.00000271427*np.cos(1.05376720660 + 19896.8801273274*t)
	Y0 += 0.00000213406*np.cos(4.22098458474 + 316.3918696566*t)
	Y0 += 0.00000175993*np.cos(1.40721119359 + 191.4482661116*t)
	Y0 += 0.00000154080*np.cos(3.78432893453 + 4705.7323075436*t)
	Y0 += 0.00000146618*np.cos(3.98848869231 + 19651.048481098*t)
	Y0 += 0.00000138629*np.cos(0.43043658246 + 1.4844727083*t)
	Y0 += 0.00000112370*np.cos(0.85361972526 + 632.7837393132*t)
	Y0 += 0.00000105561*np.cos(1.55141487704 + 433.7117378768*t)
	Y0 += 0.00000097825*np.cos(1.45604337842 + 1052.2683831884*t)
	Y0 += 0.00000108349*np.cos(1.58713111946 + 1162.4747044078*t)
	Y0 += 0.00000069607*np.cos(4.80578213159 + 9103.9069941176*t)
	Y0 += 0.00000069030*np.cos(5.52848982683 + 1066.49547719*t)
	Y0 += 0.00000062765*np.cos(1.56960357113 + 11322.6640983044*t)
	Y0 += 0.00000080946*np.cos(2.57565274435 + 15720.8387848784*t)
	Y0 += 0.00000058886*np.cos(1.48624205515 + 20618.0193585336*t)
	Y0 += 0.00000056409*np.cos(6.03069527264 + 949.1756089698*t)
	Y0 += 0.00000069363*np.cos(3.69964170363 + 13367.9726311066*t)
	Y0 += 0.00000060880*np.cos(2.21481236691 + 4551.9534970588*t)
	Y0 += 0.00000065869*np.cos(4.98944094696 + 846.0828347512*t)
	Y0 += 0.00000063109*np.cos(4.22325583135 + 148.0787244263*t)
	Y0 += 0.00000046449*np.cos(5.23328801608 + 10192.5101507186*t)
	Y0 += 0.00000046324*np.cos(1.11900673339 + 10234.0609417034*t)
	Y0 += 0.00000063123*np.cos(5.44446058384 + 224.3447957019*t)
	Y0 += 0.00000062214*np.cos(1.01972067969 + 25934.1243310894*t)
	Y0 += 0.00000050886*np.cos(0.04577660930 + 8624.2126509272*t)
	Y0 += 0.00000045635*np.cos(0.06422916339 + 19367.1891622328*t)
	Y0 += 0.00000057305*np.cos(2.21379435263 + 3154.6870848956*t)
	Y0 += 0.00000043008*np.cos(4.77406484115 + 11015.1064773348*t)
	Y0 += 0.00000040191*np.cos(1.64117305351 + 9411.4646150872*t)
	Y0 += 0.00000039695*np.cos(3.21219423570 + 801.8209311238*t)
	Y0 += 0.00000045195*np.cos(0.48101910280 + 29580.4747084438*t)
	Y0 += 0.00000036983*np.cos(2.82425916202 + 7058.5984613154*t)
	Y0 += 0.00000034784*np.cos(3.03113665420 + 35.1640902212*t)
	Y0 += 0.00000028623*np.cos(3.35612170637 + 1109.3785520934*t)
	Y0 += 0.00000030361*np.cos(2.65126296125 + 11.0457002639*t)
	Y0 += 0.00000032033*np.cos(4.14384371647 + 15874.6175953632*t)
	Y0 += 0.00000036570*np.cos(2.34542445828 + 9999.986450773*t)
	Y0 += 0.00000037215*np.cos(1.48907281159 + 3340.6124266998*t)
	Y0 += 0.00000035385*np.cos(4.01098677439 + 10426.584641649*t)
	Y0 += 0.00000026683*np.cos(4.05505010621 + 7860.4193924392*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000031203*np.cos(5.14153242529 + 17298.1823273262*t)
	Y0 += 0.00000028733*np.cos(2.14315245629 + 151.0476698429*t)
	Y0 += 0.00000027688*np.cos(5.44433605847 + 63.7358983034*t)
	Y0 += 0.00000023815*np.cos(2.19051967809 + 227.5261894396*t)
	Y0 += 0.00000020281*np.cos(1.13139072441 + 10220.3990932118*t)
	Y0 += 0.00000020203*np.cos(5.21881955034 + 10206.1719992102*t)
	Y0 += 0.00000023457*np.cos(0.09576335036 + 71.8126531507*t)
	Y0 += 0.00000023256*np.cos(5.18050538435 + 85.8272988312*t)
	Y0 += 0.00000021268*np.cos(1.37799999997 + 3128.3887650958*t)
	Y0 += 0.00000018029*np.cos(3.17523041625 + 2118.7638603784*t)
	Y0 += 0.00000018884*np.cos(0.61668932816 + 26.2983197998*t)
	Y0 += 0.00000022104*np.cos(2.36649230999 + 2.9689454166*t)
	Y0 += 0.00000021981*np.cos(4.82484958838 + 77.7505439839*t)
	Y0 += 0.00000020052*np.cos(2.45637769313 + 209.3669421749*t)
	Y0 += 0.00000019691*np.cos(5.58713076986 + 217.2312487011*t)
	Y0 += 0.00000015682*np.cos(3.70800811377 + 742.9900605326*t)
	Y0 += 0.00000018552*np.cos(4.31061638297 + 202.2533951741*t)
	Y0 += 0.00000018318*np.cos(1.49471267476 + 323.5054166574*t)
	Y0 += 0.00000019675*np.cos(1.34966583849 + 3930.2096962196*t)
	Y0 += 0.00000017492*np.cos(1.45131471586 + 138.5174968707*t)
	Y0 += 0.00000015554*np.cos(1.06805925164 + 735.8765135318*t)
	Y0 += 0.00000015545*np.cos(2.44244738845 + 515.463871093*t)
	Y0 += 0.00000016441*np.cos(0.25514103996 + 853.196381752*t)
	Y0 += 0.00000017677*np.cos(1.74739410911 + 3532.0606928114*t)
	Y0 += 0.00000015237*np.cos(2.81371933371 + 9830.3890139878*t)
	Y0 += 0.00000017691*np.cos(3.60800987998 + 7084.8967811152*t)
	Y0 += 0.00000013327*np.cos(5.53453199388 + 5661.3320491522*t)
	Y0 += 0.00000014371*np.cos(3.52598338070 + 10596.1820784342*t)
	Y0 += 0.00000016090*np.cos(0.78654424919 + 20213.271996984*t)
	Y0 += 0.00000011121*np.cos(2.20216490389 + 28286.9904848612*t)
	Y0 += 0.00000014763*np.cos(2.49676145619 + 29864.334027309*t)
	Y0 += 0.00000014712*np.cos(2.29133684995 + 23581.2581773176*t)
	Y0 += 0.00000011595*np.cos(5.83451477433 + 199.0720014364*t)
	Y0 += 0.00000010833*np.cos(5.05422968004 + 543.9180590962*t)
	Y0 += 0.00000011585*np.cos(5.32336141881 + 525.7588118315*t)
	Y0 += 0.00000009394*np.cos(5.33533491552 + 11272.6674764002*t)
	Y0 += 0.00000011435*np.cos(2.15573411853 + 533.6231183577*t)
	Y0 += 0.00000010763*np.cos(5.94541303751 + 9929.4262273458*t)
	Y0 += 0.00000008797*np.cos(2.17920528527 + 12566.1516999828*t)
	Y0 += 0.00000007830*np.cos(0.86240453613 + 1478.8665740644*t)
	Y0 += 0.00000008761*np.cos(0.11029927382 + 29050.7837433492*t)
	Y0 += 0.00000010378*np.cos(0.40689057274 + 10497.1448650762*t)
	Y0 += 0.00000007445*np.cos(3.28642860734 + 21535.9496445154*t)
	Y0 += 0.00000007498*np.cos(4.24533507981 + 40853.142184844*t)
	Y0 += 0.00000007389*np.cos(5.51255095771 + 16496.3613962024*t)
	Y0 += 0.00000008792*np.cos(5.18118052529 + 10207.7626219036*t)
	Y0 += 0.00000008786*np.cos(1.17109977659 + 10218.8084705184*t)
	Y0 += 0.00000007196*np.cos(1.94802350337 + 216.4804891757*t)
	Y0 += 0.00000008154*np.cos(1.94122863440 + 1692.1656695024*t)
	Y0 += 0.00000009913*np.cos(6.14997101823 + 9786.687355335*t)
	Y0 += 0.00000007036*np.cos(6.09743344991 + 210.1177017003*t)
	Y0 += 0.00000007148*np.cos(0.89057242152 + 415.5524906121*t)
	Y0 += 0.00000006899*np.cos(2.82570489004 + 117.3198682202*t)
	Y0 += 0.00000007423*np.cos(2.59067946967 + 10175.2578735752*t)
	Y0 += 0.00000007386*np.cos(3.76162101633 + 10251.3132188468*t)
	Y0 += 0.00000007206*np.cos(2.48107180970 + 1265.5674786264*t)
	Y0 += 0.00000006884*np.cos(1.29204559424 + 956.2891559706*t)
	Y0 += 0.00000008148*np.cos(3.12774143805 + 18837.49819713819*t)
	Y0 += 0.00000006728*np.cos(5.95684074920 + 8094.5216858326*t)
	Y0 += 0.00000007393*np.cos(3.42626457157 + 14.2270940016*t)
	Y0 += 0.00000006531*np.cos(5.88279509445 + 20419.45754542119*t)
	Y0 += 0.00000005882*np.cos(0.45870719779 + 32217.2001810808*t)
	Y0 += 0.00000006604*np.cos(0.80525786731 + 647.0108333148*t)
	Y0 += 0.00000005728*np.cos(0.74065551442 + 24356.7807886416*t)
	Y0 += 0.00000007293*np.cos(1.69359367608 + 1581.959348283*t)
	Y0 += 0.00000007040*np.cos(0.48482036852 + 95.9792272178*t)
	Y0 += 0.00000006330*np.cos(3.87859376833 + 70.8494453042*t)
	Y0 += 0.00000005078*np.cos(2.67641304277 + 526.5095713569*t)
	Y0 += 0.00000004977*np.cos(4.80328860665 + 532.8723588323*t)
	Y0 += 0.00000004944*np.cos(2.08956957827 + 3149.1641605882*t)
	Y0 += 0.00000005879*np.cos(0.79782511263 + 78.7137518304*t)
	Y0 += 0.00000005640*np.cos(3.95018415563 + 382.8965322232*t)
	Y0 += 0.00000004593*np.cos(1.06358355759 + 14765.2390432698*t)
	Y0 += 0.00000006103*np.cos(4.10884733063 + 111.4301614968*t)
	Y0 += 0.00000004701*np.cos(4.97985542466 + 18849.2275499742*t)
	Y0 += 0.00000005507*np.cos(1.80406867812 + 25158.6017197654*t)
	Y0 += 0.00000005495*np.cos(1.72074788403 + 17085.9586657222*t)
	Y0 += 0.00000004361*np.cos(5.32253972289 + 1375.7737998458*t)
	Y0 += 0.00000005326*np.cos(3.83237566744 + 33794.5437235286*t)
	Y0 += 0.00000005089*np.cos(0.10337236315 + 14945.3161735544*t)
	Y0 += 0.00000004423*np.cos(6.24070525621 + 277.0349937414*t)
	Y0 += 0.00000004713*np.cos(3.21489250017 + 114.3991069134*t)
	Y0 += 0.00000003978*np.cos(1.32528412563 + 13745.3462390224*t)
	Y0 += 0.00000005182*np.cos(0.28726404719 + 222.8603229936*t)
	Y0 += 0.00000003686*np.cos(5.86108668094 + 1596.1864422846*t)
	Y0 += 0.00000004659*np.cos(1.22404458937 + 20452.8694122218*t)
	Y0 += 0.00000003694*np.cos(5.09796980483 + 6681.2248533996*t)
	Y0 += 0.00000004577*np.cos(5.47618219772 + 146.594251718*t)
	Y0 += 0.00000003998*np.cos(4.65648271949 + 4732.0306273434*t)
	Y0 += 0.00000004330*np.cos(1.83563721109 + 23958.6317852334*t)
	Y0 += 0.00000003477*np.cos(5.05468526636 + 1551.045222648*t)
	Y0 += 0.00000002830*np.cos(5.36742188515 + 309.2783226558*t)
	Y0 += 0.00000003761*np.cos(5.75801604585 + 490.3340891794*t)
	Y0 += 0.00000002949*np.cos(1.25283495999 + 10198.033075026*t)
	Y0 += 0.00000002944*np.cos(5.09946217029 + 10228.538017396*t)
	Y0 += 0.00000003221*np.cos(5.14877320147 + 20400.2727726222*t)
	Y0 += 0.00000002820*np.cos(1.86334392833 + 299.1263942692*t)
	Y0 += 0.00000003317*np.cos(1.49275898018 + 18875.525869774*t)
	Y0 += 0.00000002888*np.cos(2.65887654829 + 18307.8072320436*t)
	Y0 += 0.00000003425*np.cos(0.95244785238 + 351.8165923087*t)
	Y0 += 0.00000002743*np.cos(0.21013076684 + 5481.2549188676*t)
	Y0 += 0.00000003422*np.cos(3.20260172773 + 29088.811415985*t)
	Y0 += 0.00000003167*np.cos(3.72833942933 + 27511.4678735372*t)
	Y0 += 0.00000002922*np.cos(5.30505468617 + 109.9456887885*t)
	Y0 += 0.00000002431*np.cos(2.28525105333 + 30110.1656735384*t)
	Y0 += 0.00000002308*np.cos(1.19399794720 + 6872.6731195112*t)
	Y0 += 0.00000002471*np.cos(1.29713026645 + 625.6701923124*t)
	Y0 += 0.00000002306*np.cos(2.32729148663 + 3442.5749449654*t)
	Y0 += 0.00000002424*np.cos(5.68140954809 + 20956.2620575166*t)
	Y0 += 0.00000002371*np.cos(5.80250598790 + 3.9321532631*t)
	Y0 += 0.00000002376*np.cos(5.99390031067 + 8662.240323563*t)
	Y0 += 0.00000002431*np.cos(2.10516277403 + 21228.3920235458*t)
	Y0 += 0.00000002601*np.cos(2.22431686363 + 9580.5018068978*t)
	Y0 += 0.00000001984*np.cos(4.11155161070 + 17277.4069318338*t)
	Y0 += 0.00000002044*np.cos(5.75289655241 + 19999.97290154599*t)
	Y0 += 0.00000002547*np.cos(4.75277405496 + 1169.5882514086*t)
	Y0 += 0.00000002100*np.cos(5.81905329229 + 28521.0927782546*t)
	Y0 += 0.00000002010*np.cos(5.27974132127 + 21202.093703746*t)
	Y0 += 0.00000002471*np.cos(4.17663285501 + 10846.0692855242*t)
	Y0 += 0.00000001988*np.cos(4.08614647864 + 20809.4676246452*t)
	Y0 += 0.00000002285*np.cos(1.22344285748 + 1045.1548361876*t)
	Y0 += 0.00000002188*np.cos(4.41129276996 + 9967.4538999816*t)
	Y0 += 0.00000002278*np.cos(3.53119029368 + 10316.3783204296*t)
	Y0 += 0.00000002278*np.cos(2.82110310010 + 10110.1927719924*t)
	Y0 += 0.00000001804*np.cos(2.43206099970 + 22779.4372461938*t)
	Y0 += 0.00000002118*np.cos(1.94080328198 + 10459.1171924404*t)
	Y0 += 0.00000002260*np.cos(0.59802721740 + 9573.388259897*t)
	Y0 += 0.00000001753*np.cos(5.10951080278 + 13553.8979729108*t)
	Y0 += 0.00000001766*np.cos(4.70160896115 + 7064.1213856228*t)
	Y0 += 0.00000002093*np.cos(2.69264168456 + 9690.7081281172*t)
	Y0 += 0.00000001913*np.cos(1.75777087654 + 1155.361157407*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000001649*np.cos(1.44498561983 + 440.8252848776*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001962*np.cos(3.66416649367 + 10735.8629643048*t)
	Y0 += 0.00000001483*np.cos(4.31350753488 + 3723.508958923*t)
	Y0 += 0.00000002074*np.cos(4.62137633405 + 33019.0211122046*t)
	Y0 += 0.00000001480*np.cos(4.20172565416 + 16983.9961474566*t)
	Y0 += 0.00000001976*np.cos(5.25155661903 + 37724.7534197482*t)
	Y0 += 0.00000001439*np.cos(6.16071128287 + 942.062061969*t)
	Y0 += 0.00000001487*np.cos(4.35858219478 + 412.3710968744*t)
	Y0 += 0.00000001472*np.cos(5.58089341541 + 6770.7106012456*t)
	Y0 += 0.00000001659*np.cos(0.00230055843 + 20235.1228263104*t)
	Y0 += 0.00000001873*np.cos(6.21486910777 + 30213.258447757*t)
	Y0 += 0.00000001542*np.cos(2.45181007185 + 6489.776587288*t)
	Y0 += 0.00000001360*np.cos(4.22919267004 + 10232.95530711079*t)
	Y0 += 0.00000001360*np.cos(2.12310072374 + 10193.61578531121*t)
	Y0 += 0.00000001428*np.cos(4.17962469716 + 65.2203710117*t)
	Y0 += 0.00000001567*np.cos(3.66460689276 + 9146.790069021*t)
	Y0 += 0.00000001592*np.cos(0.91871579673 + 10288.0671447783*t)
	Y0 += 0.00000001592*np.cos(5.43357759705 + 10138.5039476437*t)
	Y0 += 0.00000001257*np.cos(3.93598172725 + 9793.8009023358*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001232*np.cos(5.36389077993 + 20.7753954924*t)
	Y0 += 0.00000001560*np.cos(1.27586109556 + 10529.6774158676*t)
	Y0 += 0.00000001560*np.cos(5.07643229822 + 9896.8936765544*t)
	Y0 += 0.00000001178*np.cos(4.45247045018 + 14919.0178537546*t)
	Y0 += 0.00000001158*np.cos(2.28822825043 + 10632.7701900862*t)
	Y0 += 0.00000001485*np.cos(6.11611294959 + 210.8514148832*t)
	Y0 += 0.00000001473*np.cos(1.91659379347 + 215.7467759928*t)
	Y0 += 0.00000001422*np.cos(4.41813139873 + 225.8292684102*t)
	Y0 += 0.00000001254*np.cos(5.80795879481 + 2379.1644735716*t)
	Y0 += 0.00000001237*np.cos(1.11516406327 + 12592.4500197826*t)
	Y0 += 0.00000001091*np.cos(1.25744389434 + 422.6660376129*t)
	Y0 += 0.00000001402*np.cos(3.43281150113 + 10639.883737087*t)
	Y0 += 0.00000001435*np.cos(0.39193883021 + 9161.0171630226*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001019*np.cos(5.67612773072 + 145.6310438715*t)
	Y0 += 0.00000001421*np.cos(0.83890525684 + 152.5321425512*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001031*np.cos(1.65365925948 + 1795.258443721*t)
	Y0 += 0.00000000977*np.cos(0.76357046359 + 84.3428261229*t)
	Y0 += 0.00000000964*np.cos(4.63043034198 + 1272.6810256272*t)
	Y0 += 0.00000001076*np.cos(5.29118995114 + 212.3358875915*t)
	Y0 += 0.00000001071*np.cos(2.73962355675 + 214.2623032845*t)
	Y0 += 0.00000001192*np.cos(2.95601574230 + 39264.0692895602*t)
	Y0 += 0.00000001010*np.cos(5.80804230901 + 10007.0999977738*t)
	Y0 += 0.00000001008*np.cos(0.55046820997 + 10419.4710946482*t)
	Y0 += 0.00000001243*np.cos(1.30343744920 + 184.7272873558*t)
	Y0 += 0.00000001269*np.cos(6.03842899487 + 36949.2308084242*t)
	Y0 += 0.00000001187*np.cos(5.04350394974 + 31441.6775697568*t)
	Y0 += 0.00000000891*np.cos(2.41639607024 + 213.2509113282*t)
	Y0 += 0.00000000890*np.cos(5.61419511254 + 213.3472795478*t)
	Y0 += 0.00000000995*np.cos(2.96746942556 + 13341.6743113068*t)
	Y0 += 0.00000001041*np.cos(4.23685547840 + 137.0330241624*t)
	Y0 += 0.00000001120*np.cos(0.26190073863 + 245.8316462294*t)
	Y0 += 0.00000000968*np.cos(2.96119647882 + 437.6438911399*t)
	Y0 += 0.00000000812*np.cos(0.69907573293 + 288.0806940053*t)
	Y0 += 0.00000000819*np.cos(5.28403120371 + 529.6427809848*t)
	Y0 += 0.00000000819*np.cos(2.19867289777 + 529.7391492044*t)
	Y0 += 0.00000000923*np.cos(5.72786765148 + 26087.9031415742*t)
	Y0 += 0.00000000826*np.cos(3.48401474650 + 2648.454825473*t)
	Y0 += 0.00000001037*np.cos(2.70514798372 + 527.2432845398*t)
	Y0 += 0.00000001029*np.cos(4.77626567802 + 532.1386456494*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000761*np.cos(5.59004416449 + 7564.830720738*t)
	Y0 += 0.00000000776*np.cos(2.50668810243 + 203.7378678824*t)
	Y0 += 0.00000000786*np.cos(0.51228624161 + 11764.330768859*t)
	Y0 += 0.00000000734*np.cos(3.78800004602 + 112.9146342051*t)
	Y0 += 0.00000000795*np.cos(1.85352659217 + 10750.0900583064*t)
	Y0 += 0.00000000769*np.cos(5.39709006967 + 7834.1210726394*t)
	Y0 += 0.00000000784*np.cos(4.48666174060 + 9676.4810341156*t)
	Y0 += 0.00000000711*np.cos(0.35309558162 + 628.8515860501*t)
	Y0 += 0.00000000695*np.cos(1.82001334483 + 36147.4098773004*t)
	Y0 += 0.00000000845*np.cos(3.16389685660 + 22805.7355659936*t)
	Y0 += 0.00000000925*np.cos(1.39948133634 + 160.6088973985*t)
	Y0 += 0.00000000663*np.cos(3.47906442185 + 1368.660252845*t)
	Y0 += 0.00000000787*np.cos(4.31922872731 + 19889.76658032659*t)
	Y0 += 0.00000000798*np.cos(3.51175121692 + 13936.794505134*t)
	Y0 += 0.00000000742*np.cos(1.23961445295 + 9.5612275556*t)
	Y0 += 0.00000000647*np.cos(1.38461879483 + 2008.557539159*t)
	Y0 += 0.00000000789*np.cos(4.89377019350 + 7994.5284420242*t)
	Y0 += 0.00000000624*np.cos(1.27677428473 + 39793.7602546548*t)
	Y0 += 0.00000000875*np.cos(3.77647530400 + 380.12776796*t)
	Y0 += 0.00000000599*np.cos(1.67376937095 + 2111.6503133776*t)
	Y0 += 0.00000000808*np.cos(0.37657594142 + 41654.9631159678*t)
	Y0 += 0.00000000619*np.cos(5.21680002932 + 430.5303441391*t)
	Y0 += 0.00000000744*np.cos(0.94447044889 + 19903.99367432819*t)
	Y0 += 0.00000000661*np.cos(2.90920830849 + 1063.3140834523*t)
	Y0 += 0.00000000663*np.cos(2.12818812670 + 838.9692877504*t)
	Y0 += 0.00000000783*np.cos(1.17537914975 + 40879.4405046438*t)
	Y0 += 0.00000000598*np.cos(5.09026310864 + 423.4167971383*t)
	Y0 += 0.00000000633*np.cos(1.58661078881 + 12.5301729722*t)
	Y0 += 0.00000000647*np.cos(1.86412144751 + 528.7277572481*t)
	Y0 += 0.00000000646*np.cos(5.61853780158 + 530.6541729411*t)
	Y0 += 0.00000000547*np.cos(2.31713581375 + 2221.856634597*t)
	Y0 += 0.00000000541*np.cos(5.63219919123 + 1055.4497769261*t)
	Y0 += 0.00000000686*np.cos(1.54143807247 + 12432.0426503978*t)
	Y0 += 0.00000000672*np.cos(1.51129840313 + 221.3758502853*t)
	Y0 += 0.00000000490*np.cos(1.40385202337 + 71.6002048296*t)
	Y0 += 0.00000000647*np.cos(4.49596793914 + 26735.9452622132*t)
	Y0 += 0.00000000605*np.cos(3.06366110276 + 10059.5067357262*t)
	Y0 += 0.00000000503*np.cos(2.26978085577 + 17778.11626694899*t)
	Y0 += 0.00000000676*np.cos(3.63142919749 + 20529.66386664059*t)
	Y0 += 0.00000000473*np.cos(3.26277772078 + 77.962992305*t)
	Y0 += 0.00000000593*np.cos(3.28870942824 + 10367.0643566958*t)
	Y0 += 0.00000000648*np.cos(6.03788509546 + 22.0914005278*t)
	Y0 += 0.00000000624*np.cos(1.28974618222 + 330.6189636582*t)
	Y0 += 0.00000000653*np.cos(1.15486761496 + 388.4651552382*t)
	Y0 += 0.00000000468*np.cos(5.41054107443 + 1073.6090241908*t)
	Y0 += 0.00000000464*np.cos(0.84118413790 + 8631.326197928*t)
	Y0 += 0.00000000454*np.cos(5.50480758535 + 10042.6126755918*t)
	Y0 += 0.00000000532*np.cos(1.20297674206 + 728.762966531*t)
	Y0 += 0.00000000574*np.cos(4.09850700417 + 87.3117715395*t)
	Y0 += 0.00000000444*np.cos(0.84748587084 + 10383.9584168302*t)
	Y0 += 0.00000000439*np.cos(4.57010937002 + 24150.080051345*t)
	Y0 += 0.00000000604*np.cos(0.41299096165 + 984.6003316219*t)
	Y0 += 0.00000000582*np.cos(1.01106657087 + 8521.1198767086*t)
	Y0 += 0.00000000541*np.cos(1.50869067477 + 72.3339180125*t)
	Y0 += 0.00000000460*np.cos(5.40297168283 + 11802.3584414948*t)
	Y0 += 0.00000000468*np.cos(3.76982493207 + 212.7778305762*t)
	Y0 += 0.00000000466*np.cos(4.26202338577 + 213.8203602998*t)
	Y0 += 0.00000000498*np.cos(2.61301324745 + 16522.6597160022*t)
	Y0 += 0.00000000419*np.cos(1.18672277137 + 429.7795846137*t)
	Y0 += 0.00000000436*np.cos(0.28613813561 + 9638.9407478762*t)
	Y0 += 0.00000000423*np.cos(5.23795043183 + 340.7708920448*t)
	Y0 += 0.00000000416*np.cos(0.15526058452 + 10225.014899047*t)
	Y0 += 0.00000000416*np.cos(6.19703280926 + 10201.556193375*t)
	Y0 += 0.00000000462*np.cos(0.09066955654 + 860.3099287528*t)
	Y0 += 0.00000000439*np.cos(5.33807558951 + 27991.40181316*t)
	Y0 += 0.00000000431*np.cos(3.30244061049 + 8617.0991039264*t)
	Y0 += 0.00000000472*np.cos(3.26622622976 + 2218.7571041868*t)
	Y0 += 0.00000000379*np.cos(4.94184026058 + 19317.1925403286*t)
	Y0 += 0.00000000511*np.cos(3.34354440535 + 77.2292791221*t)
	Y0 += 0.00000000391*np.cos(6.01609758586 + 10787.6303445458*t)
	Y0 += 0.00000000491*np.cos(3.39044076994 + 3.1813937377*t)
	Y0 += 0.00000000355*np.cos(2.68573127230 + 30831.3049047446*t)
	Y0 += 0.00000000354*np.cos(5.08002534847 + 10103.0792249916*t)
	Y0 += 0.00000000354*np.cos(1.27226804531 + 10323.4918674304*t)
	Y0 += 0.00000000420*np.cos(1.77275125703 + 9050.8108418032*t)
	Y0 += 0.00000000478*np.cos(0.19721186884 + 35371.8872659764*t)
	Y0 += 0.00000000490*np.cos(2.59601400341 + 44809.6502008634*t)
	Y0 += 0.00000000429*np.cos(1.10169709405 + 13655.8604911764*t)
	Y0 += 0.00000000413*np.cos(0.42041417925 + 145.1097790097*t)
	Y0 += 0.00000000336*np.cos(5.60932577353 + 127.4717966068*t)
	Y0 += 0.00000000409*np.cos(0.70233676711 + 350.3321196004*t)
	Y0 += 0.00000000404*np.cos(5.98015684299 + 30666.1549584328*t)
	Y0 += 0.00000000383*np.cos(4.56297720194 + 909.8187330546*t)
	Y0 += 0.00000000331*np.cos(4.69331165984 + 27490.6924780448*t)
	Y0 += 0.00000000315*np.cos(4.73109393582 + 20639.87018786*t)
	Y0 += 0.00000000328*np.cos(1.01438027476 + 19786.67380610799*t)
	Y0 += 0.00000000375*np.cos(0.23620758788 + 108.4612160802*t)
	Y0 += 0.00000000392*np.cos(0.71173908582 + 29999.959352319*t)
	Y0 += 0.00000000399*np.cos(2.67833209975 + 10211.8010735027*t)
	Y0 += 0.00000000399*np.cos(3.67396129403 + 10214.7700189193*t)
	Y0 += 0.00000000313*np.cos(2.04966851954 + 234.6397364404*t)
	Y0 += 0.00000000382*np.cos(0.24418522119 + 186.2117600641*t)
	Y0 += 0.00000000398*np.cos(2.07757069100 + 9835.9119382952*t)
	Y0 += 0.00000000404*np.cos(2.41513448299 + 20351.7894938547*t)
	Y0 += 0.00000000385*np.cos(6.08106825320 + 20180.7394461926*t)
	Y0 += 0.00000000288*np.cos(5.63178266285 + 1905.4647649404*t)
	Y0 += 0.00000000379*np.cos(4.27472283876 + 10590.6591541268*t)
	Y0 += 0.00000000318*np.cos(0.94946325025 + 6309.3741697912*t)
	Y0 += 0.00000000365*np.cos(6.13706743141 + 10348.910871221*t)
	Y0 += 0.00000000365*np.cos(0.21522596237 + 10077.660221201*t)
	Y0 += 0.00000000308*np.cos(1.11858229845 + 362.8622925726*t)
	Y0 += 0.00000000283*np.cos(3.96316373805 + 3903.9113764198*t)
	Y0 += 0.00000000269*np.cos(4.01599389913 + 26709.6469424134*t)
	Y0 += 0.00000000271*np.cos(2.28569001687 + 9745.3205558566*t)
	Y0 += 0.00000000311*np.cos(2.87485251647 + 297.6419215609*t)
	Y0 += 0.00000000327*np.cos(1.40630049713 + 9360.089164459*t)
	Y0 += 0.00000000289*np.cos(0.35271915498 + 529.1697002328*t)
	Y0 += 0.00000000264*np.cos(2.24237848599 + 1485.9801210652*t)
	Y0 += 0.00000000289*np.cos(0.84527308658 + 530.2122299564*t)
	Y0 += 0.00000000366*np.cos(1.35412421660 + 604.4725636619*t)
	Y0 += 0.00000000282*np.cos(0.06832834990 + 62.2514255951*t)
	Y0 += 0.00000000263*np.cos(4.77643040513 + 52.6901980395*t)
	Y0 += 0.00000000314*np.cos(6.11319497702 + 20405.7956969296*t)
	Y0 += 0.00000000257*np.cos(2.63966270921 + 1258.4539316256*t)
	Y0 += 0.00000000306*np.cos(5.83870523892 + 2957.7158944766*t)
	Y0 += 0.00000000329*np.cos(1.76365842835 + 45585.1728121874*t)
	Y0 += 0.00000000254*np.cos(4.06665627806 + 10681.2505365654*t)
	Y0 += 0.00000000324*np.cos(5.37496427957 + 200.7689224658*t)
	Y0 += 0.00000000343*np.cos(3.07216304543 + 8106.2510386686*t)
	Y0 += 0.00000000275*np.cos(6.25194576299 + 565.1156877467*t)
	Y0 += 0.00000000269*np.cos(4.90534085198 + 140.001969579*t)
	Y0 += 0.00000000321*np.cos(5.03461670419 + 703.6331846174*t)
	Y0 += 0.00000000249*np.cos(4.80534758404 + 210.3783341312*t)
	Y0 += 0.00000000248*np.cos(3.22187918056 + 216.2198567448*t)
	Y0 += 0.00000000243*np.cos(5.15609899738 + 1062.5633239269*t)
	Y0 += 0.00000000336*np.cos(6.10975677385 + 454.9093665273*t)
	Y0 += 0.00000000240*np.cos(1.67381717935 + 37.611770776*t)
	Y0 += 0.00000000237*np.cos(2.15132956903 + 212.5483359126*t)
	Y0 += 0.00000000255*np.cos(3.33122871209 + 153.4953503977*t)
	Y0 += 0.00000000294*np.cos(3.40944983272 + 19360.07561523199*t)
	Y0 += 0.00000000236*np.cos(5.87788994285 + 214.0498549634*t)
	Y0 += 0.00000000234*np.cos(2.24935611965 + 19624.7501612982*t)
	Y0 += 0.00000000236*np.cos(2.66792286959 + 38.6543004996*t)
	Y0 += 0.00000000252*np.cos(3.03988883560 + 209.106309744*t)
	Y0 += 0.00000000281*np.cos(5.49571066653 + 9399.7352622512*t)
	Y0 += 0.00000000248*np.cos(4.98513016170 + 217.491881132*t)
	Y0 += 0.00000000229*np.cos(0.20430029596 + 574.3447983348*t)
	Y0 += 0.00000000280*np.cos(2.60576987045 + 38734.3783244656*t)
	Y0 += 0.00000000225*np.cos(1.81041528541 + 223.5940361765*t)
	Y0 += 0.00000000224*np.cos(3.94824411240 + 38.084851528*t)
	Y0 += 0.00000000223*np.cos(0.39234241482 + 38.1812197476*t)
	Y0 += 0.00000000309*np.cos(4.01568679365 + 48739.859897083*t)
	Y0 += 0.00000000222*np.cos(2.81789285850 + 8734.4189721466*t)
	Y0 += 0.00000000292*np.cos(3.65814608665 + 27197.2816936676*t)
	Y0 += 0.00000000216*np.cos(6.22908327759 + 2125.8774073792*t)
	Y0 += 0.00000000267*np.cos(2.30394736960 + 31749.2351907264*t)
	Y0 += 0.00000000229*np.cos(2.85216297633 + 9264.1099372412*t)
	Y0 += 0.00000000244*np.cos(2.64604748092 + 173.9422195228*t)
	Y0 += 0.00000000255*np.cos(2.46385009073 + 9992.8729037722*t)
	Y0 += 0.00000000255*np.cos(3.88844330305 + 10433.6981886498*t)
	Y0 += 0.00000000234*np.cos(5.26336192114 + 74.2603337055*t)
	Y0 += 0.00000000233*np.cos(5.70130722395 + 75.3028634291*t)
	Y0 += 0.00000000259*np.cos(3.73915077229 + 29573.361161443*t)
	Y0 += 0.00000000211*np.cos(4.89515362389 + 10249.3134128884*t)
	Y0 += 0.00000000211*np.cos(1.45713976989 + 10177.2576795336*t)
	Y0 += 0.00000000255*np.cos(0.85666245088 + 11026.8358301708*t)
	Y0 += 0.00000000247*np.cos(5.27605423414 + 252.6559713532*t)
	Y0 += 0.00000000275*np.cos(1.03976284586 + 34596.3646546524*t)
	Y0 += 0.00000000220*np.cos(2.13242742555 + 38.0276726358*t)
	Y0 += 0.00000000247*np.cos(0.33731775967 + 29587.5882554446*t)
	Y0 += 0.00000000203*np.cos(5.54978754111 + 18.1592472647*t)
	Y0 += 0.00000000206*np.cos(1.80396539478 + 30426.557543195*t)
	Y0 += 0.00000000282*np.cos(6.12964546434 + 563.6312150384*t)
	Y0 += 0.00000000263*np.cos(1.59050643196 + 20433.6846394228*t)
	Y0 += 0.00000000212*np.cos(1.58965720399 + 10206.65698731099*t)
	Y0 += 0.00000000212*np.cos(4.76263618979 + 10219.91410511101*t)
	Y0 += 0.00000000202*np.cos(5.53771508607 + 16894.5103996106*t)
	Y0 += 0.00000000224*np.cos(0.66388865647 + 88.865680217*t)
	Y0 += 0.00000000197*np.cos(3.20271468078 + 40077.61957352*t)
	Y0 += 0.00000000254*np.cos(2.17517906027 + 37410.5672398786*t)
	Y0 += 0.00000000272*np.cos(3.28012791525 + 12320.3200537534*t)
	Y0 += 0.00000000205*np.cos(4.98750840184 + 417.0369633204*t)
	Y0 += 0.00000000211*np.cos(3.54449702303 + 11162.4611551808*t)
	Y0 += 0.00000000211*np.cos(3.56508711838 + 37.1698277913*t)
	Y0 += 0.00000000215*np.cos(5.07155551847 + 1699.2792165032*t)
	Y0 += 0.00000000192*np.cos(2.70968461449 + 66.70484372*t)
	Y0 += 0.00000000266*np.cos(2.72829191880 + 377.3736079158*t)
	Y0 += 0.00000000186*np.cos(2.96624941532 + 10251.4185818488*t)
	Y0 += 0.00000000186*np.cos(3.38604397846 + 10175.1525105732*t)
	Y0 += 0.00000000204*np.cos(2.47411750627 + 207.6700211455*t)
	Y0 += 0.00000000258*np.cos(0.95259827692 + 9864.361125763*t)
	Y0 += 0.00000000228*np.cos(3.58367417249 + 207.8824694666*t)
	Y0 += 0.00000000203*np.cos(0.77682463263 + 39.0962434843*t)
	Y0 += 0.00000000186*np.cos(3.29302251278 + 17271.8840075264*t)
	Y0 += 0.00000000186*np.cos(2.34538148826 + 1898.3512179396*t)
	Y0 += 0.00000000220*np.cos(4.46432405157 + 218.7157214094*t)
	Y0 += 0.00000000257*np.cos(3.20894861459 + 10063.7223490764*t)
	Y0 += 0.00000000254*np.cos(1.58851548099 + 19264.0963880142*t)
	Y0 += 0.00000000186*np.cos(2.59788381829 + 508.3503240922*t)
	Y0 += 0.00000000195*np.cos(5.53819155539 + 218.9281697305*t)
	Y0 += 0.00000000246*np.cos(5.39979365811 + 10562.209966659*t)
	Y0 += 0.00000000211*np.cos(4.59175138406 + 11375.7602506188*t)
	Y0 += 0.00000000233*np.cos(1.59229597312 + 39302.096962196*t)
	Y0 += 0.00000000178*np.cos(5.22149503543 + 10949.1620597428*t)
	Y0 += 0.00000000178*np.cos(1.13079835835 + 9477.4090326792*t)
	Y0 += 0.00000000178*np.cos(4.08297672654 + 211.8146227297*t)
	Y0 += 0.00000000177*np.cos(4.83529684993 + 20316.36477120259*t)
	Y0 += 0.00000000224*np.cos(2.49436555659 + 1056.2005364515*t)
	Y0 += 0.00000000195*np.cos(0.90841744066 + 28.5718080822*t)
	Y0 += 0.00000000190*np.cos(4.35107066119 + 142.4496501338*t)
	Y0 += 0.00000000171*np.cos(1.38853028989 + 526.7702037878*t)
	Y0 += 0.00000000186*np.cos(5.42678326989 + 554.0699874828*t)
	Y0 += 0.00000000169*np.cos(6.09402587013 + 532.6117264014*t)
	Y0 += 0.00000000217*np.cos(2.01707572818 + 124.433415221*t)
	Y0 += 0.00000000175*np.cos(5.92248308601 + 525.4981794006*t)
	Y0 += 0.00000000187*np.cos(1.52481751621 + 1574.8458012822*t)
	Y0 += 0.00000000158*np.cos(5.04734034343 + 528.9402055692*t)
	Y0 += 0.00000000169*np.cos(0.93171590629 + 1471.7530270636*t)
	Y0 += 0.00000000157*np.cos(2.43465536306 + 530.44172462*t)
	Y0 += 0.00000000188*np.cos(1.87050370857 + 569.0478410098*t)
	Y0 += 0.00000000154*np.cos(5.43597579906 + 10199.0584522094*t)
	Y0 += 0.00000000154*np.cos(0.91631759472 + 10227.5126402126*t)
	Y0 += 0.00000000194*np.cos(2.55166855580 + 183.2428146475*t)
	Y0 += 0.00000000199*np.cos(2.28730999946 + 1685.0521225016*t)
	Y0 += 0.00000000178*np.cos(6.20228633181 + 5.9378908332*t)
	Y0 += 0.00000000152*np.cos(4.19364670284 + 283.8593188652*t)
	Y0 += 0.00000000207*np.cos(0.24572465192 + 73.8183907208*t)
	Y0 += 0.00000000185*np.cos(3.34815986923 + 265.9892934775*t)
	Y0 += 0.00000000175*np.cos(5.99371438486 + 217.964961884*t)
	Y0 += 0.00000000166*np.cos(2.18082507791 + 10263.0425716828*t)
	Y0 += 0.00000000166*np.cos(4.17146831587 + 10163.5285207392*t)
	Y0 += 0.00000000148*np.cos(2.83101653780 + 519.3960243561*t)
	Y0 += 0.00000000168*np.cos(0.62501827359 + 7991.428911614*t)
	Y0 += 0.00000000146*np.cos(2.06659470489 + 82.8583534146*t)
	Y0 += 0.00000000192*np.cos(4.39395898967 + 425.1137181677*t)
	Y0 += 0.00000000182*np.cos(2.27073026813 + 9256.9963902404*t)
	Y0 += 0.00000000149*np.cos(1.96157392100 + 414.0680179038*t)
	Y0 += 0.00000000165*np.cos(3.65136085639 + 231.4583427027*t)
	Y0 += 0.00000000201*np.cos(4.11002299299 + 453.424893819*t)
	Y0 += 0.00000000200*np.cos(4.96476307548 + 1439.5096981492*t)
	Y0 += 0.00000000169*np.cos(4.14838568997 + 11265.5539293994*t)
	Y0 += 0.00000000152*np.cos(4.81054163957 + 9367.2027114598*t)
	Y0 += 0.00000000195*np.cos(3.84051863538 + 8837.5117463652*t)
	Y0 += 0.00000000140*np.cos(4.10887314023 + 408.4389436113*t)
	Y0 += 0.00000000140*np.cos(5.04268037408 + 10191.4347168846*t)
	Y0 += 0.00000000140*np.cos(1.30961301970 + 10235.1363755374*t)
	Y0 += 0.00000000196*np.cos(3.84517606319 + 1293.4842235826*t)
	Y0 += 0.00000000191*np.cos(4.47590456732 + 75.7448064138*t)
	Y0 += 0.00000000191*np.cos(5.43460705034 + 52670.0695933026*t)
	Y0 += 0.00000000183*np.cos(2.47363849671 + 38526.574350872*t)
	Y0 += 0.00000000149*np.cos(1.58541955295 + 533.8837507886*t)
	Y0 += 0.00000000158*np.cos(2.03821572977 + 208.633228992*t)
	Y0 += 0.00000000138*np.cos(5.09734035169 + 10217.2176994741*t)
	Y0 += 0.00000000138*np.cos(1.25495304209 + 10209.3533929479*t)
	Y0 += 0.00000000153*np.cos(3.42669369028 + 47.6942631934*t)
	Y0 += 0.00000000131*np.cos(6.22770537067 + 203.0041546995*t)
	Y0 += 0.00000000148*np.cos(0.77105069393 + 19374.3027092336*t)
	Y0 += 0.00000000183*np.cos(0.59231255504 + 1021.2488945514*t)
	Y0 += 0.00000000139*np.cos(4.27354999851 + 373.9079928365*t)
	Y0 += 0.00000000139*np.cos(4.04425486837 + 214.7835681463*t)
	Y0 += 0.00000000143*np.cos(6.11571774821 + 20447.3464879144*t)
	Y0 += 0.00000000156*np.cos(6.26097721339 + 9779.5738083342*t)
	Y0 += 0.00000000126*np.cos(2.24994178665 + 20277.0078952874*t)
	Y0 += 0.00000000166*np.cos(1.38695682715 + 305.3461693927*t)
	Y0 += 0.00000000130*np.cos(0.69748880175 + 654.1243803156*t)
	Y0 += 0.00000000144*np.cos(6.26381421560 + 4.192785694*t)
	Y0 += 0.00000000139*np.cos(5.93780077355 + 251.4321310758*t)
	Y0 += 0.00000000121*np.cos(3.73123340759 + 479.2883889155*t)
	Y0 += 0.00000000119*np.cos(5.90821338773 + 114.1384744825*t)
	Y0 += 0.00000000149*np.cos(0.61484998961 + 10135.611775783*t)
	Y0 += 0.00000000149*np.cos(5.73744340417 + 10290.959316639*t)
	Y0 += 0.00000000151*np.cos(5.55480633210 + 10245.8180970024*t)
	Y0 += 0.00000000151*np.cos(0.79748706168 + 10180.7529954196*t)
	Y0 += 0.00000000119*np.cos(1.19706827555 + 7255.5696517344*t)
	Y0 += 0.00000000115*np.cos(4.65379442884 + 539.9859058331*t)
	Y0 += 0.00000000144*np.cos(2.25615309488 + 9985.809413422*t)
	Y0 += 0.00000000144*np.cos(4.09614029890 + 10440.76167900*t)
	Y0 += 0.00000000130*np.cos(4.00092308815 + 10236.0607476618*t)
	Y0 += 0.00000000130*np.cos(2.35137030563 + 10190.5103447602*t)
	Y0 += 0.00000000156*np.cos(2.62001496108 + 20388.4380567842*t)
	Y0 += 0.00000000155*np.cos(5.57179123583 + 8237.793000355*t)
	Y0 += 0.00000000114*np.cos(3.22069040111 + 213.4109700226*t)
	Y0 += 0.00000000114*np.cos(4.81084790265 + 213.1872208534*t)
	Y0 += 0.00000000129*np.cos(6.17361043988 + 302.164775655*t)
	Y0 += 0.00000000134*np.cos(3.09738168989 + 49515.382508407*t)
	Y0 += 0.00000000130*np.cos(2.02381333844 + 38204.687359371*t)
	Y0 += 0.00000000106*np.cos(6.19602488368 + 17468.8551979454*t)
	Y0 += 0.00000000116*np.cos(5.36019004356 + 524.0618908021*t)
	Y0 += 0.00000000115*np.cos(2.12419003336 + 535.3200393871*t)
	Y0 += 0.00000000131*np.cos(0.68489685701 + 8101.6352328334*t)
	Y0 += 0.00000000103*np.cos(2.80780479569 + 24978.5245894808*t)
	Y0 += 0.00000000126*np.cos(5.34406107671 + 540.7366653585*t)
	Y0 += 0.00000000119*np.cos(4.95824095217 + 983.1158589136*t)
	Y0 += 0.00000000115*np.cos(0.35603129387 + 98.8999885246*t)
	Y0 += 0.00000000118*np.cos(4.91950265277 + 525.0250986486*t)
	Y0 += 0.00000000102*np.cos(1.89629804705 + 56.6223513026*t)
	Y0 += 0.00000000100*np.cos(2.14566059864 + 529.851023789*t)
	Y0 += 0.00000000100*np.cos(5.33661471676 + 529.5309064002*t)
	Y0 += 0.00000000099*np.cos(0.29530316101 + 198.321241911*t)
	Y0 += 0.00000000102*np.cos(6.02433300674 + 963.4027029714*t)
	Y0 += 0.00000000122*np.cos(2.34109232351 + 19793.7873531088*t)
	Y0 += 0.00000000101*np.cos(3.69358080572 + 20043.6745601988*t)
	Y0 += 0.00000000109*np.cos(2.17221801259 + 175.1660598002*t)
	Y0 += 0.00000000111*np.cos(6.01414242152 + 80.1982245387*t)
	Y0 += 0.00000000135*np.cos(4.50553232470 + 5999.2165311262*t)
	Y0 += 0.00000000096*np.cos(5.43048994495 + 213.0866471169*t)
	Y0 += 0.00000000096*np.cos(2.60104835880 + 213.5115437591*t)
	Y0 += 0.00000000099*np.cos(4.90758830995 + 551.031606097*t)
	Y0 += 0.00000000113*np.cos(1.88238867485 + 2324.9494088156*t)
	Y0 += 0.00000000123*np.cos(2.99027576045 + 43232.3066584156*t)
	Y0 += 0.00000000111*np.cos(2.56844286864 + 534.3568315406*t)
	Y0 += 0.00000000117*np.cos(0.19396627342 + 524.2743391232*t)
	Y0 += 0.00000000109*np.cos(4.59018786120 + 43071.8992890308*t)
	Y0 += 0.00000000095*np.cos(3.70643398698 + 327.4375699205*t)
	Y0 += 0.00000000130*np.cos(1.64611266829 + 4176.041342449*t)
	Y0 += 0.00000000104*np.cos(5.47404374073 + 32.1951448046*t)
	Y0 += 0.00000000122*np.cos(5.60169381159 + 24383.0791084414*t)
	Y0 += 0.00000000127*np.cos(3.26672162678 + 21.3406410024*t)
	Y0 += 0.00000000097*np.cos(5.88286380267 + 32858.61374281979*t)
	Y0 += 0.00000000115*np.cos(1.00365590687 + 535.107591066*t)
	Y0 += 0.00000000112*np.cos(0.89977181729 + 20206.15844998319*t)
	Y0 += 0.00000000093*np.cos(1.80493983620 + 8204.728007052*t)
	Y0 += 0.00000000096*np.cos(4.77567549605 + 35.685355083*t)
	Y0 += 0.00000000098*np.cos(1.55452229557 + 11059.3683809622*t)
	Y0 += 0.00000000121*np.cos(3.89536747733 + 42456.7840470916*t)
	Y0 += 0.00000000103*np.cos(2.84917048342 + 219.891377577*t)
	Y0 += 0.00000000091*np.cos(2.45754138550 + 18844.61174413899*t)
	Y0 += 0.00000000091*np.cos(4.79589087629 + 1802.3719907218*t)
	Y0 += 0.00000000103*np.cos(3.58160703323 + 10244.199671846*t)
	Y0 += 0.00000000103*np.cos(2.77068636055 + 10182.371420576*t)
	Y0 += 0.00000000090*np.cos(1.60104298475 + 1382.8873468466*t)
	Y0 += 0.00000000125*np.cos(0.78050551092 + 12188.778092067*t)
	Y0 += 0.00000000093*np.cos(4.20565309570 + 99.1606209555*t)
	Y0 += 0.00000000097*np.cos(2.34874466786 + 2333.196392872*t)
	Y0 += 0.00000000122*np.cos(0.57162307533 + 56600.2792895222*t)
	Y0 += 0.00000000088*np.cos(2.76213355426 + 20350.3050211464*t)
	Y0 += 0.00000000087*np.cos(1.28166497839 + 228.276948965*t)
	Y0 += 0.00000000122*np.cos(3.86087135261 + 2636.725472637*t)
	Y0 += 0.00000000087*np.cos(2.93241416282 + 8087.4081388318*t)
	Y0 += 0.00000000086*np.cos(5.21923091634 + 7035.1397556434*t)
	Y0 += 0.00000000100*np.cos(1.82319423846 + 96.8729990951*t)
	Y0 += 0.00000000086*np.cos(0.89639333663 + 29057.89729034999*t)
	Y0 += 0.00000000085*np.cos(3.63689104790 + 74.8297826771*t)
	Y0 += 0.00000000085*np.cos(1.04303023325 + 74.7334144575*t)
	Y0 += 0.00000000095*np.cos(0.46006492106 + 10202.2398459471*t)
	Y0 += 0.00000000095*np.cos(5.89222847272 + 10224.3312464749*t)
	Y0 += 0.00000000084*np.cos(5.03945503208 + 27461.7108480654*t)
	Y0 += 0.00000000084*np.cos(5.94038512576 + 10401.2106939736*t)
	Y0 += 0.00000000084*np.cos(0.41190826802 + 10025.3603984484*t)
	Y0 += 0.00000000113*np.cos(5.85548952542 + 177.8743727859*t)
	Y0 += 0.00000000085*np.cos(3.46647958947 + 19477.39548345219*t)
	Y0 += 0.00000000085*np.cos(5.99437376237 + 191.9584544356*t)
	Y0 += 0.00000000087*np.cos(5.84639583938 + 40.5807161926*t)
	Y0 += 0.00000000102*np.cos(4.67254721576 + 131.4039498699*t)
	Y0 += 0.00000000093*np.cos(5.77977069690 + 74.5209661364*t)
	Y0 += 0.00000000093*np.cos(5.18093640996 + 75.0422309982*t)
	Y0 += 0.00000000080*np.cos(2.87647086515 + 278.5194664497*t)
	Y0 += 0.00000000089*np.cos(1.46011729281 + 191.2076949102*t)
	Y0 += 0.00000000079*np.cos(2.74811848231 + 38.0211610532*t)
	Y0 += 0.00000000079*np.cos(1.59253269036 + 38.2449102224*t)
	Y0 += 0.00000000098*np.cos(3.80111874017 + 20220.3855439848*t)
	Y0 += 0.00000000083*np.cos(0.78518936484 + 300.6108669775*t)
	Y0 += 0.00000000091*np.cos(3.84142883929 + 14169.7935622304*t)
	Y0 += 0.00000000078*np.cos(5.64618149774 + 30.0562807905*t)
	Y0 += 0.00000000097*np.cos(3.75597837361 + 259.5088859231*t)
	Y0 += 0.00000000095*np.cos(1.78055741695 + 29477.3819342252*t)
	Y0 += 0.00000000096*np.cos(0.05074222339 + 30206.14490075619*t)
	Y0 += 0.00000000101*np.cos(2.86422529330 + 38500.2760310722*t)
	Y0 += 0.00000000095*np.cos(2.94691545874 + 30220.3719947578*t)
	Y0 += 0.00000000077*np.cos(2.01507273057 + 10853.182832525*t)
	Y0 += 0.00000000107*np.cos(3.08276575514 + 2069.0068349066*t)
	Y0 += 0.00000000085*np.cos(5.14758347117 + 44.070926471*t)
	Y0 += 0.00000000076*np.cos(3.30386469943 + 10243.1069843598*t)
	Y0 += 0.00000000076*np.cos(3.04842869435 + 10183.4641080622*t)
	Y0 += 0.00000000076*np.cos(4.53950259247 + 44007.8292697396*t)
	Y0 += 0.00000000089*np.cos(2.25592202290 + 835.0371344873*t)
	Y0 += 0.00000000076*np.cos(3.13724740029 + 106.2741679563*t)
	Y0 += 0.00000000078*np.cos(5.37998455046 + 7880.08915333899*t)
	Y0 += 0.00000000091*np.cos(2.31009109472 + 80.7194894005*t)
	Y0 += 0.00000000075*np.cos(0.93284040810 + 205.2223405907*t)
	Y0 += 0.00000000079*np.cos(1.02058994543 + 74.6215398729*t)
	Y0 += 0.00000000078*np.cos(3.65920759701 + 74.9416572617*t)
	Y0 += 0.00000000100*np.cos(1.06747118471 + 28947.6909691306*t)
	Y0 += 0.00000000072*np.cos(1.90029548750 + 17248.4253018544*t)
	Y0 += 0.00000000082*np.cos(5.95948324562 + 5.5229243074*t)
	Y0 += 0.00000000077*np.cos(1.39895481144 + 195.1398481733*t)
	Y0 += 0.00000000072*np.cos(4.78502700351 + 213.0384630071*t)
	Y0 += 0.00000000072*np.cos(3.24651089369 + 213.5597278689*t)
	Y0 += 0.00000000096*np.cos(2.67801150530 + 483.2205421786*t)
	Y0 += 0.00000000078*np.cos(3.37272107675 + 29043.67019634839*t)
	Y0 += 0.00000000086*np.cos(2.73735833770 + 2.4476805548*t)
	Y0 += 0.00000000075*np.cos(0.44027902661 + 21000.9158907568*t)
	Y0 += 0.00000000071*np.cos(2.52223847071 + 22645.32819660879*t)
	Y0 += 0.00000000074*np.cos(0.35341011835 + 8827.3902698748*t)
	Y0 += 0.00000000085*np.cos(0.56779936902 + 3914.9572250346*t)
	Y0 += 0.00000000070*np.cos(6.20393956561 + 6298.3283211764*t)
	Y0 += 0.00000000072*np.cos(2.38867048672 + 34171.9173314444*t)
	Y0 += 0.00000000079*np.cos(1.08839441675 + 10018.3141617504*t)
	Y0 += 0.00000000079*np.cos(5.26389897703 + 10408.2569306716*t)
	Y0 += 0.00000000095*np.cos(2.11170756015 + 248.7238180901*t)
	Y0 += 0.00000000075*np.cos(0.64877739613 + 18734.4054229196*t)
	Y0 += 0.00000000069*np.cos(1.88886878891 + 529.4785167735*t)
	Y0 += 0.00000000069*np.cos(5.59340951305 + 529.9034134157*t)
	Y0 += 0.00000000076*np.cos(1.98904461594 + 518.6452648307*t)
	Y0 += 0.00000000069*np.cos(5.61697903331 + 41044.5904509556*t)
	Y0 += 0.00000000066*np.cos(0.44946982323 + 635.9651330509*t)
	Y0 += 0.00000000069*np.cos(0.68347421356 + 9644.4636721836*t)
	Y0 += 0.00000000069*np.cos(5.66881918022 + 10782.1074202384*t)
	Y0 += 0.00000000066*np.cos(1.92154628038 + 2214.7430875962*t)
	Y0 += 0.00000000074*np.cos(2.48641792134 + 68.8437077341*t)
	Y0 += 0.00000000083*np.cos(4.22258770909 + 9721.6222537522*t)
	Y0 += 0.00000000083*np.cos(2.12970568469 + 10704.9488386698*t)
	Y0 += 0.00000000072*np.cos(0.13848852336 + 18830.38465013739*t)
	Y0 += 0.00000000090*np.cos(3.61691095667 + 20049.1974845062*t)
	Y0 += 0.00000000076*np.cos(5.76440532006 + 21485.95302261119*t)
	Y0 += 0.00000000084*np.cos(5.41269775901 + 424.1505103212*t)
	Y0 += 0.00000000071*np.cos(1.03137133715 + 275.5505210331*t)
	Y0 += 0.00000000066*np.cos(4.46930207827 + 33.9402499438*t)
	Y0 += 0.00000000072*np.cos(2.56964528099 + 19573.37471066999*t)
	Y0 += 0.00000000063*np.cos(1.65767004610 + 20.6069278195*t)
	Y0 += 0.00000000063*np.cos(3.18646450612 + 18314.9207790444*t)
	Y0 += 0.00000000070*np.cos(1.43478197258 + 1573.8204240988*t)
	Y0 += 0.00000000083*np.cos(5.34151461839 + 46386.9937433112*t)
	Y0 += 0.00000000083*np.cos(5.09775374255 + 404.5067903482*t)
	Y0 += 0.00000000063*np.cos(2.94014383007 + 8.0767548473*t)
	Y0 += 0.00000000068*np.cos(2.22365421702 + 831.8557407496*t)
	Y0 += 0.00000000082*np.cos(5.88510225867 + 154.0166152595*t)
	Y0 += 0.00000000067*np.cos(2.05862077241 + 3956.5080160194*t)
	Y0 += 0.00000000070*np.cos(0.75267806535 + 1580.8666607968*t)
	Y0 += 0.00000000081*np.cos(2.12955581519 + 37.8724032069*t)
	Y0 += 0.00000000087*np.cos(3.90827818520 + 29264.0828387872*t)
	Y0 += 0.00000000073*np.cos(5.60150844280 + 115.8835796217*t)
	Y0 += 0.00000000080*np.cos(2.21108404080 + 38.3936680687*t)
	Y0 += 0.00000000064*np.cos(4.44827566878 + 284.1485407422*t)
	Y0 += 0.00000000071*np.cos(0.66382087848 + 28418.000004036*t)
	Y0 += 0.00000000061*np.cos(1.55846256298 + 27682.1407441564*t)
	Y0 += 0.00000000070*np.cos(0.48885804664 + 107.0249274817*t)
	Y0 += 0.00000000060*np.cos(6.06109901775 + 20421.0481681146*t)
	Y0 += 0.00000000069*np.cos(0.94467164100 + 511.5317178299*t)
	Y0 += 0.00000000076*np.cos(2.36906364898 + 29683.56748266239*t)
	Y0 += 0.00000000064*np.cos(5.87747392917 + 18300.69368504279*t)
	Y0 += 0.00000000062*np.cos(5.99888400949 + 11599.1808225472*t)
	Y0 += 0.00000000079*np.cos(0.78455831236 + 28313.288804661*t)
	Y0 += 0.00000000058*np.cos(1.51132246914 + 7576.560073574*t)
	Y0 += 0.00000000058*np.cos(4.95419870669 + 46.2097904851*t)
	Y0 += 0.00000000057*np.cos(2.10835504837 + 11279.781023401*t)
	Y0 += 0.00000000079*np.cos(1.99170433665 + 60530.4889857418*t)
	Y0 += 0.00000000079*np.cos(4.15336422499 + 531.1754378029*t)
	Y0 += 0.00000000067*np.cos(5.81376296368 + 643.8294395771*t)
	Y0 += 0.00000000059*np.cos(5.97279707503 + 10254.8363371958*t)
	Y0 += 0.00000000059*np.cos(0.37949631875 + 10171.7347552262*t)
	Y0 += 0.00000000057*np.cos(2.49183550585 + 20464.5987650578*t)
	Y0 += 0.00000000079*np.cos(3.55016127148 + 10137.0194749354*t)
	Y0 += 0.00000000056*np.cos(6.15449621937 + 842.1506814881*t)
	Y0 += 0.00000000065*np.cos(0.26869494906 + 547.8502123593*t)
	Y0 += 0.00000000062*np.cos(1.89895196585 + 31022.7531708562*t)
	Y0 += 0.00000000074*np.cos(3.35112731202 + 53285.1848352418*t)
	Y0 += 0.00000000069*np.cos(3.21235031019 + 269.9214467406*t)
	Y0 += 0.00000000075*np.cos(3.14349504273 + 227.3137411185*t)
	Y0 += 0.00000000061*np.cos(4.72931440223 + 121.2520214833*t)
	Y0 += 0.00000000064*np.cos(4.00074980257 + 30007.0728993198*t)
	Y0 += 0.00000000061*np.cos(1.41008037643 + 429.0458714308*t)
	Y0 += 0.00000000064*np.cos(2.72423324964 + 159.1244246902*t)
	Y0 += 0.00000000061*np.cos(2.23944425679 + 650.9429865779*t)
	Y0 += 0.00000000058*np.cos(1.48653338098 + 75449.50683949639*t)
	Y0 += 0.00000000073*np.cos(2.27987119168 + 51449.3242632782*t)
	Y0 += 0.00000000074*np.cos(3.91369739911 + 21720.0553160046*t)
	Y0 += 0.00000000069*np.cos(4.29368361875 + 18093.37469954999*t)
	Y0 += 0.00000000072*np.cos(2.90060146744 + 100608.10855926179*t)
	Y0 += 0.00000000073*np.cos(3.31073272937 + 528.2064923863*t)
	Y0 += 0.00000000057*np.cos(1.89137287758 + 92.940845832*t)
	Y0 += 0.00000000061*np.cos(5.27096932810 + 18100.00325845*t)
	Y0 += 0.00000000068*np.cos(5.14472869299 + 219.4494345923*t)
	Y0 += 0.00000000052*np.cos(0.52182858466 + 40426.543993968*t)
	Y0 += 0.00000000051*np.cos(3.53345258541 + 1048.3362299253*t)
	Y0 += 0.00000000062*np.cos(4.52301275304 + 425.6349830295*t)
	Y0 += 0.00000000065*np.cos(1.17174840770 + 14.977853527*t)
	Y0 += 0.00000000058*np.cos(6.02426265881 + 20412.34399842039*t)
	Y0 += 0.00000000065*np.cos(2.14229590210 + 32243.4985008806*t)
	Y0 += 0.00000000059*np.cos(4.73931220180 + 47162.5163546352*t)
	Y0 += 0.00000000058*np.cos(4.32481237367 + 72.0732855816*t)
	Y0 += 0.00000000050*np.cos(6.18510990638 + 960.2213092337*t)
	Y0 += 0.00000000055*np.cos(0.04281344157 + 42.3258213318*t)
	Y0 += 0.00000000056*np.cos(4.39886775705 + 53445.5922046266*t)
	Y0 += 0.00000000050*np.cos(4.83446941002 + 426.6463749858*t)
	Y0 += 0.00000000049*np.cos(3.21271029936 + 514.7131115676*t)
	Y0 += 0.00000000065*np.cos(2.41337358880 + 494.2662424425*t)
	Y0 += 0.00000000067*np.cos(2.57317423197 + 618.5566453116*t)
	Y0 += 0.00000000057*np.cos(3.46964286996 + 8307.8207812706*t)
	Y0 += 0.00000000052*np.cos(1.85871885411 + 2641.3412784722*t)
	Y0 += 0.00000000050*np.cos(6.27092935627 + 8418.02710249*t)
	Y0 += 0.00000000062*np.cos(6.11167050077 + 750.1036075334*t)
	Y0 += 0.00000000053*np.cos(0.86945819735 + 2428.0421830342*t)
	Y0 += 0.00000000066*np.cos(3.34109931244 + 78604.19392439199*t)
	Y0 += 0.00000000050*np.cos(1.63663518288 + 426.5500067662*t)
	Y0 += 0.00000000066*np.cos(4.48087077585 + 19580.4882576708*t)
	Y0 += 0.00000000047*np.cos(4.26489760399 + 544.6688186216*t)
	Y0 += 0.00000000047*np.cos(3.24772372978 + 38741.4918714664*t)
	Y0 += 0.00000000047*np.cos(4.45256678947 + 387.2413149608*t)
	Y0 += 0.00000000055*np.cos(3.70101890767 + 81.8951455681*t)
	Y0 += 0.00000000060*np.cos(0.53980789709 + 488.8496164711*t)
	Y0 += 0.00000000064*np.cos(2.60081517768 + 1364.7280995819*t)
	Y0 += 0.00000000050*np.cos(6.05227901906 + 59160.9494168876*t)
	Y0 += 0.00000000055*np.cos(5.41416986220 + 48947.6638706766*t)
	Y0 += 0.00000000052*np.cos(2.81764658144 + 210.5907824523*t)
	Y0 += 0.00000000046*np.cos(5.77895747608 + 194.9713844606*t)
	Y0 += 0.00000000056*np.cos(5.79105836654 + 9936.5397743466*t)
	Y0 += 0.00000000056*np.cos(0.56123502724 + 10490.0313180754*t)
	Y0 += 0.00000000053*np.cos(2.05896623723 + 427.5613987225*t)
	Y0 += 0.00000000051*np.cos(5.21356444643 + 216.0074084237*t)
	Y0 += 0.00000000050*np.cos(3.05458837611 + 1056.9342496344*t)
	Y0 += 0.00000000049*np.cos(6.03922030861 + 501.3797894433*t)
	Y0 += 0.00000000054*np.cos(2.92585194345 + 9922.312680345*t)
	Y0 += 0.00000000054*np.cos(3.42644145033 + 10504.258412077*t)
	Y0 += 0.00000000059*np.cos(3.59330170983 + 18204.71445782499*t)
	Y0 += 0.00000000044*np.cos(1.83359720481 + 2538.2485042536*t)
	Y0 += 0.00000000044*np.cos(3.59534331356 + 74.0308390419*t)
	Y0 += 0.00000000048*np.cos(5.93972997403 + 38727.2647774648*t)
	Y0 += 0.00000000061*np.cos(1.93644248401 + 10286.58267207*t)
	Y0 += 0.00000000061*np.cos(4.41585090977 + 10139.988420352*t)
	Y0 += 0.00000000061*np.cos(5.28413978764 + 6566.9351688566*t)
	Y0 += 0.00000000050*np.cos(5.77173682772 + 355.7487455718*t)
	Y0 += 0.00000000044*np.cos(1.08481523531 + 75.5323580927*t)
	Y0 += 0.00000000043*np.cos(5.70834575414 + 213.4591541324*t)
	Y0 += 0.00000000043*np.cos(2.32287306604 + 213.1390367436*t)
	Y0 += 0.00000000043*np.cos(5.47593276555 + 220.4608265486*t)
	Y0 += 0.00000000056*np.cos(1.59993474661 + 491.8185618877*t)
	Y0 += 0.00000000060*np.cos(6.18401612782 + 86464.61331683119*t)
	Y0 += 0.00000000048*np.cos(1.78116870506 + 9246.3146687754*t)
	Y0 += 0.00000000060*np.cos(4.34226209904 + 3684.3780499902*t)
	Y0 += 0.00000000060*np.cos(1.84622268138 + 14427.3545612958*t)
	Y0 += 0.00000000051*np.cos(0.71928664610 + 9566.2747128962*t)
	Y0 += 0.00000000054*np.cos(5.39695767554 + 187.6962327724*t)
	Y0 += 0.00000000052*np.cos(1.63253830755 + 8727.3054251458*t)
	Y0 += 0.00000000050*np.cos(3.99260483640 + 296.1574488526*t)
	Y0 += 0.00000000057*np.cos(5.35044527046 + 1061.829610744*t)
	Y0 += 0.00000000054*np.cos(3.78910232599 + 47623.8527860896*t)
	Y0 += 0.00000000043*np.cos(3.24179066608 + 128.9562693151*t)
	Y0 += 0.00000000045*np.cos(3.95006454295 + 10263.2821681152*t)
	Y0 += 0.00000000045*np.cos(2.40222885083 + 10163.2889243068*t)
	Y0 += 0.00000000047*np.cos(4.95696645233 + 1279.794572628*t)
	Y0 += 0.00000000049*np.cos(0.08548300777 + 9794.3611473104*t)
	Y0 += 0.00000000049*np.cos(6.26681038601 + 10632.2099451116*t)
	Y0 += 0.00000000058*np.cos(1.48165013529 + 1861.202861313*t)
	Y0 += 0.00000000047*np.cos(6.22156178529 + 20142.7117735568*t)
	Y0 += 0.00000000054*np.cos(2.89069416534 + 207.1487562837*t)
	Y0 += 0.00000000044*np.cos(0.47724556879 + 30632.74309163219*t)
	Y0 += 0.00000000041*np.cos(4.84097099797 + 12850.011018848*t)
	Y0 += 0.00000000048*np.cos(1.44348407688 + 106.9767433719*t)
	Y0 += 0.00000000045*np.cos(3.81128625757 + 2349.3430354228*t)
	Y0 += 0.00000000045*np.cos(3.12918282665 + 2356.3892721208*t)
	Y0 += 0.00000000056*np.cos(3.88391523095 + 1057.8974574809*t)
	Y0 += 0.00000000047*np.cos(3.45990384746 + 679.2541622292*t)
	Y0 += 0.00000000053*np.cos(0.36365795711 + 601.7642506762*t)
	Y0 += 0.00000000045*np.cos(3.92464674406 + 3178.1457905676*t)
	Y0 += 0.00000000042*np.cos(3.51224472308 + 77802.37299326819*t)
	Y0 += 0.00000000046*np.cos(1.42734790968 + 115674.27666460119*t)
	Y0 += 0.00000000040*np.cos(2.54799612698 + 1059.430114299*t)
	Y0 += 0.00000000045*np.cos(3.08256873858 + 10.2949407385*t)
	Y0 += 0.00000000044*np.cos(2.89783366184 + 79379.716535716*t)
	Y0 += 0.00000000051*np.cos(4.18413102003 + 344.7030453079*t)
	Y0 += 0.00000000042*np.cos(2.30009534060 + 220.364458329*t)
	Y0 += 0.00000000041*np.cos(1.23522586481 + 25132.3033999656*t)
	Y0 += 0.00000000055*np.cos(5.75395220831 + 188.9200730498*t)
	Y0 += 0.00000000053*np.cos(0.70077978084 + 67.6680515665*t)
	Y0 += 0.00000000039*np.cos(1.93706467599 + 1788.1448967202*t)
	Y0 += 0.00000000039*np.cos(1.87346435474 + 28631.29909947399*t)
	Y0 += 0.00000000052*np.cos(3.63882972952 + 38631.285550247*t)
	Y0 += 0.00000000043*np.cos(4.57112464191 + 11180.2564236466*t)
	Y0 += 0.00000000044*np.cos(4.99425187685 + 179.3588454942*t)
	Y0 += 0.00000000044*np.cos(0.26434468297 + 289.5651667136*t)
	Y0 += 0.00000000040*np.cos(4.73960650797 + 436.1594184316*t)
	Y0 += 0.00000000047*np.cos(0.17782919736 + 187.9251477626*t)
	Y0 += 0.00000000040*np.cos(3.26413558741 + 149.45132255*t)
	Y0 += 0.00000000039*np.cos(5.18683524181 + 54981.3849560896*t)
	Y0 += 0.00000000044*np.cos(5.88330364964 + 10168.1443265744*t)
	Y0 += 0.00000000044*np.cos(0.46898974414 + 10258.4267658476*t)
	Y0 += 0.00000000041*np.cos(1.16123981348 + 24341.5283174566*t)
	Y0 += 0.00000000047*np.cos(1.24067371450 + 1038.0412891868*t)
	Y0 += 0.00000000051*np.cos(3.41164207102 + 64460.6986819614*t)
	Y0 += 0.00000000043*np.cos(0.40869970249 + 22030.2129546696*t)
	Y0 += 0.00000000041*np.cos(0.99171071955 + 47358.5909753928*t)
	Y0 += 0.00000000044*np.cos(0.82332847780 + 358.9301393095*t)
	Y0 += 0.00000000051*np.cos(4.32233055210 + 104538.3182554814*t)
	Y0 += 0.00000000051*np.cos(4.70514482859 + 16250.529749973*t)
	Y0 += 0.00000000037*np.cos(2.91616393795 + 29160.9900645686*t)
	Y0 += 0.00000000036*np.cos(1.35884346175 + 68.1893164283*t)
	Y0 += 0.00000000043*np.cos(3.35259007747 + 10362.8487433456*t)
	Y0 += 0.00000000039*np.cos(1.62990239695 + 37674.9963942764*t)
	Y0 += 0.00000000038*np.cos(2.56508843435 + 47917.2635704668*t)
	Y0 += 0.00000000036*np.cos(2.69669701623 + 2751.5475996916*t)
	Y0 += 0.00000000037*np.cos(2.84218380221 + 6256.7775301916*t)
	Y0 += 0.00000000047*np.cos(5.73121342219 + 523.5406259403*t)
	Y0 += 0.00000000036*np.cos(1.39948651785 + 8673.969676399*t)
	Y0 += 0.00000000050*np.cos(1.83789408271 + 54247.4131357504*t)
	Y0 += 0.00000000044*np.cos(0.56832443467 + 50317.2034395308*t)
	Y0 += 0.00000000036*np.cos(1.89385828446 + 59.8037450403*t)
	Y0 += 0.00000000040*np.cos(5.63337030653 + 1059.3337460794*t)
	Y0 += 0.00000000049*np.cos(0.39141584772 + 491.6632924588*t)
	Y0 += 0.00000000035*np.cos(1.18237243551 + 12546.481939083*t)
	Y0 += 0.00000000038*np.cos(4.07163115574 + 212.0270710508*t)
	Y0 += 0.00000000037*np.cos(3.95930414230 + 214.5711198252*t)
	Y0 += 0.00000000047*np.cos(0.89434277888 + 50.4025761791*t)
	Y0 += 0.00000000039*np.cos(0.73367000632 + 1514.2912967165*t)
	Y0 += 0.00000000040*np.cos(5.57904418434 + 497.4476361802*t)
	Y0 += 0.00000000035*np.cos(2.73744180385 + 672.1406152284*t)
	Y0 += 0.00000000044*np.cos(2.73569081007 + 9697.821675118*t)
	Y0 += 0.00000000044*np.cos(3.61660258371 + 10728.749417304*t)
	Y0 += 0.00000000036*np.cos(0.66587329374 + 69941.95360082899*t)
	Y0 += 0.00000000037*np.cos(1.68139239859 + 35191.8101356918*t)
	Y0 += 0.00000000040*np.cos(1.63699678518 + 143.6253063014*t)
	Y0 += 0.00000000035*np.cos(0.76656495982 + 48733.23133818299*t)
	Y0 += 0.00000000035*np.cos(3.13094039439 + 10415.5389413851*t)
	Y0 += 0.00000000035*np.cos(3.22135299939 + 10011.0321510369*t)
	Y0 += 0.00000000036*np.cos(3.56130087049 + 1361.5467058442*t)
	Y0 += 0.00000000035*np.cos(3.08830623607 + 89.7594520943*t)
	Y0 += 0.00000000036*np.cos(3.40125641272 + 100909.03762133139*t)
	Y0 += 0.00000000040*np.cos(0.01680612963 + 149.6750717192*t)
	Y0 += 0.00000000044*np.cos(1.20989531942 + 36301.18868778519*t)
	Y0 += 0.00000000047*np.cos(2.53044739139 + 88041.956859279*t)
	Y0 += 0.00000000034*np.cos(5.96407611411 + 47938.0389659592*t)
	Y0 += 0.00000000043*np.cos(1.35224903493 + 312.4597163935*t)
	Y0 += 0.00000000033*np.cos(3.80922491688 + 49477.35483577119*t)
	Y0 += 0.00000000045*np.cos(6.15174229277 + 66038.04222440919*t)
	Y0 += 0.00000000040*np.cos(5.33231345721 + 28513.97923125379*t)
	Y0 += 0.00000000033*np.cos(1.28829842226 + 34363.365597556*t)
	Y0 += 0.00000000033*np.cos(2.72260069006 + 55798.4583583984*t)
	Y0 += 0.00000000042*np.cos(1.76079418628 + 535.8413042489*t)
	Y0 += 0.00000000033*np.cos(3.40692233770 + 54394.56338733519*t)
	Y0 += 0.00000000034*np.cos(4.57649322994 + 31214.2014369678*t)
	Y0 += 0.00000000033*np.cos(4.17419241267 + 10309.2647734288*t)
	Y0 += 0.00000000033*np.cos(2.17810098111 + 10117.3063189932*t)
	Y0 += 0.00000000034*np.cos(0.22515043919 + 7461.7379465194*t)
	Y0 += 0.00000000035*np.cos(0.17606718200 + 529.9515975255*t)
	Y0 += 0.00000000035*np.cos(1.02336134569 + 529.4303326637*t)
	Y0 += 0.00000000032*np.cos(2.54476552980 + 206.1373643274*t)
	Y0 += 0.00000000045*np.cos(5.30626896435 + 1512.8068240082*t)
	Y0 += 0.00000000037*np.cos(5.80408586611 + 58946.51688439399*t)
	Y0 += 0.00000000043*np.cos(2.21665582542 + 237.6781178262*t)
	Y0 += 0.00000000040*np.cos(3.35479050773 + 1593.0050485469*t)
	Y0 += 0.00000000033*np.cos(2.42762603478 + 2001.4439921582*t)
	Y0 += 0.00000000044*np.cos(1.32352355619 + 90394.82301305079*t)
	Y0 += 0.00000000034*np.cos(2.34445071844 + 522.6256022036*t)
	Y0 += 0.00000000031*np.cos(3.37478583123 + 81.3738807063*t)
	Y0 += 0.00000000031*np.cos(5.42920592130 + 522.529233984*t)
	Y0 += 0.00000000038*np.cos(1.18845657835 + 74821.13447975718*t)
	Y0 += 0.00000000031*np.cos(1.87707549397 + 30103.05212653759*t)
	Y0 += 0.00000000032*np.cos(0.98619416724 + 34570.0663348526*t)
	Y0 += 0.00000000032*np.cos(3.35243256009 + 767.3690829208*t)
	Y0 += 0.00000000032*np.cos(1.81438986358 + 29786.660256881*t)
	Y0 += 0.00000000038*np.cos(5.10282384073 + 92.0470739547*t)
	Y0 += 0.00000000032*np.cos(2.19359308367 + 21977.61631507*t)
	Y0 += 0.00000000031*np.cos(6.06589927522 + 35.212274331*t)
	Y0 += 0.00000000036*np.cos(5.94106521859 + 20430.50324568509*t)
	Y0 += 0.00000000033*np.cos(6.06643896212 + 1060.3451380357*t)
	Y0 += 0.00000000032*np.cos(4.93495248062 + 81732.5826894878*t)
	Y0 += 0.00000000043*np.cos(3.24614367572 + 58177.62283197*t)
	Y0 += 0.00000000035*np.cos(6.20793918435 + 51092.7260508548*t)
	Y0 += 0.00000000033*np.cos(4.63488708885 + 5.4166259714*t)
	Y0 += 0.00000000033*np.cos(1.38971011469 + 55022.9357470744*t)
	Y0 += 0.00000000036*np.cos(5.94088407657 + 181.0557665236*t)
	Y0 += 0.00000000033*np.cos(4.31034440765 + 83309.92623193559*t)
	Y0 += 0.00000000029*np.cos(4.95280733068 + 11752.601416023*t)
	Y0 += 0.00000000029*np.cos(3.94608385223 + 9800.9144493366*t)
	Y0 += 0.00000000029*np.cos(2.40620954155 + 10625.6566430854*t)
	Y0 += 0.00000000031*np.cos(5.71228872293 + 206.233732547*t)
	Y0 += 0.00000000030*np.cos(2.05100908229 + 20432.0940167294*t)
	Y0 += 0.00000000029*np.cos(5.95807433561 + 1585.1407420207*t)
	Y0 += 0.00000000029*np.cos(5.98297157212 + 9889.7801295536*t)
	Y0 += 0.00000000038*np.cos(1.57699576377 + 47964.337285759*t)
	Y0 += 0.00000000039*np.cos(5.95942234005 + 47888.2819404874*t)
	Y0 += 0.00000000039*np.cos(5.51640686424 + 14128.2427712456*t)
	Y0 += 0.00000000029*np.cos(1.67115577064 + 85034.42002596818*t)
	Y0 += 0.00000000039*np.cos(5.81881044351 + 73898.46161684839*t)
	Y0 += 0.00000000040*np.cos(2.84352268392 + 80181.53746683979*t)
	Y0 += 0.00000000028*np.cos(4.98574596975 + 10098.84625752579*t)
	Y0 += 0.00000000028*np.cos(1.36654742403 + 10327.72483489621*t)
	Y0 += 0.00000000039*np.cos(2.90361169612 + 5791.4125575326*t)
	Y0 += 0.00000000039*np.cos(3.61855841109 + 30563.5905673574*t)
	Y0 += 0.00000000034*np.cos(2.65806280363 + 1539.315869812*t)
	Y0 += 0.00000000028*np.cos(0.72550860398 + 1179.1945390396*t)
	Y0 += 0.00000000031*np.cos(3.89570695535 + 39786.646707654*t)
	Y0 += 0.00000000028*np.cos(2.08868760692 + 73872.1632970486*t)
	Y0 += 0.00000000029*np.cos(2.97395589358 + 426.0769260142*t)
	Y0 += 0.00000000028*np.cos(5.13152921511 + 15694.5404650786*t)
	Y0 += 0.00000000034*np.cos(2.10761573799 + 40213.24489853*t)
	Y0 += 0.00000000027*np.cos(0.43069996566 + 643.0786800517*t)
	Y0 += 0.00000000034*np.cos(2.04440145216 + 245.5424243524*t)
	Y0 += 0.00000000030*np.cos(4.24679619338 + 62883.3551395136*t)
	Y0 += 0.00000000029*np.cos(3.97759672159 + 458.8415197904*t)
	Y0 += 0.00000000027*np.cos(2.79321900732 + 113.3877149571*t)
	Y0 += 0.00000000029*np.cos(5.12998256913 + 536.7563279856*t)
	Y0 += 0.00000000029*np.cos(5.84823794150 + 110012.94461544899*t)
	Y0 += 0.00000000026*np.cos(2.06190087041 + 536.8526962052*t)
	Y0 += 0.00000000034*np.cos(1.33501180136 + 42430.4857272918*t)
	Y0 += 0.00000000037*np.cos(4.74983943559 + 82534.40362061159*t)
	Y0 += 0.00000000037*np.cos(1.06810341965 + 13859.6359235654*t)
	Y0 += 0.00000000030*np.cos(2.98025809633 + 247.2393453818*t)
	Y0 += 0.00000000037*np.cos(2.06942308542 + 37703.9780242558*t)
	Y0 += 0.00000000031*np.cos(1.84196344987 + 25960.4226508892*t)
	Y0 += 0.00000000028*np.cos(3.49625376754 + 7886.717712239*t)
	return Y0




def Venus_Y1 (t): # 574 terms of order 1

	Y1 = 0.
	Y1 += 0.00039237546
	Y1 += 0.00017282284*np.cos(5.63824735900 + 20426.571092422*t)
	Y1 += 0.00005968061*np.cos(3.60854941167 + 10213.285546211*t)
	Y1 += 0.00000898218*np.cos(5.83996118482 + 426.598190876*t)
	Y1 += 0.00000781308*np.cos(1.12962566094 + 206.1855484372*t)
	Y1 += 0.00000754802*np.cos(0.61969529688 + 220.4126424388*t)
	Y1 += 0.00000600351*np.cos(1.68664617318 + 1059.3819301892*t)
	Y1 += 0.00000572669*np.cos(4.00093192089 + 522.5774180938*t)
	Y1 += 0.00000560655*np.cos(3.48676353022 + 536.8045120954*t)
	Y1 += 0.00000175529*np.cos(0.23554665359 + 30639.856638633*t)
	Y1 += 0.00000098812*np.cos(1.87383067719 + 7.1135470008*t)
	Y1 += 0.00000072713*np.cos(5.07512093664 + 639.897286314*t)
	Y1 += 0.00000087320*np.cos(0.09065280320 + 419.4846438752*t)
	Y1 += 0.00000060346*np.cos(3.35752563808 + 8635.9420037632*t)
	Y1 += 0.00000053759*np.cos(6.03942421773 + 433.7117378768*t)
	Y1 += 0.00000063046*np.cos(0.52083190822 + 10186.9872264112*t)
	Y1 += 0.00000062777*np.cos(5.83131036994 + 10239.5838660108*t)
	Y1 += 0.00000049333*np.cos(3.00159177408 + 11790.6290886588*t)
	Y1 += 0.00000047382*np.cos(2.15007843045 + 213.299095438*t)
	Y1 += 0.00000044926*np.cos(5.05155033853 + 529.6909650946*t)
	Y1 += 0.00000042965*np.cos(2.03245335079 + 1589.0728952838*t)
	Y1 += 0.00000036923*np.cos(0.50255601130 + 775.522611324*t)
	Y1 += 0.00000030992*np.cos(3.31452429738 + 1052.2683831884*t)
	Y1 += 0.00000030098*np.cos(3.75634285091 + 10021.8372800994*t)
	Y1 += 0.00000029363*np.cos(2.59481166718 + 10404.7338123226*t)
	Y1 += 0.00000029951*np.cos(3.91019546176 + 1066.49547719*t)
	Y1 += 0.00000032071*np.cos(1.27581809571 + 149.5631971346*t)
	Y1 += 0.00000021415*np.cos(5.30131509744 + 316.3918696566*t)
	Y1 += 0.00000019871*np.cos(5.85591903319 + 9437.762934887*t)
	Y1 += 0.00000019019*np.cos(0.48946385175 + 227.5261894396*t)
	Y1 += 0.00000017907*np.cos(0.50709742814 + 10988.808157535*t)
	Y1 += 0.00000016079*np.cos(2.44810994983 + 110.2063212194*t)
	Y1 += 0.00000014387*np.cos(2.14852937659 + 9683.5945811164*t)
	Y1 += 0.00000013498*np.cos(2.90084412618 + 191.4482661116*t)
	Y1 += 0.00000013527*np.cos(4.20185541440 + 10742.9765113056*t)
	Y1 += 0.00000015875*np.cos(4.20914007335 + 76.2660712756*t)
	Y1 += 0.00000014059*np.cos(1.92999301659 + 4705.7323075436*t)
	Y1 += 0.00000013447*np.cos(5.86031739106 + 19651.048481098*t)
	Y1 += 0.00000012413*np.cos(4.14057132118 + 515.463871093*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000011814*np.cos(1.50628561093 + 632.7837393132*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000010164*np.cos(0.62992310390 + 73.297125859*t)
	Y1 += 0.00000009222*np.cos(1.25927718333 + 199.0720014364*t)
	Y1 += 0.00000008663*np.cos(3.35360012494 + 543.9180590962*t)
	Y1 += 0.00000007755*np.cos(1.44764390538 + 949.1756089698*t)
	Y1 += 0.00000007691*np.cos(1.12047989646 + 103.0927742186*t)
	Y1 += 0.00000006877*np.cos(3.26548847716 + 9103.9069941176*t)
	Y1 += 0.00000007454*np.cos(4.42301263508 + 15720.8387848784*t)
	Y1 += 0.00000006040*np.cos(3.09328817274 + 11322.6640983044*t)
	Y1 += 0.00000005966*np.cos(0.53259218563 + 10206.1719992102*t)
	Y1 += 0.00000005966*np.cos(5.81970120815 + 10220.3990932118*t)
	Y1 += 0.00000005487*np.cos(4.43944248381 + 853.196381752*t)
	Y1 += 0.00000005170*np.cos(0.37516758388 + 209.3669421749*t)
	Y1 += 0.00000005081*np.cos(1.39059455730 + 217.2312487011*t)
	Y1 += 0.00000004660*np.cos(0.15626149972 + 216.4804891757*t)
	Y1 += 0.00000005176*np.cos(4.06410179125 + 3154.6870848956*t)
	Y1 += 0.00000004553*np.cos(1.60431626596 + 210.1177017003*t)
	Y1 += 0.00000004564*np.cos(3.01891927717 + 20618.0193585336*t)
	Y1 += 0.00000004447*np.cos(5.48065037241 + 323.5054166574*t)
	Y1 += 0.00000004240*np.cos(4.49316795437 + 9999.986450773*t)
	Y1 += 0.00000004157*np.cos(1.86903191118 + 10426.584641649*t)
	Y1 += 0.00000004151*np.cos(1.93098926861 + 63.7358983034*t)
	Y1 += 0.00000004099*np.cos(5.22964063969 + 647.0108333148*t)
	Y1 += 0.00000004649*np.cos(1.29491122903 + 9830.3890139878*t)
	Y1 += 0.00000005058*np.cos(1.73136117173 + 14.2270940016*t)
	Y1 += 0.00000004293*np.cos(2.71452907477 + 735.8765135318*t)
	Y1 += 0.00000004405*np.cos(5.05081380319 + 10596.1820784342*t)
	Y1 += 0.00000003443*np.cos(2.77873462243 + 85.8272988312*t)
	Y1 += 0.00000003590*np.cos(0.89608249763 + 7860.4193924392*t)
	Y1 += 0.00000003302*np.cos(0.78944659795 + 11.0457002639*t)
	Y1 += 0.00000003246*np.cos(4.47251198694 + 526.5095713569*t)
	Y1 += 0.00000003180*np.cos(3.00772018402 + 532.8723588323*t)
	Y1 += 0.00000002903*np.cos(3.22514351914 + 525.7588118315*t)
	Y1 += 0.00000002896*np.cos(1.12069020939 + 117.3198682202*t)
	Y1 += 0.00000002863*np.cos(4.25448918131 + 533.6231183577*t)
	Y1 += 0.00000002838*np.cos(0.45959307618 + 202.2533951741*t)
	Y1 += 0.00000002625*np.cos(0.95628165683 + 8624.2126509272*t)
	Y1 += 0.00000002726*np.cos(2.33981418835 + 19367.1891622328*t)
	Y1 += 0.00000002696*np.cos(5.36941111650 + 7058.5984613154*t)
	Y1 += 0.00000002863*np.cos(2.16989496338 + 95.9792272178*t)
	Y1 += 0.00000002546*np.cos(1.70280413881 + 11015.1064773348*t)
	Y1 += 0.00000002044*np.cos(3.86812530423 + 138.5174968707*t)
	Y1 += 0.00000002707*np.cos(0.24920171339 + 801.8209311238*t)
	Y1 += 0.00000001977*np.cos(2.19636388255 + 742.9900605326*t)
	Y1 += 0.00000002701*np.cos(2.36778194506 + 2118.7638603784*t)
	Y1 += 0.00000002539*np.cos(4.39873959203 + 9411.4646150872*t)
	Y1 += 0.00000001912*np.cos(4.86762627934 + 1109.3785520934*t)
	Y1 += 0.00000001909*np.cos(0.39529260174 + 956.2891559706*t)
	Y1 += 0.00000001768*np.cos(4.34051785227 + 1596.1864422846*t)
	Y1 += 0.00000001933*np.cos(3.28230569196 + 3930.2096962196*t)
	Y1 += 0.00000001699*np.cos(1.87566644469 + 70.8494453042*t)
	Y1 += 0.00000001833*np.cos(0.97295205973 + 13367.9726311066*t)
	Y1 += 0.00000001586*np.cos(1.12226291756 + 40853.142184844*t)
	Y1 += 0.00000001570*np.cos(2.80724611689 + 78.7137518304*t)
	Y1 += 0.00000001758*np.cos(0.69532491254 + 4551.9534970588*t)
	Y1 += 0.00000001992*np.cos(4.09610698677 + 26.2983197998*t)
	Y1 += 0.00000001694*np.cos(0.76426907626 + 1577.3435424478*t)
	Y1 += 0.00000001493*np.cos(5.97213767442 + 440.8252848776*t)
	Y1 += 0.00000001810*np.cos(3.43597556192 + 1581.959348283*t)
	Y1 += 0.00000001465*np.cos(1.19009717807 + 74.7815985673*t)
	Y1 += 0.00000001484*np.cos(5.54999908988 + 7084.8967811152*t)
	Y1 += 0.00000001559*np.cos(2.97028792257 + 1045.1548361876*t)
	Y1 += 0.00000001426*np.cos(5.44329745197 + 12566.1516999828*t)
	Y1 += 0.00000001646*np.cos(2.40413866073 + 224.3447957019*t)
	Y1 += 0.00000001400*np.cos(4.67642362946 + 11272.6674764002*t)
	Y1 += 0.00000001282*np.cos(3.09230484373 + 10218.8084705184*t)
	Y1 += 0.00000001282*np.cos(3.25998855005 + 10207.7626219036*t)
	Y1 += 0.00000001352*np.cos(1.29314419649 + 20419.45754542119*t)
	Y1 += 0.00000001469*np.cos(4.11460578747 + 3128.3887650958*t)
	Y1 += 0.00000001241*np.cos(4.14143822683 + 23581.2581773176*t)
	Y1 += 0.00000001284*np.cos(5.45408487651 + 382.8965322232*t)
	Y1 += 0.00000001307*np.cos(1.82500475732 + 9153.9036160218*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001191*np.cos(3.69515282095 + 2352.8661537718*t)
	Y1 += 0.00000001057*np.cos(0.79522639484 + 309.2783226558*t)
	Y1 += 0.00000001112*np.cos(2.89652371372 + 625.6701923124*t)
	Y1 += 0.00000001000*np.cos(4.09863557302 + 1265.5674786264*t)
	Y1 += 0.00000001084*np.cos(2.78444751991 + 10198.033075026*t)
	Y1 += 0.00000001084*np.cos(3.56784587387 + 10228.538017396*t)
	Y1 += 0.00000001192*np.cos(3.38577049275 + 16496.3613962024*t)
	Y1 += 0.00000000989*np.cos(6.14826697847 + 412.3710968744*t)
	Y1 += 0.00000000917*np.cos(5.67300034485 + 15874.6175953632*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000000936*np.cos(2.99521995909 + 1169.5882514086*t)
	Y1 += 0.00000000943*np.cos(0.21048093986 + 151.0476698429*t)
	Y1 += 0.00000000771*np.cos(1.58200018736 + 942.062061969*t)
	Y1 += 0.00000000760*np.cos(5.36638189114 + 28286.9904848612*t)
	Y1 += 0.00000000747*np.cos(0.58426038651 + 3149.1641605882*t)
	Y1 += 0.00000000762*np.cos(3.43418344370 + 1155.361157407*t)
	Y1 += 0.00000000712*np.cos(1.82235727085 + 71.8126531507*t)
	Y1 += 0.00000000718*np.cos(2.94974266304 + 77.7505439839*t)
	Y1 += 0.00000000617*np.cos(4.93603196300 + 21535.9496445154*t)
	Y1 += 0.00000000625*np.cos(1.61452093926 + 20400.2727726222*t)
	Y1 += 0.00000000613*np.cos(0.59191874324 + 5661.3320491522*t)
	Y1 += 0.00000000820*np.cos(0.36295378777 + 21228.3920235458*t)
	Y1 += 0.00000000674*np.cos(0.56550938814 + 8094.5216858326*t)
	Y1 += 0.00000000633*np.cos(4.96985222859 + 18849.2275499742*t)
	Y1 += 0.00000000718*np.cos(1.70498371588 + 1162.4747044078*t)
	Y1 += 0.00000000657*np.cos(2.20985602421 + 17298.1823273262*t)
	Y1 += 0.00000000504*np.cos(2.36012441072 + 277.0349937414*t)
	Y1 += 0.00000000510*np.cos(5.30981933415 + 20452.8694122218*t)
	Y1 += 0.00000000486*np.cos(5.53252452947 + 422.6660376129*t)
	Y1 += 0.00000000455*np.cos(1.18907814059 + 1692.1656695024*t)
	Y1 += 0.00000000432*np.cos(3.60135550460 + 32217.2001810808*t)
	Y1 += 0.00000000457*np.cos(1.01447998087 + 29050.7837433492*t)
	Y1 += 0.00000000414*np.cos(3.89598271580 + 24356.7807886416*t)
	Y1 += 0.00000000472*np.cos(5.35027481275 + 9146.790069021*t)
	Y1 += 0.00000000391*np.cos(3.73837604066 + 1073.6090241908*t)
	Y1 += 0.00000000375*np.cos(0.35041804232 + 234.6397364404*t)
	Y1 += 0.00000000394*np.cos(2.90954841406 + 5507.5532386674*t)
	Y1 += 0.00000000373*np.cos(3.98254461376 + 415.5524906121*t)
	Y1 += 0.00000000364*np.cos(1.14500385840 + 10639.883737087*t)
	Y1 += 0.00000000361*np.cos(5.90601998518 + 846.0828347512*t)
	Y1 += 0.00000000384*np.cos(5.64976516740 + 330.6189636582*t)
	Y1 += 0.00000000360*np.cos(5.19238212137 + 9786.687355335*t)
	Y1 += 0.00000000361*np.cos(2.31869873474 + 14945.3161735544*t)
	Y1 += 0.00000000422*np.cos(4.94394431892 + 9161.0171630226*t)
	Y1 += 0.00000000439*np.cos(0.89714640250 + 9690.7081281172*t)
	Y1 += 0.00000000425*np.cos(5.51224263435 + 20809.4676246452*t)
	Y1 += 0.00000000440*np.cos(5.44930026371 + 10735.8629643048*t)
	Y1 += 0.00000000335*np.cos(4.48297896956 + 860.3099287528*t)
	Y1 += 0.00000000372*np.cos(5.21504043865 + 10251.3132188468*t)
	Y1 += 0.00000000372*np.cos(1.13725295513 + 10175.2578735752*t)
	Y1 += 0.00000000337*np.cos(3.18444650009 + 71.6002048296*t)
	Y1 += 0.00000000324*np.cos(0.71684229879 + 423.4167971383*t)
	Y1 += 0.00000000433*np.cos(1.36147512776 + 3.9321532631*t)
	Y1 += 0.00000000319*np.cos(5.77038311559 + 17277.4069318338*t)
	Y1 += 0.00000000326*np.cos(1.48465704932 + 77.962992305*t)
	Y1 += 0.00000000384*np.cos(1.50030220266 + 1478.8665740644*t)
	Y1 += 0.00000000389*np.cos(4.76446577072 + 6283.0758499914*t)
	Y1 += 0.00000000316*np.cos(5.62533566974 + 429.7795846137*t)
	Y1 += 0.00000000412*np.cos(4.35484091112 + 22003.9146348698*t)
	Y1 += 0.00000000423*np.cos(1.39634467087 + 18837.49819713819*t)
	Y1 += 0.00000000304*np.cos(3.98761648250 + 145.6310438715*t)
	Y1 += 0.00000000301*np.cos(5.78050751122 + 14765.2390432698*t)
	Y1 += 0.00000000352*np.cos(0.64575728139 + 2.9689454166*t)
	Y1 += 0.00000000351*np.cos(0.93761476307 + 6489.776587288*t)
	Y1 += 0.00000000384*np.cos(4.55881127062 + 210.8514148832*t)
	Y1 += 0.00000000380*np.cos(3.47993786173 + 215.7467759928*t)
	Y1 += 0.00000000297*np.cos(5.78070702462 + 10232.95530711079*t)
	Y1 += 0.00000000297*np.cos(0.57158636916 + 10193.61578531121*t)
	Y1 += 0.00000000360*np.cos(2.88459167183 + 728.762966531*t)
	Y1 += 0.00000000291*np.cos(3.33683517922 + 18073.7049386502*t)
	Y1 += 0.00000000287*np.cos(0.79492340372 + 3442.5749449654*t)
	Y1 += 0.00000000290*np.cos(3.01296539996 + 13745.3462390224*t)
	Y1 += 0.00000000262*np.cos(1.65344723077 + 21202.093703746*t)
	Y1 += 0.00000000338*np.cos(4.31589716519 + 148.0787244263*t)
	Y1 += 0.00000000289*np.cos(4.21532853378 + 20235.1228263104*t)
	Y1 += 0.00000000269*np.cos(6.12924784861 + 9676.4810341156*t)
	Y1 += 0.00000000255*np.cos(0.68716361250 + 437.6438911399*t)
	Y1 += 0.00000000261*np.cos(4.05709707087 + 22779.4372461938*t)
	Y1 += 0.00000000281*np.cos(3.53032805800 + 14919.0178537546*t)
	Y1 += 0.00000000262*np.cos(0.23413334905 + 10750.0900583064*t)
	Y1 += 0.00000000284*np.cos(3.67849455855 + 838.9692877504*t)
	Y1 += 0.00000000256*np.cos(2.84423020029 + 10234.0609417034*t)
	Y1 += 0.00000000256*np.cos(3.50806319349 + 10192.5101507186*t)
	Y1 += 0.00000000238*np.cos(2.72262438861 + 9573.388259897*t)
	Y1 += 0.00000000284*np.cos(1.52451893915 + 4732.0306273434*t)
	Y1 += 0.00000000233*np.cos(3.85294503850 + 18875.525869774*t)
	Y1 += 0.00000000232*np.cos(5.81292836693 + 3723.508958923*t)
	Y1 += 0.00000000285*np.cos(3.95599055369 + 20956.2620575166*t)
	Y1 += 0.00000000270*np.cos(2.83438706731 + 19999.97290154599*t)
	Y1 += 0.00000000234*np.cos(0.03317726903 + 223.5940361765*t)
	Y1 += 0.00000000222*np.cos(4.29914928209 + 508.3503240922*t)
	Y1 += 0.00000000225*np.cos(2.53611507701 + 14143.4952424306*t)
	Y1 += 0.00000000234*np.cos(5.59143946418 + 27511.4678735372*t)
	Y1 += 0.00000000233*np.cos(3.30440847719 + 1272.6810256272*t)
	Y1 += 0.00000000245*np.cos(3.22919068877 + 6681.2248533996*t)
	Y1 += 0.00000000265*np.cos(1.64615612331 + 3.1813937377*t)
	Y1 += 0.00000000232*np.cos(6.01167605637 + 19889.76658032659*t)
	Y1 += 0.00000000199*np.cos(5.04355453043 + 9638.9407478762*t)
	Y1 += 0.00000000218*np.cos(5.53074283644 + 19903.99367432819*t)
	Y1 += 0.00000000203*np.cos(2.88548150239 + 6872.6731195112*t)
	Y1 += 0.00000000201*np.cos(4.46138168832 + 1375.7737998458*t)
	Y1 += 0.00000000234*np.cos(1.73310379947 + 1551.045222648*t)
	Y1 += 0.00000000188*np.cos(1.32418537499 + 10787.6303445458*t)
	Y1 += 0.00000000179*np.cos(4.84532694620 + 30110.1656735384*t)
	Y1 += 0.00000000211*np.cos(2.96248499763 + 8662.240323563*t)
	Y1 += 0.00000000207*np.cos(1.05108863363 + 29864.334027309*t)
	Y1 += 0.00000000181*np.cos(2.37018594067 + 88.865680217*t)
	Y1 += 0.00000000208*np.cos(4.04763155841 + 10007.0999977738*t)
	Y1 += 0.00000000208*np.cos(2.30466183537 + 10419.4710946482*t)
	Y1 += 0.00000000199*np.cos(1.40110998613 + 430.5303441391*t)
	Y1 += 0.00000000177*np.cos(0.78176584307 + 6770.7106012456*t)
	Y1 += 0.00000000189*np.cos(0.25718944825 + 124.433415221*t)
	Y1 += 0.00000000174*np.cos(5.22081710422 + 1368.660252845*t)
	Y1 += 0.00000000184*np.cos(0.09028640270 + 9967.4538999816*t)
	Y1 += 0.00000000167*np.cos(3.42353804022 + 1062.5633239269*t)
	Y1 += 0.00000000180*np.cos(2.72835603995 + 2648.454825473*t)
	Y1 += 0.00000000163*np.cos(3.38894514289 + 10225.014899047*t)
	Y1 += 0.00000000163*np.cos(2.96334825089 + 10201.556193375*t)
	Y1 += 0.00000000157*np.cos(2.10855674162 + 9793.8009023358*t)
	Y1 += 0.00000000156*np.cos(4.49619634182 + 10316.3783204296*t)
	Y1 += 0.00000000156*np.cos(1.85609705196 + 10110.1927719924*t)
	Y1 += 0.00000000160*np.cos(5.67144686210 + 16983.9961474566*t)
	Y1 += 0.00000000178*np.cos(6.26185130623 + 10459.1171924404*t)
	Y1 += 0.00000000204*np.cos(5.28633538343 + 13936.794505134*t)
	Y1 += 0.00000000163*np.cos(4.90881626780 + 8617.0991039264*t)
	Y1 += 0.00000000157*np.cos(3.58488866748 + 13553.8979729108*t)
	Y1 += 0.00000000152*np.cos(5.50666765279 + 160.6088973985*t)
	Y1 += 0.00000000172*np.cos(0.02323350795 + 65.2203710117*t)
	Y1 += 0.00000000154*np.cos(4.59717983879 + 519.3960243561*t)
	Y1 += 0.00000000140*np.cos(5.31634257150 + 8631.326197928*t)
	Y1 += 0.00000000145*np.cos(6.19538998481 + 7064.1213856228*t)
	Y1 += 0.00000000139*np.cos(3.64890818066 + 1055.4497769261*t)
	Y1 += 0.00000000138*np.cos(4.30414447043 + 1258.4539316256*t)
	Y1 += 0.00000000132*np.cos(5.18037129096 + 654.1243803156*t)
	Y1 += 0.00000000136*np.cos(1.73632400099 + 203.0041546995*t)
	Y1 += 0.00000000128*np.cos(3.89903128812 + 10632.7701900862*t)
	Y1 += 0.00000000176*np.cos(3.03968242278 + 5481.2549188676*t)
	Y1 += 0.00000000121*np.cos(4.88476463619 + 1063.3140834523*t)
	Y1 += 0.00000000118*np.cos(3.20236689438 + 551.031606097*t)
	Y1 += 0.00000000120*np.cos(2.88381733148 + 539.9859058331*t)
	Y1 += 0.00000000143*np.cos(3.32004421353 + 7994.5284420242*t)
	Y1 += 0.00000000140*np.cos(4.29359662977 + 1056.2005364515*t)
	Y1 += 0.00000000111*np.cos(4.11806246187 + 222.8603229936*t)
	Y1 += 0.00000000111*np.cos(4.75059162228 + 2125.8774073792*t)
	Y1 += 0.00000000133*np.cos(3.06193509061 + 22.0914005278*t)
	Y1 += 0.00000000106*np.cos(3.32721912157 + 18307.8072320436*t)
	Y1 += 0.00000000136*np.cos(1.56582531149 + 21.3406410024*t)
	Y1 += 0.00000000144*np.cos(6.19128577365 + 299.1263942692*t)
	Y1 += 0.00000000108*np.cos(1.67634660643 + 302.164775655*t)
	Y1 += 0.00000000122*np.cos(0.66618818020 + 28521.0927782546*t)
	Y1 += 0.00000000101*np.cos(1.41448120448 + 191.9584544356*t)
	Y1 += 0.00000000139*np.cos(1.37682327925 + 1485.9801210652*t)
	Y1 += 0.00000000098*np.cos(3.86407649478 + 20.7753954924*t)
	Y1 += 0.00000000104*np.cos(4.60450548155 + 36147.4098773004*t)
	Y1 += 0.00000000114*np.cos(4.33617309197 + 12592.4500197826*t)
	Y1 += 0.00000000112*np.cos(5.96644557875 + 25934.1243310894*t)
	Y1 += 0.00000000095*np.cos(3.83184038977 + 18.1592472647*t)
	Y1 += 0.00000000094*np.cos(1.74801590640 + 87.3117715395*t)
	Y1 += 0.00000000129*np.cos(0.19360167861 + 7564.830720738*t)
	Y1 += 0.00000000093*np.cos(1.72016321457 + 574.3447983348*t)
	Y1 += 0.00000000119*np.cos(3.20779882655 + 1574.8458012822*t)
	Y1 += 0.00000000092*np.cos(3.49830258795 + 9360.089164459*t)
	Y1 += 0.00000000122*np.cos(4.95627332740 + 84.3428261229*t)
	Y1 += 0.00000000095*np.cos(2.09703168525 + 10433.6981886498*t)
	Y1 += 0.00000000095*np.cos(4.25526170853 + 9992.8729037722*t)
	Y1 += 0.00000000117*np.cos(3.09675047102 + 12432.0426503978*t)
	Y1 += 0.00000000097*np.cos(4.30891602532 + 217.964961884*t)
	Y1 += 0.00000000096*np.cos(3.59501512720 + 2111.6503133776*t)
	Y1 += 0.00000000093*np.cos(6.00441441624 + 33.6796175129*t)
	Y1 += 0.00000000087*np.cos(1.75505290273 + 231.4583427027*t)
	Y1 += 0.00000000097*np.cos(0.07381843439 + 72.3339180125*t)
	Y1 += 0.00000000090*np.cos(3.89285886336 + 628.8515860501*t)
	Y1 += 0.00000000089*np.cos(3.43002043997 + 1699.2792165032*t)
	Y1 += 0.00000000110*np.cos(5.01502416629 + 11802.3584414948*t)
	Y1 += 0.00000000108*np.cos(3.56320379623 + 29580.4747084438*t)
	Y1 += 0.00000000093*np.cos(4.32292624028 + 2957.7158944766*t)
	Y1 += 0.00000000080*np.cos(5.99267916099 + 12.5301729722*t)
	Y1 += 0.00000000094*np.cos(6.19217661869 + 20433.6846394228*t)
	Y1 += 0.00000000086*np.cos(3.72646183478 + 208.633228992*t)
	Y1 += 0.00000000097*np.cos(4.70823534788 + 22805.7355659936*t)
	Y1 += 0.00000000076*np.cos(4.88733161640 + 9.5612275556*t)
	Y1 += 0.00000000077*np.cos(4.73669756226 + 38.1330356378*t)
	Y1 += 0.00000000076*np.cos(4.18947022170 + 288.0806940053*t)
	Y1 += 0.00000000077*np.cos(2.93440992089 + 10177.2576795336*t)
	Y1 += 0.00000000077*np.cos(3.41788347289 + 10249.3134128884*t)
	Y1 += 0.00000000087*np.cos(2.72065485079 + 2379.1644735716*t)
	Y1 += 0.00000000080*np.cos(4.52003698796 + 19896.8801273274*t)
	Y1 += 0.00000000096*np.cos(4.64169775712 + 203.7378678824*t)
	Y1 += 0.00000000076*np.cos(5.12453730610 + 362.8622925726*t)
	Y1 += 0.00000000076*np.cos(2.48257518078 + 1471.7530270636*t)
	Y1 += 0.00000000071*np.cos(5.88504650520 + 24150.080051345*t)
	Y1 += 0.00000000075*np.cos(0.38132378506 + 525.0250986486*t)
	Y1 += 0.00000000069*np.cos(2.64295754993 + 114.3991069134*t)
	Y1 += 0.00000000068*np.cos(5.35287430069 + 153.4953503977*t)
	Y1 += 0.00000000068*np.cos(5.70841220182 + 73.8183907208*t)
	Y1 += 0.00000000071*np.cos(4.97845884396 + 29043.67019634839*t)
	Y1 += 0.00000000071*np.cos(0.81628722181 + 534.3568315406*t)
	Y1 += 0.00000000068*np.cos(2.38966490616 + 10383.9584168302*t)
	Y1 += 0.00000000068*np.cos(3.96262848762 + 10042.6126755918*t)
	Y1 += 0.00000000077*np.cos(5.37170501434 + 29573.361161443*t)
	Y1 += 0.00000000073*np.cos(4.93041743859 + 29587.5882554446*t)
	Y1 += 0.00000000064*np.cos(5.24500232218 + 75.7448064138*t)
	Y1 += 0.00000000067*np.cos(0.87827389481 + 31441.6775697568*t)
	Y1 += 0.00000000066*np.cos(4.60699109440 + 42.5864537627*t)
	Y1 += 0.00000000061*np.cos(1.32159131349 + 207.8824694666*t)
	Y1 += 0.00000000061*np.cos(5.37334569388 + 29057.89729034999*t)
	Y1 += 0.00000000081*np.cos(3.17506116360 + 11764.330768859*t)
	Y1 += 0.00000000059*np.cos(0.45173742414 + 218.7157214094*t)
	Y1 += 0.00000000081*np.cos(5.09723714696 + 19360.07561523199*t)
	Y1 += 0.00000000059*np.cos(5.95742231142 + 408.4389436113*t)
	Y1 += 0.00000000067*np.cos(5.87155987351 + 40077.61957352*t)
	Y1 += 0.00000000077*np.cos(5.42249781467 + 20213.271996984*t)
	Y1 += 0.00000000077*np.cos(1.74322642947 + 7834.1210726394*t)
	Y1 += 0.00000000067*np.cos(5.29778871808 + 152.5321425512*t)
	Y1 += 0.00000000076*np.cos(4.82056450443 + 77.2292791221*t)
	Y1 += 0.00000000063*np.cos(1.72943225747 + 79.2350166922*t)
	Y1 += 0.00000000060*np.cos(4.64344417198 + 30831.3049047446*t)
	Y1 += 0.00000000067*np.cos(3.14528019429 + 17778.11626694899*t)
	Y1 += 0.00000000062*np.cos(0.02038792256 + 26735.9452622132*t)
	Y1 += 0.00000000055*np.cos(1.48510731583 + 200.7689224658*t)
	Y1 += 0.00000000062*np.cos(1.67372745688 + 9779.5738083342*t)
	Y1 += 0.00000000055*np.cos(2.03729558857 + 340.7708920448*t)
	Y1 += 0.00000000076*np.cos(0.68351123517 + 146.594251718*t)
	Y1 += 0.00000000054*np.cos(3.33030021242 + 19317.1925403286*t)
	Y1 += 0.00000000072*np.cos(1.86379528122 + 127.4717966068*t)
	Y1 += 0.00000000055*np.cos(3.89290884441 + 831.8557407496*t)
	Y1 += 0.00000000051*np.cos(1.99163070525 + 225.8292684102*t)
	Y1 += 0.00000000058*np.cos(1.52964509339 + 2221.856634597*t)
	Y1 += 0.00000000051*np.cos(2.54206679415 + 29088.811415985*t)
	Y1 += 0.00000000057*np.cos(5.68632410752 + 4.4534181249*t)
	Y1 += 0.00000000051*np.cos(6.18969950383 + 27490.6924780448*t)
	Y1 += 0.00000000059*np.cos(4.32589692662 + 618.5566453116*t)
	Y1 += 0.00000000064*np.cos(3.86347940489 + 1685.0521225016*t)
	Y1 += 0.00000000053*np.cos(3.04286367857 + 70.3281804424*t)
	Y1 += 0.00000000050*np.cos(0.18460290148 + 10103.0792249916*t)
	Y1 += 0.00000000050*np.cos(6.16769049230 + 10323.4918674304*t)
	Y1 += 0.00000000050*np.cos(4.63967914172 + 39793.7602546548*t)
	Y1 += 0.00000000049*np.cos(1.07108765064 + 2008.557539159*t)
	Y1 += 0.00000000048*np.cos(2.75851599881 + 350.3321196004*t)
	Y1 += 0.00000000051*np.cos(0.22846885309 + 210.3783341312*t)
	Y1 += 0.00000000051*np.cos(1.50810894489 + 216.2198567448*t)
	Y1 += 0.00000000059*np.cos(4.81241059013 + 2218.7571041868*t)
	Y1 += 0.00000000049*np.cos(4.34430964617 + 963.4027029714*t)
	Y1 += 0.00000000047*np.cos(2.05343620014 + 20639.87018786*t)
	Y1 += 0.00000000046*np.cos(2.74639399772 + 19786.67380610799*t)
	Y1 += 0.00000000047*np.cos(4.18910494546 + 57837.1383323006*t)
	Y1 += 0.00000000052*np.cos(5.97532002180 + 142.4496501338*t)
	Y1 += 0.00000000045*np.cos(3.23715580244 + 37.611770776*t)
	Y1 += 0.00000000049*np.cos(5.28696888326 + 26709.6469424134*t)
	Y1 += 0.00000000044*np.cos(2.82427089648 + 29999.959352319*t)
	Y1 += 0.00000000044*np.cos(2.92943406327 + 62.2514255951*t)
	Y1 += 0.00000000050*np.cos(2.96247842378 + 1038.0412891868*t)
	Y1 += 0.00000000044*np.cos(3.83988514830 + 33019.0211122046*t)
	Y1 += 0.00000000044*np.cos(5.38579680438 + 16522.6597160022*t)
	Y1 += 0.00000000044*np.cos(4.06912509984 + 524.2743391232*t)
	Y1 += 0.00000000044*np.cos(1.10360628000 + 38.6543004996*t)
	Y1 += 0.00000000043*np.cos(3.56791317771 + 29786.660256881*t)
	Y1 += 0.00000000044*np.cos(3.41315318980 + 535.107591066*t)
	Y1 += 0.00000000051*np.cos(0.93431467650 + 44007.8292697396*t)
	Y1 += 0.00000000059*np.cos(4.20691421118 + 1795.258443721*t)
	Y1 += 0.00000000042*np.cos(3.26999492630 + 195.1398481733*t)
	Y1 += 0.00000000043*np.cos(2.09042966596 + 74.8934731519*t)
	Y1 += 0.00000000043*np.cos(2.58927275174 + 74.6697239827*t)
	Y1 += 0.00000000050*np.cos(0.24741236723 + 131.4039498699*t)
	Y1 += 0.00000000049*np.cos(4.20329151784 + 207.6700211455*t)
	Y1 += 0.00000000051*np.cos(6.00716095198 + 13341.6743113068*t)
	Y1 += 0.00000000048*np.cos(0.71033320787 + 109.9456887885*t)
	Y1 += 0.00000000051*np.cos(5.84065348173 + 13655.8604911764*t)
	Y1 += 0.00000000039*np.cos(0.11315588432 + 1382.8873468466*t)
	Y1 += 0.00000000039*np.cos(4.20765456607 + 20447.3464879144*t)
	Y1 += 0.00000000038*np.cos(2.82768070464 + 703.6331846174*t)
	Y1 += 0.00000000040*np.cos(1.29300189092 + 10.2949407385*t)
	Y1 += 0.00000000046*np.cos(3.79813773531 + 218.9281697305*t)
	Y1 += 0.00000000049*np.cos(1.86400601956 + 25158.6017197654*t)
	Y1 += 0.00000000037*np.cos(2.83593964107 + 511.5317178299*t)
	Y1 += 0.00000000042*np.cos(3.20675553761 + 38204.687359371*t)
	Y1 += 0.00000000041*np.cos(2.07859666220 + 3914.9572250346*t)
	Y1 += 0.00000000035*np.cos(5.19408052685 + 36949.2308084242*t)
	Y1 += 0.00000000036*np.cos(4.38221463656 + 10077.660221201*t)
	Y1 += 0.00000000036*np.cos(1.97007875722 + 10348.910871221*t)
	Y1 += 0.00000000035*np.cos(4.28290669029 + 565.1156877467*t)
	Y1 += 0.00000000041*np.cos(0.04248316951 + 27991.40181316*t)
	Y1 += 0.00000000039*np.cos(1.66722657698 + 18830.38465013739*t)
	Y1 += 0.00000000039*np.cos(1.44095509312 + 30666.1549584328*t)
	Y1 += 0.00000000035*np.cos(4.65527976927 + 547.8502123593*t)
	Y1 += 0.00000000039*np.cos(1.17630403927 + 18844.61174413899*t)
	Y1 += 0.00000000039*np.cos(2.38629347866 + 490.3340891794*t)
	Y1 += 0.00000000042*np.cos(3.87683640837 + 56.6223513026*t)
	Y1 += 0.00000000033*np.cos(3.96639362427 + 750.1036075334*t)
	Y1 += 0.00000000037*np.cos(4.69414299267 + 635.9651330509*t)
	Y1 += 0.00000000037*np.cos(4.90257598448 + 19374.3027092336*t)
	Y1 += 0.00000000038*np.cos(4.43072611572 + 483.2205421786*t)
	Y1 += 0.00000000035*np.cos(3.11075553675 + 526.7702037878*t)
	Y1 += 0.00000000032*np.cos(1.54363874459 + 17468.8551979454*t)
	Y1 += 0.00000000037*np.cos(5.13021678677 + 49515.382508407*t)
	Y1 += 0.00000000040*np.cos(2.31585340283 + 47938.0389659592*t)
	Y1 += 0.00000000035*np.cos(4.37175047624 + 532.6117264014*t)
	Y1 += 0.00000000032*np.cos(3.92861114802 + 16894.5103996106*t)
	Y1 += 0.00000000042*np.cos(5.08244679686 + 55798.4583583984*t)
	Y1 += 0.00000000031*np.cos(1.66877830319 + 21000.9158907568*t)
	Y1 += 0.00000000031*np.cos(1.94569247568 + 20043.6745601988*t)
	Y1 += 0.00000000033*np.cos(6.15577840084 + 48417.97290558199*t)
	Y1 += 0.00000000037*np.cos(0.13743210410 + 265.9892934775*t)
	Y1 += 0.00000000031*np.cos(5.89336305342 + 447.9388318784*t)
	Y1 += 0.00000000034*np.cos(0.55952854816 + 54247.4131357504*t)
	Y1 += 0.00000000032*np.cos(0.55000852758 + 10191.4347168846*t)
	Y1 += 0.00000000032*np.cos(5.80228486620 + 10235.1363755374*t)
	Y1 += 0.00000000031*np.cos(4.45837229281 + 8087.4081388318*t)
	Y1 += 0.00000000030*np.cos(5.15245353060 + 209.106309744*t)
	Y1 += 0.00000000030*np.cos(2.87235713038 + 217.491881132*t)
	Y1 += 0.00000000030*np.cos(0.02207663615 + 92.940845832*t)
	Y1 += 0.00000000030*np.cos(0.39582329080 + 10853.182832525*t)
	Y1 += 0.00000000039*np.cos(5.08202984393 + 1.4844727083*t)
	Y1 += 0.00000000033*np.cos(2.51511900155 + 7255.5696517344*t)
	Y1 += 0.00000000038*np.cos(0.97224853307 + 52.6901980395*t)
	Y1 += 0.00000000029*np.cos(3.64083349524 + 10290.959316639*t)
	Y1 += 0.00000000029*np.cos(2.71145989854 + 10135.611775783*t)
	Y1 += 0.00000000028*np.cos(1.77462370325 + 80.1982245387*t)
	Y1 += 0.00000000028*np.cos(4.16989490843 + 104351.61256629678*t)
	Y1 += 0.00000000028*np.cos(0.27992982935 + 40879.4405046438*t)
	Y1 += 0.00000000032*np.cos(2.59502959120 + 20206.15844998319*t)
	Y1 += 0.00000000032*np.cos(0.89449566883 + 66813.5648357332*t)
	Y1 += 0.00000000034*np.cos(5.07299879866 + 269.9214467406*t)
	Y1 += 0.00000000028*np.cos(2.45238897056 + 107.0249274817*t)
	Y1 += 0.00000000028*np.cos(1.18666538399 + 106.2741679563*t)
	Y1 += 0.00000000031*np.cos(3.61860838672 + 424.1505103212*t)
	Y1 += 0.00000000027*np.cos(2.79364979031 + 1279.794572628*t)
	Y1 += 0.00000000032*np.cos(3.80176203654 + 9835.9119382952*t)
	Y1 += 0.00000000032*np.cos(2.55053135724 + 10590.6591541268*t)
	Y1 += 0.00000000027*np.cos(4.68213586027 + 6298.3283211764*t)
	Y1 += 0.00000000035*np.cos(3.77990327166 + 9985.809413422*t)
	Y1 += 0.00000000035*np.cos(2.57239012212 + 10440.76167900*t)
	Y1 += 0.00000000027*np.cos(3.23525952036 + 1802.3719907218*t)
	Y1 += 0.00000000026*np.cos(3.20523902336 + 34363.365597556*t)
	Y1 += 0.00000000032*np.cos(5.77908535567 + 11265.5539293994*t)
	Y1 += 0.00000000027*np.cos(4.24057714278 + 1898.3512179396*t)
	Y1 += 0.00000000029*np.cos(1.74099609995 + 30206.14490075619*t)
	Y1 += 0.00000000032*np.cos(3.71438295524 + 51868.2486621788*t)
	Y1 += 0.00000000025*np.cos(2.53077774895 + 3532.0606928114*t)
	Y1 += 0.00000000033*np.cos(0.22007720629 + 59728.668054618*t)
	Y1 += 0.00000000029*np.cos(2.13149426586 + 20220.3855439848*t)
	Y1 += 0.00000000024*np.cos(1.14570150294 + 8734.4189721466*t)
	Y1 += 0.00000000028*np.cos(5.75151342282 + 62883.3551395136*t)
	Y1 += 0.00000000024*np.cos(2.78432068759 + 36173.7081971002*t)
	Y1 += 0.00000000024*np.cos(2.85202212155 + 31022.7531708562*t)
	Y1 += 0.00000000024*np.cos(1.83048948732 + 24383.0791084414*t)
	Y1 += 0.00000000027*np.cos(1.25677560111 + 30220.3719947578*t)
	Y1 += 0.00000000023*np.cos(1.14068817117 + 10367.0643566958*t)
	Y1 += 0.00000000023*np.cos(5.21160522261 + 10059.5067357262*t)
	Y1 += 0.00000000026*np.cos(1.22668255838 + 39271.182836561*t)
	Y1 += 0.00000000023*np.cos(6.28082090370 + 650.9429865779*t)
	Y1 += 0.00000000026*np.cos(1.70916432914 + 39256.95574255939*t)
	Y1 += 0.00000000023*np.cos(4.99790910102 + 137.0330241624*t)
	Y1 += 0.00000000023*np.cos(3.28519702781 + 35.685355083*t)
	Y1 += 0.00000000023*np.cos(1.65963740543 + 44809.6502008634*t)
	Y1 += 0.00000000024*np.cos(1.93436586234 + 14128.2427712456*t)
	Y1 += 0.00000000023*np.cos(3.28897425519 + 28.5718080822*t)
	Y1 += 0.00000000022*np.cos(5.43332862700 + 337.732510659*t)
	Y1 += 0.00000000026*np.cos(5.25543048954 + 8101.6352328334*t)
	Y1 += 0.00000000022*np.cos(1.35770769295 + 24978.5245894808*t)
	Y1 += 0.00000000023*np.cos(5.16035150168 + 2.4476805548*t)
	Y1 += 0.00000000023*np.cos(4.82793901796 + 643.0786800517*t)
	Y1 += 0.00000000030*np.cos(5.92769775641 + 17248.4253018544*t)
	Y1 += 0.00000000022*np.cos(2.63350741660 + 43071.8992890308*t)
	Y1 += 0.00000000024*np.cos(2.87771905446 + 34596.3646546524*t)
	Y1 += 0.00000000024*np.cos(5.25759177705 + 1361.5467058442*t)
	Y1 += 0.00000000022*np.cos(0.18339358050 + 30426.557543195*t)
	Y1 += 0.00000000022*np.cos(1.70327289493 + 934.9485149682*t)
	Y1 += 0.00000000023*np.cos(2.98215154259 + 284.1485407422*t)
	Y1 += 0.00000000024*np.cos(5.00394819251 + 47623.8527860896*t)
	Y1 += 0.00000000023*np.cos(2.48673782346 + 27461.7108480654*t)
	Y1 += 0.00000000024*np.cos(2.31573395875 + 70743.77453195279*t)
	Y1 += 0.00000000024*np.cos(4.50083076815 + 191.2076949102*t)
	Y1 += 0.00000000021*np.cos(1.05341004601 + 40.5807161926*t)
	Y1 += 0.00000000022*np.cos(2.50653771933 + 9566.2747128962*t)
	Y1 += 0.00000000023*np.cos(4.03659045702 + 6309.3741697912*t)
	Y1 += 0.00000000021*np.cos(0.48695657465 + 10949.1620597428*t)
	Y1 += 0.00000000021*np.cos(5.86533681913 + 9477.4090326792*t)
	Y1 += 0.00000000024*np.cos(5.27936669763 + 10288.0671447783*t)
	Y1 += 0.00000000024*np.cos(1.07292669615 + 10138.5039476437*t)
	Y1 += 0.00000000027*np.cos(2.11906192246 + 9580.5018068978*t)
	Y1 += 0.00000000020*np.cos(0.64178978255 + 11279.781023401*t)
	Y1 += 0.00000000021*np.cos(1.35819574535 + 525.4981794006*t)
	Y1 += 0.00000000024*np.cos(3.37809061150 + 540.7366653585*t)
	Y1 += 0.00000000025*np.cos(5.09676204562 + 96.8729990951*t)
	Y1 += 0.00000000020*np.cos(3.97670500643 + 251.4321310758*t)
	Y1 += 0.00000000027*np.cos(4.63548485210 + 1905.4647649404*t)
	Y1 += 0.00000000024*np.cos(3.34248986355 + 219.4494345923*t)
	Y1 += 0.00000000023*np.cos(1.10446661612 + 10263.0425716828*t)
	Y1 += 0.00000000023*np.cos(5.24782677766 + 10163.5285207392*t)
	Y1 += 0.00000000022*np.cos(0.81492467590 + 46386.9937433112*t)
	Y1 += 0.00000000020*np.cos(1.20516011145 + 18300.69368504279*t)
	Y1 += 0.00000000026*np.cos(1.64244752119 + 63658.8777508376*t)
	Y1 += 0.00000000019*np.cos(0.23803378346 + 20316.36477120259*t)
	Y1 += 0.00000000020*np.cos(5.63439724563 + 62081.5342083898*t)
	Y1 += 0.00000000019*np.cos(1.29742572058 + 99.1606209555*t)
	Y1 += 0.00000000020*np.cos(1.96622391594 + 81.8951455681*t)
	Y1 += 0.00000000020*np.cos(1.13738100407 + 49477.35483577119*t)
	Y1 += 0.00000000022*np.cos(2.04754590576 + 114.1384744825*t)
	Y1 += 0.00000000018*np.cos(3.04721004004 + 48739.859897083*t)
	Y1 += 0.00000000021*np.cos(5.89651875201 + 344.7030453079*t)
	Y1 += 0.00000000018*np.cos(0.41312927370 + 479.2883889155*t)
	Y1 += 0.00000000018*np.cos(0.69437828159 + 9050.8108418032*t)
	Y1 += 0.00000000017*np.cos(3.19845935674 + 28313.288804661*t)
	Y1 += 0.00000000018*np.cos(1.05659266627 + 47.6942631934*t)
	Y1 += 0.00000000017*np.cos(2.89862116564 + 10497.1448650762*t)
	Y1 += 0.00000000017*np.cos(3.45367222814 + 9929.4262273458*t)
	Y1 += 0.00000000019*np.cos(1.03948249798 + 113.3877149571*t)
	Y1 += 0.00000000017*np.cos(1.80554865966 + 24341.5283174566*t)
	Y1 += 0.00000000018*np.cos(5.36139144851 + 66.70484372*t)
	Y1 += 0.00000000017*np.cos(2.91822171111 + 235.3904959658*t)
	Y1 += 0.00000000017*np.cos(3.41082764288 + 38734.3783244656*t)
	Y1 += 0.00000000017*np.cos(5.48500145482 + 19624.7501612982*t)
	Y1 += 0.00000000018*np.cos(5.53310135976 + 436.8931316145*t)
	Y1 += 0.00000000017*np.cos(1.42397530088 + 18314.9207790444*t)
	Y1 += 0.00000000016*np.cos(4.13205563870 + 1603.2999892854*t)
	Y1 += 0.00000000017*np.cos(5.48950262612 + 909.8187330546*t)
	Y1 += 0.00000000018*np.cos(4.74133155662 + 42430.4857272918*t)
	Y1 += 0.00000000018*np.cos(5.39681560820 + 358.9301393095*t)
	Y1 += 0.00000000016*np.cos(3.86440292184 + 9745.3205558566*t)
	Y1 += 0.00000000016*np.cos(2.48789047194 + 10681.2505365654*t)
	Y1 += 0.00000000017*np.cos(6.15299165414 + 533.8837507886*t)
	Y1 += 0.00000000016*np.cos(3.68087340604 + 1788.1448967202*t)
	Y1 += 0.00000000019*np.cos(4.72886285917 + 207.1487562837*t)
	Y1 += 0.00000000018*np.cos(2.57871349196 + 67.6680515665*t)
	Y1 += 0.00000000017*np.cos(3.83900403821 + 497.4476361802*t)
	Y1 += 0.00000000015*np.cos(3.83207526863 + 10199.0584522094*t)
	Y1 += 0.00000000015*np.cos(2.52021812515 + 10227.5126402126*t)
	Y1 += 0.00000000017*np.cos(5.84159114613 + 417.0369633204*t)
	Y1 += 0.00000000019*np.cos(5.68038426151 + 55022.9357470744*t)
	Y1 += 0.00000000015*np.cos(5.64700993390 + 27197.2816936676*t)
	Y1 += 0.00000000014*np.cos(5.96767163228 + 41654.9631159678*t)
	Y1 += 0.00000000015*np.cos(1.13326219925 + 53285.1848352418*t)
	Y1 += 0.00000000014*np.cos(4.20789843971 + 175.1660598002*t)
	Y1 += 0.00000000015*np.cos(0.77488131034 + 66011.74390460939*t)
	Y1 += 0.00000000015*np.cos(3.58225207772 + 220.4608265486*t)
	Y1 += 0.00000000015*np.cos(1.26648472710 + 38727.2647774648*t)
	Y1 += 0.00000000014*np.cos(0.57687637914 + 416.3032501375*t)
	Y1 += 0.00000000015*np.cos(6.23108278461 + 46360.6954235114*t)
	Y1 += 0.00000000016*np.cos(5.66380096786 + 42456.7840470916*t)
	Y1 += 0.00000000015*np.cos(5.66819746086 + 146.3818033969*t)
	Y1 += 0.00000000019*np.cos(3.03299422296 + 67589.08744705719*t)
	Y1 += 0.00000000014*np.cos(5.08678738606 + 39999.945803092*t)
	Y1 += 0.00000000019*np.cos(1.98725402688 + 554.0699874828*t)
	Y1 += 0.00000000014*np.cos(6.23973256044 + 11026.8358301708*t)
	Y1 += 0.00000000014*np.cos(0.11256083334 + 9399.7352622512*t)
	Y1 += 0.00000000015*np.cos(4.29556829645 + 38526.574350872*t)
	Y1 += 0.00000000014*np.cos(2.61946078132 + 99.9113804809*t)
	Y1 += 0.00000000014*np.cos(3.43836595760 + 518.6452648307*t)
	Y1 += 0.00000000016*np.cos(2.23316987672 + 50317.2034395308*t)
	Y1 += 0.00000000014*np.cos(6.10752868717 + 37895.4262903674*t)
	Y1 += 0.00000000014*np.cos(3.65383778432 + 1049.0869894507*t)
	Y1 += 0.00000000014*np.cos(6.16126093965 + 37410.5672398786*t)
	Y1 += 0.00000000014*np.cos(3.58473930386 + 351.8165923087*t)
	Y1 += 0.00000000014*np.cos(1.37134390822 + 50290.905119731*t)
	Y1 += 0.00000000014*np.cos(3.09174780856 + 429.0458714308*t)
	Y1 += 0.00000000015*np.cos(4.65282324499 + 21485.95302261119*t)
	Y1 += 0.00000000013*np.cos(4.57052023792 + 52670.0695933026*t)
	Y1 += 0.00000000013*np.cos(4.57568246165 + 32243.4985008806*t)
	Y1 += 0.00000000016*np.cos(1.89603210492 + 404.5067903482*t)
	return Y1*t




def Venus_Y2 (t): # 264 terms of order 2

	Y2 = 0.
	Y2 -= 0.00002062969
	Y2 += 0.00000702050*np.cos(3.52724964753 + 20426.571092422*t)
	Y2 += 0.00000265708*np.cos(4.68092693055 + 10213.285546211*t)
	Y2 += 0.00000160849*np.cos(2.83104666823 + 206.1855484372*t)
	Y2 += 0.00000155973*np.cos(5.19309730583 + 220.4126424388*t)
	Y2 += 0.00000118316*np.cos(5.70681506981 + 522.5774180938*t)
	Y2 += 0.00000115781*np.cos(1.78259431361 + 536.8045120954*t)
	Y2 += 0.00000103374*np.cos(4.03691274682 + 213.299095438*t)
	Y2 += 0.00000065392*np.cos(4.05826871786 + 426.598190876*t)
	Y2 += 0.00000073065*np.cos(0.61752643976 + 529.6909650946*t)
	Y2 += 0.00000039437*np.cos(0.41578903342 + 1059.3819301892*t)
	Y2 += 0.00000014254*np.cos(4.25680464915 + 433.7117378768*t)
	Y2 += 0.00000011646*np.cos(3.93744761819 + 30639.856638633*t)
	Y2 += 0.00000014479*np.cos(0.14336346755 + 7.1135470008*t)
	Y2 += 0.00000012723*np.cos(1.91903810105 + 419.4846438752*t)
	Y2 += 0.00000009344*np.cos(3.14385567645 + 639.897286314*t)
	Y2 += 0.00000008639*np.cos(1.13135823620 + 10186.9872264112*t)
	Y2 += 0.00000008604*np.cos(5.22297159997 + 10239.5838660108*t)
	Y2 += 0.00000007720*np.cos(5.06798604557 + 227.5261894396*t)
	Y2 += 0.00000006795*np.cos(2.30303656447 + 1066.49547719*t)
	Y2 += 0.00000005452*np.cos(5.20193437243 + 1052.2683831884*t)
	Y2 += 0.00000005040*np.cos(5.84239832938 + 515.463871093*t)
	Y2 += 0.00000003852*np.cos(0.87182418595 + 1589.0728952838*t)
	Y2 += 0.00000003729*np.cos(2.96611895542 + 199.0720014364*t)
	Y2 += 0.00000003521*np.cos(1.65043749771 + 543.9180590962*t)
	Y2 += 0.00000003811*np.cos(5.48798160948 + 9437.762934887*t)
	Y2 += 0.00000002807*np.cos(1.65676292385 + 8635.9420037632*t)
	Y2 += 0.00000003369*np.cos(0.86189885486 + 10988.808157535*t)
	Y2 += 0.00000002198*np.cos(2.17683619702 + 10021.8372800994*t)
	Y2 += 0.00000002289*np.cos(4.69814874247 + 11790.6290886588*t)
	Y2 += 0.00000002148*np.cos(4.17521761989 + 10404.7338123226*t)
	Y2 += 0.00000001696*np.cos(5.08313144954 + 775.522611324*t)
	Y2 += 0.00000001351*np.cos(0.59351678849 + 316.3918696566*t)
	Y2 += 0.00000001409*np.cos(4.65471130275 + 216.4804891757*t)
	Y2 += 0.00000001321*np.cos(3.39383854482 + 647.0108333148*t)
	Y2 += 0.00000001368*np.cos(3.38543777835 + 210.1177017003*t)
	Y2 += 0.00000001717*np.cos(0.02861328541 + 14.2270940016*t)
	Y2 += 0.00000000974*np.cos(2.45036377276 + 853.196381752*t)
	Y2 += 0.00000000950*np.cos(2.81842708673 + 632.7837393132*t)
	Y2 += 0.00000000848*np.cos(6.23917434526 + 526.5095713569*t)
	Y2 += 0.00000000806*np.cos(2.96434145307 + 103.0927742186*t)
	Y2 += 0.00000000825*np.cos(1.24361863355 + 532.8723588323*t)
	Y2 += 0.00000000761*np.cos(4.73161044526 + 209.3669421749*t)
	Y2 += 0.00000000733*np.cos(3.30972792259 + 217.2312487011*t)
	Y2 += 0.00000000885*np.cos(0.58376168802 + 110.2063212194*t)
	Y2 += 0.00000000689*np.cos(4.21955395780 + 440.8252848776*t)
	Y2 += 0.00000000716*np.cos(6.06671484212 + 9830.3890139878*t)
	Y2 += 0.00000000644*np.cos(0.22734493457 + 4705.7323075436*t)
	Y2 += 0.00000000682*np.cos(0.28558057356 + 10596.1820784342*t)
	Y2 += 0.00000000631*np.cos(5.67308971270 + 117.3198682202*t)
	Y2 += 0.00000000600*np.cos(3.56706010534 + 323.5054166574*t)
	Y2 += 0.00000000594*np.cos(1.23861380027 + 19651.048481098*t)
	Y2 += 0.00000000549*np.cos(3.24495575230 + 949.1756089698*t)
	Y2 += 0.00000000606*np.cos(3.86357846284 + 95.9792272178*t)
	Y2 += 0.00000000554*np.cos(4.44452698973 + 191.4482661116*t)
	Y2 += 0.00000000726*np.cos(5.43722942949 + 74.7815985673*t)
	Y2 += 0.00000000528*np.cos(3.41861650599 + 9683.5945811164*t)
	Y2 += 0.00000000527*np.cos(2.94644114647 + 10742.9765113056*t)
	Y2 += 0.00000000545*np.cos(4.73162468373 + 1045.1548361876*t)
	Y2 += 0.00000000599*np.cos(4.43359462367 + 735.8765135318*t)
	Y2 += 0.00000000490*np.cos(1.25898273127 + 525.7588118315*t)
	Y2 += 0.00000000488*np.cos(6.22654201321 + 533.6231183577*t)
	Y2 += 0.00000000437*np.cos(2.81553406247 + 1596.1864422846*t)
	Y2 += 0.00000000566*np.cos(0.35292137179 + 801.8209311238*t)
	Y2 += 0.00000000519*np.cos(4.53503189245 + 149.5631971346*t)
	Y2 += 0.00000000525*np.cos(5.72227596543 + 7058.5984613154*t)
	Y2 += 0.00000000328*np.cos(6.11646091965 + 15720.8387848784*t)
	Y2 += 0.00000000317*np.cos(1.28846217460 + 2118.7638603784*t)
	Y2 += 0.00000000358*np.cos(2.02954020915 + 11015.1064773348*t)
	Y2 += 0.00000000286*np.cos(1.68423535567 + 9103.9069941176*t)
	Y2 += 0.00000000362*np.cos(4.34706999662 + 9411.4646150872*t)
	Y2 += 0.00000000299*np.cos(3.84462203798 + 26.2983197998*t)
	Y2 += 0.00000000349*np.cos(4.12933332026 + 63.7358983034*t)
	Y2 += 0.00000000359*np.cos(0.61996179973 + 13367.9726311066*t)
	Y2 += 0.00000000337*np.cos(1.63942541135 + 412.3710968744*t)
	Y2 += 0.00000000250*np.cos(4.66823756637 + 11322.6640983044*t)
	Y2 += 0.00000000270*np.cos(5.28007746957 + 1581.959348283*t)
	Y2 += 0.00000000260*np.cos(4.50952770985 + 625.6701923124*t)
	Y2 += 0.00000000237*np.cos(0.07292901465 + 70.8494453042*t)
	Y2 += 0.00000000227*np.cos(4.92862031663 + 234.6397364404*t)
	Y2 += 0.00000000239*np.cos(5.77307549832 + 3154.6870848956*t)
	Y2 += 0.00000000219*np.cos(5.43349299793 + 11.0457002639*t)
	Y2 += 0.00000000256*np.cos(5.25900695618 + 956.2891559706*t)
	Y2 += 0.00000000301*np.cos(4.25962414255 + 3128.3887650958*t)
	Y2 += 0.00000000218*np.cos(4.61617873387 + 78.7137518304*t)
	Y2 += 0.00000000283*np.cos(0.60090092021 + 85.8272988312*t)
	Y2 += 0.00000000211*np.cos(3.29348428114 + 942.062061969*t)
	Y2 += 0.00000000226*np.cos(3.69462756239 + 73.297125859*t)
	Y2 += 0.00000000190*np.cos(0.21249868991 + 10426.584641649*t)
	Y2 += 0.00000000190*np.cos(6.13979470387 + 9999.986450773*t)
	Y2 += 0.00000000235*np.cos(0.31453942563 + 36.6485629295*t)
	Y2 += 0.00000000213*np.cos(2.54349021425 + 309.2783226558*t)
	Y2 += 0.00000000192*np.cos(4.62315723240 + 20618.0193585336*t)
	Y2 += 0.00000000224*np.cos(4.02383631251 + 39.6175083461*t)
	Y2 += 0.00000000231*np.cos(2.66318410477 + 202.2533951741*t)
	Y2 += 0.00000000187*np.cos(1.29115653830 + 1169.5882514086*t)
	Y2 += 0.00000000167*np.cos(2.07259165182 + 1073.6090241908*t)
	Y2 += 0.00000000196*np.cos(5.64541899687 + 224.3447957019*t)
	Y2 += 0.00000000158*np.cos(5.13689612572 + 1155.361157407*t)
	Y2 += 0.00000000179*np.cos(0.42909787895 + 21228.3920235458*t)
	Y2 += 0.00000000137*np.cos(0.50600690701 + 742.9900605326*t)
	Y2 += 0.00000000135*np.cos(5.63458486706 + 138.5174968707*t)
	Y2 += 0.00000000148*np.cos(1.53909219281 + 76.2660712756*t)
	Y2 += 0.00000000133*np.cos(6.00639174435 + 508.3503240922*t)
	Y2 += 0.00000000156*np.cos(4.63001323046 + 40853.142184844*t)
	Y2 += 0.00000000162*np.cos(0.68333343155 + 382.8965322232*t)
	Y2 += 0.00000000126*np.cos(3.76226961231 + 330.6189636582*t)
	Y2 += 0.00000000126*np.cos(2.61435997717 + 860.3099287528*t)
	Y2 += 0.00000000125*np.cos(1.07117378709 + 18849.2275499742*t)
	Y2 += 0.00000000142*np.cos(5.97606134065 + 1577.3435424478*t)
	Y2 += 0.00000000158*np.cos(2.17797348306 + 38.1330356378*t)
	Y2 += 0.00000000110*np.cos(2.14128325211 + 8624.2126509272*t)
	Y2 += 0.00000000141*np.cos(2.93513683988 + 7860.4193924392*t)
	Y2 += 0.00000000109*np.cos(4.55956211819 + 2352.8661537718*t)
	Y2 += 0.00000000115*np.cos(4.52412782775 + 223.5940361765*t)
	Y2 += 0.00000000110*np.cos(4.93056089704 + 71.6002048296*t)
	Y2 += 0.00000000115*np.cos(3.76754615650 + 429.7795846137*t)
	Y2 += 0.00000000106*np.cos(6.02834271847 + 77.962992305*t)
	Y2 += 0.00000000134*np.cos(2.07232763439 + 17298.1823273262*t)
	Y2 += 0.00000000123*np.cos(4.57966985938 + 728.762966531*t)
	Y2 += 0.00000000115*np.cos(4.27710770643 + 20452.8694122218*t)
	Y2 += 0.00000000105*np.cos(6.21526366678 + 1162.4747044078*t)
	Y2 += 0.00000000102*np.cos(3.63292130858 + 422.6660376129*t)
	Y2 += 0.00000000084*np.cos(4.77208861984 + 124.433415221*t)
	Y2 += 0.00000000074*np.cos(4.08123538694 + 88.865680217*t)
	Y2 += 0.00000000076*np.cos(2.63432357020 + 423.4167971383*t)
	Y2 += 0.00000000073*np.cos(5.78330657332 + 1265.5674786264*t)
	Y2 += 0.00000000076*np.cos(0.89056324144 + 7084.8967811152*t)
	Y2 += 0.00000000071*np.cos(1.48891806144 + 551.031606097*t)
	Y2 += 0.00000000081*np.cos(0.13371582190 + 519.3960243561*t)
	Y2 += 0.00000000071*np.cos(5.87255690826 + 23581.2581773176*t)
	Y2 += 0.00000000068*np.cos(3.39472444791 + 654.1243803156*t)
	Y2 += 0.00000000064*np.cos(4.23014249947 + 19367.1891622328*t)
	Y2 += 0.00000000063*np.cos(0.19465269649 + 1109.3785520934*t)
	Y2 += 0.00000000074*np.cos(1.59098773305 + 16496.3613962024*t)
	Y2 += 0.00000000072*np.cos(6.15951862716 + 21.3406410024*t)
	Y2 += 0.00000000060*np.cos(3.13717737901 + 191.9584544356*t)
	Y2 += 0.00000000061*np.cos(2.45374361751 + 9153.9036160218*t)
	Y2 += 0.00000000063*np.cos(2.58253929093 + 18073.7049386502*t)
	Y2 += 0.00000000065*np.cos(3.55971117777 + 203.0041546995*t)
	Y2 += 0.00000000064*np.cos(1.05451249819 + 539.9859058331*t)
	Y2 += 0.00000000061*np.cos(5.33630384952 + 838.9692877504*t)
	Y2 += 0.00000000061*np.cos(0.00617004446 + 3.1813937377*t)
	Y2 += 0.00000000047*np.cos(3.46367064388 + 302.164775655*t)
	Y2 += 0.00000000045*np.cos(2.73683504159 + 846.0828347512*t)
	Y2 += 0.00000000054*np.cos(0.79386600924 + 20809.4676246452*t)
	Y2 += 0.00000000045*np.cos(2.31642282675 + 145.6310438715*t)
	Y2 += 0.00000000043*np.cos(2.21625350053 + 29050.7837433492*t)
	Y2 += 0.00000000055*np.cos(1.81114570337 + 4732.0306273434*t)
	Y2 += 0.00000000043*np.cos(1.72253634885 + 8094.5216858326*t)
	Y2 += 0.00000000047*np.cos(1.74738635330 + 1062.5633239269*t)
	Y2 += 0.00000000049*np.cos(4.77430806005 + 3930.2096962196*t)
	Y2 += 0.00000000044*np.cos(2.81774994428 + 10787.6303445458*t)
	Y2 += 0.00000000044*np.cos(3.53454344950 + 9638.9407478762*t)
	Y2 += 0.00000000046*np.cos(3.14760491945 + 3.9321532631*t)
	Y2 += 0.00000000046*np.cos(0.97289096935 + 22003.9146348698*t)
	Y2 += 0.00000000038*np.cos(5.98916947033 + 1258.4539316256*t)
	Y2 += 0.00000000040*np.cos(0.56664961294 + 6283.0758499914*t)
	Y2 += 0.00000000035*np.cos(6.26763450664 + 1692.1656695024*t)
	Y2 += 0.00000000033*np.cos(4.03936498647 + 277.0349937414*t)
	Y2 += 0.00000000030*np.cos(3.29256356524 + 2125.8774073792*t)
	Y2 += 0.00000000033*np.cos(5.75412898458 + 14919.0178537546*t)
	Y2 += 0.00000000035*np.cos(5.96755475967 + 1056.2005364515*t)
	Y2 += 0.00000000039*np.cos(4.91039224856 + 1574.8458012822*t)
	Y2 += 0.00000000037*np.cos(3.04751770033 + 8662.240323563*t)
	Y2 += 0.00000000028*np.cos(2.28310684992 + 20235.1228263104*t)
	Y2 += 0.00000000036*np.cos(4.84158532799 + 437.6438911399*t)
	Y2 += 0.00000000038*np.cos(3.51477120338 + 12566.1516999828*t)
	Y2 += 0.00000000028*np.cos(1.90040914464 + 1055.4497769261*t)
	Y2 += 0.00000000033*np.cos(5.70769321932 + 6489.776587288*t)
	Y2 += 0.00000000031*np.cos(1.82502538910 + 1272.6810256272*t)
	Y2 += 0.00000000027*np.cos(5.52864193077 + 10639.883737087*t)
	Y2 += 0.00000000027*np.cos(0.82365146301 + 9786.687355335*t)
	Y2 += 0.00000000029*np.cos(3.29953382621 + 28286.9904848612*t)
	Y2 += 0.00000000030*np.cos(1.80392203545 + 24356.7807886416*t)
	Y2 += 0.00000000027*np.cos(4.68673408301 + 1038.0412891868*t)
	Y2 += 0.00000000026*np.cos(5.34455326161 + 3149.1641605882*t)
	Y2 += 0.00000000027*np.cos(0.29620716954 + 14143.4952424306*t)
	Y2 += 0.00000000029*np.cos(0.08375583590 + 1485.9801210652*t)
	Y2 += 0.00000000027*np.cos(6.07872663556 + 618.5566453116*t)
	Y2 += 0.00000000026*np.cos(5.52380000200 + 415.5524906121*t)
	Y2 += 0.00000000030*np.cos(2.30925665899 + 20400.2727726222*t)
	Y2 += 0.00000000026*np.cos(2.03778959040 + 18875.525869774*t)
	Y2 += 0.00000000024*np.cos(3.73809869847 + 11272.6674764002*t)
	Y2 += 0.00000000026*np.cos(3.49078871449 + 430.5303441391*t)
	Y2 += 0.00000000024*np.cos(1.05266162760 + 27511.4678735372*t)
	Y2 += 0.00000000024*np.cos(0.28968474189 + 21535.9496445154*t)
	Y2 += 0.00000000024*np.cos(1.99820614050 + 18.1592472647*t)
	Y2 += 0.00000000023*np.cos(6.16563076611 + 231.4583427027*t)
	Y2 += 0.00000000023*np.cos(5.58098323545 + 831.8557407496*t)
	Y2 += 0.00000000022*np.cos(1.57206710017 + 18307.8072320436*t)
	Y2 += 0.00000000025*np.cos(1.67396248390 + 2648.454825473*t)
	Y2 += 0.00000000021*np.cos(4.15712645283 + 447.9388318784*t)
	Y2 += 0.00000000024*np.cos(0.66675947895 + 1368.660252845*t)
	Y2 += 0.00000000020*np.cos(5.70175704295 + 10.2949407385*t)
	Y2 += 0.00000000025*np.cos(4.18795706116 + 5507.5532386674*t)
	Y2 += 0.00000000022*np.cos(3.76535003503 + 151.0476698429*t)
	Y2 += 0.00000000020*np.cos(1.82615991897 + 1699.2792165032*t)
	Y2 += 0.00000000019*np.cos(0.17448576187 + 1063.3140834523*t)
	Y2 += 0.00000000020*np.cos(0.96756200367 + 35.1640902212*t)
	Y2 += 0.00000000023*np.cos(0.64543351157 + 13936.794505134*t)
	Y2 += 0.00000000021*np.cos(4.76218572464 + 72.3339180125*t)
	Y2 += 0.00000000018*np.cos(1.79009115313 + 28521.0927782546*t)
	Y2 += 0.00000000018*np.cos(4.04819585578 + 1471.7530270636*t)
	Y2 += 0.00000000016*np.cos(3.64206691792 + 1478.8665740644*t)
	Y2 += 0.00000000016*np.cos(0.58395212576 + 22.0914005278*t)
	Y2 += 0.00000000017*np.cos(0.49891545478 + 77.7505439839*t)
	Y2 += 0.00000000016*np.cos(3.38818988576 + 41.1019810544*t)
	Y2 += 0.00000000014*np.cos(3.27141245862 + 1375.7737998458*t)
	Y2 += 0.00000000015*np.cos(3.46067246830 + 160.6088973985*t)
	Y2 += 0.00000000014*np.cos(1.62650115265 + 21202.093703746*t)
	Y2 += 0.00000000014*np.cos(1.00989513563 + 17277.4069318338*t)
	Y2 += 0.00000000017*np.cos(0.01999942730 + 77.2292791221*t)
	Y2 += 0.00000000014*np.cos(3.69383400063 + 11764.330768859*t)
	Y2 += 0.00000000014*np.cos(4.11314424872 + 71.8126531507*t)
	Y2 += 0.00000000015*np.cos(1.62123638185 + 65.2203710117*t)
	Y2 += 0.00000000016*np.cos(1.34949765828 + 32217.2001810808*t)
	Y2 += 0.00000000013*np.cos(2.10315959516 + 131.4039498699*t)
	Y2 += 0.00000000013*np.cos(0.36409212654 + 34570.0663348526*t)
	Y2 += 0.00000000012*np.cos(3.60070147194 + 337.732510659*t)
	Y2 += 0.00000000012*np.cos(5.16899217088 + 195.1398481733*t)
	Y2 += 0.00000000013*np.cos(1.57968548593 + 408.4389436113*t)
	Y2 += 0.00000000013*np.cos(5.39780269855 + 22779.4372461938*t)
	Y2 += 0.00000000011*np.cos(3.20491922374 + 25934.1243310894*t)
	Y2 += 0.00000000012*np.cos(2.32661613460 + 31441.6775697568*t)
	Y2 += 0.00000000015*np.cos(2.03363077483 + 29580.4747084438*t)
	Y2 += 0.00000000014*np.cos(5.41918866932 + 2111.6503133776*t)
	Y2 += 0.00000000011*np.cos(4.73842604358 + 511.5317178299*t)
	Y2 += 0.00000000012*np.cos(2.63845374146 + 963.4027029714*t)
	Y2 += 0.00000000010*np.cos(2.74385211018 + 547.8502123593*t)
	Y2 += 0.00000000012*np.cos(1.93485474982 + 25158.6017197654*t)
	Y2 += 0.00000000010*np.cos(4.24006763767 + 127.4717966068*t)
	Y2 += 0.00000000010*np.cos(3.10795031986 + 362.8622925726*t)
	Y2 += 0.00000000012*np.cos(5.50291077360 + 1685.0521225016*t)
	Y2 += 0.00000000010*np.cos(3.38695373136 + 934.9485149682*t)
	Y2 += 0.00000000010*np.cos(3.93946468852 + 14945.3161735544*t)
	Y2 += 0.00000000013*np.cos(3.34698985021 + 84.3428261229*t)
	Y2 += 0.00000000009*np.cos(4.89802068656 + 1382.8873468466*t)
	Y2 += 0.00000000012*np.cos(1.08976567704 + 148.0787244263*t)
	Y2 += 0.00000000009*np.cos(0.86970882362 + 153.4953503977*t)
	Y2 += 0.00000000010*np.cos(5.98112560726 + 56.6223513026*t)
	Y2 += 0.00000000009*np.cos(1.78868782927 + 38500.2760310722*t)
	Y2 += 0.00000000011*np.cos(1.80725352207 + 222.8603229936*t)
	Y2 += 0.00000000008*np.cos(4.44940554836 + 92.940845832*t)
	Y2 += 0.00000000011*np.cos(2.71165214295 + 635.9651330509*t)
	Y2 += 0.00000000011*np.cos(6.25031686000 + 203.7378678824*t)
	Y2 += 0.00000000008*np.cos(1.97062836873 + 750.1036075334*t)
	Y2 += 0.00000000010*np.cos(3.73718799858 + 436.8931316145*t)
	Y2 += 0.00000000008*np.cos(0.62172049419 + 269.9214467406*t)
	Y2 += 0.00000000010*np.cos(2.95730289498 + 643.0786800517*t)
	Y2 += 0.00000000009*np.cos(3.39001858921 + 29088.811415985*t)
	Y2 += 0.00000000008*np.cos(4.28675667624 + 131.5469622218*t)
	Y2 += 0.00000000007*np.cos(2.53028727253 + 1603.2999892854*t)
	Y2 += 0.00000000007*np.cos(3.45037167055 + 22805.7355659936*t)
	Y2 += 0.00000000007*np.cos(0.37787568636 + 43232.3066584156*t)
	Y2 += 0.00000000007*np.cos(1.23251889653 + 9573.388259897*t)
	Y2 += 0.00000000007*np.cos(4.44320821952 + 29999.959352319*t)
	Y2 += 0.00000000007*np.cos(5.10450860305 + 6681.2248533996*t)
	Y2 += 0.00000000007*np.cos(1.83420571334 + 30110.1656735384*t)
	Y2 += 0.00000000009*np.cos(0.64587598578 + 1279.794572628*t)
	Y2 += 0.00000000007*np.cos(6.16053809700 + 483.2205421786*t)
	Y2 += 0.00000000009*np.cos(5.81958505267 + 87.3117715395*t)
	Y2 += 0.00000000007*np.cos(2.57134529838 + 867.4234757536*t)
	Y2 += 0.00000000008*np.cos(0.69696747390 + 1361.5467058442*t)
	return Y2*t*t




def Venus_Y3 (t): # 106 terms of order 3

	Y3 = 0.
	Y3 += 0.00000022088*np.cos(4.54598360855 + 206.1855484372*t)
	Y3 += 0.00000021546*np.cos(3.46116671016 + 220.4126424388*t)
	Y3 += 0.00000022966*np.cos(0.38709241285 + 10213.285546211*t)
	Y3 += 0.00000024860*np.cos(1.68572825734 + 20426.571092422*t)
	Y3 += 0.00000016300*np.cos(1.14934178921 + 522.5774180938*t)
	Y3 += 0.00000015923*np.cos(0.06221071687 + 536.8045120954*t)
	Y3 += 0.00000003093*np.cos(2.22514436528 + 426.598190876*t)
	Y3 += 0.00000002568*np.cos(2.47493921494 + 433.7117378768*t)
	Y3 += 0.00000002105*np.cos(3.35595521974 + 227.5261894396*t)
	Y3 += 0.00000001700*np.cos(5.13510489936 + 1059.3819301892*t)
	Y3 += 0.00000001378*np.cos(1.27086042787 + 515.463871093*t)
	Y3 += 0.00000001266*np.cos(3.80209162712 + 419.4846438752*t)
	Y3 += 0.00000001363*np.cos(4.63636570705 + 7.1135470008*t)
	Y3 += 0.00000001013*np.cos(4.67704889552 + 199.0720014364*t)
	Y3 += 0.00000001037*np.cos(0.69915801725 + 1066.49547719*t)
	Y3 += 0.00000000964*np.cos(6.22045145850 + 543.9180590962*t)
	Y3 -= 0.00000001104
	Y3 += 0.00000000849*np.cos(1.26670686968 + 639.897286314*t)
	Y3 += 0.00000000678*np.cos(0.79554783130 + 1052.2683831884*t)
	Y3 += 0.00000000623*np.cos(1.67630174215 + 30639.856638633*t)
	Y3 += 0.00000000392*np.cos(4.59101411052 + 14.2270940016*t)
	Y3 += 0.00000000291*np.cos(1.57357745396 + 647.0108333148*t)
	Y3 += 0.00000000248*np.cos(5.85725743749 + 1589.0728952838*t)
	Y3 += 0.00000000214*np.cos(2.46865385667 + 440.8252848776*t)
	Y3 += 0.00000000231*np.cos(2.85226310193 + 216.4804891757*t)
	Y3 += 0.00000000220*np.cos(5.18394074276 + 210.1177017003*t)
	Y3 += 0.00000000129*np.cos(0.22762324749 + 1045.1548361876*t)
	Y3 += 0.00000000123*np.cos(0.51351773704 + 853.196381752*t)
	Y3 += 0.00000000137*np.cos(2.15435863260 + 529.6909650946*t)
	Y3 += 0.00000000092*np.cos(3.22442461302 + 234.6397364404*t)
	Y3 += 0.00000000087*np.cos(4.52965482365 + 103.0927742186*t)
	Y3 += 0.00000000092*np.cos(3.90819414656 + 117.3198682202*t)
	Y3 += 0.00000000085*np.cos(5.57189606315 + 95.9792272178*t)
	Y3 += 0.00000000094*np.cos(2.25901632919 + 213.299095438*t)
	Y3 += 0.00000000075*np.cos(1.30082808866 + 1596.1864422846*t)
	Y3 += 0.00000000078*np.cos(4.96547279129 + 110.2063212194*t)
	Y3 += 0.00000000071*np.cos(4.48281367743 + 632.7837393132*t)
	Y3 += 0.00000000076*np.cos(3.40988387446 + 412.3710968744*t)
	Y3 += 0.00000000064*np.cos(2.39566214965 + 316.3918696566*t)
	Y3 += 0.00000000056*np.cos(1.44254805098 + 508.3503240922*t)
	Y3 += 0.00000000055*np.cos(1.71252125469 + 323.5054166574*t)
	Y3 += 0.00000000048*np.cos(0.40111970766 + 1073.6090241908*t)
	Y3 += 0.00000000056*np.cos(6.19540120033 + 735.8765135318*t)
	Y3 += 0.00000000042*np.cos(6.13276553266 + 625.6701923124*t)
	Y3 += 0.00000000039*np.cos(5.02961841371 + 942.062061969*t)
	Y3 += 0.00000000036*np.cos(3.01279484364 + 209.3669421749*t)
	Y3 += 0.00000000031*np.cos(0.88356246900 + 1581.959348283*t)
	Y3 += 0.00000000031*np.cos(6.03310463140 + 551.031606097*t)
	Y3 += 0.00000000032*np.cos(4.98300318004 + 217.2312487011*t)
	Y3 += 0.00000000033*np.cos(0.75212348383 + 860.3099287528*t)
	Y3 += 0.00000000030*np.cos(4.51763020093 + 70.8494453042*t)
	Y3 += 0.00000000027*np.cos(2.35184788494 + 149.5631971346*t)
	Y3 += 0.00000000028*np.cos(1.91930691377 + 330.6189636582*t)
	Y3 += 0.00000000027*np.cos(0.05305218851 + 2118.7638603784*t)
	Y3 += 0.00000000028*np.cos(0.17790568355 + 78.7137518304*t)
	Y3 += 0.00000000027*np.cos(4.37487614145 + 21.3406410024*t)
	Y3 += 0.00000000029*np.cos(5.17540731322 + 949.1756089698*t)
	Y3 += 0.00000000025*np.cos(3.02081007506 + 124.433415221*t)
	Y3 += 0.00000000033*np.cos(2.73570572399 + 223.5940361765*t)
	Y3 += 0.00000000025*np.cos(5.88306502494 + 1169.5882514086*t)
	Y3 += 0.00000000024*np.cos(6.25389986741 + 63.7358983034*t)
	Y3 += 0.00000000024*np.cos(4.81432332838 + 191.9584544356*t)
	Y3 += 0.00000000028*np.cos(0.01012773075 + 728.762966531*t)
	Y3 += 0.00000000024*np.cos(1.59054971444 + 654.1243803156*t)
	Y3 += 0.00000000030*np.cos(4.35202882411 + 309.2783226558*t)
	Y3 += 0.00000000022*np.cos(0.58430377684 + 1155.361157407*t)
	Y3 += 0.00000000020*np.cos(5.79574932921 + 88.865680217*t)
	Y3 += 0.00000000023*np.cos(3.64404039148 + 956.2891559706*t)
	Y3 += 0.00000000019*np.cos(4.74503190924 + 85.8272988312*t)
	Y3 += 0.00000000019*np.cos(5.66498805054 + 73.297125859*t)
	Y3 += 0.00000000025*np.cos(1.94036276937 + 429.7795846137*t)
	Y3 += 0.00000000024*np.cos(1.95947716237 + 519.3960243561*t)
	Y3 += 0.00000000020*np.cos(0.29570924626 + 71.6002048296*t)
	Y3 += 0.00000000018*np.cos(4.38365354248 + 77.962992305*t)
	Y3 += 0.00000000016*np.cos(4.70914310164 + 202.2533951741*t)
	Y3 += 0.00000000020*np.cos(5.48263393467 + 539.9859058331*t)
	Y3 += 0.00000000016*np.cos(3.45867068386 + 224.3447957019*t)
	Y3 += 0.00000000015*np.cos(5.26771574252 + 302.164775655*t)
	Y3 += 0.00000000014*np.cos(5.35318240788 + 76.2660712756*t)
	Y3 += 0.00000000017*np.cos(5.40518600219 + 203.0041546995*t)
	Y3 += 0.00000000011*np.cos(3.87206824630 + 11.0457002639*t)
	Y3 += 0.00000000010*np.cos(2.40929335654 + 36.6485629295*t)
	Y3 += 0.00000000012*np.cos(1.79980409055 + 422.6660376129*t)
	Y3 += 0.00000000009*np.cos(1.93147151515 + 39.6175083461*t)
	Y3 += 0.00000000009*np.cos(0.16500567398 + 1038.0412891868*t)
	Y3 += 0.00000000009*np.cos(2.15288290431 + 40853.142184844*t)
	Y3 += 0.00000000009*np.cos(0.79081879948 + 838.9692877504*t)
	Y3 += 0.00000000009*np.cos(2.40868380460 + 447.9388318784*t)
	Y3 += 0.00000000008*np.cos(1.59402806626 + 618.5566453116*t)
	Y3 += 0.00000000009*np.cos(2.51756026677 + 74.7815985673*t)
	Y3 += 0.00000000008*np.cos(5.09979031312 + 423.4167971383*t)
	Y3 += 0.00000000009*np.cos(0.33848481291 + 1574.8458012822*t)
	Y3 += 0.00000000007*np.cos(1.37888755215 + 1258.4539316256*t)
	Y3 += 0.00000000006*np.cos(1.09195739886 + 831.8557407496*t)
	Y3 += 0.00000000006*np.cos(1.00867247429 + 138.5174968707*t)
	Y3 += 0.00000000006*np.cos(4.91543048225 + 742.9900605326*t)
	Y3 += 0.00000000006*np.cos(1.82818120946 + 2125.8774073792*t)
	Y3 += 0.00000000005*np.cos(0.60506372351 + 145.6310438715*t)
	Y3 += 0.00000000007*np.cos(5.32328426995 + 38.1330356378*t)
	Y3 += 0.00000000005*np.cos(0.66965342943 + 195.1398481733*t)
	Y3 += 0.00000000004*np.cos(0.41274254704 + 18.1592472647*t)
	Y3 += 0.00000000004*np.cos(1.83690246048 + 337.732510659*t)
	Y3 += 0.00000000004*np.cos(1.32611242407 + 1265.5674786264*t)
	Y3 += 0.00000000004*np.cos(2.71001820282 + 437.6438911399*t)
	Y3 += 0.00000000003*np.cos(5.02306065714 + 1485.9801210652*t)
	Y3 += 0.00000000004*np.cos(4.61647130206 + 3.9321532631*t)
	return Y3*t*t*t




def Venus_Y4 (t): # 59 terms of order 4

	Y4 = 0.
	Y4 += 0.00000002278*np.cos(6.27388903010 + 206.1855484372*t)
	Y4 += 0.00000002245*np.cos(1.70782913671 + 220.4126424388*t)
	Y4 += 0.00000001682*np.cos(2.89988955370 + 522.5774180938*t)
	Y4 += 0.00000001636*np.cos(4.60365551069 + 536.8045120954*t)
	Y4 += 0.00000000801*np.cos(2.03074942043 + 10213.285546211*t)
	Y4 += 0.00000000755
	Y4 += 0.00000000431*np.cos(1.63508563664 + 227.5261894396*t)
	Y4 += 0.00000000349*np.cos(0.69586528581 + 433.7117378768*t)
	Y4 += 0.00000000291*np.cos(3.00165310731 + 515.463871093*t)
	Y4 += 0.00000000286*np.cos(5.64884337944 + 20426.571092422*t)
	Y4 += 0.00000000206*np.cos(4.48461122025 + 543.9180590962*t)
	Y4 += 0.00000000204*np.cos(0.11049991144 + 199.0720014364*t)
	Y4 += 0.00000000123*np.cos(5.38340390628 + 1066.49547719*t)
	Y4 += 0.00000000099*np.cos(5.70623543947 + 419.4846438752*t)
	Y4 += 0.00000000117*np.cos(0.28020890432 + 426.598190876*t)
	Y4 += 0.00000000096*np.cos(2.80306869168 + 7.1135470008*t)
	Y4 += 0.00000000061*np.cos(2.82818345895 + 14.2270940016*t)
	Y4 += 0.00000000052*np.cos(3.37268534533 + 1059.3819301892*t)
	Y4 += 0.00000000066*np.cos(2.63263056615 + 1052.2683831884*t)
	Y4 += 0.00000000050*np.cos(0.71576934216 + 440.8252848776*t)
	Y4 += 0.00000000059*np.cos(5.69532892910 + 639.897286314*t)
	Y4 += 0.00000000049*np.cos(6.02940323662 + 647.0108333148*t)
	Y4 += 0.00000000030*np.cos(5.69980612910 + 30639.856638633*t)
	Y4 += 0.00000000028*np.cos(0.26064157330 + 213.299095438*t)
	Y4 += 0.00000000024*np.cos(1.48209397973 + 234.6397364404*t)
	Y4 += 0.00000000023*np.cos(2.06131193005 + 1045.1548361876*t)
	Y4 += 0.00000000014*np.cos(3.25423631036 + 508.3503240922*t)
	Y4 += 0.00000000013*np.cos(4.48491117264 + 1589.0728952838*t)
	Y4 += 0.00000000011*np.cos(5.24080280774 + 412.3710968744*t)
	Y4 += 0.00000000012*np.cos(4.87116288717 + 853.196381752*t)
	Y4 += 0.00000000010*np.cos(5.03146150255 + 1073.6090241908*t)
	Y4 += 0.00000000010*np.cos(1.05727005468 + 95.9792272178*t)
	Y4 += 0.00000000010*np.cos(6.06799555020 + 1596.1864422846*t)
	Y4 += 0.00000000010*np.cos(5.71091802020 + 529.6909650946*t)
	Y4 += 0.00000000009*np.cos(2.76384051230 + 21.3406410024*t)
	Y4 += 0.00000000008*np.cos(6.23072779166 + 103.0927742186*t)
	Y4 += 0.00000000010*np.cos(2.05522879011 + 117.3198682202*t)
	Y4 += 0.00000000007*np.cos(3.08813888762 + 110.2063212194*t)
	Y4 += 0.00000000007*np.cos(4.14773765350 + 551.031606097*t)
	Y4 += 0.00000000006*np.cos(6.11652071967 + 654.1243803156*t)
	Y4 += 0.00000000005*np.cos(1.24583749139 + 124.433415221*t)
	Y4 += 0.00000000005*np.cos(0.40108066581 + 942.062061969*t)
	Y4 += 0.00000000006*np.cos(5.14748397921 + 860.3099287528*t)
	Y4 += 0.00000000005*np.cos(1.40699621378 + 88.865680217*t)
	Y4 += 0.00000000004*np.cos(6.24919197648 + 632.7837393132*t)
	Y4 += 0.00000000005*np.cos(1.37080964211 + 625.6701923124*t)
	Y4 += 0.00000000004*np.cos(0.18776272435 + 330.6189636582*t)
	Y4 += 0.00000000004*np.cos(1.88093591443 + 728.762966531*t)
	Y4 += 0.00000000004*np.cos(0.14204776620 + 309.2783226558*t)
	Y4 += 0.00000000003*np.cos(0.28739337099 + 191.9584544356*t)
	Y4 += 0.00000000004*np.cos(1.69042467345 + 735.8765135318*t)
	Y4 += 0.00000000003*np.cos(0.60316005015 + 447.9388318784*t)
	Y4 += 0.00000000003*np.cos(0.87226207854 + 302.164775655*t)
	Y4 += 0.00000000003*np.cos(2.70524481937 + 1581.959348283*t)
	Y4 += 0.00000000002*np.cos(4.14482411178 + 1169.5882514086*t)
	Y4 += 0.00000000003*np.cos(0.15041780827 + 323.5054166574*t)
	Y4 += 0.00000000002*np.cos(2.35344419082 + 1155.361157407*t)
	Y4 += 0.00000000002*np.cos(6.26658939437 + 429.7795846137*t)
	Y4 += 0.00000000003*np.cos(4.51313719193 + 316.3918696566*t)
	return Y4*t*t*t*t




def Venus_Y5 (t): # 31 terms of order 5

	Y5 = 0.
	Y5 += 0.00000000168*np.cos(1.70751121627 + 206.1855484372*t)
	Y5 += 0.00000000168*np.cos(6.23113008656 + 220.4126424388*t)
	Y5 += 0.00000000126*np.cos(4.78360062168 + 522.5774180938*t)
	Y5 += 0.00000000121*np.cos(2.73213408225 + 536.8045120954*t)
	Y5 += 0.00000000065*np.cos(6.17991345652 + 227.5261894396*t)
	Y5 += 0.00000000047*np.cos(4.76645839063 + 515.463871093*t)
	Y5 += 0.00000000038*np.cos(5.19126826175 + 433.7117378768*t)
	Y5 += 0.00000000032*np.cos(2.69880941648 + 543.9180590962*t)
	Y5 += 0.00000000029*np.cos(3.51424873779 + 10213.285546211*t)
	Y5 += 0.00000000027*np.cos(1.88223142168 + 199.0720014364*t)
	Y5 += 0.00000000022*np.cos(5.05580482246 + 20426.571092422*t)
	Y5 += 0.00000000018
	Y5 += 0.00000000011*np.cos(1.18187733048 + 14.2270940016*t)
	Y5 += 0.00000000011*np.cos(3.76420251280 + 1066.49547719*t)
	Y5 += 0.00000000010*np.cos(5.22684912304 + 440.8252848776*t)
	Y5 += 0.00000000007*np.cos(4.23388483049 + 647.0108333148*t)
	Y5 += 0.00000000004*np.cos(4.91327178242 + 1052.2683831884*t)
	Y5 += 0.00000000004*np.cos(2.02140363828 + 419.4846438752*t)
	Y5 += 0.00000000003*np.cos(3.88823715659 + 639.897286314*t)
	Y5 += 0.00000000003*np.cos(6.08770400766 + 234.6397364404*t)
	Y5 += 0.00000000002*np.cos(5.07541839899 + 191.9584544356*t)
	Y5 += 0.00000000002*np.cos(4.00021439308 + 426.598190876*t)
	Y5 += 0.00000000002*np.cos(3.32317518434 + 1073.6090241908*t)
	Y5 += 0.00000000002*np.cos(4.64180795349 + 1045.1548361876*t)
	Y5 += 0.00000000001*np.cos(3.09946039705 + 88.865680217*t)
	Y5 += 0.00000000001*np.cos(0.32868254087 + 7.1135470008*t)
	Y5 += 0.00000000001*np.cos(3.90945727398 + 405.2575498736*t)
	Y5 += 0.00000000001*np.cos(5.35212670493 + 213.299095438*t)
	Y5 += 0.00000000001*np.cos(4.33591184160 + 654.1243803156*t)
	Y5 += 0.00000000001*np.cos(2.98586613188 + 853.196381752*t)
	Y5 += 0.00000000001*np.cos(5.47044078046 + 124.433415221*t)
	return Y5*t*t*t*t*t




def Venus_Z0 (t): # 288 terms of order 0

	Z0 = 0.
	Z0 += 0.04282979819*np.cos(0.26703856471 + 10213.285546211*t)
	Z0 -= 0.00036740999
	Z0 += 0.00014501844*np.cos(1.14696911390 + 20426.571092422*t)
	Z0 += 0.00011808377*np.cos(0.46064367724 + 213.299095438*t)
	Z0 += 0.00011238047*np.cos(0.41541669438 + 529.6909650946*t)
	Z0 += 0.00004802048*np.cos(4.58264723370 + 38.1330356378*t)
	Z0 += 0.00001130978*np.cos(5.75878690645 + 74.7815985673*t)
	Z0 += 0.00000330051*np.cos(5.97815122863 + 426.598190876*t)
	Z0 += 0.00000269953*np.cos(0.74639629873 + 1059.3819301892*t)
	Z0 += 0.00000140675*np.cos(0.85984113219 + 1577.3435424478*t)
	Z0 += 0.00000134921*np.cos(3.70465787853 + 2352.8661537718*t)
	Z0 += 0.00000095750*np.cos(3.66962547073 + 9437.762934887*t)
	Z0 += 0.00000094247*np.cos(3.71017552866 + 206.1855484372*t)
	Z0 += 0.00000081859*np.cos(0.33908959552 + 220.4126424388*t)
	Z0 += 0.00000072910*np.cos(1.55750278240 + 9153.9036160218*t)
	Z0 += 0.00000073654*np.cos(2.02778434780 + 30639.856638633*t)
	Z0 += 0.00000059714*np.cos(6.25390371649 + 18073.7049386502*t)
	Z0 += 0.00000045307*np.cos(2.28075620268 + 5507.5532386674*t)
	Z0 += 0.00000037415*np.cos(4.53900359933 + 22003.9146348698*t)
	Z0 += 0.00000040676*np.cos(0.45442087272 + 522.5774180938*t)
	Z0 += 0.00000032943*np.cos(0.72316171903 + 10239.5838660108*t)
	Z0 += 0.00000031570*np.cos(3.44472935941 + 536.8045120954*t)
	Z0 += 0.00000028156*np.cos(2.93415727239 + 10186.9872264112*t)
	Z0 += 0.00000032447*np.cos(3.86196252330 + 8635.9420037632*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000027853*np.cos(6.12790511758 + 11790.6290886588*t)
	Z0 += 0.00000026057*np.cos(1.93178628731 + 149.5631971346*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000023013*np.cos(0.98699428893 + 775.522611324*t)
	Z0 += 0.00000019730*np.cos(3.16782731236 + 76.2660712756*t)
	Z0 += 0.00000019425*np.cos(5.12759462747 + 6283.0758499914*t)
	Z0 += 0.00000020947*np.cos(1.50959578031 + 7.1135470008*t)
	Z0 += 0.00000016289*np.cos(2.90852685195 + 10988.808157535*t)
	Z0 += 0.00000014512*np.cos(1.58375269275 + 110.2063212194*t)
	Z0 += 0.00000013631*np.cos(5.23796257375 + 639.897286314*t)
	Z0 += 0.00000015382*np.cos(5.98588709813 + 19896.8801273274*t)
	Z0 += 0.00000015507*np.cos(2.00401259454 + 13367.9726311066*t)
	Z0 += 0.00000012412*np.cos(4.13644030917 + 10021.8372800994*t)
	Z0 += 0.00000013004*np.cos(4.83195492470 + 14143.4952424306*t)
	Z0 += 0.00000010730*np.cos(5.61235409382 + 10404.7338123226*t)
	Z0 += 0.00000010504*np.cos(2.26694979515 + 316.3918696566*t)
	Z0 += 0.00000010498*np.cos(2.71149033603 + 419.4846438752*t)
	Z0 += 0.00000010336*np.cos(2.75167531541 + 191.4482661116*t)
	Z0 += 0.00000009656*np.cos(1.05402126149 + 1589.0728952838*t)
	Z0 += 0.00000010848*np.cos(3.29419910254 + 11015.1064773348*t)
	Z0 += 0.00000009775*np.cos(1.21418881204 + 8624.2126509272*t)
	Z0 += 0.00000010158*np.cos(5.71954183827 + 9683.5945811164*t)
	Z0 += 0.00000008080*np.cos(2.69831049093 + 19651.048481098*t)
	Z0 += 0.00000008040*np.cos(3.77010741170 + 73.297125859*t)
	Z0 += 0.00000008209*np.cos(3.55371021890 + 10742.9765113056*t)
	Z0 += 0.00000006416*np.cos(0.46264840234 + 9786.687355335*t)
	Z0 += 0.00000006722*np.cos(2.41848486045 + 4705.7323075436*t)
	Z0 += 0.00000005903*np.cos(5.96215831403 + 25934.1243310894*t)
	Z0 += 0.00000005337*np.cos(2.42617024681 + 103.0927742186*t)
	Z0 += 0.00000005647*np.cos(3.57594715836 + 3154.6870848956*t)
	Z0 += 0.00000004610*np.cos(5.85854264972 + 433.7117378768*t)
	Z0 += 0.00000004044*np.cos(6.24650537722 + 11322.6640983044*t)
	Z0 += 0.00000004033*np.cos(3.42887820794 + 9103.9069941176*t)
	Z0 += 0.00000004210*np.cos(4.99232132925 + 7084.8967811152*t)
	Z0 += 0.00000004135*np.cos(3.43782832503 + 17298.1823273262*t)
	Z0 += 0.00000003747*np.cos(1.30318722019 + 15720.8387848784*t)
	Z0 += 0.00000003417*np.cos(3.95474989164 + 7860.4193924392*t)
	Z0 += 0.00000003440*np.cos(0.77140273510 + 4551.9534970588*t)
	Z0 += 0.00000003948*np.cos(0.33532528162 + 1.4844727083*t)
	Z0 += 0.00000003488*np.cos(0.14633368219 + 20618.0193585336*t)
	Z0 += 0.00000002851*np.cos(5.68591706153 + 10206.1719992102*t)
	Z0 += 0.00000002750*np.cos(3.89497095361 + 10192.5101507186*t)
	Z0 += 0.00000002734*np.cos(5.62996472233 + 12566.1516999828*t)
	Z0 += 0.00000002682*np.cos(4.58018033496 + 801.8209311238*t)
	Z0 += 0.00000002743*np.cos(6.06387494803 + 10234.0609417034*t)
	Z0 += 0.00000002756*np.cos(5.43236957664 + 29580.4747084438*t)
	Z0 += 0.00000002610*np.cos(5.41057398526 + 632.7837393132*t)
	Z0 += 0.00000002155*np.cos(0.29731467355 + 9411.4646150872*t)
	Z0 += 0.00000002403*np.cos(4.90533210845 + 19367.1891622328*t)
	Z0 += 0.00000002454*np.cos(6.12024070891 + 1162.4747044078*t)
	Z0 += 0.00000002375*np.cos(6.05534556046 + 1052.2683831884*t)
	Z0 += 0.00000002103*np.cos(1.12514771936 + 29864.334027309*t)
	Z0 += 0.00000001632*np.cos(4.67123397256 + 1109.3785520934*t)
	Z0 += 0.00000001783*np.cos(3.14608208810 + 846.0828347512*t)
	Z0 += 0.00000001594*np.cos(3.78244334906 + 1066.49547719*t)
	Z0 += 0.00000001787*np.cos(2.52506338741 + 15874.6175953632*t)
	Z0 += 0.00000001613*np.cos(1.47525165805 + 7058.5984613154*t)
	Z0 += 0.00000001566*np.cos(1.99768150464 + 202.2533951741*t)
	Z0 += 0.00000001598*np.cos(2.21757389250 + 10426.584641649*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001332*np.cos(4.33184702387 + 949.1756089698*t)
	Z0 += 0.00000001154*np.cos(1.98818396175 + 26.2983197998*t)
	Z0 += 0.00000001137*np.cos(6.15183461939 + 2.9689454166*t)
	Z0 += 0.00000001076*np.cos(0.86222140421 + 3340.6124266998*t)
	Z0 += 0.00000001468*np.cos(0.75541488791 + 9999.986450773*t)
	Z0 += 0.00000001028*np.cos(0.21025596115 + 227.5261894396*t)
	Z0 += 0.00000001118*np.cos(0.96571599573 + 23581.2581773176*t)
	Z0 += 0.00000001210*np.cos(3.17717646354 + 3532.0606928114*t)
	Z0 += 0.00000000965*np.cos(0.01161931809 + 3128.3887650958*t)
	Z0 += 0.00000001027*np.cos(2.51592691800 + 33794.5437235286*t)
	Z0 += 0.00000000882*np.cos(0.48413591726 + 209.3669421749*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000000847*np.cos(1.24888706950 + 9573.388259897*t)
	Z0 += 0.00000000889*np.cos(1.48214942791 + 9830.3890139878*t)
	Z0 += 0.00000000953*np.cos(5.73118460251 + 20213.271996984*t)
	Z0 += 0.00000000987*np.cos(4.70495944427 + 14945.3161735544*t)
	Z0 += 0.00000001030*np.cos(0.84929643011 + 8094.5216858326*t)
	Z0 += 0.00000000770*np.cos(4.54196353475 + 21228.3920235458*t)
	Z0 += 0.00000000864*np.cos(2.92013522974 + 148.0787244263*t)
	Z0 += 0.00000000846*np.cos(3.60649450344 + 217.2312487011*t)
	Z0 += 0.00000000778*np.cos(1.16378510983 + 8662.240323563*t)
	Z0 += 0.00000000860*np.cos(5.74281955136 + 5661.3320491522*t)
	Z0 += 0.00000000779*np.cos(3.77257775192 + 63.7358983034*t)
	Z0 += 0.00000000831*np.cos(6.20016431490 + 323.5054166574*t)
	Z0 += 0.00000000693*np.cos(4.54324890551 + 853.196381752*t)
	Z0 += 0.00000000740*np.cos(1.97614280765 + 10596.1820784342*t)
	Z0 += 0.00000000687*np.cos(2.88181717922 + 71.8126531507*t)
	Z0 += 0.00000000606*np.cos(6.22070159607 + 25158.6017197654*t)
	Z0 += 0.00000000533*np.cos(0.73765107493 + 28286.9904848612*t)
	Z0 += 0.00000000547*np.cos(5.06653964506 + 29050.7837433492*t)
	Z0 += 0.00000000591*np.cos(4.62374022159 + 9929.4262273458*t)
	Z0 += 0.00000000537*np.cos(6.00327539255 + 4732.0306273434*t)
	Z0 += 0.00000000559*np.cos(1.77674120898 + 742.9900605326*t)
	Z0 += 0.00000000569*np.cos(5.37276655331 + 10497.1448650762*t)
	Z0 += 0.00000000520*np.cos(6.11596800207 + 10218.8084705184*t)
	Z0 += 0.00000000542*np.cos(3.94171539558 + 37724.7534197482*t)
	Z0 += 0.00000000459*np.cos(3.95268976842 + 77.7505439839*t)
	Z0 += 0.00000000575*np.cos(2.29073875885 + 21535.9496445154*t)
	Z0 += 0.00000000575*np.cos(3.85836565065 + 199.0720014364*t)
	Z0 += 0.00000000437*np.cos(2.42330391120 + 10251.3132188468*t)
	Z0 += 0.00000000421*np.cos(5.42036909165 + 11.0457002639*t)
	Z0 += 0.00000000439*np.cos(2.90237828484 + 40853.142184844*t)
	Z0 += 0.00000000421*np.cos(3.41138490065 + 224.3447957019*t)
	Z0 += 0.00000000459*np.cos(1.69153061401 + 3930.2096962196*t)
	Z0 += 0.00000000405*np.cos(1.42927875873 + 9161.0171630226*t)
	Z0 += 0.00000000418*np.cos(5.48110803243 + 32217.2001810808*t)
	Z0 += 0.00000000408*np.cos(1.32226655530 + 2118.7638603784*t)
	Z0 += 0.00000000521*np.cos(3.84286345199 + 10207.7626219036*t)
	Z0 += 0.00000000534*np.cos(0.54255389653 + 515.463871093*t)
	Z0 += 0.00000000457*np.cos(6.16974742379 + 10220.3990932118*t)
	Z0 += 0.00000000385*np.cos(0.88914902748 + 151.0476698429*t)
	Z0 += 0.00000000429*np.cos(1.40544578224 + 14.2270940016*t)
	Z0 += 0.00000000440*np.cos(1.25236241968 + 10175.2578735752*t)
	Z0 += 0.00000000394*np.cos(4.81650684498 + 9146.790069021*t)
	Z0 += 0.00000000362*np.cos(0.02259543121 + 14765.2390432698*t)
	Z0 += 0.00000000396*np.cos(4.56209231282 + 10063.7223490764*t)
	Z0 += 0.00000000407*np.cos(6.15731262846 + 18875.525869774*t)
	Z0 += 0.00000000349*np.cos(5.78507522549 + 12592.4500197826*t)
	Z0 += 0.00000000379*np.cos(4.56511543982 + 20419.45754542119*t)
	Z0 += 0.00000000319*np.cos(1.05944718196 + 117.3198682202*t)
	Z0 += 0.00000000314*np.cos(5.08259050420 + 18837.49819713819*t)
	Z0 += 0.00000000343*np.cos(2.36516734231 + 27511.4678735372*t)
	Z0 += 0.00000000312*np.cos(6.24838646568 + 216.4804891757*t)
	Z0 += 0.00000000289*np.cos(3.59841384736 + 11272.6674764002*t)
	Z0 += 0.00000000290*np.cos(5.11770361174 + 647.0108333148*t)
	Z0 += 0.00000000301*np.cos(4.24971815099 + 14919.0178537546*t)
	Z0 += 0.00000000322*np.cos(1.36846420067 + 29088.811415985*t)
	Z0 += 0.00000000292*np.cos(0.74997511570 + 3149.1641605882*t)
	Z0 += 0.00000000314*np.cos(4.10256974515 + 210.1177017003*t)
	Z0 += 0.00000000296*np.cos(1.59458223926 + 309.2783226558*t)
	Z0 += 0.00000000306*np.cos(0.47092243462 + 23958.6317852334*t)
	Z0 += 0.00000000254*np.cos(4.34026574490 + 10137.0194749354*t)
	Z0 += 0.00000000298*np.cos(5.25958947836 + 415.5524906121*t)
	Z0 += 0.00000000304*np.cos(5.33181632059 + 41654.9631159678*t)
	Z0 += 0.00000000276*np.cos(3.54425558449 + 525.7588118315*t)
	Z0 += 0.00000000264*np.cos(0.01153452145 + 20452.8694122218*t)
	Z0 += 0.00000000334*np.cos(5.28920083729 + 382.8965322232*t)
	Z0 += 0.00000000317*np.cos(3.85456671343 + 85.8272988312*t)
	Z0 += 0.00000000236*np.cos(1.03442196051 + 22779.4372461938*t)
	Z0 += 0.00000000277*np.cos(0.31958662741 + 138.5174968707*t)
	Z0 += 0.00000000250*np.cos(5.05395469123 + 24356.7807886416*t)
	Z0 += 0.00000000241*np.cos(3.32660302434 + 543.9180590962*t)
	Z0 += 0.00000000224*np.cos(3.65658130240 + 6681.2248533996*t)
	Z0 += 0.00000000278*np.cos(0.10022232617 + 16496.3613962024*t)
	Z0 += 0.00000000232*np.cos(0.48064662619 + 17085.9586657222*t)
	Z0 += 0.00000000205*np.cos(6.19639409918 + 7064.1213856228*t)
	Z0 += 0.00000000198*np.cos(2.49240240273 + 95.9792272178*t)
	Z0 += 0.00000000197*np.cos(3.71380377240 + 1551.045222648*t)
	Z0 += 0.00000000200*np.cos(4.06516779510 + 18849.2275499742*t)
	Z0 += 0.00000000186*np.cos(4.39437140248 + 277.0349937414*t)
	Z0 += 0.00000000188*np.cos(0.20392851067 + 1692.1656695024*t)
	Z0 += 0.00000000175*np.cos(5.39840733123 + 1478.8665740644*t)
	Z0 += 0.00000000242*np.cos(0.43270824867 + 533.6231183577*t)
	Z0 += 0.00000000179*np.cos(5.79528713551 + 956.2891559706*t)
	Z0 += 0.00000000170*np.cos(5.96522395118 + 10198.033075026*t)
	Z0 += 0.00000000170*np.cos(3.52866583267 + 10228.538017396*t)
	Z0 += 0.00000000161*np.cos(3.79231132145 + 490.3340891794*t)
	Z0 += 0.00000000180*np.cos(0.48168923159 + 45585.1728121874*t)
	Z0 += 0.00000000151*np.cos(5.25734718420 + 26087.9031415742*t)
	Z0 += 0.00000000146*np.cos(0.92939894424 + 114.3991069134*t)
	Z0 += 0.00000000144*np.cos(2.81280885697 + 17277.4069318338*t)
	Z0 += 0.00000000177*np.cos(3.58248029244 + 20400.2727726222*t)
	Z0 += 0.00000000170*np.cos(6.26857937202 + 1581.959348283*t)
	Z0 += 0.00000000170*np.cos(3.72282190488 + 31441.6775697568*t)
	Z0 += 0.00000000157*np.cos(0.79065950021 + 1265.5674786264*t)
	Z0 += 0.00000000166*np.cos(0.03569768750 + 13745.3462390224*t)
	Z0 += 0.00000000154*np.cos(0.00941929392 + 735.8765135318*t)
	Z0 += 0.00000000127*np.cos(5.14389302386 + 5481.2549188676*t)
	Z0 += 0.00000000129*np.cos(5.30043284887 + 351.8165923087*t)
	Z0 += 0.00000000138*np.cos(1.19253977825 + 22805.7355659936*t)
	Z0 += 0.00000000117*np.cos(4.81725910872 + 625.6701923124*t)
	Z0 += 0.00000000126*np.cos(4.21594185374 + 20956.2620575166*t)
	Z0 += 0.00000000118*np.cos(1.71706550416 + 13341.6743113068*t)
	Z0 += 0.00000000131*np.cos(0.92317994329 + 3442.5749449654*t)
	Z0 += 0.00000000113*np.cos(3.04973288935 + 532.8723588323*t)
	Z0 += 0.00000000116*np.cos(0.92093201468 + 526.5095713569*t)
	Z0 += 0.00000000137*np.cos(2.89407950366 + 33019.0211122046*t)
	Z0 += 0.00000000129*np.cos(1.11079063120 + 33.6796175129*t)
	Z0 += 0.00000000107*np.cos(3.52070197299 + 1375.7737998458*t)
	Z0 += 0.00000000104*np.cos(2.47347358674 + 26709.6469424134*t)
	Z0 += 0.00000000126*np.cos(2.84049662693 + 9967.4538999816*t)
	Z0 += 0.00000000107*np.cos(4.19045394315 + 19999.97290154599*t)
	Z0 += 0.00000000110*np.cos(0.73944778374 + 30110.1656735384*t)
	Z0 += 0.00000000138*np.cos(4.01403107693 + 21202.093703746*t)
	Z0 += 0.00000000122*np.cos(0.37000676558 + 10459.1171924404*t)
	Z0 += 0.00000000095*np.cos(5.25435135477 + 30213.258447757*t)
	Z0 += 0.00000000099*np.cos(5.61149803116 + 10529.6774158676*t)
	Z0 += 0.00000000095*np.cos(4.92440852569 + 4.4534181249*t)
	Z0 += 0.00000000106*np.cos(2.42064996718 + 20809.4676246452*t)
	Z0 += 0.00000000106*np.cos(2.29924580245 + 111.4301614968*t)
	Z0 += 0.00000000103*np.cos(3.99294762314 + 70.3281804424*t)
	Z0 += 0.00000000095*np.cos(3.11317801589 + 9896.8936765544*t)
	Z0 += 0.00000000085*np.cos(5.88248062550 + 3723.508958923*t)
	Z0 += 0.00000000085*np.cos(4.12867184796 + 1596.1864422846*t)
	Z0 += 0.00000000099*np.cos(1.93329637732 + 49515.382508407*t)
	Z0 += 0.00000000086*np.cos(0.85755223960 + 2379.1644735716*t)
	Z0 += 0.00000000110*np.cos(1.44699918003 + 43232.3066584156*t)
	Z0 += 0.00000000088*np.cos(1.59017183044 + 10110.1927719924*t)
	Z0 += 0.00000000085*np.cos(6.03717451925 + 127.4717966068*t)
	Z0 += 0.00000000086*np.cos(0.87055324194 + 16522.6597160022*t)
	Z0 += 0.00000000089*np.cos(2.33714216061 + 10316.3783204296*t)
	Z0 += 0.00000000098*np.cos(4.66807552803 + 20235.1228263104*t)
	Z0 += 0.00000000104*np.cos(5.02724740402 + 35371.8872659764*t)
	Z0 += 0.00000000093*np.cos(4.21356144460 + 36301.18868778519*t)
	Z0 += 0.00000000089*np.cos(0.88060757437 + 6489.776587288*t)
	Z0 += 0.00000000081*np.cos(5.75718254218 + 78.7137518304*t)
	Z0 += 0.00000000083*np.cos(2.07543775594 + 31749.2351907264*t)
	Z0 += 0.00000000096*np.cos(2.90682399304 + 9793.8009023358*t)
	Z0 += 0.00000000076*np.cos(4.37868021510 + 146.594251718*t)
	Z0 += 0.00000000078*np.cos(2.65839634325 + 10232.95530711079*t)
	Z0 += 0.00000000078*np.cos(0.55230439694 + 10193.61578531121*t)
	Z0 += 0.00000000073*np.cos(5.74180456867 + 440.8252848776*t)
	Z0 += 0.00000000092*np.cos(5.63110477712 + 10288.0671447783*t)
	Z0 += 0.00000000092*np.cos(3.86278127025 + 10138.5039476437*t)
	Z0 += 0.00000000090*np.cos(4.34324193073 + 36949.2308084242*t)
	Z0 += 0.00000000073*np.cos(2.56775245907 + 13936.794505134*t)
	Z0 += 0.00000000071*np.cos(0.64943236639 + 20.7753954924*t)
	Z0 += 0.00000000094*np.cos(2.55599744292 + 70.8494453042*t)
	Z0 += 0.00000000090*np.cos(0.07319663423 + 6872.6731195112*t)
	Z0 += 0.00000000069*np.cos(1.52914774412 + 9690.7081281172*t)
	Z0 += 0.00000000086*np.cos(1.02476175384 + 65236.2212932854*t)
	Z0 += 0.00000000079*np.cos(1.65446145032 + 39264.0692895602*t)
	Z0 += 0.00000000071*np.cos(0.70714638996 + 36147.4098773004*t)
	Z0 += 0.00000000071*np.cos(2.52879760001 + 26735.9452622132*t)
	Z0 += 0.00000000074*np.cos(6.17414394369 + 137.0330241624*t)
	Z0 += 0.00000000065*np.cos(4.13140277621 + 210.8514148832*t)
	Z0 += 0.00000000061*np.cos(5.47943297658 + 11764.330768859*t)
	Z0 += 0.00000000080*np.cos(2.87220602049 + 47162.5163546352*t)
	Z0 += 0.00000000065*np.cos(2.53312656681 + 10735.8629643048*t)
	Z0 += 0.00000000068*np.cos(2.28501865578 + 8521.1198767086*t)
	Z0 += 0.00000000064*np.cos(6.21657611750 + 215.7467759928*t)
	Z0 += 0.00000000065*np.cos(2.12423586627 + 28313.288804661*t)
	Z0 += 0.00000000062*np.cos(2.28587915309 + 3903.9113764198*t)
	Z0 += 0.00000000069*np.cos(0.42270579845 + 9580.5018068978*t)
	Z0 += 0.00000000063*np.cos(3.35690006984 + 53445.5922046266*t)
	Z0 += 0.00000000053*np.cos(2.14583523296 + 8631.326197928*t)
	Z0 += 0.00000000066*np.cos(4.12244312057 + 28521.0927782546*t)
	Z0 += 0.00000000058*np.cos(5.25045057985 + 10419.4710946482*t)
	Z0 += 0.00000000058*np.cos(4.23724598221 + 10007.0999977738*t)
	Z0 += 0.00000000053*np.cos(3.02375632858 + 19317.1925403286*t)
	Z0 += 0.00000000066*np.cos(4.90503958113 + 222.8603229936*t)
	Z0 += 0.00000000062*np.cos(2.46239069210 + 10846.0692855242*t)
	Z0 += 0.00000000061*np.cos(3.77333230443 + 51868.2486621788*t)
	Z0 += 0.00000000050*np.cos(0.81093625490 + 3.9321532631*t)
	Z0 += 0.00000000055*np.cos(2.96642314550 + 1169.5882514086*t)
	Z0 += 0.00000000046*np.cos(0.75603425226 + 214.2623032845*t)
	Z0 += 0.00000000047*np.cos(5.59856718264 + 422.6660376129*t)
	Z0 += 0.00000000043*np.cos(0.99886063885 + 437.6438911399*t)
	Z0 += 0.00000000042*np.cos(4.06841238442 + 42.5864537627*t)
	Z0 += 0.00000000047*np.cos(3.95753360395 + 109.9456887885*t)
	Z0 += 0.00000000055*np.cos(5.81384971899 + 1045.1548361876*t)
	Z0 += 0.00000000039*np.cos(4.38780950886 + 942.062061969*t)
	Z0 += 0.00000000047*np.cos(3.30738241951 + 212.3358875915*t)
	Z0 += 0.00000000039*np.cos(3.63042667673 + 213.3472795478*t)
	Z0 += 0.00000000038*np.cos(0.54320017724 + 299.1263942692*t)
	Z0 += 0.00000000039*np.cos(5.79384191199 + 380.12776796*t)
	Z0 += 0.00000000039*np.cos(0.43264760342 + 213.2509113282*t)
	Z0 += 0.00000000030*np.cos(2.75112354254 + 838.9692877504*t)
	Z0 += 0.00000000030*np.cos(3.04343823849 + 200.7689224658*t)
	Z0 += 0.00000000040*np.cos(6.23354889167 + 1155.361157407*t)
	Z0 += 0.00000000032*np.cos(4.71988612983 + 628.8515860501*t)
	Z0 += 0.00000000031*np.cos(0.58732919927 + 9.5612275556*t)
	Z0 += 0.00000000028*np.cos(5.43761306842 + 388.4651552382*t)
	return Z0




def Venus_Z1 (t): # 186 terms of order 1

	Z1 = 0.
	Z1 += 0.00208095894*np.cos(1.88967278742 + 10213.285546211*t)
	Z1 += 0.00001264986*np.cos(3.71037501321 + 20426.571092422*t)
	Z1 += 0.00001497542
	Z1 += 0.00000544259*np.cos(1.80363829989 + 213.299095438*t)
	Z1 += 0.00000389480*np.cos(4.67283251553 + 529.6909650946*t)
	Z1 += 0.00000037294*np.cos(5.40133589632 + 206.1855484372*t)
	Z1 += 0.00000028944*np.cos(4.93245710560 + 220.4126424388*t)
	Z1 += 0.00000028635*np.cos(3.15447649004 + 74.7815985673*t)
	Z1 += 0.00000024982*np.cos(3.65569053585 + 426.598190876*t)
	Z1 += 0.00000019184*np.cos(5.75026102661 + 1059.3819301892*t)
	Z1 += 0.00000013710*np.cos(1.71243761670 + 536.8045120954*t)
	Z1 += 0.00000012132*np.cos(2.31169793598 + 522.5774180938*t)
	Z1 += 0.00000011139*np.cos(4.85437878205 + 30639.856638633*t)
	Z1 += 0.00000009557*np.cos(2.27891093355 + 9437.762934887*t)
	Z1 += 0.00000007822*np.cos(5.54315419538 + 1577.3435424478*t)
	Z1 += 0.00000008010*np.cos(5.28413417446 + 38.1330356378*t)
	Z1 += 0.00000004978*np.cos(4.29826949554 + 419.4846438752*t)
	Z1 += 0.00000005390*np.cos(5.37203588853 + 2352.8661537718*t)
	Z1 += 0.00000005760*np.cos(0.27988422334 + 9153.9036160218*t)
	Z1 += 0.00000004254*np.cos(6.12140673022 + 7.1135470008*t)
	Z1 += 0.00000004681*np.cos(5.23427572089 + 10186.9872264112*t)
	Z1 += 0.00000003589*np.cos(1.59383779306 + 11790.6290886588*t)
	Z1 += 0.00000003297*np.cos(0.73050419137 + 5507.5532386674*t)
	Z1 += 0.00000003681*np.cos(4.17406921354 + 10239.5838660108*t)
	Z1 += 0.00000002586*np.cos(3.01944725018 + 639.897286314*t)
	Z1 += 0.00000002395*np.cos(1.34531028758 + 10404.7338123226*t)
	Z1 += 0.00000002557*np.cos(1.61905357827 + 18073.7049386502*t)
	Z1 += 0.00000002131*np.cos(4.06053382034 + 433.7117378768*t)
	Z1 += 0.00000001893*np.cos(5.04556374323 + 10988.808157535*t)
	Z1 += 0.00000001957*np.cos(6.14586118921 + 22003.9146348698*t)
	Z1 += 0.00000001749*np.cos(1.72876483551 + 8635.9420037632*t)
	Z1 += 0.00000001560*np.cos(3.28261094599 + 316.3918696566*t)
	Z1 += 0.00000001361*np.cos(0.40192228967 + 13367.9726311066*t)
	Z1 += 0.00000001159*np.cos(2.31994412916 + 10021.8372800994*t)
	Z1 += 0.00000001060*np.cos(4.40549998074 + 19651.048481098*t)
	Z1 += 0.00000001173*np.cos(0.00063234885 + 1589.0728952838*t)
	Z1 += 0.00000001026*np.cos(5.05449603850 + 775.522611324*t)
	Z1 += 0.00000001029*np.cos(5.86675536556 + 149.5631971346*t)
	Z1 += 0.00000000775*np.cos(4.79688880139 + 227.5261894396*t)
	Z1 += 0.00000000894*np.cos(6.18769608247 + 7860.4193924392*t)
	Z1 += 0.00000000739*np.cos(2.12600457660 + 1066.49547719*t)
	Z1 += 0.00000000686*np.cos(1.37692807485 + 19896.8801273274*t)
	Z1 += 0.00000000645*np.cos(1.62570263847 + 1052.2683831884*t)
	Z1 += 0.00000000559*np.cos(0.63256033185 + 8624.2126509272*t)
	Z1 += 0.00000000542*np.cos(1.44488755125 + 110.2063212194*t)
	Z1 += 0.00000000531*np.cos(1.77610826151 + 11322.6640983044*t)
	Z1 += 0.00000000533*np.cos(2.34579176940 + 76.2660712756*t)
	Z1 += 0.00000000415*np.cos(3.00153763564 + 15720.8387848784*t)
	Z1 += 0.00000000403*np.cos(1.25691345472 + 36.6485629295*t)
	Z1 += 0.00000000390*np.cos(5.10646391319 + 9786.687355335*t)
	Z1 += 0.00000000440*np.cos(1.71617898465 + 20618.0193585336*t)
	Z1 += 0.00000000426*np.cos(2.83056359378 + 14143.4952424306*t)
	Z1 += 0.00000000382*np.cos(0.29076532255 + 4705.7323075436*t)
	Z1 += 0.00000000352*np.cos(4.79823464785 + 39.6175083461*t)
	Z1 += 0.00000000446*np.cos(5.55248874462 + 199.0720014364*t)
	Z1 += 0.00000000372*np.cos(1.80541993350 + 17298.1823273262*t)
	Z1 += 0.00000000369*np.cos(1.25931663640 + 25934.1243310894*t)
	Z1 += 0.00000000368*np.cos(5.32358181908 + 103.0927742186*t)
	Z1 += 0.00000000302*np.cos(5.15335876647 + 632.7837393132*t)
	Z1 += 0.00000000343*np.cos(2.32388226037 + 515.463871093*t)
	Z1 += 0.00000000278*np.cos(4.22437893192 + 191.4482661116*t)
	Z1 += 0.00000000296*np.cos(0.68834496754 + 19367.1891622328*t)
	Z1 += 0.00000000325*np.cos(0.20788633679 + 11015.1064773348*t)
	Z1 += 0.00000000316*np.cos(2.29565820718 + 10742.9765113056*t)
	Z1 += 0.00000000258*np.cos(5.99544147559 + 14.2270940016*t)
	Z1 += 0.00000000231*np.cos(6.23978632212 + 9830.3890139878*t)
	Z1 += 0.00000000305*np.cos(3.73514346008 + 10596.1820784342*t)
	Z1 += 0.00000000266*np.cos(0.49468027720 + 73.297125859*t)
	Z1 += 0.00000000230*np.cos(4.92924491630 + 3930.2096962196*t)
	Z1 += 0.00000000233*np.cos(2.14466305631 + 801.8209311238*t)
	Z1 += 0.00000000251*np.cos(5.58497774438 + 217.2312487011*t)
	Z1 += 0.00000000210*np.cos(5.87638250776 + 210.1177017003*t)
	Z1 += 0.00000000207*np.cos(1.90716961392 + 9103.9069941176*t)
	Z1 += 0.00000000200*np.cos(1.60953815793 + 543.9180590962*t)
	Z1 += 0.00000000205*np.cos(2.38357660053 + 853.196381752*t)
	Z1 += 0.00000000253*np.cos(2.27887468784 + 9999.986450773*t)
	Z1 += 0.00000000193*np.cos(2.68584410734 + 23581.2581773176*t)
	Z1 += 0.00000000186*np.cos(4.63128120913 + 209.3669421749*t)
	Z1 += 0.00000000198*np.cos(2.61036398872 + 9411.4646150872*t)
	Z1 += 0.00000000166*np.cos(3.25384215179 + 647.0108333148*t)
	Z1 += 0.00000000192*np.cos(1.96688749719 + 6283.0758499914*t)
	Z1 += 0.00000000188*np.cos(4.45601446980 + 216.4804891757*t)
	Z1 += 0.00000000173*np.cos(3.75026764989 + 7058.5984613154*t)
	Z1 += 0.00000000199*np.cos(4.79364893479 + 10206.1719992102*t)
	Z1 += 0.00000000153*np.cos(5.90450931307 + 3154.6870848956*t)
	Z1 += 0.00000000147*np.cos(4.91154015633 + 202.2533951741*t)
	Z1 += 0.00000000180*np.cos(3.65160439089 + 21228.3920235458*t)
	Z1 += 0.00000000148*np.cos(6.00943832296 + 949.1756089698*t)
	Z1 += 0.00000000143*np.cos(3.70203142149 + 323.5054166574*t)
	Z1 += 0.00000000161*np.cos(3.21958303712 + 12566.1516999828*t)
	Z1 += 0.00000000140*np.cos(0.83132381305 + 735.8765135318*t)
	Z1 += 0.00000000138*np.cos(6.13843515618 + 9161.0171630226*t)
	Z1 += 0.00000000147*np.cos(4.40417469081 + 10220.3990932118*t)
	Z1 += 0.00000000148*np.cos(1.39050905939 + 10234.0609417034*t)
	Z1 += 0.00000000127*np.cos(6.11794706117 + 10426.584641649*t)
	Z1 += 0.00000000139*np.cos(2.69109384056 + 29864.334027309*t)
	Z1 += 0.00000000120*np.cos(5.56979067201 + 10192.5101507186*t)
	Z1 += 0.00000000122*np.cos(5.67146512225 + 117.3198682202*t)
	Z1 += 0.00000000132*np.cos(0.65236823857 + 29580.4747084438*t)
	Z1 += 0.00000000148*np.cos(5.78273623919 + 26.2983197998*t)
	Z1 += 0.00000000110*np.cos(1.54178765941 + 9683.5945811164*t)
	Z1 += 0.00000000147*np.cos(4.38575949385 + 15874.6175953632*t)
	Z1 += 0.00000000100*np.cos(2.78745027781 + 1.4844727083*t)
	Z1 += 0.00000000099*np.cos(1.18053788195 + 7084.8967811152*t)
	Z1 += 0.00000000097*np.cos(5.83350659322 + 40853.142184844*t)
	Z1 += 0.00000000103*np.cos(2.37976615570 + 3128.3887650958*t)
	Z1 += 0.00000000107*np.cos(2.90868508133 + 3340.6124266998*t)
	Z1 += 0.00000000097*np.cos(4.64659904732 + 25158.6017197654*t)
	Z1 += 0.00000000084*np.cos(4.30248448955 + 1162.4747044078*t)
	Z1 += 0.00000000092*np.cos(0.17084455774 + 9146.790069021*t)
	Z1 += 0.00000000077*np.cos(4.22942639128 + 95.9792272178*t)
	Z1 += 0.00000000079*np.cos(0.36636125409 + 11.0457002639*t)
	Z1 += 0.00000000077*np.cos(1.60206102260 + 10207.7626219036*t)
	Z1 += 0.00000000077*np.cos(1.60857575234 + 10218.8084705184*t)
	Z1 += 0.00000000075*np.cos(1.47982807612 + 525.7588118315*t)
	Z1 += 0.00000000078*np.cos(5.16888914284 + 8662.240323563*t)
	Z1 += 0.00000000086*np.cos(5.48266928025 + 37724.7534197482*t)
	Z1 += 0.00000000076*np.cos(1.24245643745 + 532.8723588323*t)
	Z1 += 0.00000000096*np.cos(0.86129378681 + 63.7358983034*t)
	Z1 += 0.00000000071*np.cos(2.75365102566 + 526.5095713569*t)
	Z1 += 0.00000000072*np.cos(2.49760315888 + 4551.9534970588*t)
	Z1 += 0.00000000079*np.cos(6.07206626858 + 20419.45754542119*t)
	Z1 += 0.00000000071*np.cos(0.43437193243 + 2118.7638603784*t)
	Z1 += 0.00000000070*np.cos(5.55011021099 + 5661.3320491522*t)
	Z1 += 0.00000000063*np.cos(3.98868546710 + 440.8252848776*t)
	Z1 += 0.00000000074*np.cos(0.74329919338 + 382.8965322232*t)
	Z1 += 0.00000000075*np.cos(4.01698827629 + 33794.5437235286*t)
	Z1 += 0.00000000061*np.cos(2.62473045895 + 533.6231183577*t)
	Z1 += 0.00000000074*np.cos(6.21974610833 + 18837.49819713819*t)
	Z1 += 0.00000000062*np.cos(1.21365119312 + 10198.033075026*t)
	Z1 += 0.00000000062*np.cos(1.99704954707 + 10228.538017396*t)
	Z1 += 0.00000000054*np.cos(1.42941204449 + 85.8272988312*t)
	Z1 += 0.00000000056*np.cos(0.16985541402 + 14919.0178537546*t)
	Z1 += 0.00000000057*np.cos(3.98493436395 + 309.2783226558*t)
	Z1 += 0.00000000051*np.cos(0.39392917326 + 742.9900605326*t)
	Z1 += 0.00000000049*np.cos(4.84482792493 + 956.2891559706*t)
	Z1 += 0.00000000057*np.cos(0.62155717729 + 41654.9631159678*t)
	Z1 += 0.00000000049*np.cos(3.44789037675 + 28286.9904848612*t)
	Z1 += 0.00000000048*np.cos(2.58976541849 + 22779.4372461938*t)
	Z1 += 0.00000000043*np.cos(2.55616001516 + 1596.1864422846*t)
	Z1 += 0.00000000043*np.cos(5.29403475475 + 3149.1641605882*t)
	Z1 += 0.00000000044*np.cos(3.34917429540 + 11272.6674764002*t)
	Z1 += 0.00000000053*np.cos(1.80084365566 + 45585.1728121874*t)
	Z1 += 0.00000000037*np.cos(4.19631930368 + 27511.4678735372*t)
	Z1 += 0.00000000049*np.cos(1.74739410911 + 3532.0606928114*t)
	Z1 += 0.00000000036*np.cos(0.04372461247 + 20400.2727726222*t)
	Z1 += 0.00000000036*np.cos(0.55224025396 + 625.6701923124*t)
	Z1 += 0.00000000033*np.cos(2.63152688250 + 16496.3613962024*t)
	Z1 += 0.00000000035*np.cos(3.59004163922 + 21535.9496445154*t)
	Z1 += 0.00000000044*np.cos(0.78654424919 + 20213.271996984*t)
	Z1 += 0.00000000033*np.cos(6.02490547159 + 21202.093703746*t)
	Z1 += 0.00000000038*np.cos(6.19285352338 + 29088.811415985*t)
	Z1 += 0.00000000039*np.cos(2.77790342477 + 35.1640902212*t)
	Z1 += 0.00000000030*np.cos(4.35442775962 + 412.3710968744*t)
	Z1 += 0.00000000031*np.cos(1.57491569709 + 32217.2001810808*t)
	Z1 += 0.00000000038*np.cos(5.38040433295 + 224.3447957019*t)
	Z1 += 0.00000000029*np.cos(3.64911521641 + 20452.8694122218*t)
	Z1 += 0.00000000035*np.cos(1.26816443678 + 1045.1548361876*t)
	Z1 += 0.00000000031*np.cos(0.64597904023 + 70.8494453042*t)
	Z1 += 0.00000000027*np.cos(1.46263510852 + 8094.5216858326*t)
	Z1 += 0.00000000034*np.cos(4.19685270992 + 13341.6743113068*t)
	Z1 += 0.00000000028*np.cos(0.28339069792 + 29050.7837433492*t)
	Z1 += 0.00000000031*np.cos(1.20392434392 + 12592.4500197826*t)
	Z1 += 0.00000000031*np.cos(1.27304383227 + 33019.0211122046*t)
	Z1 += 0.00000000036*np.cos(3.22618486892 + 49515.382508407*t)
	Z1 += 0.00000000028*np.cos(3.70748385631 + 4732.0306273434*t)
	Z1 += 0.00000000036*np.cos(1.74852565178 + 1581.959348283*t)
	Z1 += 0.00000000026*np.cos(3.58372397053 + 41.1019810544*t)
	Z1 += 0.00000000030*np.cos(3.31574729193 + 138.5174968707*t)
	Z1 += 0.00000000024*np.cos(1.14783906654 + 71.8126531507*t)
	Z1 += 0.00000000022*np.cos(1.56359401952 + 78.7137518304*t)
	Z1 += 0.00000000022*np.cos(1.22800274368 + 1169.5882514086*t)
	Z1 += 0.00000000024*np.cos(0.09566124749 + 277.0349937414*t)
	Z1 += 0.00000000019*np.cos(1.46315634551 + 215.7467759928*t)
	Z1 += 0.00000000018*np.cos(6.15872883408 + 942.062061969*t)
	Z1 += 0.00000000021*np.cos(4.93349279148 + 151.0476698429*t)
	Z1 += 0.00000000018*np.cos(0.76975485466 + 26087.9031415742*t)
	Z1 += 0.00000000017*np.cos(0.45299038457 + 148.0787244263*t)
	Z1 += 0.00000000017*np.cos(1.01231551874 + 415.5524906121*t)
	Z1 += 0.00000000017*np.cos(2.42309662009 + 1265.5674786264*t)
	Z1 += 0.00000000016*np.cos(4.65513429214 + 234.6397364404*t)
	Z1 += 0.00000000019*np.cos(3.54990981323 + 422.6660376129*t)
	Z1 += 0.00000000015*np.cos(4.05286495428 + 330.6189636582*t)
	Z1 += 0.00000000017*np.cos(1.47291446860 + 77.7505439839*t)
	Z1 += 0.00000000015*np.cos(4.99910482431 + 423.4167971383*t)
	Z1 += 0.00000000014*np.cos(2.62615297219 + 210.8514148832*t)
	return Z1*t




def Venus_Z2 (t): # 100 terms of order 2

	Z2 = 0.
	Z2 += 0.00009148022*np.cos(3.34791005272 + 10213.285546211*t)
	Z2 += 0.00000162299
	Z2 += 0.00000037478*np.cos(3.23028568613 + 213.299095438*t)
	Z2 += 0.00000027386*np.cos(6.15738229214 + 529.6909650946*t)
	Z2 += 0.00000013554*np.cos(5.33914310904 + 20426.571092422*t)
	Z2 += 0.00000008616*np.cos(0.77209239310 + 206.1855484372*t)
	Z2 += 0.00000005511*np.cos(3.23377546695 + 220.4126424388*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	Z2 += 0.00000002272*np.cos(4.09618627765 + 522.5774180938*t)
	Z2 += 0.00000001982*np.cos(2.34242027589 + 426.598190876*t)
	Z2 += 0.00000001250*np.cos(5.19399610895 + 1059.3819301892*t)
	Z2 += 0.00000000743*np.cos(6.08844686068 + 419.4846438752*t)
	Z2 += 0.00000000683*np.cos(0.01279354578 + 10186.9872264112*t)
	Z2 += 0.00000000641*np.cos(4.89317483950 + 74.7815985673*t)
	Z2 += 0.00000000527*np.cos(2.28325191846 + 433.7117378768*t)
	Z2 += 0.00000000519*np.cos(4.43200328483 + 7.1135470008*t)
	Z2 += 0.00000000540*np.cos(4.13666778984 + 10239.5838660108*t)
	Z2 += 0.00000000471*np.cos(1.76796792110 + 30639.856638633*t)
	Z2 += 0.00000000300*np.cos(3.09602587558 + 227.5261894396*t)
	Z2 += 0.00000000304*np.cos(6.04133491762 + 10988.808157535*t)
	Z2 += 0.00000000275*np.cos(3.26254603491 + 11790.6290886588*t)
	Z2 += 0.00000000303*np.cos(0.54544143559 + 2352.8661537718*t)
	Z2 += 0.00000000241*np.cos(6.17158812425 + 9437.762934887*t)
	Z2 += 0.00000000282*np.cos(4.03266493057 + 1577.3435424478*t)
	Z2 += 0.00000000238*np.cos(2.83008439932 + 10404.7338123226*t)
	Z2 += 0.00000000294*np.cos(1.18226869992 + 639.897286314*t)
	Z2 += 0.00000000259*np.cos(5.13154893421 + 9153.9036160218*t)
	Z2 += 0.00000000173*np.cos(0.49687224658 + 1066.49547719*t)
	Z2 += 0.00000000184*np.cos(0.95286916137 + 199.0720014364*t)
	Z2 += 0.00000000149*np.cos(4.90906266305 + 316.3918696566*t)
	Z2 += 0.00000000119*np.cos(4.09508225076 + 515.463871093*t)
	Z2 += 0.00000000106*np.cos(3.65846401642 + 1052.2683831884*t)
	Z2 += 0.00000000111*np.cos(5.37256662943 + 1589.0728952838*t)
	Z2 += 0.00000000117*np.cos(5.42784121915 + 5507.5532386674*t)
	Z2 += 0.00000000091*np.cos(6.04946077734 + 19651.048481098*t)
	Z2 += 0.00000000085*np.cos(6.16812793384 + 543.9180590962*t)
	Z2 += 0.00000000094*np.cos(3.15707903458 + 18073.7049386502*t)
	Z2 += 0.00000000079*np.cos(4.29766380692 + 14.2270940016*t)
	Z2 += 0.00000000071*np.cos(0.79640279433 + 10021.8372800994*t)
	Z2 += 0.00000000087*np.cos(5.24030699307 + 13367.9726311066*t)
	Z2 += 0.00000000068*np.cos(1.33776656115 + 210.1177017003*t)
	Z2 += 0.00000000075*np.cos(0.23631944253 + 8635.9420037632*t)
	Z2 += 0.00000000065*np.cos(5.05560764351 + 38.1330356378*t)
	Z2 += 0.00000000058*np.cos(1.55728577024 + 103.0927742186*t)
	Z2 += 0.00000000069*np.cos(1.12472727399 + 22003.9146348698*t)
	Z2 += 0.00000000050*np.cos(4.62591678818 + 15720.8387848784*t)
	Z2 += 0.00000000048*np.cos(2.40223184288 + 6283.0758499914*t)
	Z2 += 0.00000000062*np.cos(2.52935211512 + 9683.5945811164*t)
	Z2 += 0.00000000050*np.cos(1.42158496561 + 647.0108333148*t)
	Z2 += 0.00000000042*np.cos(1.14028846687 + 217.2312487011*t)
	Z2 += 0.00000000039*np.cos(3.30445248741 + 11322.6640983044*t)
	Z2 += 0.00000000053*np.cos(5.25641571023 + 10596.1820784342*t)
	Z2 += 0.00000000048*np.cos(3.80682230141 + 775.522611324*t)
	Z2 += 0.00000000053*np.cos(2.67570413760 + 216.4804891757*t)
	Z2 += 0.00000000041*np.cos(4.19285341280 + 14143.4952424306*t)
	Z2 += 0.00000000038*np.cos(4.71787306716 + 7058.5984613154*t)
	Z2 += 0.00000000031*np.cos(4.21025720942 + 110.2063212194*t)
	Z2 += 0.00000000029*np.cos(4.73183895530 + 9830.3890139878*t)
	Z2 += 0.00000000029*np.cos(6.18539185721 + 632.7837393132*t)
	Z2 += 0.00000000038*np.cos(1.87932224242 + 801.8209311238*t)
	Z2 += 0.00000000028*np.cos(2.23145809257 + 440.8252848776*t)
	Z2 += 0.00000000033*np.cos(0.42157783312 + 853.196381752*t)
	Z2 += 0.00000000034*np.cos(2.62408666722 + 19896.8801273274*t)
	Z2 += 0.00000000025*np.cos(3.95236444346 + 117.3198682202*t)
	Z2 += 0.00000000025*np.cos(2.78460430400 + 209.3669421749*t)
	Z2 += 0.00000000025*np.cos(2.85904964714 + 9411.4646150872*t)
	Z2 += 0.00000000022*np.cos(2.31119555973 + 18849.2275499742*t)
	Z2 += 0.00000000021*np.cos(5.74317740279 + 532.8723588323*t)
	Z2 += 0.00000000018*np.cos(1.87060868220 + 323.5054166574*t)
	Z2 += 0.00000000017*np.cos(4.58615737180 + 526.5095713569*t)
	Z2 += 0.00000000018*np.cos(4.95998579326 + 4705.7323075436*t)
	Z2 += 0.00000000017*np.cos(6.02623550832 + 95.9792272178*t)
	Z2 += 0.00000000019*np.cos(3.25100262086 + 20618.0193585336*t)
	Z2 += 0.00000000016*np.cos(0.53259218563 + 10206.1719992102*t)
	Z2 += 0.00000000016*np.cos(5.81970120815 + 10220.3990932118*t)
	Z2 += 0.00000000017*np.cos(5.41171132064 + 26.2983197998*t)
	Z2 += 0.00000000016*np.cos(6.02211293999 + 412.3710968744*t)
	Z2 += 0.00000000015*np.cos(4.61555386478 + 9999.986450773*t)
	Z2 += 0.00000000015*np.cos(4.88064054230 + 10426.584641649*t)
	Z2 += 0.00000000021*np.cos(0.31827807970 + 11015.1064773348*t)
	Z2 += 0.00000000015*np.cos(0.00767394500 + 202.2533951741*t)
	Z2 += 0.00000000015*np.cos(6.18636933791 + 191.4482661116*t)
	Z2 += 0.00000000016*np.cos(3.94104051711 + 10742.9765113056*t)
	Z2 += 0.00000000017*np.cos(2.69405014279 + 3128.3887650958*t)
	Z2 += 0.00000000012*np.cos(2.50603952514 + 149.5631971346*t)
	Z2 += 0.00000000013*np.cos(5.75707842894 + 525.7588118315*t)
	Z2 += 0.00000000011*np.cos(2.77607629936 + 73.297125859*t)
	Z2 += 0.00000000011*np.cos(0.99969948118 + 1596.1864422846*t)
	Z2 += 0.00000000012*np.cos(3.07376705363 + 1045.1548361876*t)
	Z2 += 0.00000000011*np.cos(0.01879438470 + 309.2783226558*t)
	Z2 += 0.00000000010*np.cos(4.70919553736 + 533.6231183577*t)
	Z2 += 0.00000000009*np.cos(2.95298668799 + 234.6397364404*t)
	Z2 += 0.00000000008*np.cos(5.32804606956 + 1162.4747044078*t)
	Z2 += 0.00000000010*np.cos(2.94983110269 + 735.8765135318*t)
	Z2 += 0.00000000009*np.cos(5.72498770637 + 2118.7638603784*t)
	Z2 += 0.00000000008*np.cos(2.26838540542 + 625.6701923124*t)
	Z2 += 0.00000000009*np.cos(2.32555299082 + 949.1756089698*t)
	Z2 += 0.00000000007*np.cos(4.26888098753 + 36.6485629295*t)
	Z2 += 0.00000000007*np.cos(3.46601151480 + 956.2891559706*t)
	Z2 += 0.00000000007*np.cos(1.63081873969 + 39.6175083461*t)
	return Z2*t*t




def Venus_Z3 (t): # 42 terms of order 3

	Z3 = 0.
	Z3 += 0.00000272005*np.cos(4.87648116140 + 10213.285546211*t)
	Z3 -= 0.00000014894
	Z3 += 0.00000001743*np.cos(0.42985032723 + 20426.571092422*t)
	Z3 += 0.00000001302*np.cos(4.84806136860 + 213.299095438*t)
	Z3 += 0.00000001364*np.cos(2.43564490971 + 206.1855484372*t)
	Z3 += 0.00000000920*np.cos(1.65069146673 + 529.6909650946*t)
	Z3 += 0.00000000716*np.cos(1.50799790954 + 220.4126424388*t)
	Z3 += 0.00000000423*np.cos(4.54129218357 + 536.8045120954*t)
	Z3 += 0.00000000282*np.cos(5.95440671732 + 522.5774180938*t)
	Z3 += 0.00000000090*np.cos(0.51819099535 + 433.7117378768*t)
	Z3 += 0.00000000094*np.cos(1.55249614896 + 419.4846438752*t)
	Z3 += 0.00000000079*np.cos(1.38892285542 + 227.5261894396*t)
	Z3 += 0.00000000094*np.cos(0.17438010106 + 426.598190876*t)
	Z3 += 0.00000000048*np.cos(3.11903200545 + 1059.3819301892*t)
	Z3 += 0.00000000050*np.cos(2.64433369691 + 199.0720014364*t)
	Z3 += 0.00000000042*np.cos(2.65785543548 + 7.1135470008*t)
	Z3 += 0.00000000033*np.cos(1.54914240166 + 10186.9872264112*t)
	Z3 += 0.00000000028*np.cos(5.89394518040 + 515.463871093*t)
	Z3 += 0.00000000027*np.cos(5.17159300173 + 1066.49547719*t)
	Z3 += 0.00000000024*np.cos(4.43334493389 + 543.9180590962*t)
	Z3 += 0.00000000026*np.cos(5.61220088462 + 639.897286314*t)
	Z3 += 0.00000000018*np.cos(0.02154769101 + 74.7815985673*t)
	Z3 += 0.00000000025*np.cos(5.78743368814 + 10239.5838660108*t)
	Z3 += 0.00000000017*np.cos(2.57902262762 + 14.2270940016*t)
	Z3 += 0.00000000013*np.cos(3.07320748125 + 210.1177017003*t)
	Z3 += 0.00000000015*np.cos(0.26812223508 + 30639.856638633*t)
	Z3 += 0.00000000012*np.cos(5.68952008926 + 1052.2683831884*t)
	Z3 += 0.00000000011*np.cos(0.06567554803 + 316.3918696566*t)
	Z3 += 0.00000000011*np.cos(5.88691938543 + 647.0108333148*t)
	Z3 += 0.00000000010*np.cos(5.48827753353 + 9437.762934887*t)
	Z3 += 0.00000000008*np.cos(4.60069153442 + 11790.6290886588*t)
	Z3 += 0.00000000009*np.cos(0.49541679064 + 440.8252848776*t)
	Z3 += 0.00000000010*np.cos(1.90027732701 + 2352.8661537718*t)
	Z3 += 0.00000000007*np.cos(4.01090297903 + 1589.0728952838*t)
	Z3 += 0.00000000009*np.cos(0.86239699726 + 10988.808157535*t)
	Z3 += 0.00000000008*np.cos(0.88032790118 + 216.4804891757*t)
	Z3 += 0.00000000006*np.cos(6.21088176821 + 38.1330356378*t)
	Z3 += 0.00000000007*np.cos(3.28974856542 + 103.0927742186*t)
	Z3 += 0.00000000004*np.cos(4.75446574078 + 853.196381752*t)
	Z3 += 0.00000000004*np.cos(1.59186789207 + 632.7837393132*t)
	Z3 += 0.00000000004*np.cos(1.52800084237 + 412.3710968744*t)
	Z3 += 0.00000000003*np.cos(2.72859893423 + 217.2312487011*t)
	return Z3*t*t*t




def Venus_Z4 (t): # 20 terms of order 4

	Z4 = 0.
	Z4 += 0.00000006175*np.cos(0.17121460361 + 10213.285546211*t)
	Z4 += 0.00000000164*np.cos(4.10546661445 + 206.1855484372*t)
	Z4 -= 0.00000000115
	Z4 += 0.00000000072*np.cos(6.04348211714 + 220.4126424388*t)
	Z4 += 0.00000000070*np.cos(6.10651561968 + 213.299095438*t)
	Z4 += 0.00000000044*np.cos(2.79536133222 + 536.8045120954*t)
	Z4 += 0.00000000041*np.cos(2.50364136928 + 20426.571092422*t)
	Z4 += 0.00000000026*np.cos(1.66128176108 + 522.5774180938*t)
	Z4 += 0.00000000016*np.cos(5.95724279756 + 227.5261894396*t)
	Z4 += 0.00000000011*np.cos(4.33140895473 + 199.0720014364*t)
	Z4 += 0.00000000012*np.cos(5.02489197754 + 433.7117378768*t)
	Z4 += 0.00000000008*np.cos(3.36029048603 + 419.4846438752*t)
	Z4 += 0.00000000006*np.cos(1.39462759175 + 515.463871093*t)
	Z4 += 0.00000000005*np.cos(2.67511593664 + 543.9180590962*t)
	Z4 += 0.00000000004*np.cos(4.65054077397 + 529.6909650946*t)
	Z4 += 0.00000000005*np.cos(4.82245392155 + 426.598190876*t)
	Z4 += 0.00000000003*np.cos(0.96348403857 + 7.1135470008*t)
	Z4 += 0.00000000003*np.cos(0.80949781331 + 14.2270940016*t)
	Z4 += 0.00000000003*np.cos(3.63118822382 + 1066.49547719*t)
	Z4 += 0.00000000002*np.cos(3.76452892490 + 639.897286314*t)
	return Z4*t*t*t*t




def Venus_Z5 (t): # 11 terms of order 5

	Z5 = 0.
	Z5 += 0.00000000108*np.cos(1.67439739641 + 10213.285546211*t)
	Z5 += 0.00000000028
	Z5 += 0.00000000015*np.cos(5.75563126750 + 206.1855484372*t)
	Z5 += 0.00000000005*np.cos(4.29978807671 + 220.4126424388*t)
	Z5 += 0.00000000003*np.cos(0.96254361103 + 536.8045120954*t)
	Z5 += 0.00000000003*np.cos(3.66751123903 + 20426.571092422*t)
	Z5 += 0.00000000002*np.cos(3.96773929080 + 522.5774180938*t)
	Z5 += 0.00000000002*np.cos(4.22112932205 + 227.5261894396*t)
	Z5 += 0.00000000002*np.cos(6.02426931559 + 199.0720014364*t)
	Z5 += 0.00000000001*np.cos(3.19657723128 + 515.463871093*t)
	Z5 += 0.00000000001*np.cos(3.25850463040 + 433.7117378768*t)
	return Z5*t*t*t*t*t





def Earth_X0 (t): # 1199 terms of order 0

	X0 = 0.
	X0 += 0.99982624851*np.cos(1.75348568475 + 6283.0758499914*t)
	X0 += 0.00835254761*np.cos(1.71034539458 + 12566.1516999828*t)
	X0 += 0.00590518455
	X0 += 0.00493120585*np.cos(3.74115834452 + 529.6909650946*t)
	X0 += 0.00271650686*np.cos(4.01601440281 + 213.299095438*t)
	X0 += 0.00155434220*np.cos(2.17052065758 + 38.1330356378*t)
	X0 += 0.00083789104*np.cos(2.33967726393 + 74.7815985673*t)
	X0 += 0.00011821467*np.cos(4.04599151293 + 1059.3819301892*t)
	X0 += 0.00010466596*np.cos(1.66722645223 + 18849.2275499742*t)
	X0 += 0.00007614486*np.cos(3.24052535910 + 426.598190876*t)
	X0 += 0.00003110838*np.cos(0.66875185215 + 83996.84731811189*t)
	X0 += 0.00001940284*np.cos(1.01236647756 + 206.1855484372*t)
	X0 += 0.00001941229*np.cos(4.79891913828 + 149.5631971346*t)
	X0 += 0.00001887816*np.cos(3.89254735986 + 220.4126424388*t)
	X0 += 0.00002137256*np.cos(1.09235189672 + 1577.3435424478*t)
	X0 += 0.00001709103*np.cos(0.49540223397 + 6279.5527316424*t)
	X0 += 0.00001707882*np.cos(6.15315547484 + 6286.5989683404*t)
	X0 += 0.00001427281*np.cos(3.86901277110 + 522.5774180938*t)
	X0 += 0.00001399119*np.cos(0.47619416596 + 536.8045120954*t)
	X0 += 0.00001186109*np.cos(0.77647243459 + 76.2660712756*t)
	X0 += 0.00001445242*np.cos(3.47272783760 + 2352.8661537718*t)
	X0 += 0.00001091006*np.cos(3.68984782465 + 5223.6939198022*t)
	X0 += 0.00000934429*np.cos(6.07389922585 + 12036.4607348882*t)
	X0 += 0.00000813685*np.cos(3.25483611884 + 36.6485629295*t)
	X0 += 0.00000767074*np.cos(4.22743731914 + 39.6175083461*t)
	X0 += 0.00000684416*np.cos(1.30699021227 + 5753.3848848968*t)
	X0 += 0.00000734455*np.cos(4.35500196530 + 398.1490034082*t)
	X0 += 0.00000722380*np.cos(3.17571010919 + 10213.285546211*t)
	X0 += 0.00000681437*np.cos(2.21821534685 + 4705.7323075436*t)
	X0 += 0.00000611238*np.cos(5.38479234323 + 6812.766815086*t)
	X0 += 0.00000624814*np.cos(0.27936466811 + 73.297125859*t)
	X0 += 0.00000451836*np.cos(6.08768280868 + 5884.9268465832*t)
	X0 += 0.00000451953*np.cos(1.27933728354 + 6256.7775301916*t)
	X0 += 0.00000449517*np.cos(5.36923831714 + 6309.3741697912*t)
	X0 += 0.00000430020*np.cos(4.27132872598 + 1589.0728952838*t)
	X0 += 0.00000404057*np.cos(0.54520082887 + 6681.2248533996*t)
	X0 += 0.00000540957*np.cos(0.78677364655 + 775.522611324*t)
	X0 += 0.00000547004*np.cos(1.46146650376 + 14143.4952424306*t)
	X0 += 0.00000520484*np.cos(4.43295799975 + 7860.4193924392*t)
	X0 += 0.00000317027*np.cos(5.15642699057 + 7.1135470008*t)
	X0 += 0.00000315448*np.cos(6.15822972778 + 419.4846438752*t)
	X0 += 0.00000314535*np.cos(2.49150428438 + 639.897286314*t)
	X0 += 0.00000278283*np.cos(4.92949906340 + 110.2063212194*t)
	X0 += 0.00000214960*np.cos(4.50213844573 + 11506.7697697936*t)
	X0 += 0.00000227892*np.cos(1.23941482802 + 7058.5984613154*t)
	X0 += 0.00000225878*np.cos(3.27244306207 + 4694.0029547076*t)
	X0 += 0.00000255820*np.cos(2.26556277246 + 12168.0026965746*t)
	X0 += 0.00000256182*np.cos(1.45474116190 + 709.9330485583*t)
	X0 += 0.00000215880*np.cos(5.80308851749 + 316.3918696566*t)
	X0 += 0.00000220723*np.cos(5.28296138948 + 103.0927742186*t)
	X0 += 0.00000178120*np.cos(2.96205424204 + 796.2980068164*t)
	X0 += 0.00000161205*np.cos(1.47337718956 + 5486.777843175*t)
	X0 += 0.00000178325*np.cos(6.24374704602 + 6283.14316029419*t)
	X0 += 0.00000178325*np.cos(0.40466470869 + 6283.0085396886*t)
	X0 += 0.00000155487*np.cos(1.62409309523 + 25132.3033999656*t)
	X0 += 0.00000209024*np.cos(5.85207528073 + 11790.6290886588*t)
	X0 += 0.00000199971*np.cos(4.07209938245 + 17789.845619785*t)
	X0 += 0.00000128933*np.cos(5.21693314150 + 7079.3738568078*t)
	X0 += 0.00000128099*np.cos(4.80182882228 + 3738.761430108*t)
	X0 += 0.00000136024*np.cos(2.00155312383 + 1.4844727083*t)
	X0 += 0.00000115751*np.cos(2.42719613583 + 632.7837393132*t)
	X0 += 0.00000105920*np.cos(3.12238967563 + 433.7117378768*t)
	X0 += 0.00000099041*np.cos(3.01619631297 + 1052.2683831884*t)
	X0 += 0.00000094483*np.cos(4.60187620729 + 10977.078804699*t)
	X0 += 0.00000106729*np.cos(3.15526562554 + 1162.4747044078*t)
	X0 += 0.00000077801*np.cos(1.84444797200 + 8827.3902698748*t)
	X0 += 0.00000077277*np.cos(3.58396027325 + 5507.5532386674*t)
	X0 += 0.00000068586*np.cos(0.77840084573 + 1066.49547719*t)
	X0 += 0.00000065359*np.cos(3.65156347970 + 11769.8536931664*t)
	X0 += 0.00000063240*np.cos(2.24124130944 + 6262.300454499*t)
	X0 += 0.00000062961*np.cos(4.40729381941 + 6303.8512454838*t)
	X0 += 0.00000085870*np.cos(3.02430773140 + 167283.76158766549*t)
	X0 += 0.00000079201*np.cos(2.49366716519 + 6069.7767545534*t)
	X0 += 0.00000060048*np.cos(3.39951805979 + 4136.9104335162*t)
	X0 += 0.00000075601*np.cos(4.15956023781 + 6496.3749454294*t)
	X0 += 0.00000056030*np.cos(1.32365571358 + 949.1756089698*t)
	X0 += 0.00000067771*np.cos(4.03416283669 + 9437.762934887*t)
	X0 += 0.00000053715*np.cos(1.56222706033 + 1194.4470102246*t)
	X0 += 0.00000057574*np.cos(2.67881766950 + 6282.0955289232*t)
	X0 += 0.00000057574*np.cos(3.96971590315 + 6284.0561710596*t)
	X0 += 0.00000051129*np.cos(1.31255522350 + 6290.1893969922*t)
	X0 += 0.00000065337*np.cos(0.27633556843 + 846.0828347512*t)
	X0 += 0.00000050529*np.cos(5.34827650648 + 6275.9623029906*t)
	X0 += 0.00000049613*np.cos(2.64370071484 + 6127.6554505572*t)
	X0 += 0.00000063189*np.cos(5.79436684832 + 148.0787244263*t)
	X0 += 0.00000063140*np.cos(0.73615138189 + 224.3447957019*t)
	X0 += 0.00000048085*np.cos(4.00886197380 + 6438.4962494256*t)
	X0 += 0.00000057340*np.cos(3.79459979103 + 3154.6870848956*t)
	X0 += 0.00000047378*np.cos(6.10705175562 + 3128.3887650958*t)
	X0 += 0.00000048104*np.cos(4.77180566934 + 801.8209311238*t)
	X0 += 0.00000041149*np.cos(3.32726302190 + 8429.2412664666*t)
	X0 += 0.00000052309*np.cos(5.30571599873 + 13367.9726311066*t)
	X0 += 0.00000051321*np.cos(5.78450026632 + 12352.8526045448*t)
	X0 += 0.00000050648*np.cos(2.05206551992 + 11856.2186514245*t)
	X0 += 0.00000043381*np.cos(3.64501749522 + 17260.1546546904*t)
	X0 += 0.00000039554*np.cos(4.93022392385 + 5481.2549188676*t)
	X0 += 0.00000048969*np.cos(0.45418080759 + 9225.539273283*t)
	X0 += 0.00000047568*np.cos(3.16123585999 + 5856.4776591154*t)
	X0 += 0.00000047271*np.cos(0.62147119447 + 2544.3144198834*t)
	X0 += 0.00000032481*np.cos(0.80957263520 + 3930.2096962196*t)
	X0 += 0.00000032559*np.cos(1.97427864771 + 2146.1654164752*t)
	X0 += 0.00000037824*np.cos(4.58891701161 + 35.1640902212*t)
	X0 += 0.00000031150*np.cos(1.37429681895 + 63.7358983034*t)
	X0 += 0.00000032521*np.cos(2.84566871337 + 4164.311989613*t)
	X0 += 0.00000030675*np.cos(4.21800166059 + 11.0457002639*t)
	X0 += 0.00000032546*np.cos(3.01796808307 + 5088.6288397668*t)
	X0 += 0.00000028515*np.cos(6.10933021271 + 12569.6748183318*t)
	X0 += 0.00000036898*np.cos(2.91097134183 + 18073.7049386502*t)
	X0 += 0.00000033986*np.cos(6.17599336585 + 3340.6124266998*t)
	X0 += 0.00000028741*np.cos(3.71398829023 + 151.0476698429*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000024936*np.cos(2.17935828787 + 26.2983197998*t)
	X0 += 0.00000030322*np.cos(1.99340330773 + 4535.0594369244*t)
	X0 += 0.00000028166*np.cos(0.48127325250 + 12562.6285816338*t)
	X0 += 0.00000021880*np.cos(5.12635088590 + 11371.7046897582*t)
	X0 += 0.00000023782*np.cos(3.76207354349 + 227.5261894396*t)
	X0 += 0.00000021642*np.cos(4.63524156478 + 12559.038152982*t)
	X0 += 0.00000020480*np.cos(1.46713660207 + 7084.8967811152*t)
	X0 += 0.00000023267*np.cos(0.46827104623 + 85.8272988312*t)
	X0 += 0.00000022744*np.cos(1.67012539714 + 71.8126531507*t)
	X0 += 0.00000019930*np.cos(4.38335547038 + 2118.7638603784*t)
	X0 += 0.00000026112*np.cos(0.30447108865 + 71430.69561812909*t)
	X0 += 0.00000022867*np.cos(4.76437399404 + 8031.0922630584*t)
	X0 += 0.00000018593*np.cos(3.38415795860 + 1748.016413067*t)
	X0 += 0.00000023250*np.cos(6.19030311409 + 18319.5365848796*t)
	X0 += 0.00000022286*np.cos(3.93734569173 + 2.9689454166*t)
	X0 += 0.00000021992*np.cos(0.11232184552 + 77.7505439839*t)
	X0 += 0.00000017104*np.cos(0.58684867006 + 4933.2084403326*t)
	X0 += 0.00000020026*np.cos(4.02923197304 + 209.3669421749*t)
	X0 += 0.00000021687*np.cos(4.30348901447 + 10447.3878396044*t)
	X0 += 0.00000019681*np.cos(0.87544248531 + 217.2312487011*t)
	X0 += 0.00000021065*np.cos(3.80028088787 + 7477.522860216*t)
	X0 += 0.00000019075*np.cos(5.91973929854 + 202.2533951741*t)
	X0 += 0.00000016444*np.cos(2.55185354475 + 735.8765135318*t)
	X0 += 0.00000015582*np.cos(5.27513963301 + 742.9900605326*t)
	X0 += 0.00000018299*np.cos(3.06814130824 + 323.5054166574*t)
	X0 += 0.00000017360*np.cos(3.01137661271 + 138.5174968707*t)
	X0 += 0.00000015488*np.cos(4.00542220967 + 515.463871093*t)
	X0 += 0.00000014285*np.cos(1.29528607840 + 2942.4634232916*t)
	X0 += 0.00000013898*np.cos(4.59171958613 + 8635.9420037632*t)
	X0 += 0.00000019220*np.cos(0.49428010004 + 17298.1823273262*t)
	X0 += 0.00000018884*np.cos(2.42694414831 + 156137.47598479928*t)
	X0 += 0.00000017889*np.cos(0.15750451509 + 1592.5960136328*t)
	X0 += 0.00000016952*np.cos(1.82073561882 + 853.196381752*t)
	X0 += 0.00000013605*np.cos(5.19721055627 + 13095.8426650774*t)
	X0 += 0.00000015049*np.cos(3.12084096050 + 16496.3613962024*t)
	X0 += 0.00000013852*np.cos(6.16243027421 + 7632.9432596502*t)
	X0 += 0.00000014942*np.cos(1.41788930965 + 20426.571092422*t)
	X0 += 0.00000013247*np.cos(3.60768174652 + 12139.5535091068*t)
	X0 += 0.00000011583*np.cos(5.46076026245 + 5331.3574437408*t)
	X0 += 0.00000014329*np.cos(6.02791958133 + 7342.4577801806*t)
	X0 += 0.00000011229*np.cos(1.18029367551 + 199.0720014364*t)
	X0 += 0.00000012375*np.cos(3.10941923273 + 6279.4854213396*t)
	X0 += 0.00000012366*np.cos(3.53911446434 + 6286.6662786432*t)
	X0 += 0.00000009951*np.cos(1.25735916596 + 7234.794256242*t)
	X0 += 0.00000010836*np.cos(0.34161370756 + 543.9180590962*t)
	X0 += 0.00000012425*np.cos(1.06396563046 + 15110.4661198662*t)
	X0 += 0.00000011587*np.cos(0.61075744193 + 525.7588118315*t)
	X0 += 0.00000011004*np.cos(2.19276723240 + 10988.808157535*t)
	X0 += 0.00000011447*np.cos(3.72704255770 + 533.6231183577*t)
	X0 += 0.00000011583*np.cos(4.05256206393 + 5729.506447149*t)
	X0 += 0.00000009046*np.cos(5.43016645841 + 9623.6882766912*t)
	X0 += 0.00000008869*np.cos(5.04690941813 + 6148.010769956*t)
	X0 += 0.00000010507*np.cos(2.62758025060 + 6836.6452528338*t)
	X0 += 0.00000011129*np.cos(4.17728063171 + 15720.8387848784*t)
	X0 += 0.00000008614*np.cos(1.60161176919 + 6418.1409300268*t)
	X0 += 0.00000008532*np.cos(2.46198384967 + 14712.317116458*t)
	X0 += 0.00000010546*np.cos(4.79503596728 + 1349.8674096588*t)
	X0 += 0.00000010480*np.cos(2.95288908781 + 5999.2165311262*t)
	X0 += 0.00000007456*np.cos(5.42522643084 + 6040.3472460174*t)
	X0 += 0.00000007968*np.cos(3.42892246372 + 1692.1656695024*t)
	X0 += 0.00000007469*np.cos(2.41048728829 + 1478.8665740644*t)
	X0 += 0.00000007185*np.cos(3.51955509534 + 216.4804891757*t)
	X0 += 0.00000009820*np.cos(3.69556194245 + 6566.9351688566*t)
	X0 += 0.00000007015*np.cos(1.38855213071 + 210.1177017003*t)
	X0 += 0.00000009171*np.cos(3.92216439653 + 5643.1785636774*t)
	X0 += 0.00000007018*np.cos(1.23420199826 + 6525.8044539654*t)
	X0 += 0.00000007120*np.cos(2.46055859947 + 415.5524906121*t)
	X0 += 0.00000009797*np.cos(1.91951822764 + 21228.3920235458*t)
	X0 += 0.00000009060*np.cos(4.61643194755 + 4690.4798363586*t)
	X0 += 0.00000006867*np.cos(4.39735582882 + 117.3198682202*t)
	X0 += 0.00000007545*np.cos(1.23604549224 + 12539.853380183*t)
	X0 += 0.00000008227*np.cos(0.32929613711 + 10973.55568635*t)
	X0 += 0.00000007202*np.cos(5.88391543785 + 6245.0481773556*t)
	X0 += 0.00000007144*np.cos(0.76464650349 + 6321.1035226272*t)
	X0 += 0.00000006998*np.cos(4.03899647772 + 1265.5674786264*t)
	X0 += 0.00000006625*np.cos(0.70112927898 + 5327.4761083828*t)
	X0 += 0.00000006681*np.cos(2.82477610388 + 956.2891559706*t)
	X0 += 0.00000007412*np.cos(5.03197290869 + 23543.23050468179*t)
	X0 += 0.00000006160*np.cos(0.94570829909 + 12964.300703391*t)
	X0 += 0.00000006378*np.cos(6.20903842618 + 951.7184062506*t)
	X0 += 0.00000006359*np.cos(5.03541261021 + 1990.745017041*t)
	X0 += 0.00000007016*np.cos(5.01568204778 + 14.2270940016*t)
	X0 += 0.00000007409*np.cos(3.19745179103 + 1581.959348283*t)
	X0 += 0.00000006656*np.cos(2.37523372802 + 647.0108333148*t)
	X0 += 0.00000005777*np.cos(6.10164059960 + 955.5997416086*t)
	X0 += 0.00000006393*np.cos(3.97543391449 + 24072.9214697764*t)
	X0 += 0.00000007793*np.cos(4.30411864972 + 22003.9146348698*t)
	X0 += 0.00000006346*np.cos(3.50687769075 + 5230.807466803*t)
	X0 += 0.00000007534*np.cos(3.51457135016 + 18422.62935909819*t)
	X0 += 0.00000006953*np.cos(2.74384548965 + 155.4203994342*t)
	X0 += 0.00000006224*np.cos(2.24416723229 + 18451.07854656599*t)
	X0 += 0.00000006244*np.cos(5.44473078234 + 70.8494453042*t)
	X0 += 0.00000006258*np.cos(5.30284030996 + 95.9792272178*t)
	X0 += 0.00000005762*np.cos(3.49866583471 + 1551.045222648*t)
	X0 += 0.00000006251*np.cos(4.45479090841 + 6288.5987742988*t)
	X0 += 0.00000006251*np.cos(2.19374266424 + 6277.552925684*t)
	X0 += 0.00000005074*np.cos(4.24610777191 + 526.5095713569*t)
	X0 += 0.00000004978*np.cos(0.09070559075 + 532.8723588323*t)
	X0 += 0.00000006278*np.cos(0.64265846614 + 5216.5803728014*t)
	X0 += 0.00000005875*np.cos(2.36907113150 + 78.7137518304*t)
	X0 += 0.00000006405*np.cos(2.25334669847 + 5650.2921106782*t)
	X0 += 0.00000004737*np.cos(3.74210997787 + 14314.1681130498*t)
	X0 += 0.00000004646*np.cos(1.33492108974 + 553.5694028424*t)
	X0 += 0.00000006109*np.cos(5.67990095410 + 111.4301614968*t)
	X0 += 0.00000006196*np.cos(2.58704269072 + 84672.47584450469*t)
	X0 += 0.00000006160*np.cos(4.78249950381 + 239424.39025435288*t)
	X0 += 0.00000004988*np.cos(0.73122576373 + 77713.7714681205*t)
	X0 += 0.00000005414*np.cos(2.99961957880 + 6179.9830757728*t)
	X0 += 0.00000005414*np.cos(3.65424820690 + 6386.16862421*t)
	X0 += 0.00000004863*np.cos(3.76722340488 + 90279.92316810328*t)
	X0 += 0.00000005711*np.cos(4.32714492993 + 6915.8595893046*t)
	X0 += 0.00000004269*np.cos(2.38367994999 + 7875.6718636242*t)
	X0 += 0.00000004017*np.cos(3.78580907612 + 6254.6266625236*t)
	X0 += 0.00000004067*np.cos(2.42033776129 + 3634.6210245184*t)
	X0 += 0.00000003993*np.cos(2.86272124248 + 6311.5250374592*t)
	X0 += 0.00000004272*np.cos(0.55411909769 + 1375.7737998458*t)
	X0 += 0.00000004712*np.cos(4.78612693635 + 114.3991069134*t)
	X0 += 0.00000005305*np.cos(3.34359172920 + 25158.6017197654*t)
	X0 += 0.00000005185*np.cos(1.85847454376 + 222.8603229936*t)
	X0 += 0.00000004288*np.cos(1.51938558324 + 277.0349937414*t)
	X0 += 0.00000003701*np.cos(1.00270889275 + 1596.1864422846*t)
	X0 += 0.00000004804*np.cos(2.82827032932 + 5760.4984318976*t)
	X0 += 0.00000004349*np.cos(5.62752376053 + 7238.67559160*t)
	X0 += 0.00000004598*np.cos(0.76405567220 + 146.594251718*t)
	X0 += 0.00000004119*np.cos(3.29663921982 + 6709.6740408674*t)
	X0 += 0.00000004024*np.cos(0.55473527406 + 11015.1064773348*t)
	X0 += 0.00000004409*np.cos(3.80563977803 + 6805.6532680852*t)
	X0 += 0.00000003348*np.cos(3.54433469125 + 12592.4500197826*t)
	X0 += 0.00000003532*np.cos(3.92898013298 + 9917.6968745098*t)
	X0 += 0.00000003580*np.cos(4.19680692038 + 11926.2544136688*t)
	X0 += 0.00000003336*np.cos(1.79793376416 + 10575.4066829418*t)
	X0 += 0.00000003149*np.cos(6.21487368875 + 4292.3308329504*t)
	X0 += 0.00000002979*np.cos(6.20067573402 + 12566.2190102856*t)
	X0 += 0.00000003981*np.cos(1.19685195313 + 13341.6743113068*t)
	X0 += 0.00000003025*np.cos(3.18620101831 + 18052.9295431578*t)
	X0 += 0.00000003624*np.cos(5.60981856994 + 6208.2942514241*t)
	X0 += 0.00000003754*np.cos(1.04640420137 + 490.3340891794*t)
	X0 += 0.00000003581*np.cos(1.03995231220 + 6357.8574485587*t)
	X0 += 0.00000003698*np.cos(5.22105764023 + 5966.6839803348*t)
	X0 += 0.00000002793*np.cos(4.13369432245 + 3.523118349*t)
	X0 += 0.00000003626*np.cos(1.42632163253 + 6599.467719648*t)
	X0 += 0.00000003625*np.cos(3.00192353938 + 6019.9919266186*t)
	X0 += 0.00000002821*np.cos(3.43414737256 + 299.1263942692*t)
	X0 += 0.00000002611*np.cos(2.43263787635 + 6702.5604938666*t)
	X0 += 0.00000002535*np.cos(1.58310693201 + 31415.379249957*t)
	X0 += 0.00000003520*np.cos(5.37986364075 + 250570.67585721909*t)
	X0 += 0.00000003418*np.cos(2.52366884638 + 351.8165923087*t)
	X0 += 0.00000002593*np.cos(4.91225714775 + 16730.4636895958*t)
	X0 += 0.00000003434*np.cos(3.64656881585 + 6546.1597733642*t)
	X0 += 0.00000002788*np.cos(3.30835728306 + 12721.572099417*t)
	X0 += 0.00000003383*np.cos(1.74748489437 + 14945.3161735544*t)
	X0 += 0.00000002655*np.cos(2.90453219642 + 625.6701923124*t)
	X0 += 0.00000002653*np.cos(4.42220751136 + 5863.5912061162*t)
	X0 += 0.00000003049*np.cos(0.02765893726 + 4732.0306273434*t)
	X0 += 0.00000002378*np.cos(3.62936279948 + 2388.8940204492*t)
	X0 += 0.00000002982*np.cos(0.59289983624 + 109.9456887885*t)
	X0 += 0.00000002979*np.cos(0.36159339669 + 12566.08438968*t)
	X0 += 0.00000002716*np.cos(3.06935305016 + 12029.3471878874*t)
	X0 += 0.00000002221*np.cos(5.26072022037 + 13362.4497067992*t)
	X0 += 0.00000003014*np.cos(4.76640877174 + 29088.811415985*t)
	X0 += 0.00000002742*np.cos(5.06666852445 + 13916.0191096416*t)
	X0 += 0.00000002265*np.cos(5.95706192557 + 6076.8903015542*t)
	X0 += 0.00000002529*np.cos(5.94709040579 + 12043.574281889*t)
	X0 += 0.00000002015*np.cos(2.48432243402 + 6262.7205305926*t)
	X0 += 0.00000002218*np.cos(0.69324011482 + 6489.2613984286*t)
	X0 += 0.00000002005*np.cos(4.16423889100 + 6303.4311693902*t)
	X0 += 0.00000002009*np.cos(4.09759324685 + 4701.1165017084*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000002105*np.cos(4.63993587835 + 5746.271337896*t)
	X0 += 0.00000001937*np.cos(0.22112768064 + 13521.7514415914*t)
	X0 += 0.00000002464*np.cos(4.36724603517 + 10021.8372800994*t)
	X0 += 0.00000002602*np.cos(4.28001549113 + 4590.910180489*t)
	X0 += 0.00000001893*np.cos(5.66795892365 + 6286.9571853494*t)
	X0 += 0.00000001893*np.cos(0.98057464900 + 6279.1945146334*t)
	X0 += 0.00000002549*np.cos(0.03994924305 + 1169.5882514086*t)
	X0 += 0.00000002156*np.cos(2.00898711721 + 18139.2945014159*t)
	X0 += 0.00000001962*np.cos(0.25060934155 + 4686.8894077068*t)
	X0 += 0.00000001884*np.cos(5.27011523204 + 242.728603974*t)
	X0 += 0.00000002289*np.cos(2.78836600930 + 1045.1548361876*t)
	X0 += 0.00000002436*np.cos(4.40772141072 + 95143.1329209781*t)
	X0 += 0.00000001759*np.cos(0.19888470443 + 13517.8701062334*t)
	X0 += 0.00000002163*np.cos(1.41797947214 + 6037.244203762*t)
	X0 += 0.00000002167*np.cos(4.72612563566 + 23013.5395395872*t)
	X0 += 0.00000002250*np.cos(2.39728930597 + 12669.2444742014*t)
	X0 += 0.00000002052*np.cos(5.23006568302 + 6528.9074962208*t)
	X0 += 0.00000001774*np.cos(2.08484497348 + 6819.8803620868*t)
	X0 += 0.00000001842*np.cos(0.34675193374 + 65147.6197681377*t)
	X0 += 0.00000001945*np.cos(3.29102485680 + 1155.361157407*t)
	X0 += 0.00000001549*np.cos(0.71612589777 + 20.7753954924*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001646*np.cos(3.01660183388 + 440.8252848776*t)
	X0 += 0.00000001543*np.cos(5.96098287839 + 6272.4391846416*t)
	X0 += 0.00000001543*np.cos(0.68755069426 + 6293.7125153412*t)
	X0 += 0.00000001539*np.cos(5.57331447211 + 65.2203710117*t)
	X0 += 0.00000001727*np.cos(4.50674659690 + 17654.7805397496*t)
	X0 += 0.00000001433*np.cos(1.48123692595 + 942.062061969*t)
	X0 += 0.00000001427*np.cos(1.68851809181 + 13119.72110282519*t)
	X0 += 0.00000001395*np.cos(3.25347392533 + 10177.2576795336*t)
	X0 += 0.00000001819*np.cos(3.18848907826 + 18875.525869774*t)
	X0 += 0.00000001740*np.cos(5.48710781556 + 19651.048481098*t)
	X0 += 0.00000001794*np.cos(5.74176427744 + 25934.1243310894*t)
	X0 += 0.00000001800*np.cos(6.18908014275 + 33019.0211122046*t)
	X0 += 0.00000001349*np.cos(5.75097793699 + 6016.4688082696*t)
	X0 += 0.00000001477*np.cos(4.14004787537 + 12779.4507954208*t)
	X0 += 0.00000001251*np.cos(1.50045769848 + 3894.1818295422*t)
	X0 += 0.00000001492*np.cos(6.22975090570 + 9411.4646150872*t)
	X0 += 0.00000001471*np.cos(5.75783391755 + 18635.9284545362*t)
	X0 += 0.00000001672*np.cos(5.43726223249 + 16200.7727245012*t)
	X0 += 0.00000001263*np.cos(0.91728971350 + 12573.2652469836*t)
	X0 += 0.00000001390*np.cos(6.12238564495 + 412.3710968744*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001366*np.cos(1.09160445123 + 2379.1644735716*t)
	X0 += 0.00000001272*np.cos(0.89738866811 + 6549.6828917132*t)
	X0 += 0.00000001156*np.cos(1.38847609016 + 11499.6562227928*t)
	X0 += 0.00000001543*np.cos(4.26237609038 + 18209.33026366019*t)
	X0 += 0.00000001483*np.cos(1.40459440941 + 210.8514148832*t)
	X0 += 0.00000001423*np.cos(5.98922157377 + 225.8292684102*t)
	X0 += 0.00000001472*np.cos(3.48774945967 + 215.7467759928*t)
	X0 += 0.00000001460*np.cos(4.97233669659 + 245.8316462294*t)
	X0 += 0.00000001090*np.cos(2.83082031323 + 422.6660376129*t)
	X0 += 0.00000001253*np.cos(1.41164782000 + 6993.0088985497*t)
	X0 += 0.00000001047*np.cos(0.50899510052 + 309.2783226558*t)
	X0 += 0.00000001228*np.cos(2.83750345253 + 24356.7807886416*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001022*np.cos(0.96352485877 + 145.6310438715*t)
	X0 += 0.00000001422*np.cos(2.40975714524 + 152.5321425512*t)
	X0 += 0.00000001028*np.cos(2.51030023881 + 6112.4029793722*t)
	X0 += 0.00000001034*np.cos(3.22353796512 + 1795.258443721*t)
	X0 += 0.00000001268*np.cos(4.67217109478 + 5429.8794682394*t)
	X0 += 0.00000001312*np.cos(1.10091569645 + 12491.3701014155*t)
	X0 += 0.00000000992*np.cos(4.13817717100 + 6453.7487206106*t)
	X0 += 0.00000000988*np.cos(0.98006619973 + 8273.8208670324*t)
	X0 += 0.00000001191*np.cos(3.43008039922 + 6290.1220866894*t)
	X0 += 0.00000001191*np.cos(3.21845317343 + 6276.02961329339*t)
	X0 += 0.00000000978*np.cos(4.73852763851 + 6247.04798331399*t)
	X0 += 0.00000000979*np.cos(2.33360006154 + 84.3428261229*t)
	X0 += 0.00000000971*np.cos(1.91000718426 + 6319.1037166688*t)
	X0 += 0.00000001192*np.cos(4.42856842639 + 2648.454825473*t)
	X0 += 0.00000000966*np.cos(6.19909761751 + 1272.6810256272*t)
	X0 += 0.00000000962*np.cos(2.63568544853 + 12565.1713789146*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000001025*np.cos(2.21768401152 + 12545.3763044904*t)
	X0 += 0.00000001075*np.cos(0.57961253778 + 212.3358875915*t)
	X0 += 0.00000001070*np.cos(4.31120526838 + 214.2623032845*t)
	X0 += 0.00000001244*np.cos(2.87441597074 + 184.7272873558*t)
	X0 += 0.00000000944*np.cos(0.78473810598 + 6306.9542877392*t)
	X0 += 0.00000000944*np.cos(5.86379546667 + 6259.1974122436*t)
	X0 += 0.00000001092*np.cos(3.92002105501 + 17796.9591667858*t)
	X0 += 0.00000000886*np.cos(5.23132430543 + 6172.869528772*t)
	X0 += 0.00000001098*np.cos(2.95983802473 + 137.0330241624*t)
	X0 += 0.00000000889*np.cos(3.98790631605 + 213.2509113282*t)
	X0 += 0.00000000889*np.cos(0.90251570889 + 213.3472795478*t)
	X0 += 0.00000001211*np.cos(4.04154480615 + 82576.98122099529*t)
	X0 += 0.00000001132*np.cos(0.96198039943 + 17782.7320727842*t)
	X0 += 0.00000000942*np.cos(1.42062620155 + 6267.82337880639*t)
	X0 += 0.00000000942*np.cos(5.22790737110 + 6298.3283211764*t)
	X0 += 0.00000001045*np.cos(0.46337213067 + 15508.6151232744*t)
	X0 += 0.00000000850*np.cos(1.45204280805 + 6393.2821712108*t)
	X0 += 0.00000000895*np.cos(2.40085098648 + 3903.9113764198*t)
	X0 += 0.00000000967*np.cos(4.53246389020 + 437.6438911399*t)
	X0 += 0.00000000819*np.cos(0.57163728715 + 529.6427809848*t)
	X0 += 0.00000000819*np.cos(3.76946397274 + 529.7391492044*t)
	X0 += 0.00000000811*np.cos(2.26915207928 + 288.0806940053*t)
	X0 += 0.00000001037*np.cos(4.27554240329 + 527.2432845398*t)
	X0 += 0.00000000917*np.cos(2.47015034331 + 149854.40013480789*t)
	X0 += 0.00000001031*np.cos(0.06363683037 + 532.1386456494*t)
	X0 += 0.00000000797*np.cos(4.06306935733 + 203.7378678824*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000001085*np.cos(1.32862144392 + 36949.2308084242*t)
	X0 += 0.00000001000*np.cos(0.24880432000 + 11403.676995575*t)
	X0 += 0.00000000962*np.cos(3.92658368218 + 12567.132021051*t)
	X0 += 0.00000000770*np.cos(6.20173754399 + 4804.209275927*t)
	X0 += 0.00000000734*np.cos(5.35841388096 + 112.9146342051*t)
	X0 += 0.00000000986*np.cos(4.62897469531 + 22805.7355659936*t)
	X0 += 0.00000000931*np.cos(2.22558469426 + 2787.0430238574*t)
	X0 += 0.00000000709*np.cos(1.92302056629 + 628.8515860501*t)
	X0 += 0.00000000743*np.cos(3.79903933428 + 7834.1210726394*t)
	X0 += 0.00000000905*np.cos(2.83314540925 + 6281.5913772831*t)
	X0 += 0.00000000905*np.cos(3.81538816339 + 6284.5603226997*t)
	X0 += 0.00000000715*np.cos(5.50312651042 + 17256.6315363414*t)
	X0 += 0.00000000798*np.cos(2.62501077543 + 12410.7313005486*t)
	X0 += 0.00000000828*np.cos(1.54060095214 + 10969.9652576982*t)
	X0 += 0.00000000926*np.cos(2.97025862788 + 160.6088973985*t)
	X0 += 0.00000000821*np.cos(0.52122150189 + 12416.5885028482*t)
	X0 += 0.00000000826*np.cos(3.32684274495 + 838.9692877504*t)
	X0 += 0.00000000640*np.cos(2.73696788768 + 2008.557539159*t)
	X0 += 0.00000000826*np.cos(4.78071938299 + 10984.1923516998*t)
	X0 += 0.00000000639*np.cos(3.07427988266 + 2111.6503133776*t)
	X0 += 0.00000000754*np.cos(3.82898538792 + 4061.2192153944*t)
	X0 += 0.00000000723*np.cos(3.06755247513 + 161000.6857376741*t)
	X0 += 0.00000000692*np.cos(2.83117936839 + 9.5612275556*t)
	X0 += 0.00000000624*np.cos(0.50120316917 + 430.5303441391*t)
	X0 += 0.00000000832*np.cos(2.20242516999 + 380.12776796*t)
	X0 += 0.00000000662*np.cos(4.47978464665 + 1063.3140834523*t)
	X0 += 0.00000000616*np.cos(5.14603483362 + 1368.660252845*t)
	X0 += 0.00000000782*np.cos(0.87676753080 + 4907.3020501456*t)
	X0 += 0.00000000707*np.cos(3.28533306159 + 5849.3641121146*t)
	X0 += 0.00000000623*np.cos(2.94730498294 + 5333.9002410216*t)
	X0 += 0.00000000696*np.cos(4.89623582044 + 11712.9553182308*t)
	X0 += 0.00000000616*np.cos(1.47727208161 + 5573.1428014331*t)
	X0 += 0.00000000595*np.cos(1.30546777768 + 12323.4230960088*t)
	X0 += 0.00000000611*np.cos(1.31321200457 + 11933.3679606696*t)
	X0 += 0.00000000570*np.cos(4.54665961586 + 12586.9270954752*t)
	X0 += 0.00000000778*np.cos(1.57590278073 + 8662.240323563*t)
	X0 += 0.00000000639*np.cos(3.15793381912 + 12.5301729722*t)
	X0 += 0.00000000599*np.cos(0.38463092695 + 423.4167971383*t)
	X0 += 0.00000000648*np.cos(3.43475812975 + 528.7277572481*t)
	X0 += 0.00000000646*np.cos(0.90574398043 + 530.6541729411*t)
	X0 += 0.00000000597*np.cos(4.69316038420 + 9779.1086761254*t)
	X0 += 0.00000000542*np.cos(3.49258842674 + 2221.856634597*t)
	X0 += 0.00000000536*np.cos(6.06660590951 + 18852.7506683232*t)
	X0 += 0.00000000532*np.cos(4.58762153412 + 18842.11400297339*t)
	X0 += 0.00000000599*np.cos(2.11793250999 + 6151.533888305*t)
	X0 += 0.00000000540*np.cos(3.40440707564 + 6279.7894925736*t)
	X0 += 0.00000000540*np.cos(3.24412649701 + 6286.3622074092*t)
	X0 += 0.00000000538*np.cos(6.04102038970 + 127.4717966068*t)
	X0 += 0.00000000542*np.cos(0.91953382373 + 1055.4497769261*t)
	X0 += 0.00000000513*np.cos(3.70291605445 + 12455.9453787634*t)
	X0 += 0.00000000623*np.cos(5.52546598759 + 5326.7866940208*t)
	X0 += 0.00000000649*np.cos(4.90568768794 + 11764.330768859*t)
	X0 += 0.00000000582*np.cos(4.53092407532 + 6414.6178116778*t)
	X0 += 0.00000000672*np.cos(3.08200615608 + 221.3758502853*t)
	X0 += 0.00000000610*np.cos(3.94320832220 + 10419.9862835076*t)
	X0 += 0.00000000679*np.cos(0.26045226696 + 6133.5126528568*t)
	X0 += 0.00000000531*np.cos(3.00684541494 + 3496.032826134*t)
	X0 += 0.00000000566*np.cos(2.70414246898 + 728.762966531*t)
	X0 += 0.00000000536*np.cos(3.70224967645 + 7232.2514589612*t)
	X0 += 0.00000000490*np.cos(2.97472409276 + 71.6002048296*t)
	X0 += 0.00000000510*np.cos(4.38198402315 + 11513.8833167944*t)
	X0 += 0.00000000643*np.cos(6.06382589060 + 26735.9452622132*t)
	X0 += 0.00000000649*np.cos(1.32346646305 + 22.0914005278*t)
	X0 += 0.00000000665*np.cos(2.75085842376 + 40879.4405046438*t)
	X0 += 0.00000000471*np.cos(4.83320292258 + 77.962992305*t)
	X0 += 0.00000000623*np.cos(2.85969660852 + 330.6189636582*t)
	X0 += 0.00000000549*np.cos(0.63911798007 + 22483.84857449259*t)
	X0 += 0.00000000479*np.cos(1.33580595339 + 5547.1993364596*t)
	X0 += 0.00000000652*np.cos(2.72637797985 + 388.4651552382*t)
	X0 += 0.00000000564*np.cos(3.92025647347 + 4171.4255366138*t)
	X0 += 0.00000000462*np.cos(1.96611775944 + 3104.9300594238*t)
	X0 += 0.00000000468*np.cos(0.69788003422 + 1073.6090241908*t)
	X0 += 0.00000000551*np.cos(4.03874430699 + 6503.4884924302*t)
	X0 += 0.00000000535*np.cos(6.12277226234 + 173566.83743765688*t)
	X0 += 0.00000000545*np.cos(2.61441075819 + 6062.6632075526*t)
	X0 += 0.00000000477*np.cos(3.50657951584 + 9388.0059094152*t)
	X0 += 0.00000000574*np.cos(5.66932742997 + 87.3117715395*t)
	X0 += 0.00000000448*np.cos(5.09815034585 + 4274.5183108324*t)
	X0 += 0.00000000605*np.cos(1.98317483331 + 984.6003316219*t)
	X0 += 0.00000000541*np.cos(3.08246188636 + 72.3339180125*t)
	X0 += 0.00000000532*np.cos(0.22623731981 + 283.8593188652*t)
	X0 += 0.00000000527*np.cos(6.24827316267 + 24602.61243487099*t)
	X0 += 0.00000000502*np.cos(0.97407194728 + 12489.8856287072*t)
	X0 += 0.00000000603*np.cos(0.85487083482 + 322711.30452390644*t)
	X0 += 0.00000000467*np.cos(5.34128135139 + 212.7778305762*t)
	X0 += 0.00000000466*np.cos(5.83324087524 + 213.8203602998*t)
	X0 += 0.00000000493*np.cos(6.11920290350 + 29296.6153895786*t)
	X0 += 0.00000000530*np.cos(0.43491203890 + 18845.7044316252*t)
	X0 += 0.00000000431*np.cos(5.31145947560 + 7018.9523635232*t)
	X0 += 0.00000000418*np.cos(2.75937640828 + 429.7795846137*t)
	X0 += 0.00000000584*np.cos(0.07135689258 + 72850.56171524568*t)
	X0 += 0.00000000462*np.cos(1.66174622090 + 860.3099287528*t)
	X0 += 0.00000000569*np.cos(2.95236791425 + 97238.62754448749*t)
	X0 += 0.00000000405*np.cos(5.39493918596 + 10873.9860304804*t)
	X0 += 0.00000000401*np.cos(4.50443000854 + 17267.26820169119*t)
	X0 += 0.00000000389*np.cos(3.21806007009 + 6321.2088856292*t)
	X0 += 0.00000000389*np.cos(3.43047350256 + 6244.9428143536*t)
	X0 += 0.00000000388*np.cos(1.13963224225 + 6297.302943993*t)
	X0 += 0.00000000388*np.cos(5.50890133040 + 6268.8487559898*t)
	X0 += 0.00000000515*np.cos(1.67075193318 + 12320.3200537534*t)
	X0 += 0.00000000393*np.cos(4.37184659923 + 14919.0178537546*t)
	X0 += 0.00000000394*np.cos(6.10411050787 + 4157.1984426122*t)
	X0 += 0.00000000505*np.cos(4.66096327599 + 17157.0618804718*t)
	X0 += 0.00000000528*np.cos(5.62841514056 + 135.0650800354*t)
	X0 += 0.00000000511*np.cos(4.91405448075 + 77.2292791221*t)
	X0 += 0.00000000439*np.cos(4.82558161657 + 233141.31440436149*t)
	X0 += 0.00000000417*np.cos(3.74443512826 + 13760.5987102074*t)
	X0 += 0.00000000419*np.cos(5.08318905121 + 15671.0817594066*t)
	X0 += 0.00000000393*np.cos(1.56711153414 + 7872.1487452752*t)
	X0 += 0.00000000384*np.cos(0.64251152112 + 340.7708920448*t)
	X0 += 0.00000000365*np.cos(2.11020607854 + 6922.9731363054*t)
	X0 += 0.00000000419*np.cos(0.62417554081 + 5642.1982426092*t)
	X0 += 0.00000000387*np.cos(0.68719040069 + 17253.04110768959*t)
	X0 += 0.00000000371*np.cos(5.76233828697 + 13625.533630172*t)
	X0 += 0.00000000379*np.cos(0.81831291068 + 3185.1920272656*t)
	X0 += 0.00000000499*np.cos(2.72563350590 + 161710.61878623239*t)
	X0 += 0.00000000414*np.cos(3.32204347851 + 22779.4372461938*t)
	X0 += 0.00000000485*np.cos(1.35444198321 + 12528.018664345*t)
	X0 += 0.00000000358*np.cos(3.15737999738 + 6271.3464971554*t)
	X0 += 0.00000000358*np.cos(3.49115357527 + 6294.8052028274*t)
	X0 += 0.00000000351*np.cos(2.21887707287 + 11616.976091013*t)
	X0 += 0.00000000354*np.cos(2.54868316520 + 62.2514255951*t)
	X0 += 0.00000000395*np.cos(3.93999186550 + 52.6901980395*t)
	X0 += 0.00000000451*np.cos(0.91836677580 + 29864.334027309*t)
	X0 += 0.00000000421*np.cos(4.82745120825 + 7445.5505543992*t)
	X0 += 0.00000000406*np.cos(2.27584736071 + 350.3321196004*t)
	X0 += 0.00000000396*np.cos(1.99989177453 + 145.1097790097*t)
	X0 += 0.00000000327*np.cos(3.95232223910 + 20995.3929664494*t)
	X0 += 0.00000000336*np.cos(1.41330667750 + 6279.1436967283*t)
	X0 += 0.00000000336*np.cos(5.23522689515 + 6287.0080032545*t)
	X0 += 0.00000000358*np.cos(0.81490874525 + 21393.5419698576*t)
	X0 += 0.00000000450*np.cos(0.23149923655 + 1385.5615749511*t)
	X0 += 0.00000000385*np.cos(6.13244198192 + 909.8187330546*t)
	X0 += 0.00000000320*np.cos(0.03172757569 + 16858.4825329332*t)
	X0 += 0.00000000363*np.cos(4.29069778349 + 7335.3442331798*t)
	X0 += 0.00000000330*np.cos(3.68113867113 + 38.0276726358*t)
	X0 += 0.00000000395*np.cos(5.39428043096 + 5905.7022420756*t)
	X0 += 0.00000000313*np.cos(3.62090724113 + 234.6397364404*t)
	X0 += 0.00000000414*np.cos(4.19402575890 + 44809.6502008634*t)
	X0 += 0.00000000382*np.cos(1.81523910449 + 186.2117600641*t)
	X0 += 0.00000000300*np.cos(3.87083875051 + 640.8776073822*t)
	X0 += 0.00000000304*np.cos(0.15986036979 + 5749.8617665478*t)
	X0 += 0.00000000351*np.cos(5.93395455459 + 12345.739057544*t)
	X0 += 0.00000000307*np.cos(5.30261033229 + 5120.6011455836*t)
	X0 += 0.00000000304*np.cos(4.93657040735 + 29826.3063546732*t)
	X0 += 0.00000000297*np.cos(6.01664889580 + 20597.2439630412*t)
	X0 += 0.00000000400*np.cos(1.38752434540 + 454.9093665273*t)
	X0 += 0.00000000372*np.cos(4.82853244691 + 3.1813937377*t)
	X0 += 0.00000000395*np.cos(0.07726910331 + 4176.041342449*t)
	X0 += 0.00000000288*np.cos(0.91857388482 + 1905.4647649404*t)
	X0 += 0.00000000320*np.cos(2.49799253183 + 10818.1352869158*t)
	X0 += 0.00000000365*np.cos(1.25425297875 + 6660.4494579072*t)
	X0 += 0.00000000339*np.cos(6.10828911901 + 6923.9534573736*t)
	X0 += 0.00000000274*np.cos(1.11162071728 + 26709.6469424134*t)
	X0 += 0.00000000386*np.cos(2.29044623019 + 2636.725472637*t)
	X0 += 0.00000000367*np.cos(1.18722914434 + 30666.1549584328*t)
	X0 += 0.00000000308*np.cos(2.68902321898 + 362.8622925726*t)
	X0 += 0.00000000268*np.cos(4.95835137530 + 10454.5013866052*t)
	X0 += 0.00000000335*np.cos(0.71030115582 + 200.7689224658*t)
	X0 += 0.00000000265*np.cos(5.11010291991 + 19378.9185150688*t)
	X0 += 0.00000000325*np.cos(2.49277998223 + 12359.9661515456*t)
	X0 += 0.00000000311*np.cos(4.44573637765 + 297.6419215609*t)
	X0 += 0.00000000264*np.cos(3.81456195150 + 1485.9801210652*t)
	X0 += 0.00000000326*np.cos(4.24702233173 + 16522.6597160022*t)
	X0 += 0.00000000289*np.cos(1.92464337356 + 529.1697002328*t)
	X0 += 0.00000000366*np.cos(2.92406939426 + 604.4725636619*t)
	X0 += 0.00000000288*np.cos(2.41719522186 + 530.2122299564*t)
	X0 += 0.00000000269*np.cos(0.20537129126 + 6816.289933435*t)
	X0 += 0.00000000314*np.cos(1.84357518690 + 108.4612160802*t)
	X0 += 0.00000000298*np.cos(5.15059518785 + 10344.2950653858*t)
	X0 += 0.00000000262*np.cos(4.15566435137 + 1258.4539316256*t)
	X0 += 0.00000000344*np.cos(3.51559745333 + 6147.4505249814*t)
	X0 += 0.00000000334*np.cos(3.13303102229 + 6418.7011750014*t)
	X0 += 0.00000000316*np.cos(5.54205366730 + 6055.5997172024*t)
	X0 += 0.00000000274*np.cos(1.54026728979 + 565.1156877467*t)
	X0 += 0.00000000268*np.cos(0.19545433539 + 140.001969579*t)
	X0 += 0.00000000316*np.cos(0.36194124996 + 21954.15760939799*t)
	X0 += 0.00000000243*np.cos(4.10172883526 + 6310.4774060882*t)
	X0 += 0.00000000243*np.cos(2.54680473739 + 6255.6742938946*t)
	X0 += 0.00000000314*np.cos(4.99359717889 + 17996.0311682222*t)
	X0 += 0.00000000320*np.cos(0.32229958420 + 703.6331846174*t)
	X0 += 0.00000000243*np.cos(0.44342371962 + 1062.5633239269*t)
	X0 += 0.00000000248*np.cos(0.09445957496 + 210.3783341312*t)
	X0 += 0.00000000248*np.cos(4.79327801971 + 216.2198567448*t)
	X0 += 0.00000000296*np.cos(0.07899534657 + 6129.2970395066*t)
	X0 += 0.00000000241*np.cos(3.24545153339 + 37.611770776*t)
	X0 += 0.00000000255*np.cos(4.90697050745 + 153.4953503977*t)
	X0 += 0.00000000237*np.cos(3.72326482255 + 212.5483359126*t)
	X0 += 0.00000000301*np.cos(1.10648000281 + 6510.5519827804*t)
	X0 += 0.00000000329*np.cos(1.15676558971 + 377.3736079158*t)
	X0 += 0.00000000236*np.cos(1.16575065097 + 214.0498549634*t)
	X0 += 0.00000000267*np.cos(3.42007125342 + 24705.70520908959*t)
	X0 += 0.00000000285*np.cos(2.50494681053 + 5469.5255660316*t)
	X0 += 0.00000000236*np.cos(4.23871934676 + 38.6543004996*t)
	X0 += 0.00000000311*np.cos(3.23911937497 + 11720.0688652316*t)
	X0 += 0.00000000252*np.cos(4.61065643475 + 209.106309744*t)
	X0 += 0.00000000286*np.cos(0.28647339668 + 6436.8546604762*t)
	X0 += 0.00000000247*np.cos(0.27272991614 + 217.491881132*t)
	X0 += 0.00000000273*np.cos(4.29648399498 + 28286.9904848612*t)
	X0 += 0.00000000319*np.cos(4.71062528834 + 169379.25621117488*t)
	X0 += 0.00000000225*np.cos(3.38119852586 + 223.5940361765*t)
	X0 += 0.00000000224*np.cos(5.51904045547 + 38.084851528*t)
	X0 += 0.00000000223*np.cos(1.96313876697 + 38.1812197476*t)
	X0 += 0.00000000234*np.cos(3.36893910039 + 4487.8174062704*t)
	X0 += 0.00000000252*np.cos(0.51301411030 + 4377.611085051*t)
	X0 += 0.00000000245*np.cos(4.21060733239 + 173.9422195228*t)
	X0 += 0.00000000217*np.cos(1.51605950497 + 2125.8774073792*t)
	X0 += 0.00000000213*np.cos(3.79431896643 + 30355.9973197678*t)
	X0 += 0.00000000234*np.cos(0.55106604784 + 74.2603337055*t)
	X0 += 0.00000000233*np.cos(0.98887023825 + 75.3028634291*t)
	X0 += 0.00000000263*np.cos(6.11317571912 + 9380.9596727172*t)
	X0 += 0.00000000239*np.cos(1.33165763648 + 10440.2742926036*t)
	X0 += 0.00000000289*np.cos(0.55454156939 + 6206.8097787158*t)
	X0 += 0.00000000247*np.cos(0.56642494969 + 252.6559713532*t)
	X0 += 0.00000000259*np.cos(3.43127382595 + 6282.83203250789*t)
	X0 += 0.00000000259*np.cos(3.21725974670 + 6283.3196674749*t)
	X0 += 0.00000000204*np.cos(0.84533704687 + 18.1592472647*t)
	X0 += 0.00000000282*np.cos(1.41766310537 + 563.6312150384*t)
	X0 += 0.00000000243*np.cos(4.14346390349 + 7096.6261339512*t)
	X0 += 0.00000000246*np.cos(5.83734028861 + 8671.9698704406*t)
	X0 += 0.00000000207*np.cos(5.75479453376 + 142.4496501338*t)
	X0 += 0.00000000199*np.cos(0.93488663037 + 11216.284290324*t)
	X0 += 0.00000000204*np.cos(0.27721513871 + 417.0369633204*t)
	X0 += 0.00000000195*np.cos(4.23402090499 + 66.70484372*t)
	X0 += 0.00000000211*np.cos(5.13588313603 + 37.1698277913*t)
	X0 += 0.00000000215*np.cos(0.35886038032 + 1699.2792165032*t)
	X0 += 0.00000000265*np.cos(5.61985831637 + 48739.859897083*t)
	X0 += 0.00000000207*np.cos(3.06628694399 + 12562.561271331*t)
	X0 += 0.00000000212*np.cos(1.75471606720 + 7129.1586847426*t)
	X0 += 0.00000000269*np.cos(1.52668826951 + 70755.06709173629*t)
	X0 += 0.00000000225*np.cos(4.01656879083 + 5636.0650166766*t)
	X0 += 0.00000000192*np.cos(2.04748658291 + 17271.8840075264*t)
	X0 += 0.00000000240*np.cos(5.09605084016 + 15906.7641266826*t)
	X0 += 0.00000000227*np.cos(5.15751336106 + 207.8824694666*t)
	X0 += 0.00000000203*np.cos(2.35104519506 + 39.0962434843*t)
	X0 += 0.00000000202*np.cos(4.05217682796 + 207.6700211455*t)
	X0 += 0.00000000187*np.cos(0.15192842664 + 11609.8625440122*t)
	X0 += 0.00000000182*np.cos(3.89203001563 + 1898.3512179396*t)
	X0 += 0.00000000219*np.cos(6.03807342488 + 218.7157214094*t)
	X0 += 0.00000000206*np.cos(5.35930784504 + 88.865680217*t)
	X0 += 0.00000000250*np.cos(4.24183292428 + 5934.1514295434*t)
	X0 += 0.00000000188*np.cos(2.43290559306 + 1471.7530270636*t)
	X0 += 0.00000000185*np.cos(4.15018423748 + 508.3503240922*t)
	X0 += 0.00000000195*np.cos(0.82662766477 + 218.9281697305*t)
	X0 += 0.00000000220*np.cos(0.73345029623 + 11087.2851259184*t)
	X0 += 0.00000000175*np.cos(5.41174539523 + 11614.4332937322*t)
	X0 += 0.00000000175*np.cos(4.58212579300 + 3744.8273457378*t)
	X0 += 0.00000000241*np.cos(0.28788321480 + 8390.1103575338*t)
	X0 += 0.00000000234*np.cos(2.61192358068 + 34596.3646546524*t)
	X0 += 0.00000000174*np.cos(2.85207900960 + 263.0839233728*t)
	X0 += 0.00000000224*np.cos(4.06529944699 + 1056.2005364515*t)
	X0 += 0.00000000190*np.cos(6.26917436708 + 394.6258850592*t)
	X0 += 0.00000000187*np.cos(5.58825382870 + 401.6721217572*t)
	X0 += 0.00000000178*np.cos(3.72578587318 + 12132.439962106*t)
	X0 += 0.00000000230*np.cos(2.40692341132 + 6632.0002704394*t)
	X0 += 0.00000000172*np.cos(2.96155542160 + 526.7702037878*t)
	X0 += 0.00000000186*np.cos(0.73069210814 + 554.0699874828*t)
	X0 += 0.00000000194*np.cos(2.50663265946 + 28.5718080822*t)
	X0 += 0.00000000169*np.cos(1.38093325803 + 532.6117264014*t)
	X0 += 0.00000000192*np.cos(3.08542976535 + 1574.8458012822*t)
	X0 += 0.00000000217*np.cos(3.59114151623 + 124.433415221*t)
	X0 += 0.00000000176*np.cos(1.20681960915 + 525.4981794006*t)
	X0 += 0.00000000172*np.cos(5.60194767636 + 211.8146227297*t)
	X0 += 0.00000000177*np.cos(4.73089168144 + 4797.0957289262*t)
	X0 += 0.00000000167*np.cos(3.97388034335 + 5714.253975964*t)
	X0 += 0.00000000214*np.cos(4.34116392416 + 24492.40611365159*t)
	X0 += 0.00000000217*np.cos(4.52620284574 + 3097.88382272579*t)
	X0 += 0.00000000172*np.cos(5.38973312367 + 6332.8328754632*t)
	X0 += 0.00000000172*np.cos(1.25880044898 + 6233.3188245196*t)
	X0 += 0.00000000221*np.cos(4.98998061605 + 266.6070417218*t)
	X0 += 0.00000000159*np.cos(3.90246086071 + 13198.935439296*t)
	X0 += 0.00000000188*np.cos(3.44598602635 + 569.0478410098*t)
	X0 += 0.00000000158*np.cos(0.33551046271 + 528.9402055692*t)
	X0 += 0.00000000157*np.cos(4.00545168863 + 530.44172462*t)
	X0 += 0.00000000207*np.cos(3.49598218672 + 12569.7421286346*t)
	X0 += 0.00000000176*np.cos(4.05199455874 + 12012.5822971404*t)
	X0 += 0.00000000177*np.cos(0.70756419313 + 32.1951448046*t)
	X0 += 0.00000000157*np.cos(5.43302098132 + 16840.67001081519*t)
	X0 += 0.00000000170*np.cos(0.63813817825 + 6272.0301497275*t)
	X0 += 0.00000000170*np.cos(6.01039539440 + 6294.1215502553*t)
	X0 += 0.00000000191*np.cos(4.12314886390 + 183.2428146475*t)
	X0 += 0.00000000179*np.cos(1.49110102879 + 5.9378908332*t)
	X0 += 0.00000000213*np.cos(4.21609963122 + 19804.8272915828*t)
	X0 += 0.00000000170*np.cos(5.83704197169 + 305.3461693927*t)
	X0 += 0.00000000167*np.cos(5.54070880349 + 17686.7528455664*t)
	X0 += 0.00000000207*np.cos(1.81656116060 + 73.8183907208*t)
	X0 += 0.00000000175*np.cos(1.28027815287 + 217.964961884*t)
	X0 += 0.00000000187*np.cos(5.70099962642 + 20452.8694122218*t)
	X0 += 0.00000000148*np.cos(4.39633643688 + 519.3960243561*t)
	X0 += 0.00000000147*np.cos(3.63497942528 + 82.8583534146*t)
	X0 += 0.00000000203*np.cos(2.54569209930 + 453.424893819*t)
	X0 += 0.00000000191*np.cos(5.96603240618 + 425.1137181677*t)
	X0 += 0.00000000148*np.cos(3.53096991388 + 414.0680179038*t)
	X0 += 0.00000000147*np.cos(4.99188388936 + 16737.5772365966*t)
	X0 += 0.00000000200*np.cos(0.25134097583 + 1439.5096981492*t)
	X0 += 0.00000000165*np.cos(5.22234420384 + 231.4583427027*t)
	X0 += 0.00000000148*np.cos(2.67465318849 + 6851.8977240188*t)
	X0 += 0.00000000146*np.cos(0.23801153618 + 17370.3609759098*t)
	X0 += 0.00000000143*np.cos(0.85202449839 + 5618.3198048614*t)
	X0 += 0.00000000141*np.cos(5.69421526925 + 408.4389436113*t)
	X0 += 0.00000000193*np.cos(3.57442994352 + 33326.5787331742*t)
	X0 += 0.00000000155*np.cos(0.27598891874 + 20199.094959633*t)
	X0 += 0.00000000191*np.cos(6.04625942487 + 75.7448064138*t)
	X0 += 0.00000000182*np.cos(5.69212378196 + 28766.924424484*t)
	X0 += 0.00000000184*np.cos(3.48483358167 + 5540.0857894588*t)
	X0 += 0.00000000162*np.cos(4.78754155685 + 12551.9246059812*t)
	X0 += 0.00000000143*np.cos(2.32151913243 + 5010.3948243642*t)
	X0 += 0.00000000178*np.cos(3.84899225076 + 1685.0521225016*t)
	X0 += 0.00000000190*np.cos(0.66924538276 + 23581.2581773176*t)
	X0 += 0.00000000149*np.cos(3.15621899577 + 533.8837507886*t)
	X0 += 0.00000000135*np.cos(0.07815962516 + 12431.0866199474*t)
	X0 += 0.00000000134*np.cos(3.03203004875 + 11925.2740926006*t)
	X0 += 0.00000000157*np.cos(3.61532012746 + 208.633228992*t)
	X0 += 0.00000000179*np.cos(1.07503153366 + 16460.33352952499*t)
	X0 += 0.00000000153*np.cos(4.99836680146 + 47.6942631934*t)
	X0 += 0.00000000184*np.cos(2.16301573772 + 1021.2488945514*t)
	X0 += 0.00000000139*np.cos(5.84452648935 + 373.9079928365*t)
	X0 += 0.00000000182*np.cos(3.66470209346 + 28.4491874678*t)
	X0 += 0.00000000138*np.cos(5.61172177506 + 214.7835681463*t)
	X0 += 0.00000000129*np.cos(1.54390762080 + 203.0041546995*t)
	X0 += 0.00000000128*np.cos(5.24161490581 + 479.2883889155*t)
	X0 += 0.00000000146*np.cos(1.55848605346 + 12701.2167800182*t)
	X0 += 0.00000000167*np.cos(1.26986508714 + 17473.4537501284*t)
	X0 += 0.00000000125*np.cos(5.28169583835 + 3.9321532631*t)
	X0 += 0.00000000170*np.cos(0.76594212114 + 52670.0695933026*t)
	X0 += 0.00000000124*np.cos(5.79650915048 + 6947.8318951214*t)
	X0 += 0.00000000135*np.cos(3.38698681678 + 3531.5282502998*t)
	X0 += 0.00000000172*np.cos(4.94248686856 + 167959.39011405829*t)
	X0 += 0.00000000130*np.cos(2.26702486739 + 654.1243803156*t)
	X0 += 0.00000000122*np.cos(5.69264255527 + 3583.3410306738*t)
	X0 += 0.00000000170*np.cos(1.45223415923 + 333857.59012677266*t)
	X0 += 0.00000000155*np.cos(4.05744056379 + 6058.7310542895*t)
	X0 += 0.00000000120*np.cos(1.19140907580 + 12808.8803039568*t)
	X0 += 0.00000000141*np.cos(5.52534979149 + 162420.55183479069*t)
	X0 += 0.00000000144*np.cos(1.54442458059 + 4.192785694*t)
	X0 += 0.00000000139*np.cos(1.22510407970 + 251.4321310758*t)
	X0 += 0.00000000160*np.cos(5.11540883899 + 265.9892934775*t)
	X0 += 0.00000000124*np.cos(1.37398060221 + 8982.810669309*t)
	X0 += 0.00000000120*np.cos(5.84076902832 + 12528.124027347*t)
	X0 += 0.00000000121*np.cos(5.05113331022 + 56.6223513026*t)
	X0 += 0.00000000119*np.cos(1.19695856457 + 19247.3765533824*t)
	X0 += 0.00000000117*np.cos(0.73795877914 + 11610.5519583742*t)
	X0 += 0.00000000154*np.cos(4.06475922223 + 38526.574350872*t)
	X0 += 0.00000000163*np.cos(3.11560982847 + 661.232926781*t)
	X0 += 0.00000000163*np.cos(4.35848910377 + 9929.4262273458*t)
	X0 += 0.00000000115*np.cos(2.14676232906 + 19402.7969528166*t)
	X0 += 0.00000000119*np.cos(4.28708216617 + 12249.7598303262*t)
	X0 += 0.00000000145*np.cos(2.74250030398 + 6360.7496204194*t)
	X0 += 0.00000000145*np.cos(3.90603326867 + 6205.4020795634*t)
	X0 += 0.00000000115*np.cos(6.22459411775 + 539.9859058331*t)
	X0 += 0.00000000159*np.cos(4.18513291774 + 228278.10465148659*t)
	X0 += 0.00000000156*np.cos(2.57788957454 + 4307.5833041354*t)
	X0 += 0.00000000116*np.cos(0.60146141700 + 24065.80792277559*t)
	X0 += 0.00000000118*np.cos(1.23925579836 + 6302.74561089119*t)
	X0 += 0.00000000118*np.cos(5.40927777429 + 6263.4060890916*t)
	X0 += 0.00000000114*np.cos(0.09813992796 + 213.1872208534*t)
	X0 += 0.00000000114*np.cos(4.79116773360 + 213.4109700226*t)
	X0 += 0.00000000110*np.cos(2.33480621176 + 16062.1845261168*t)
	X0 += 0.00000000137*np.cos(4.10438279102 + 6250.54329920*t)
	X0 += 0.00000000137*np.cos(2.54415078163 + 6315.6084007828*t)
	X0 += 0.00000000111*np.cos(2.27442358208 + 6339.974224927*t)
	X0 += 0.00000000111*np.cos(4.37410999057 + 6226.1774750558*t)
	X0 += 0.00000000150*np.cos(0.96205875343 + 19800.9459562248*t)
	X0 += 0.00000000123*np.cos(2.37616666242 + 24734.1543965574*t)
	X0 += 0.00000000123*np.cos(5.10501021239 + 98.8999885246*t)
	X0 += 0.00000000116*np.cos(0.64506154486 + 524.0618908021*t)
	X0 += 0.00000000107*np.cos(2.16622176546 + 12463.0589257642*t)
	X0 += 0.00000000123*np.cos(1.00594418221 + 6305.8510514422*t)
	X0 += 0.00000000123*np.cos(5.64258939044 + 6260.3006485406*t)
	X0 += 0.00000000106*np.cos(1.67655703852 + 11190.377900137*t)
	X0 += 0.00000000115*np.cos(3.69498632982 + 535.3200393871*t)
	X0 += 0.00000000131*np.cos(3.61185299316 + 18415.51581209739*t)
	X0 += 0.00000000127*np.cos(0.63003020942 + 540.7366653585*t)
	X0 += 0.00000000110*np.cos(4.88667127380 + 6276.44729109139*t)
	X0 += 0.00000000110*np.cos(1.76186229885 + 6289.70440889141*t)
	X0 += 0.00000000103*np.cos(2.75809551865 + 6324.6266409762*t)
	X0 += 0.00000000103*np.cos(3.89043805400 + 6241.5250590066*t)
	X0 += 0.00000000103*np.cos(5.76083420502 + 23937.856389741*t)
	X0 += 0.00000000107*np.cos(1.72027333824 + 83973.83535572988*t)
	X0 += 0.00000000107*np.cos(2.75882604296 + 84019.8592804939*t)
	X0 += 0.00000000118*np.cos(0.24752969879 + 983.1158589136*t)
	X0 += 0.00000000113*np.cos(2.65508166498 + 24336.0053931492*t)
	X0 += 0.00000000106*np.cos(3.27680652019 + 12772.33724842*t)
	X0 += 0.00000000143*np.cos(1.51199781479 + 2069.0068349066*t)
	X0 += 0.00000000143*np.cos(0.91985752497 + 18772.9614786986*t)
	X0 += 0.00000000115*np.cos(3.78220330855 + 3641.7345715192*t)
	X0 += 0.00000000118*np.cos(0.19804778544 + 525.0250986486*t)
	X0 += 0.00000000100*np.cos(3.71645704441 + 529.851023789*t)
	X0 += 0.00000000100*np.cos(0.62422783083 + 529.5309064002*t)
	X0 += 0.00000000126*np.cos(1.19294266238 + 18822.9292301744*t)
	X0 += 0.00000000102*np.cos(1.31527898088 + 963.4027029714*t)
	X0 += 0.00000000099*np.cos(1.87542989608 + 198.321241911*t)
	X0 += 0.00000000115*np.cos(4.66544469064 + 12570.0838532459*t)
	X0 += 0.00000000098*np.cos(5.07674655291 + 16310.9790457206*t)
	X0 += 0.00000000138*np.cos(2.08935051421 + 6356.3729758504*t)
	X0 += 0.00000000138*np.cos(4.55918305844 + 6209.7787241324*t)
	X0 += 0.00000000120*np.cos(4.95740945799 + 9814.6041002912*t)
	X0 += 0.00000000135*np.cos(0.57059381593 + 18699.6643528396*t)
	X0 += 0.00000000104*np.cos(2.15061044327 + 12560.6287756754*t)
	X0 += 0.00000000111*np.cos(1.30109743855 + 80.1982245387*t)
	X0 += 0.00000000098*np.cos(5.57514710248 + 5815.11085963699*t)
	X0 += 0.00000000096*np.cos(4.17152569130 + 213.5115437591*t)
	X0 += 0.00000000096*np.cos(0.71778197027 + 213.0866471169*t)
	X0 += 0.00000000106*np.cos(1.77919890262 + 23539.7073863328*t)
	X0 += 0.00000000099*np.cos(0.19873228449 + 551.031606097*t)
	X0 += 0.00000000112*np.cos(3.45345978303 + 2324.9494088156*t)
	X0 += 0.00000000111*np.cos(4.13924061941 + 534.3568315406*t)
	X0 += 0.00000000117*np.cos(1.76475239313 + 524.2743391232*t)
	X0 += 0.00000000114*np.cos(3.75372093481 + 6155.057006654*t)
	X0 += 0.00000000114*np.cos(2.89481263784 + 6411.0946933288*t)
	X0 += 0.00000000125*np.cos(4.85236761160 + 21.3406410024*t)
	X0 += 0.00000000095*np.cos(5.28465176922 + 327.4375699205*t)
	X0 += 0.00000000115*np.cos(2.57406093768 + 535.107591066*t)
	X0 += 0.00000000097*np.cos(6.03825791149 + 27043.5028831828*t)
	X0 += 0.00000000100*np.cos(2.94090698274 + 195.1398481733*t)
	X0 += 0.00000000095*np.cos(5.63307798614 + 11300.5842213564*t)
	X0 += 0.00000000110*np.cos(3.85733099272 + 6253.6463414554*t)
	X0 += 0.00000000110*np.cos(2.79120257993 + 6312.5053585274*t)
	X0 += 0.00000000091*np.cos(2.99457476326 + 12829.2356233556*t)
	X0 += 0.00000000128*np.cos(5.41337210078 + 1293.4842235826*t)
	X0 += 0.00000000096*np.cos(0.06385619665 + 35.685355083*t)
	X0 += 0.00000000113*np.cos(1.72263005108 + 114.1384744825*t)
	X0 += 0.00000000096*np.cos(5.97584747761 + 2699.7348193176*t)
	X0 += 0.00000000119*np.cos(5.98882616741 + 17892.93839400359*t)
	X0 += 0.00000000126*np.cos(0.25750574604 + 311565.01892104017*t)
	X0 += 0.00000000091*np.cos(0.08598161680 + 1802.3719907218*t)
	X0 += 0.00000000120*np.cos(2.08798412726 + 14158.7477136156*t)
	X0 += 0.00000000089*np.cos(3.16908258340 + 1382.8873468466*t)
	X0 += 0.00000000100*np.cos(4.30344030661 + 16627.3709153772*t)
	X0 += 0.00000000099*np.cos(3.61958161583 + 6432.639047126*t)
	X0 += 0.00000000102*np.cos(4.42228976166 + 219.891377577*t)
	X0 += 0.00000000124*np.cos(0.48010020247 + 178430.0471905317*t)
	X0 += 0.00000000089*np.cos(1.07338604948 + 6751.0408403458*t)
	X0 += 0.00000000096*np.cos(2.64494034094 + 7349.5713271814*t)
	X0 += 0.00000000086*np.cos(2.85915032438 + 228.276948965*t)
	X0 += 0.00000000117*np.cos(5.44811650549 + 42456.7840470916*t)
	X0 += 0.00000000100*np.cos(3.39323367399 + 96.8729990951*t)
	X0 += 0.00000000103*np.cos(4.37748903957 + 18202.21671665939*t)
	X0 += 0.00000000099*np.cos(0.58169736416 + 6313.9899756264*t)
	X0 += 0.00000000099*np.cos(6.06683620849 + 6252.1617243564*t)
	X0 += 0.00000000090*np.cos(0.38965081024 + 58864.5439181463*t)
	X0 += 0.00000000097*np.cos(0.27231106216 + 10557.5941608238*t)
	X0 += 0.00000000101*np.cos(3.42372783781 + 19004.6479494084*t)
	X0 += 0.00000000098*np.cos(3.23381285207 + 6126.675129489*t)
	X0 += 0.00000000098*np.cos(3.41472072058 + 6439.4765704938*t)
	X0 += 0.00000000084*np.cos(2.61330768505 + 74.7334144575*t)
	X0 += 0.00000000084*np.cos(5.20716850754 + 74.8297826771*t)
	X0 += 0.00000000086*np.cos(1.34149823513 + 23123.74586080659*t)
	X0 += 0.00000000114*np.cos(1.15232105885 + 177.8743727859*t)
	X0 += 0.00000000118*np.cos(3.73846259947 + 13951.7132749339*t)
	X0 += 0.00000000084*np.cos(3.13824782000 + 8858.3149443206*t)
	X0 += 0.00000000117*np.cos(4.10879972365 + 89569.99011954499*t)
	X0 += 0.00000000101*np.cos(0.23009068890 + 18429.742906099*t)
	X0 += 0.00000000088*np.cos(3.76745959676 + 17053.96910625319*t)
	X0 += 0.00000000113*np.cos(2.05049922518 + 12985.636343858*t)
	X0 += 0.00000000082*np.cos(0.19375634761 + 5483.254724826*t)
	X0 += 0.00000000087*np.cos(1.13401038923 + 40.5807161926*t)
	X0 += 0.00000000084*np.cos(4.23745405632 + 6379.0550772092*t)
	X0 += 0.00000000084*np.cos(2.41107951633 + 6187.0966227736*t)
	X0 += 0.00000000097*np.cos(4.02159784443 + 10239.5838660108*t)
	X0 += 0.00000000105*np.cos(3.87374571694 + 6131.1785689062*t)
	X0 += 0.00000000105*np.cos(2.77478785571 + 6434.9731310766*t)
	X0 += 0.00000000114*np.cos(4.07080498725 + 8258.5683958474*t)
	X0 += 0.00000000082*np.cos(3.82704107824 + 3958.1264411758*t)
	X0 += 0.00000000081*np.cos(3.33902328234 + 191.2076949102*t)
	X0 += 0.00000000093*np.cos(1.35189028328 + 18216.443810661*t)
	X0 += 0.00000000102*np.cos(2.89783593458 + 5767.6119788984*t)
	X0 += 0.00000000102*np.cos(3.75069763806 + 6798.5397210844*t)
	X0 += 0.00000000093*np.cos(1.06738164563 + 74.5209661364*t)
	X0 += 0.00000000110*np.cos(2.19234510205 + 56600.2792895222*t)
	X0 += 0.00000000112*np.cos(5.48905138227 + 12188.778092067*t)
	X0 += 0.00000000093*np.cos(0.46802035326 + 75.0422309982*t)
	X0 += 0.00000000080*np.cos(3.59070813227 + 24080.03501677719*t)
	X0 += 0.00000000079*np.cos(4.31891477024 + 38.0211610532*t)
	X0 += 0.00000000079*np.cos(3.16332905605 + 38.2449102224*t)
	X0 += 0.00000000080*np.cos(1.40233563562 + 191.9584544356*t)
	X0 += 0.00000000088*np.cos(3.00398297222 + 1573.8204240988*t)
	X0 += 0.00000000092*np.cos(4.36461689094 + 101426.20877096949*t)
	X0 += 0.00000000079*np.cos(4.46070108071 + 278.5194664497*t)
	X0 += 0.00000000080*np.cos(3.95392779576 + 175.1660598002*t)
	X0 += 0.00000000087*np.cos(2.32187773582 + 1580.8666607968*t)
	X0 += 0.00000000110*np.cos(0.37009059115 + 78423.70451667879*t)
	X0 += 0.00000000083*np.cos(2.35608099285 + 300.6108669775*t)
	X0 += 0.00000000099*np.cos(2.40898854628 + 33794.5437235286*t)
	X0 += 0.00000000078*np.cos(0.92843223712 + 30.0562807905*t)
	X0 += 0.00000000097*np.cos(5.32653372215 + 259.5088859231*t)
	X0 += 0.00000000080*np.cos(3.27906531246 + 6485.3292451655*t)
	X0 += 0.00000000080*np.cos(3.36946826019 + 6080.8224548173*t)
	X0 += 0.00000000089*np.cos(5.20240793768 + 17363.24742890899*t)
	X0 += 0.00000000077*np.cos(2.50991636518 + 205.2223405907*t)
	X0 += 0.00000000079*np.cos(4.53817935583 + 36109.38220466459*t)
	X0 += 0.00000000088*np.cos(0.87070535180 + 16943.7627850338*t)
	X0 += 0.00000000088*np.cos(3.24901264480 + 12537.702512515*t)
	X0 += 0.00000000087*np.cos(1.75120977431 + 28237.2334593894*t)
	X0 += 0.00000000085*np.cos(0.43515691954 + 44.070926471*t)
	X0 += 0.00000000096*np.cos(6.24127646307 + 131.4039498699*t)
	X0 += 0.00000000080*np.cos(3.62211320521 + 3956.5080160194*t)
	X0 += 0.00000000091*np.cos(3.88112259566 + 80.7194894005*t)
	X0 += 0.00000000083*np.cos(0.01677699839 + 21424.4666443034*t)
	X0 += 0.00000000099*np.cos(4.35778148149 + 5017.508371365*t)
	X0 += 0.00000000078*np.cos(2.59112277976 + 74.6215398729*t)
	X0 += 0.00000000078*np.cos(5.22948432343 + 74.9416572617*t)
	X0 += 0.00000000079*np.cos(4.50777133706 + 5621.8429232104*t)
	X0 += 0.00000000096*np.cos(1.98497858569 + 5888.4499649322*t)
	X0 += 0.00000000096*np.cos(4.66355498696 + 6677.7017350506*t)
	X0 += 0.00000000075*np.cos(2.21732650708 + 302.164775655*t)
	X0 += 0.00000000074*np.cos(5.98124271909 + 6304.4114904584*t)
	X0 += 0.00000000074*np.cos(0.66729085356 + 6261.7402095244*t)
	X0 += 0.00000000073*np.cos(2.62129339640 + 6695.4469468658*t)
	X0 += 0.00000000073*np.cos(4.02724017625 + 5870.704753117*t)
	X0 += 0.00000000085*np.cos(3.65241534932 + 12850.011018848*t)
	X0 += 0.00000000076*np.cos(1.33659857866 + 40796.33892267419*t)
	X0 += 0.00000000075*np.cos(4.65930914063 + 3178.1457905676*t)
	X0 += 0.00000000072*np.cos(4.81698863150 + 213.5597278689*t)
	X0 += 0.00000000072*np.cos(0.07231943414 + 213.0384630071*t)
	X0 += 0.00000000097*np.cos(0.92251430623 + 24383.0791084414*t)
	X0 += 0.00000000072*np.cos(0.32356695638 + 6312.8972881402*t)
	X0 += 0.00000000072*np.cos(0.04178130909 + 6253.25441184259*t)
	X0 += 0.00000000095*np.cos(0.62289841825 + 11080.1715789176*t)
	X0 += 0.00000000100*np.cos(5.37794668456 + 5316.1049725558*t)
	X0 += 0.00000000096*np.cos(4.24511131293 + 483.2205421786*t)
	X0 += 0.00000000085*np.cos(2.90983978106 + 12282.2923811176*t)
	X0 += 0.00000000071*np.cos(6.13573135109 + 41194.4879260824*t)
	X0 += 0.00000000072*np.cos(4.76869158882 + 15141.390794312*t)
	X0 += 0.00000000075*np.cos(1.96590126974 + 24422.3703514073*t)
	X0 += 0.00000000073*np.cos(1.29002951973 + 45892.73043315699*t)
	X0 += 0.00000000076*np.cos(1.98229485596 + 63658.8777508376*t)
	X0 += 0.00000000087*np.cos(3.63418769958 + 18106.2374894416*t)
	X0 += 0.00000000070*np.cos(2.01720588184 + 6442.0193677746*t)
	X0 += 0.00000000070*np.cos(4.63132769081 + 6124.1323322082*t)
	X0 += 0.00000000097*np.cos(4.76857001908 + 92747.68916682259*t)
	X0 += 0.00000000078*np.cos(4.94336223185 + 23550.34405168259*t)
	X0 += 0.00000000076*np.cos(3.43423122344 + 5237.9210138038*t)
	X0 += 0.00000000069*np.cos(3.45966511571 + 529.4785167735*t)
	X0 += 0.00000000069*np.cos(0.88102053266 + 529.9034134157*t)
	X0 += 0.00000000094*np.cos(3.68180477512 + 248.7238180901*t)
	X0 += 0.00000000077*np.cos(3.59376629306 + 518.6452648307*t)
	X0 += 0.00000000078*np.cos(4.98905027033 + 9924.8104215106*t)
	X0 += 0.00000000082*np.cos(5.48703292615 + 6774.7391424502*t)
	X0 += 0.00000000067*np.cos(0.17045052997 + 7082.8969751568*t)
	X0 += 0.00000000067*np.cos(4.81312573338 + 6171.8892077038*t)
	X0 += 0.00000000067*np.cos(1.83540783927 + 6394.262492279*t)
	X0 += 0.00000000080*np.cos(5.36760004078 + 22380.755800274*t)
	X0 += 0.00000000070*np.cos(2.04678665255 + 6175.4123260528*t)
	X0 += 0.00000000070*np.cos(4.60174692010 + 6390.73937393*t)
	X0 += 0.00000000066*np.cos(2.02327672376 + 635.9651330509*t)
	X0 += 0.00000000091*np.cos(2.47526506655 + 6652.7756659318*t)
	X0 += 0.00000000091*np.cos(4.17326850610 + 5913.376034051*t)
	X0 += 0.00000000067*np.cos(0.13241010748 + 6300.8883721094*t)
	X0 += 0.00000000067*np.cos(0.23293815799 + 6265.2633278734*t)
	X0 += 0.00000000067*np.cos(1.43864813435 + 5959.570433334*t)
	X0 += 0.00000000080*np.cos(0.77942675353 + 23646.32327890039*t)
	X0 += 0.00000000068*np.cos(3.64312434743 + 4897.1805736552*t)
	X0 += 0.00000000069*np.cos(2.14076204045 + 6944.3087767724*t)
	X0 += 0.00000000064*np.cos(3.46792160676 + 2214.7430875962*t)
	X0 += 0.00000000089*np.cos(1.97945887866 + 10660.6869350424*t)
	X0 += 0.00000000063*np.cos(3.22324471895 + 20.6069278195*t)
	X0 += 0.00000000084*np.cos(0.70408445885 + 424.1505103212*t)
	X0 += 0.00000000073*np.cos(4.53414425046 + 6195.76764545159*t)
	X0 += 0.00000000073*np.cos(2.11438932219 + 6370.3840545312*t)
	X0 += 0.00000000066*np.cos(3.95274142218 + 6251.1035441746*t)
	X0 += 0.00000000066*np.cos(2.69579215047 + 6315.0481558082*t)
	X0 += 0.00000000082*np.cos(1.17323562782 + 154.0166152595*t)
	X0 += 0.00000000065*np.cos(5.99619164093 + 284.1485407422*t)
	X0 += 0.00000000076*np.cos(3.59374291647 + 831.8557407496*t)
	X0 += 0.00000000063*np.cos(4.27995423229 + 11823.1616394502*t)
	X0 += 0.00000000081*np.cos(3.70025004502 + 37.8724032069*t)
	X0 += 0.00000000064*np.cos(0.09094709813 + 28774.0379714848*t)
	X0 += 0.00000000086*np.cos(4.32355291567 + 12341.8069042809*t)
	X0 += 0.00000000069*np.cos(2.58402361347 + 275.5505210331*t)
	X0 += 0.00000000081*np.cos(0.47769423835 + 31441.6775697568*t)
	X0 += 0.00000000071*np.cos(3.88813675038 + 835.0371344873*t)
	X0 += 0.00000000071*np.cos(5.70281660725 + 16207.886271502*t)
	X0 += 0.00000000080*np.cos(3.78188046031 + 38.3936680687*t)
	X0 += 0.00000000073*np.cos(0.88865626886 + 115.8835796217*t)
	X0 += 0.00000000061*np.cos(0.43078256287 + 35050.00027447539*t)
	X0 += 0.00000000066*np.cos(2.78136130877 + 17576.546524347*t)
	X0 += 0.00000000072*np.cos(0.54355547965 + 18100.00325845*t)
	X0 += 0.00000000072*np.cos(1.59783293112 + 245707.46610434429*t)
	X0 += 0.00000000064*np.cos(1.93356156446 + 23006.42599258639*t)
	X0 += 0.00000000068*np.cos(2.90815872826 + 28759.81087748319*t)
	X0 += 0.00000000062*np.cos(0.67966053291 + 3855.0336669572*t)
	X0 += 0.00000000073*np.cos(6.18334008725 + 23440.1377304632*t)
	X0 += 0.00000000060*np.cos(3.22950754418 + 13088.7291180766*t)
	X0 += 0.00000000078*np.cos(4.56094059497 + 12564.6672272745*t)
	X0 += 0.00000000060*np.cos(4.47214922427 + 7548.6433286178*t)
	X0 += 0.00000000075*np.cos(4.42126467141 + 18624.8827542723*t)
	X0 += 0.00000000069*np.cos(2.49762583501 + 511.5317178299*t)
	X0 += 0.00000000069*np.cos(5.82409328726 + 167993.69463622378*t)
	X0 += 0.00000000059*np.cos(0.42392189557 + 41990.7859328988*t)
	X0 += 0.00000000081*np.cos(1.27058672695 + 7250.046727427*t)
	X0 += 0.00000000059*np.cos(3.96273011871 + 6289.1417656212*t)
	X0 += 0.00000000059*np.cos(2.68580345394 + 6277.0099343616*t)
	X0 += 0.00000000063*np.cos(4.91003104939 + 5436.9930152402*t)
	X0 += 0.00000000059*np.cos(2.73782977803 + 8584.6616659008*t)
	X0 += 0.00000000058*np.cos(0.25471831888 + 46.2097904851*t)
	X0 += 0.00000000068*np.cos(1.09479629612 + 643.8294395771*t)
	X0 += 0.00000000074*np.cos(2.29556008890 + 28313.288804661*t)
	X0 += 0.00000000057*np.cos(0.01221429824 + 10027.9031957292*t)
	X0 += 0.00000000057*np.cos(4.87299369650 + 792.7748884674*t)
	X0 += 0.00000000079*np.cos(5.72688311333 + 531.1754378029*t)
	X0 += 0.00000000056*np.cos(4.47895058873 + 15265.8865193004*t)
	X0 += 0.00000000072*np.cos(4.16398251563 + 4598.0237274898*t)
	X0 += 0.00000000079*np.cos(0.46444983025 + 404.5067903482*t)
	X0 += 0.00000000077*np.cos(4.08353330283 + 618.5566453116*t)
	X0 += 0.00000000056*np.cos(1.44522132533 + 842.1506814881*t)
	X0 += 0.00000000063*np.cos(1.27506758028 + 5.5229243074*t)
	X0 += 0.00000000068*np.cos(2.71579728238 + 3166.4164377316*t)
	X0 += 0.00000000074*np.cos(3.23404191447 + 82534.40362061159*t)
	X0 += 0.00000000056*np.cos(1.96997381249 + 6339.8791121612*t)
	X0 += 0.00000000056*np.cos(4.67855976016 + 6226.2725878216*t)
	X0 += 0.00000000069*np.cos(1.89738325082 + 23536.11695768099*t)
	X0 += 0.00000000056*np.cos(2.52728721608 + 12303.06777661*t)
	X0 += 0.00000000055*np.cos(3.89144240866 + 22345.2603761082*t)
	X0 += 0.00000000062*np.cos(0.88771657360 + 99.1606209555*t)
	X0 += 0.00000000065*np.cos(1.84460485390 + 547.8502123593*t)
	X0 += 0.00000000057*np.cos(3.55801157684 + 6702.000248892*t)
	X0 += 0.00000000057*np.cos(3.09052199581 + 5864.1514510908*t)
	X0 += 0.00000000062*np.cos(4.06674027154 + 68.8437077341*t)
	X0 += 0.00000000064*np.cos(5.42433316705 + 14169.7935622304*t)
	X0 += 0.00000000075*np.cos(5.93374782872 + 32217.2001810808*t)
	X0 += 0.00000000061*np.cos(0.01100073598 + 121.2520214833*t)
	X0 += 0.00000000059*np.cos(2.17826568386 + 18003.144715223*t)
	X0 += 0.00000000059*np.cos(3.38504946794 + 67589.08744705719*t)
	X0 += 0.00000000076*np.cos(4.86986651697 + 528.2064923863*t)
	X0 += 0.00000000075*np.cos(4.71498755910 + 227.3137411185*t)
	X0 += 0.00000000076*np.cos(2.34884503279 + 23226.8386350252*t)
	X0 += 0.00000000073*np.cos(6.00950734574 + 30348.883772767*t)
	X0 += 0.00000000070*np.cos(1.56579326622 + 12299.544658261*t)
	X0 += 0.00000000060*np.cos(0.37221954582 + 12171.5258149236*t)
	X0 += 0.00000000058*np.cos(3.15618940951 + 6716.7875878682*t)
	X0 += 0.00000000074*np.cos(5.91246929008 + 3684.3780499902*t)
	X0 += 0.00000000067*np.cos(2.65177830926 + 22743.4093795164*t)
	X0 += 0.00000000062*np.cos(2.47017142882 + 16193.65917750039*t)
	X0 += 0.00000000059*np.cos(2.60023110979 + 15.252471185*t)
	X0 += 0.00000000059*np.cos(1.05069387628 + 12164.4795782256*t)
	X0 += 0.00000000061*np.cos(3.81064825215 + 650.9429865779*t)
	X0 += 0.00000000064*np.cos(4.29409388919 + 159.1244246902*t)
	X0 += 0.00000000063*np.cos(3.66056370325 + 5219.7617665391*t)
	X0 += 0.00000000061*np.cos(2.96999279527 + 429.0458714308*t)
	X0 += 0.00000000063*np.cos(0.58993036842 + 5227.6260730653*t)
	X0 += 0.00000000071*np.cos(3.61897462493 + 60530.4889857418*t)
	X0 += 0.00000000072*np.cos(1.05408545034 + 4583.7966334882*t)
	X0 += 0.00000000052*np.cos(5.67741459488 + 3627.5074775176*t)
	X0 += 0.00000000052*np.cos(1.77495138030 + 6155.1243169568*t)
	X0 += 0.00000000052*np.cos(4.87358219235 + 6411.027383026*t)
	X0 += 0.00000000073*np.cos(4.40543588100 + 80181.53746683979*t)
	X0 += 0.00000000057*np.cos(3.46227126270 + 92.940845832*t)
	X0 += 0.00000000068*np.cos(0.43233787470 + 219.4494345923*t)
	X0 += 0.00000000059*np.cos(5.80351575464 + 33.9402499438*t)
	X0 += 0.00000000058*np.cos(4.29308512080 + 30775.481963643*t)
	X0 += 0.00000000062*np.cos(5.86330508473 + 2.4476805548*t)
	X0 += 0.00000000062*np.cos(6.09623774456 + 425.6349830295*t)
	X0 += 0.00000000068*np.cos(1.86654756299 + 35371.8872659764*t)
	X0 += 0.00000000051*np.cos(5.10012533555 + 1048.3362299253*t)
	X0 += 0.00000000062*np.cos(4.46845874247 + 6908.7460423038*t)
	X0 += 0.00000000062*np.cos(2.18007483018 + 5657.405657679*t)
	X0 += 0.00000000054*np.cos(3.07019079387 + 59.8037450403*t)
	X0 += 0.00000000050*np.cos(1.48104982763 + 960.2213092337*t)
	X0 += 0.00000000059*np.cos(5.90527689512 + 72.0732855816*t)
	X0 += 0.00000000050*np.cos(1.53898120800 + 2575.2390943292*t)
	X0 += 0.00000000050*np.cos(0.12167728428 + 426.6463749858*t)
	X0 += 0.00000000064*np.cos(4.78297114148 + 269.9214467406*t)
	X0 += 0.00000000050*np.cos(4.78368432558 + 514.7131115676*t)
	X0 += 0.00000000051*np.cos(5.96112457648 + 387.2413149608*t)
	X0 += 0.00000000055*np.cos(1.61378048542 + 42.3258213318*t)
	X0 += 0.00000000052*np.cos(1.82842431930 + 5244.049239201*t)
	X0 += 0.00000000050*np.cos(4.69455799921 + 5881.4037282342*t)
	X0 += 0.00000000050*np.cos(1.95397557344 + 6684.7479717486*t)
	X0 += 0.00000000053*np.cos(5.33677558065 + 12146.6670561076*t)
	X0 += 0.00000000068*np.cos(6.19033473088 + 96677.8988630422*t)
	X0 += 0.00000000051*np.cos(3.43355246408 + 2641.3412784722*t)
	X0 += 0.00000000063*np.cos(1.40789341724 + 750.1036075334*t)
	X0 += 0.00000000064*np.cos(5.16841754323 + 24279.10701821359*t)
	X0 += 0.00000000050*np.cos(3.20702872042 + 426.5500067662*t)
	X0 += 0.00000000063*np.cos(3.98505374586 + 494.2662424425*t)
	X0 += 0.00000000050*np.cos(3.21675900656 + 43738.8023459658*t)
	X0 += 0.00000000050*np.cos(1.95435790721 + 23141.5583829246*t)
	X0 += 0.00000000053*np.cos(2.43583780027 + 2428.0421830342*t)
	X0 += 0.00000000059*np.cos(4.28456134455 + 3981.490034082*t)
	X0 += 0.00000000058*np.cos(2.65359377943 + 40077.61957352*t)
	X0 += 0.00000000054*np.cos(3.56564135998 + 15664.03552270859*t)
	X0 += 0.00000000061*np.cos(2.88962487651 + 40398.189919266*t)
	X0 += 0.00000000051*np.cos(3.00540767523 + 7668.9711263276*t)
	X0 += 0.00000000048*np.cos(4.80656273565 + 3646.3503773544*t)
	X0 += 0.00000000047*np.cos(5.83569926578 + 544.6688186216*t)
	X0 += 0.00000000048*np.cos(2.00982466333 + 39.3568759152*t)
	X0 += 0.00000000048*np.cos(2.80573655186 + 170.6728706192*t)
	X0 += 0.00000000055*np.cos(5.26856872787 + 81.8951455681*t)
	X0 += 0.00000000059*np.cos(2.11187321665 + 488.8496164711*t)
	X0 += 0.00000000065*np.cos(6.08902325889 + 47162.5163546352*t)
	X0 += 0.00000000056*np.cos(4.19093499866 + 799.8211251654*t)
	X0 += 0.00000000049*np.cos(3.72443814803 + 96562.99901809469*t)
	X0 += 0.00000000063*np.cos(4.17349551052 + 1364.7280995819*t)
	X0 += 0.00000000050*np.cos(5.17709552474 + 17583.6600713478*t)
	X0 += 0.00000000054*np.cos(3.62421804697 + 427.5613987225*t)
	X0 += 0.00000000052*np.cos(4.38844382678 + 210.5907824523*t)
	X0 += 0.00000000049*np.cos(5.16566731300 + 5490.300961524*t)
	X0 += 0.00000000058*np.cos(5.40778008235 + 6076.3751126948*t)
	X0 += 0.00000000058*np.cos(1.24075349030 + 6489.776587288*t)
	X0 += 0.00000000051*np.cos(0.50117453824 + 216.0074084237*t)
	X0 += 0.00000000046*np.cos(4.79961635192 + 106.2741679563*t)
	X0 += 0.00000000059*np.cos(1.72439508836 + 44034.1275895394*t)
	X0 += 0.00000000050*np.cos(4.62538441124 + 1056.9342496344*t)
	X0 += 0.00000000045*np.cos(1.62661962717 + 4480.7038592696*t)
	X0 += 0.00000000048*np.cos(1.32358795195 + 501.3797894433*t)
	X0 += 0.00000000061*np.cos(5.10264428859 + 491.6632924588*t)
	X0 += 0.00000000050*np.cos(1.09462754777 + 355.7487455718*t)
	X0 += 0.00000000044*np.cos(1.10033696885 + 2301.58581590939*t)
	X0 += 0.00000000054*np.cos(3.85123315789 + 6559.8216218558*t)
	X0 += 0.00000000054*np.cos(2.79730041476 + 6006.330078127*t)
	X0 += 0.00000000044*np.cos(5.16479782395 + 74.0308390419*t)
	X0 += 0.00000000052*np.cos(5.42245980619 + 244287.60000722769*t)
	X0 += 0.00000000048*np.cos(1.42585982742 + 36147.4098773004*t)
	X0 += 0.00000000044*np.cos(3.40081468635 + 2538.2485042536*t)
	X0 += 0.00000000044*np.cos(0.81389810430 + 5113.4875985828*t)
	X0 += 0.00000000055*np.cos(2.70454523909 + 14.977853527*t)
	X0 += 0.00000000045*np.cos(4.22954077900 + 533.2140834436*t)
	X0 += 0.00000000046*np.cos(2.27703250571 + 4384.7246320518*t)
	X0 += 0.00000000048*np.cos(6.20173890368 + 35579.69123957*t)
	X0 += 0.00000000057*np.cos(3.17248775727 + 491.8185618877*t)
	X0 += 0.00000000043*np.cos(0.99595677376 + 213.4591541324*t)
	X0 += 0.00000000043*np.cos(3.89366939283 + 213.1390367436*t)
	X0 += 0.00000000043*np.cos(2.65544175682 + 75.5323580927*t)
	X0 += 0.00000000043*np.cos(0.76354191371 + 220.4608265486*t)
	X0 += 0.00000000051*np.cos(0.20646603354 + 18326.65013188039*t)
	X0 += 0.00000000043*np.cos(3.18939503640 + 27832.0382192832*t)
	X0 += 0.00000000046*np.cos(4.72419541485 + 16703.062133499*t)
	X0 += 0.00000000052*np.cos(4.17179726389 + 11919.140866668*t)
	X0 += 0.00000000052*np.cos(0.71926561105 + 46386.9937433112*t)
	X0 += 0.00000000047*np.cos(0.82248881139 + 5209.4668258006*t)
	X0 += 0.00000000046*np.cos(4.04752097938 + 12555.1059997189*t)
	X0 += 0.00000000052*np.cos(0.43326734132 + 6574.0487158574*t)
	X0 += 0.00000000052*np.cos(6.21526623133 + 5992.1029841254*t)
	X0 += 0.00000000044*np.cos(5.37918791865 + 69941.95360082899*t)
	X0 += 0.00000000058*np.cos(0.36325356715 + 74673.9842281724*t)
	X0 += 0.00000000056*np.cos(1.50089021543 + 27707.5424942948*t)
	X0 += 0.00000000054*np.cos(0.68459749075 + 187.6962327724*t)
	X0 += 0.00000000045*np.cos(6.22182195617 + 46360.6954235114*t)
	X0 += 0.00000000043*np.cos(3.11608101277 + 8401.8397103698*t)
	X0 += 0.00000000057*np.cos(0.63863230611 + 1061.829610744*t)
	X0 += 0.00000000047*np.cos(2.39687793686 + 143571.32428481648*t)
	X0 += 0.00000000043*np.cos(1.13301289185 + 30639.856638633*t)
	X0 += 0.00000000050*np.cos(5.56308110598 + 296.1574488526*t)
	X0 += 0.00000000049*np.cos(1.97844011728 + 22030.2129546696*t)
	X0 += 0.00000000045*np.cos(4.79114307475 + 71519.2971432768*t)
	X0 += 0.00000000051*np.cos(4.52703512787 + 7761.9424240558*t)
	X0 += 0.00000000047*np.cos(0.24841658475 + 1279.794572628*t)
	X0 += 0.00000000041*np.cos(0.43156447693 + 3735.238311759*t)
	X0 += 0.00000000041*np.cos(4.51930257295 + 128.9562693151*t)
	X0 += 0.00000000041*np.cos(1.66415755313 + 44136.951349374*t)
	X0 += 0.00000000056*np.cos(5.45458264580 + 1057.8974574809*t)
	X0 += 0.00000000047*np.cos(4.45924253669 + 4708.2300487092*t)
	X0 += 0.00000000053*np.cos(1.93518633525 + 601.7642506762*t)
	X0 += 0.00000000056*np.cos(0.65498687965 + 28663.8316502654*t)
	X0 += 0.00000000047*np.cos(5.03443210464 + 679.2541622292*t)
	X0 += 0.00000000055*np.cos(3.26682599355 + 39302.096962196*t)
	X0 += 0.00000000049*np.cos(5.40929899528 + 27511.4678735372*t)
	X0 += 0.00000000047*np.cos(0.89791015009 + 316428.22867391503*t)
	X0 += 0.00000000040*np.cos(0.05000438602 + 18208.349942592*t)
	X0 += 0.00000000056*np.cos(2.85120720656 + 83659.27687239899*t)
	X0 += 0.00000000054*np.cos(4.48267339963 + 207.1487562837*t)
	X0 += 0.00000000040*np.cos(4.11879245377 + 1059.430114299*t)
	X0 += 0.00000000053*np.cos(3.02524199997 + 38650.173506199*t)
	X0 += 0.00000000042*np.cos(3.87088947499 + 220.364458329*t)
	X0 += 0.00000000048*np.cos(2.50261741205 + 12662.1309272006*t)
	X0 += 0.00000000046*np.cos(4.69192941021 + 10.2949407385*t)
	X0 += 0.00000000052*np.cos(4.41165168727 + 12571.6746242902*t)
	X0 += 0.00000000043*np.cos(4.69793306978 + 7322.1024607818*t)
	X0 += 0.00000000041*np.cos(3.56541409677 + 664.75604513*t)
	X0 += 0.00000000044*np.cos(5.20087497624 + 6140.8972229552*t)
	X0 += 0.00000000044*np.cos(1.44765859641 + 6425.2544770276*t)
	X0 += 0.00000000051*np.cos(5.74770428324 + 344.7030453079*t)
	X0 += 0.00000000039*np.cos(0.38207420659 + 22594.05489571199*t)
	X0 += 0.00000000054*np.cos(1.04857075083 + 188.9200730498*t)
	X0 += 0.00000000039*np.cos(4.22033276864 + 27278.4688164408*t)
	X0 += 0.00000000041*np.cos(2.70677059989 + 67.6680515665*t)
	X0 += 0.00000000045*np.cos(4.12311427457 + 44007.8292697396*t)
	X0 += 0.00000000054*np.cos(1.95689060462 + 6560.1108437328*t)
	X0 += 0.00000000054*np.cos(4.69164296803 + 6006.04085625*t)
	X0 += 0.00000000045*np.cos(5.54498349441 + 142861.39123625819*t)
	X0 += 0.00000000047*np.cos(1.12159858858 + 24499.5196606524*t)
	X0 += 0.00000000043*np.cos(1.36615498859 + 7026.065910524*t)
	X0 += 0.00000000040*np.cos(0.90738693747 + 26880.3198130326*t)
	X0 += 0.00000000044*np.cos(0.29252718625 + 179.3588454942*t)
	X0 += 0.00000000047*np.cos(4.50830744099 + 24485.29256665079*t)
	X0 += 0.00000000044*np.cos(1.83547130154 + 289.5651667136*t)
	X0 += 0.00000000043*np.cos(5.81439105801 + 6359.341921267*t)
	X0 += 0.00000000040*np.cos(4.83551999164 + 149.45132255*t)
	X0 += 0.00000000042*np.cos(4.70083045322 + 6231.79551212899*t)
	X0 += 0.00000000042*np.cos(1.94770311943 + 6334.35618785381*t)
	X0 += 0.00000000037*np.cos(5.39982800110 + 23020.65308658799*t)
	X0 += 0.00000000040*np.cos(0.02735864866 + 436.1594184316*t)
	X0 += 0.00000000052*np.cos(3.53311914292 + 11904.9187732018*t)
	X0 += 0.00000000040*np.cos(1.50947925293 + 7075.8507384588*t)
	X0 += 0.00000000047*np.cos(2.80270200743 + 1038.0412891868*t)
	X0 += 0.00000000037*np.cos(3.31019033964 + 1788.1448967202*t)
	X0 += 0.00000000049*np.cos(3.73016699917 + 32243.4985008806*t)
	X0 += 0.00000000043*np.cos(4.45265815492 + 40000.04091585779*t)
	X0 += 0.00000000045*np.cos(2.39073394193 + 358.9301393095*t)
	X0 += 0.00000000040*np.cos(0.07156369559 + 7122.0451377418*t)
	X0 += 0.00000000040*np.cos(0.29378456988 + 5444.106562241*t)
	X0 += 0.00000000038*np.cos(2.24527247949 + 44933.2493561904*t)
	X0 += 0.00000000047*np.cos(1.00325671943 + 523.5406259403*t)
	X0 += 0.00000000037*np.cos(0.09116813653 + 6850.7944877218*t)
	X0 += 0.00000000037*np.cos(0.27418012894 + 5715.357212261*t)
	X0 += 0.00000000039*np.cos(2.88920508037 + 20.3553193988*t)
	X0 += 0.00000000051*np.cos(5.82785362503 + 84111.74716305939*t)
	X0 += 0.00000000036*np.cos(2.92998162283 + 68.1893164283*t)
	X0 += 0.00000000037*np.cos(1.90653942815 + 16723.350142595*t)
	X0 += 0.00000000042*np.cos(3.79031051907 + 6328.217069628*t)
	X0 += 0.00000000042*np.cos(2.85822305358 + 6237.9346303548*t)
	X0 += 0.00000000036*np.cos(2.35204592553 + 20760.4270331914*t)
	X0 += 0.00000000049*np.cos(4.54040658078 + 11293.4706743556*t)
	X0 += 0.00000000036*np.cos(4.28412749882 + 2751.5475996916*t)
	X0 += 0.00000000040*np.cos(3.64328287226 + 3215.1363806432*t)
	X0 += 0.00000000040*np.cos(0.92098132614 + 1059.3337460794*t)
	X0 += 0.00000000050*np.cos(1.62788844152 + 84334.41776382479*t)
	X0 += 0.00000000040*np.cos(0.78396796338 + 71980.63357473118*t)
	return X0




def Earth_X1 (t): # 698 terms of order 1

	X1 = 0.
	X1 += 0.00122106982
	X1 += 0.00051500000*np.cos(6.00266267204 + 12566.1516999828*t)
	X1 += 0.00001290723*np.cos(5.95943124583 + 18849.2275499742*t)
	X1 += 0.00001068627*np.cos(2.01554176551 + 6283.0758499914*t)
	X1 += 0.00000898976*np.cos(1.12887038368 + 426.598190876*t)
	X1 += 0.00000776634*np.cos(2.70605024384 + 206.1855484372*t)
	X1 += 0.00000753346*np.cos(2.19132598402 + 220.4126424388*t)
	X1 += 0.00000565656*np.cos(3.22349285267 + 1059.3819301892*t)
	X1 += 0.00000570555*np.cos(5.57003898297 + 522.5774180938*t)
	X1 += 0.00000559385*np.cos(5.05751993763 + 536.8045120954*t)
	X1 += 0.00000212689*np.cos(1.73380190491 + 6279.5527316424*t)
	X1 += 0.00000212515*np.cos(4.91489371033 + 6286.5989683404*t)
	X1 += 0.00000088507*np.cos(3.47757021691 + 7.1135470008*t)
	X1 += 0.00000073550*np.cos(0.36357570430 + 639.897286314*t)
	X1 += 0.00000087568*np.cos(1.66327387610 + 419.4846438752*t)
	X1 += 0.00000062260*np.cos(0.36239798178 + 4705.7323075436*t)
	X1 += 0.00000053855*np.cos(1.32730357021 + 433.7117378768*t)
	X1 += 0.00000057347*np.cos(4.24377582130 + 213.299095438*t)
	X1 += 0.00000059822*np.cos(3.81195369871 + 6256.7775301916*t)
	X1 += 0.00000059514*np.cos(2.83634160150 + 6309.3741697912*t)
	X1 += 0.00000048841*np.cos(5.21419389335 + 775.522611324*t)
	X1 += 0.00000046286*np.cos(0.01839494103 + 7860.4193924392*t)
	X1 += 0.00000035675*np.cos(1.45279327264 + 5884.9268465832*t)
	X1 += 0.00000036061*np.cos(2.16002201071 + 5753.3848848968*t)
	X1 += 0.00000035367*np.cos(4.47243820095 + 6812.766815086*t)
	X1 += 0.00000031960*np.cos(5.19645600029 + 6681.2248533996*t)
	X1 += 0.00000031267*np.cos(4.87970239848 + 1052.2683831884*t)
	X1 += 0.00000032346*np.cos(1.00156514807 + 529.6909650946*t)
	X1 += 0.00000038757*np.cos(3.44658477283 + 1589.0728952838*t)
	X1 += 0.00000029717*np.cos(5.44950931785 + 1066.49547719*t)
	X1 += 0.00000032144*np.cos(2.85116756808 + 149.5631971346*t)
	X1 += 0.00000028763*np.cos(5.91618989512 + 25132.3033999656*t)
	X1 += 0.00000028447*np.cos(1.14976253807 + 6127.6554505572*t)
	X1 += 0.00000027573*np.cos(5.50119104683 + 6438.4962494256*t)
	X1 += 0.00000024815*np.cos(2.92204909812 + 5486.777843175*t)
	X1 += 0.00000021371*np.cos(0.56918433581 + 316.3918696566*t)
	X1 += 0.00000020611*np.cos(3.71790880968 + 7079.3738568078*t)
	X1 += 0.00000019565*np.cos(2.89351924469 + 5507.5532386674*t)
	X1 += 0.00000018990*np.cos(2.06104675595 + 227.5261894396*t)
	X1 += 0.00000018308*np.cos(1.46954314992 + 11790.6290886588*t)
	X1 += 0.00000016471*np.cos(6.22682639292 + 11506.7697697936*t)
	X1 += 0.00000016757*np.cos(3.81935015812 + 7058.5984613154*t)
	X1 += 0.00000014555*np.cos(5.97554823531 + 6290.1893969922*t)
	X1 += 0.00000014388*np.cos(0.68157599309 + 6275.9623029906*t)
	X1 += 0.00000013858*np.cos(4.17419232578 + 110.2063212194*t)
	X1 += 0.00000013921*np.cos(1.44156172409 + 796.2980068164*t)
	X1 += 0.00000015841*np.cos(5.77523709799 + 76.2660712756*t)
	X1 += 0.00000012374*np.cos(5.70562636316 + 515.463871093*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000011845*np.cos(4.15246503623 + 4694.0029547076*t)
	X1 += 0.00000011759*np.cos(3.04881045275 + 632.7837393132*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000010073*np.cos(3.28940171828 + 3738.761430108*t)
	X1 += 0.00000009513*np.cos(4.62657118532 + 6069.7767545534*t)
	X1 += 0.00000010425*np.cos(4.26610810148 + 6282.0955289232*t)
	X1 += 0.00000010425*np.cos(2.38242547117 + 6284.0561710596*t)
	X1 += 0.00000009565*np.cos(1.89315044337 + 4136.9104335162*t)
	X1 += 0.00000010223*np.cos(2.19747174258 + 73.297125859*t)
	X1 += 0.00000009044*np.cos(2.00977420682 + 6496.3749454294*t)
	X1 += 0.00000009014*np.cos(2.86872754290 + 199.0720014364*t)
	X1 += 0.00000008667*np.cos(4.92419711400 + 543.9180590962*t)
	X1 += 0.00000008543*np.cos(0.05563879210 + 1194.4470102246*t)
	X1 += 0.00000007682*np.cos(3.01488506505 + 949.1756089698*t)
	X1 += 0.00000007535*np.cos(2.70484475866 + 103.0927742186*t)
	X1 += 0.00000006181*np.cos(3.36235656603 + 8827.3902698748*t)
	X1 += 0.00000006252*np.cos(4.75560512125 + 8429.2412664666*t)
	X1 += 0.00000005657*np.cos(6.00342322432 + 853.196381752*t)
	X1 += 0.00000005525*np.cos(5.36960259598 + 4933.2084403326*t)
	X1 += 0.00000007312*np.cos(0.49039562572 + 4535.0594369244*t)
	X1 += 0.00000007074*np.cos(4.39447155183 + 5088.6288397668*t)
	X1 += 0.00000005158*np.cos(1.94900517603 + 209.3669421749*t)
	X1 += 0.00000005168*np.cos(5.15700586490 + 11769.8536931664*t)
	X1 += 0.00000005079*np.cos(2.96229494906 + 217.2312487011*t)
	X1 += 0.00000004878*np.cos(0.63279675325 + 6040.3472460174*t)
	X1 += 0.00000005339*np.cos(5.63168593753 + 3154.6870848956*t)
	X1 += 0.00000004985*np.cos(4.62777616911 + 12569.6748183318*t)
	X1 += 0.00000004653*np.cos(1.72782369127 + 216.4804891757*t)
	X1 += 0.00000004902*np.cos(4.14599178687 + 3930.2096962196*t)
	X1 += 0.00000004709*np.cos(3.96401482904 + 5331.3574437408*t)
	X1 += 0.00000004601*np.cos(6.02376082863 + 6525.8044539654*t)
	X1 += 0.00000004541*np.cos(3.17727011849 + 210.1177017003*t)
	X1 += 0.00000004456*np.cos(0.76977956324 + 323.5054166574*t)
	X1 += 0.00000004331*np.cos(1.32999081524 + 7632.9432596502*t)
	X1 += 0.00000004233*np.cos(3.49063898076 + 63.7358983034*t)
	X1 += 0.00000005607*np.cos(2.55800588736 + 5729.506447149*t)
	X1 += 0.00000004095*np.cos(0.51793431422 + 647.0108333148*t)
	X1 += 0.00000004989*np.cos(3.32377727482 + 14.2270940016*t)
	X1 += 0.00000003968*np.cos(2.72696169781 + 7234.794256242*t)
	X1 += 0.00000004394*np.cos(0.04709283876 + 12559.038152982*t)
	X1 += 0.00000004320*np.cos(4.28845188920 + 735.8765135318*t)
	X1 += 0.00000005262*np.cos(6.19471325132 + 8031.0922630584*t)
	X1 += 0.00000005100*np.cos(4.10862449537 + 6836.6452528338*t)
	X1 += 0.00000005075*np.cos(2.30582917471 + 7477.522860216*t)
	X1 += 0.00000003445*np.cos(4.34972240938 + 85.8272988312*t)
	X1 += 0.00000003338*np.cos(2.34738225115 + 11.0457002639*t)
	X1 += 0.00000003244*np.cos(6.04240714038 + 526.5095713569*t)
	X1 += 0.00000003287*np.cos(5.41013501104 + 10977.078804699*t)
	X1 += 0.00000003366*np.cos(0.28947921379 + 11371.7046897582*t)
	X1 += 0.00000003341*np.cos(1.64988056630 + 5223.6939198022*t)
	X1 += 0.00000003181*np.cos(4.57837074085 + 532.8723588323*t)
	X1 += 0.00000003495*np.cos(3.73571049570 + 4164.311989613*t)
	X1 += 0.00000004294*np.cos(4.93755825416 + 1592.5960136328*t)
	X1 += 0.00000003408*np.cos(2.40593164878 + 3128.3887650958*t)
	X1 += 0.00000002903*np.cos(4.79566936964 + 525.7588118315*t)
	X1 += 0.00000002864*np.cos(5.82538312855 + 533.6231183577*t)
	X1 += 0.00000002876*np.cos(2.69265723530 + 117.3198682202*t)
	X1 += 0.00000002997*np.cos(4.86533819655 + 1748.016413067*t)
	X1 += 0.00000002750*np.cos(5.24429623672 + 7342.4577801806*t)
	X1 += 0.00000002833*np.cos(2.05576755359 + 202.2533951741*t)
	X1 += 0.00000002669*np.cos(3.42836090012 + 2146.1654164752*t)
	X1 += 0.00000003313*np.cos(1.92016526057 + 801.8209311238*t)
	X1 += 0.00000002991*np.cos(2.26433580653 + 8635.9420037632*t)
	X1 += 0.00000003390*np.cos(4.23836515895 + 155.4203994342*t)
	X1 += 0.00000002488*np.cos(3.49719268728 + 2118.7638603784*t)
	X1 += 0.00000002384*np.cos(5.74836325186 + 7084.8967811152*t)
	X1 += 0.00000002514*np.cos(0.74093420826 + 95.9792272178*t)
	X1 += 0.00000002288*np.cos(4.51088946570 + 17260.1546546904*t)
	X1 += 0.00000002405*np.cos(5.96195251565 + 4690.4798363586*t)
	X1 += 0.00000002055*np.cos(5.42893438245 + 138.5174968707*t)
	X1 += 0.00000002052*np.cos(1.42012676041 + 951.7184062506*t)
	X1 += 0.00000001996*np.cos(3.76028525032 + 742.9900605326*t)
	X1 += 0.00000002049*np.cos(3.53634954129 + 1990.745017041*t)
	X1 += 0.00000002778*np.cos(1.46151348750 + 5481.2549188676*t)
	X1 += 0.00000002656*np.cos(5.71405746008 + 26.2983197998*t)
	X1 += 0.00000002529*np.cos(0.00975556739 + 1349.8674096588*t)
	X1 += 0.00000001877*np.cos(2.82846563483 + 553.5694028424*t)
	X1 += 0.00000001858*np.cos(0.74657310664 + 398.1490034082*t)
	X1 += 0.00000001910*np.cos(1.96850101416 + 956.2891559706*t)
	X1 += 0.00000001721*np.cos(5.77917332978 + 1596.1864422846*t)
	X1 += 0.00000001904*np.cos(4.23263119723 + 9437.762934887*t)
	X1 += 0.00000001708*np.cos(0.29065876129 + 10988.808157535*t)
	X1 += 0.00000001853*np.cos(1.84012190435 + 5230.807466803*t)
	X1 += 0.00000001668*np.cos(3.43481125656 + 70.8494453042*t)
	X1 += 0.00000001857*np.cos(2.34009177634 + 5216.5803728014*t)
	X1 += 0.00000001570*np.cos(4.37765395011 + 78.7137518304*t)
	X1 += 0.00000001543*np.cos(5.14512865944 + 10447.3878396044*t)
	X1 += 0.00000001555*np.cos(3.67004205114 + 13095.8426650774*t)
	X1 += 0.00000001491*np.cos(1.26055544534 + 440.8252848776*t)
	X1 += 0.00000001779*np.cos(1.80817581905 + 12562.6285816338*t)
	X1 += 0.00000001450*np.cos(5.64890887043 + 6303.4311693902*t)
	X1 += 0.00000001450*np.cos(0.99962470222 + 6262.7205305926*t)
	X1 += 0.00000001880*np.cos(1.74872544631 + 10973.55568635*t)
	X1 += 0.00000001837*np.cos(4.94810307591 + 1581.959348283*t)
	X1 += 0.00000001561*np.cos(4.53702050944 + 1045.1548361876*t)
	X1 += 0.00000001447*np.cos(1.95238298727 + 74.7815985673*t)
	X1 += 0.00000001372*np.cos(0.89279228106 + 7875.6718636242*t)
	X1 += 0.00000001645*np.cos(3.97870726126 + 224.3447957019*t)
	X1 += 0.00000001231*np.cos(4.10277044176 + 18319.5365848796*t)
	X1 += 0.00000001373*np.cos(4.83873686423 + 12721.572099417*t)
	X1 += 0.00000001127*np.cos(6.04843564608 + 5643.1785636774*t)
	X1 += 0.00000001136*np.cos(2.83389341769 + 2942.4634232916*t)
	X1 += 0.00000001161*np.cos(4.49256510074 + 625.6701923124*t)
	X1 += 0.00000001071*np.cos(3.77511422440 + 242.728603974*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000001165*np.cos(5.90779831262 + 15720.8387848784*t)
	X1 += 0.00000000999*np.cos(5.67443465200 + 1265.5674786264*t)
	X1 += 0.00000000973*np.cos(1.30526267473 + 4292.3308329504*t)
	X1 += 0.00000000993*np.cos(3.20822379065 + 10575.4066829418*t)
	X1 += 0.00000000964*np.cos(2.13521649390 + 2388.8940204492*t)
	X1 += 0.00000000929*np.cos(1.06241249364 + 16496.3613962024*t)
	X1 += 0.00000000934*np.cos(5.73801908186 + 20426.571092422*t)
	X1 += 0.00000000889*np.cos(0.06581239696 + 6288.5987742988*t)
	X1 += 0.00000000889*np.cos(0.29953586851 + 6277.552925684*t)
	X1 += 0.00000001018*np.cos(4.23379398746 + 12539.853380183*t)
	X1 += 0.00000001033*np.cos(1.04793549544 + 5760.4984318976*t)
	X1 += 0.00000001017*np.cos(5.59172649862 + 6805.6532680852*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000000938*np.cos(4.56608679745 + 1169.5882514086*t)
	X1 += 0.00000000801*np.cos(5.36423767778 + 14314.1681130498*t)
	X1 += 0.00000000943*np.cos(1.78153635749 + 151.0476698429*t)
	X1 += 0.00000000965*np.cos(1.55576378944 + 412.3710968744*t)
	X1 += 0.00000000769*np.cos(3.16951506066 + 942.062061969*t)
	X1 += 0.00000000795*np.cos(4.97031461103 + 6279.7894925736*t)
	X1 += 0.00000000795*np.cos(1.67821896162 + 6286.3622074092*t)
	X1 += 0.00000000723*np.cos(3.87714868475 + 9623.6882766912*t)
	X1 += 0.00000000800*np.cos(4.75445675725 + 12029.3471878874*t)
	X1 += 0.00000000698*np.cos(0.23124375738 + 6148.010769956*t)
	X1 += 0.00000000675*np.cos(5.56136235734 + 12964.300703391*t)
	X1 += 0.00000000678*np.cos(0.13408273301 + 6418.1409300268*t)
	X1 += 0.00000000671*np.cos(1.28940504615 + 6709.6740408674*t)
	X1 += 0.00000000768*np.cos(4.99147918103 + 1155.361157407*t)
	X1 += 0.00000000898*np.cos(2.26352977340 + 13367.9726311066*t)
	X1 += 0.00000000716*np.cos(4.07157593048 + 16730.4636895958*t)
	X1 += 0.00000000711*np.cos(3.39057215594 + 71.8126531507*t)
	X1 += 0.00000000651*np.cos(5.31876664276 + 5856.4776591154*t)
	X1 += 0.00000000744*np.cos(4.25820617142 + 12043.574281889*t)
	X1 += 0.00000000650*np.cos(3.96082074858 + 14712.317116458*t)
	X1 += 0.00000000719*np.cos(4.52061983489 + 77.7505439839*t)
	X1 += 0.00000000643*np.cos(6.14575788122 + 2352.8661537718*t)
	X1 += 0.00000000666*np.cos(6.18664331112 + 5746.271337896*t)
	X1 += 0.00000000588*np.cos(3.24442116878 + 13119.72110282519*t)
	X1 += 0.00000000627*np.cos(1.85323853183 + 4686.8894077068*t)
	X1 += 0.00000000584*np.cos(1.78420561597 + 13517.8701062334*t)
	X1 += 0.00000000572*np.cos(2.30412060804 + 309.2783226558*t)
	X1 += 0.00000000610*np.cos(0.48716946879 + 6819.8803620868*t)
	X1 += 0.00000000724*np.cos(3.25902076369 + 1162.4747044078*t)
	X1 += 0.00000000666*np.cos(3.29946942274 + 3634.6210245184*t)
	X1 += 0.00000000585*np.cos(0.14860338726 + 12036.4607348882*t)
	X1 += 0.00000000620*np.cos(5.87390167695 + 31415.379249957*t)
	X1 += 0.00000000553*np.cos(2.36074148933 + 6306.9542877392*t)
	X1 += 0.00000000553*np.cos(4.28779208332 + 6259.1974122436*t)
	X1 += 0.00000000527*np.cos(4.65845256725 + 10177.2576795336*t)
	X1 += 0.00000000523*np.cos(5.55991825992 + 12139.5535091068*t)
	X1 += 0.00000000514*np.cos(2.30343678959 + 4701.1165017084*t)
	X1 += 0.00000000510*np.cos(3.90147691268 + 277.0349937414*t)
	X1 += 0.00000000495*np.cos(3.58067041581 + 13362.4497067992*t)
	X1 += 0.00000000688*np.cos(0.41160312810 + 13916.0191096416*t)
	X1 += 0.00000000481*np.cos(4.14197696514 + 6286.9571853494*t)
	X1 += 0.00000000481*np.cos(2.50655660751 + 6279.1945146334*t)
	X1 += 0.00000000486*np.cos(0.82245463791 + 422.6660376129*t)
	X1 += 0.00000000465*np.cos(0.81901657744 + 14143.4952424306*t)
	X1 += 0.00000000440*np.cos(2.91975126929 + 3894.1818295422*t)
	X1 += 0.00000000431*np.cos(3.09968854047 + 11499.6562227928*t)
	X1 += 0.00000000452*np.cos(5.55409870988 + 12573.2652469836*t)
	X1 += 0.00000000499*np.cos(1.08746978287 + 12410.7313005486*t)
	X1 += 0.00000000440*np.cos(2.14902528642 + 24072.9214697764*t)
	X1 += 0.00000000431*np.cos(2.74190891091 + 1692.1656695024*t)
	X1 += 0.00000000435*np.cos(4.76945528790 + 9917.6968745098*t)
	X1 += 0.00000000391*np.cos(5.30832534377 + 1073.6090241908*t)
	X1 += 0.00000000398*np.cos(5.77181168519 + 8273.8208670324*t)
	X1 += 0.00000000379*np.cos(4.62464502982 + 6386.16862421*t)
	X1 += 0.00000000379*np.cos(2.02388854283 + 6179.9830757728*t)
	X1 += 0.00000000377*np.cos(5.90355422208 + 7872.1487452752*t)
	X1 += 0.00000000419*np.cos(5.62219999256 + 5327.4761083828*t)
	X1 += 0.00000000383*np.cos(0.40420536338 + 6319.1037166688*t)
	X1 += 0.00000000383*np.cos(6.24432820927 + 6247.04798331399*t)
	X1 += 0.00000000486*np.cos(3.05618432546 + 12592.4500197826*t)
	X1 += 0.00000000374*np.cos(1.92168872074 + 234.6397364404*t)
	X1 += 0.00000000457*np.cos(2.45652916518 + 6489.2613984286*t)
	X1 += 0.00000000457*np.cos(4.19200440747 + 6076.8903015542*t)
	X1 += 0.00000000512*np.cos(1.88365818219 + 11015.1064773348*t)
	X1 += 0.00000000384*np.cos(0.93539249733 + 330.6189636582*t)
	X1 += 0.00000000371*np.cos(5.54353838421 + 415.5524906121*t)
	X1 += 0.00000000353*np.cos(1.18721605495 + 846.0828347512*t)
	X1 += 0.00000000344*np.cos(0.28667648401 + 18451.07854656599*t)
	X1 += 0.00000000340*np.cos(2.75068444234 + 12323.4230960088*t)
	X1 += 0.00000000335*np.cos(6.05401158140 + 860.3099287528*t)
	X1 += 0.00000000454*np.cos(0.72878821246 + 2787.0430238574*t)
	X1 += 0.00000000337*np.cos(4.75525977824 + 71.6002048296*t)
	X1 += 0.00000000364*np.cos(2.25070711701 + 6321.1035226272*t)
	X1 += 0.00000000364*np.cos(4.39782645564 + 6245.0481773556*t)
	X1 += 0.00000000324*np.cos(2.28921417158 + 423.4167971383*t)
	X1 += 0.00000000342*np.cos(6.10019640486 + 6303.8512454838*t)
	X1 += 0.00000000342*np.cos(0.54833716779 + 6262.300454499*t)
	X1 += 0.00000000390*np.cos(2.72203516881 + 10021.8372800994*t)
	X1 += 0.00000000324*np.cos(2.66245548691 + 77713.7714681205*t)
	X1 += 0.00000000316*np.cos(0.14807870151 + 11926.2544136688*t)
	X1 += 0.00000000318*np.cos(1.32350341546 + 6311.5250374592*t)
	X1 += 0.00000000318*np.cos(5.32503015719 + 6254.6266625236*t)
	X1 += 0.00000000324*np.cos(3.05393333292 + 77.962992305*t)
	X1 += 0.00000000384*np.cos(3.06685995823 + 1478.8665740644*t)
	X1 += 0.00000000316*np.cos(0.91375113764 + 429.7795846137*t)
	X1 += 0.00000000361*np.cos(2.21089537404 + 2.9689454166*t)
	X1 += 0.00000000305*np.cos(5.55791649320 + 145.6310438715*t)
	X1 += 0.00000000304*np.cos(2.00970548291 + 12779.4507954208*t)
	X1 += 0.00000000343*np.cos(2.93550529951 + 6267.82337880639*t)
	X1 += 0.00000000343*np.cos(3.71302827314 + 6298.3283211764*t)
	X1 += 0.00000000398*np.cos(0.12276624389 + 1551.045222648*t)
	X1 += 0.00000000374*np.cos(4.41343415577 + 728.762966531*t)
	X1 += 0.00000000300*np.cos(1.77610616438 + 90279.92316810328*t)
	X1 += 0.00000000297*np.cos(0.51546903036 + 5429.8794682394*t)
	X1 += 0.00000000337*np.cos(2.71244267795 + 17782.7320727842*t)
	X1 += 0.00000000295*np.cos(4.05850212848 + 6702.5604938666*t)
	X1 += 0.00000000383*np.cos(6.13188528401 + 210.8514148832*t)
	X1 += 0.00000000380*np.cos(5.05058792236 + 215.7467759928*t)
	X1 += 0.00000000331*np.cos(0.94287498279 + 7238.67559160*t)
	X1 += 0.00000000321*np.cos(2.23719619346 + 17796.9591667858*t)
	X1 += 0.00000000268*np.cos(4.36573038796 + 2544.3144198834*t)
	X1 += 0.00000000349*np.cos(0.95962542267 + 17789.845619785*t)
	X1 += 0.00000000338*np.cos(5.87862918623 + 148.0787244263*t)
	X1 += 0.00000000255*np.cos(2.25536828287 + 437.6438911399*t)
	X1 += 0.00000000275*np.cos(3.67150875811 + 14945.3161735544*t)
	X1 += 0.00000000253*np.cos(2.22918080251 + 18073.7049386502*t)
	X1 += 0.00000000257*np.cos(1.04749733742 + 955.5997416086*t)
	X1 += 0.00000000311*np.cos(5.13228886176 + 838.9692877504*t)
	X1 += 0.00000000237*np.cos(2.28726007142 + 3.9321532631*t)
	X1 += 0.00000000282*np.cos(4.50260494490 + 13341.6743113068*t)
	X1 += 0.00000000266*np.cos(5.06649873732 + 38.1330356378*t)
	X1 += 0.00000000269*np.cos(6.10957634874 + 9779.1086761254*t)
	X1 += 0.00000000234*np.cos(1.60395818860 + 223.5940361765*t)
	X1 += 0.00000000306*np.cos(3.20523259534 + 5863.5912061162*t)
	X1 += 0.00000000221*np.cos(5.85413979591 + 508.3503240922*t)
	X1 += 0.00000000234*np.cos(4.87225306441 + 1272.6810256272*t)
	X1 += 0.00000000216*np.cos(5.60561646872 + 3185.1920272656*t)
	X1 += 0.00000000280*np.cos(1.91082976057 + 5642.1982426092*t)
	X1 += 0.00000000233*np.cos(3.01339621844 + 10984.1923516998*t)
	X1 += 0.00000000263*np.cos(2.16888500036 + 12168.0026965746*t)
	X1 += 0.00000000226*np.cos(4.44534966925 + 3496.032826134*t)
	X1 += 0.00000000260*np.cos(3.16564185469 + 10969.9652576982*t)
	X1 += 0.00000000227*np.cos(4.95666866168 + 5849.3641121146*t)
	X1 += 0.00000000211*np.cos(1.22111379347 + 19651.048481098*t)
	X1 += 0.00000000250*np.cos(4.61595902292 + 6923.9534573736*t)
	X1 += 0.00000000194*np.cos(2.37630770389 + 640.8776073822*t)
	X1 += 0.00000000203*np.cos(4.39496828470 + 6062.6632075526*t)
	X1 += 0.00000000203*np.cos(2.25356528795 + 6503.4884924302*t)
	X1 += 0.00000000200*np.cos(6.03453757404 + 1375.7737998458*t)
	X1 += 0.00000000184*np.cos(0.13859812924 + 18209.33026366019*t)
	X1 += 0.00000000184*np.cos(4.20955149479 + 12566.2190102856*t)
	X1 += 0.00000000190*np.cos(3.42922211260 + 2648.454825473*t)
	X1 += 0.00000000199*np.cos(2.84103239065 + 3.523118349*t)
	X1 += 0.00000000187*np.cos(2.05685668523 + 6290.1220866894*t)
	X1 += 0.00000000187*np.cos(4.59167688742 + 6276.02961329339*t)
	X1 += 0.00000000192*np.cos(2.99578290747 + 4732.0306273434*t)
	X1 += 0.00000000184*np.cos(4.65365446464 + 12566.08438968*t)
	X1 += 0.00000000230*np.cos(2.23774195109 + 12567.132021051*t)
	X1 += 0.00000000199*np.cos(2.97222353917 + 430.5303441391*t)
	X1 += 0.00000000188*np.cos(1.83168099087 + 124.433415221*t)
	X1 += 0.00000000184*np.cos(3.38049914956 + 6037.244203762*t)
	X1 += 0.00000000173*np.cos(0.50653444879 + 1368.660252845*t)
	X1 += 0.00000000166*np.cos(4.99522557947 + 1062.5633239269*t)
	X1 += 0.00000000164*np.cos(2.91444613296 + 3.1813937377*t)
	X1 += 0.00000000175*np.cos(3.26771507312 + 6528.9074962208*t)
	X1 += 0.00000000174*np.cos(1.61176269489 + 65.2203710117*t)
	X1 += 0.00000000163*np.cos(0.77052245905 + 88.865680217*t)
	X1 += 0.00000000154*np.cos(0.97127667708 + 6112.4029793722*t)
	X1 += 0.00000000154*np.cos(5.67725689556 + 6453.7487206106*t)
	X1 += 0.00000000153*np.cos(0.79359507111 + 160.6088973985*t)
	X1 += 0.00000000154*np.cos(6.16274455061 + 519.3960243561*t)
	X1 += 0.00000000166*np.cos(4.51313560848 + 12352.8526045448*t)
	X1 += 0.00000000172*np.cos(0.88734623011 + 1577.3435424478*t)
	X1 += 0.00000000144*np.cos(3.76179690789 + 18635.9284545362*t)
	X1 += 0.00000000140*np.cos(5.84592048082 + 1258.4539316256*t)
	X1 += 0.00000000146*np.cos(1.99164761433 + 13760.5987102074*t)
	X1 += 0.00000000138*np.cos(5.22139410630 + 1055.4497769261*t)
	X1 += 0.00000000136*np.cos(0.75192359085 + 11712.9553182308*t)
	X1 += 0.00000000142*np.cos(1.34533369944 + 4157.1984426122*t)
	X1 += 0.00000000133*np.cos(0.01824912792 + 18139.2945014159*t)
	X1 += 0.00000000132*np.cos(0.46806671232 + 654.1243803156*t)
	X1 += 0.00000000134*np.cos(3.33556330332 + 203.0041546995*t)
	X1 += 0.00000000124*np.cos(0.99880484927 + 17256.6315363414*t)
	X1 += 0.00000000140*np.cos(1.25451695814 + 9380.9596727172*t)
	X1 += 0.00000000120*np.cos(0.17691589754 + 1063.3140834523*t)
	X1 += 0.00000000123*np.cos(0.26259126301 + 6172.869528772*t)
	X1 += 0.00000000123*np.cos(0.10275700246 + 6393.2821712108*t)
	X1 += 0.00000000121*np.cos(5.40082218265 + 20.7753954924*t)
	X1 += 0.00000000117*np.cos(4.47711713051 + 18852.7506683232*t)
	X1 += 0.00000000118*np.cos(4.77280443966 + 551.031606097*t)
	X1 += 0.00000000120*np.cos(4.45697558744 + 539.9859058331*t)
	X1 += 0.00000000140*np.cos(5.86589845886 + 1056.2005364515*t)
	X1 += 0.00000000114*np.cos(2.33765655466 + 65147.6197681377*t)
	X1 += 0.00000000120*np.cos(2.29184279740 + 17253.04110768959*t)
	X1 += 0.00000000132*np.cos(4.94196827917 + 18875.525869774*t)
	X1 += 0.00000000111*np.cos(5.69390808885 + 222.8603229936*t)
	X1 += 0.00000000111*np.cos(0.03988488946 + 2125.8774073792*t)
	X1 += 0.00000000123*np.cos(4.42839393502 + 12565.1713789146*t)
	X1 += 0.00000000133*np.cos(4.62837772547 + 22.0914005278*t)
	X1 += 0.00000000129*np.cos(2.56187150433 + 11513.8833167944*t)
	X1 += 0.00000000121*np.cos(2.27781803851 + 10419.9862835076*t)
	X1 += 0.00000000118*np.cos(5.96799701373 + 17654.7805397496*t)
	X1 += 0.00000000144*np.cos(1.47900802038 + 299.1263942692*t)
	X1 += 0.00000000105*np.cos(5.26799267002 + 23013.5395395872*t)
	X1 += 0.00000000103*np.cos(0.24702432231 + 6271.3464971554*t)
	X1 += 0.00000000103*np.cos(0.11832394316 + 6294.8052028274*t)
	X1 += 0.00000000102*np.cos(2.69803619583 + 17267.26820169119*t)
	X1 += 0.00000000108*np.cos(2.49639211639 + 23543.23050468179*t)
	X1 += 0.00000000114*np.cos(2.21695343681 + 4171.4255366138*t)
	X1 += 0.00000000101*np.cos(4.42100430236 + 4804.209275927*t)
	X1 += 0.00000000134*np.cos(3.16966777445 + 21.3406410024*t)
	X1 += 0.00000000139*np.cos(2.94662252756 + 1485.9801210652*t)
	X1 += 0.00000000102*np.cos(5.67042027327 + 6549.6828917132*t)
	X1 += 0.00000000102*np.cos(0.97811329938 + 6016.4688082696*t)
	X1 += 0.00000000097*np.cos(5.41467539027 + 18.1592472647*t)
	X1 += 0.00000000125*np.cos(0.12553662943 + 10213.285546211*t)
	X1 += 0.00000000096*np.cos(3.08170402360 + 191.9584544356*t)
	X1 += 0.00000000120*np.cos(4.77545420807 + 1574.8458012822*t)
	X1 += 0.00000000094*np.cos(3.31739742370 + 87.3117715395*t)
	X1 += 0.00000000101*np.cos(1.27086316315 + 33.6796175129*t)
	X1 += 0.00000000121*np.cos(0.05336972054 + 13625.533630172*t)
	X1 += 0.00000000122*np.cos(0.24302263595 + 84.3428261229*t)
	X1 += 0.00000000096*np.cos(5.16231260208 + 2111.6503133776*t)
	X1 += 0.00000000097*np.cos(5.87982327909 + 217.964961884*t)
	X1 += 0.00000000086*np.cos(5.93949751968 + 12808.8803039568*t)
	X1 += 0.00000000087*np.cos(3.32576161903 + 231.4583427027*t)
	X1 += 0.00000000095*np.cos(1.34358559692 + 12345.739057544*t)
	X1 += 0.00000000097*np.cos(1.64179644592 + 72.3339180125*t)
	X1 += 0.00000000089*np.cos(5.45720829907 + 628.8515860501*t)
	X1 += 0.00000000106*np.cos(5.14281705612 + 11216.284290324*t)
	X1 += 0.00000000095*np.cos(2.50046439714 + 12012.5822971404*t)
	X1 += 0.00000000081*np.cos(3.84772814821 + 11614.4332937322*t)
	X1 += 0.00000000088*np.cos(5.00348782624 + 1699.2792165032*t)
	X1 += 0.00000000084*np.cos(1.14755262027 + 6255.6742938946*t)
	X1 += 0.00000000084*np.cos(5.50098095238 + 6310.4774060882*t)
	X1 += 0.00000000081*np.cos(1.26377078095 + 12.5301729722*t)
	X1 += 0.00000000080*np.cos(2.34508693340 + 3340.6124266998*t)
	X1 += 0.00000000106*np.cos(6.00471264495 + 3097.88382272579*t)
	X1 += 0.00000000080*np.cos(0.34711727404 + 6922.9731363054*t)
	X1 += 0.00000000085*np.cos(5.79536877725 + 5636.0650166766*t)
	X1 += 0.00000000086*np.cos(3.03921945697 + 127.4717966068*t)
	X1 += 0.00000000092*np.cos(0.87789019103 + 10818.1352869158*t)
	X1 += 0.00000000080*np.cos(4.19702650261 + 3583.3410306738*t)
	X1 += 0.00000000083*np.cos(3.70902039500 + 5120.6011455836*t)
	X1 += 0.00000000080*np.cos(1.41939312484 + 13521.7514415914*t)
	X1 += 0.00000000084*np.cos(3.01891268791 + 10440.2742926036*t)
	X1 += 0.00000000085*np.cos(5.30523639998 + 208.633228992*t)
	X1 += 0.00000000077*np.cos(5.70306938809 + 6993.0088985497*t)
	X1 += 0.00000000104*np.cos(5.42105253386 + 5650.2921106782*t)
	X1 += 0.00000000086*np.cos(0.81273058913 + 12359.9661515456*t)
	X1 += 0.00000000080*np.cos(4.03019573108 + 1471.7530270636*t)
	X1 += 0.00000000076*np.cos(5.75771357218 + 288.0806940053*t)
	X1 += 0.00000000090*np.cos(6.02294397735 + 6195.76764545159*t)
	X1 += 0.00000000090*np.cos(0.62558959530 + 6370.3840545312*t)
	X1 += 0.00000000082*np.cos(0.19767948100 + 18842.11400297339*t)
	X1 += 0.00000000083*np.cos(5.31994916859 + 18415.51581209739*t)
	X1 += 0.00000000101*np.cos(2.86191811970 + 3104.9300594238*t)
	X1 += 0.00000000096*np.cos(6.22255663987 + 203.7378678824*t)
	X1 += 0.00000000076*np.cos(0.40948960322 + 362.8622925726*t)
	X1 += 0.00000000072*np.cos(3.81559276845 + 302.164775655*t)
	X1 += 0.00000000075*np.cos(1.95113506965 + 525.0250986486*t)
	X1 += 0.00000000069*np.cos(4.21368560293 + 114.3991069134*t)
	X1 += 0.00000000068*np.cos(0.64071253014 + 153.4953503977*t)
	X1 += 0.00000000084*np.cos(4.35521501162 + 2379.1644735716*t)
	X1 += 0.00000000068*np.cos(0.16388050208 + 9.5612275556*t)
	X1 += 0.00000000068*np.cos(0.99582401938 + 73.8183907208*t)
	X1 += 0.00000000075*np.cos(1.62833922577 + 30355.9973197678*t)
	X1 += 0.00000000069*np.cos(3.24662354142 + 10454.5013866052*t)
	X1 += 0.00000000076*np.cos(3.92665935350 + 17298.1823273262*t)
	X1 += 0.00000000076*np.cos(4.83482959872 + 18429.742906099*t)
	X1 += 0.00000000071*np.cos(2.38708525663 + 534.3568315406*t)
	X1 += 0.00000000079*np.cos(0.06205634713 + 22805.7355659936*t)
	X1 += 0.00000000077*np.cos(2.05455640378 + 16858.4825329332*t)
	X1 += 0.00000000064*np.cos(0.53528518109 + 75.7448064138*t)
	X1 += 0.00000000087*np.cos(5.09755111164 + 3903.9113764198*t)
	X1 += 0.00000000066*np.cos(6.17786477200 + 42.5864537627*t)
	X1 += 0.00000000061*np.cos(2.88776849923 + 207.8824694666*t)
	X1 += 0.00000000061*np.cos(3.70271756349 + 16737.5772365966*t)
	X1 += 0.00000000078*np.cos(4.31638741861 + 8671.9698704406*t)
	X1 += 0.00000000063*np.cos(0.99541849434 + 24356.7807886416*t)
	X1 += 0.00000000060*np.cos(2.02282855033 + 218.7157214094*t)
	X1 += 0.00000000070*np.cos(0.83559773197 + 52.6901980395*t)
	X1 += 0.00000000075*np.cos(2.14136838637 + 23581.2581773176*t)
	X1 += 0.00000000059*np.cos(1.24623136375 + 408.4389436113*t)
	X1 += 0.00000000073*np.cos(4.49527510239 + 9388.0059094152*t)
	X1 += 0.00000000058*np.cos(0.89406841198 + 17996.0311682222*t)
	X1 += 0.00000000067*np.cos(0.58534149028 + 152.5321425512*t)
	X1 += 0.00000000076*np.cos(0.10784891475 + 77.2292791221*t)
	X1 += 0.00000000064*np.cos(3.30054842989 + 79.2350166922*t)
	X1 += 0.00000000061*np.cos(0.45486168004 + 56.6223513026*t)
	X1 += 0.00000000062*np.cos(4.06342805588 + 11925.2740926006*t)
	X1 += 0.00000000060*np.cos(3.51548088474 + 34570.0663348526*t)
	X1 += 0.00000000057*np.cos(4.46050926275 + 149854.40013480789*t)
	X1 += 0.00000000056*np.cos(5.33393809517 + 12455.9453787634*t)
	X1 += 0.00000000055*np.cos(3.57207397234 + 340.7708920448*t)
	X1 += 0.00000000056*np.cos(2.17965993818 + 11764.330768859*t)
	X1 += 0.00000000055*np.cos(3.08168513239 + 200.7689224658*t)
	X1 += 0.00000000061*np.cos(0.15194461973 + 28237.2334593894*t)
	X1 += 0.00000000076*np.cos(2.25541605095 + 146.594251718*t)
	X1 += 0.00000000065*np.cos(5.87045161229 + 7335.3442331798*t)
	X1 += 0.00000000060*np.cos(5.32793915897 + 831.8557407496*t)
	X1 += 0.00000000054*np.cos(2.83216128661 + 1.4844727083*t)
	X1 += 0.00000000072*np.cos(5.87296425674 + 6510.5519827804*t)
	X1 += 0.00000000072*np.cos(0.77556931591 + 6055.5997172024*t)
	X1 += 0.00000000066*np.cos(5.83578469159 + 618.5566453116*t)
	X1 += 0.00000000071*np.cos(0.23083621209 + 12545.3763044904*t)
	X1 += 0.00000000061*np.cos(5.37705181537 + 6253.6463414554*t)
	X1 += 0.00000000061*np.cos(1.27148175728 + 6312.5053585274*t)
	X1 += 0.00000000055*np.cos(1.18603703570 + 2699.7348193176*t)
	X1 += 0.00000000056*np.cos(6.18401368339 + 5573.1428014331*t)
	X1 += 0.00000000058*np.cos(0.97037460116 + 4.4534181249*t)
	X1 += 0.00000000055*np.cos(5.94073604896 + 15671.0817594066*t)
	X1 += 0.00000000052*np.cos(0.26563539971 + 5326.7866940208*t)
	X1 += 0.00000000051*np.cos(3.56752380688 + 225.8292684102*t)
	X1 += 0.00000000058*np.cos(3.10263152972 + 2221.856634597*t)
	X1 += 0.00000000051*np.cos(4.54732927101 + 62.2514255951*t)
	X1 += 0.00000000053*np.cos(1.77739578512 + 26735.9452622132*t)
	X1 += 0.00000000064*np.cos(5.43530311047 + 1685.0521225016*t)
	X1 += 0.00000000050*np.cos(4.84629478021 + 195.1398481733*t)
	X1 += 0.00000000065*np.cos(2.33938496802 + 14919.0178537546*t)
	X1 += 0.00000000049*np.cos(2.64059175393 + 2008.557539159*t)
	X1 += 0.00000000049*np.cos(4.18739781015 + 35579.69123957*t)
	X1 += 0.00000000053*np.cos(5.28549359722 + 6357.8574485587*t)
	X1 += 0.00000000053*np.cos(1.36303997543 + 6208.2942514241*t)
	X1 += 0.00000000051*np.cos(0.76407742618 + 16522.6597160022*t)
	X1 += 0.00000000052*np.cos(4.61821041475 + 70.3281804424*t)
	X1 += 0.00000000049*np.cos(4.92674479666 + 21393.5419698576*t)
	X1 += 0.00000000049*np.cos(0.60525485888 + 7018.9523635232*t)
	X1 += 0.00000000049*np.cos(6.04327871377 + 5547.1993364596*t)
	X1 += 0.00000000049*np.cos(4.31351627712 + 350.3321196004*t)
	X1 += 0.00000000049*np.cos(2.59123701567 + 12416.5885028482*t)
	X1 += 0.00000000050*np.cos(0.07523239468 + 26084.0218062162*t)
	X1 += 0.00000000048*np.cos(5.46985443988 + 12132.439962106*t)
	X1 += 0.00000000051*np.cos(3.40683294217 + 23006.42599258639*t)
	X1 += 0.00000000058*np.cos(2.46543150418 + 15141.390794312*t)
	X1 += 0.00000000051*np.cos(1.79926614465 + 210.3783341312*t)
	X1 += 0.00000000048*np.cos(4.88190521609 + 16200.7727245012*t)
	X1 += 0.00000000051*np.cos(3.07938265367 + 216.2198567448*t)
	X1 += 0.00000000047*np.cos(0.97667389279 + 24279.10701821359*t)
	X1 += 0.00000000049*np.cos(1.66846784739 + 5749.8617665478*t)
	X1 += 0.00000000049*np.cos(4.98006572526 + 6816.289933435*t)
	X1 += 0.00000000046*np.cos(3.45134537804 + 19378.9185150688*t)
	X1 += 0.00000000047*np.cos(2.09300174029 + 24065.80792277559*t)
	X1 += 0.00000000049*np.cos(5.92307582908 + 963.4027029714*t)
	X1 += 0.00000000053*np.cos(1.27341801656 + 142.4496501338*t)
	X1 += 0.00000000046*np.cos(5.73797450552 + 104351.61256629678*t)
	X1 += 0.00000000049*np.cos(1.45701599108 + 8982.810669309*t)
	X1 += 0.00000000050*np.cos(4.49441848554 + 24602.61243487099*t)
	X1 += 0.00000000045*np.cos(0.12799634054 + 24491.4257925834*t)
	X1 += 0.00000000049*np.cos(2.95918505969 + 16460.33352952499*t)
	X1 += 0.00000000054*np.cos(0.03974674424 + 7834.1210726394*t)
	X1 += 0.00000000045*np.cos(5.05860612319 + 161000.6857376741*t)
	X1 += 0.00000000045*np.cos(4.80760215190 + 37.611770776*t)
	X1 += 0.00000000044*np.cos(3.92726741188 + 8662.240323563*t)
	X1 += 0.00000000049*np.cos(4.51486356794 + 29303.7289365794*t)
	X1 += 0.00000000050*np.cos(4.51633294079 + 1038.0412891868*t)
	X1 += 0.00000000044*np.cos(5.63991949724 + 524.2743391232*t)
	X1 += 0.00000000044*np.cos(2.67440279390 + 38.6543004996*t)
	X1 += 0.00000000044*np.cos(4.98395147244 + 535.107591066*t)
	X1 += 0.00000000058*np.cos(5.77065508757 + 1795.258443721*t)
	X1 += 0.00000000049*np.cos(4.98978743446 + 29289.5018425778*t)
	X1 += 0.00000000043*np.cos(3.34677142688 + 5244.049239201*t)
	X1 += 0.00000000044*np.cos(3.63764737159 + 6175.4123260528*t)
	X1 += 0.00000000044*np.cos(3.01088620106 + 6390.73937393*t)
	X1 += 0.00000000042*np.cos(1.47305743112 + 24705.70520908959*t)
	X1 += 0.00000000043*np.cos(4.16006907854 + 74.6697239827*t)
	X1 += 0.00000000043*np.cos(3.66062507509 + 74.8934731519*t)
	X1 += 0.00000000049*np.cos(5.77857770467 + 207.6700211455*t)
	X1 += 0.00000000041*np.cos(4.78696656856 + 17370.3609759098*t)
	X1 += 0.00000000041*np.cos(4.99610869214 + 22483.84857449259*t)
	X1 += 0.00000000057*np.cos(3.19497095530 + 84334.66158130829*t)
	X1 += 0.00000000041*np.cos(3.62603303245 + 23020.65308658799*t)
	X1 += 0.00000000045*np.cos(2.13147646951 + 54247.4131357504*t)
	X1 += 0.00000000049*np.cos(1.81278199589 + 131.4039498699*t)
	X1 += 0.00000000040*np.cos(3.00393229632 + 32243.4985008806*t)
	X1 += 0.00000000040*np.cos(0.45946989377 + 24336.0053931492*t)
	X1 += 0.00000000047*np.cos(2.28831256912 + 109.9456887885*t)
	X1 += 0.00000000040*np.cos(0.00254937606 + 8401.8397103698*t)
	X1 += 0.00000000039*np.cos(1.67338261788 + 1382.8873468466*t)
	X1 += 0.00000000041*np.cos(5.05922003836 + 26482.1708096244*t)
	X1 += 0.00000000044*np.cos(4.93011217974 + 28230.18722269139*t)
	X1 += 0.00000000039*np.cos(5.54872052106 + 45585.1728121874*t)
	X1 += 0.00000000041*np.cos(2.93602685311 + 10.2949407385*t)
	X1 += 0.00000000038*np.cos(4.40087475081 + 703.6331846174*t)
	X1 += 0.00000000038*np.cos(3.93561558747 + 6268.8487559898*t)
	X1 += 0.00000000038*np.cos(2.71291798518 + 6297.302943993*t)
	X1 += 0.00000000041*np.cos(4.95311845784 + 15508.6151232744*t)
	X1 += 0.00000000038*np.cos(0.10976793876 + 6171.8892077038*t)
	X1 += 0.00000000038*np.cos(0.25558032671 + 6394.262492279*t)
	X1 += 0.00000000039*np.cos(3.31511780881 + 29826.3063546732*t)
	X1 += 0.00000000046*np.cos(5.36914408518 + 218.9281697305*t)
	X1 += 0.00000000038*np.cos(4.03952051907 + 16062.1845261168*t)
	X1 += 0.00000000037*np.cos(2.07587316842 + 20452.8694122218*t)
	X1 += 0.00000000037*np.cos(4.39032344034 + 511.5317178299*t)
	X1 += 0.00000000049*np.cos(5.78169307611 + 18216.443810661*t)
	X1 += 0.00000000041*np.cos(1.35496527372 + 29088.811415985*t)
	X1 += 0.00000000038*np.cos(6.16268217428 + 18202.21671665939*t)
	X1 += 0.00000000036*np.cos(3.84319801860 + 39302.096962196*t)
	X1 += 0.00000000038*np.cos(6.14920442251 + 26709.6469424134*t)
	X1 += 0.00000000036*np.cos(6.28049708584 + 9924.8104215106*t)
	X1 += 0.00000000035*np.cos(5.85809750059 + 565.1156877467*t)
	X1 += 0.00000000035*np.cos(4.66732134451 + 4061.2192153944*t)
	X1 += 0.00000000040*np.cos(3.43223548088 + 27511.4678735372*t)
	X1 += 0.00000000035*np.cos(6.22608295766 + 547.8502123593*t)
	X1 += 0.00000000034*np.cos(1.38801022558 + 6147.4505249814*t)
	X1 += 0.00000000034*np.cos(5.26052334707 + 6418.7011750014*t)
	X1 += 0.00000000038*np.cos(3.93290315553 + 490.3340891794*t)
	X1 += 0.00000000034*np.cos(1.97967478962 + 17271.8840075264*t)
	X1 += 0.00000000034*np.cos(5.54907603693 + 750.1036075334*t)
	X1 += 0.00000000037*np.cos(6.26293750649 + 635.9651330509*t)
	X1 += 0.00000000037*np.cos(6.05744777692 + 21150.8133658836*t)
	X1 += 0.00000000034*np.cos(1.90509484306 + 29026.48522950779*t)
	X1 += 0.00000000035*np.cos(3.20661690466 + 7322.1024607818*t)
	X1 += 0.00000000044*np.cos(2.79017179925 + 3981.490034082*t)
	X1 += 0.00000000034*np.cos(1.21719184072 + 21548.9623692918*t)
	X1 += 0.00000000033*np.cos(4.13127114332 + 173566.83743765688*t)
	X1 += 0.00000000038*np.cos(5.99103573925 + 483.2205421786*t)
	X1 += 0.00000000035*np.cos(4.68155089578 + 526.7702037878*t)
	X1 += 0.00000000033*np.cos(3.22867201822 + 30666.1549584328*t)
	X1 += 0.00000000034*np.cos(4.95128499531 + 38500.2760310722*t)
	X1 += 0.00000000035*np.cos(5.94254789616 + 532.6117264014*t)
	X1 += 0.00000000032*np.cos(4.38302389502 + 17686.7528455664*t)
	X1 += 0.00000000038*np.cos(4.95582614524 + 19004.6479494084*t)
	X1 += 0.00000000033*np.cos(1.70921741352 + 34520.3093093808*t)
	X1 += 0.00000000041*np.cos(4.09101902227 + 21202.093703746*t)
	X1 += 0.00000000031*np.cos(0.28544969417 + 22003.9146348698*t)
	X1 += 0.00000000037*np.cos(1.21597687953 + 7349.5713271814*t)
	X1 += 0.00000000031*np.cos(1.18565768932 + 447.9388318784*t)
	X1 += 0.00000000031*np.cos(0.19462514993 + 27832.0382192832*t)
	X1 += 0.00000000037*np.cos(3.41912843249 + 29296.6153895786*t)
	X1 += 0.00000000035*np.cos(2.69261244483 + 11919.140866668*t)
	X1 += 0.00000000035*np.cos(0.83074174405 + 29062.5130961852*t)
	X1 += 0.00000000030*np.cos(0.44298905817 + 209.106309744*t)
	X1 += 0.00000000030*np.cos(2.96012497927 + 12489.8856287072*t)
	X1 += 0.00000000030*np.cos(1.59264152747 + 92.940845832*t)
	X1 += 0.00000000035*np.cos(4.83736876925 + 21228.3920235458*t)
	X1 += 0.00000000030*np.cos(4.44526322933 + 217.491881132*t)
	X1 += 0.00000000032*np.cos(6.26164802166 + 6231.79551212899*t)
	X1 += 0.00000000032*np.cos(0.38688555099 + 6334.35618785381*t)
	X1 += 0.00000000035*np.cos(1.72609608211 + 265.9892934775*t)
	X1 += 0.00000000029*np.cos(0.70432070922 + 49515.382508407*t)
	X1 += 0.00000000032*np.cos(0.44788919628 + 31172.650645983*t)
	X1 += 0.00000000031*np.cos(2.69970301246 + 33019.0211122046*t)
	X1 += 0.00000000029*np.cos(2.26256470092 + 27278.4688164408*t)
	X1 += 0.00000000031*np.cos(3.19023486538 + 5017.508371365*t)
	X1 += 0.00000000028*np.cos(3.34466525843 + 80.1982245387*t)
	X1 += 0.00000000028*np.cos(1.87849143707 + 24080.03501677719*t)
	X1 += 0.00000000034*np.cos(0.78574341965 + 5905.7022420756*t)
	X1 += 0.00000000034*np.cos(5.86279015300 + 6660.4494579072*t)
	X1 += 0.00000000038*np.cos(5.12224209756 + 31570.7996493912*t)
	X1 += 0.00000000027*np.cos(4.35707854664 + 1279.794572628*t)
	X1 += 0.00000000031*np.cos(5.18940920282 + 424.1505103212*t)
	X1 += 0.00000000027*np.cos(3.76025315460 + 19402.7969528166*t)
	X1 += 0.00000000027*np.cos(0.53327304803 + 233141.31440436149*t)
	X1 += 0.00000000030*np.cos(2.32405719366 + 12586.9270954752*t)
	X1 += 0.00000000028*np.cos(5.54772804461 + 34911.412076091*t)
	X1 += 0.00000000027*np.cos(5.30079330746 + 43232.3066584156*t)
	X1 += 0.00000000033*np.cos(0.34449594524 + 269.9214467406*t)
	X1 += 0.00000000036*np.cos(4.81217077776 + 15664.03552270859*t)
	X1 += 0.00000000027*np.cos(0.65637418130 + 6360.7496204194*t)
	X1 += 0.00000000027*np.cos(5.99215939135 + 6205.4020795634*t)
	X1 += 0.00000000026*np.cos(3.42413737440 + 24383.0791084414*t)
	X1 += 0.00000000033*np.cos(3.45722382528 + 28628.3362260996*t)
	X1 += 0.00000000027*np.cos(4.81466818286 + 1802.3719907218*t)
	X1 += 0.00000000027*np.cos(2.32049228976 + 32367.0976562076*t)
	X1 += 0.00000000026*np.cos(1.98182489066 + 19804.8272915828*t)
	X1 += 0.00000000027*np.cos(1.77114813957 + 4487.8174062704*t)
	X1 += 0.00000000028*np.cos(2.89944615107 + 58953.145443294*t)
	X1 += 0.00000000028*np.cos(3.80331477821 + 10239.5838660108*t)
	X1 += 0.00000000026*np.cos(0.36912120822 + 6339.974224927*t)
	X1 += 0.00000000026*np.cos(6.27941236443 + 6226.1774750558*t)
	X1 += 0.00000000026*np.cos(6.01416870867 + 4797.0957289262*t)
	X1 += 0.00000000028*np.cos(2.80825729869 + 22476.73502749179*t)
	X1 += 0.00000000029*np.cos(0.17746825116 + 6592.3541726472*t)
	X1 += 0.00000000029*np.cos(0.18788001431 + 5973.7975273356*t)
	X1 += 0.00000000026*np.cos(3.93576097012 + 36949.2308084242*t)
	X1 += 0.00000000027*np.cos(5.82028492837 + 1898.3512179396*t)
	X1 += 0.00000000027*np.cos(0.64682460545 + 29424.634232916*t)
	X1 += 0.00000000026*np.cos(2.54059552040 + 9910.583327509*t)
	X1 += 0.00000000028*np.cos(2.41855003101 + 46386.9937433112*t)
	X1 += 0.00000000024*np.cos(1.22629501602 + 21947.11137270*t)
	X1 += 0.00000000024*np.cos(0.55027097678 + 11616.976091013*t)
	X1 += 0.00000000025*np.cos(2.78491065355 + 6302.74561089119*t)
	X1 += 0.00000000025*np.cos(3.86362291910 + 6263.4060890916*t)
	X1 += 0.00000000026*np.cos(4.44347824401 + 15110.4661198662*t)
	X1 += 0.00000000023*np.cos(1.56475852877 + 650.9429865779*t)
	X1 += 0.00000000028*np.cos(6.10918595816 + 18052.9295431578*t)
	X1 += 0.00000000023*np.cos(1.99242379288 + 30774.5016425748*t)
	X1 += 0.00000000024*np.cos(3.73458431258 + 31968.9486527994*t)
	X1 += 0.00000000023*np.cos(4.85605613315 + 35.685355083*t)
	X1 += 0.00000000023*np.cos(0.62347300029 + 17892.93839400359*t)
	X1 += 0.00000000024*np.cos(3.21260068222 + 23550.34405168259*t)
	X1 += 0.00000000023*np.cos(4.85338065767 + 28.5718080822*t)
	X1 += 0.00000000022*np.cos(0.71803323367 + 337.732510659*t)
	X1 += 0.00000000023*np.cos(1.36063534536 + 6716.7875878682*t)
	X1 += 0.00000000027*np.cos(0.02724821878 + 25158.6017197654*t)
	X1 += 0.00000000026*np.cos(3.57645528088 + 8584.6616659008*t)
	X1 += 0.00000000022*np.cos(3.99741791962 + 7445.5505543992*t)
	X1 += 0.00000000023*np.cos(0.11555144192 + 643.0786800517*t)
	X1 += 0.00000000022*np.cos(6.10694895695 + 15265.8865193004*t)
	X1 += 0.00000000023*np.cos(4.51155345742 + 284.1485407422*t)
	X1 += 0.00000000025*np.cos(0.81555419576 + 14155.2245952666*t)
	X1 += 0.00000000023*np.cos(3.06283945185 + 6272.0301497275*t)
	X1 += 0.00000000023*np.cos(3.58569412080 + 6294.1215502553*t)
	X1 += 0.00000000025*np.cos(2.44880076940 + 20199.094959633*t)
	X1 += 0.00000000023*np.cos(6.22294900930 + 191.2076949102*t)
	X1 += 0.00000000021*np.cos(5.78253540504 + 22779.4372461938*t)
	X1 += 0.00000000023*np.cos(2.25096306087 + 34115.1140692746*t)
	X1 += 0.00000000022*np.cos(4.67990936559 + 34596.3646546524*t)
	X1 += 0.00000000029*np.cos(0.93434607315 + 11933.3679606696*t)
	X1 += 0.00000000021*np.cos(0.34726135597 + 137.0330241624*t)
	X1 += 0.00000000021*np.cos(4.08577407328 + 30220.9322397324*t)
	X1 += 0.00000000021*np.cos(2.62420739411 + 40.5807161926*t)
	X1 += 0.00000000021*np.cos(3.37519693925 + 934.9485149682*t)
	X1 += 0.00000000021*np.cos(2.93989832001 + 525.4981794006*t)
	X1 += 0.00000000020*np.cos(0.47093224249 + 47162.5163546352*t)
	X1 += 0.00000000022*np.cos(1.38262024424 + 4379.6390374902*t)
	X1 += 0.00000000023*np.cos(4.92629143648 + 540.7366653585*t)
	X1 += 0.00000000020*np.cos(5.31355969163 + 40879.4405046438*t)
	X1 += 0.00000000023*np.cos(0.59531277141 + 1361.5467058442*t)
	X1 += 0.00000000022*np.cos(4.52226925108 + 28759.81087748319*t)
	X1 += 0.00000000026*np.cos(3.41054638032 + 18422.62935909819*t)
	X1 += 0.00000000025*np.cos(0.38304523465 + 96.8729990951*t)
	X1 += 0.00000000027*np.cos(0.67002293804 + 34513.2630726828*t)
	X1 += 0.00000000027*np.cos(6.21242304915 + 1905.4647649404*t)
	X1 += 0.00000000019*np.cos(4.78610064760 + 28313.288804661*t)
	X1 += 0.00000000020*np.cos(5.54734924390 + 251.4321310758*t)
	X1 += 0.00000000024*np.cos(4.91328411886 + 219.4494345923*t)
	X1 += 0.00000000020*np.cos(5.09152714894 + 8186.5126624926*t)
	X1 += 0.00000000025*np.cos(3.53211055104 + 55798.4583583984*t)
	X1 += 0.00000000025*np.cos(0.38024667868 + 9225.539273283*t)
	X1 += 0.00000000020*np.cos(1.71238700404 + 27433.88921587499*t)
	X1 += 0.00000000024*np.cos(1.20856889899 + 9411.4646150872*t)
	X1 += 0.00000000020*np.cos(1.65292451759 + 6379.0550772092*t)
	X1 += 0.00000000020*np.cos(4.99560905506 + 6187.0966227736*t)
	X1 += 0.00000000020*np.cos(2.94178503134 + 19800.9459562248*t)
	X1 += 0.00000000020*np.cos(4.32349571107 + 62883.3551395136*t)
	X1 += 0.00000000022*np.cos(4.44470422678 + 18326.65013188039*t)
	X1 += 0.00000000019*np.cos(4.37840329985 + 16207.886271502*t)
	X1 += 0.00000000022*np.cos(4.46505143635 + 6332.8328754632*t)
	X1 += 0.00000000022*np.cos(2.18348213630 + 6233.3188245196*t)
	X1 += 0.00000000019*np.cos(1.36569875427 + 23539.7073863328*t)
	X1 += 0.00000000020*np.cos(3.55117744188 + 81.8951455681*t)
	X1 += 0.00000000018*np.cos(4.61817062443 + 6593.9166488598*t)
	X1 += 0.00000000018*np.cos(2.03036294822 + 5972.235051123*t)
	X1 += 0.00000000019*np.cos(2.36455752682 + 5618.3198048614*t)
	X1 += 0.00000000019*np.cos(4.28397604583 + 6947.8318951214*t)
	X1 += 0.00000000019*np.cos(0.18461307728 + 83973.83535572988*t)
	X1 += 0.00000000019*np.cos(4.29574440213 + 84019.8592804939*t)
	X1 += 0.00000000020*np.cos(2.85390720284 + 9070.1188738488*t)
	X1 += 0.00000000021*np.cos(1.17914689008 + 344.7030453079*t)
	return X1*t




def Earth_X2 (t): # 349 terms of order 2

	X2 = 0.
	X2 -= 0.00004098432
	X2 += 0.00002175689*np.cos(4.39999849572 + 12566.1516999828*t)
	X2 += 0.00000995233*np.cos(0.20790847155 + 6283.0758499914*t)
	X2 += 0.00000160293*np.cos(4.40406062613 + 206.1855484372*t)
	X2 += 0.00000155633*np.cos(0.48183983171 + 220.4126424388*t)
	X2 += 0.00000118222*np.cos(0.99338493688 + 522.5774180938*t)
	X2 += 0.00000115842*np.cos(3.35337160144 + 536.8045120954*t)
	X2 += 0.00000092659*np.cos(4.19285471010 + 18849.2275499742*t)
	X2 += 0.00000096063*np.cos(5.56707571020 + 213.299095438*t)
	X2 += 0.00000065107*np.cos(5.63089478188 + 426.598190876*t)
	X2 += 0.00000074211*np.cos(2.15619420586 + 529.6909650946*t)
	X2 += 0.00000037796*np.cos(1.97621753751 + 1059.3819301892*t)
	X2 += 0.00000014232*np.cos(5.82837756444 + 433.7117378768*t)
	X2 += 0.00000013989*np.cos(1.76434060619 + 7.1135470008*t)
	X2 += 0.00000012711*np.cos(3.49149798770 + 419.4846438752*t)
	X2 += 0.00000013679*np.cos(3.37833642063 + 6286.5989683404*t)
	X2 += 0.00000013668*np.cos(3.27271492019 + 6279.5527316424*t)
	X2 += 0.00000009377*np.cos(4.71464439900 + 639.897286314*t)
	X2 += 0.00000008190*np.cos(4.41928022030 + 6256.7775301916*t)
	X2 += 0.00000008145*np.cos(2.22925093408 + 6309.3741697912*t)
	X2 += 0.00000008004*np.cos(5.92288197328 + 6127.6554505572*t)
	X2 += 0.00000007707*np.cos(0.35647823047 + 227.5261894396*t)
	X2 += 0.00000007746*np.cos(0.72469358509 + 6438.4962494256*t)
	X2 += 0.00000006797*np.cos(3.87383015136 + 1066.49547719*t)
	X2 += 0.00000008899*np.cos(5.38113427234 + 83996.84731811189*t)
	X2 += 0.00000005452*np.cos(0.48898137631 + 1052.2683831884*t)
	X2 += 0.00000005027*np.cos(1.12572622612 + 515.463871093*t)
	X2 += 0.00000003667*np.cos(4.56283602529 + 199.0720014364*t)
	X2 += 0.00000003523*np.cos(3.22103209546 + 543.9180590962*t)
	X2 += 0.00000003456*np.cos(2.36040843812 + 1589.0728952838*t)
	X2 += 0.00000004754*np.cos(6.16710003373 + 709.9330485583*t)
	X2 += 0.00000003737*np.cos(2.48724420764 + 5507.5532386674*t)
	X2 += 0.00000002893*np.cos(4.94972697460 + 4705.7323075436*t)
	X2 += 0.00000002937*np.cos(4.08160813245 + 25132.3033999656*t)
	X2 += 0.00000003203*np.cos(4.14275083744 + 7058.5984613154*t)
	X2 += 0.00000002254*np.cos(3.51957213521 + 775.522611324*t)
	X2 += 0.00000002170*np.cos(1.70495739017 + 7860.4193924392*t)
	X2 += 0.00000002031*np.cos(2.29363438970 + 6275.9623029906*t)
	X2 += 0.00000002031*np.cos(4.35489918295 + 6290.1893969922*t)
	X2 += 0.00000001904*np.cos(4.46668961834 + 5486.777843175*t)
	X2 += 0.00000001548*np.cos(2.12906745749 + 6040.3472460174*t)
	X2 += 0.00000001563*np.cos(2.18101487697 + 7079.3738568078*t)
	X2 += 0.00000001456*np.cos(3.53770823599 + 5753.3848848968*t)
	X2 += 0.00000001424*np.cos(3.16250984559 + 6812.766815086*t)
	X2 += 0.00000001470*np.cos(4.51659549398 + 6525.8044539654*t)
	X2 += 0.00000001429*np.cos(3.01998118552 + 5884.9268465832*t)
	X2 += 0.00000001347*np.cos(2.19024470415 + 316.3918696566*t)
	X2 += 0.00000001405*np.cos(6.22622304401 + 216.4804891757*t)
	X2 += 0.00000001320*np.cos(4.96541286159 + 647.0108333148*t)
	X2 += 0.00000001365*np.cos(4.95810524231 + 210.1177017003*t)
	X2 += 0.00000001281*np.cos(3.62939670157 + 6681.2248533996*t)
	X2 += 0.00000001687*np.cos(1.62553064962 + 14.2270940016*t)
	X2 += 0.00000001093*np.cos(4.21067890946 + 103.0927742186*t)
	X2 += 0.00000001338*np.cos(1.04445705185 + 5729.506447149*t)
	X2 += 0.00000000973*np.cos(4.02172041169 + 853.196381752*t)
	X2 += 0.00000001039*np.cos(5.85310113863 + 6282.0955289232*t)
	X2 += 0.00000001039*np.cos(0.79543243402 + 6284.0561710596*t)
	X2 += 0.00000001212*np.cos(5.61713170172 + 6836.6452528338*t)
	X2 += 0.00000000904*np.cos(2.43535199673 + 5331.3574437408*t)
	X2 += 0.00000000871*np.cos(3.84816000443 + 4933.2084403326*t)
	X2 += 0.00000000938*np.cos(4.40679265580 + 632.7837393132*t)
	X2 += 0.00000000879*np.cos(3.06133930098 + 11790.6290886588*t)
	X2 += 0.00000000848*np.cos(1.52469724284 + 526.5095713569*t)
	X2 += 0.00000001102*np.cos(4.59510736976 + 167283.76158766549*t)
	X2 += 0.00000000826*np.cos(2.81425975210 + 532.8723588323*t)
	X2 += 0.00000000769*np.cos(4.22812146942 + 7234.794256242*t)
	X2 += 0.00000000758*np.cos(0.02371551403 + 209.3669421749*t)
	X2 += 0.00000000733*np.cos(4.88186040762 + 217.2312487011*t)
	X2 += 0.00000000744*np.cos(0.34956564055 + 4136.9104335162*t)
	X2 += 0.00000000688*np.cos(5.79109380413 + 440.8252848776*t)
	X2 += 0.00000000939*np.cos(3.62288542048 + 11856.2186514245*t)
	X2 += 0.00000000675*np.cos(2.82587446878 + 7632.9432596502*t)
	X2 += 0.00000000654*np.cos(1.40322441961 + 11506.7697697936*t)
	X2 += 0.00000000854*np.cos(5.24328642976 + 4535.0594369244*t)
	X2 += 0.00000000665*np.cos(4.81749499447 + 1194.4470102246*t)
	X2 += 0.00000000834*np.cos(5.75118975782 + 155.4203994342*t)
	X2 += 0.00000000603*np.cos(5.14215709084 + 323.5054166574*t)
	X2 += 0.00000000624*np.cos(0.96146126905 + 117.3198682202*t)
	X2 += 0.00000000785*np.cos(5.88776299473 + 5088.6288397668*t)
	X2 += 0.00000000549*np.cos(4.81966003612 + 949.1756089698*t)
	X2 += 0.00000000702*np.cos(0.69460527884 + 74.7815985673*t)
	X2 += 0.00000000548*np.cos(6.12128965864 + 796.2980068164*t)
	X2 += 0.00000000546*np.cos(0.01597529774 + 1045.1548361876*t)
	X2 += 0.00000000686*np.cos(1.90135823927 + 801.8209311238*t)
	X2 += 0.00000000507*np.cos(5.42408029291 + 4694.0029547076*t)
	X2 += 0.00000000499*np.cos(2.95394998140 + 110.2063212194*t)
	X2 += 0.00000000510*np.cos(2.48615954177 + 95.9792272178*t)
	X2 += 0.00000000604*np.cos(6.00696167862 + 735.8765135318*t)
	X2 += 0.00000000677*np.cos(2.71965226391 + 3128.3887650958*t)
	X2 += 0.00000000499*np.cos(3.02752235850 + 12569.6748183318*t)
	X2 += 0.00000000490*np.cos(2.82889535700 + 525.7588118315*t)
	X2 += 0.00000000488*np.cos(1.51375734651 + 533.6231183577*t)
	X2 += 0.00000000480*np.cos(0.01327044252 + 8429.2412664666*t)
	X2 += 0.00000000592*np.cos(1.39433962245 + 8031.0922630584*t)
	X2 += 0.00000000438*np.cos(4.38613869498 + 1596.1864422846*t)
	X2 += 0.00000000519*np.cos(6.10806295653 + 149.5631971346*t)
	X2 += 0.00000000562*np.cos(0.77105088912 + 7477.522860216*t)
	X2 += 0.00000000415*np.cos(0.00558962450 + 6069.7767545534*t)
	X2 += 0.00000000415*np.cos(0.35131226280 + 6496.3749454294*t)
	X2 += 0.00000000402*np.cos(1.72177128440 + 3738.761430108*t)
	X2 += 0.00000000503*np.cos(3.41456622371 + 1592.5960136328*t)
	X2 += 0.00000000390*np.cos(5.36711219721 + 26.2983197998*t)
	X2 += 0.00000000372*np.cos(4.35153585802 + 553.5694028424*t)
	X2 += 0.00000000458*np.cos(0.85618925594 + 156137.47598479928*t)
	X2 += 0.00000000325*np.cos(2.94948293011 + 951.7184062506*t)
	X2 += 0.00000000321*np.cos(2.01798251637 + 1990.745017041*t)
	X2 += 0.00000000335*np.cos(1.12608331535 + 4690.4798363586*t)
	X2 += 0.00000000366*np.cos(0.10449761483 + 12721.572099417*t)
	X2 += 0.00000000287*np.cos(2.26476426223 + 242.728603974*t)
	X2 += 0.00000000347*np.cos(1.34248948630 + 5481.2549188676*t)
	X2 += 0.00000000368*np.cos(3.91910931412 + 9437.762934887*t)
	X2 += 0.00000000353*np.cos(5.67450059858 + 63.7358983034*t)
	X2 += 0.00000000289*np.cos(2.73071540241 + 2118.7638603784*t)
	X2 += 0.00000000267*np.cos(6.09793545646 + 625.6701923124*t)
	X2 += 0.00000000270*np.cos(0.56801609869 + 1581.959348283*t)
	X2 += 0.00000000335*np.cos(3.28599535784 + 412.3710968744*t)
	X2 += 0.00000000255*np.cos(1.83876117314 + 11371.7046897582*t)
	X2 += 0.00000000242*np.cos(4.92327001310 + 8827.3902698748*t)
	X2 += 0.00000000307*np.cos(1.56817330160 + 1349.8674096588*t)
	X2 += 0.00000000230*np.cos(1.62446688541 + 70.8494453042*t)
	X2 += 0.00000000226*np.cos(0.21648774887 + 234.6397364404*t)
	X2 += 0.00000000242*np.cos(0.12263961387 + 1748.016413067*t)
	X2 += 0.00000000222*np.cos(4.88851960168 + 4164.311989613*t)
	X2 += 0.00000000257*np.cos(0.55141837710 + 956.2891559706*t)
	X2 += 0.00000000230*np.cos(1.05870192923 + 3154.6870848956*t)
	X2 += 0.00000000218*np.cos(6.18732888250 + 78.7137518304*t)
	X2 += 0.00000000216*np.cos(0.69406612425 + 11.0457002639*t)
	X2 += 0.00000000283*np.cos(2.17198423111 + 85.8272988312*t)
	X2 += 0.00000000210*np.cos(4.87169565788 + 942.062061969*t)
	X2 += 0.00000000204*np.cos(0.44240387853 + 11769.8536931664*t)
	X2 += 0.00000000227*np.cos(5.26494518266 + 73.297125859*t)
	X2 += 0.00000000235*np.cos(1.88541486477 + 36.6485629295*t)
	X2 += 0.00000000188*np.cos(5.65888993470 + 7875.6718636242*t)
	X2 += 0.00000000224*np.cos(5.59487510601 + 39.6175083461*t)
	X2 += 0.00000000189*np.cos(0.61654841817 + 2388.8940204492*t)
	X2 += 0.00000000233*np.cos(5.23023625373 + 7084.8967811152*t)
	X2 += 0.00000000228*np.cos(4.22772621951 + 202.2533951741*t)
	X2 += 0.00000000183*np.cos(4.10128236867 + 7342.4577801806*t)
	X2 += 0.00000000187*np.cos(2.86279402460 + 1169.5882514086*t)
	X2 += 0.00000000167*np.cos(3.64468986986 + 1073.6090241908*t)
	X2 += 0.00000000195*np.cos(0.93545523133 + 224.3447957019*t)
	X2 += 0.00000000173*np.cos(0.52511015365 + 10977.078804699*t)
	X2 += 0.00000000159*np.cos(2.72294432534 + 4292.3308329504*t)
	X2 += 0.00000000207*np.cos(2.28587256917 + 13367.9726311066*t)
	X2 += 0.00000000202*np.cos(3.21445201981 + 10973.55568635*t)
	X2 += 0.00000000158*np.cos(0.41813276311 + 1155.361157407*t)
	X2 += 0.00000000141*np.cos(2.05881354566 + 742.9900605326*t)
	X2 += 0.00000000145*np.cos(5.45882589245 + 398.1490034082*t)
	X2 += 0.00000000135*np.cos(0.93601004324 + 138.5174968707*t)
	X2 += 0.00000000149*np.cos(3.11048959872 + 76.2660712756*t)
	X2 += 0.00000000155*np.cos(5.81412827494 + 12410.7313005486*t)
	X2 += 0.00000000133*np.cos(1.27948900541 + 508.3503240922*t)
	X2 += 0.00000000134*np.cos(4.56296979111 + 10575.4066829418*t)
	X2 += 0.00000000145*np.cos(4.08945624026 + 309.2783226558*t)
	X2 += 0.00000000126*np.cos(5.33539657707 + 330.6189636582*t)
	X2 += 0.00000000127*np.cos(4.84612567560 + 13119.72110282519*t)
	X2 += 0.00000000126*np.cos(4.18511285279 + 860.3099287528*t)
	X2 += 0.00000000160*np.cos(3.76409728390 + 38.1330356378*t)
	X2 += 0.00000000115*np.cos(4.96539448045 + 2146.1654164752*t)
	X2 += 0.00000000125*np.cos(3.87814283336 + 12562.6285816338*t)
	X2 += 0.00000000125*np.cos(0.17913722961 + 8635.9420037632*t)
	X2 += 0.00000000122*np.cos(1.05019176110 + 12592.4500197826*t)
	X2 += 0.00000000111*np.cos(2.15765835240 + 1577.3435424478*t)
	X2 += 0.00000000134*np.cos(6.25201667258 + 3930.2096962196*t)
	X2 += 0.00000000107*np.cos(3.43601884429 + 13517.8701062334*t)
	X2 += 0.00000000115*np.cos(6.09545736763 + 223.5940361765*t)
	X2 += 0.00000000110*np.cos(0.21868987814 + 71.6002048296*t)
	X2 += 0.00000000115*np.cos(5.33896891891 + 429.7795846137*t)
	X2 += 0.00000000105*np.cos(1.31705960331 + 77.962992305*t)
	X2 += 0.00000000102*np.cos(4.37125144267 + 10988.808157535*t)
	X2 += 0.00000000095*np.cos(5.98656941724 + 17260.1546546904*t)
	X2 += 0.00000000127*np.cos(6.12277131240 + 728.762966531*t)
	X2 += 0.00000000106*np.cos(1.49565452639 + 1162.4747044078*t)
	X2 += 0.00000000100*np.cos(2.34969093002 + 13095.8426650774*t)
	X2 += 0.00000000110*np.cos(3.63768958070 + 5223.6939198022*t)
	X2 += 0.00000000102*np.cos(5.20836098548 + 422.6660376129*t)
	X2 += 0.00000000085*np.cos(4.32512089859 + 3894.1818295422*t)
	X2 += 0.00000000109*np.cos(3.99726753431 + 12539.853380183*t)
	X2 += 0.00000000084*np.cos(0.06183751259 + 124.433415221*t)
	X2 += 0.00000000079*np.cos(5.22586609526 + 16730.4636895958*t)
	X2 += 0.00000000079*np.cos(0.08497701397 + 10447.3878396044*t)
	X2 += 0.00000000076*np.cos(4.11846374330 + 12323.4230960088*t)
	X2 += 0.00000000105*np.cos(3.53845510796 + 5642.1982426092*t)
	X2 += 0.00000000075*np.cos(5.73067319226 + 6709.6740408674*t)
	X2 += 0.00000000075*np.cos(0.91786038039 + 5856.4776591154*t)
	X2 += 0.00000000082*np.cos(5.90914298142 + 10177.2576795336*t)
	X2 += 0.00000000074*np.cos(1.07138930276 + 1265.5674786264*t)
	X2 += 0.00000000076*np.cos(4.22098650571 + 423.4167971383*t)
	X2 += 0.00000000100*np.cos(0.66749297482 + 250570.67585721909*t)
	X2 += 0.00000000071*np.cos(3.05925118734 + 551.031606097*t)
	X2 += 0.00000000082*np.cos(1.68324374227 + 519.3960243561*t)
	X2 += 0.00000000071*np.cos(0.59970099558 + 14314.1681130498*t)
	X2 += 0.00000000068*np.cos(4.96510846230 + 654.1243803156*t)
	X2 += 0.00000000092*np.cos(1.98240564470 + 13916.0191096416*t)
	X2 += 0.00000000091*np.cos(3.10960444681 + 6923.9534573736*t)
	X2 += 0.00000000066*np.cos(2.46864705656 + 88.865680217*t)
	X2 += 0.00000000082*np.cos(4.00218490582 + 31415.379249957*t)
	X2 += 0.00000000083*np.cos(5.97854162397 + 95143.1329209781*t)
	X2 += 0.00000000073*np.cos(1.49901280909 + 21.3406410024*t)
	X2 += 0.00000000061*np.cos(4.23984291228 + 8273.8208670324*t)
	X2 += 0.00000000058*np.cos(4.77256654994 + 191.9584544356*t)
	X2 += 0.00000000064*np.cos(0.59210224706 + 838.9692877504*t)
	X2 += 0.00000000055*np.cos(1.41429091428 + 5643.1785636774*t)
	X2 += 0.00000000064*np.cos(2.62531230776 + 539.9859058331*t)
	X2 += 0.00000000054*np.cos(5.63153101737 + 16496.3613962024*t)
	X2 += 0.00000000064*np.cos(5.15957430521 + 203.0041546995*t)
	X2 += 0.00000000075*np.cos(5.01329496789 + 71430.69561812909*t)
	X2 += 0.00000000055*np.cos(3.83548544187 + 13341.6743113068*t)
	X2 += 0.00000000052*np.cos(4.39839251424 + 3634.6210245184*t)
	X2 += 0.00000000056*np.cos(1.31106242697 + 15720.8387848784*t)
	X2 += 0.00000000050*np.cos(4.18716262207 + 12573.2652469836*t)
	X2 += 0.00000000064*np.cos(3.35781526441 + 4732.0306273434*t)
	X2 += 0.00000000066*np.cos(5.49585898905 + 2787.0430238574*t)
	X2 += 0.00000000048*np.cos(2.02353005537 + 13362.4497067992*t)
	X2 += 0.00000000049*np.cos(2.48296676043 + 14143.4952424306*t)
	X2 += 0.00000000053*np.cos(4.12375134867 + 14919.0178537546*t)
	X2 += 0.00000000047*np.cos(3.82959048333 + 12964.300703391*t)
	X2 += 0.00000000045*np.cos(4.29961594202 + 846.0828347512*t)
	X2 += 0.00000000046*np.cos(3.88547191366 + 145.6310438715*t)
	X2 += 0.00000000042*np.cos(0.38069707842 + 24072.9214697764*t)
	X2 += 0.00000000047*np.cos(3.31818308830 + 1062.5633239269*t)
	X2 += 0.00000000051*np.cos(1.26573618407 + 6195.76764545159*t)
	X2 += 0.00000000051*np.cos(5.38279738858 + 6370.3840545312*t)
	X2 += 0.00000000041*np.cos(2.49731951011 + 18319.5365848796*t)
	X2 += 0.00000000041*np.cos(4.09328168773 + 3185.1920272656*t)
	X2 += 0.00000000056*np.cos(1.01626259839 + 84672.47584450469*t)
	X2 += 0.00000000038*np.cos(1.25489937051 + 1258.4539316256*t)
	X2 += 0.00000000039*np.cos(4.27641929836 + 20426.571092422*t)
	X2 += 0.00000000053*np.cos(3.21190793912 + 239424.39025435288*t)
	X2 += 0.00000000040*np.cos(6.05039617409 + 3496.032826134*t)
	X2 += 0.00000000035*np.cos(1.55855229745 + 1692.1656695024*t)
	X2 += 0.00000000036*np.cos(0.59325228587 + 10213.285546211*t)
	X2 += 0.00000000044*np.cos(1.67103342381 + 8662.240323563*t)
	X2 += 0.00000000036*np.cos(5.46623211848 + 302.164775655*t)
	X2 += 0.00000000034*np.cos(5.64744481308 + 277.0349937414*t)
	X2 += 0.00000000043*np.cos(3.69693055127 + 18139.2945014159*t)
	X2 += 0.00000000035*np.cos(3.60804630271 + 18875.525869774*t)
	X2 += 0.00000000035*np.cos(6.09077128153 + 10419.9862835076*t)
	X2 += 0.00000000031*np.cos(0.64652215197 + 23013.5395395872*t)
	X2 += 0.00000000035*np.cos(0.91150627653 + 9779.1086761254*t)
	X2 += 0.00000000030*np.cos(4.86335561218 + 2125.8774073792*t)
	X2 += 0.00000000035*np.cos(1.25631519996 + 1056.2005364515*t)
	X2 += 0.00000000030*np.cos(4.39715700541 + 12808.8803039568*t)
	X2 += 0.00000000042*np.cos(5.61217219717 + 82576.98122099529*t)
	X2 += 0.00000000031*np.cos(5.53053428232 + 14712.317116458*t)
	X2 += 0.00000000041*np.cos(5.62875780162 + 17789.845619785*t)
	X2 += 0.00000000031*np.cos(0.76672410297 + 22779.4372461938*t)
	X2 += 0.00000000039*np.cos(0.20293002946 + 1574.8458012822*t)
	X2 += 0.00000000028*np.cos(2.34481351815 + 5429.8794682394*t)
	X2 += 0.00000000027*np.cos(4.68961132588 + 16200.7727245012*t)
	X2 += 0.00000000036*np.cos(0.12982829645 + 437.6438911399*t)
	X2 += 0.00000000031*np.cos(3.39518273216 + 1272.6810256272*t)
	X2 += 0.00000000027*np.cos(3.47340764254 + 1055.4497769261*t)
	X2 += 0.00000000029*np.cos(1.32325847141 + 618.5566453116*t)
	X2 += 0.00000000028*np.cos(3.91086715449 + 11015.1064773348*t)
	X2 += 0.00000000026*np.cos(2.29393980670 + 9623.6882766912*t)
	X2 += 0.00000000026*np.cos(4.35459376595 + 2942.4634232916*t)
	X2 += 0.00000000028*np.cos(6.24637219690 + 1038.0412891868*t)
	X2 += 0.00000000027*np.cos(0.82567085480 + 415.5524906121*t)
	X2 += 0.00000000026*np.cos(1.75234208326 + 18209.33026366019*t)
	X2 += 0.00000000025*np.cos(6.04606961258 + 9917.6968745098*t)
	X2 += 0.00000000028*np.cos(1.64332966541 + 1485.9801210652*t)
	X2 += 0.00000000025*np.cos(2.68813215214 + 3583.3410306738*t)
	X2 += 0.00000000026*np.cos(5.05893496491 + 430.5303441391*t)
	X2 += 0.00000000024*np.cos(3.54369543262 + 18.1592472647*t)
	X2 += 0.00000000024*np.cos(0.77717557683 + 831.8557407496*t)
	X2 += 0.00000000026*np.cos(0.90493478768 + 12012.5822971404*t)
	X2 += 0.00000000023*np.cos(2.29788589227 + 9380.9596727172*t)
	X2 += 0.00000000023*np.cos(1.45497436681 + 231.4583427027*t)
	X2 += 0.00000000023*np.cos(2.49168005831 + 12559.038152982*t)
	X2 += 0.00000000023*np.cos(2.26727226510 + 26709.6469424134*t)
	X2 += 0.00000000025*np.cos(2.24207971146 + 1368.660252845*t)
	X2 += 0.00000000024*np.cos(3.24916661957 + 2648.454825473*t)
	X2 += 0.00000000021*np.cos(5.72791145125 + 447.9388318784*t)
	X2 += 0.00000000024*np.cos(4.92046069591 + 77713.7714681205*t)
	X2 += 0.00000000022*np.cos(5.99172814093 + 6993.0088985497*t)
	X2 += 0.00000000021*np.cos(2.38334945179 + 17256.6315363414*t)
	X2 += 0.00000000020*np.cos(0.71402000433 + 3.1813937377*t)
	X2 += 0.00000000022*np.cos(5.33490739950 + 151.0476698429*t)
	X2 += 0.00000000019*np.cos(1.74528256840 + 1063.3140834523*t)
	X2 += 0.00000000023*np.cos(0.80841468126 + 149854.40013480789*t)
	X2 += 0.00000000026*np.cos(3.19870156016 + 84334.66158130829*t)
	X2 += 0.00000000020*np.cos(3.40302634906 + 1699.2792165032*t)
	X2 += 0.00000000020*np.cos(2.53484218621 + 35.1640902212*t)
	X2 += 0.00000000018*np.cos(1.08092680576 + 10.2949407385*t)
	X2 += 0.00000000023*np.cos(2.53410224481 + 19651.048481098*t)
	X2 += 0.00000000021*np.cos(0.04948675860 + 72.3339180125*t)
	X2 += 0.00000000019*np.cos(1.93058658449 + 11926.2544136688*t)
	X2 += 0.00000000018*np.cos(2.28255799994 + 11614.4332937322*t)
	X2 += 0.00000000019*np.cos(3.66100662326 + 30639.856638633*t)
	X2 += 0.00000000022*np.cos(3.76382094449 + 17298.1823273262*t)
	X2 += 0.00000000019*np.cos(5.39096925285 + 16460.33352952499*t)
	X2 += 0.00000000018*np.cos(4.11934903377 + 3.9321532631*t)
	X2 += 0.00000000023*np.cos(4.78353231767 + 72850.56171524568*t)
	X2 += 0.00000000018*np.cos(3.19936496001 + 18073.7049386502*t)
	X2 += 0.00000000018*np.cos(5.63577174804 + 1471.7530270636*t)
	X2 += 0.00000000016*np.cos(2.13005908431 + 22.0914005278*t)
	X2 += 0.00000000017*np.cos(3.95703025000 + 8982.810669309*t)
	X2 += 0.00000000016*np.cos(5.22446000797 + 1478.8665740644*t)
	X2 += 0.00000000021*np.cos(3.77368081700 + 16858.4825329332*t)
	X2 += 0.00000000017*np.cos(2.07219008042 + 77.7505439839*t)
	X2 += 0.00000000021*np.cos(4.47047819380 + 12036.4607348882*t)
	X2 += 0.00000000015*np.cos(0.65562803693 + 16062.1845261168*t)
	X2 += 0.00000000015*np.cos(4.85349684848 + 1375.7737998458*t)
	X2 += 0.00000000016*np.cos(4.95896524219 + 41.1019810544*t)
	X2 += 0.00000000015*np.cos(5.03114029381 + 160.6088973985*t)
	X2 += 0.00000000014*np.cos(4.12927933278 + 2352.8661537718*t)
	X2 += 0.00000000015*np.cos(4.21849500083 + 20199.094959633*t)
	X2 += 0.00000000014*np.cos(0.15947511180 + 22483.84857449259*t)
	X2 += 0.00000000019*np.cos(2.81419648175 + 8671.9698704406*t)
	X2 += 0.00000000014*np.cos(0.47915039682 + 195.1398481733*t)
	X2 += 0.00000000016*np.cos(2.16860864742 + 56.6223513026*t)
	X2 += 0.00000000017*np.cos(1.59080059391 + 77.2292791221*t)
	X2 += 0.00000000014*np.cos(5.69583373076 + 71.8126531507*t)
	X2 += 0.00000000014*np.cos(1.26341547558 + 90279.92316810328*t)
	X2 += 0.00000000015*np.cos(3.19537134319 + 65.2203710117*t)
	X2 += 0.00000000016*np.cos(0.41160329502 + 23543.23050468179*t)
	X2 += 0.00000000012*np.cos(2.70990889006 + 17996.0311682222*t)
	X2 += 0.00000000012*np.cos(0.72222975090 + 19402.7969528166*t)
	X2 += 0.00000000012*np.cos(5.17033303670 + 337.732510659*t)
	X2 += 0.00000000013*np.cos(3.64691089977 + 131.4039498699*t)
	X2 += 0.00000000012*np.cos(4.37880728616 + 10818.1352869158*t)
	X2 += 0.00000000015*np.cos(0.57625721169 + 12567.132021051*t)
	X2 += 0.00000000013*np.cos(3.14880532464 + 408.4389436113*t)
	X2 += 0.00000000011*np.cos(1.78472830783 + 28766.924424484*t)
	X2 += 0.00000000013*np.cos(3.18567583228 + 5573.1428014331*t)
	X2 += 0.00000000012*np.cos(4.22650218163 + 963.4027029714*t)
	X2 += 0.00000000011*np.cos(4.93327896664 + 18451.07854656599*t)
	X2 += 0.00000000011*np.cos(0.02603069623 + 511.5317178299*t)
	X2 += 0.00000000011*np.cos(5.43587992260 + 14945.3161735544*t)
	X2 += 0.00000000010*np.cos(4.31465510142 + 547.8502123593*t)
	X2 += 0.00000000011*np.cos(2.24607508630 + 35371.8872659764*t)
	X2 += 0.00000000011*np.cos(5.02228901732 + 22805.7355659936*t)
	X2 += 0.00000000013*np.cos(0.73737685844 + 2111.6503133776*t)
	X2 += 0.00000000010*np.cos(2.16930383321 + 15664.03552270859*t)
	X2 += 0.00000000014*np.cos(1.93314444705 + 21228.3920235458*t)
	X2 += 0.00000000010*np.cos(6.05310595892 + 23141.5583829246*t)
	X2 += 0.00000000010*np.cos(4.67908297368 + 362.8622925726*t)
	X2 += 0.00000000010*np.cos(5.60218831936 + 127.4717966068*t)
	X2 += 0.00000000012*np.cos(0.78764611551 + 1685.0521225016*t)
	X2 += 0.00000000010*np.cos(2.55645282698 + 22345.2603761082*t)
	X2 += 0.00000000009*np.cos(1.49155179482 + 29826.3063546732*t)
	X2 += 0.00000000010*np.cos(0.18358815992 + 12779.4507954208*t)
	X2 += 0.00000000013*np.cos(4.91836873304 + 84.3428261229*t)
	X2 += 0.00000000011*np.cos(4.05473090705 + 23581.2581773176*t)
	X2 += 0.00000000010*np.cos(5.07263788261 + 934.9485149682*t)
	X2 += 0.00000000011*np.cos(0.39656469738 + 25158.6017197654*t)
	X2 += 0.00000000012*np.cos(2.66109784913 + 148.0787244263*t)
	X2 += 0.00000000009*np.cos(2.44042399381 + 153.4953503977*t)
	return X2*t*t




def Earth_X3 (t): # 112 terms of order 3

	X3 = 0.
	X3 -= 0.00000173206
	X3 += 0.00000072337*np.cos(2.89303952476 + 12566.1516999828*t)
	X3 += 0.00000022035*np.cos(6.11822426048 + 206.1855484372*t)
	X3 += 0.00000021482*np.cos(5.03368299703 + 220.4126424388*t)
	X3 += 0.00000016291*np.cos(2.71940457791 + 522.5774180938*t)
	X3 += 0.00000015934*np.cos(1.63320186413 + 536.8045120954*t)
	X3 += 0.00000008364*np.cos(3.85500954096 + 6283.0758499914*t)
	X3 += 0.00000005040*np.cos(2.53152989786 + 18849.2275499742*t)
	X3 += 0.00000003063*np.cos(3.80201225520 + 426.598190876*t)
	X3 += 0.00000002563*np.cos(4.04702837579 + 433.7117378768*t)
	X3 += 0.00000002101*np.cos(4.92786996750 + 227.5261894396*t)
	X3 += 0.00000001706*np.cos(0.42316599671 + 1059.3819301892*t)
	X3 += 0.00000001481*np.cos(2.23672235234 + 6438.4962494256*t)
	X3 += 0.00000001481*np.cos(4.41181122031 + 6127.6554505572*t)
	X3 += 0.00000001375*np.cos(2.83821817426 + 515.463871093*t)
	X3 += 0.00000001266*np.cos(5.37509106080 + 419.4846438752*t)
	X3 += 0.00000001038*np.cos(2.26994057258 + 1066.49547719*t)
	X3 += 0.00000001000*np.cos(6.26567671131 + 199.0720014364*t)
	X3 += 0.00000000964*np.cos(1.50782014667 + 543.9180590962*t)
	X3 += 0.00000001275*np.cos(0.02482955002 + 7.1135470008*t)
	X3 += 0.00000000845*np.cos(2.83708264275 + 639.897286314*t)
	X3 += 0.00000000678*np.cos(2.36507413871 + 1052.2683831884*t)
	X3 += 0.00000000644*np.cos(4.88567904780 + 6279.5527316424*t)
	X3 += 0.00000000644*np.cos(1.76285452485 + 6286.5989683404*t)
	X3 += 0.00000000344*np.cos(1.24961127281 + 213.299095438*t)
	X3 += 0.00000000382*np.cos(6.20559320688 + 14.2270940016*t)
	X3 += 0.00000000318*np.cos(3.63840310183 + 6040.3472460174*t)
	X3 += 0.00000000318*np.cos(3.01013047082 + 6525.8044539654*t)
	X3 += 0.00000000291*np.cos(3.14472957178 + 647.0108333148*t)
	X3 += 0.00000000249*np.cos(1.14107482666 + 1589.0728952838*t)
	X3 += 0.00000000214*np.cos(4.03956747124 + 440.8252848776*t)
	X3 += 0.00000000230*np.cos(4.42377888159 + 216.4804891757*t)
	X3 += 0.00000000219*np.cos(0.47150010549 + 210.1177017003*t)
	X3 += 0.00000000220*np.cos(2.34166945312 + 25132.3033999656*t)
	X3 += 0.00000000201*np.cos(0.82714760810 + 6836.6452528338*t)
	X3 += 0.00000000201*np.cos(5.82138596455 + 5729.506447149*t)
	X3 += 0.00000000129*np.cos(1.79919042809 + 1045.1548361876*t)
	X3 += 0.00000000123*np.cos(2.08253199617 + 853.196381752*t)
	X3 += 0.00000000092*np.cos(4.79503944157 + 234.6397364404*t)
	X3 += 0.00000000086*np.cos(6.10758245301 + 103.0927742186*t)
	X3 += 0.00000000091*np.cos(5.48002372488 + 117.3198682202*t)
	X3 += 0.00000000093*np.cos(5.08172811528 + 529.6909650946*t)
	X3 += 0.00000000075*np.cos(2.87101566525 + 1596.1864422846*t)
	X3 += 0.00000000069*np.cos(4.27897139677 + 95.9792272178*t)
	X3 += 0.00000000073*np.cos(6.02905465950 + 632.7837393132*t)
	X3 += 0.00000000077*np.cos(5.03142217150 + 412.3710968744*t)
	X3 += 0.00000000064*np.cos(3.94993325790 + 316.3918696566*t)
	X3 += 0.00000000056*np.cos(2.99558443348 + 508.3503240922*t)
	X3 += 0.00000000055*np.cos(3.29709092103 + 323.5054166574*t)
	X3 += 0.00000000048*np.cos(1.97191764285 + 1073.6090241908*t)
	X3 += 0.00000000056*np.cos(1.48325794833 + 735.8765135318*t)
	X3 += 0.00000000042*np.cos(1.41375480258 + 625.6701923124*t)
	X3 += 0.00000000039*np.cos(0.30611138474 + 942.062061969*t)
	X3 += 0.00000000036*np.cos(1.41202770454 + 12569.6748183318*t)
	X3 += 0.00000000036*np.cos(4.59308117276 + 209.3669421749*t)
	X3 += 0.00000000031*np.cos(2.46171091539 + 1581.959348283*t)
	X3 += 0.00000000031*np.cos(1.32072373030 + 551.031606097*t)
	X3 += 0.00000000032*np.cos(0.26519734656 + 217.2312487011*t)
	X3 += 0.00000000033*np.cos(2.32289510783 + 860.3099287528*t)
	X3 += 0.00000000033*np.cos(4.23554585611 + 12410.7313005486*t)
	X3 += 0.00000000028*np.cos(3.48885797103 + 330.6189636582*t)
	X3 += 0.00000000027*np.cos(3.92096513265 + 149.5631971346*t)
	X3 += 0.00000000029*np.cos(6.05526972992 + 70.8494453042*t)
	X3 += 0.00000000027*np.cos(1.63715408955 + 2118.7638603784*t)
	X3 += 0.00000000028*np.cos(1.74838965252 + 78.7137518304*t)
	X3 += 0.00000000029*np.cos(0.48147029137 + 949.1756089698*t)
	X3 += 0.00000000025*np.cos(4.58797131637 + 124.433415221*t)
	X3 += 0.00000000033*np.cos(4.30649710462 + 223.5940361765*t)
	X3 += 0.00000000032*np.cos(1.93089098387 + 110.2063212194*t)
	X3 += 0.00000000027*np.cos(6.02243954440 + 21.3406410024*t)
	X3 += 0.00000000025*np.cos(1.16107900100 + 1169.5882514086*t)
	X3 += 0.00000000024*np.cos(1.53395713354 + 63.7358983034*t)
	X3 += 0.00000000028*np.cos(1.56238914694 + 728.762966531*t)
	X3 += 0.00000000024*np.cos(3.16134826622 + 654.1243803156*t)
	X3 += 0.00000000023*np.cos(0.20728622886 + 191.9584544356*t)
	X3 += 0.00000000022*np.cos(2.15937343363 + 1155.361157407*t)
	X3 += 0.00000000019*np.cos(0.03186061495 + 85.8272988312*t)
	X3 += 0.00000000019*np.cos(0.95260076413 + 73.297125859*t)
	X3 += 0.00000000022*np.cos(5.27304712373 + 956.2891559706*t)
	X3 += 0.00000000018*np.cos(2.32709487755 + 12721.572099417*t)
	X3 += 0.00000000024*np.cos(5.89117970906 + 309.2783226558*t)
	X3 += 0.00000000025*np.cos(3.51115533622 + 429.7795846137*t)
	X3 += 0.00000000024*np.cos(3.53027023690 + 519.3960243561*t)
	X3 += 0.00000000020*np.cos(1.86650914141 + 71.6002048296*t)
	X3 += 0.00000000017*np.cos(4.13765972175 + 88.865680217*t)
	X3 += 0.00000000019*np.cos(5.95485140431 + 77.962992305*t)
	X3 += 0.00000000016*np.cos(0.00550329231 + 202.2533951741*t)
	X3 += 0.00000000020*np.cos(0.77024887951 + 539.9859058331*t)
	X3 += 0.00000000015*np.cos(5.02720184968 + 224.3447957019*t)
	X3 += 0.00000000013*np.cos(0.64071359315 + 76.2660712756*t)
	X3 += 0.00000000016*np.cos(0.70623098744 + 203.0041546995*t)
	X3 += 0.00000000012*np.cos(0.84507236712 + 302.164775655*t)
	X3 += 0.00000000010*np.cos(5.28489326618 + 11.0457002639*t)
	X3 += 0.00000000010*np.cos(3.98008913039 + 36.6485629295*t)
	X3 += 0.00000000012*np.cos(3.35651610375 + 422.6660376129*t)
	X3 += 0.00000000009*np.cos(3.50226842635 + 39.6175083461*t)
	X3 += 0.00000000009*np.cos(1.66650203128 + 1038.0412891868*t)
	X3 += 0.00000000009*np.cos(3.97946790815 + 447.9388318784*t)
	X3 += 0.00000000011*np.cos(6.27313981891 + 12592.4500197826*t)
	X3 += 0.00000000009*np.cos(3.09433206743 + 618.5566453116*t)
	X3 += 0.00000000008*np.cos(2.36406802666 + 838.9692877504*t)
	X3 += 0.00000000008*np.cos(0.38739265309 + 423.4167971383*t)
	X3 += 0.00000000009*np.cos(1.90795498674 + 1574.8458012822*t)
	X3 += 0.00000000007*np.cos(2.99983273700 + 1258.4539316256*t)
	X3 += 0.00000000007*np.cos(2.49966387854 + 831.8557407496*t)
	X3 += 0.00000000008*np.cos(3.95391486424 + 74.7815985673*t)
	X3 += 0.00000000006*np.cos(2.56028859854 + 242.728603974*t)
	X3 += 0.00000000006*np.cos(2.58853517839 + 138.5174968707*t)
	X3 += 0.00000000007*np.cos(0.08989351607 + 742.9900605326*t)
	X3 += 0.00000000006*np.cos(3.39896707822 + 2125.8774073792*t)
	X3 += 0.00000000005*np.cos(2.18119549382 + 145.6310438715*t)
	X3 += 0.00000000007*np.cos(0.58812910406 + 38.1330356378*t)
	return X3*t*t*t




def Earth_X4 (t): # 67 terms of order 4

	X4 = 0.
	X4 += 0.00000003932
	X4 += 0.00000002272*np.cos(1.56364838180 + 206.1855484372*t)
	X4 += 0.00000002236*np.cos(3.28143366276 + 220.4126424388*t)
	X4 += 0.00000001927*np.cos(1.18746233453 + 12566.1516999828*t)
	X4 += 0.00000001682*np.cos(4.46996330708 + 522.5774180938*t)
	X4 += 0.00000001638*np.cos(6.17513895178 + 536.8045120954*t)
	X4 += 0.00000000491*np.cos(5.29890244491 + 6283.0758499914*t)
	X4 += 0.00000000430*np.cos(3.20713267334 + 227.5261894396*t)
	X4 += 0.00000000348*np.cos(2.26681787351 + 433.7117378768*t)
	X4 += 0.00000000291*np.cos(4.56956279775 + 515.463871093*t)
	X4 += 0.00000000210*np.cos(3.74319530048 + 6438.4962494256*t)
	X4 += 0.00000000210*np.cos(2.90533827217 + 6127.6554505572*t)
	X4 += 0.00000000229*np.cos(0.88072621187 + 18849.2275499742*t)
	X4 += 0.00000000206*np.cos(6.05364860885 + 543.9180590962*t)
	X4 += 0.00000000202*np.cos(1.69320982304 + 199.0720014364*t)
	X4 += 0.00000000123*np.cos(0.67135155073 + 1066.49547719*t)
	X4 += 0.00000000099*np.cos(0.99265774704 + 419.4846438752*t)
	X4 += 0.00000000113*np.cos(1.85695441801 + 426.598190876*t)
	X4 += 0.00000000080*np.cos(4.55016686641 + 7.1135470008*t)
	X4 += 0.00000000062*np.cos(4.48609878362 + 14.2270940016*t)
	X4 += 0.00000000053*np.cos(4.95103975600 + 1059.3819301892*t)
	X4 += 0.00000000066*np.cos(4.20375595982 + 1052.2683831884*t)
	X4 += 0.00000000050*np.cos(2.28699829686 + 440.8252848776*t)
	X4 += 0.00000000060*np.cos(0.97558287548 + 639.897286314*t)
	X4 += 0.00000000049*np.cos(1.31593641965 + 647.0108333148*t)
	X4 += 0.00000000044*np.cos(4.59638160457 + 709.9330485583*t)
	X4 += 0.00000000031*np.cos(6.26226050601 + 213.299095438*t)
	X4 += 0.00000000024*np.cos(3.05754167589 + 234.6397364404*t)
	X4 += 0.00000000023*np.cos(3.61004405073 + 1045.1548361876*t)
	X4 += 0.00000000021*np.cos(0.18140710246 + 6286.5989683404*t)
	X4 += 0.00000000021*np.cos(0.18394116301 + 6279.5527316424*t)
	X4 += 0.00000000014*np.cos(4.76472781912 + 508.3503240922*t)
	X4 += 0.00000000013*np.cos(6.04976474685 + 1589.0728952838*t)
	X4 += 0.00000000011*np.cos(0.54626079593 + 412.3710968744*t)
	X4 += 0.00000000012*np.cos(0.15818608564 + 853.196381752*t)
	X4 += 0.00000000010*np.cos(0.31907502124 + 1073.6090241908*t)
	X4 += 0.00000000010*np.cos(1.35560891851 + 1596.1864422846*t)
	X4 += 0.00000000013*np.cos(3.81035106449 + 83996.84731811189*t)
	X4 += 0.00000000009*np.cos(4.24672231397 + 21.3406410024*t)
	X4 += 0.00000000011*np.cos(0.65552931190 + 25132.3033999656*t)
	X4 += 0.00000000011*np.cos(3.71353247018 + 117.3198682202*t)
	X4 += 0.00000000008*np.cos(1.50012562224 + 103.0927742186*t)
	X4 += 0.00000000007*np.cos(6.08752157484 + 95.9792272178*t)
	X4 += 0.00000000007*np.cos(6.27374846424 + 529.6909650946*t)
	X4 += 0.00000000007*np.cos(5.71854398962 + 551.031606097*t)
	X4 += 0.00000000009*np.cos(5.19374498802 + 11856.2186514245*t)
	X4 += 0.00000000006*np.cos(1.40413206867 + 654.1243803156*t)
	X4 += 0.00000000007*np.cos(6.16589776486 + 167283.76158766549*t)
	X4 += 0.00000000005*np.cos(2.81686507397 + 124.433415221*t)
	X4 += 0.00000000005*np.cos(3.21271191075 + 625.6701923124*t)
	X4 += 0.00000000006*np.cos(0.43509868093 + 860.3099287528*t)
	X4 += 0.00000000005*np.cos(2.68915538708 + 12410.7313005486*t)
	X4 += 0.00000000004*np.cos(1.55213484100 + 632.7837393132*t)
	X4 += 0.00000000005*np.cos(3.17881881452 + 728.762966531*t)
	X4 += 0.00000000006*np.cos(5.56853736836 + 156137.47598479928*t)
	X4 += 0.00000000004*np.cos(1.76651819729 + 330.6189636582*t)
	X4 += 0.00000000005*np.cos(2.10225977593 + 942.062061969*t)
	X4 += 0.00000000004*np.cos(5.76705671645 + 88.865680217*t)
	X4 += 0.00000000004*np.cos(3.27648798915 + 735.8765135318*t)
	X4 += 0.00000000003*np.cos(4.78415680549 + 618.5566453116*t)
	X4 += 0.00000000003*np.cos(0.90449193126 + 110.2063212194*t)
	X4 += 0.00000000003*np.cos(2.17395214560 + 447.9388318784*t)
	X4 += 0.00000000003*np.cos(4.27605231904 + 1581.959348283*t)
	X4 += 0.00000000003*np.cos(1.69135933489 + 323.5054166574*t)
	X4 += 0.00000000002*np.cos(5.71553727369 + 1169.5882514086*t)
	X4 += 0.00000000003*np.cos(2.34507379864 + 191.9584544356*t)
	X4 += 0.00000000002*np.cos(3.94362184472 + 1155.361157407*t)
	return X4*t*t*t*t




def Earth_X5 (t): # 29 terms of order 5

	X5 = 0.
	X5 += 0.00000000168*np.cos(3.28069809842 + 206.1855484372*t)
	X5 += 0.00000000167*np.cos(1.52399958265 + 220.4126424388*t)
	X5 += 0.00000000126*np.cos(0.07122523863 + 522.5774180938*t)
	X5 += 0.00000000121*np.cos(4.30466267493 + 536.8045120954*t)
	X5 += 0.00000000108
	X5 += 0.00000000064*np.cos(1.46493444949 + 227.5261894396*t)
	X5 += 0.00000000047*np.cos(0.05687052745 + 515.463871093*t)
	X5 += 0.00000000043*np.cos(6.08789652058 + 12566.1516999828*t)
	X5 += 0.00000000037*np.cos(0.48304760543 + 433.7117378768*t)
	X5 += 0.00000000032*np.cos(4.26961178617 + 543.9180590962*t)
	X5 += 0.00000000028*np.cos(3.41370273509 + 199.0720014364*t)
	X5 += 0.00000000025*np.cos(5.33779665346 + 6438.4962494256*t)
	X5 += 0.00000000025*np.cos(1.31073691919 + 6127.6554505572*t)
	X5 += 0.00000000020*np.cos(0.94333339828 + 6283.0758499914*t)
	X5 += 0.00000000011*np.cos(2.75798781903 + 14.2270940016*t)
	X5 += 0.00000000011*np.cos(5.33499883960 + 1066.49547719*t)
	X5 += 0.00000000010*np.cos(0.51443337467 + 440.8252848776*t)
	X5 += 0.00000000008*np.cos(5.52588061142 + 18849.2275499742*t)
	X5 += 0.00000000007*np.cos(5.80467663011 + 647.0108333148*t)
	X5 += 0.00000000004*np.cos(0.20088280204 + 1052.2683831884*t)
	X5 += 0.00000000004*np.cos(3.59221465704 + 419.4846438752*t)
	X5 += 0.00000000003*np.cos(5.43212710597 + 639.897286314*t)
	X5 += 0.00000000003*np.cos(1.37528056638 + 234.6397364404*t)
	X5 += 0.00000000002*np.cos(0.38337547624 + 191.9584544356*t)
	X5 += 0.00000000002*np.cos(5.49829989028 + 426.598190876*t)
	X5 += 0.00000000002*np.cos(4.89397151114 + 1073.6090241908*t)
	X5 += 0.00000000002*np.cos(6.21263006019 + 1045.1548361876*t)
	X5 += 0.00000000001*np.cos(1.31653362066 + 88.865680217*t)
	X5 += 0.00000000001*np.cos(5.40855784676 + 405.2575498736*t)
	return X5*t*t*t*t*t




def Earth_Y0 (t): # 1212 terms of order 0

	Y0 = 0.
	Y0 += 0.99988907017*np.cos(0.18265890456 + 6283.0758499914*t)
	Y0 -= 0.02408829501
	Y0 += 0.00835289774*np.cos(0.13952879005 + 12566.1516999828*t)
	Y0 += 0.00492966037*np.cos(2.17052458400 + 529.6909650946*t)
	Y0 += 0.00272033033*np.cos(2.44443635549 + 213.299095438*t)
	Y0 += 0.00155442849*np.cos(0.59927021065 + 38.1330356378*t)
	Y0 += 0.00083751910*np.cos(0.76880010707 + 74.7815985673*t)
	Y0 += 0.00011819755*np.cos(2.47524448851 + 1059.3819301892*t)
	Y0 += 0.00010466933*np.cos(0.09641690558 + 18849.2275499742*t)
	Y0 += 0.00007623032*np.cos(1.66896617535 + 426.598190876*t)
	Y0 += 0.00003110838*np.cos(5.38114091484 + 83996.84731811189*t)
	Y0 += 0.00001962913*np.cos(5.70756734336 + 206.1855484372*t)
	Y0 += 0.00001940704*np.cos(3.22808267633 + 149.5631971346*t)
	Y0 += 0.00001890481*np.cos(2.32098683748 + 220.4126424388*t)
	Y0 += 0.00002147473*np.cos(2.66253538905 + 1577.3435424478*t)
	Y0 += 0.00001709219*np.cos(5.20780401071 + 6279.5527316424*t)
	Y0 += 0.00001707987*np.cos(4.58232858766 + 6286.5989683404*t)
	Y0 += 0.00001429933*np.cos(2.30184513257 + 522.5774180938*t)
	Y0 += 0.00001398661*np.cos(5.18874483163 + 536.8045120954*t)
	Y0 += 0.00001185789*np.cos(5.48845966910 + 76.2660712756*t)
	Y0 += 0.00001440265*np.cos(1.90068164664 + 2352.8661537718*t)
	Y0 += 0.00001135092*np.cos(5.27313415220 + 5223.6939198022*t)
	Y0 += 0.00000934539*np.cos(4.50301201844 + 12036.4607348882*t)
	Y0 += 0.00000813077*np.cos(1.68393442622 + 36.6485629295*t)
	Y0 += 0.00000767125*np.cos(2.65620459324 + 39.6175083461*t)
	Y0 += 0.00000744932*np.cos(2.80728871886 + 398.1490034082*t)
	Y0 += 0.00000639316*np.cos(6.02923915017 + 5753.3848848968*t)
	Y0 += 0.00000723524*np.cos(1.60560698821 + 10213.285546211*t)
	Y0 += 0.00000681324*np.cos(0.64729627497 + 4705.7323075436*t)
	Y0 += 0.00000611347*np.cos(3.81381495286 + 6812.766815086*t)
	Y0 += 0.00000628788*np.cos(4.99295631526 + 73.297125859*t)
	Y0 += 0.00000450435*np.cos(4.52785572489 + 5884.9268465832*t)
	Y0 += 0.00000452018*np.cos(5.99167242707 + 6256.7775301916*t)
	Y0 += 0.00000449968*np.cos(3.79880375595 + 6309.3741697912*t)
	Y0 += 0.00000551390*np.cos(3.96125249369 + 5507.5532386674*t)
	Y0 += 0.00000430002*np.cos(2.70052997175 + 1589.0728952838*t)
	Y0 += 0.00000404146*np.cos(5.25775211904 + 6681.2248533996*t)
	Y0 += 0.00000541273*np.cos(5.49902805917 + 775.522611324*t)
	Y0 += 0.00000546360*np.cos(6.17311131785 + 14143.4952424306*t)
	Y0 += 0.00000507084*np.cos(2.87025193381 + 7860.4193924392*t)
	Y0 += 0.00000319364*np.cos(3.56022620000 + 7.1135470008*t)
	Y0 += 0.00000317653*np.cos(4.53488042414 + 419.4846438752*t)
	Y0 += 0.00000314951*np.cos(0.91999346670 + 639.897286314*t)
	Y0 += 0.00000286693*np.cos(3.35830049094 + 110.2063212194*t)
	Y0 += 0.00000219504*np.cos(2.95216139568 + 11506.7697697936*t)
	Y0 += 0.00000262993*np.cos(0.28803097515 + 103.0927742186*t)
	Y0 += 0.00000227937*np.cos(5.95179248814 + 7058.5984613154*t)
	Y0 += 0.00000227792*np.cos(4.84547074733 + 4694.0029547076*t)
	Y0 += 0.00000255845*np.cos(0.69454231563 + 12168.0026965746*t)
	Y0 += 0.00000256132*np.cos(6.16722512388 + 709.9330485583*t)
	Y0 += 0.00000213096*np.cos(4.22106062967 + 316.3918696566*t)
	Y0 += 0.00000179242*np.cos(1.40003446021 + 796.2980068164*t)
	Y0 += 0.00000178280*np.cos(5.11717552231 + 6283.0085396886*t)
	Y0 += 0.00000178280*np.cos(4.67307255246 + 6283.14316029419*t)
	Y0 += 0.00000155454*np.cos(0.05340525434 + 25132.3033999656*t)
	Y0 += 0.00000206257*np.cos(4.28366728882 + 11790.6290886588*t)
	Y0 += 0.00000149769*np.cos(6.07429023278 + 5486.777843175*t)
	Y0 += 0.00000200005*np.cos(2.50144088120 + 17789.845619785*t)
	Y0 += 0.00000129006*np.cos(3.64623708634 + 7079.3738568078*t)
	Y0 += 0.00000128211*np.cos(3.23254821381 + 3738.761430108*t)
	Y0 += 0.00000138816*np.cos(0.43047773659 + 1.4844727083*t)
	Y0 += 0.00000111114*np.cos(0.85403021572 + 632.7837393132*t)
	Y0 += 0.00000106045*np.cos(1.55087419808 + 433.7117378768*t)
	Y0 += 0.00000118725*np.cos(5.45361490488 + 9437.762934887*t)
	Y0 += 0.00000099046*np.cos(1.44954618610 + 1052.2683831884*t)
	Y0 += 0.00000106628*np.cos(1.58474270218 + 1162.4747044078*t)
	Y0 += 0.00000078419*np.cos(0.28253093914 + 8827.3902698748*t)
	Y0 += 0.00000068578*np.cos(5.49084675578 + 1066.49547719*t)
	Y0 += 0.00000065694*np.cos(2.08898587059 + 11769.8536931664*t)
	Y0 += 0.00000063240*np.cos(0.67044491570 + 6262.300454499*t)
	Y0 += 0.00000062961*np.cos(2.83649755996 + 6303.8512454838*t)
	Y0 += 0.00000085870*np.cos(1.45351152151 + 167283.76158766549*t)
	Y0 += 0.00000080740*np.cos(0.92225805400 + 6069.7767545534*t)
	Y0 += 0.00000060039*np.cos(1.82878888713 + 4136.9104335162*t)
	Y0 += 0.00000075626*np.cos(2.58860726122 + 6496.3749454294*t)
	Y0 += 0.00000055765*np.cos(6.03101173028 + 949.1756089698*t)
	Y0 += 0.00000058089*np.cos(0.55165509745 + 10977.078804699*t)
	Y0 += 0.00000053747*np.cos(6.27553948416 + 1194.4470102246*t)
	Y0 += 0.00000057574*np.cos(1.10802134270 + 6282.0955289232*t)
	Y0 += 0.00000057574*np.cos(2.39891957636 + 6284.0561710596*t)
	Y0 += 0.00000051141*np.cos(6.02458046766 + 6290.1893969922*t)
	Y0 += 0.00000065279*np.cos(4.98927111441 + 846.0828347512*t)
	Y0 += 0.00000050679*np.cos(3.77133779892 + 6275.9623029906*t)
	Y0 += 0.00000049613*np.cos(1.07290390127 + 6127.6554505572*t)
	Y0 += 0.00000063109*np.cos(4.22325583135 + 148.0787244263*t)
	Y0 += 0.00000063109*np.cos(5.44811820644 + 224.3447957019*t)
	Y0 += 0.00000047934*np.cos(2.43176952238 + 6438.4962494256*t)
	Y0 += 0.00000061133*np.cos(5.34335721244 + 3154.6870848956*t)
	Y0 += 0.00000048425*np.cos(0.05833183710 + 801.8209311238*t)
	Y0 += 0.00000047359*np.cos(4.53607945311 + 3128.3887650958*t)
	Y0 += 0.00000048379*np.cos(0.25856696781 + 7084.8967811152*t)
	Y0 += 0.00000051293*np.cos(4.21367834558 + 12352.8526045448*t)
	Y0 += 0.00000050630*np.cos(0.48144269678 + 11856.2186514245*t)
	Y0 += 0.00000037539*np.cos(1.60040603609 + 8429.2412664666*t)
	Y0 += 0.00000049347*np.cos(2.15740113992 + 2544.3144198834*t)
	Y0 += 0.00000039555*np.cos(3.35943284176 + 5481.2549188676*t)
	Y0 += 0.00000048913*np.cos(5.16531049040 + 9225.539273283*t)
	Y0 += 0.00000042135*np.cos(2.06532560040 + 17260.1546546904*t)
	Y0 += 0.00000031140*np.cos(3.61579568733 + 2146.1654164752*t)
	Y0 += 0.00000032603*np.cos(4.41806626166 + 4164.311989613*t)
	Y0 += 0.00000039728*np.cos(4.70048863454 + 5856.4776591154*t)
	Y0 += 0.00000034784*np.cos(3.03113665420 + 35.1640902212*t)
	Y0 += 0.00000030359*np.cos(2.64775002249 + 11.0457002639*t)
	Y0 += 0.00000028515*np.cos(4.53853388964 + 12569.6748183318*t)
	Y0 += 0.00000036368*np.cos(1.33416490018 + 18073.7049386502*t)
	Y0 += 0.00000034601*np.cos(4.63240700311 + 3340.6124266998*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000028733*np.cos(2.14315245629 + 151.0476698429*t)
	Y0 += 0.00000025032*np.cos(3.74982021361 + 26.2983197998*t)
	Y0 += 0.00000027688*np.cos(5.44433605847 + 63.7358983034*t)
	Y0 += 0.00000030329*np.cos(0.42324614391 + 4535.0594369244*t)
	Y0 += 0.00000026741*np.cos(5.97172882162 + 3930.2096962196*t)
	Y0 += 0.00000028166*np.cos(5.19366222912 + 12562.6285816338*t)
	Y0 += 0.00000023815*np.cos(2.19051967809 + 227.5261894396*t)
	Y0 += 0.00000024843*np.cos(1.00265326013 + 5088.6288397668*t)
	Y0 += 0.00000021642*np.cos(3.06444526478 + 12559.038152982*t)
	Y0 += 0.00000025701*np.cos(0.75895390818 + 13367.9726311066*t)
	Y0 += 0.00000020498*np.cos(3.44435384536 + 11371.7046897582*t)
	Y0 += 0.00000023457*np.cos(0.09576335036 + 71.8126531507*t)
	Y0 += 0.00000023256*np.cos(5.18050538435 + 85.8272988312*t)
	Y0 += 0.00000019931*np.cos(2.81254368420 + 2118.7638603784*t)
	Y0 += 0.00000025997*np.cos(1.87312778491 + 71430.69561812909*t)
	Y0 += 0.00000017888*np.cos(5.01504194498 + 1748.016413067*t)
	Y0 += 0.00000023246*np.cos(4.61910038205 + 18319.5365848796*t)
	Y0 += 0.00000022104*np.cos(2.36649230999 + 2.9689454166*t)
	Y0 += 0.00000021981*np.cos(4.82484958838 + 77.7505439839*t)
	Y0 += 0.00000020052*np.cos(2.45637769313 + 209.3669421749*t)
	Y0 += 0.00000017077*np.cos(5.29722216277 + 4933.2084403326*t)
	Y0 += 0.00000019691*np.cos(5.58713076986 + 217.2312487011*t)
	Y0 += 0.00000021070*np.cos(2.22959477131 + 7477.522860216*t)
	Y0 += 0.00000017512*np.cos(6.16192589291 + 10447.3878396044*t)
	Y0 += 0.00000015517*np.cos(3.70546925724 + 742.9900605326*t)
	Y0 += 0.00000020024*np.cos(2.96823180998 + 8031.0922630584*t)
	Y0 += 0.00000018552*np.cos(4.31061638297 + 202.2533951741*t)
	Y0 += 0.00000018291*np.cos(1.49785845895 + 323.5054166574*t)
	Y0 += 0.00000017492*np.cos(1.45131471586 + 138.5174968707*t)
	Y0 += 0.00000015492*np.cos(1.06568154314 + 735.8765135318*t)
	Y0 += 0.00000015545*np.cos(2.44244738845 + 515.463871093*t)
	Y0 += 0.00000013831*np.cos(3.02450528624 + 8635.9420037632*t)
	Y0 += 0.00000014095*np.cos(6.03707103538 + 2942.4634232916*t)
	Y0 += 0.00000018884*np.cos(0.85614789376 + 156137.47598479928*t)
	Y0 += 0.00000017861*np.cos(4.86809570283 + 1592.5960136328*t)
	Y0 += 0.00000016966*np.cos(0.24919778633 + 853.196381752*t)
	Y0 += 0.00000013605*np.cos(3.62641145030 + 13095.8426650774*t)
	Y0 += 0.00000015078*np.cos(1.55132224732 + 16496.3613962024*t)
	Y0 += 0.00000017985*np.cos(2.07741211308 + 17298.1823273262*t)
	Y0 += 0.00000014909*np.cos(6.12895641025 + 20426.571092422*t)
	Y0 += 0.00000012227*np.cos(4.38359423735 + 7632.9432596502*t)
	Y0 += 0.00000013376*np.cos(2.03616887071 + 12139.5535091068*t)
	Y0 += 0.00000011583*np.cos(3.88971333608 + 5331.3574437408*t)
	Y0 += 0.00000013558*np.cos(1.44666331503 + 16730.4636895958*t)
	Y0 += 0.00000014332*np.cos(4.45678693729 + 7342.4577801806*t)
	Y0 += 0.00000011595*np.cos(5.83451477433 + 199.0720014364*t)
	Y0 += 0.00000012375*np.cos(1.53862289477 + 6279.4854213396*t)
	Y0 += 0.00000012366*np.cos(1.96831814872 + 6286.6662786432*t)
	Y0 += 0.00000010833*np.cos(5.05422968004 + 543.9180590962*t)
	Y0 += 0.00000012446*np.cos(5.78094918529 + 15110.4661198662*t)
	Y0 += 0.00000011585*np.cos(5.32336141881 + 525.7588118315*t)
	Y0 += 0.00000010989*np.cos(0.62040343662 + 10988.808157535*t)
	Y0 += 0.00000012556*np.cos(2.59194808538 + 15720.8387848784*t)
	Y0 += 0.00000011435*np.cos(2.15573411853 + 533.6231183577*t)
	Y0 += 0.00000011583*np.cos(2.48165809843 + 5729.506447149*t)
	Y0 += 0.00000009023*np.cos(3.85655029499 + 9623.6882766912*t)
	Y0 += 0.00000009121*np.cos(5.83006047147 + 7234.794256242*t)
	Y0 += 0.00000008869*np.cos(3.47611265290 + 6148.010769956*t)
	Y0 += 0.00000008614*np.cos(0.03081589303 + 6418.1409300268*t)
	Y0 += 0.00000008293*np.cos(0.85407021371 + 14712.317116458*t)
	Y0 += 0.00000010219*np.cos(0.13075179540 + 1349.8674096588*t)
	Y0 += 0.00000010126*np.cos(0.99630008630 + 6836.6452528338*t)
	Y0 += 0.00000010480*np.cos(1.38209301929 + 5999.2165311262*t)
	Y0 += 0.00000007353*np.cos(3.83220307326 + 6040.3472460174*t)
	Y0 += 0.00000007963*np.cos(1.85811815388 + 1692.1656695024*t)
	Y0 += 0.00000007460*np.cos(0.83911111300 + 1478.8665740644*t)
	Y0 += 0.00000007196*np.cos(1.94802350337 + 216.4804891757*t)
	Y0 += 0.00000009820*np.cos(2.12476655144 + 6566.9351688566*t)
	Y0 += 0.00000007036*np.cos(6.09743344991 + 210.1177017003*t)
	Y0 += 0.00000007148*np.cos(0.89057242152 + 415.5524906121*t)
	Y0 += 0.00000007018*np.cos(5.94659180519 + 6525.8044539654*t)
	Y0 += 0.00000006899*np.cos(2.82570489004 + 117.3198682202*t)
	Y0 += 0.00000006874*np.cos(4.57503512461 + 7238.67559160*t)
	Y0 += 0.00000007545*np.cos(5.94843444430 + 12539.853380183*t)
	Y0 += 0.00000009540*np.cos(3.49613271706 + 21228.3920235458*t)
	Y0 += 0.00000007202*np.cos(4.31311898936 + 6245.0481773556*t)
	Y0 += 0.00000007144*np.cos(5.47703560836 + 6321.1035226272*t)
	Y0 += 0.00000007016*np.cos(2.47820281371 + 1265.5674786264*t)
	Y0 += 0.00000006627*np.cos(5.41373102778 + 5327.4761083828*t)
	Y0 += 0.00000008544*np.cos(1.82829301857 + 11015.1064773348*t)
	Y0 += 0.00000006687*np.cos(1.25257611175 + 956.2891559706*t)
	Y0 += 0.00000008602*np.cos(5.43953575310 + 5643.1785636774*t)
	Y0 += 0.00000006158*np.cos(5.65852675233 + 12964.300703391*t)
	Y0 += 0.00000007414*np.cos(3.46720433621 + 23543.23050468179*t)
	Y0 += 0.00000006352*np.cos(3.46461304398 + 1990.745017041*t)
	Y0 += 0.00000007085*np.cos(3.42541681943 + 14.2270940016*t)
	Y0 += 0.00000007401*np.cos(1.62945495419 + 1581.959348283*t)
	Y0 += 0.00000006251*np.cos(1.52860898333 + 951.7184062506*t)
	Y0 += 0.00000006663*np.cos(0.80373241909 + 647.0108333148*t)
	Y0 += 0.00000005828*np.cos(1.37555383064 + 955.5997416086*t)
	Y0 += 0.00000006389*np.cos(2.40580071461 + 24072.9214697764*t)
	Y0 += 0.00000006976*np.cos(4.76626361488 + 10973.55568635*t)
	Y0 += 0.00000007459*np.cos(2.71133898870 + 22003.9146348698*t)
	Y0 += 0.00000005376*np.cos(2.34968505500 + 14314.1681130498*t)
	Y0 += 0.00000006852*np.cos(4.33781274406 + 155.4203994342*t)
	Y0 += 0.00000007527*np.cos(1.94392127074 + 18422.62935909819*t)
	Y0 += 0.00000006896*np.cos(0.48307355730 + 95.9792272178*t)
	Y0 += 0.00000006330*np.cos(3.87859376833 + 70.8494453042*t)
	Y0 += 0.00000006222*np.cos(0.67296135144 + 18451.07854656599*t)
	Y0 += 0.00000006487*np.cos(2.22135874272 + 5216.5803728014*t)
	Y0 += 0.00000006251*np.cos(2.88399458161 + 6288.5987742988*t)
	Y0 += 0.00000006251*np.cos(0.62294633745 + 6277.552925684*t)
	Y0 += 0.00000005078*np.cos(2.67641304277 + 526.5095713569*t)
	Y0 += 0.00000005337*np.cos(1.97127813671 + 4690.4798363586*t)
	Y0 += 0.00000005605*np.cos(1.92150700481 + 1551.045222648*t)
	Y0 += 0.00000004977*np.cos(4.80328860665 + 532.8723588323*t)
	Y0 += 0.00000005879*np.cos(0.79782511263 + 78.7137518304*t)
	Y0 += 0.00000006210*np.cos(0.81866451118 + 5650.2921106782*t)
	Y0 += 0.00000006064*np.cos(5.19708779870 + 5230.807466803*t)
	Y0 += 0.00000004596*np.cos(2.92936593195 + 553.5694028424*t)
	Y0 += 0.00000005386*np.cos(5.40633950052 + 77713.7714681205*t)
	Y0 += 0.00000006103*np.cos(4.10884733063 + 111.4301614968*t)
	Y0 += 0.00000006196*np.cos(4.15787078176 + 84672.47584450469*t)
	Y0 += 0.00000006160*np.cos(3.21170435536 + 239424.39025435288*t)
	Y0 += 0.00000005016*np.cos(1.46006858313 + 4732.0306273434*t)
	Y0 += 0.00000005414*np.cos(1.42882325200 + 6179.9830757728*t)
	Y0 += 0.00000005413*np.cos(2.08325983447 + 6386.16862421*t)
	Y0 += 0.00000004863*np.cos(2.19642746549 + 90279.92316810328*t)
	Y0 += 0.00000005711*np.cos(2.75630374926 + 6915.8595893046*t)
	Y0 += 0.00000004270*np.cos(0.81269903423 + 7875.6718636242*t)
	Y0 += 0.00000004017*np.cos(2.21501265909 + 6254.6266625236*t)
	Y0 += 0.00000004071*np.cos(3.99159158863 + 3634.6210245184*t)
	Y0 += 0.00000003993*np.cos(1.29192500625 + 6311.5250374592*t)
	Y0 += 0.00000004274*np.cos(5.26697629294 + 1375.7737998458*t)
	Y0 += 0.00000004423*np.cos(6.24070525621 + 277.0349937414*t)
	Y0 += 0.00000004713*np.cos(3.21489250017 + 114.3991069134*t)
	Y0 += 0.00000004858*np.cos(1.27914374675 + 5760.4984318976*t)
	Y0 += 0.00000005274*np.cos(4.91687036691 + 25158.6017197654*t)
	Y0 += 0.00000005182*np.cos(0.28726404719 + 222.8603229936*t)
	Y0 += 0.00000003701*np.cos(5.71514424825 + 1596.1864422846*t)
	Y0 += 0.00000004577*np.cos(5.47618219772 + 146.594251718*t)
	Y0 += 0.00000004120*np.cos(1.72568521475 + 6709.6740408674*t)
	Y0 += 0.00000004410*np.cos(2.23536264210 + 6805.6532680852*t)
	Y0 += 0.00000003064*np.cos(2.46605561478 + 5863.5912061162*t)
	Y0 += 0.00000003083*np.cos(5.68731909779 + 9917.6968745098*t)
	Y0 += 0.00000003385*np.cos(3.81076637101 + 13916.0191096416*t)
	Y0 += 0.00000002979*np.cos(4.62987940723 + 12566.2190102856*t)
	Y0 += 0.00000003980*np.cos(5.90917210624 + 13341.6743113068*t)
	Y0 += 0.00000003290*np.cos(0.95752698537 + 16200.7727245012*t)
	Y0 += 0.00000003060*np.cos(1.63142398497 + 18052.9295431578*t)
	Y0 += 0.00000002830*np.cos(5.36742188515 + 309.2783226558*t)
	Y0 += 0.00000003745*np.cos(3.65023712104 + 5966.6839803348*t)
	Y0 += 0.00000003761*np.cos(5.75801604585 + 490.3340891794*t)
	Y0 += 0.00000003592*np.cos(4.03843804285 + 6208.2942514241*t)
	Y0 += 0.00000003581*np.cos(5.75234129258 + 6357.8574485587*t)
	Y0 += 0.00000003626*np.cos(6.13871061291 + 6599.467719648*t)
	Y0 += 0.00000002927*np.cos(1.79201822142 + 12721.572099417*t)
	Y0 += 0.00000003625*np.cos(1.43112641053 + 6019.9919266186*t)
	Y0 += 0.00000002589*np.cos(2.27559640821 + 12592.4500197826*t)
	Y0 += 0.00000002820*np.cos(1.86334392833 + 299.1263942692*t)
	Y0 += 0.00000002558*np.cos(6.08151329647 + 10575.4066829418*t)
	Y0 += 0.00000002670*np.cos(2.64370887209 + 3.523118349*t)
	Y0 += 0.00000002611*np.cos(0.86180315523 + 6702.5604938666*t)
	Y0 += 0.00000002535*np.cos(0.01231078888 + 31415.379249957*t)
	Y0 += 0.00000003520*np.cos(3.80906746266 + 250570.67585721909*t)
	Y0 += 0.00000003425*np.cos(0.95244785238 + 351.8165923087*t)
	Y0 += 0.00000003434*np.cos(2.07577333297 + 6546.1597733642*t)
	Y0 += 0.00000002378*np.cos(2.05651519036 + 2388.8940204492*t)
	Y0 += 0.00000002597*np.cos(5.80919919910 + 3.9321532631*t)
	Y0 += 0.00000002979*np.cos(5.07398237708 + 12566.08438968*t)
	Y0 += 0.00000002716*np.cos(1.49855840728 + 12029.3471878874*t)
	Y0 += 0.00000002922*np.cos(5.30505468617 + 109.9456887885*t)
	Y0 += 0.00000002220*np.cos(3.69012746334 + 13362.4497067992*t)
	Y0 += 0.00000002471*np.cos(1.29713026645 + 625.6701923124*t)
	Y0 += 0.00000003049*np.cos(0.05228873308 + 29088.811415985*t)
	Y0 += 0.00000002784*np.cos(3.37954165171 + 14945.3161735544*t)
	Y0 += 0.00000002284*np.cos(4.38146814547 + 6076.8903015542*t)
	Y0 += 0.00000002529*np.cos(4.37629589914 + 12043.574281889*t)
	Y0 += 0.00000002015*np.cos(0.91352603582 + 6262.7205305926*t)
	Y0 += 0.00000002218*np.cos(5.40562909521 + 6489.2613984286*t)
	Y0 += 0.00000002005*np.cos(2.59344263770 + 6303.4311693902*t)
	Y0 += 0.00000002681*np.cos(5.85620039558 + 4590.910180489*t)
	Y0 += 0.00000002011*np.cos(5.69828891426 + 4701.1165017084*t)
	Y0 += 0.00000002454*np.cos(2.79445983744 + 10021.8372800994*t)
	Y0 += 0.00000002600*np.cos(3.93109819647 + 19651.048481098*t)
	Y0 += 0.00000002197*np.cos(5.22411628121 + 13517.8701062334*t)
	Y0 += 0.00000001893*np.cos(4.09716259686 + 6286.9571853494*t)
	Y0 += 0.00000001893*np.cos(5.69296362938 + 6279.1945146334*t)
	Y0 += 0.00000002547*np.cos(4.75277405496 + 1169.5882514086*t)
	Y0 += 0.00000002156*np.cos(0.43826128691 + 18139.2945014159*t)
	Y0 += 0.00000001778*np.cos(2.79119893202 + 4292.3308329504*t)
	Y0 += 0.00000001966*np.cos(1.82224928185 + 4686.8894077068*t)
	Y0 += 0.00000002285*np.cos(1.22344285748 + 1045.1548361876*t)
	Y0 += 0.00000002436*np.cos(2.83689873280 + 95143.1329209781*t)
	Y0 += 0.00000002163*np.cos(6.13036765564 + 6037.244203762*t)
	Y0 += 0.00000001841*np.cos(3.67947373190 + 242.728603974*t)
	Y0 += 0.00000001672*np.cos(0.33097080655 + 13119.72110282519*t)
	Y0 += 0.00000002250*np.cos(0.82649282051 + 12669.2444742014*t)
	Y0 += 0.00000001627*np.cos(4.77445737868 + 13521.7514415914*t)
	Y0 += 0.00000001888*np.cos(2.87850805387 + 8662.240323563*t)
	Y0 += 0.00000002052*np.cos(3.65927016475 + 6528.9074962208*t)
	Y0 += 0.00000001774*np.cos(0.51400448882 + 6819.8803620868*t)
	Y0 += 0.00000001840*np.cos(1.91711006767 + 65147.6197681377*t)
	Y0 += 0.00000001913*np.cos(1.75777087654 + 1155.361157407*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000001756*np.cos(2.96482886554 + 5746.271337896*t)
	Y0 += 0.00000001649*np.cos(1.44498561983 + 440.8252848776*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001543*np.cos(4.39018655159 + 6272.4391846416*t)
	Y0 += 0.00000001543*np.cos(5.39993967465 + 6293.7125153412*t)
	Y0 += 0.00000001952*np.cos(3.09643550846 + 23013.5395395872*t)
	Y0 += 0.00000001439*np.cos(6.16071128287 + 942.062061969*t)
	Y0 += 0.00000001484*np.cos(2.15301976837 + 20.7753954924*t)
	Y0 += 0.00000001487*np.cos(4.35858219478 + 412.3710968744*t)
	Y0 += 0.00000001558*np.cos(2.79679951671 + 17654.7805397496*t)
	Y0 += 0.00000001795*np.cos(1.47161886169 + 33019.0211122046*t)
	Y0 += 0.00000001349*np.cos(4.18018072818 + 6016.4688082696*t)
	Y0 += 0.00000001477*np.cos(2.56925128481 + 12779.4507954208*t)
	Y0 += 0.00000001428*np.cos(4.17962469716 + 65.2203710117*t)
	Y0 += 0.00000001252*np.cos(6.26830198321 + 11499.6562227928*t)
	Y0 += 0.00000001491*np.cos(4.65893645946 + 9411.4646150872*t)
	Y0 += 0.00000001471*np.cos(4.18695456530 + 18635.9284545362*t)
	Y0 += 0.00000001263*np.cos(5.62967869388 + 12573.2652469836*t)
	Y0 += 0.00000001385*np.cos(2.65776727703 + 2379.1644735716*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001272*np.cos(5.60977857361 + 6549.6828917132*t)
	Y0 += 0.00000001578*np.cos(4.10046385407 + 25934.1243310894*t)
	Y0 += 0.00000001557*np.cos(4.78614835776 + 18875.525869774*t)
	Y0 += 0.00000001358*np.cos(0.33781842226 + 5120.6011455836*t)
	Y0 += 0.00000001505*np.cos(2.70837129901 + 18209.33026366019*t)
	Y0 += 0.00000001485*np.cos(6.11611294959 + 210.8514148832*t)
	Y0 += 0.00000001473*np.cos(1.91659379347 + 215.7467759928*t)
	Y0 += 0.00000001422*np.cos(4.41813139873 + 225.8292684102*t)
	Y0 += 0.00000001460*np.cos(3.40156973977 + 245.8316462294*t)
	Y0 += 0.00000001091*np.cos(1.25744389434 + 422.6660376129*t)
	Y0 += 0.00000001252*np.cos(6.12407876457 + 6993.0088985497*t)
	Y0 += 0.00000001242*np.cos(1.27359177098 + 24356.7807886416*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001019*np.cos(5.67612773072 + 145.6310438715*t)
	Y0 += 0.00000001421*np.cos(0.83890525684 + 152.5321425512*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001028*np.cos(0.93950338023 + 6112.4029793722*t)
	Y0 += 0.00000001014*np.cos(4.36072926630 + 17256.6315363414*t)
	Y0 += 0.00000001031*np.cos(1.65365925948 + 1795.258443721*t)
	Y0 += 0.00000001312*np.cos(5.81330496460 + 12491.3701014155*t)
	Y0 += 0.00000000992*np.cos(2.56738139157 + 6453.7487206106*t)
	Y0 += 0.00000000988*np.cos(5.69171453384 + 8273.8208670324*t)
	Y0 += 0.00000001191*np.cos(1.64765684664 + 6276.02961329339*t)
	Y0 += 0.00000001191*np.cos(1.85928407242 + 6290.1220866894*t)
	Y0 += 0.00000000978*np.cos(3.16773119822 + 6247.04798331399*t)
	Y0 += 0.00000001223*np.cos(6.22694723537 + 5429.8794682394*t)
	Y0 += 0.00000000971*np.cos(0.33921097188 + 6319.1037166688*t)
	Y0 += 0.00000000977*np.cos(0.76357046359 + 84.3428261229*t)
	Y0 += 0.00000001192*np.cos(2.85757763157 + 2648.454825473*t)
	Y0 += 0.00000000964*np.cos(4.63043034198 + 1272.6810256272*t)
	Y0 += 0.00000000962*np.cos(1.06488912173 + 12565.1713789146*t)
	Y0 += 0.00000001025*np.cos(0.64688768472 + 12545.3763044904*t)
	Y0 += 0.00000001076*np.cos(5.29118995114 + 212.3358875915*t)
	Y0 += 0.00000001234*np.cos(2.50427756599 + 22483.84857449259*t)
	Y0 += 0.00000001071*np.cos(2.73962355675 + 214.2623032845*t)
	Y0 += 0.00000001134*np.cos(5.76287831677 + 17782.7320727842*t)
	Y0 += 0.00000001243*np.cos(1.30343744920 + 184.7272873558*t)
	Y0 += 0.00000000944*np.cos(5.49712708636 + 6306.9542877392*t)
	Y0 += 0.00000000944*np.cos(4.29299913988 + 6259.1974122436*t)
	Y0 += 0.00000001092*np.cos(2.35048657695 + 17796.9591667858*t)
	Y0 += 0.00000000891*np.cos(2.41639607024 + 213.2509113282*t)
	Y0 += 0.00000000890*np.cos(5.61419511254 + 213.3472795478*t)
	Y0 += 0.00000000995*np.cos(1.11794413013 + 10177.2576795336*t)
	Y0 += 0.00000001216*np.cos(5.61396859194 + 82576.98122099529*t)
	Y0 += 0.00000000942*np.cos(6.13301518193 + 6267.82337880639*t)
	Y0 += 0.00000000942*np.cos(3.65711104430 + 6298.3283211764*t)
	Y0 += 0.00000001045*np.cos(5.17292899506 + 15508.6151232744*t)
	Y0 += 0.00000000850*np.cos(6.16443178844 + 6393.2821712108*t)
	Y0 += 0.00000000896*np.cos(0.83013691514 + 3903.9113764198*t)
	Y0 += 0.00000000856*np.cos(1.36181993943 + 4804.209275927*t)
	Y0 += 0.00000001041*np.cos(4.23685547840 + 137.0330241624*t)
	Y0 += 0.00000001033*np.cos(3.31340063953 + 5573.1428014331*t)
	Y0 += 0.00000000968*np.cos(2.96119647882 + 437.6438911399*t)
	Y0 += 0.00000000817*np.cos(3.58855573226 + 6172.869528772*t)
	Y0 += 0.00000000812*np.cos(0.69907573293 + 288.0806940053*t)
	Y0 += 0.00000000819*np.cos(5.28403120371 + 529.6427809848*t)
	Y0 += 0.00000000819*np.cos(2.19867289777 + 529.7391492044*t)
	Y0 += 0.00000001037*np.cos(2.70514798372 + 527.2432845398*t)
	Y0 += 0.00000000917*np.cos(0.89919993710 + 149854.40013480789*t)
	Y0 += 0.00000001029*np.cos(4.77626567802 + 532.1386456494*t)
	Y0 += 0.00000001081*np.cos(2.89245979526 + 36949.2308084242*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000776*np.cos(2.50668810243 + 203.7378678824*t)
	Y0 += 0.00000000962*np.cos(2.35578735539 + 12567.132021051*t)
	Y0 += 0.00000000990*np.cos(4.97210778261 + 11403.676995575*t)
	Y0 += 0.00000000734*np.cos(3.78800004602 + 112.9146342051*t)
	Y0 += 0.00000000739*np.cos(3.39896198161 + 11926.2544136688*t)
	Y0 += 0.00000000929*np.cos(0.64994792213 + 2787.0430238574*t)
	Y0 += 0.00000000973*np.cos(6.19358824421 + 22805.7355659936*t)
	Y0 += 0.00000000711*np.cos(0.35309558162 + 628.8515860501*t)
	Y0 += 0.00000000743*np.cos(2.22828430376 + 7834.1210726394*t)
	Y0 += 0.00000000905*np.cos(1.26234908246 + 6281.5913772831*t)
	Y0 += 0.00000000905*np.cos(2.24459183660 + 6284.5603226997*t)
	Y0 += 0.00000000798*np.cos(1.05421393588 + 12410.7313005486*t)
	Y0 += 0.00000000925*np.cos(1.39948133634 + 160.6088973985*t)
	Y0 += 0.00000000663*np.cos(3.47906442185 + 1368.660252845*t)
	Y0 += 0.00000000813*np.cos(5.23283372183 + 12416.5885028482*t)
	Y0 += 0.00000000640*np.cos(1.16666859771 + 2008.557539159*t)
	Y0 += 0.00000000869*np.cos(1.74785663537 + 6133.5126528568*t)
	Y0 += 0.00000000639*np.cos(1.50357516119 + 2111.6503133776*t)
	Y0 += 0.00000000742*np.cos(1.23961445295 + 9.5612275556*t)
	Y0 += 0.00000000756*np.cos(5.40063116731 + 4061.2192153944*t)
	Y0 += 0.00000000875*np.cos(3.77647530400 + 380.12776796*t)
	Y0 += 0.00000000724*np.cos(1.49651873854 + 161000.6857376741*t)
	Y0 += 0.00000000619*np.cos(5.21680002932 + 430.5303441391*t)
	Y0 += 0.00000000661*np.cos(2.90920830849 + 1063.3140834523*t)
	Y0 += 0.00000000612*np.cos(5.89184406078 + 16858.4825329332*t)
	Y0 += 0.00000000814*np.cos(3.82004246488 + 3894.1818295422*t)
	Y0 += 0.00000000785*np.cos(2.44918664136 + 4907.3020501456*t)
	Y0 += 0.00000000663*np.cos(2.12818812670 + 838.9692877504*t)
	Y0 += 0.00000000570*np.cos(2.97586328906 + 12586.9270954752*t)
	Y0 += 0.00000000561*np.cos(5.85814246596 + 12323.4230960088*t)
	Y0 += 0.00000000598*np.cos(5.09026310864 + 423.4167971383*t)
	Y0 += 0.00000000633*np.cos(1.58661078881 + 12.5301729722*t)
	Y0 += 0.00000000647*np.cos(1.86412144751 + 528.7277572481*t)
	Y0 += 0.00000000646*np.cos(5.61853780158 + 530.6541729411*t)
	Y0 += 0.00000000590*np.cos(0.47736597307 + 15671.0817594066*t)
	Y0 += 0.00000000542*np.cos(1.92142092432 + 2221.856634597*t)
	Y0 += 0.00000000555*np.cos(2.86698301793 + 11513.8833167944*t)
	Y0 += 0.00000000536*np.cos(4.49580958272 + 18852.7506683232*t)
	Y0 += 0.00000000737*np.cos(5.41358302312 + 23581.2581773176*t)
	Y0 += 0.00000000532*np.cos(3.01682571392 + 18842.11400297339*t)
	Y0 += 0.00000000552*np.cos(6.08260944683 + 11933.3679606696*t)
	Y0 += 0.00000000599*np.cos(0.54713576844 + 6151.533888305*t)
	Y0 += 0.00000000540*np.cos(1.83361074884 + 6279.7894925736*t)
	Y0 += 0.00000000540*np.cos(1.67333017022 + 6286.3622074092*t)
	Y0 += 0.00000000541*np.cos(5.63219919123 + 1055.4497769261*t)
	Y0 += 0.00000000513*np.cos(2.13211972766 + 12455.9453787634*t)
	Y0 += 0.00000000649*np.cos(3.33488856037 + 11764.330768859*t)
	Y0 += 0.00000000582*np.cos(2.96012819576 + 6414.6178116778*t)
	Y0 += 0.00000000672*np.cos(1.51129840313 + 221.3758502853*t)
	Y0 += 0.00000000608*np.cos(2.37588807672 + 10419.9862835076*t)
	Y0 += 0.00000000620*np.cos(0.83937590497 + 5326.7866940208*t)
	Y0 += 0.00000000536*np.cos(2.13145334966 + 7232.2514589612*t)
	Y0 += 0.00000000490*np.cos(1.40385202337 + 71.6002048296*t)
	Y0 += 0.00000000538*np.cos(1.33481115516 + 5333.9002410216*t)
	Y0 += 0.00000000596*np.cos(0.99065349155 + 6062.6632075526*t)
	Y0 += 0.00000000664*np.cos(4.31358012484 + 40879.4405046438*t)
	Y0 += 0.00000000607*np.cos(4.79849916312 + 5849.3641121146*t)
	Y0 += 0.00000000473*np.cos(3.26277772078 + 77.962992305*t)
	Y0 += 0.00000000648*np.cos(6.03788509546 + 22.0914005278*t)
	Y0 += 0.00000000624*np.cos(1.28974618222 + 330.6189636582*t)
	Y0 += 0.00000000629*np.cos(1.34455816041 + 26735.9452622132*t)
	Y0 += 0.00000000479*np.cos(6.04755907663 + 5547.1993364596*t)
	Y0 += 0.00000000653*np.cos(1.15486761496 + 388.4651552382*t)
	Y0 += 0.00000000565*np.cos(5.49238261982 + 4171.4255366138*t)
	Y0 += 0.00000000472*np.cos(3.81181804730 + 10969.9652576982*t)
	Y0 += 0.00000000462*np.cos(3.53729128828 + 3104.9300594238*t)
	Y0 += 0.00000000468*np.cos(5.41054107443 + 1073.6090241908*t)
	Y0 += 0.00000000551*np.cos(2.46794798020 + 6503.4884924302*t)
	Y0 += 0.00000000535*np.cos(4.55197627124 + 173566.83743765688*t)
	Y0 += 0.00000000532*np.cos(1.20297674206 + 728.762966531*t)
	Y0 += 0.00000000574*np.cos(4.09850700417 + 87.3117715395*t)
	Y0 += 0.00000000450*np.cos(0.38613288324 + 4274.5183108324*t)
	Y0 += 0.00000000604*np.cos(0.41299096165 + 984.6003316219*t)
	Y0 += 0.00000000541*np.cos(1.50869067477 + 72.3339180125*t)
	Y0 += 0.00000000527*np.cos(4.67747327047 + 24602.61243487099*t)
	Y0 += 0.00000000502*np.cos(5.68646136646 + 12489.8856287072*t)
	Y0 += 0.00000000603*np.cos(5.56725954240 + 322711.30452390644*t)
	Y0 += 0.00000000468*np.cos(3.76982493207 + 212.7778305762*t)
	Y0 += 0.00000000466*np.cos(4.26202338577 + 213.8203602998*t)
	Y0 += 0.00000000432*np.cos(5.22277533085 + 9388.0059094152*t)
	Y0 += 0.00000000530*np.cos(5.14730101928 + 18845.7044316252*t)
	Y0 += 0.00000000431*np.cos(3.74066314880 + 7018.9523635232*t)
	Y0 += 0.00000000419*np.cos(1.18672277137 + 429.7795846137*t)
	Y0 += 0.00000000423*np.cos(5.23795043183 + 340.7708920448*t)
	Y0 += 0.00000000584*np.cos(4.78380792490 + 72850.56171524568*t)
	Y0 += 0.00000000462*np.cos(0.09066955654 + 860.3099287528*t)
	Y0 += 0.00000000408*np.cos(4.98636538552 + 3496.032826134*t)
	Y0 += 0.00000000569*np.cos(1.38164944312 + 97238.62754448749*t)
	Y0 += 0.00000000478*np.cos(4.58275550120 + 29296.6153895786*t)
	Y0 += 0.00000000389*np.cos(1.64726374330 + 6321.2088856292*t)
	Y0 += 0.00000000389*np.cos(1.85967717576 + 6244.9428143536*t)
	Y0 += 0.00000000388*np.cos(5.85202122263 + 6297.302943993*t)
	Y0 += 0.00000000388*np.cos(3.93810500361 + 6268.8487559898*t)
	Y0 += 0.00000000515*np.cos(0.09995703640 + 12320.3200537534*t)
	Y0 += 0.00000000395*np.cos(1.39225625253 + 4157.1984426122*t)
	Y0 += 0.00000000423*np.cos(2.45281376602 + 9779.1086761254*t)
	Y0 += 0.00000000511*np.cos(3.34354440535 + 77.2292791221*t)
	Y0 += 0.00000000439*np.cos(3.25487944876 + 233141.31440436149*t)
	Y0 += 0.00000000501*np.cos(3.08355690853 + 17157.0618804718*t)
	Y0 += 0.00000000416*np.cos(2.17399987974 + 13760.5987102074*t)
	Y0 += 0.00000000503*np.cos(4.02857067171 + 135.0650800354*t)
	Y0 += 0.00000000393*np.cos(6.27884951137 + 7872.1487452752*t)
	Y0 += 0.00000000491*np.cos(3.39044076994 + 3.1813937377*t)
	Y0 += 0.00000000365*np.cos(0.53940975175 + 6922.9731363054*t)
	Y0 += 0.00000000409*np.cos(6.14577564379 + 10984.1923516998*t)
	Y0 += 0.00000000371*np.cos(4.19153897517 + 13625.533630172*t)
	Y0 += 0.00000000370*np.cos(2.79623025524 + 14919.0178537546*t)
	Y0 += 0.00000000499*np.cos(1.15482230725 + 161710.61878623239*t)
	Y0 += 0.00000000379*np.cos(5.52650430530 + 3185.1920272656*t)
	Y0 += 0.00000000420*np.cos(1.76851201552 + 22779.4372461938*t)
	Y0 += 0.00000000485*np.cos(6.06683096360 + 12528.018664345*t)
	Y0 += 0.00000000358*np.cos(1.58658367058 + 6271.3464971554*t)
	Y0 += 0.00000000358*np.cos(1.92035724848 + 6294.8052028274*t)
	Y0 += 0.00000000354*np.cos(2.96580857786 + 17267.26820169119*t)
	Y0 += 0.00000000351*np.cos(0.64808322427 + 11616.976091013*t)
	Y0 += 0.00000000409*np.cos(2.03946298626 + 21954.15760939799*t)
	Y0 += 0.00000000413*np.cos(0.42041417925 + 145.1097790097*t)
	Y0 += 0.00000000369*np.cos(3.36327405725 + 5436.9930152402*t)
	Y0 += 0.00000000336*np.cos(5.60932577353 + 127.4717966068*t)
	Y0 += 0.00000000421*np.cos(3.25654135729 + 7445.5505543992*t)
	Y0 += 0.00000000409*np.cos(0.70233676711 + 350.3321196004*t)
	Y0 += 0.00000000361*np.cos(5.53538077166 + 21393.5419698576*t)
	Y0 += 0.00000000336*np.cos(6.12569565789 + 6279.1436967283*t)
	Y0 += 0.00000000336*np.cos(3.66443056835 + 6287.0080032545*t)
	Y0 += 0.00000000450*np.cos(1.80230243402 + 1385.5615749511*t)
	Y0 += 0.00000000383*np.cos(4.56297720194 + 909.8187330546*t)
	Y0 += 0.00000000315*np.cos(3.47678894225 + 10873.9860304804*t)
	Y0 += 0.00000000375*np.cos(0.23620758788 + 108.4612160802*t)
	Y0 += 0.00000000363*np.cos(2.71990145670 + 7335.3442331798*t)
	Y0 += 0.00000000347*np.cos(5.27040068469 + 17253.04110768959*t)
	Y0 += 0.00000000395*np.cos(3.82348293170 + 5905.7022420756*t)
	Y0 += 0.00000000313*np.cos(2.04966851954 + 234.6397364404*t)
	Y0 += 0.00000000382*np.cos(0.24418522119 + 186.2117600641*t)
	Y0 += 0.00000000308*np.cos(2.54337606421 + 20995.3929664494*t)
	Y0 += 0.00000000319*np.cos(5.30613709521 + 38.0276726358*t)
	Y0 += 0.00000000304*np.cos(4.87224757874 + 5749.8617665478*t)
	Y0 += 0.00000000414*np.cos(5.73458482925 + 44809.6502008634*t)
	Y0 += 0.00000000298*np.cos(2.28443357697 + 640.8776073822*t)
	Y0 += 0.00000000351*np.cos(4.36315900786 + 12345.739057544*t)
	Y0 += 0.00000000304*np.cos(3.36893995706 + 29826.3063546732*t)
	Y0 += 0.00000000395*np.cos(4.78955929514 + 4176.041342449*t)
	Y0 += 0.00000000288*np.cos(5.63178266285 + 1905.4647649404*t)
	Y0 += 0.00000000374*np.cos(5.15697532254 + 5642.1982426092*t)
	Y0 += 0.00000000320*np.cos(0.92923666608 + 10818.1352869158*t)
	Y0 += 0.00000000365*np.cos(5.96664322939 + 6660.4494579072*t)
	Y0 += 0.00000000339*np.cos(4.53749520696 + 6923.9534573736*t)
	Y0 += 0.00000000357*np.cos(1.12153755723 + 16460.33352952499*t)
	Y0 += 0.00000000386*np.cos(0.71941423743 + 2636.725472637*t)
	Y0 += 0.00000000273*np.cos(5.79109432105 + 26709.6469424134*t)
	Y0 += 0.00000000308*np.cos(1.11858229845 + 362.8622925726*t)
	Y0 += 0.00000000265*np.cos(3.53930695872 + 19378.9185150688*t)
	Y0 += 0.00000000325*np.cos(0.92198442483 + 12359.9661515456*t)
	Y0 += 0.00000000311*np.cos(2.87485251647 + 297.6419215609*t)
	Y0 += 0.00000000289*np.cos(0.35271915498 + 529.1697002328*t)
	Y0 += 0.00000000264*np.cos(2.24237848599 + 1485.9801210652*t)
	Y0 += 0.00000000278*np.cos(3.86335874809 + 20597.2439630412*t)
	Y0 += 0.00000000289*np.cos(0.84527308658 + 530.2122299564*t)
	Y0 += 0.00000000294*np.cos(2.59935512947 + 28286.9904848612*t)
	Y0 += 0.00000000366*np.cos(1.35412421660 + 604.4725636619*t)
	Y0 += 0.00000000282*np.cos(0.06832834990 + 62.2514255951*t)
	Y0 += 0.00000000269*np.cos(4.91776226798 + 6816.289933435*t)
	Y0 += 0.00000000357*np.cos(2.74654149425 + 30666.1549584328*t)
	Y0 += 0.00000000263*np.cos(4.77643040513 + 52.6901980395*t)
	Y0 += 0.00000000344*np.cos(1.94480070409 + 6147.4505249814*t)
	Y0 += 0.00000000257*np.cos(2.63966270921 + 1258.4539316256*t)
	Y0 += 0.00000000308*np.cos(5.40069482744 + 29864.334027309*t)
	Y0 += 0.00000000334*np.cos(1.56223513612 + 6418.7011750014*t)
	Y0 += 0.00000000324*np.cos(5.37496427957 + 200.7689224658*t)
	Y0 += 0.00000000316*np.cos(3.97125662279 + 6055.5997172024*t)
	Y0 += 0.00000000275*np.cos(6.25194576299 + 565.1156877467*t)
	Y0 += 0.00000000269*np.cos(4.90534085198 + 140.001969579*t)
	Y0 += 0.00000000321*np.cos(5.03461670419 + 703.6331846174*t)
	Y0 += 0.00000000243*np.cos(2.53093250846 + 6310.4774060882*t)
	Y0 += 0.00000000243*np.cos(0.97600841060 + 6255.6742938946*t)
	Y0 += 0.00000000249*np.cos(4.80534758404 + 210.3783341312*t)
	Y0 += 0.00000000248*np.cos(3.22187918056 + 216.2198567448*t)
	Y0 += 0.00000000243*np.cos(5.15609899738 + 1062.5633239269*t)
	Y0 += 0.00000000336*np.cos(6.10975677385 + 454.9093665273*t)
	Y0 += 0.00000000296*np.cos(4.79138384974 + 6129.2970395066*t)
	Y0 += 0.00000000240*np.cos(1.67381717935 + 37.611770776*t)
	Y0 += 0.00000000237*np.cos(2.15132956903 + 212.5483359126*t)
	Y0 += 0.00000000255*np.cos(3.33122871209 + 153.4953503977*t)
	Y0 += 0.00000000301*np.cos(5.81886973641 + 6510.5519827804*t)
	Y0 += 0.00000000329*np.cos(5.86928788098 + 377.3736079158*t)
	Y0 += 0.00000000236*np.cos(5.87788994285 + 214.0498549634*t)
	Y0 += 0.00000000282*np.cos(3.64505853337 + 263.0839233728*t)
	Y0 += 0.00000000267*np.cos(1.84936252726 + 24705.70520908959*t)
	Y0 += 0.00000000285*np.cos(0.93414827012 + 5469.5255660316*t)
	Y0 += 0.00000000236*np.cos(2.66792286959 + 38.6543004996*t)
	Y0 += 0.00000000234*np.cos(0.33992064306 + 5017.508371365*t)
	Y0 += 0.00000000252*np.cos(3.03988883560 + 209.106309744*t)
	Y0 += 0.00000000286*np.cos(4.99886287753 + 6436.8546604762*t)
	Y0 += 0.00000000309*np.cos(0.57495592500 + 27511.4678735372*t)
	Y0 += 0.00000000248*np.cos(4.98513016170 + 217.491881132*t)
	Y0 += 0.00000000319*np.cos(3.13977654412 + 169379.25621117488*t)
	Y0 += 0.00000000263*np.cos(6.04953863141 + 11712.9553182308*t)
	Y0 += 0.00000000225*np.cos(1.81041528541 + 223.5940361765*t)
	Y0 += 0.00000000285*np.cos(5.85104532566 + 16522.6597160022*t)
	Y0 += 0.00000000224*np.cos(3.94824411240 + 38.084851528*t)
	Y0 += 0.00000000223*np.cos(0.39234241482 + 38.1812197476*t)
	Y0 += 0.00000000235*np.cos(4.94143074133 + 4487.8174062704*t)
	Y0 += 0.00000000253*np.cos(2.08490293021 + 4377.611085051*t)
	Y0 += 0.00000000312*np.cos(1.61150992635 + 11720.0688652316*t)
	Y0 += 0.00000000220*np.cos(6.00356459702 + 20199.094959633*t)
	Y0 += 0.00000000216*np.cos(6.22908327759 + 2125.8774073792*t)
	Y0 += 0.00000000244*np.cos(2.64604748092 + 173.9422195228*t)
	Y0 += 0.00000000213*np.cos(2.22365237019 + 30355.9973197678*t)
	Y0 += 0.00000000234*np.cos(5.26336192114 + 74.2603337055*t)
	Y0 += 0.00000000233*np.cos(5.70130722395 + 75.3028634291*t)
	Y0 += 0.00000000247*np.cos(5.27605423414 + 252.6559713532*t)
	Y0 += 0.00000000259*np.cos(1.86047749915 + 6282.83203250789*t)
	Y0 += 0.00000000259*np.cos(1.64646341991 + 6283.3196674749*t)
	Y0 += 0.00000000203*np.cos(5.54978754111 + 18.1592472647*t)
	Y0 += 0.00000000282*np.cos(6.12964546434 + 563.6312150384*t)
	Y0 += 0.00000000243*np.cos(2.57267015777 + 7096.6261339512*t)
	Y0 += 0.00000000221*np.cos(4.65757923242 + 5540.0857894588*t)
	Y0 += 0.00000000224*np.cos(0.66388865647 + 88.865680217*t)
	Y0 += 0.00000000246*np.cos(4.26495076165 + 8671.9698704406*t)
	Y0 += 0.00000000208*np.cos(3.10897679499 + 10440.2742926036*t)
	Y0 += 0.00000000199*np.cos(5.64807046697 + 11216.284290324*t)
	Y0 += 0.00000000205*np.cos(4.98750840184 + 417.0369633204*t)
	Y0 += 0.00000000211*np.cos(3.56508711838 + 37.1698277913*t)
	Y0 += 0.00000000215*np.cos(5.07155551847 + 1699.2792165032*t)
	Y0 += 0.00000000207*np.cos(1.49549061720 + 12562.561271331*t)
	Y0 += 0.00000000212*np.cos(0.18391974040 + 7129.1586847426*t)
	Y0 += 0.00000000269*np.cos(6.23907991227 + 70755.06709173629*t)
	Y0 += 0.00000000192*np.cos(2.70968461449 + 66.70484372*t)
	Y0 += 0.00000000224*np.cos(5.58680388524 + 5636.0650166766*t)
	Y0 += 0.00000000192*np.cos(0.47333599881 + 17271.8840075264*t)
	Y0 += 0.00000000204*np.cos(2.47411750627 + 207.6700211455*t)
	Y0 += 0.00000000228*np.cos(3.58367417249 + 207.8824694666*t)
	Y0 += 0.00000000241*np.cos(3.52161359834 + 15906.7641266826*t)
	Y0 += 0.00000000203*np.cos(0.77682463263 + 39.0962434843*t)
	Y0 += 0.00000000186*np.cos(2.34538148826 + 1898.3512179396*t)
	Y0 += 0.00000000257*np.cos(0.87147328095 + 48739.859897083*t)
	Y0 += 0.00000000184*np.cos(3.83487369725 + 9380.9596727172*t)
	Y0 += 0.00000000220*np.cos(4.46432405157 + 218.7157214094*t)
	Y0 += 0.00000000250*np.cos(2.67103537581 + 5934.1514295434*t)
	Y0 += 0.00000000185*np.cos(1.51386870105 + 19800.9459562248*t)
	Y0 += 0.00000000186*np.cos(2.59788381829 + 508.3503240922*t)
	Y0 += 0.00000000195*np.cos(5.53819155539 + 218.9281697305*t)
	Y0 += 0.00000000189*np.cos(2.52919302388 + 16062.1845261168*t)
	Y0 += 0.00000000175*np.cos(3.84093628240 + 11614.4332937322*t)
	Y0 += 0.00000000175*np.cos(6.15313646522 + 3744.8273457378*t)
	Y0 += 0.00000000241*np.cos(5.00040455119 + 8390.1103575338*t)
	Y0 += 0.00000000193*np.cos(4.71506547135 + 394.6258850592*t)
	Y0 += 0.00000000178*np.cos(4.08297672654 + 211.8146227297*t)
	Y0 += 0.00000000224*np.cos(2.49436555659 + 1056.2005364515*t)
	Y0 += 0.00000000195*np.cos(0.90841744066 + 28.5718080822*t)
	Y0 += 0.00000000189*np.cos(4.03411872458 + 401.6721217572*t)
	Y0 += 0.00000000190*np.cos(4.35107066119 + 142.4496501338*t)
	Y0 += 0.00000000230*np.cos(0.83612842798 + 6632.0002704394*t)
	Y0 += 0.00000000171*np.cos(1.38853028989 + 526.7702037878*t)
	Y0 += 0.00000000227*np.cos(4.16811397278 + 34596.3646546524*t)
	Y0 += 0.00000000165*np.cos(0.39341190294 + 10454.5013866052*t)
	Y0 += 0.00000000221*np.cos(2.07224292531 + 6206.8097787158*t)
	Y0 += 0.00000000186*np.cos(5.42678326989 + 554.0699874828*t)
	Y0 += 0.00000000201*np.cos(6.23059857608 + 3097.88382272579*t)
	Y0 += 0.00000000169*np.cos(6.09402587013 + 532.6117264014*t)
	Y0 += 0.00000000217*np.cos(2.01707572818 + 124.433415221*t)
	Y0 += 0.00000000205*np.cos(2.56533473350 + 16627.3709153772*t)
	Y0 += 0.00000000178*np.cos(0.01807925983 + 4797.0957289262*t)
	Y0 += 0.00000000175*np.cos(5.92248308601 + 525.4981794006*t)
	Y0 += 0.00000000225*np.cos(3.43883654828 + 266.6070417218*t)
	Y0 += 0.00000000167*np.cos(2.40308228314 + 5714.253975964*t)
	Y0 += 0.00000000167*np.cos(1.16660958168 + 10344.2950653858*t)
	Y0 += 0.00000000172*np.cos(3.81893679688 + 6332.8328754632*t)
	Y0 += 0.00000000172*np.cos(5.97118942936 + 6233.3188245196*t)
	Y0 += 0.00000000214*np.cos(2.77237801335 + 24492.40611365159*t)
	Y0 += 0.00000000187*np.cos(1.52481751621 + 1574.8458012822*t)
	Y0 += 0.00000000159*np.cos(2.33166453392 + 13198.935439296*t)
	Y0 += 0.00000000158*np.cos(5.04734034343 + 528.9402055692*t)
	Y0 += 0.00000000169*np.cos(0.93171590629 + 1471.7530270636*t)
	Y0 += 0.00000000157*np.cos(2.43465536306 + 530.44172462*t)
	Y0 += 0.00000000207*np.cos(1.92518585993 + 12569.7421286346*t)
	Y0 += 0.00000000188*np.cos(1.87050370857 + 569.0478410098*t)
	Y0 += 0.00000000194*np.cos(2.55166855580 + 183.2428146475*t)
	Y0 += 0.00000000176*np.cos(2.48119329994 + 12012.5822971404*t)
	Y0 += 0.00000000196*np.cos(5.41851032427 + 11087.2851259184*t)
	Y0 += 0.00000000199*np.cos(2.28730999946 + 1685.0521225016*t)
	Y0 += 0.00000000161*np.cos(2.18455666842 + 12132.439962106*t)
	Y0 += 0.00000000170*np.cos(5.35052715864 + 6272.0301497275*t)
	Y0 += 0.00000000170*np.cos(4.43959906760 + 6294.1215502553*t)
	Y0 += 0.00000000168*np.cos(3.97617357428 + 17686.7528455664*t)
	Y0 += 0.00000000178*np.cos(6.20228633181 + 5.9378908332*t)
	Y0 += 0.00000000207*np.cos(0.24572465192 + 73.8183907208*t)
	Y0 += 0.00000000185*np.cos(3.34815986923 + 265.9892934775*t)
	Y0 += 0.00000000175*np.cos(5.99371438486 + 217.964961884*t)
	Y0 += 0.00000000148*np.cos(2.83101653780 + 519.3960243561*t)
	Y0 += 0.00000000199*np.cos(5.15620822027 + 33326.5787331742*t)
	Y0 += 0.00000000146*np.cos(2.06659470489 + 82.8583534146*t)
	Y0 += 0.00000000192*np.cos(4.39395898967 + 425.1137181677*t)
	Y0 += 0.00000000194*np.cos(2.13712729333 + 28.4491874678*t)
	Y0 += 0.00000000144*np.cos(2.03929994576 + 16737.5772365966*t)
	Y0 += 0.00000000149*np.cos(1.96157392100 + 414.0680179038*t)
	Y0 += 0.00000000165*np.cos(3.65136085639 + 231.4583427027*t)
	Y0 += 0.00000000201*np.cos(4.11002299299 + 453.424893819*t)
	Y0 += 0.00000000200*np.cos(4.96476307548 + 1439.5096981492*t)
	Y0 += 0.00000000148*np.cos(1.10385881777 + 6851.8977240188*t)
	Y0 += 0.00000000146*np.cos(4.95201849548 + 17370.3609759098*t)
	Y0 += 0.00000000143*np.cos(5.56441147227 + 5618.3198048614*t)
	Y0 += 0.00000000140*np.cos(4.10887314023 + 408.4389436113*t)
	Y0 += 0.00000000191*np.cos(4.47590456732 + 75.7448064138*t)
	Y0 += 0.00000000162*np.cos(3.21674523006 + 12551.9246059812*t)
	Y0 += 0.00000000143*np.cos(3.89365374642 + 5010.3948243642*t)
	Y0 += 0.00000000149*np.cos(1.58541955295 + 533.8837507886*t)
	Y0 += 0.00000000161*np.cos(1.75025798421 + 31441.6775697568*t)
	Y0 += 0.00000000151*np.cos(4.72729575304 + 16723.350142595*t)
	Y0 += 0.00000000135*np.cos(4.79054860554 + 12431.0866199474*t)
	Y0 += 0.00000000158*np.cos(2.03821572977 + 208.633228992*t)
	Y0 += 0.00000000153*np.cos(3.42669369028 + 47.6942631934*t)
	Y0 += 0.00000000131*np.cos(6.22770537067 + 203.0041546995*t)
	Y0 += 0.00000000183*np.cos(0.59231255504 + 1021.2488945514*t)
	Y0 += 0.00000000139*np.cos(4.27354999851 + 373.9079928365*t)
	Y0 += 0.00000000139*np.cos(4.04425486837 + 214.7835681463*t)
	Y0 += 0.00000000148*np.cos(3.93657905776 + 28766.924424484*t)
	Y0 += 0.00000000146*np.cos(6.27087503385 + 12701.2167800182*t)
	Y0 += 0.00000000167*np.cos(5.98371371124 + 17473.4537501284*t)
	Y0 += 0.00000000166*np.cos(1.38695682715 + 305.3461693927*t)
	Y0 += 0.00000000161*np.cos(1.02898808001 + 20452.8694122218*t)
	Y0 += 0.00000000124*np.cos(4.22571513469 + 6947.8318951214*t)
	Y0 += 0.00000000135*np.cos(4.95838914470 + 3531.5282502998*t)
	Y0 += 0.00000000172*np.cos(0.23035302794 + 167959.39011405829*t)
	Y0 += 0.00000000130*np.cos(0.69748880175 + 654.1243803156*t)
	Y0 += 0.00000000122*np.cos(4.12184077581 + 3583.3410306738*t)
	Y0 += 0.00000000170*np.cos(6.16462338453 + 333857.59012677266*t)
	Y0 += 0.00000000144*np.cos(6.26381421560 + 4.192785694*t)
	Y0 += 0.00000000155*np.cos(5.62826239458 + 6058.7310542895*t)
	Y0 += 0.00000000120*np.cos(5.90379805618 + 12808.8803039568*t)
	Y0 += 0.00000000141*np.cos(3.95455987291 + 162420.55183479069*t)
	Y0 += 0.00000000139*np.cos(5.93780077355 + 251.4321310758*t)
	Y0 += 0.00000000121*np.cos(3.73123340759 + 479.2883889155*t)
	Y0 += 0.00000000119*np.cos(5.90821338773 + 114.1384744825*t)
	Y0 += 0.00000000120*np.cos(4.26997270152 + 12528.124027347*t)
	Y0 += 0.00000000119*np.cos(5.90934719297 + 19247.3765533824*t)
	Y0 += 0.00000000117*np.cos(5.45034772919 + 11610.5519583742*t)
	Y0 += 0.00000000163*np.cos(1.54432161045 + 661.232926781*t)
	Y0 += 0.00000000161*np.cos(2.28994816795 + 52670.0695933026*t)
	Y0 += 0.00000000163*np.cos(2.78769644779 + 9929.4262273458*t)
	Y0 += 0.00000000119*np.cos(2.71628583938 + 12249.7598303262*t)
	Y0 += 0.00000000145*np.cos(1.17170397718 + 6360.7496204194*t)
	Y0 += 0.00000000145*np.cos(2.33523694188 + 6205.4020795634*t)
	Y0 += 0.00000000115*np.cos(4.65379442884 + 539.9859058331*t)
	Y0 += 0.00000000159*np.cos(2.61434351364 + 228278.10465148659*t)
	Y0 += 0.00000000156*np.cos(1.00708912320 + 4307.5833041354*t)
	Y0 += 0.00000000118*np.cos(5.95164477875 + 6302.74561089119*t)
	Y0 += 0.00000000118*np.cos(3.83848144749 + 6263.4060890916*t)
	Y0 += 0.00000000114*np.cos(3.22069040111 + 213.4109700226*t)
	Y0 += 0.00000000114*np.cos(4.81084790265 + 213.1872208534*t)
	Y0 += 0.00000000129*np.cos(6.17361043988 + 302.164775655*t)
	Y0 += 0.00000000135*np.cos(2.80387650268 + 19804.8272915828*t)
	Y0 += 0.00000000112*np.cos(3.88136222265 + 16840.67001081519*t)
	Y0 += 0.00000000148*np.cos(3.55909740786 + 28237.2334593894*t)
	Y0 += 0.00000000124*np.cos(5.50657775921 + 10239.5838660108*t)
	Y0 += 0.00000000137*np.cos(2.53358646423 + 6250.54329920*t)
	Y0 += 0.00000000137*np.cos(0.97335445483 + 6315.6084007828*t)
	Y0 += 0.00000000111*np.cos(0.70362725529 + 6339.974224927*t)
	Y0 += 0.00000000111*np.cos(2.80331366377 + 6226.1774750558*t)
	Y0 += 0.00000000139*np.cos(4.20829691432 + 11609.8625440122*t)
	Y0 += 0.00000000124*np.cos(3.12647421017 + 19402.7969528166*t)
	Y0 += 0.00000000123*np.cos(0.80538262187 + 24734.1543965574*t)
	Y0 += 0.00000000107*np.cos(0.59542543867 + 12463.0589257642*t)
	Y0 += 0.00000000140*np.cos(5.62756230388 + 38526.574350872*t)
	Y0 += 0.00000000116*np.cos(5.36019004356 + 524.0618908021*t)
	Y0 += 0.00000000123*np.cos(5.71833316259 + 6305.8510514422*t)
	Y0 += 0.00000000123*np.cos(4.07179306365 + 6260.3006485406*t)
	Y0 += 0.00000000115*np.cos(2.12419003336 + 535.3200393871*t)
	Y0 += 0.00000000117*np.cos(1.11114131260 + 24336.0053931492*t)
	Y0 += 0.00000000131*np.cos(2.04122395494 + 18415.51581209739*t)
	Y0 += 0.00000000106*np.cos(2.18835416515 + 12341.8069042809*t)
	Y0 += 0.00000000110*np.cos(3.31587494701 + 6276.44729109139*t)
	Y0 += 0.00000000110*np.cos(0.19106597205 + 6289.70440889141*t)
	Y0 += 0.00000000103*np.cos(1.18729919186 + 6324.6266409762*t)
	Y0 += 0.00000000103*np.cos(2.31964172720 + 6241.5250590066*t)
	Y0 += 0.00000000126*np.cos(5.34406107671 + 540.7366653585*t)
	Y0 += 0.00000000131*np.cos(5.93782050272 + 5791.4125575326*t)
	Y0 += 0.00000000119*np.cos(4.95824095217 + 983.1158589136*t)
	Y0 += 0.00000000107*np.cos(0.14948042255 + 83973.83535572988*t)
	Y0 += 0.00000000107*np.cos(1.18803015964 + 84019.8592804939*t)
	Y0 += 0.00000000106*np.cos(1.70601019340 + 12772.33724842*t)
	Y0 += 0.00000000143*np.cos(6.22488817389 + 2069.0068349066*t)
	Y0 += 0.00000000115*np.cos(0.35603129387 + 98.8999885246*t)
	Y0 += 0.00000000143*np.cos(5.63221604750 + 18772.9614786986*t)
	Y0 += 0.00000000115*np.cos(5.35511207484 + 3641.7345715192*t)
	Y0 += 0.00000000121*np.cos(3.53431033420 + 17996.0311682222*t)
	Y0 += 0.00000000118*np.cos(4.91950265277 + 525.0250986486*t)
	Y0 += 0.00000000102*np.cos(1.89629804705 + 56.6223513026*t)
	Y0 += 0.00000000100*np.cos(2.14566059864 + 529.851023789*t)
	Y0 += 0.00000000100*np.cos(5.33661471676 + 529.5309064002*t)
	Y0 += 0.00000000099*np.cos(0.29530316101 + 198.321241911*t)
	Y0 += 0.00000000126*np.cos(5.90533164276 + 18822.9292301744*t)
	Y0 += 0.00000000102*np.cos(6.02433300674 + 963.4027029714*t)
	Y0 += 0.00000000115*np.cos(3.09464836385 + 12570.0838532459*t)
	Y0 += 0.00000000119*np.cos(0.26217017763 + 9814.6041002912*t)
	Y0 += 0.00000000138*np.cos(0.51855418741 + 6356.3729758504*t)
	Y0 += 0.00000000138*np.cos(2.98838673165 + 6209.7787241324*t)
	Y0 += 0.00000000109*np.cos(2.17221801259 + 175.1660598002*t)
	Y0 += 0.00000000100*np.cos(3.07908951574 + 5.5229243074*t)
	Y0 += 0.00000000135*np.cos(5.28292512146 + 18699.6643528396*t)
	Y0 += 0.00000000104*np.cos(0.57981411648 + 12560.6287756754*t)
	Y0 += 0.00000000111*np.cos(6.01414242152 + 80.1982245387*t)
	Y0 += 0.00000000098*np.cos(4.00434933508 + 5815.11085963699*t)
	Y0 += 0.00000000096*np.cos(3.47793123567 + 22743.4093795164*t)
	Y0 += 0.00000000096*np.cos(5.43048994495 + 213.0866471169*t)
	Y0 += 0.00000000096*np.cos(2.60104835880 + 213.5115437591*t)
	Y0 += 0.00000000099*np.cos(4.90758830995 + 551.031606097*t)
	Y0 += 0.00000000113*np.cos(1.88238867485 + 2324.9494088156*t)
	Y0 += 0.00000000111*np.cos(2.56844286864 + 534.3568315406*t)
	Y0 += 0.00000000117*np.cos(0.19396627342 + 524.2743391232*t)
	Y0 += 0.00000000095*np.cos(3.70643398698 + 327.4375699205*t)
	Y0 += 0.00000000114*np.cos(2.18292460802 + 6155.057006654*t)
	Y0 += 0.00000000114*np.cos(1.32401631104 + 6411.0946933288*t)
	Y0 += 0.00000000104*np.cos(5.47404374073 + 32.1951448046*t)
	Y0 += 0.00000000127*np.cos(3.26672162678 + 21.3406410024*t)
	Y0 += 0.00000000093*np.cos(0.34809743975 + 11190.377900137*t)
	Y0 += 0.00000000115*np.cos(1.00365590687 + 535.107591066*t)
	Y0 += 0.00000000095*np.cos(4.06228552408 + 11300.5842213564*t)
	Y0 += 0.00000000117*np.cos(2.41831042685 + 24383.0791084414*t)
	Y0 += 0.00000000110*np.cos(2.28653466592 + 6253.6463414554*t)
	Y0 += 0.00000000110*np.cos(1.22040625314 + 6312.5053585274*t)
	Y0 += 0.00000000091*np.cos(1.42377843647 + 12829.2356233556*t)
	Y0 += 0.00000000096*np.cos(4.77567549605 + 35.685355083*t)
	Y0 += 0.00000000120*np.cos(4.42365311529 + 17892.93839400359*t)
	Y0 += 0.00000000090*np.cos(4.05016333707 + 15664.03552270859*t)
	Y0 += 0.00000000126*np.cos(0.70432668892 + 1293.4842235826*t)
	Y0 += 0.00000000103*np.cos(2.84917048342 + 219.891377577*t)
	Y0 += 0.00000000126*np.cos(4.96989709208 + 311565.01892104017*t)
	Y0 += 0.00000000091*np.cos(4.79589087629 + 1802.3719907218*t)
	Y0 += 0.00000000120*np.cos(0.51717377640 + 14158.7477136156*t)
	Y0 += 0.00000000090*np.cos(1.60104298475 + 1382.8873468466*t)
	Y0 += 0.00000000110*np.cos(1.99803947181 + 16097.6799502826*t)
	Y0 += 0.00000000092*np.cos(1.75886109740 + 21424.4666443034*t)
	Y0 += 0.00000000099*np.cos(2.04878528903 + 6432.639047126*t)
	Y0 += 0.00000000093*np.cos(4.20565309570 + 99.1606209555*t)
	Y0 += 0.00000000124*np.cos(5.19244899173 + 178430.0471905317*t)
	Y0 += 0.00000000088*np.cos(0.12768507477 + 15141.390794312*t)
	Y0 += 0.00000000089*np.cos(5.78577662098 + 6751.0408403458*t)
	Y0 += 0.00000000096*np.cos(1.07414401415 + 7349.5713271814*t)
	Y0 += 0.00000000094*np.cos(1.30652024350 + 2699.7348193176*t)
	Y0 += 0.00000000087*np.cos(1.63535344372 + 23141.5583829246*t)
	Y0 += 0.00000000087*np.cos(1.28166497839 + 228.276948965*t)
	Y0 += 0.00000000103*np.cos(2.80666225492 + 18202.21671665939*t)
	Y0 += 0.00000000099*np.cos(5.29408634455 + 6313.9899756264*t)
	Y0 += 0.00000000099*np.cos(4.49603988169 + 6252.1617243564*t)
	Y0 += 0.00000000100*np.cos(1.82319423846 + 96.8729990951*t)
	Y0 += 0.00000000090*np.cos(1.96045243600 + 58864.5439181463*t)
	Y0 += 0.00000000113*np.cos(3.06789441452 + 10557.5941608238*t)
	Y0 += 0.00000000085*np.cos(3.63689104790 + 74.8297826771*t)
	Y0 += 0.00000000085*np.cos(1.04303023325 + 74.7334144575*t)
	Y0 += 0.00000000098*np.cos(1.66301652528 + 6126.675129489*t)
	Y0 += 0.00000000098*np.cos(1.84392439378 + 6439.4765704938*t)
	Y0 += 0.00000000086*np.cos(6.05385675766 + 23123.74586080659*t)
	Y0 += 0.00000000094*np.cos(5.54106526599 + 23539.7073863328*t)
	Y0 += 0.00000000113*np.cos(5.85548952542 + 177.8743727859*t)
	Y0 += 0.00000000118*np.cos(2.16762826283 + 13951.7132749339*t)
	Y0 += 0.00000000117*np.cos(2.53845687210 + 89569.99011954499*t)
	Y0 += 0.00000000083*np.cos(4.71523084157 + 8858.3149443206*t)
	Y0 += 0.00000000101*np.cos(4.94270501848 + 18429.742906099*t)
	Y0 += 0.00000000088*np.cos(2.19663281211 + 17053.96910625319*t)
	Y0 += 0.00000000113*np.cos(0.47970289838 + 12985.636343858*t)
	Y0 += 0.00000000082*np.cos(4.90614256431 + 5483.254724826*t)
	Y0 += 0.00000000085*np.cos(5.99437376237 + 191.9584544356*t)
	Y0 += 0.00000000087*np.cos(5.84639583938 + 40.5807161926*t)
	Y0 += 0.00000000095*np.cos(0.81797133475 + 11925.2740926006*t)
	Y0 += 0.00000000084*np.cos(2.66665772953 + 6379.0550772092*t)
	Y0 += 0.00000000084*np.cos(0.84028318953 + 6187.0966227736*t)
	Y0 += 0.00000000093*np.cos(3.10680657507 + 35371.8872659764*t)
	Y0 += 0.00000000105*np.cos(2.30294939014 + 6131.1785689062*t)
	Y0 += 0.00000000105*np.cos(1.20399152892 + 6434.9731310766*t)
	Y0 += 0.00000000114*np.cos(2.50001433093 + 8258.5683958474*t)
	Y0 += 0.00000000084*np.cos(3.82196413310 + 32217.2001810808*t)
	Y0 += 0.00000000082*np.cos(5.40278723857 + 3958.1264411758*t)
	Y0 += 0.00000000102*np.cos(4.67254721576 + 131.4039498699*t)
	Y0 += 0.00000000102*np.cos(1.32703960779 + 5767.6119788984*t)
	Y0 += 0.00000000102*np.cos(2.17990131127 + 6798.5397210844*t)
	Y0 += 0.00000000093*np.cos(5.77977069690 + 74.5209661364*t)
	Y0 += 0.00000000092*np.cos(6.07396273786 + 18216.443810661*t)
	Y0 += 0.00000000112*np.cos(3.91825505548 + 12188.778092067*t)
	Y0 += 0.00000000093*np.cos(5.18093640996 + 75.0422309982*t)
	Y0 += 0.00000000080*np.cos(2.87647086515 + 278.5194664497*t)
	Y0 += 0.00000000089*np.cos(1.46011729281 + 191.2076949102*t)
	Y0 += 0.00000000086*np.cos(4.18439486840 + 16193.65917750039*t)
	Y0 += 0.00000000080*np.cos(2.01988251452 + 24080.03501677719*t)
	Y0 += 0.00000000079*np.cos(2.74811848231 + 38.0211610532*t)
	Y0 += 0.00000000093*np.cos(4.66163367881 + 23937.856389741*t)
	Y0 += 0.00000000079*np.cos(1.59253269036 + 38.2449102224*t)
	Y0 += 0.00000000088*np.cos(4.57496913724 + 1573.8204240988*t)
	Y0 += 0.00000000092*np.cos(2.79375473262 + 101426.20877096949*t)
	Y0 += 0.00000000110*np.cos(5.08243853758 + 78423.70451667879*t)
	Y0 += 0.00000000087*np.cos(3.89286413327 + 1580.8666607968*t)
	Y0 += 0.00000000083*np.cos(0.78518936484 + 300.6108669775*t)
	Y0 += 0.00000000078*np.cos(5.64618149774 + 30.0562807905*t)
	Y0 += 0.00000000097*np.cos(3.75597837361 + 259.5088859231*t)
	Y0 += 0.00000000080*np.cos(1.70826898567 + 6485.3292451655*t)
	Y0 += 0.00000000080*np.cos(1.79867193339 + 6080.8224548173*t)
	Y0 += 0.00000000079*np.cos(6.16114738580 + 40796.33892267419*t)
	Y0 += 0.00000000079*np.cos(2.96735408932 + 36109.38220466459*t)
	Y0 += 0.00000000088*np.cos(5.58306387433 + 16943.7627850338*t)
	Y0 += 0.00000000093*np.cos(0.22422436515 + 283.8593188652*t)
	Y0 += 0.00000000088*np.cos(1.67821631800 + 12537.702512515*t)
	Y0 += 0.00000000085*np.cos(5.14758347117 + 44.070926471*t)
	Y0 += 0.00000000079*np.cos(4.76362160922 + 41194.4879260824*t)
	Y0 += 0.00000000081*np.cos(5.19149105668 + 3956.5080160194*t)
	Y0 += 0.00000000089*np.cos(2.25592202290 + 835.0371344873*t)
	Y0 += 0.00000000076*np.cos(3.13724740029 + 106.2741679563*t)
	Y0 += 0.00000000091*np.cos(2.31009109472 + 80.7194894005*t)
	Y0 += 0.00000000075*np.cos(0.93284040810 + 205.2223405907*t)
	Y0 += 0.00000000103*np.cos(3.71008010926 + 56600.2792895222*t)
	Y0 += 0.00000000079*np.cos(1.02058994543 + 74.6215398729*t)
	Y0 += 0.00000000078*np.cos(3.65920759701 + 74.9416572617*t)
	Y0 += 0.00000000079*np.cos(2.93697301370 + 5621.8429232104*t)
	Y0 += 0.00000000096*np.cos(0.41418225890 + 5888.4499649322*t)
	Y0 += 0.00000000096*np.cos(3.09275866016 + 6677.7017350506*t)
	Y0 += 0.00000000074*np.cos(4.41044639229 + 6304.4114904584*t)
	Y0 += 0.00000000074*np.cos(5.37967983395 + 6261.7402095244*t)
	Y0 += 0.00000000073*np.cos(1.05049706961 + 6695.4469468658*t)
	Y0 += 0.00000000073*np.cos(2.45644384945 + 5870.704753117*t)
	Y0 += 0.00000000073*np.cos(1.61765616896 + 16207.886271502*t)
	Y0 += 0.00000000085*np.cos(2.08161902252 + 12850.011018848*t)
	Y0 += 0.00000000075*np.cos(3.08910097280 + 3178.1457905676*t)
	Y0 += 0.00000000077*np.cos(1.39895481144 + 195.1398481733*t)
	Y0 += 0.00000000072*np.cos(4.78502700351 + 213.0384630071*t)
	Y0 += 0.00000000072*np.cos(3.24651089369 + 213.5597278689*t)
	Y0 += 0.00000000096*np.cos(2.67801150530 + 483.2205421786*t)
	Y0 += 0.00000000086*np.cos(2.73735833770 + 2.4476805548*t)
	Y0 += 0.00000000072*np.cos(5.03595593677 + 6312.8972881402*t)
	Y0 += 0.00000000072*np.cos(4.75417028947 + 6253.25441184259*t)
	Y0 += 0.00000000100*np.cos(3.80714752393 + 5316.1049725558*t)
	Y0 += 0.00000000085*np.cos(1.33904345426 + 12282.2923811176*t)
	Y0 += 0.00000000077*np.cos(5.07586430304 + 22345.2603761082*t)
	Y0 += 0.00000000075*np.cos(0.39510451579 + 24422.3703514073*t)
	Y0 += 0.00000000076*np.cos(0.41146256256 + 63658.8777508376*t)
	Y0 += 0.00000000087*np.cos(2.06336091493 + 18106.2374894416*t)
	Y0 += 0.00000000070*np.cos(0.44640955505 + 6442.0193677746*t)
	Y0 += 0.00000000070*np.cos(3.06053136401 + 6124.1323322082*t)
	Y0 += 0.00000000074*np.cos(5.61945589711 + 15265.8865193004*t)
	Y0 += 0.00000000078*np.cos(3.38283383527 + 23550.34405168259*t)
	Y0 += 0.00000000077*np.cos(5.00656029204 + 5237.9210138038*t)
	Y0 += 0.00000000075*np.cos(3.64547243832 + 27832.0382192832*t)
	Y0 += 0.00000000095*np.cos(2.11170756015 + 248.7238180901*t)
	Y0 += 0.00000000069*np.cos(1.88886878891 + 529.4785167735*t)
	Y0 += 0.00000000069*np.cos(5.59340951305 + 529.9034134157*t)
	Y0 += 0.00000000076*np.cos(1.98904461594 + 518.6452648307*t)
	Y0 += 0.00000000082*np.cos(3.91623659935 + 6774.7391424502*t)
	Y0 += 0.00000000067*np.cos(4.88284279928 + 7082.8969751568*t)
	Y0 += 0.00000000067*np.cos(3.24232940659 + 6171.8892077038*t)
	Y0 += 0.00000000067*np.cos(0.26461151247 + 6394.262492279*t)
	Y0 += 0.00000000080*np.cos(3.79677325613 + 22380.755800274*t)
	Y0 += 0.00000000070*np.cos(0.47599032576 + 6175.4123260528*t)
	Y0 += 0.00000000070*np.cos(3.03095059330 + 6390.73937393*t)
	Y0 += 0.00000000066*np.cos(0.44946982323 + 635.9651330509*t)
	Y0 += 0.00000000077*np.cos(0.29137018417 + 9924.8104215106*t)
	Y0 += 0.00000000091*np.cos(0.90446873976 + 6652.7756659318*t)
	Y0 += 0.00000000091*np.cos(2.60247217930 + 5913.376034051*t)
	Y0 += 0.00000000067*np.cos(4.84479908786 + 6300.8883721094*t)
	Y0 += 0.00000000067*np.cos(4.94532713838 + 6265.2633278734*t)
	Y0 += 0.00000000066*np.cos(1.92154628038 + 2214.7430875962*t)
	Y0 += 0.00000000074*np.cos(2.48641792134 + 68.8437077341*t)
	Y0 += 0.00000000088*np.cos(3.59122542798 + 10660.6869350424*t)
	Y0 += 0.00000000066*np.cos(3.01430181986 + 5959.570433334*t)
	Y0 += 0.00000000080*np.cos(5.49178527606 + 23646.32327890039*t)
	Y0 += 0.00000000068*np.cos(2.07232411643 + 4897.1805736552*t)
	Y0 += 0.00000000069*np.cos(0.56996801147 + 6944.3087767724*t)
	Y0 += 0.00000000084*np.cos(5.41269775901 + 424.1505103212*t)
	Y0 += 0.00000000071*np.cos(1.03137133715 + 275.5505210331*t)
	Y0 += 0.00000000066*np.cos(4.46930207827 + 33.9402499438*t)
	Y0 += 0.00000000073*np.cos(2.96334792367 + 6195.76764545159*t)
	Y0 += 0.00000000073*np.cos(0.54359299539 + 6370.3840545312*t)
	Y0 += 0.00000000071*np.cos(3.57166978930 + 17363.24742890899*t)
	Y0 += 0.00000000063*np.cos(1.65767004610 + 20.6069278195*t)
	Y0 += 0.00000000074*np.cos(1.56614709067 + 27043.5028831828*t)
	Y0 += 0.00000000066*np.cos(2.38194509538 + 6251.1035441746*t)
	Y0 += 0.00000000066*np.cos(1.12499582368 + 6315.0481558082*t)
	Y0 += 0.00000000083*np.cos(5.09775374255 + 404.5067903482*t)
	Y0 += 0.00000000063*np.cos(2.94014383007 + 8.0767548473*t)
	Y0 += 0.00000000068*np.cos(2.22365421702 + 831.8557407496*t)
	Y0 += 0.00000000082*np.cos(5.88510225867 + 154.0166152595*t)
	Y0 += 0.00000000078*np.cos(0.83740696355 + 42456.7840470916*t)
	Y0 += 0.00000000063*np.cos(2.70916268945 + 11823.1616394502*t)
	Y0 += 0.00000000064*np.cos(4.80330562067 + 28774.0379714848*t)
	Y0 += 0.00000000081*np.cos(2.12955581519 + 37.8724032069*t)
	Y0 += 0.00000000079*np.cos(5.66337403718 + 24065.80792277559*t)
	Y0 += 0.00000000072*np.cos(2.11096843463 + 18100.00325845*t)
	Y0 += 0.00000000073*np.cos(5.60150844280 + 115.8835796217*t)
	Y0 += 0.00000000080*np.cos(2.21108404080 + 38.3936680687*t)
	Y0 += 0.00000000064*np.cos(4.44827566878 + 284.1485407422*t)
	Y0 += 0.00000000066*np.cos(1.21053452412 + 17576.546524347*t)
	Y0 += 0.00000000072*np.cos(0.02703779211 + 245707.46610434429*t)
	Y0 += 0.00000000068*np.cos(0.52464381855 + 18003.144715223*t)
	Y0 += 0.00000000068*np.cos(1.33733194362 + 28759.81087748319*t)
	Y0 += 0.00000000070*np.cos(0.48885804664 + 107.0249274817*t)
	Y0 += 0.00000000062*np.cos(2.25046717820 + 3855.0336669572*t)
	Y0 += 0.00000000060*np.cos(5.83008017266 + 18606.4989460002*t)
	Y0 += 0.00000000079*np.cos(2.49476757272 + 22476.73502749179*t)
	Y0 += 0.00000000073*np.cos(4.61251602377 + 23440.1377304632*t)
	Y0 += 0.00000000060*np.cos(1.65871121739 + 13088.7291180766*t)
	Y0 += 0.00000000078*np.cos(2.99014426818 + 12564.6672272745*t)
	Y0 += 0.00000000060*np.cos(2.90135289748 + 7548.6433286178*t)
	Y0 += 0.00000000069*np.cos(0.94467164100 + 511.5317178299*t)
	Y0 += 0.00000000059*np.cos(2.43330626408 + 5113.4875985828*t)
	Y0 += 0.00000000075*np.cos(2.85043788676 + 18624.8827542723*t)
	Y0 += 0.00000000069*np.cos(4.25329739931 + 167993.69463622378*t)
	Y0 += 0.00000000059*np.cos(5.13628041810 + 41990.7859328988*t)
	Y0 += 0.00000000081*np.cos(5.98297918907 + 7250.046727427*t)
	Y0 += 0.00000000059*np.cos(2.39193379192 + 6289.1417656212*t)
	Y0 += 0.00000000059*np.cos(1.11500712714 + 6277.0099343616*t)
	Y0 += 0.00000000072*np.cos(4.87534601803 + 8982.810669309*t)
	Y0 += 0.00000000058*np.cos(4.95419870669 + 46.2097904851*t)
	Y0 += 0.00000000057*np.cos(3.30911091342 + 792.7748884674*t)
	Y0 += 0.00000000057*np.cos(1.61290511224 + 10027.9031957292*t)
	Y0 += 0.00000000079*np.cos(4.15336422499 + 531.1754378029*t)
	Y0 += 0.00000000067*np.cos(5.81376296368 + 643.8294395771*t)
	Y0 += 0.00000000072*np.cos(5.73653948228 + 4598.0237274898*t)
	Y0 += 0.00000000066*np.cos(0.80721495515 + 5220.1708014532*t)
	Y0 += 0.00000000056*np.cos(5.24002840662 + 35050.00027447539*t)
	Y0 += 0.00000000077*np.cos(2.14165124499 + 46386.9937433112*t)
	Y0 += 0.00000000056*np.cos(6.15449621937 + 842.1506814881*t)
	Y0 += 0.00000000068*np.cos(1.14499338723 + 3166.4164377316*t)
	Y0 += 0.00000000065*np.cos(0.26869494906 + 547.8502123593*t)
	Y0 += 0.00000000056*np.cos(0.39917748570 + 6339.8791121612*t)
	Y0 += 0.00000000056*np.cos(3.10776343336 + 6226.2725878216*t)
	Y0 += 0.00000000056*np.cos(0.95649088929 + 12303.06777661*t)
	Y0 += 0.00000000057*np.cos(1.98721525004 + 6702.000248892*t)
	Y0 += 0.00000000057*np.cos(1.51972566902 + 5864.1514510908*t)
	Y0 += 0.00000000069*np.cos(0.33788710387 + 23536.11695768099*t)
	Y0 += 0.00000000059*np.cos(1.81421782103 + 67589.08744705719*t)
	Y0 += 0.00000000069*np.cos(3.21235031019 + 269.9214467406*t)
	Y0 += 0.00000000075*np.cos(3.14349504273 + 227.3137411185*t)
	Y0 += 0.00000000076*np.cos(0.77801824814 + 23226.8386350252*t)
	Y0 += 0.00000000061*np.cos(4.72931440223 + 121.2520214833*t)
	Y0 += 0.00000000059*np.cos(1.03968301691 + 15.252471185*t)
	Y0 += 0.00000000073*np.cos(4.43868056110 + 30348.883772767*t)
	Y0 += 0.00000000054*np.cos(4.96201305869 + 36147.4098773004*t)
	Y0 += 0.00000000070*np.cos(6.27818224660 + 12299.544658261*t)
	Y0 += 0.00000000060*np.cos(5.08461088458 + 12171.5258149236*t)
	Y0 += 0.00000000074*np.cos(1.19928905734 + 3684.3780499902*t)
	Y0 += 0.00000000058*np.cos(1.58539308271 + 6716.7875878682*t)
	Y0 += 0.00000000061*np.cos(3.25163800829 + 27707.5424942948*t)
	Y0 += 0.00000000059*np.cos(5.76308524321 + 12164.4795782256*t)
	Y0 += 0.00000000070*np.cos(0.07217173698 + 16833.55646381439*t)
	Y0 += 0.00000000063*np.cos(2.16224668422 + 5227.6260730653*t)
	Y0 += 0.00000000063*np.cos(5.23287718161 + 5219.7617665391*t)
	Y0 += 0.00000000061*np.cos(1.41008037643 + 429.0458714308*t)
	Y0 += 0.00000000064*np.cos(2.72423324964 + 159.1244246902*t)
	Y0 += 0.00000000061*np.cos(2.23944425679 + 650.9429865779*t)
	Y0 += 0.00000000072*np.cos(2.62702736253 + 4583.7966334882*t)
	Y0 += 0.00000000052*np.cos(0.96546586882 + 3627.5074775176*t)
	Y0 += 0.00000000052*np.cos(0.20415505351 + 6155.1243169568*t)
	Y0 += 0.00000000052*np.cos(3.30278586555 + 6411.027383026*t)
	Y0 += 0.00000000073*np.cos(3.31073272937 + 528.2064923863*t)
	Y0 += 0.00000000057*np.cos(1.89137287758 + 92.940845832*t)
	Y0 += 0.00000000060*np.cos(0.48342399631 + 5244.049239201*t)
	Y0 += 0.00000000068*np.cos(5.14472869299 + 219.4494345923*t)
	Y0 += 0.00000000058*np.cos(2.72226132172 + 30775.481963643*t)
	Y0 += 0.00000000051*np.cos(3.53345258541 + 1048.3362299253*t)
	Y0 += 0.00000000052*np.cos(5.80291300969 + 30639.856638633*t)
	Y0 += 0.00000000053*np.cos(5.75258856716 + 37724.7534197482*t)
	Y0 += 0.00000000062*np.cos(4.52301275304 + 425.6349830295*t)
	Y0 += 0.00000000065*np.cos(1.17174840770 + 14.977853527*t)
	Y0 += 0.00000000062*np.cos(2.89766241568 + 6908.7460423038*t)
	Y0 += 0.00000000062*np.cos(0.60927850338 + 5657.405657679*t)
	Y0 += 0.00000000058*np.cos(4.32481237367 + 72.0732855816*t)
	Y0 += 0.00000000050*np.cos(6.18510990638 + 960.2213092337*t)
	Y0 += 0.00000000050*np.cos(3.11011154958 + 2575.2390943292*t)
	Y0 += 0.00000000054*np.cos(1.15676928987 + 18208.349942592*t)
	Y0 += 0.00000000055*np.cos(0.04281344157 + 42.3258213318*t)
	Y0 += 0.00000000050*np.cos(4.83446941002 + 426.6463749858*t)
	Y0 += 0.00000000049*np.cos(3.21271029936 + 514.7131115676*t)
	Y0 += 0.00000000065*np.cos(2.41337358880 + 494.2662424425*t)
	Y0 += 0.00000000050*np.cos(3.12376167242 + 5881.4037282342*t)
	Y0 += 0.00000000050*np.cos(0.38317924664 + 6684.7479717486*t)
	Y0 += 0.00000000067*np.cos(2.57317423197 + 618.5566453116*t)
	Y0 += 0.00000000052*np.cos(1.85871885411 + 2641.3412784722*t)
	Y0 += 0.00000000068*np.cos(4.61950794623 + 96677.8988630422*t)
	Y0 += 0.00000000054*np.cos(0.77163765121 + 41654.9631159678*t)
	Y0 += 0.00000000062*np.cos(6.11167050077 + 750.1036075334*t)
	Y0 += 0.00000000053*np.cos(0.86945819735 + 2428.0421830342*t)
	Y0 += 0.00000000066*np.cos(5.13003693613 + 60530.4889857418*t)
	Y0 += 0.00000000050*np.cos(1.64593222191 + 43738.8023459658*t)
	Y0 += 0.00000000048*np.cos(5.44674337925 + 25685.872802808*t)
	Y0 += 0.00000000050*np.cos(1.63663518288 + 426.5500067662*t)
	Y0 += 0.00000000059*np.cos(2.71376008731 + 3981.490034082*t)
	Y0 += 0.00000000058*np.cos(0.74658643142 + 14169.7935622304*t)
	Y0 += 0.00000000051*np.cos(1.43461659855 + 7668.9711263276*t)
	Y0 += 0.00000000048*np.cos(3.23576011756 + 3646.3503773544*t)
	Y0 += 0.00000000047*np.cos(4.26489760399 + 544.6688186216*t)
	Y0 += 0.00000000054*np.cos(4.50803792908 + 39302.096962196*t)
	Y0 += 0.00000000057*np.cos(2.62704971421 + 799.8211251654*t)
	Y0 += 0.00000000047*np.cos(4.45256678947 + 387.2413149608*t)
	Y0 += 0.00000000055*np.cos(3.70101890767 + 81.8951455681*t)
	Y0 += 0.00000000060*np.cos(0.53980789709 + 488.8496164711*t)
	Y0 += 0.00000000064*np.cos(2.60081517768 + 1364.7280995819*t)
	Y0 += 0.00000000061*np.cos(3.28745263972 + 44034.1275895394*t)
	Y0 += 0.00000000049*np.cos(2.15365169571 + 96562.99901809469*t)
	Y0 += 0.00000000050*np.cos(3.60626874009 + 17583.6600713478*t)
	Y0 += 0.00000000051*np.cos(1.16028405425 + 38650.173506199*t)
	Y0 += 0.00000000052*np.cos(2.81764658144 + 210.5907824523*t)
	Y0 += 0.00000000053*np.cos(1.90122336672 + 11080.1715789176*t)
	Y0 += 0.00000000053*np.cos(2.05896623723 + 427.5613987225*t)
	Y0 += 0.00000000059*np.cos(0.68886289824 + 62883.3551395136*t)
	Y0 += 0.00000000046*np.cos(0.83996053249 + 25287.7237993998*t)
	Y0 += 0.00000000049*np.cos(3.59486880927 + 5490.300961524*t)
	Y0 += 0.00000000058*np.cos(3.83698375555 + 6076.3751126948*t)
	Y0 += 0.00000000058*np.cos(5.95314247069 + 6489.776587288*t)
	Y0 += 0.00000000051*np.cos(5.21356444643 + 216.0074084237*t)
	Y0 += 0.00000000047*np.cos(4.43378504018 + 170.6728706192*t)
	Y0 += 0.00000000050*np.cos(3.05458837611 + 1056.9342496344*t)
	Y0 += 0.00000000045*np.cos(5.81363953764 + 33318.8160624582*t)
	Y0 += 0.00000000046*np.cos(3.19651245272 + 4480.7038592696*t)
	Y0 += 0.00000000049*np.cos(6.03922030861 + 501.3797894433*t)
	Y0 += 0.00000000060*np.cos(3.92066214096 + 28313.288804661*t)
	Y0 += 0.00000000061*np.cos(3.53510681440 + 491.6632924588*t)
	Y0 += 0.00000000051*np.cos(6.00904914233 + 3428.4354760812*t)
	Y0 += 0.00000000060*np.cos(3.51283911810 + 50317.2034395308*t)
	Y0 += 0.00000000044*np.cos(1.83359720481 + 2538.2485042536*t)
	Y0 += 0.00000000054*np.cos(2.28043683109 + 6559.8216218558*t)
	Y0 += 0.00000000054*np.cos(1.22650408797 + 6006.330078127*t)
	Y0 += 0.00000000044*np.cos(3.59534331356 + 74.0308390419*t)
	Y0 += 0.00000000052*np.cos(3.85271761797 + 244287.60000722769*t)
	Y0 += 0.00000000046*np.cos(3.84965479184 + 4384.7246320518*t)
	Y0 += 0.00000000045*np.cos(0.29195078507 + 44136.951349374*t)
	Y0 += 0.00000000050*np.cos(5.77173682772 + 355.7487455718*t)
	Y0 += 0.00000000044*np.cos(2.71274650311 + 2301.58581590939*t)
	Y0 += 0.00000000044*np.cos(1.08481523531 + 75.5323580927*t)
	Y0 += 0.00000000043*np.cos(5.70834575414 + 213.4591541324*t)
	Y0 += 0.00000000043*np.cos(2.32287306604 + 213.1390367436*t)
	Y0 += 0.00000000043*np.cos(5.47593276555 + 220.4608265486*t)
	Y0 += 0.00000000048*np.cos(4.64164514773 + 35579.69123957*t)
	Y0 += 0.00000000056*np.cos(1.59993474661 + 491.8185618877*t)
	Y0 += 0.00000000051*np.cos(4.91887651070 + 18326.65013188039*t)
	Y0 += 0.00000000046*np.cos(3.15339406184 + 16703.062133499*t)
	Y0 += 0.00000000048*np.cos(2.39477993061 + 5209.4668258006*t)
	Y0 += 0.00000000046*np.cos(2.47672465258 + 12555.1059997189*t)
	Y0 += 0.00000000052*np.cos(5.14565632171 + 6574.0487158574*t)
	Y0 += 0.00000000052*np.cos(4.64446990453 + 5992.1029841254*t)
	Y0 += 0.00000000044*np.cos(3.80836113401 + 69941.95360082899*t)
	Y0 += 0.00000000050*np.cos(3.54529295551 + 22030.2129546696*t)
	Y0 += 0.00000000043*np.cos(1.20775471242 + 20894.77567920879*t)
	Y0 += 0.00000000044*np.cos(2.61939991177 + 533.2140834436*t)
	Y0 += 0.00000000045*np.cos(4.65113002963 + 46360.6954235114*t)
	Y0 += 0.00000000054*np.cos(5.39695767554 + 187.6962327724*t)
	Y0 += 0.00000000047*np.cos(2.17023181784 + 45585.1728121874*t)
	Y0 += 0.00000000043*np.cos(1.54528183996 + 8401.8397103698*t)
	Y0 += 0.00000000050*np.cos(3.99260483640 + 296.1574488526*t)
	Y0 += 0.00000000054*np.cos(3.62371389676 + 24279.10701821359*t)
	Y0 += 0.00000000057*np.cos(5.35044527046 + 1061.829610744*t)
	Y0 += 0.00000000043*np.cos(3.24179066608 + 128.9562693151*t)
	Y0 += 0.00000000042*np.cos(5.13054174413 + 27433.88921587499*t)
	Y0 += 0.00000000047*np.cos(4.95696645233 + 1279.794572628*t)
	Y0 += 0.00000000042*np.cos(1.32093818083 + 21548.9623692918*t)
	Y0 += 0.00000000045*np.cos(3.22031193914 + 71519.2971432768*t)
	Y0 += 0.00000000043*np.cos(2.75467576214 + 27278.4688164408*t)
	Y0 += 0.00000000042*np.cos(2.68353478578 + 28230.18722269139*t)
	Y0 += 0.00000000051*np.cos(2.95623880108 + 7761.9424240558*t)
	Y0 += 0.00000000041*np.cos(5.14394847571 + 3735.238311759*t)
	Y0 += 0.00000000042*np.cos(3.66392136716 + 26084.0218062162*t)
	Y0 += 0.00000000054*np.cos(2.89069416534 + 207.1487562837*t)
	Y0 += 0.00000000047*np.cos(6.03338630990 + 4708.2300487092*t)
	Y0 += 0.00000000048*np.cos(1.44348407688 + 106.9767433719*t)
	Y0 += 0.00000000056*np.cos(3.88391523095 + 1057.8974574809*t)
	Y0 += 0.00000000056*np.cos(5.67442109710 + 88041.956859279*t)
	Y0 += 0.00000000047*np.cos(3.45990384746 + 679.2541622292*t)
	Y0 += 0.00000000053*np.cos(0.36365795711 + 601.7642506762*t)
	Y0 += 0.00000000056*np.cos(5.36734540218 + 28663.8316502654*t)
	Y0 += 0.00000000040*np.cos(1.07842393153 + 28628.3362260996*t)
	Y0 += 0.00000000047*np.cos(5.61045374376 + 316428.22867391503*t)
	Y0 += 0.00000000056*np.cos(1.28041118541 + 83659.27687239899*t)
	Y0 += 0.00000000040*np.cos(2.54799612698 + 1059.430114299*t)
	Y0 += 0.00000000045*np.cos(3.08256873858 + 10.2949407385*t)
	Y0 += 0.00000000039*np.cos(0.71682305362 + 34570.0663348526*t)
	Y0 += 0.00000000056*np.cos(1.60418809786 + 82534.40362061159*t)
	Y0 += 0.00000000052*np.cos(1.15000260118 + 40398.189919266*t)
	Y0 += 0.00000000051*np.cos(4.18413102003 + 344.7030453079*t)
	Y0 += 0.00000000042*np.cos(2.30009534060 + 220.364458329*t)
	Y0 += 0.00000000048*np.cos(0.93182108526 + 12662.1309272006*t)
	Y0 += 0.00000000041*np.cos(4.95215656542 + 37057.5774925662*t)
	Y0 += 0.00000000055*np.cos(5.75395220831 + 188.9200730498*t)
	Y0 += 0.00000000052*np.cos(2.84085536047 + 12571.6746242902*t)
	Y0 += 0.00000000043*np.cos(3.12714109961 + 7322.1024607818*t)
	Y0 += 0.00000000041*np.cos(1.98689255259 + 664.75604513*t)
	Y0 += 0.00000000043*np.cos(4.45441019609 + 19004.6479494084*t)
	Y0 += 0.00000000044*np.cos(3.63007864944 + 6140.8972229552*t)
	Y0 += 0.00000000044*np.cos(6.16004757680 + 6425.2544770276*t)
	Y0 += 0.00000000044*np.cos(3.57757676616 + 49515.382508407*t)
	Y0 += 0.00000000053*np.cos(0.70077978084 + 67.6680515665*t)
	Y0 += 0.00000000039*np.cos(5.09443272912 + 22594.05489571199*t)
	Y0 += 0.00000000055*np.cos(5.97876206707 + 80181.53746683979*t)
	Y0 += 0.00000000039*np.cos(1.93706467599 + 1788.1448967202*t)
	Y0 += 0.00000000054*np.cos(0.38609427782 + 6560.1108437328*t)
	Y0 += 0.00000000054*np.cos(3.12084664124 + 6006.04085625*t)
	Y0 += 0.00000000045*np.cos(0.83262497188 + 142861.39123625819*t)
	Y0 += 0.00000000047*np.cos(5.83395711112 + 24499.5196606524*t)
	Y0 += 0.00000000043*np.cos(6.07854396898 + 7026.065910524*t)
	Y0 += 0.00000000044*np.cos(4.99425187685 + 179.3588454942*t)
	Y0 += 0.00000000047*np.cos(2.57216284949 + 11919.140866668*t)
	Y0 += 0.00000000047*np.cos(2.93748065634 + 24485.29256665079*t)
	Y0 += 0.00000000044*np.cos(0.26434468297 + 289.5651667136*t)
	Y0 += 0.00000000050*np.cos(3.13873979564 + 92747.68916682259*t)
	Y0 += 0.00000000040*np.cos(4.73960650797 + 436.1594184316*t)
	Y0 += 0.00000000043*np.cos(4.24359473122 + 6359.341921267*t)
	Y0 += 0.00000000049*np.cos(2.11824959319 + 66813.5648357332*t)
	Y0 += 0.00000000042*np.cos(3.13003412642 + 6231.79551212899*t)
	Y0 += 0.00000000042*np.cos(0.37690679264 + 6334.35618785381*t)
	Y0 += 0.00000000040*np.cos(3.26413558741 + 149.45132255*t)
	Y0 += 0.00000000052*np.cos(1.96232281613 + 11904.9187732018*t)
	Y0 += 0.00000000040*np.cos(6.22187276386 + 7075.8507384588*t)
	Y0 += 0.00000000047*np.cos(1.24067371450 + 1038.0412891868*t)
	Y0 += 0.00000000040*np.cos(4.78395267597 + 7122.0451377418*t)
	Y0 += 0.00000000040*np.cos(5.00617355027 + 5444.106562241*t)
	Y0 += 0.00000000038*np.cos(0.67444569484 + 44933.2493561904*t)
	Y0 += 0.00000000044*np.cos(0.82332847780 + 358.9301393095*t)
	Y0 += 0.00000000037*np.cos(4.80355711691 + 6850.7944877218*t)
	Y0 += 0.00000000037*np.cos(4.98656910933 + 5715.357212261*t)
	Y0 += 0.00000000050*np.cos(0.35643037555 + 21947.11137270*t)
	Y0 += 0.00000000039*np.cos(2.97136332005 + 21150.8133658836*t)
	Y0 += 0.00000000036*np.cos(1.35884346175 + 68.1893164283*t)
	Y0 += 0.00000000042*np.cos(2.21951419227 + 6328.217069628*t)
	Y0 += 0.00000000042*np.cos(1.28742672679 + 6237.9346303548*t)
	Y0 += 0.00000000051*np.cos(4.42510682790 + 60284.4100152629*t)
	Y0 += 0.00000000040*np.cos(5.21447072458 + 3215.1363806432*t)
	Y0 += 0.00000000036*np.cos(2.69669701623 + 2751.5475996916*t)
	Y0 += 0.00000000047*np.cos(5.73121342219 + 523.5406259403*t)
	Y0 += 0.00000000039*np.cos(3.85122558089 + 30774.5016425748*t)
	Y0 += 0.00000000036*np.cos(1.89385828446 + 59.8037450403*t)
	Y0 += 0.00000000040*np.cos(5.63337030653 + 1059.3337460794*t)
	Y0 += 0.00000000046*np.cos(3.45581538922 + 12146.6670561076*t)
	Y0 += 0.00000000050*np.cos(0.05709243771 + 84334.41776382479*t)
	return Y0




def Earth_Y1 (t): # 710 terms of order 1

	Y1 = 0.
	Y1 += 0.00093052441
	Y1 += 0.00051506453*np.cos(4.43180499286 + 12566.1516999828*t)
	Y1 += 0.00001290796*np.cos(4.38860548540 + 18849.2275499742*t)
	Y1 += 0.00000900270*np.cos(5.84057602289 + 426.598190876*t)
	Y1 += 0.00000781136*np.cos(1.12959177265 + 206.1855484372*t)
	Y1 += 0.00000754610*np.cos(0.61970612390 + 220.4126424388*t)
	Y1 += 0.00000565322*np.cos(1.65278682736 + 1059.3819301892*t)
	Y1 += 0.00000571251*np.cos(4.00106150799 + 522.5774180938*t)
	Y1 += 0.00000559143*np.cos(3.48680691788 + 536.8045120954*t)
	Y1 += 0.00000464550*np.cos(5.82729912952 + 6283.0758499914*t)
	Y1 += 0.00000212689*np.cos(0.16300556918 + 6279.5527316424*t)
	Y1 += 0.00000212533*np.cos(3.34400595407 + 6286.5989683404*t)
	Y1 += 0.00000089934*np.cos(1.86498162492 + 7.1135470008*t)
	Y1 += 0.00000073661*np.cos(5.07557169089 + 639.897286314*t)
	Y1 += 0.00000087320*np.cos(0.09065280320 + 419.4846438752*t)
	Y1 += 0.00000062345*np.cos(5.07377354827 + 4705.7323075436*t)
	Y1 += 0.00000053924*np.cos(6.03901927875 + 433.7117378768*t)
	Y1 += 0.00000059794*np.cos(2.24100907272 + 6256.7775301916*t)
	Y1 += 0.00000059441*np.cos(1.26619990626 + 6309.3741697912*t)
	Y1 += 0.00000048987*np.cos(3.64166577835 + 775.522611324*t)
	Y1 += 0.00000047619*np.cos(2.15295666289 + 213.299095438*t)
	Y1 += 0.00000046642*np.cos(4.71575215800 + 7860.4193924392*t)
	Y1 += 0.00000047112*np.cos(5.04021592457 + 529.6909650946*t)
	Y1 += 0.00000037274*np.cos(0.66041323804 + 5753.3848848968*t)
	Y1 += 0.00000035625*np.cos(6.15462846966 + 5884.9268465832*t)
	Y1 += 0.00000035373*np.cos(2.90052012152 + 6812.766815086*t)
	Y1 += 0.00000031980*np.cos(3.62728133561 + 6681.2248533996*t)
	Y1 += 0.00000031263*np.cos(3.30956065388 + 1052.2683831884*t)
	Y1 += 0.00000038790*np.cos(1.87592194521 + 1589.0728952838*t)
	Y1 += 0.00000029711*np.cos(3.87870738442 + 1066.49547719*t)
	Y1 += 0.00000032122*np.cos(1.28008455196 + 149.5631971346*t)
	Y1 += 0.00000028763*np.cos(4.34539355621 + 25132.3033999656*t)
	Y1 += 0.00000028447*np.cos(5.86215103214 + 6127.6554505572*t)
	Y1 += 0.00000027502*np.cos(3.92641632542 + 6438.4962494256*t)
	Y1 += 0.00000024830*np.cos(1.35190115953 + 5486.777843175*t)
	Y1 += 0.00000021415*np.cos(5.30131509744 + 316.3918696566*t)
	Y1 += 0.00000020618*np.cos(2.14772396647 + 7079.3738568078*t)
	Y1 += 0.00000019019*np.cos(0.48946385175 + 227.5261894396*t)
	Y1 += 0.00000019531*np.cos(1.29958310594 + 5507.5532386674*t)
	Y1 += 0.00000018447*np.cos(6.17330532651 + 11790.6290886588*t)
	Y1 += 0.00000016520*np.cos(4.63328039489 + 11506.7697697936*t)
	Y1 += 0.00000015976*np.cos(2.44551801692 + 110.2063212194*t)
	Y1 += 0.00000016754*np.cos(2.24862220282 + 7058.5984613154*t)
	Y1 += 0.00000014560*np.cos(4.40425761361 + 6290.1893969922*t)
	Y1 += 0.00000014426*np.cos(5.39226330857 + 6275.9623029906*t)
	Y1 += 0.00000014186*np.cos(6.18547219419 + 796.2980068164*t)
	Y1 += 0.00000015830*np.cos(4.20419608904 + 76.2660712756*t)
	Y1 += 0.00000012666*np.cos(5.73231393752 + 4694.0029547076*t)
	Y1 += 0.00000012413*np.cos(4.14057132118 + 515.463871093*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000011720*np.cos(1.50209200374 + 632.7837393132*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000010100*np.cos(1.72464513593 + 3738.761430108*t)
	Y1 += 0.00000009427*np.cos(3.08115743044 + 6069.7767545534*t)
	Y1 += 0.00000010425*np.cos(2.69531177468 + 6282.0955289232*t)
	Y1 += 0.00000010425*np.cos(0.81162914438 + 6284.0561710596*t)
	Y1 += 0.00000009576*np.cos(0.32459396888 + 4136.9104335162*t)
	Y1 += 0.00000010164*np.cos(0.62992310390 + 73.297125859*t)
	Y1 += 0.00000009043*np.cos(0.43888880403 + 6496.3749454294*t)
	Y1 += 0.00000009222*np.cos(1.25927718333 + 199.0720014364*t)
	Y1 += 0.00000008663*np.cos(3.35360012494 + 543.9180590962*t)
	Y1 += 0.00000008545*np.cos(4.77137497641 + 1194.4470102246*t)
	Y1 += 0.00000007691*np.cos(1.12047989646 + 103.0927742186*t)
	Y1 += 0.00000007682*np.cos(1.44821098204 + 949.1756089698*t)
	Y1 += 0.00000006291*np.cos(3.18312019173 + 8429.2412664666*t)
	Y1 += 0.00000006133*np.cos(1.78033290355 + 8827.3902698748*t)
	Y1 += 0.00000005662*np.cos(4.43184042162 + 853.196381752*t)
	Y1 += 0.00000005524*np.cos(3.79842135217 + 4933.2084403326*t)
	Y1 += 0.00000007316*np.cos(5.20404355405 + 4535.0594369244*t)
	Y1 += 0.00000005170*np.cos(0.37516758388 + 209.3669421749*t)
	Y1 += 0.00000005146*np.cos(3.57146870511 + 11769.8536931664*t)
	Y1 += 0.00000005081*np.cos(1.39059455730 + 217.2312487011*t)
	Y1 += 0.00000006461*np.cos(2.67840586109 + 5088.6288397668*t)
	Y1 += 0.00000005270*np.cos(0.94095218349 + 3154.6870848956*t)
	Y1 += 0.00000004829*np.cos(5.32876538500 + 6040.3472460174*t)
	Y1 += 0.00000004985*np.cos(3.05697984231 + 12569.6748183318*t)
	Y1 += 0.00000004660*np.cos(0.15626149972 + 216.4804891757*t)
	Y1 += 0.00000004709*np.cos(2.39292099451 + 5331.3574437408*t)
	Y1 += 0.00000004601*np.cos(4.45296532710 + 6525.8044539654*t)
	Y1 += 0.00000004553*np.cos(1.60431626596 + 210.1177017003*t)
	Y1 += 0.00000004447*np.cos(5.48065037241 + 323.5054166574*t)
	Y1 += 0.00000005607*np.cos(0.98720797401 + 5729.506447149*t)
	Y1 += 0.00000004151*np.cos(1.93098926861 + 63.7358983034*t)
	Y1 += 0.00000004081*np.cos(5.94191743597 + 7632.9432596502*t)
	Y1 += 0.00000004099*np.cos(5.22964063969 + 647.0108333148*t)
	Y1 += 0.00000005058*np.cos(1.73136117173 + 14.2270940016*t)
	Y1 += 0.00000004394*np.cos(4.75948184840 + 12559.038152982*t)
	Y1 += 0.00000004293*np.cos(2.71452907477 + 735.8765135318*t)
	Y1 += 0.00000005053*np.cos(4.55162942081 + 8031.0922630584*t)
	Y1 += 0.00000005077*np.cos(0.73549620962 + 7477.522860216*t)
	Y1 += 0.00000003779*np.cos(1.07385171253 + 7234.794256242*t)
	Y1 += 0.00000004974*np.cos(2.50029147401 + 6836.6452528338*t)
	Y1 += 0.00000003614*np.cos(2.52455299148 + 3930.2096962196*t)
	Y1 += 0.00000003482*np.cos(3.82652198801 + 10977.078804699*t)
	Y1 += 0.00000003443*np.cos(2.77873462243 + 85.8272988312*t)
	Y1 += 0.00000003302*np.cos(0.78944659795 + 11.0457002639*t)
	Y1 += 0.00000003576*np.cos(5.30219799481 + 4164.311989613*t)
	Y1 += 0.00000003246*np.cos(4.47251198694 + 526.5095713569*t)
	Y1 += 0.00000003376*np.cos(5.00213145251 + 11371.7046897582*t)
	Y1 += 0.00000003180*np.cos(3.00772018402 + 532.8723588323*t)
	Y1 += 0.00000004290*np.cos(3.36736739298 + 1592.5960136328*t)
	Y1 += 0.00000003406*np.cos(0.83525752781 + 3128.3887650958*t)
	Y1 += 0.00000003124*np.cos(3.17143982984 + 7084.8967811152*t)
	Y1 += 0.00000002903*np.cos(3.22514351914 + 525.7588118315*t)
	Y1 += 0.00000002896*np.cos(1.12069020939 + 117.3198682202*t)
	Y1 += 0.00000002863*np.cos(4.25448918131 + 533.6231183577*t)
	Y1 += 0.00000002838*np.cos(0.45959307618 + 202.2533951741*t)
	Y1 += 0.00000002752*np.cos(3.67389621489 + 7342.4577801806*t)
	Y1 += 0.00000002778*np.cos(0.26817898615 + 1748.016413067*t)
	Y1 += 0.00000002820*np.cos(0.23146914320 + 5223.6939198022*t)
	Y1 += 0.00000003334*np.cos(3.48823993118 + 801.8209311238*t)
	Y1 += 0.00000003328*np.cos(5.83812544995 + 155.4203994342*t)
	Y1 += 0.00000003008*np.cos(0.67203387304 + 8635.9420037632*t)
	Y1 += 0.00000002863*np.cos(2.16989496338 + 95.9792272178*t)
	Y1 += 0.00000002488*np.cos(1.92630128592 + 2118.7638603784*t)
	Y1 += 0.00000002348*np.cos(5.19665664165 + 2146.1654164752*t)
	Y1 += 0.00000002307*np.cos(2.98930142346 + 17260.1546546904*t)
	Y1 += 0.00000002044*np.cos(3.86812530423 + 138.5174968707*t)
	Y1 += 0.00000002778*np.cos(6.17392405934 + 5481.2549188676*t)
	Y1 += 0.00000002046*np.cos(1.96605971472 + 1990.745017041*t)
	Y1 += 0.00000001977*np.cos(2.19636388255 + 742.9900605326*t)
	Y1 += 0.00000002670*np.cos(1.00151747879 + 26.2983197998*t)
	Y1 += 0.00000002000*np.cos(3.03124266219 + 951.7184062506*t)
	Y1 += 0.00000001830*np.cos(4.43806423544 + 553.5694028424*t)
	Y1 += 0.00000001762*np.cos(3.84931185617 + 4690.4798363586*t)
	Y1 += 0.00000001909*np.cos(0.39529260174 + 956.2891559706*t)
	Y1 += 0.00000002430*np.cos(1.64090263419 + 1349.8674096588*t)
	Y1 += 0.00000001721*np.cos(4.20873668375 + 1596.1864422846*t)
	Y1 += 0.00000001902*np.cos(2.66567222573 + 9437.762934887*t)
	Y1 += 0.00000001699*np.cos(1.87566644469 + 70.8494453042*t)
	Y1 += 0.00000001940*np.cos(3.91085273629 + 5216.5803728014*t)
	Y1 += 0.00000001708*np.cos(5.00417878382 + 10988.808157535*t)
	Y1 += 0.00000001762*np.cos(2.39542835845 + 398.1490034082*t)
	Y1 += 0.00000001570*np.cos(2.80724611689 + 78.7137518304*t)
	Y1 += 0.00000001790*np.cos(3.48655562486 + 5230.807466803*t)
	Y1 += 0.00000001555*np.cos(2.09924417685 + 13095.8426650774*t)
	Y1 += 0.00000001493*np.cos(5.97213767442 + 440.8252848776*t)
	Y1 += 0.00000001779*np.cos(0.23737949225 + 12562.6285816338*t)
	Y1 += 0.00000001450*np.cos(4.07811254364 + 6303.4311693902*t)
	Y1 += 0.00000001450*np.cos(5.71201368260 + 6262.7205305926*t)
	Y1 += 0.00000001465*np.cos(1.19009717807 + 74.7815985673*t)
	Y1 += 0.00000001559*np.cos(2.97028792257 + 1045.1548361876*t)
	Y1 += 0.00000001838*np.cos(3.37688364803 + 1581.959348283*t)
	Y1 += 0.00000001768*np.cos(0.08826500577 + 10973.55568635*t)
	Y1 += 0.00000001373*np.cos(5.60523185373 + 7875.6718636242*t)
	Y1 += 0.00000001646*np.cos(2.40413866073 + 224.3447957019*t)
	Y1 += 0.00000001428*np.cos(3.29442777483 + 12721.572099417*t)
	Y1 += 0.00000001230*np.cos(2.53131850803 + 18319.5365848796*t)
	Y1 += 0.00000001140*np.cos(1.21410806683 + 2942.4634232916*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001057*np.cos(0.79522639484 + 309.2783226558*t)
	Y1 += 0.00000001112*np.cos(2.89652371372 + 625.6701923124*t)
	Y1 += 0.00000001045*np.cos(2.17535721280 + 242.728603974*t)
	Y1 += 0.00000001000*np.cos(4.09863557302 + 1265.5674786264*t)
	Y1 += 0.00000000969*np.cos(1.29405045734 + 5643.1785636774*t)
	Y1 += 0.00000001064*np.cos(4.40566643488 + 15720.8387848784*t)
	Y1 += 0.00000000962*np.cos(0.55758587779 + 2388.8940204492*t)
	Y1 += 0.00000000937*np.cos(4.17606834663 + 20426.571092422*t)
	Y1 += 0.00000000869*np.cos(5.80860615243 + 16496.3613962024*t)
	Y1 += 0.00000000874*np.cos(1.43036958888 + 10575.4066829418*t)
	Y1 += 0.00000001088*np.cos(5.77656856686 + 5760.4984318976*t)
	Y1 += 0.00000000989*np.cos(6.14826697847 + 412.3710968744*t)
	Y1 += 0.00000000889*np.cos(4.77820137734 + 6288.5987742988*t)
	Y1 += 0.00000000889*np.cos(5.01192484889 + 6277.552925684*t)
	Y1 += 0.00000001018*np.cos(2.66299766067 + 12539.853380183*t)
	Y1 += 0.00000001017*np.cos(4.02093017183 + 6805.6532680852*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000000936*np.cos(2.99521995909 + 1169.5882514086*t)
	Y1 += 0.00000000943*np.cos(0.21048093986 + 151.0476698429*t)
	Y1 += 0.00000000794*np.cos(3.79329079940 + 14314.1681130498*t)
	Y1 += 0.00000000771*np.cos(1.58200018736 + 942.062061969*t)
	Y1 += 0.00000000795*np.cos(3.39951828424 + 6279.7894925736*t)
	Y1 += 0.00000000795*np.cos(0.10742263482 + 6286.3622074092*t)
	Y1 += 0.00000000759*np.cos(4.98301749094 + 1577.3435424478*t)
	Y1 += 0.00000000757*np.cos(3.81754073272 + 5856.4776591154*t)
	Y1 += 0.00000000800*np.cos(3.18366218591 + 12029.3471878874*t)
	Y1 += 0.00000000716*np.cos(2.28687269516 + 9623.6882766912*t)
	Y1 += 0.00000000698*np.cos(4.94363229969 + 6148.010769956*t)
	Y1 += 0.00000000907*np.cos(0.70119368826 + 13367.9726311066*t)
	Y1 += 0.00000000672*np.cos(3.99153941403 + 12964.300703391*t)
	Y1 += 0.00000000678*np.cos(4.84647216304 + 6418.1409300268*t)
	Y1 += 0.00000000671*np.cos(6.00179402654 + 6709.6740408674*t)
	Y1 += 0.00000000762*np.cos(3.43418344370 + 1155.361157407*t)
	Y1 += 0.00000000657*np.cos(1.80163596347 + 13119.72110282519*t)
	Y1 += 0.00000000662*np.cos(4.04031103640 + 11015.1064773348*t)
	Y1 += 0.00000000712*np.cos(1.82235727085 + 71.8126531507*t)
	Y1 += 0.00000000744*np.cos(2.68741160780 + 12043.574281889*t)
	Y1 += 0.00000000673*np.cos(2.45322928062 + 14712.317116458*t)
	Y1 += 0.00000000696*np.cos(2.53877129238 + 16730.4636895958*t)
	Y1 += 0.00000000718*np.cos(2.94974266304 + 77.7505439839*t)
	Y1 += 0.00000000671*np.cos(0.40543909773 + 13517.8701062334*t)
	Y1 += 0.00000000604*np.cos(5.39462125376 + 14143.4952424306*t)
	Y1 += 0.00000000754*np.cos(5.24655445271 + 13916.0191096416*t)
	Y1 += 0.00000000629*np.cos(3.42493725594 + 4686.8894077068*t)
	Y1 += 0.00000000718*np.cos(1.70498371588 + 1162.4747044078*t)
	Y1 += 0.00000000610*np.cos(5.19955844918 + 6819.8803620868*t)
	Y1 += 0.00000000667*np.cos(4.87151372910 + 3634.6210245184*t)
	Y1 += 0.00000000609*np.cos(4.57544043999 + 5746.271337896*t)
	Y1 += 0.00000000620*np.cos(4.30310535016 + 31415.379249957*t)
	Y1 += 0.00000000553*np.cos(0.78994516254 + 6306.9542877392*t)
	Y1 += 0.00000000553*np.cos(2.71699575652 + 6259.1974122436*t)
	Y1 += 0.00000000524*np.cos(3.96543945899 + 12139.5535091068*t)
	Y1 += 0.00000000514*np.cos(3.87793148429 + 4701.1165017084*t)
	Y1 += 0.00000000553*np.cos(4.81568395217 + 12036.4607348882*t)
	Y1 += 0.00000000495*np.cos(2.00987395637 + 13362.4497067992*t)
	Y1 += 0.00000000504*np.cos(2.36012441072 + 277.0349937414*t)
	Y1 += 0.00000000562*np.cos(4.76145666018 + 4292.3308329504*t)
	Y1 += 0.00000000481*np.cos(2.57118063835 + 6286.9571853494*t)
	Y1 += 0.00000000481*np.cos(0.93576028071 + 6279.1945146334*t)
	Y1 += 0.00000000486*np.cos(5.53252452947 + 422.6660376129*t)
	Y1 += 0.00000000635*np.cos(3.19879108676 + 84334.66158130829*t)
	Y1 += 0.00000000445*np.cos(1.68959289911 + 11499.6562227928*t)
	Y1 += 0.00000000596*np.cos(1.08038043695 + 10447.3878396044*t)
	Y1 += 0.00000000452*np.cos(3.98330238308 + 12573.2652469836*t)
	Y1 += 0.00000000499*np.cos(5.79985861523 + 12410.7313005486*t)
	Y1 += 0.00000000440*np.cos(0.58121786395 + 24072.9214697764*t)
	Y1 += 0.00000000430*np.cos(1.17248306119 + 1692.1656695024*t)
	Y1 += 0.00000000575*np.cos(1.39410252291 + 12592.4500197826*t)
	Y1 += 0.00000000404*np.cos(0.56451183179 + 5863.5912061162*t)
	Y1 += 0.00000000391*np.cos(3.73837604066 + 1073.6090241908*t)
	Y1 += 0.00000000398*np.cos(4.20035189119 + 8273.8208670324*t)
	Y1 += 0.00000000418*np.cos(2.76069368004 + 10177.2576795336*t)
	Y1 += 0.00000000379*np.cos(3.05384870302 + 6386.16862421*t)
	Y1 += 0.00000000379*np.cos(0.45309221604 + 6179.9830757728*t)
	Y1 += 0.00000000377*np.cos(4.33269290931 + 7872.1487452752*t)
	Y1 += 0.00000000419*np.cos(4.05140116867 + 5327.4761083828*t)
	Y1 += 0.00000000383*np.cos(5.11659434377 + 6319.1037166688*t)
	Y1 += 0.00000000383*np.cos(4.67353188247 + 6247.04798331399*t)
	Y1 += 0.00000000375*np.cos(0.35041804232 + 234.6397364404*t)
	Y1 += 0.00000000457*np.cos(0.88573283839 + 6489.2613984286*t)
	Y1 += 0.00000000457*np.cos(2.62120808067 + 6076.8903015542*t)
	Y1 += 0.00000000373*np.cos(3.98254461376 + 415.5524906121*t)
	Y1 += 0.00000000361*np.cos(5.90601998518 + 846.0828347512*t)
	Y1 += 0.00000000384*np.cos(5.64976516740 + 330.6189636582*t)
	Y1 += 0.00000000378*np.cos(5.80861101902 + 7238.67559160*t)
	Y1 += 0.00000000344*np.cos(4.99907349425 + 18451.07854656599*t)
	Y1 += 0.00000000334*np.cos(0.56215917990 + 18073.7049386502*t)
	Y1 += 0.00000000335*np.cos(4.48297896956 + 860.3099287528*t)
	Y1 += 0.00000000453*np.cos(5.43513758472 + 2787.0430238574*t)
	Y1 += 0.00000000337*np.cos(3.18444650009 + 71.6002048296*t)
	Y1 += 0.00000000364*np.cos(0.67991079022 + 6321.1035226272*t)
	Y1 += 0.00000000364*np.cos(2.82703012884 + 6245.0481773556*t)
	Y1 += 0.00000000324*np.cos(0.71684229879 + 423.4167971383*t)
	Y1 += 0.00000000342*np.cos(4.52940007807 + 6303.8512454838*t)
	Y1 += 0.00000000342*np.cos(5.26072614817 + 6262.300454499*t)
	Y1 += 0.00000000386*np.cos(1.14024921261 + 10021.8372800994*t)
	Y1 += 0.00000000319*np.cos(4.83173153249 + 11926.2544136688*t)
	Y1 += 0.00000000433*np.cos(1.36147512776 + 3.9321532631*t)
	Y1 += 0.00000000316*np.cos(1.17362065540 + 77713.7714681205*t)
	Y1 += 0.00000000326*np.cos(1.48465704932 + 77.962992305*t)
	Y1 += 0.00000000318*np.cos(6.03589239585 + 6311.5250374592*t)
	Y1 += 0.00000000318*np.cos(3.75423383039 + 6254.6266625236*t)
	Y1 += 0.00000000315*np.cos(1.09950918957 + 12323.4230960088*t)
	Y1 += 0.00000000384*np.cos(1.50030220266 + 1478.8665740644*t)
	Y1 += 0.00000000311*np.cos(5.94074472453 + 2352.8661537718*t)
	Y1 += 0.00000000316*np.cos(5.62533566974 + 429.7795846137*t)
	Y1 += 0.00000000304*np.cos(0.43890915612 + 12779.4507954208*t)
	Y1 += 0.00000000304*np.cos(3.98761648250 + 145.6310438715*t)
	Y1 += 0.00000000343*np.cos(1.36470897271 + 6267.82337880639*t)
	Y1 += 0.00000000343*np.cos(2.14223194635 + 6298.3283211764*t)
	Y1 += 0.00000000398*np.cos(4.83558508405 + 1551.045222648*t)
	Y1 += 0.00000000300*np.cos(0.20527323254 + 90279.92316810328*t)
	Y1 += 0.00000000352*np.cos(0.64575728139 + 2.9689454166*t)
	Y1 += 0.00000000297*np.cos(4.04385751107 + 10213.285546211*t)
	Y1 += 0.00000000297*np.cos(2.07974536467 + 5429.8794682394*t)
	Y1 += 0.00000000334*np.cos(1.16416729842 + 17782.7320727842*t)
	Y1 += 0.00000000295*np.cos(2.48770580169 + 6702.5604938666*t)
	Y1 += 0.00000000384*np.cos(4.55881127062 + 210.8514148832*t)
	Y1 += 0.00000000380*np.cos(3.47993786173 + 215.7467759928*t)
	Y1 += 0.00000000321*np.cos(0.66776723307 + 17796.9591667858*t)
	Y1 += 0.00000000360*np.cos(2.88459167183 + 728.762966531*t)
	Y1 += 0.00000000369*np.cos(4.78231597870 + 4732.0306273434*t)
	Y1 += 0.00000000338*np.cos(4.31589716519 + 148.0787244263*t)
	Y1 += 0.00000000263*np.cos(2.60909847321 + 955.5997416086*t)
	Y1 += 0.00000000255*np.cos(0.68716361250 + 437.6438911399*t)
	Y1 += 0.00000000305*np.cos(0.57265325631 + 5642.1982426092*t)
	Y1 += 0.00000000284*np.cos(3.67849455855 + 838.9692877504*t)
	Y1 += 0.00000000287*np.cos(0.31572653335 + 9917.6968745098*t)
	Y1 += 0.00000000261*np.cos(1.93782216260 + 16200.7727245012*t)
	Y1 += 0.00000000282*np.cos(2.93181184874 + 13341.6743113068*t)
	Y1 += 0.00000000262*np.cos(5.15409122759 + 14945.3161735544*t)
	Y1 += 0.00000000234*np.cos(0.03317726903 + 223.5940361765*t)
	Y1 += 0.00000000222*np.cos(4.29914928209 + 508.3503240922*t)
	Y1 += 0.00000000276*np.cos(0.59107321564 + 12168.0026965746*t)
	Y1 += 0.00000000217*np.cos(2.74597813026 + 2544.3144198834*t)
	Y1 += 0.00000000233*np.cos(3.30440847719 + 1272.6810256272*t)
	Y1 += 0.00000000259*np.cos(5.53112324599 + 3894.1818295422*t)
	Y1 += 0.00000000265*np.cos(1.64615612331 + 3.1813937377*t)
	Y1 += 0.00000000216*np.cos(4.02991604351 + 3185.1920272656*t)
	Y1 += 0.00000000250*np.cos(3.04516511604 + 6923.9534573736*t)
	Y1 += 0.00000000193*np.cos(0.78779752820 + 640.8776073822*t)
	Y1 += 0.00000000203*np.cos(2.82417195790 + 6062.6632075526*t)
	Y1 += 0.00000000203*np.cos(0.68276896116 + 6503.4884924302*t)
	Y1 += 0.00000000201*np.cos(4.46138168832 + 1375.7737998458*t)
	Y1 += 0.00000000188*np.cos(4.83298725434 + 18209.33026366019*t)
	Y1 += 0.00000000184*np.cos(2.63875516800 + 12566.2190102856*t)
	Y1 += 0.00000000213*np.cos(4.09959554852 + 9779.1086761254*t)
	Y1 += 0.00000000189*np.cos(1.85609145755 + 2648.454825473*t)
	Y1 += 0.00000000248*np.cos(5.62050900898 + 17789.845619785*t)
	Y1 += 0.00000000181*np.cos(2.37018594067 + 88.865680217*t)
	Y1 += 0.00000000187*np.cos(0.48606035843 + 6290.1220866894*t)
	Y1 += 0.00000000187*np.cos(3.02088056063 + 6276.02961329339*t)
	Y1 += 0.00000000184*np.cos(3.08285813784 + 12566.08438968*t)
	Y1 += 0.00000000230*np.cos(0.66694562430 + 12567.132021051*t)
	Y1 += 0.00000000199*np.cos(1.40110998613 + 430.5303441391*t)
	Y1 += 0.00000000189*np.cos(0.25718944825 + 124.433415221*t)
	Y1 += 0.00000000174*np.cos(5.22081710422 + 1368.660252845*t)
	Y1 += 0.00000000184*np.cos(1.80970202711 + 6037.244203762*t)
	Y1 += 0.00000000159*np.cos(0.31775301914 + 3496.032826134*t)
	Y1 += 0.00000000167*np.cos(3.42353804022 + 1062.5633239269*t)
	Y1 += 0.00000000179*np.cos(1.27622455391 + 3.523118349*t)
	Y1 += 0.00000000182*np.cos(0.19927362554 + 5849.3641121146*t)
	Y1 += 0.00000000175*np.cos(1.69691956469 + 6528.9074962208*t)
	Y1 += 0.00000000154*np.cos(5.68366565747 + 6112.4029793722*t)
	Y1 += 0.00000000154*np.cos(4.10646056877 + 6453.7487206106*t)
	Y1 += 0.00000000152*np.cos(5.50666765279 + 160.6088973985*t)
	Y1 += 0.00000000162*np.cos(0.40509792796 + 18875.525869774*t)
	Y1 += 0.00000000172*np.cos(0.02323350795 + 65.2203710117*t)
	Y1 += 0.00000000154*np.cos(4.59717983879 + 519.3960243561*t)
	Y1 += 0.00000000163*np.cos(2.96167567065 + 12352.8526045448*t)
	Y1 += 0.00000000143*np.cos(0.06272029982 + 19651.048481098*t)
	Y1 += 0.00000000144*np.cos(2.19098385924 + 18635.9284545362*t)
	Y1 += 0.00000000141*np.cos(5.63574749070 + 10969.9652576982*t)
	Y1 += 0.00000000162*np.cos(4.37345556932 + 3340.6124266998*t)
	Y1 += 0.00000000146*np.cos(0.42084370397 + 13760.5987102074*t)
	Y1 += 0.00000000139*np.cos(3.64890818066 + 1055.4497769261*t)
	Y1 += 0.00000000138*np.cos(4.30414447043 + 1258.4539316256*t)
	Y1 += 0.00000000161*np.cos(6.06631099179 + 8662.240323563*t)
	Y1 += 0.00000000142*np.cos(2.91677439721 + 4157.1984426122*t)
	Y1 += 0.00000000133*np.cos(4.73063338736 + 18139.2945014159*t)
	Y1 += 0.00000000132*np.cos(5.18037129096 + 654.1243803156*t)
	Y1 += 0.00000000136*np.cos(1.73632400099 + 203.0041546995*t)
	Y1 += 0.00000000125*np.cos(0.78764990758 + 20.7753954924*t)
	Y1 += 0.00000000121*np.cos(4.88476463619 + 1063.3140834523*t)
	Y1 += 0.00000000123*np.cos(4.97498024339 + 6172.869528772*t)
	Y1 += 0.00000000123*np.cos(4.81514598285 + 6393.2821712108*t)
	Y1 += 0.00000000135*np.cos(4.59213390099 + 10984.1923516998*t)
	Y1 += 0.00000000117*np.cos(2.90632080371 + 18852.7506683232*t)
	Y1 += 0.00000000118*np.cos(3.20236689438 + 551.031606097*t)
	Y1 += 0.00000000118*np.cos(5.67650820416 + 17256.6315363414*t)
	Y1 += 0.00000000147*np.cos(4.60612631701 + 17654.7805397496*t)
	Y1 += 0.00000000120*np.cos(2.88381733148 + 539.9859058331*t)
	Y1 += 0.00000000140*np.cos(4.29359662977 + 1056.2005364515*t)
	Y1 += 0.00000000113*np.cos(3.90726609167 + 65147.6197681377*t)
	Y1 += 0.00000000111*np.cos(4.11806246187 + 222.8603229936*t)
	Y1 += 0.00000000111*np.cos(4.75059162228 + 2125.8774073792*t)
	Y1 += 0.00000000123*np.cos(2.85759760823 + 12565.1713789146*t)
	Y1 += 0.00000000133*np.cos(3.06193509061 + 22.0914005278*t)
	Y1 += 0.00000000107*np.cos(5.46942612515 + 9380.9596727172*t)
	Y1 += 0.00000000136*np.cos(1.56582531149 + 21.3406410024*t)
	Y1 += 0.00000000144*np.cos(6.19128577365 + 299.1263942692*t)
	Y1 += 0.00000000119*np.cos(0.71211331875 + 10419.9862835076*t)
	Y1 += 0.00000000103*np.cos(4.95941330270 + 6271.3464971554*t)
	Y1 += 0.00000000103*np.cos(4.83071292354 + 6294.8052028274*t)
	Y1 += 0.00000000108*np.cos(1.67634660643 + 302.164775655*t)
	Y1 += 0.00000000102*np.cos(5.99360230997 + 4804.209275927*t)
	Y1 += 0.00000000114*np.cos(3.78885344182 + 4171.4255366138*t)
	Y1 += 0.00000000113*np.cos(4.29988480427 + 23013.5395395872*t)
	Y1 += 0.00000000112*np.cos(0.61034141917 + 17253.04110768959*t)
	Y1 += 0.00000000101*np.cos(1.41448120448 + 191.9584544356*t)
	Y1 += 0.00000000113*np.cos(0.97983808350 + 16858.4825329332*t)
	Y1 += 0.00000000139*np.cos(1.37682327925 + 1485.9801210652*t)
	Y1 += 0.00000000102*np.cos(4.09962394648 + 6549.6828917132*t)
	Y1 += 0.00000000102*np.cos(5.69050227976 + 6016.4688082696*t)
	Y1 += 0.00000000106*np.cos(0.87687085688 + 23543.23050468179*t)
	Y1 += 0.00000000095*np.cos(3.83184038977 + 18.1592472647*t)
	Y1 += 0.00000000094*np.cos(1.74801590640 + 87.3117715395*t)
	Y1 += 0.00000000119*np.cos(3.20779882655 + 1574.8458012822*t)
	Y1 += 0.00000000121*np.cos(4.76575782873 + 13625.533630172*t)
	Y1 += 0.00000000122*np.cos(4.95627332740 + 84.3428261229*t)
	Y1 += 0.00000000088*np.cos(1.18967345782 + 17298.1823273262*t)
	Y1 += 0.00000000097*np.cos(4.30891602532 + 217.964961884*t)
	Y1 += 0.00000000087*np.cos(1.12941525302 + 17267.26820169119*t)
	Y1 += 0.00000000096*np.cos(3.59501512720 + 2111.6503133776*t)
	Y1 += 0.00000000093*np.cos(6.00441441624 + 33.6796175129*t)
	Y1 += 0.00000000092*np.cos(1.84158032509 + 22805.7355659936*t)
	Y1 += 0.00000000086*np.cos(4.36870119289 + 12808.8803039568*t)
	Y1 += 0.00000000087*np.cos(1.75505290273 + 231.4583427027*t)
	Y1 += 0.00000000111*np.cos(0.85102422912 + 11513.8833167944*t)
	Y1 += 0.00000000097*np.cos(0.07381843439 + 72.3339180125*t)
	Y1 += 0.00000000095*np.cos(6.05597457730 + 12345.739057544*t)
	Y1 += 0.00000000090*np.cos(3.89285886336 + 628.8515860501*t)
	Y1 += 0.00000000106*np.cos(3.57199937061 + 11216.284290324*t)
	Y1 += 0.00000000087*np.cos(1.36534411656 + 8982.810669309*t)
	Y1 += 0.00000000095*np.cos(0.92966303480 + 12012.5822971404*t)
	Y1 += 0.00000000089*np.cos(3.43002043997 + 1699.2792165032*t)
	Y1 += 0.00000000081*np.cos(2.27691876526 + 11614.4332937322*t)
	Y1 += 0.00000000084*np.cos(5.85994160066 + 6255.6742938946*t)
	Y1 += 0.00000000084*np.cos(3.93018462558 + 6310.4774060882*t)
	Y1 += 0.00000000080*np.cos(5.05950625443 + 6922.9731363054*t)
	Y1 += 0.00000000085*np.cos(1.08198764342 + 5636.0650166766*t)
	Y1 += 0.00000000084*np.cos(4.64040201203 + 10440.2742926036*t)
	Y1 += 0.00000000089*np.cos(6.25985265406 + 16723.350142595*t)
	Y1 += 0.00000000080*np.cos(5.99267916099 + 12.5301729722*t)
	Y1 += 0.00000000080*np.cos(2.62622474570 + 3583.3410306738*t)
	Y1 += 0.00000000091*np.cos(5.59316682916 + 10818.1352869158*t)
	Y1 += 0.00000000091*np.cos(1.43612727660 + 15671.0817594066*t)
	Y1 += 0.00000000086*np.cos(3.72646183478 + 208.633228992*t)
	Y1 += 0.00000000077*np.cos(4.13229801300 + 6993.0088985497*t)
	Y1 += 0.00000000076*np.cos(2.85409687552 + 11925.2740926006*t)
	Y1 += 0.00000000076*np.cos(4.88733161640 + 9.5612275556*t)
	Y1 += 0.00000000096*np.cos(1.47205677028 + 3097.88382272579*t)
	Y1 += 0.00000000077*np.cos(4.73669756226 + 38.1330356378*t)
	Y1 += 0.00000000104*np.cos(0.70746530546 + 5650.2921106782*t)
	Y1 += 0.00000000086*np.cos(5.52511956951 + 12359.9661515456*t)
	Y1 += 0.00000000076*np.cos(4.18947022170 + 288.0806940053*t)
	Y1 += 0.00000000080*np.cos(6.03205499783 + 13521.7514415914*t)
	Y1 += 0.00000000090*np.cos(4.45214765055 + 6195.76764545159*t)
	Y1 += 0.00000000090*np.cos(5.33797857569 + 6370.3840545312*t)
	Y1 += 0.00000000082*np.cos(4.91006846138 + 18842.11400297339*t)
	Y1 += 0.00000000083*np.cos(3.74911363362 + 18415.51581209739*t)
	Y1 += 0.00000000102*np.cos(4.43384315891 + 3104.9300594238*t)
	Y1 += 0.00000000096*np.cos(4.64169775712 + 203.7378678824*t)
	Y1 += 0.00000000074*np.cos(5.90055438198 + 5120.6011455836*t)
	Y1 += 0.00000000076*np.cos(5.12453730610 + 362.8622925726*t)
	Y1 += 0.00000000076*np.cos(2.48257518078 + 1471.7530270636*t)
	Y1 += 0.00000000093*np.cos(2.53140640111 + 16460.33352952499*t)
	Y1 += 0.00000000075*np.cos(0.38132378506 + 525.0250986486*t)
	Y1 += 0.00000000084*np.cos(5.92514029201 + 2379.1644735716*t)
	Y1 += 0.00000000069*np.cos(2.64295754993 + 114.3991069134*t)
	Y1 += 0.00000000068*np.cos(5.35287430069 + 153.4953503977*t)
	Y1 += 0.00000000068*np.cos(5.70841220182 + 73.8183907208*t)
	Y1 += 0.00000000075*np.cos(0.05752343047 + 30355.9973197678*t)
	Y1 += 0.00000000076*np.cos(3.26399401386 + 18429.742906099*t)
	Y1 += 0.00000000071*np.cos(0.81628722181 + 534.3568315406*t)
	Y1 += 0.00000000067*np.cos(4.00530001957 + 16062.1845261168*t)
	Y1 += 0.00000000064*np.cos(5.24500232218 + 75.7448064138*t)
	Y1 += 0.00000000066*np.cos(4.81634064130 + 10454.5013866052*t)
	Y1 += 0.00000000087*np.cos(3.52675041577 + 3903.9113764198*t)
	Y1 += 0.00000000066*np.cos(4.60699109440 + 42.5864537627*t)
	Y1 += 0.00000000061*np.cos(1.32159131349 + 207.8824694666*t)
	Y1 += 0.00000000078*np.cos(2.74560762552 + 8671.9698704406*t)
	Y1 += 0.00000000063*np.cos(5.70772167485 + 24356.7807886416*t)
	Y1 += 0.00000000059*np.cos(0.45173742414 + 218.7157214094*t)
	Y1 += 0.00000000059*np.cos(5.95742231142 + 408.4389436113*t)
	Y1 += 0.00000000067*np.cos(5.29778871808 + 152.5321425512*t)
	Y1 += 0.00000000076*np.cos(4.82056450443 + 77.2292791221*t)
	Y1 += 0.00000000063*np.cos(1.72943225747 + 79.2350166922*t)
	Y1 += 0.00000000073*np.cos(6.08379700055 + 9388.0059094152*t)
	Y1 += 0.00000000060*np.cos(1.94470153573 + 34570.0663348526*t)
	Y1 += 0.00000000057*np.cos(2.89018663881 + 149854.40013480789*t)
	Y1 += 0.00000000056*np.cos(3.76314176838 + 12455.9453787634*t)
	Y1 += 0.00000000055*np.cos(1.32127703933 + 23539.7073863328*t)
	Y1 += 0.00000000055*np.cos(5.60680941684 + 15664.03552270859*t)
	Y1 += 0.00000000055*np.cos(1.48510731583 + 200.7689224658*t)
	Y1 += 0.00000000055*np.cos(2.03729558857 + 340.7708920448*t)
	Y1 += 0.00000000056*np.cos(0.60887110989 + 11764.330768859*t)
	Y1 += 0.00000000076*np.cos(0.68351123517 + 146.594251718*t)
	Y1 += 0.00000000061*np.cos(4.86427999867 + 28237.2334593894*t)
	Y1 += 0.00000000065*np.cos(4.29965528550 + 7335.3442331798*t)
	Y1 += 0.00000000067*np.cos(4.20742811531 + 11933.3679606696*t)
	Y1 += 0.00000000072*np.cos(4.30216792995 + 6510.5519827804*t)
	Y1 += 0.00000000072*np.cos(5.48795829629 + 6055.5997172024*t)
	Y1 += 0.00000000072*np.cos(1.86379528122 + 127.4717966068*t)
	Y1 += 0.00000000053*np.cos(5.64466034451 + 17996.0311682222*t)
	Y1 += 0.00000000055*np.cos(3.89290884441 + 831.8557407496*t)
	Y1 += 0.00000000071*np.cos(4.94322519248 + 12545.3763044904*t)
	Y1 += 0.00000000061*np.cos(3.80625548858 + 6253.6463414554*t)
	Y1 += 0.00000000061*np.cos(5.98387073766 + 6312.5053585274*t)
	Y1 += 0.00000000052*np.cos(1.83796108842 + 5326.7866940208*t)
	Y1 += 0.00000000066*np.cos(0.79633834660 + 14919.0178537546*t)
	Y1 += 0.00000000051*np.cos(1.99163070525 + 225.8292684102*t)
	Y1 += 0.00000000058*np.cos(1.52964509339 + 2221.856634597*t)
	Y1 += 0.00000000057*np.cos(5.68632410752 + 4.4534181249*t)
	Y1 += 0.00000000053*np.cos(2.81005325604 + 2699.7348193176*t)
	Y1 += 0.00000000059*np.cos(4.32589692662 + 618.5566453116*t)
	Y1 += 0.00000000064*np.cos(3.86347940489 + 1685.0521225016*t)
	Y1 += 0.00000000053*np.cos(3.04286367857 + 70.3281804424*t)
	Y1 += 0.00000000051*np.cos(2.33512659118 + 16522.6597160022*t)
	Y1 += 0.00000000049*np.cos(1.07108765064 + 2008.557539159*t)
	Y1 += 0.00000000049*np.cos(2.61656735675 + 35579.69123957*t)
	Y1 += 0.00000000053*np.cos(3.71469727042 + 6357.8574485587*t)
	Y1 += 0.00000000053*np.cos(6.07542895582 + 6208.2942514241*t)
	Y1 += 0.00000000058*np.cos(6.24714677357 + 16737.5772365966*t)
	Y1 += 0.00000000049*np.cos(3.35591683551 + 21393.5419698576*t)
	Y1 += 0.00000000049*np.cos(5.31764383927 + 7018.9523635232*t)
	Y1 += 0.00000000049*np.cos(4.47248238697 + 5547.1993364596*t)
	Y1 += 0.00000000049*np.cos(1.02044068888 + 12416.5885028482*t)
	Y1 += 0.00000000048*np.cos(0.93318398067 + 5573.1428014331*t)
	Y1 += 0.00000000048*np.cos(2.75851599881 + 350.3321196004*t)
	Y1 += 0.00000000050*np.cos(4.78756360288 + 26084.0218062162*t)
	Y1 += 0.00000000052*np.cos(0.61376591765 + 45585.1728121874*t)
	Y1 += 0.00000000051*np.cos(1.83598363802 + 23006.42599258639*t)
	Y1 += 0.00000000058*np.cos(4.03624047121 + 15141.390794312*t)
	Y1 += 0.00000000047*np.cos(3.55960074091 + 22743.4093795164*t)
	Y1 += 0.00000000050*np.cos(5.52194731109 + 21424.4666443034*t)
	Y1 += 0.00000000051*np.cos(0.22846885309 + 210.3783341312*t)
	Y1 += 0.00000000051*np.cos(1.50810894489 + 216.2198567448*t)
	Y1 += 0.00000000047*np.cos(5.68901702449 + 24279.10701821359*t)
	Y1 += 0.00000000049*np.cos(0.09767152059 + 5749.8617665478*t)
	Y1 += 0.00000000049*np.cos(3.40926939847 + 6816.289933435*t)
	Y1 += 0.00000000046*np.cos(1.88054905125 + 19378.9185150688*t)
	Y1 += 0.00000000047*np.cos(0.52217551707 + 24065.80792277559*t)
	Y1 += 0.00000000049*np.cos(4.34430964617 + 963.4027029714*t)
	Y1 += 0.00000000046*np.cos(4.16716226231 + 104351.61256629678*t)
	Y1 += 0.00000000050*np.cos(2.92366135772 + 24602.61243487099*t)
	Y1 += 0.00000000054*np.cos(4.75214506546 + 7834.1210726394*t)
	Y1 += 0.00000000052*np.cos(5.97532002180 + 142.4496501338*t)
	Y1 += 0.00000000045*np.cos(3.48834172987 + 161000.6857376741*t)
	Y1 += 0.00000000045*np.cos(3.23715580244 + 37.611770776*t)
	Y1 += 0.00000000044*np.cos(2.92943406327 + 62.2514255951*t)
	Y1 += 0.00000000050*np.cos(2.96247842378 + 1038.0412891868*t)
	Y1 += 0.00000000049*np.cos(2.94403678329 + 29303.7289365794*t)
	Y1 += 0.00000000048*np.cos(1.95408707684 + 5244.049239201*t)
	Y1 += 0.00000000044*np.cos(4.06912509984 + 524.2743391232*t)
	Y1 += 0.00000000044*np.cos(1.10360628000 + 38.6543004996*t)
	Y1 += 0.00000000043*np.cos(3.93857315871 + 12132.439962106*t)
	Y1 += 0.00000000044*np.cos(3.41315318980 + 535.107591066*t)
	Y1 += 0.00000000047*np.cos(5.81677586075 + 18208.349942592*t)
	Y1 += 0.00000000059*np.cos(4.20691421118 + 1795.258443721*t)
	Y1 += 0.00000000049*np.cos(3.41896064981 + 29289.5018425778*t)
	Y1 += 0.00000000044*np.cos(2.06685104480 + 6175.4123260528*t)
	Y1 += 0.00000000044*np.cos(1.44008987426 + 6390.73937393*t)
	Y1 += 0.00000000042*np.cos(6.18541909471 + 24705.70520908959*t)
	Y1 += 0.00000000042*np.cos(3.26999492630 + 195.1398481733*t)
	Y1 += 0.00000000043*np.cos(2.09042966596 + 74.8934731519*t)
	Y1 += 0.00000000043*np.cos(2.58927275174 + 74.6697239827*t)
	Y1 += 0.00000000050*np.cos(0.24741236723 + 131.4039498699*t)
	Y1 += 0.00000000049*np.cos(4.20329151784 + 207.6700211455*t)
	Y1 += 0.00000000041*np.cos(3.21613978391 + 17370.3609759098*t)
	Y1 += 0.00000000047*np.cos(1.17418881008 + 58953.145443294*t)
	Y1 += 0.00000000048*np.cos(0.71033320787 + 109.9456887885*t)
	Y1 += 0.00000000041*np.cos(2.05518926769 + 23020.65308658799*t)
	Y1 += 0.00000000044*np.cos(3.20914273688 + 26735.9452622132*t)
	Y1 += 0.00000000045*np.cos(3.70228663504 + 54247.4131357504*t)
	Y1 += 0.00000000040*np.cos(4.57474127522 + 32243.4985008806*t)
	Y1 += 0.00000000040*np.cos(5.17182769558 + 24336.0053931492*t)
	Y1 += 0.00000000040*np.cos(3.62816477586 + 19804.8272915828*t)
	Y1 += 0.00000000039*np.cos(1.13462594128 + 18606.4989460002*t)
	Y1 += 0.00000000040*np.cos(4.71493835645 + 8401.8397103698*t)
	Y1 += 0.00000000039*np.cos(0.11315588432 + 1382.8873468466*t)
	Y1 += 0.00000000041*np.cos(2.69655967341 + 16207.886271502*t)
	Y1 += 0.00000000038*np.cos(5.56507429543 + 29088.811415985*t)
	Y1 += 0.00000000038*np.cos(2.82768070464 + 703.6331846174*t)
	Y1 += 0.00000000040*np.cos(1.29300189092 + 10.2949407385*t)
	Y1 += 0.00000000038*np.cos(2.36481926067 + 6268.8487559898*t)
	Y1 += 0.00000000038*np.cos(1.14212165839 + 6297.302943993*t)
	Y1 += 0.00000000041*np.cos(3.38234777816 + 15508.6151232744*t)
	Y1 += 0.00000000038*np.cos(4.82215691915 + 6171.8892077038*t)
	Y1 += 0.00000000038*np.cos(4.96796930709 + 6394.262492279*t)
	Y1 += 0.00000000046*np.cos(3.79813773531 + 218.9281697305*t)
	Y1 += 0.00000000039*np.cos(1.75198804720 + 29826.3063546732*t)
	Y1 += 0.00000000037*np.cos(3.64776861935 + 20452.8694122218*t)
	Y1 += 0.00000000052*np.cos(3.98463781177 + 1047.7473117547*t)
	Y1 += 0.00000000043*np.cos(6.01711305973 + 55022.9357470744*t)
	Y1 += 0.00000000037*np.cos(6.18577055273 + 4061.2192153944*t)
	Y1 += 0.00000000040*np.cos(2.02818434731 + 49515.382508407*t)
	Y1 += 0.00000000037*np.cos(2.83593964107 + 511.5317178299*t)
	Y1 += 0.00000000049*np.cos(4.21086629146 + 18216.443810661*t)
	Y1 += 0.00000000038*np.cos(4.59185538964 + 18202.21671665939*t)
	Y1 += 0.00000000035*np.cos(3.16929714068 + 26482.1708096244*t)
	Y1 += 0.00000000035*np.cos(4.28290669029 + 565.1156877467*t)
	Y1 += 0.00000000036*np.cos(1.56812014048 + 9924.8104215106*t)
	Y1 += 0.00000000039*np.cos(0.88019393819 + 24889.5747959916*t)
	Y1 += 0.00000000039*np.cos(4.63870568395 + 26709.6469424134*t)
	Y1 += 0.00000000036*np.cos(6.07069720518 + 25287.7237993998*t)
	Y1 += 0.00000000035*np.cos(4.65527976927 + 547.8502123593*t)
	Y1 += 0.00000000034*np.cos(6.10039920596 + 6147.4505249814*t)
	Y1 += 0.00000000034*np.cos(3.68972702028 + 6418.7011750014*t)
	Y1 += 0.00000000034*np.cos(2.54760886649 + 21228.3920235458*t)
	Y1 += 0.00000000034*np.cos(0.68922440987 + 33019.0211122046*t)
	Y1 += 0.00000000039*np.cos(2.38629347866 + 490.3340891794*t)
	Y1 += 0.00000000034*np.cos(0.40887359374 + 17271.8840075264*t)
	Y1 += 0.00000000042*np.cos(3.87683640837 + 56.6223513026*t)
	Y1 += 0.00000000033*np.cos(3.96639362427 + 750.1036075334*t)
	Y1 += 0.00000000037*np.cos(4.69414299267 + 635.9651330509*t)
	Y1 += 0.00000000034*np.cos(0.33424154418 + 29026.48522950779*t)
	Y1 += 0.00000000035*np.cos(1.63582495302 + 7322.1024607818*t)
	Y1 += 0.00000000044*np.cos(1.21937055747 + 3981.490034082*t)
	Y1 += 0.00000000033*np.cos(2.56048298726 + 173566.83743765688*t)
	Y1 += 0.00000000038*np.cos(4.43072611572 + 483.2205421786*t)
	Y1 += 0.00000000035*np.cos(3.11075553675 + 526.7702037878*t)
	Y1 += 0.00000000035*np.cos(3.00160924335 + 21954.15760939799*t)
	Y1 += 0.00000000034*np.cos(3.38052068808 + 38500.2760310722*t)
	Y1 += 0.00000000035*np.cos(4.37175047624 + 532.6117264014*t)
	Y1 += 0.00000000032*np.cos(2.81219711037 + 17686.7528455664*t)
	Y1 += 0.00000000033*np.cos(0.13837047156 + 34520.3093093808*t)
	Y1 += 0.00000000041*np.cos(2.52021125438 + 21202.093703746*t)
	Y1 += 0.00000000037*np.cos(5.92836585991 + 7349.5713271814*t)
	Y1 += 0.00000000031*np.cos(2.79498926181 + 28230.18722269139*t)
	Y1 += 0.00000000037*np.cos(0.13743210410 + 265.9892934775*t)
	Y1 += 0.00000000038*np.cos(5.01277542891 + 9225.539273283*t)
	Y1 += 0.00000000035*np.cos(2.49445060142 + 8584.6616659008*t)
	Y1 += 0.00000000031*np.cos(5.89336305342 + 447.9388318784*t)
	Y1 += 0.00000000038*np.cos(2.67041435749 + 15110.4661198662*t)
	Y1 += 0.00000000037*np.cos(1.84827551648 + 29296.6153895786*t)
	Y1 += 0.00000000035*np.cos(4.26342089717 + 11919.140866668*t)
	Y1 += 0.00000000035*np.cos(2.59482262662 + 62883.3551395136*t)
	Y1 += 0.00000000035*np.cos(5.54313072444 + 29062.5130961852*t)
	Y1 += 0.00000000035*np.cos(5.96888200431 + 25685.872802808*t)
	Y1 += 0.00000000030*np.cos(5.15245353060 + 209.106309744*t)
	Y1 += 0.00000000030*np.cos(1.38932865248 + 12489.8856287072*t)
	Y1 += 0.00000000030*np.cos(2.87235713038 + 217.491881132*t)
	Y1 += 0.00000000030*np.cos(0.02207663615 + 92.940845832*t)
	Y1 += 0.00000000039*np.cos(5.08202984393 + 1.4844727083*t)
	Y1 += 0.00000000041*np.cos(4.39843263561 + 18052.9295431578*t)
	Y1 += 0.00000000032*np.cos(4.69085169487 + 6231.79551212899*t)
	Y1 += 0.00000000032*np.cos(5.09927453137 + 6334.35618785381*t)
	Y1 += 0.00000000038*np.cos(0.97224853307 + 52.6901980395*t)
	Y1 += 0.00000000033*np.cos(4.71041781828 + 5017.508371365*t)
	Y1 += 0.00000000034*np.cos(3.82387178783 + 22483.84857449259*t)
	Y1 += 0.00000000029*np.cos(0.69173791628 + 27278.4688164408*t)
	Y1 += 0.00000000028*np.cos(1.77462370325 + 80.1982245387*t)
	Y1 += 0.00000000028*np.cos(0.30766379271 + 24080.03501677719*t)
	Y1 += 0.00000000028*np.cos(1.80200703459 + 21150.8133658836*t)
	Y1 += 0.00000000034*np.cos(5.49813240003 + 5905.7022420756*t)
	Y1 += 0.00000000034*np.cos(4.29199382621 + 6660.4494579072*t)
	Y1 += 0.00000000034*np.cos(5.07299879866 + 269.9214467406*t)
	Y1 += 0.00000000031*np.cos(0.77685387250 + 15265.8865193004*t)
	Y1 += 0.00000000038*np.cos(3.55141531291 + 31570.7996493912*t)
	Y1 += 0.00000000028*np.cos(2.45238897056 + 107.0249274817*t)
	Y1 += 0.00000000028*np.cos(1.18666538399 + 106.2741679563*t)
	Y1 += 0.00000000031*np.cos(3.61860838672 + 424.1505103212*t)
	Y1 += 0.00000000027*np.cos(2.79364979031 + 1279.794572628*t)
	Y1 += 0.00000000027*np.cos(2.03421614285 + 36949.2308084242*t)
	Y1 += 0.00000000030*np.cos(0.75326086687 + 12586.9270954752*t)
	Y1 += 0.00000000027*np.cos(5.24483718904 + 233141.31440436149*t)
	Y1 += 0.00000000027*np.cos(4.99665333874 + 24383.0791084414*t)
	Y1 += 0.00000000028*np.cos(3.97690125997 + 34911.412076091*t)
	Y1 += 0.00000000027*np.cos(3.01465510733 + 23581.2581773176*t)
	Y1 += 0.00000000028*np.cos(5.79946172825 + 16193.65917750039*t)
	Y1 += 0.00000000027*np.cos(5.36876316169 + 6360.7496204194*t)
	Y1 += 0.00000000027*np.cos(4.42136306455 + 6205.4020795634*t)
	Y1 += 0.00000000032*np.cos(5.04711925057 + 27511.4678735372*t)
	Y1 += 0.00000000027*np.cos(0.74966550512 + 32367.0976562076*t)
	Y1 += 0.00000000027*np.cos(3.34326768159 + 4487.8174062704*t)
	Y1 += 0.00000000027*np.cos(3.23525952036 + 1802.3719907218*t)
	Y1 += 0.00000000029*np.cos(4.00870617495 + 46386.9937433112*t)
	Y1 += 0.00000000026*np.cos(1.30285929374 + 4797.0957289262*t)
	Y1 += 0.00000000028*np.cos(5.37411984168 + 10239.5838660108*t)
	Y1 += 0.00000000026*np.cos(5.08151018860 + 6339.974224927*t)
	Y1 += 0.00000000026*np.cos(4.70861603764 + 6226.1774750558*t)
	Y1 += 0.00000000029*np.cos(4.88985723155 + 6592.3541726472*t)
	Y1 += 0.00000000029*np.cos(4.90026899469 + 5973.7975273356*t)
	Y1 += 0.00000000027*np.cos(4.24057714278 + 1898.3512179396*t)
	Y1 += 0.00000000026*np.cos(3.80920015468 + 25158.6017197654*t)
	Y1 += 0.00000000026*np.cos(4.12353757087 + 9910.583327509*t)
	Y1 += 0.00000000031*np.cos(2.37034813214 + 24491.4257925834*t)
	Y1 += 0.00000000024*np.cos(5.26265995716 + 11616.976091013*t)
	Y1 += 0.00000000024*np.cos(4.68388215645 + 31172.650645983*t)
	Y1 += 0.00000000029*np.cos(4.62741692698 + 19402.7969528166*t)
	Y1 += 0.00000000025*np.cos(1.21411432675 + 6302.74561089119*t)
	Y1 += 0.00000000025*np.cos(2.29282659231 + 6263.4060890916*t)
	Y1 += 0.00000000026*np.cos(4.64443513632 + 30666.1549584328*t)
	Y1 += 0.00000000027*np.cos(2.79813911349 + 19800.9459562248*t)
	Y1 += 0.00000000023*np.cos(6.28082090370 + 650.9429865779*t)
	Y1 += 0.00000000024*np.cos(2.16373217847 + 31968.9486527994*t)
	Y1 += 0.00000000023*np.cos(4.99790910102 + 137.0330241624*t)
	Y1 += 0.00000000023*np.cos(3.28519702781 + 35.685355083*t)
	Y1 += 0.00000000023*np.cos(5.33583152283 + 17892.93839400359*t)
	Y1 += 0.00000000023*np.cos(5.05383022333 + 29424.634232916*t)
	Y1 += 0.00000000024*np.cos(6.12085409163 + 20597.2439630412*t)
	Y1 += 0.00000000023*np.cos(3.28897425519 + 28.5718080822*t)
	Y1 += 0.00000000022*np.cos(5.43332862700 + 337.732510659*t)
	Y1 += 0.00000000024*np.cos(1.65155411828 + 23550.34405168259*t)
	Y1 += 0.00000000023*np.cos(6.07302432574 + 6716.7875878682*t)
	Y1 += 0.00000000022*np.cos(2.42662159283 + 7445.5505543992*t)
	Y1 += 0.00000000023*np.cos(5.16035150168 + 2.4476805548*t)
	Y1 += 0.00000000023*np.cos(4.82793901796 + 643.0786800517*t)
	Y1 += 0.00000000027*np.cos(1.56823801633 + 28628.3362260996*t)
	Y1 += 0.00000000022*np.cos(3.39570466574 + 40879.4405046438*t)
	Y1 += 0.00000000025*np.cos(5.52794317615 + 14155.2245952666*t)
	Y1 += 0.00000000024*np.cos(5.25759177705 + 1361.5467058442*t)
	Y1 += 0.00000000023*np.cos(1.49204312505 + 6272.0301497275*t)
	Y1 += 0.00000000023*np.cos(2.01489779401 + 6294.1215502553*t)
	Y1 += 0.00000000022*np.cos(1.70327289493 + 934.9485149682*t)
	Y1 += 0.00000000023*np.cos(2.98215154259 + 284.1485407422*t)
	Y1 += 0.00000000021*np.cos(4.21170718841 + 22779.4372461938*t)
	Y1 += 0.00000000024*np.cos(3.83904364251 + 8186.5126624926*t)
	Y1 += 0.00000000021*np.cos(2.51494728863 + 30220.9322397324*t)
	Y1 += 0.00000000024*np.cos(4.50083076815 + 191.2076949102*t)
	Y1 += 0.00000000021*np.cos(1.05341004601 + 40.5807161926*t)
	Y1 += 0.00000000022*np.cos(6.09500922463 + 4379.6390374902*t)
	Y1 += 0.00000000021*np.cos(1.35819574535 + 525.4981794006*t)
	Y1 += 0.00000000024*np.cos(3.37809061150 + 540.7366653585*t)
	Y1 += 0.00000000022*np.cos(2.95144246643 + 28759.81087748319*t)
	Y1 += 0.00000000020*np.cos(0.07597154617 + 28313.288804661*t)
	Y1 += 0.00000000026*np.cos(1.83971959567 + 18422.62935909819*t)
	Y1 += 0.00000000022*np.cos(1.06284971840 + 27707.5424942948*t)
	Y1 += 0.00000000025*np.cos(5.09676204562 + 96.8729990951*t)
	Y1 += 0.00000000027*np.cos(5.38238146057 + 34513.2630726828*t)
	Y1 += 0.00000000020*np.cos(3.97670500643 + 251.4321310758*t)
	Y1 += 0.00000000027*np.cos(4.63548485210 + 1905.4647649404*t)
	Y1 += 0.00000000024*np.cos(3.34248986355 + 219.4494345923*t)
	Y1 += 0.00000000025*np.cos(1.96129048463 + 55798.4583583984*t)
	Y1 += 0.00000000019*np.cos(0.75805525916 + 11712.9553182308*t)
	Y1 += 0.00000000025*np.cos(4.06271601240 + 29864.334027309*t)
	Y1 += 0.00000000024*np.cos(5.92086856803 + 9411.4646150872*t)
	Y1 += 0.00000000020*np.cos(0.08212819079 + 6379.0550772092*t)
	Y1 += 0.00000000020*np.cos(3.42481272827 + 6187.0966227736*t)
	Y1 += 0.00000000019*np.cos(1.29742572058 + 99.1606209555*t)
	Y1 += 0.00000000022*np.cos(2.87393551670 + 18326.65013188039*t)
	Y1 += 0.00000000020*np.cos(4.26784309163 + 21548.9623692918*t)
	Y1 += 0.00000000022*np.cos(0.61268580951 + 6233.3188245196*t)
	Y1 += 0.00000000022*np.cos(2.89425510955 + 6332.8328754632*t)
	Y1 += 0.00000000021*np.cos(5.43088404515 + 50317.2034395308*t)
	Y1 += 0.00000000020*np.cos(0.38470757997 + 22345.2603761082*t)
	Y1 += 0.00000000018*np.cos(3.04737429764 + 6593.9166488598*t)
	Y1 += 0.00000000018*np.cos(0.45956662142 + 5972.235051123*t)
	Y1 += 0.00000000019*np.cos(0.79376120003 + 5618.3198048614*t)
	Y1 += 0.00000000019*np.cos(2.71317971903 + 6947.8318951214*t)
	Y1 += 0.00000000020*np.cos(1.96622391594 + 81.8951455681*t)
	Y1 += 0.00000000018*np.cos(0.28017726157 + 34115.1140692746*t)
	Y1 += 0.00000000022*np.cos(2.04754590576 + 114.1384744825*t)
	Y1 += 0.00000000019*np.cos(4.89700323392 + 83973.83535572988*t)
	Y1 += 0.00000000019*np.cos(2.72494815105 + 84019.8592804939*t)
	Y1 += 0.00000000020*np.cos(2.60251083721 + 42456.7840470916*t)
	Y1 += 0.00000000020*np.cos(1.28313240949 + 9070.1188738488*t)
	Y1 += 0.00000000021*np.cos(5.89651875201 + 344.7030453079*t)
	Y1 += 0.00000000018*np.cos(0.41312927370 + 479.2883889155*t)
	return Y1*t




def Earth_Y2 (t): # 345 terms of order 2

	Y2 = 0.
	Y2 += 0.00005024394
	Y2 += 0.00002178009*np.cos(2.82957544235 + 12566.1516999828*t)
	Y2 += 0.00001020487*np.cos(4.63746718598 + 6283.0758499914*t)
	Y2 += 0.00000160849*np.cos(2.83104666823 + 206.1855484372*t)
	Y2 += 0.00000155973*np.cos(5.19309730583 + 220.4126424388*t)
	Y2 += 0.00000118316*np.cos(5.70681506981 + 522.5774180938*t)
	Y2 += 0.00000115781*np.cos(1.78259431361 + 536.8045120954*t)
	Y2 += 0.00000092688*np.cos(2.62218748420 + 18849.2275499742*t)
	Y2 += 0.00000103382*np.cos(4.03695721545 + 213.299095438*t)
	Y2 += 0.00000065392*np.cos(4.05826871786 + 426.598190876*t)
	Y2 += 0.00000072930*np.cos(0.61814128649 + 529.6909650946*t)
	Y2 += 0.00000037730*np.cos(0.40598353877 + 1059.3819301892*t)
	Y2 += 0.00000014254*np.cos(4.25680464915 + 433.7117378768*t)
	Y2 += 0.00000014479*np.cos(0.14336346755 + 7.1135470008*t)
	Y2 += 0.00000012723*np.cos(1.91903810105 + 419.4846438752*t)
	Y2 += 0.00000013680*np.cos(1.80736896884 + 6286.5989683404*t)
	Y2 += 0.00000013668*np.cos(1.70191859339 + 6279.5527316424*t)
	Y2 += 0.00000009400*np.cos(3.14385315650 + 639.897286314*t)
	Y2 += 0.00000008190*np.cos(2.84848380902 + 6256.7775301916*t)
	Y2 += 0.00000008145*np.cos(0.65845469208 + 6309.3741697912*t)
	Y2 += 0.00000008004*np.cos(4.35208516133 + 6127.6554505572*t)
	Y2 += 0.00000007720*np.cos(5.06798604557 + 227.5261894396*t)
	Y2 += 0.00000007754*np.cos(5.43893832496 + 6438.4962494256*t)
	Y2 += 0.00000006795*np.cos(2.30303656447 + 1066.49547719*t)
	Y2 += 0.00000008900*np.cos(3.80944637329 + 83996.84731811189*t)
	Y2 += 0.00000005452*np.cos(5.20193437243 + 1052.2683831884*t)
	Y2 += 0.00000005040*np.cos(5.84239832938 + 515.463871093*t)
	Y2 += 0.00000003729*np.cos(2.96611895542 + 199.0720014364*t)
	Y2 += 0.00000003521*np.cos(1.65043749771 + 543.9180590962*t)
	Y2 += 0.00000003454*np.cos(0.78955536940 + 1589.0728952838*t)
	Y2 += 0.00000004754*np.cos(4.59631649528 + 709.9330485583*t)
	Y2 += 0.00000002895*np.cos(3.37918924673 + 4705.7323075436*t)
	Y2 += 0.00000003730*np.cos(0.91975073803 + 5507.5532386674*t)
	Y2 += 0.00000002937*np.cos(2.51081180566 + 25132.3033999656*t)
	Y2 += 0.00000003203*np.cos(2.57193731532 + 7058.5984613154*t)
	Y2 += 0.00000002268*np.cos(1.94917686677 + 775.522611324*t)
	Y2 += 0.00000002148*np.cos(0.14152116438 + 7860.4193924392*t)
	Y2 += 0.00000002031*np.cos(0.72283806291 + 6275.9623029906*t)
	Y2 += 0.00000002031*np.cos(2.78410285615 + 6290.1893969922*t)
	Y2 += 0.00000001904*np.cos(2.89589054598 + 5486.777843175*t)
	Y2 += 0.00000001553*np.cos(0.56386962806 + 6040.3472460174*t)
	Y2 += 0.00000001563*np.cos(0.61022183613 + 7079.3738568078*t)
	Y2 += 0.00000001459*np.cos(1.88257310296 + 5753.3848848968*t)
	Y2 += 0.00000001425*np.cos(1.59147859762 + 6812.766815086*t)
	Y2 += 0.00000001436*np.cos(1.45357168378 + 5884.9268465832*t)
	Y2 += 0.00000001470*np.cos(2.94579999718 + 6525.8044539654*t)
	Y2 += 0.00000001351*np.cos(0.59351678849 + 316.3918696566*t)
	Y2 += 0.00000001409*np.cos(4.65471130275 + 216.4804891757*t)
	Y2 += 0.00000001321*np.cos(3.39383854482 + 647.0108333148*t)
	Y2 += 0.00000001368*np.cos(3.38543777835 + 210.1177017003*t)
	Y2 += 0.00000001281*np.cos(2.05865338247 + 6681.2248533996*t)
	Y2 += 0.00000001717*np.cos(0.02861328541 + 14.2270940016*t)
	Y2 += 0.00000001338*np.cos(5.75684444528 + 5729.506447149*t)
	Y2 += 0.00000000974*np.cos(2.45036377276 + 853.196381752*t)
	Y2 += 0.00000001039*np.cos(4.28230481184 + 6282.0955289232*t)
	Y2 += 0.00000001039*np.cos(5.50782141440 + 6284.0561710596*t)
	Y2 += 0.00000001191*np.cos(4.01917074242 + 6836.6452528338*t)
	Y2 += 0.00000000904*np.cos(0.86455323243 + 5331.3574437408*t)
	Y2 += 0.00000000871*np.cos(2.27688978691 + 4933.2084403326*t)
	Y2 += 0.00000000950*np.cos(2.81842708673 + 632.7837393132*t)
	Y2 += 0.00000000877*np.cos(1.49469829015 + 11790.6290886588*t)
	Y2 += 0.00000000848*np.cos(6.23917434526 + 526.5095713569*t)
	Y2 += 0.00000000806*np.cos(2.96434145307 + 103.0927742186*t)
	Y2 += 0.00000001102*np.cos(3.02451706631 + 167283.76158766549*t)
	Y2 += 0.00000000825*np.cos(1.24361863355 + 532.8723588323*t)
	Y2 += 0.00000000774*np.cos(2.68163901032 + 7234.794256242*t)
	Y2 += 0.00000000761*np.cos(4.73161044526 + 209.3669421749*t)
	Y2 += 0.00000000733*np.cos(3.30972792259 + 217.2312487011*t)
	Y2 += 0.00000000746*np.cos(5.06505548485 + 4136.9104335162*t)
	Y2 += 0.00000000885*np.cos(0.58376168802 + 110.2063212194*t)
	Y2 += 0.00000000689*np.cos(4.21955395780 + 440.8252848776*t)
	Y2 += 0.00000000938*np.cos(2.05233105969 + 11856.2186514245*t)
	Y2 += 0.00000000653*np.cos(6.14159854835 + 11506.7697697936*t)
	Y2 += 0.00000000653*np.cos(1.20042991173 + 7632.9432596502*t)
	Y2 += 0.00000000855*np.cos(3.67241064264 + 4535.0594369244*t)
	Y2 += 0.00000000664*np.cos(3.21978126910 + 1194.4470102246*t)
	Y2 += 0.00000000631*np.cos(5.67308971270 + 117.3198682202*t)
	Y2 += 0.00000000600*np.cos(3.56706010534 + 323.5054166574*t)
	Y2 += 0.00000000814*np.cos(1.07520259172 + 155.4203994342*t)
	Y2 += 0.00000000579*np.cos(4.64690913221 + 796.2980068164*t)
	Y2 += 0.00000000778*np.cos(4.32748087995 + 5088.6288397668*t)
	Y2 += 0.00000000549*np.cos(3.24495575230 + 949.1756089698*t)
	Y2 += 0.00000000606*np.cos(3.86357846284 + 95.9792272178*t)
	Y2 += 0.00000000726*np.cos(5.43722942949 + 74.7815985673*t)
	Y2 += 0.00000000545*np.cos(4.73162468373 + 1045.1548361876*t)
	Y2 += 0.00000000511*np.cos(0.71257437268 + 4694.0029547076*t)
	Y2 += 0.00000000686*np.cos(3.47131000180 + 801.8209311238*t)
	Y2 += 0.00000000677*np.cos(1.14891148781 + 3128.3887650958*t)
	Y2 += 0.00000000599*np.cos(4.43359462367 + 735.8765135318*t)
	Y2 += 0.00000000499*np.cos(1.45672603171 + 12569.6748183318*t)
	Y2 += 0.00000000490*np.cos(1.25898273127 + 525.7588118315*t)
	Y2 += 0.00000000488*np.cos(6.22654201321 + 533.6231183577*t)
	Y2 += 0.00000000480*np.cos(4.72566522648 + 8429.2412664666*t)
	Y2 += 0.00000000598*np.cos(6.12701256696 + 8031.0922630584*t)
	Y2 += 0.00000000437*np.cos(2.81553406247 + 1596.1864422846*t)
	Y2 += 0.00000000519*np.cos(4.53503189245 + 149.5631971346*t)
	Y2 += 0.00000000562*np.cos(5.48344520380 + 7477.522860216*t)
	Y2 += 0.00000000415*np.cos(5.06370124318 + 6496.3749454294*t)
	Y2 += 0.00000000414*np.cos(4.73489535739 + 6069.7767545534*t)
	Y2 += 0.00000000404*np.cos(0.15585991312 + 3738.761430108*t)
	Y2 += 0.00000000500*np.cos(1.83746339810 + 1592.5960136328*t)
	Y2 += 0.00000000392*np.cos(0.64094689719 + 26.2983197998*t)
	Y2 += 0.00000000366*np.cos(5.93255688855 + 553.5694028424*t)
	Y2 += 0.00000000458*np.cos(5.56847632382 + 156137.47598479928*t)
	Y2 += 0.00000000320*np.cos(0.43684109891 + 1990.745017041*t)
	Y2 += 0.00000000318*np.cos(4.53872367492 + 951.7184062506*t)
	Y2 += 0.00000000361*np.cos(3.78139914914 + 7084.8967811152*t)
	Y2 += 0.00000000356*np.cos(4.78764157089 + 12721.572099417*t)
	Y2 += 0.00000000279*np.cos(5.51531767271 + 4690.4798363586*t)
	Y2 += 0.00000000347*np.cos(6.05487619509 + 5481.2549188676*t)
	Y2 += 0.00000000279*np.cos(0.65072513623 + 242.728603974*t)
	Y2 += 0.00000000349*np.cos(4.12933332026 + 63.7358983034*t)
	Y2 += 0.00000000367*np.cos(2.35508391326 + 9437.762934887*t)
	Y2 += 0.00000000289*np.cos(1.16064437719 + 2118.7638603784*t)
	Y2 += 0.00000000337*np.cos(1.63942541135 + 412.3710968744*t)
	Y2 += 0.00000000270*np.cos(5.28007746957 + 1581.959348283*t)
	Y2 += 0.00000000260*np.cos(0.98725902772 + 5223.6939198022*t)
	Y2 += 0.00000000255*np.cos(0.26797013701 + 11371.7046897582*t)
	Y2 += 0.00000000260*np.cos(4.50952770985 + 625.6701923124*t)
	Y2 += 0.00000000242*np.cos(3.35248006615 + 8827.3902698748*t)
	Y2 += 0.00000000237*np.cos(0.07292901465 + 70.8494453042*t)
	Y2 += 0.00000000245*np.cos(2.60270196816 + 3154.6870848956*t)
	Y2 += 0.00000000227*np.cos(4.92862031663 + 234.6397364404*t)
	Y2 += 0.00000000222*np.cos(0.17857635292 + 4164.311989613*t)
	Y2 += 0.00000000219*np.cos(5.43349299793 + 11.0457002639*t)
	Y2 += 0.00000000256*np.cos(5.25900695618 + 956.2891559706*t)
	Y2 += 0.00000000218*np.cos(4.61617873387 + 78.7137518304*t)
	Y2 += 0.00000000221*np.cos(1.83683124614 + 1748.016413067*t)
	Y2 += 0.00000000288*np.cos(3.16521452041 + 1349.8674096588*t)
	Y2 += 0.00000000283*np.cos(0.60090092021 + 85.8272988312*t)
	Y2 += 0.00000000211*np.cos(3.29348428114 + 942.062061969*t)
	Y2 += 0.00000000204*np.cos(5.15479639183 + 11769.8536931664*t)
	Y2 += 0.00000000226*np.cos(3.69462756239 + 73.297125859*t)
	Y2 += 0.00000000235*np.cos(0.31453942563 + 36.6485629295*t)
	Y2 += 0.00000000213*np.cos(2.54349021425 + 309.2783226558*t)
	Y2 += 0.00000000188*np.cos(4.08810200628 + 7875.6718636242*t)
	Y2 += 0.00000000204*np.cos(5.17246322251 + 10977.078804699*t)
	Y2 += 0.00000000224*np.cos(4.02383631251 + 39.6175083461*t)
	Y2 += 0.00000000188*np.cos(5.32022679153 + 2388.8940204492*t)
	Y2 += 0.00000000231*np.cos(2.66318410477 + 202.2533951741*t)
	Y2 += 0.00000000183*np.cos(2.53020407005 + 7342.4577801806*t)
	Y2 += 0.00000000187*np.cos(1.29115653830 + 1169.5882514086*t)
	Y2 += 0.00000000196*np.cos(4.81306031436 + 3930.2096962196*t)
	Y2 += 0.00000000167*np.cos(2.07259165182 + 1073.6090241908*t)
	Y2 += 0.00000000196*np.cos(5.64541899687 + 224.3447957019*t)
	Y2 += 0.00000000207*np.cos(0.71423535949 + 13367.9726311066*t)
	Y2 += 0.00000000206*np.cos(1.68118727655 + 10973.55568635*t)
	Y2 += 0.00000000158*np.cos(5.13689612572 + 1155.361157407*t)
	Y2 += 0.00000000144*np.cos(3.12119544517 + 10575.4066829418*t)
	Y2 += 0.00000000137*np.cos(0.50600690701 + 742.9900605326*t)
	Y2 += 0.00000000135*np.cos(5.63458486706 + 138.5174968707*t)
	Y2 += 0.00000000155*np.cos(4.24333182826 + 12410.7313005486*t)
	Y2 += 0.00000000148*np.cos(1.53909219281 + 76.2660712756*t)
	Y2 += 0.00000000133*np.cos(6.00639174435 + 508.3503240922*t)
	Y2 += 0.00000000135*np.cos(5.62460495351 + 12592.4500197826*t)
	Y2 += 0.00000000126*np.cos(3.76226961231 + 330.6189636582*t)
	Y2 += 0.00000000126*np.cos(2.61435997717 + 860.3099287528*t)
	Y2 += 0.00000000125*np.cos(2.30734650656 + 12562.6285816338*t)
	Y2 += 0.00000000158*np.cos(2.17797348306 + 38.1330356378*t)
	Y2 += 0.00000000118*np.cos(3.15911802638 + 13119.72110282519*t)
	Y2 += 0.00000000124*np.cos(4.88716980692 + 8635.9420037632*t)
	Y2 += 0.00000000111*np.cos(0.80973565731 + 398.1490034082*t)
	Y2 += 0.00000000115*np.cos(4.52412782775 + 223.5940361765*t)
	Y2 += 0.00000000110*np.cos(4.93056089704 + 71.6002048296*t)
	Y2 += 0.00000000115*np.cos(3.76754615650 + 429.7795846137*t)
	Y2 += 0.00000000099*np.cos(1.74904579789 + 13517.8701062334*t)
	Y2 += 0.00000000097*np.cos(4.08519883679 + 17260.1546546904*t)
	Y2 += 0.00000000106*np.cos(6.02834271847 + 77.962992305*t)
	Y2 += 0.00000000102*np.cos(2.80042792551 + 10988.808157535*t)
	Y2 += 0.00000000093*np.cos(4.87729654087 + 1577.3435424478*t)
	Y2 += 0.00000000094*np.cos(4.56913615419 + 10177.2576795336*t)
	Y2 += 0.00000000123*np.cos(4.57966985938 + 728.762966531*t)
	Y2 += 0.00000000095*np.cos(0.58410858338 + 2146.1654164752*t)
	Y2 += 0.00000000100*np.cos(0.77889460323 + 13095.8426650774*t)
	Y2 += 0.00000000105*np.cos(6.21526366678 + 1162.4747044078*t)
	Y2 += 0.00000000082*np.cos(3.65082093235 + 16730.4636895958*t)
	Y2 += 0.00000000102*np.cos(3.63292130858 + 422.6660376129*t)
	Y2 += 0.00000000109*np.cos(2.42647120751 + 12539.853380183*t)
	Y2 += 0.00000000084*np.cos(4.77208861984 + 124.433415221*t)
	Y2 += 0.00000000080*np.cos(2.67636202935 + 12323.4230960088*t)
	Y2 += 0.00000000105*np.cos(1.96765666886 + 5642.1982426092*t)
	Y2 += 0.00000000101*np.cos(0.26697958405 + 4292.3308329504*t)
	Y2 += 0.00000000075*np.cos(4.15987686546 + 6709.6740408674*t)
	Y2 += 0.00000000075*np.cos(5.63024936078 + 5856.4776591154*t)
	Y2 += 0.00000000074*np.cos(4.08123538694 + 88.865680217*t)
	Y2 += 0.00000000076*np.cos(2.63432357020 + 423.4167971383*t)
	Y2 += 0.00000000073*np.cos(5.78330657332 + 1265.5674786264*t)
	Y2 += 0.00000000100*np.cos(5.37997214401 + 250570.67585721909*t)
	Y2 += 0.00000000071*np.cos(1.48891806144 + 551.031606097*t)
	Y2 += 0.00000000081*np.cos(0.13371582190 + 519.3960243561*t)
	Y2 += 0.00000000071*np.cos(5.31207567706 + 14314.1681130498*t)
	Y2 += 0.00000000068*np.cos(3.39472444791 + 654.1243803156*t)
	Y2 += 0.00000000092*np.cos(0.41159879070 + 13916.0191096416*t)
	Y2 += 0.00000000091*np.cos(1.53881053794 + 6923.9534573736*t)
	Y2 += 0.00000000082*np.cos(2.43138857903 + 31415.379249957*t)
	Y2 += 0.00000000072*np.cos(6.15951862716 + 21.3406410024*t)
	Y2 += 0.00000000060*np.cos(3.13717737901 + 191.9584544356*t)
	Y2 += 0.00000000083*np.cos(4.40764560915 + 95143.1329209781*t)
	Y2 += 0.00000000061*np.cos(2.66905862210 + 8273.8208670324*t)
	Y2 += 0.00000000065*np.cos(3.55971117777 + 203.0041546995*t)
	Y2 += 0.00000000055*np.cos(2.98440193981 + 5643.1785636774*t)
	Y2 += 0.00000000064*np.cos(1.05451249819 + 539.9859058331*t)
	Y2 += 0.00000000061*np.cos(5.33630384952 + 838.9692877504*t)
	Y2 += 0.00000000054*np.cos(4.06071028317 + 16496.3613962024*t)
	Y2 += 0.00000000055*np.cos(2.26469062405 + 13341.6743113068*t)
	Y2 += 0.00000000073*np.cos(0.30591075918 + 71430.69561812909*t)
	Y2 += 0.00000000052*np.cos(5.97085689483 + 3634.6210245184*t)
	Y2 += 0.00000000061*np.cos(0.00617004446 + 3.1813937377*t)
	Y2 += 0.00000000050*np.cos(2.61636629528 + 12573.2652469836*t)
	Y2 += 0.00000000052*np.cos(6.19672300540 + 15720.8387848784*t)
	Y2 += 0.00000000065*np.cos(4.92633618792 + 4732.0306273434*t)
	Y2 += 0.00000000066*np.cos(3.92505637420 + 2787.0430238574*t)
	Y2 += 0.00000000048*np.cos(0.45273646609 + 13362.4497067992*t)
	Y2 += 0.00000000053*np.cos(2.55293773264 + 14919.0178537546*t)
	Y2 += 0.00000000047*np.cos(3.46367064388 + 302.164775655*t)
	Y2 += 0.00000000047*np.cos(2.25879651839 + 12964.300703391*t)
	Y2 += 0.00000000045*np.cos(2.73683504159 + 846.0828347512*t)
	Y2 += 0.00000000045*np.cos(2.31642282675 + 145.6310438715*t)
	Y2 += 0.00000000047*np.cos(1.06895129610 + 3894.1818295422*t)
	Y2 += 0.00000000042*np.cos(5.09300549015 + 24072.9214697764*t)
	Y2 += 0.00000000047*np.cos(1.74738635330 + 1062.5633239269*t)
	Y2 += 0.00000000051*np.cos(5.97812516445 + 6195.76764545159*t)
	Y2 += 0.00000000051*np.cos(3.81200106179 + 6370.3840545312*t)
	Y2 += 0.00000000041*np.cos(0.92655469135 + 18319.5365848796*t)
	Y2 += 0.00000000041*np.cos(2.52247946610 + 3185.1920272656*t)
	Y2 += 0.00000000056*np.cos(2.58677293772 + 84672.47584450469*t)
	Y2 += 0.00000000046*np.cos(3.14760491945 + 3.9321532631*t)
	Y2 += 0.00000000038*np.cos(5.98916947033 + 1258.4539316256*t)
	Y2 += 0.00000000039*np.cos(2.70559904392 + 20426.571092422*t)
	Y2 += 0.00000000053*np.cos(1.64080385432 + 239424.39025435288*t)
	Y2 += 0.00000000045*np.cos(6.04609930388 + 9779.1086761254*t)
	Y2 += 0.00000000035*np.cos(6.26763450664 + 1692.1656695024*t)
	Y2 += 0.00000000044*np.cos(3.24184126256 + 8662.240323563*t)
	Y2 += 0.00000000043*np.cos(2.12627080359 + 18139.2945014159*t)
	Y2 += 0.00000000033*np.cos(4.03936498647 + 277.0349937414*t)
	Y2 += 0.00000000033*np.cos(1.67764931937 + 3496.032826134*t)
	Y2 += 0.00000000035*np.cos(5.17885502556 + 18875.525869774*t)
	Y2 += 0.00000000035*np.cos(4.51995137508 + 10419.9862835076*t)
	Y2 += 0.00000000031*np.cos(5.35886426810 + 23013.5395395872*t)
	Y2 += 0.00000000030*np.cos(3.29256356524 + 2125.8774073792*t)
	Y2 += 0.00000000035*np.cos(5.96755475967 + 1056.2005364515*t)
	Y2 += 0.00000000030*np.cos(2.82636067861 + 12808.8803039568*t)
	Y2 += 0.00000000042*np.cos(0.90184598337 + 82576.98122099529*t)
	Y2 += 0.00000000031*np.cos(3.95971884541 + 14712.317116458*t)
	Y2 += 0.00000000040*np.cos(4.02926744005 + 17789.845619785*t)
	Y2 += 0.00000000031*np.cos(5.47911308336 + 22779.4372461938*t)
	Y2 += 0.00000000039*np.cos(4.91039224856 + 1574.8458012822*t)
	Y2 += 0.00000000030*np.cos(2.31682203487 + 10447.3878396044*t)
	Y2 += 0.00000000028*np.cos(2.11876435927 + 14143.4952424306*t)
	Y2 += 0.00000000036*np.cos(4.84158532799 + 437.6438911399*t)
	Y2 += 0.00000000028*np.cos(3.91478954977 + 5429.8794682394*t)
	Y2 += 0.00000000028*np.cos(1.90040914464 + 1055.4497769261*t)
	Y2 += 0.00000000030*np.cos(1.17555913144 + 9380.9596727172*t)
	Y2 += 0.00000000031*np.cos(1.82502538910 + 1272.6810256272*t)
	Y2 += 0.00000000026*np.cos(0.72314347990 + 9623.6882766912*t)
	Y2 += 0.00000000026*np.cos(2.78379743916 + 2942.4634232916*t)
	Y2 += 0.00000000027*np.cos(4.68673408301 + 1038.0412891868*t)
	Y2 += 0.00000000026*np.cos(0.18151529861 + 18209.33026366019*t)
	Y2 += 0.00000000029*np.cos(0.08375583590 + 1485.9801210652*t)
	Y2 += 0.00000000027*np.cos(6.07872663556 + 618.5566453116*t)
	Y2 += 0.00000000026*np.cos(5.52380000200 + 415.5524906121*t)
	Y2 += 0.00000000025*np.cos(1.11733039286 + 3583.3410306738*t)
	Y2 += 0.00000000030*np.cos(1.75812035666 + 10213.285546211*t)
	Y2 += 0.00000000024*np.cos(1.36775216012 + 9917.6968745098*t)
	Y2 += 0.00000000026*np.cos(3.49078871449 + 430.5303441391*t)
	Y2 += 0.00000000024*np.cos(1.99820614050 + 18.1592472647*t)
	Y2 += 0.00000000026*np.cos(5.61732376806 + 12012.5822971404*t)
	Y2 += 0.00000000023*np.cos(6.16563076611 + 231.4583427027*t)
	Y2 += 0.00000000023*np.cos(0.92088373151 + 12559.038152982*t)
	Y2 += 0.00000000023*np.cos(5.58098323545 + 831.8557407496*t)
	Y2 += 0.00000000023*np.cos(5.52325028212 + 11015.1064773348*t)
	Y2 += 0.00000000023*np.cos(0.69647593831 + 26709.6469424134*t)
	Y2 += 0.00000000024*np.cos(3.30887701069 + 77713.7714681205*t)
	Y2 += 0.00000000025*np.cos(1.67396248390 + 2648.454825473*t)
	Y2 += 0.00000000021*np.cos(4.15712645283 + 447.9388318784*t)
	Y2 += 0.00000000024*np.cos(0.66675947895 + 1368.660252845*t)
	Y2 += 0.00000000022*np.cos(4.42086856143 + 6993.0088985497*t)
	Y2 += 0.00000000021*np.cos(0.81252266714 + 17256.6315363414*t)
	Y2 += 0.00000000020*np.cos(5.70175704295 + 10.2949407385*t)
	Y2 += 0.00000000022*np.cos(3.76535003503 + 151.0476698429*t)
	Y2 += 0.00000000020*np.cos(1.82615991897 + 1699.2792165032*t)
	Y2 += 0.00000000019*np.cos(0.17448576187 + 1063.3140834523*t)
	Y2 += 0.00000000023*np.cos(5.52062840479 + 149854.40013480789*t)
	Y2 += 0.00000000020*np.cos(0.96756200367 + 35.1640902212*t)
	Y2 += 0.00000000021*np.cos(4.76218572464 + 72.3339180125*t)
	Y2 += 0.00000000019*np.cos(0.35979025769 + 11926.2544136688*t)
	Y2 += 0.00000000018*np.cos(0.71176167314 + 11614.4332937322*t)
	Y2 += 0.00000000019*np.cos(4.89783197147 + 18073.7049386502*t)
	Y2 += 0.00000000019*np.cos(2.09021029647 + 30639.856638633*t)
	Y2 += 0.00000000022*np.cos(2.19299415984 + 17298.1823273262*t)
	Y2 += 0.00000000019*np.cos(1.23251732918 + 19651.048481098*t)
	Y2 += 0.00000000018*np.cos(4.04819585578 + 1471.7530270636*t)
	Y2 += 0.00000000023*np.cos(3.21303801707 + 72850.56171524568*t)
	Y2 += 0.00000000016*np.cos(3.64206691792 + 1478.8665740644*t)
	Y2 += 0.00000000017*np.cos(2.38624204004 + 8982.810669309*t)
	Y2 += 0.00000000016*np.cos(0.58395212576 + 22.0914005278*t)
	Y2 += 0.00000000021*np.cos(2.20285403235 + 16858.4825329332*t)
	Y2 += 0.00000000017*np.cos(0.49891545478 + 77.7505439839*t)
	Y2 += 0.00000000021*np.cos(2.89968186701 + 12036.4607348882*t)
	Y2 += 0.00000000014*np.cos(3.30566599775 + 16460.33352952499*t)
	Y2 += 0.00000000020*np.cos(4.99490943445 + 5573.1428014331*t)
	Y2 += 0.00000000016*np.cos(3.38818988576 + 41.1019810544*t)
	Y2 += 0.00000000014*np.cos(3.27141245862 + 1375.7737998458*t)
	Y2 += 0.00000000015*np.cos(3.46067246830 + 160.6088973985*t)
	Y2 += 0.00000000015*np.cos(2.64766821618 + 20199.094959633*t)
	Y2 += 0.00000000014*np.cos(4.87181144278 + 22483.84857449259*t)
	Y2 += 0.00000000019*np.cos(1.24341688060 + 8671.9698704406*t)
	Y2 += 0.00000000017*np.cos(0.01999942730 + 77.2292791221*t)
	Y2 += 0.00000000014*np.cos(4.11314424872 + 71.8126531507*t)
	Y2 += 0.00000000014*np.cos(5.97526530111 + 90279.92316810328*t)
	Y2 += 0.00000000015*np.cos(1.62123638185 + 65.2203710117*t)
	Y2 += 0.00000000016*np.cos(5.12394281212 + 23543.23050468179*t)
	Y2 += 0.00000000012*np.cos(1.13908210541 + 17996.0311682222*t)
	Y2 += 0.00000000012*np.cos(5.43458827343 + 19402.7969528166*t)
	Y2 += 0.00000000013*np.cos(2.10315959516 + 131.4039498699*t)
	Y2 += 0.00000000012*np.cos(3.60070147194 + 337.732510659*t)
	Y2 += 0.00000000012*np.cos(5.16899217088 + 195.1398481733*t)
	Y2 += 0.00000000012*np.cos(2.80798050151 + 10818.1352869158*t)
	Y2 += 0.00000000015*np.cos(5.28864619208 + 12567.132021051*t)
	Y2 += 0.00000000013*np.cos(1.57968548593 + 408.4389436113*t)
	Y2 += 0.00000000011*np.cos(0.21390152319 + 28766.924424484*t)
	Y2 += 0.00000000011*np.cos(0.68624711981 + 14945.3161735544*t)
	Y2 += 0.00000000011*np.cos(3.36248263984 + 18451.07854656599*t)
	Y2 += 0.00000000014*np.cos(5.41918866932 + 2111.6503133776*t)
	Y2 += 0.00000000011*np.cos(4.73842604358 + 511.5317178299*t)
	Y2 += 0.00000000012*np.cos(2.63845374146 + 963.4027029714*t)
	Y2 += 0.00000000011*np.cos(4.69826436697 + 2352.8661537718*t)
	Y2 += 0.00000000010*np.cos(2.74385211018 + 547.8502123593*t)
	Y2 += 0.00000000011*np.cos(0.30993049479 + 22805.7355659936*t)
	Y2 += 0.00000000011*np.cos(0.67524830165 + 35371.8872659764*t)
	Y2 += 0.00000000014*np.cos(0.36237106347 + 21228.3920235458*t)
	Y2 += 0.00000000010*np.cos(4.24006763767 + 127.4717966068*t)
	Y2 += 0.00000000010*np.cos(4.48227917427 + 23141.5583829246*t)
	Y2 += 0.00000000010*np.cos(3.10795031986 + 362.8622925726*t)
	Y2 += 0.00000000012*np.cos(5.50291077360 + 1685.0521225016*t)
	Y2 += 0.00000000010*np.cos(3.38695373136 + 934.9485149682*t)
	Y2 += 0.00000000010*np.cos(0.98562604234 + 22345.2603761082*t)
	Y2 += 0.00000000009*np.cos(6.20387541356 + 29826.3063546732*t)
	Y2 += 0.00000000010*np.cos(4.89597714031 + 12779.4507954208*t)
	Y2 += 0.00000000013*np.cos(3.34698985021 + 84.3428261229*t)
	Y2 += 0.00000000009*np.cos(4.89802068656 + 1382.8873468466*t)
	Y2 += 0.00000000011*np.cos(5.10892321991 + 25158.6017197654*t)
	Y2 += 0.00000000012*np.cos(1.08976567704 + 148.0787244263*t)
	Y2 += 0.00000000009*np.cos(2.89659186256 + 23581.2581773176*t)
	Y2 += 0.00000000009*np.cos(0.86970882362 + 153.4953503977*t)
	return Y2*t*t




def Earth_Y3 (t): # 111 terms of order 3

	Y3 = 0.
	Y3 -= 0.00000125477
	Y3 += 0.00000072366*np.cos(1.32019314413 + 12566.1516999828*t)
	Y3 += 0.00000022088*np.cos(4.54598360855 + 206.1855484372*t)
	Y3 += 0.00000021546*np.cos(3.46116671016 + 220.4126424388*t)
	Y3 += 0.00000016300*np.cos(1.14934178921 + 522.5774180938*t)
	Y3 += 0.00000015923*np.cos(0.06221071687 + 536.8045120954*t)
	Y3 += 0.00000013847*np.cos(5.37444701633 + 6283.0758499914*t)
	Y3 += 0.00000005044*np.cos(0.96001931081 + 18849.2275499742*t)
	Y3 += 0.00000003093*np.cos(2.22514436528 + 426.598190876*t)
	Y3 += 0.00000002568*np.cos(2.47493921494 + 433.7117378768*t)
	Y3 += 0.00000002105*np.cos(3.35595521974 + 227.5261894396*t)
	Y3 += 0.00000001700*np.cos(5.13510489936 + 1059.3819301892*t)
	Y3 += 0.00000001481*np.cos(0.66592602555 + 6438.4962494256*t)
	Y3 += 0.00000001481*np.cos(2.84101489351 + 6127.6554505572*t)
	Y3 += 0.00000001378*np.cos(1.27086042787 + 515.463871093*t)
	Y3 += 0.00000001266*np.cos(3.80209162712 + 419.4846438752*t)
	Y3 += 0.00000001363*np.cos(4.63636570705 + 7.1135470008*t)
	Y3 += 0.00000001013*np.cos(4.67704889552 + 199.0720014364*t)
	Y3 += 0.00000001037*np.cos(0.69915801725 + 1066.49547719*t)
	Y3 += 0.00000000964*np.cos(6.22045145850 + 543.9180590962*t)
	Y3 += 0.00000000849*np.cos(1.26670686968 + 639.897286314*t)
	Y3 += 0.00000000678*np.cos(0.79554783130 + 1052.2683831884*t)
	Y3 += 0.00000000644*np.cos(3.31488272100 + 6279.5527316424*t)
	Y3 += 0.00000000644*np.cos(0.19205819806 + 6286.5989683404*t)
	Y3 += 0.00000000392*np.cos(4.59101411052 + 14.2270940016*t)
	Y3 += 0.00000000318*np.cos(2.06760677503 + 6040.3472460174*t)
	Y3 += 0.00000000318*np.cos(1.43933414403 + 6525.8044539654*t)
	Y3 += 0.00000000291*np.cos(1.57357745396 + 647.0108333148*t)
	Y3 += 0.00000000248*np.cos(5.85725743749 + 1589.0728952838*t)
	Y3 += 0.00000000214*np.cos(2.46865385667 + 440.8252848776*t)
	Y3 += 0.00000000231*np.cos(2.85226310193 + 216.4804891757*t)
	Y3 += 0.00000000220*np.cos(5.18394074276 + 210.1177017003*t)
	Y3 += 0.00000000220*np.cos(0.77087312633 + 25132.3033999656*t)
	Y3 += 0.00000000201*np.cos(5.53953658848 + 6836.6452528338*t)
	Y3 += 0.00000000201*np.cos(4.25058963776 + 5729.506447149*t)
	Y3 += 0.00000000129*np.cos(0.22762324749 + 1045.1548361876*t)
	Y3 += 0.00000000123*np.cos(0.51351773704 + 853.196381752*t)
	Y3 += 0.00000000137*np.cos(2.15435863260 + 529.6909650946*t)
	Y3 += 0.00000000092*np.cos(3.22442461302 + 234.6397364404*t)
	Y3 += 0.00000000087*np.cos(4.52965482365 + 103.0927742186*t)
	Y3 += 0.00000000092*np.cos(3.90819414656 + 117.3198682202*t)
	Y3 += 0.00000000085*np.cos(5.57189606315 + 95.9792272178*t)
	Y3 += 0.00000000094*np.cos(2.25901632919 + 213.299095438*t)
	Y3 += 0.00000000075*np.cos(1.30082808866 + 1596.1864422846*t)
	Y3 += 0.00000000078*np.cos(4.96547279129 + 110.2063212194*t)
	Y3 += 0.00000000071*np.cos(4.48281367743 + 632.7837393132*t)
	Y3 += 0.00000000076*np.cos(3.40988387446 + 412.3710968744*t)
	Y3 += 0.00000000064*np.cos(2.39566214965 + 316.3918696566*t)
	Y3 += 0.00000000056*np.cos(1.44254805098 + 508.3503240922*t)
	Y3 += 0.00000000055*np.cos(1.71252125469 + 323.5054166574*t)
	Y3 += 0.00000000048*np.cos(0.40111970766 + 1073.6090241908*t)
	Y3 += 0.00000000056*np.cos(6.19540120033 + 735.8765135318*t)
	Y3 += 0.00000000042*np.cos(6.13276553266 + 625.6701923124*t)
	Y3 += 0.00000000039*np.cos(5.02961841371 + 942.062061969*t)
	Y3 += 0.00000000036*np.cos(6.12441668493 + 12569.6748183318*t)
	Y3 += 0.00000000036*np.cos(3.01279484364 + 209.3669421749*t)
	Y3 += 0.00000000031*np.cos(0.88356246900 + 1581.959348283*t)
	Y3 += 0.00000000031*np.cos(6.03310463140 + 551.031606097*t)
	Y3 += 0.00000000032*np.cos(4.98300318004 + 217.2312487011*t)
	Y3 += 0.00000000033*np.cos(0.75212348383 + 860.3099287528*t)
	Y3 += 0.00000000033*np.cos(2.66474952932 + 12410.7313005486*t)
	Y3 += 0.00000000030*np.cos(4.51763020093 + 70.8494453042*t)
	Y3 += 0.00000000027*np.cos(2.35184788494 + 149.5631971346*t)
	Y3 += 0.00000000028*np.cos(1.91930691377 + 330.6189636582*t)
	Y3 += 0.00000000027*np.cos(0.05305218851 + 2118.7638603784*t)
	Y3 += 0.00000000028*np.cos(0.17790568355 + 78.7137518304*t)
	Y3 += 0.00000000027*np.cos(4.37487614145 + 21.3406410024*t)
	Y3 += 0.00000000029*np.cos(5.17540731322 + 949.1756089698*t)
	Y3 += 0.00000000025*np.cos(3.02081007506 + 124.433415221*t)
	Y3 += 0.00000000033*np.cos(2.73570572399 + 223.5940361765*t)
	Y3 += 0.00000000025*np.cos(5.88306502494 + 1169.5882514086*t)
	Y3 += 0.00000000024*np.cos(6.25389986741 + 63.7358983034*t)
	Y3 += 0.00000000024*np.cos(4.81432332838 + 191.9584544356*t)
	Y3 += 0.00000000028*np.cos(0.01012773075 + 728.762966531*t)
	Y3 += 0.00000000024*np.cos(1.59054971444 + 654.1243803156*t)
	Y3 += 0.00000000030*np.cos(4.35202882411 + 309.2783226558*t)
	Y3 += 0.00000000022*np.cos(0.58430377684 + 1155.361157407*t)
	Y3 += 0.00000000020*np.cos(5.79574932921 + 88.865680217*t)
	Y3 += 0.00000000023*np.cos(3.64404039148 + 956.2891559706*t)
	Y3 += 0.00000000019*np.cos(4.74503190924 + 85.8272988312*t)
	Y3 += 0.00000000019*np.cos(5.66498805054 + 73.297125859*t)
	Y3 += 0.00000000018*np.cos(0.75629855075 + 12721.572099417*t)
	Y3 += 0.00000000025*np.cos(1.94036276937 + 429.7795846137*t)
	Y3 += 0.00000000024*np.cos(1.95947716237 + 519.3960243561*t)
	Y3 += 0.00000000020*np.cos(0.29570924626 + 71.6002048296*t)
	Y3 += 0.00000000018*np.cos(4.38365354248 + 77.962992305*t)
	Y3 += 0.00000000016*np.cos(4.70914310164 + 202.2533951741*t)
	Y3 += 0.00000000020*np.cos(5.48263393467 + 539.9859058331*t)
	Y3 += 0.00000000016*np.cos(3.45867068386 + 224.3447957019*t)
	Y3 += 0.00000000015*np.cos(5.26771574252 + 302.164775655*t)
	Y3 += 0.00000000014*np.cos(5.35318240788 + 76.2660712756*t)
	Y3 += 0.00000000017*np.cos(5.40518600219 + 203.0041546995*t)
	Y3 += 0.00000000011*np.cos(3.87206824630 + 11.0457002639*t)
	Y3 += 0.00000000010*np.cos(2.40929335654 + 36.6485629295*t)
	Y3 += 0.00000000012*np.cos(1.79980409055 + 422.6660376129*t)
	Y3 += 0.00000000009*np.cos(1.93147151515 + 39.6175083461*t)
	Y3 += 0.00000000009*np.cos(0.16500567398 + 1038.0412891868*t)
	Y3 += 0.00000000009*np.cos(0.79081879948 + 838.9692877504*t)
	Y3 += 0.00000000009*np.cos(2.40868380460 + 447.9388318784*t)
	Y3 += 0.00000000011*np.cos(4.70234349211 + 12592.4500197826*t)
	Y3 += 0.00000000008*np.cos(1.59402806626 + 618.5566453116*t)
	Y3 += 0.00000000009*np.cos(2.51756026677 + 74.7815985673*t)
	Y3 += 0.00000000008*np.cos(5.09979031312 + 423.4167971383*t)
	Y3 += 0.00000000009*np.cos(0.33848481291 + 1574.8458012822*t)
	Y3 += 0.00000000007*np.cos(1.37888755215 + 1258.4539316256*t)
	Y3 += 0.00000000006*np.cos(1.09195739886 + 831.8557407496*t)
	Y3 += 0.00000000006*np.cos(1.00867247429 + 138.5174968707*t)
	Y3 += 0.00000000006*np.cos(4.91543048225 + 742.9900605326*t)
	Y3 += 0.00000000006*np.cos(1.82818120946 + 2125.8774073792*t)
	Y3 += 0.00000000005*np.cos(0.60506372351 + 145.6310438715*t)
	Y3 += 0.00000000007*np.cos(5.32328426995 + 38.1330356378*t)
	return Y3*t*t*t




def Earth_Y4 (t): # 68 terms of order 4

	Y4 = 0.
	Y4 -= 0.00000004122
	Y4 += 0.00000002278*np.cos(6.27388903010 + 206.1855484372*t)
	Y4 += 0.00000002245*np.cos(1.70782913671 + 220.4126424388*t)
	Y4 += 0.00000001931*np.cos(5.89883838000 + 12566.1516999828*t)
	Y4 += 0.00000001682*np.cos(2.89988955370 + 522.5774180938*t)
	Y4 += 0.00000001636*np.cos(4.60365551069 + 536.8045120954*t)
	Y4 += 0.00000000595*np.cos(0.51679590840 + 6283.0758499914*t)
	Y4 += 0.00000000431*np.cos(1.63508563664 + 227.5261894396*t)
	Y4 += 0.00000000349*np.cos(0.69586528581 + 433.7117378768*t)
	Y4 += 0.00000000291*np.cos(3.00165310731 + 515.463871093*t)
	Y4 += 0.00000000210*np.cos(2.17239897368 + 6438.4962494256*t)
	Y4 += 0.00000000210*np.cos(1.33454194538 + 6127.6554505572*t)
	Y4 += 0.00000000229*np.cos(5.59311519226 + 18849.2275499742*t)
	Y4 += 0.00000000206*np.cos(4.48461122025 + 543.9180590962*t)
	Y4 += 0.00000000204*np.cos(0.11049991144 + 199.0720014364*t)
	Y4 += 0.00000000123*np.cos(5.38340390628 + 1066.49547719*t)
	Y4 += 0.00000000099*np.cos(5.70623543947 + 419.4846438752*t)
	Y4 += 0.00000000117*np.cos(0.28020890432 + 426.598190876*t)
	Y4 += 0.00000000096*np.cos(2.80306869168 + 7.1135470008*t)
	Y4 += 0.00000000061*np.cos(2.82818345895 + 14.2270940016*t)
	Y4 += 0.00000000052*np.cos(3.37268534533 + 1059.3819301892*t)
	Y4 += 0.00000000066*np.cos(2.63263056615 + 1052.2683831884*t)
	Y4 += 0.00000000050*np.cos(0.71576934216 + 440.8252848776*t)
	Y4 += 0.00000000059*np.cos(5.69532892910 + 639.897286314*t)
	Y4 += 0.00000000049*np.cos(6.02940323662 + 647.0108333148*t)
	Y4 += 0.00000000044*np.cos(3.02550685011 + 709.9330485583*t)
	Y4 += 0.00000000028*np.cos(0.26064157330 + 213.299095438*t)
	Y4 += 0.00000000024*np.cos(1.48209397973 + 234.6397364404*t)
	Y4 += 0.00000000023*np.cos(2.06131193005 + 1045.1548361876*t)
	Y4 += 0.00000000021*np.cos(4.89379608284 + 6286.5989683404*t)
	Y4 += 0.00000000021*np.cos(4.89633014340 + 6279.5527316424*t)
	Y4 += 0.00000000014*np.cos(3.25423631036 + 508.3503240922*t)
	Y4 += 0.00000000013*np.cos(4.48491117264 + 1589.0728952838*t)
	Y4 += 0.00000000011*np.cos(5.24080280774 + 412.3710968744*t)
	Y4 += 0.00000000012*np.cos(4.87116288717 + 853.196381752*t)
	Y4 += 0.00000000010*np.cos(5.03146150255 + 1073.6090241908*t)
	Y4 += 0.00000000010*np.cos(1.05727005468 + 95.9792272178*t)
	Y4 += 0.00000000010*np.cos(6.06799555020 + 1596.1864422846*t)
	Y4 += 0.00000000010*np.cos(5.71091802020 + 529.6909650946*t)
	Y4 += 0.00000000013*np.cos(2.23957099685 + 83996.84731811189*t)
	Y4 += 0.00000000011*np.cos(5.36791829228 + 25132.3033999656*t)
	Y4 += 0.00000000009*np.cos(2.76384051230 + 21.3406410024*t)
	Y4 += 0.00000000008*np.cos(6.23072779166 + 103.0927742186*t)
	Y4 += 0.00000000010*np.cos(2.05522879011 + 117.3198682202*t)
	Y4 += 0.00000000007*np.cos(3.08813888762 + 110.2063212194*t)
	Y4 += 0.00000000007*np.cos(4.14773765350 + 551.031606097*t)
	Y4 += 0.00000000009*np.cos(3.62304265651 + 11856.2186514245*t)
	Y4 += 0.00000000006*np.cos(6.11652071967 + 654.1243803156*t)
	Y4 += 0.00000000007*np.cos(4.59462394746 + 167283.76158766549*t)
	Y4 += 0.00000000005*np.cos(1.24583749139 + 124.433415221*t)
	Y4 += 0.00000000005*np.cos(0.40108066581 + 942.062061969*t)
	Y4 += 0.00000000006*np.cos(5.14748397921 + 860.3099287528*t)
	Y4 += 0.00000000005*np.cos(1.11835906029 + 12410.7313005486*t)
	Y4 += 0.00000000005*np.cos(1.40699621378 + 88.865680217*t)
	Y4 += 0.00000000004*np.cos(6.24919197648 + 632.7837393132*t)
	Y4 += 0.00000000005*np.cos(1.37080964211 + 625.6701923124*t)
	Y4 += 0.00000000004*np.cos(0.18776272435 + 330.6189636582*t)
	Y4 += 0.00000000006*np.cos(3.99789149114 + 156137.47598479928*t)
	Y4 += 0.00000000004*np.cos(1.88093591443 + 728.762966531*t)
	Y4 += 0.00000000004*np.cos(0.14204776620 + 309.2783226558*t)
	Y4 += 0.00000000003*np.cos(0.28739337099 + 191.9584544356*t)
	Y4 += 0.00000000004*np.cos(1.69042467345 + 735.8765135318*t)
	Y4 += 0.00000000003*np.cos(0.60316005015 + 447.9388318784*t)
	Y4 += 0.00000000003*np.cos(0.87226207854 + 302.164775655*t)
	Y4 += 0.00000000003*np.cos(2.70524481937 + 1581.959348283*t)
	Y4 += 0.00000000002*np.cos(4.14482411178 + 1169.5882514086*t)
	Y4 += 0.00000000003*np.cos(0.15041780827 + 323.5054166574*t)
	Y4 += 0.00000000002*np.cos(2.35344419082 + 1155.361157407*t)
	return Y4*t*t*t*t




def Earth_Y5 (t): # 29 terms of order 5

	Y5 = 0.
	Y5 += 0.00000000168*np.cos(1.70751121627 + 206.1855484372*t)
	Y5 += 0.00000000168*np.cos(6.23113008656 + 220.4126424388*t)
	Y5 += 0.00000000126*np.cos(4.78360062168 + 522.5774180938*t)
	Y5 += 0.00000000121*np.cos(2.73213408225 + 536.8045120954*t)
	Y5 += 0.00000000065*np.cos(6.17991345652 + 227.5261894396*t)
	Y5 += 0.00000000072
	Y5 += 0.00000000047*np.cos(4.76645839063 + 515.463871093*t)
	Y5 += 0.00000000043*np.cos(4.51710019379 + 12566.1516999828*t)
	Y5 += 0.00000000038*np.cos(5.19126826175 + 433.7117378768*t)
	Y5 += 0.00000000032*np.cos(2.69880941648 + 543.9180590962*t)
	Y5 += 0.00000000027*np.cos(1.88223142168 + 199.0720014364*t)
	Y5 += 0.00000000025*np.cos(3.76700032666 + 6438.4962494256*t)
	Y5 += 0.00000000025*np.cos(6.02312589958 + 6127.6554505572*t)
	Y5 += 0.00000000021*np.cos(2.56882591004 + 6283.0758499914*t)
	Y5 += 0.00000000011*np.cos(1.18187733048 + 14.2270940016*t)
	Y5 += 0.00000000011*np.cos(3.76420251280 + 1066.49547719*t)
	Y5 += 0.00000000010*np.cos(5.22684912304 + 440.8252848776*t)
	Y5 += 0.00000000008*np.cos(3.95508428463 + 18849.2275499742*t)
	Y5 += 0.00000000007*np.cos(4.23388483049 + 647.0108333148*t)
	Y5 += 0.00000000004*np.cos(4.91327178242 + 1052.2683831884*t)
	Y5 += 0.00000000004*np.cos(2.02140363828 + 419.4846438752*t)
	Y5 += 0.00000000003*np.cos(3.88823715659 + 639.897286314*t)
	Y5 += 0.00000000003*np.cos(6.08770400766 + 234.6397364404*t)
	Y5 += 0.00000000002*np.cos(5.07541839899 + 191.9584544356*t)
	Y5 += 0.00000000002*np.cos(4.00021439308 + 426.598190876*t)
	Y5 += 0.00000000002*np.cos(3.32317518434 + 1073.6090241908*t)
	Y5 += 0.00000000002*np.cos(4.64180795349 + 1045.1548361876*t)
	Y5 += 0.00000000001*np.cos(3.09946039705 + 88.865680217*t)
	Y5 += 0.00000000001*np.cos(0.32868254087 + 7.1135470008*t)
	return Y5*t*t*t*t*t




def Earth_Z0 (t): # 275 terms of order 0

	Z0 = 0.
	Z0 += 0.00011810174*np.cos(0.46078312048 + 213.299095438*t)
	Z0 += 0.00011270511*np.cos(0.41685732455 + 529.6909650946*t)
	Z0 += 0.00004802048*np.cos(4.58264723370 + 38.1330356378*t)
	Z0 += 0.00001131046*np.cos(5.75877139035 + 74.7815985673*t)
	Z0 -= 0.00001153742
	Z0 += 0.00000330209*np.cos(5.97860271259 + 426.598190876*t)
	Z0 += 0.00000272330*np.cos(0.75642153936 + 1059.3819301892*t)
	Z0 += 0.00000279620*np.cos(3.19870156017 + 84334.66158130829*t)
	Z0 += 0.00000101625*np.cos(5.42248110597 + 5507.5532386674*t)
	Z0 += 0.00000094247*np.cos(3.71017552866 + 206.1855484372*t)
	Z0 += 0.00000081859*np.cos(0.33908959552 + 220.4126424388*t)
	Z0 += 0.00000080461*np.cos(3.88027157914 + 5223.6939198022*t)
	Z0 += 0.00000043855*np.cos(3.70430347723 + 2352.8661537718*t)
	Z0 += 0.00000040793*np.cos(0.45519444489 + 522.5774180938*t)
	Z0 += 0.00000031695*np.cos(3.44538862917 + 536.8045120954*t)
	Z0 += 0.00000031853*np.cos(3.99997840986 + 1577.3435424478*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000026057*np.cos(1.93178628731 + 149.5631971346*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000024808*np.cos(3.40954687381 + 10213.285546211*t)
	Z0 += 0.00000019730*np.cos(3.16782731236 + 76.2660712756*t)
	Z0 += 0.00000021674*np.cos(1.53999461728 + 7.1135470008*t)
	Z0 += 0.00000022724*np.cos(3.98473831560 + 1047.7473117547*t)
	Z0 += 0.00000016395*np.cos(3.56456162523 + 5856.4776591154*t)
	Z0 += 0.00000018150*np.cos(4.98479613321 + 6283.0758499914*t)
	Z0 += 0.00000014512*np.cos(1.58375269275 + 110.2063212194*t)
	Z0 += 0.00000013709*np.cos(5.24058686986 + 639.897286314*t)
	Z0 += 0.00000014477*np.cos(3.70258423465 + 9437.762934887*t)
	Z0 += 0.00000010504*np.cos(2.26694979515 + 316.3918696566*t)
	Z0 += 0.00000010498*np.cos(2.71149033603 + 419.4846438752*t)
	Z0 += 0.00000009895*np.cos(1.07981196400 + 1589.0728952838*t)
	Z0 += 0.00000011204*np.cos(4.83021499098 + 14143.4952424306*t)
	Z0 += 0.00000010896*np.cos(2.08023708321 + 6812.766815086*t)
	Z0 += 0.00000009716*np.cos(3.47560205064 + 4694.0029547076*t)
	Z0 += 0.00000010363*np.cos(4.05663928093 + 71092.88135493269*t)
	Z0 += 0.00000008792*np.cos(4.44890729280 + 5753.3848848968*t)
	Z0 += 0.00000008040*np.cos(3.77010741170 + 73.297125859*t)
	Z0 += 0.00000008337*np.cos(4.99167706048 + 7084.8967811152*t)
	Z0 += 0.00000006921*np.cos(4.32559054073 + 6275.9623029906*t)
	Z0 += 0.00000009145*np.cos(1.14182646613 + 6620.8901131878*t)
	Z0 += 0.00000007698*np.cos(5.55425745881 + 167621.57585086189*t)
	Z0 += 0.00000005440*np.cos(2.41692841439 + 103.0927742186*t)
	Z0 += 0.00000004610*np.cos(5.85854264972 + 433.7117378768*t)
	Z0 += 0.00000005186*np.cos(6.25384533126 + 18073.7049386502*t)
	Z0 += 0.00000005027*np.cos(2.49727910749 + 4705.7323075436*t)
	Z0 += 0.00000004529*np.cos(2.33827747356 + 6309.3741697912*t)
	Z0 += 0.00000004754*np.cos(0.71100829534 + 5884.9268465832*t)
	Z0 += 0.00000004365*np.cos(1.09804624857 + 6681.2248533996*t)
	Z0 += 0.00000003855*np.cos(1.82331477760 + 5486.777843175*t)
	Z0 += 0.00000005256*np.cos(4.42445744523 + 7860.4193924392*t)
	Z0 += 0.00000004025*np.cos(5.11990285618 + 13367.9726311066*t)
	Z0 += 0.00000004061*np.cos(6.02923989849 + 3930.2096962196*t)
	Z0 += 0.00000003798*np.cos(0.44370219832 + 3154.6870848956*t)
	Z0 += 0.00000003948*np.cos(0.33532528162 + 1.4844727083*t)
	Z0 += 0.00000003424*np.cos(5.42065191700 + 6069.7767545534*t)
	Z0 += 0.00000003670*np.cos(4.58210192227 + 12194.0329146209*t)
	Z0 += 0.00000002912*np.cos(1.92688087702 + 10977.078804699*t)
	Z0 += 0.00000002506*np.cos(0.60484952637 + 6496.3749454294*t)
	Z0 += 0.00000002610*np.cos(5.41057398526 + 632.7837393132*t)
	Z0 += 0.00000002680*np.cos(1.39497359287 + 22003.9146348698*t)
	Z0 += 0.00000002454*np.cos(6.12024070891 + 1162.4747044078*t)
	Z0 += 0.00000002120*np.cos(4.30691000285 + 5643.1785636774*t)
	Z0 += 0.00000002235*np.cos(0.81363184041 + 8635.9420037632*t)
	Z0 += 0.00000002375*np.cos(6.05534556046 + 1052.2683831884*t)
	Z0 += 0.00000002230*np.cos(2.76407822446 + 12036.4607348882*t)
	Z0 += 0.00000001783*np.cos(3.14608208810 + 846.0828347512*t)
	Z0 += 0.00000001594*np.cos(3.78244334906 + 1066.49547719*t)
	Z0 += 0.00000001945*np.cos(5.69949789177 + 11790.6290886588*t)
	Z0 += 0.00000001566*np.cos(1.99768150464 + 202.2533951741*t)
	Z0 += 0.00000001529*np.cos(1.98639348122 + 398.1490034082*t)
	Z0 += 0.00000001581*np.cos(3.19976230948 + 5088.6288397668*t)
	Z0 += 0.00000001424*np.cos(6.26116472313 + 2544.3144198834*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001405*np.cos(4.69394873481 + 7058.5984613154*t)
	Z0 += 0.00000001588*np.cos(0.25704624784 + 17298.1823273262*t)
	Z0 += 0.00000001478*np.cos(2.81808207569 + 25934.1243310894*t)
	Z0 += 0.00000001332*np.cos(4.33184702387 + 949.1756089698*t)
	Z0 += 0.00000001693*np.cos(4.95689385293 + 156475.2902479957*t)
	Z0 += 0.00000001137*np.cos(6.15183461939 + 2.9689454166*t)
	Z0 += 0.00000001028*np.cos(0.21025596115 + 227.5261894396*t)
	Z0 += 0.00000001123*np.cos(2.38605285936 + 3738.761430108*t)
	Z0 += 0.00000000990*np.cos(4.29600699156 + 9225.539273283*t)
	Z0 += 0.00000000923*np.cos(3.07195736431 + 4164.311989613*t)
	Z0 += 0.00000000882*np.cos(0.48413591726 + 209.3669421749*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000000863*np.cos(0.55119493097 + 8429.2412664666*t)
	Z0 += 0.00000000984*np.cos(5.96784225392 + 7079.3738568078*t)
	Z0 += 0.00000000824*np.cos(1.50050055147 + 10447.3878396044*t)
	Z0 += 0.00000000829*np.cos(3.51336978167 + 11506.7697697936*t)
	Z0 += 0.00000000908*np.cos(0.12102885474 + 11015.1064773348*t)
	Z0 += 0.00000000864*np.cos(2.92013522974 + 148.0787244263*t)
	Z0 += 0.00000000850*np.cos(4.24120016095 + 29864.334027309*t)
	Z0 += 0.00000000846*np.cos(3.60649450344 + 217.2312487011*t)
	Z0 += 0.00000000762*np.cos(2.90028034892 + 4732.0306273434*t)
	Z0 += 0.00000000779*np.cos(3.77257775192 + 63.7358983034*t)
	Z0 += 0.00000000831*np.cos(6.20016431490 + 323.5054166574*t)
	Z0 += 0.00000000711*np.cos(1.38596151724 + 2146.1654164752*t)
	Z0 += 0.00000000693*np.cos(4.54324890551 + 853.196381752*t)
	Z0 += 0.00000000766*np.cos(0.61397570576 + 796.2980068164*t)
	Z0 += 0.00000000708*np.cos(1.91406542362 + 8031.0922630584*t)
	Z0 += 0.00000000810*np.cos(5.13961498599 + 2942.4634232916*t)
	Z0 += 0.00000000751*np.cos(1.67479850166 + 21228.3920235458*t)
	Z0 += 0.00000000687*np.cos(2.88181717922 + 71.8126531507*t)
	Z0 += 0.00000000589*np.cos(2.02193316047 + 775.522611324*t)
	Z0 += 0.00000000513*np.cos(2.60734651128 + 12566.1516999828*t)
	Z0 += 0.00000000559*np.cos(1.77674120898 + 742.9900605326*t)
	Z0 += 0.00000000550*np.cos(1.61119298963 + 801.8209311238*t)
	Z0 += 0.00000000459*np.cos(3.95268976842 + 77.7505439839*t)
	Z0 += 0.00000000592*np.cos(4.59481504319 + 4690.4798363586*t)
	Z0 += 0.00000000575*np.cos(3.85836565065 + 199.0720014364*t)
	Z0 += 0.00000000519*np.cos(5.72925039114 + 8827.3902698748*t)
	Z0 += 0.00000000515*np.cos(4.09976487552 + 64809.80550494129*t)
	Z0 += 0.00000000503*np.cos(5.66433137112 + 33794.5437235286*t)
	Z0 += 0.00000000427*np.cos(1.46616895111 + 2118.7638603784*t)
	Z0 += 0.00000000421*np.cos(5.42036909165 + 11.0457002639*t)
	Z0 += 0.00000000463*np.cos(1.24987240483 + 15720.8387848784*t)
	Z0 += 0.00000000421*np.cos(3.41138490065 + 224.3447957019*t)
	Z0 += 0.00000000411*np.cos(0.10769444525 + 3128.3887650958*t)
	Z0 += 0.00000000504*np.cos(3.26207669160 + 7632.9432596502*t)
	Z0 += 0.00000000552*np.cos(1.02926440457 + 239762.20451754928*t)
	Z0 += 0.00000000476*np.cos(3.52810472421 + 16496.3613962024*t)
	Z0 += 0.00000000503*np.cos(4.85802444134 + 6290.1893969922*t)
	Z0 += 0.00000000534*np.cos(0.54255389653 + 515.463871093*t)
	Z0 += 0.00000000385*np.cos(0.88914902748 + 151.0476698429*t)
	Z0 += 0.00000000417*np.cos(0.81920713533 + 5216.5803728014*t)
	Z0 += 0.00000000429*np.cos(1.40544578224 + 14.2270940016*t)
	Z0 += 0.00000000363*np.cos(1.28376436579 + 6206.8097787158*t)
	Z0 += 0.00000000353*np.cos(4.70059133110 + 7234.794256242*t)
	Z0 += 0.00000000381*np.cos(2.61890749829 + 7342.4577801806*t)
	Z0 += 0.00000000420*np.cos(0.97821135132 + 4136.9104335162*t)
	Z0 += 0.00000000335*np.cos(6.22057967320 + 12168.0026965746*t)
	Z0 += 0.00000000387*np.cos(3.09145061418 + 25158.6017197654*t)
	Z0 += 0.00000000319*np.cos(1.05944718196 + 117.3198682202*t)
	Z0 += 0.00000000349*np.cos(2.94840720073 + 9623.6882766912*t)
	Z0 += 0.00000000418*np.cos(3.75759994446 + 5230.807466803*t)
	Z0 += 0.00000000312*np.cos(6.24838646568 + 216.4804891757*t)
	Z0 += 0.00000000396*np.cos(1.22507712354 + 6438.4962494256*t)
	Z0 += 0.00000000322*np.cos(1.21162178805 + 8662.240323563*t)
	Z0 += 0.00000000290*np.cos(5.11770361174 + 647.0108333148*t)
	Z0 += 0.00000000323*np.cos(5.50254808471 + 1194.4470102246*t)
	Z0 += 0.00000000314*np.cos(4.10256974515 + 210.1177017003*t)
	Z0 += 0.00000000372*np.cos(1.72256107938 + 14945.3161735544*t)
	Z0 += 0.00000000296*np.cos(1.59458223926 + 309.2783226558*t)
	Z0 += 0.00000000305*np.cos(0.80429352049 + 37724.7534197482*t)
	Z0 += 0.00000000298*np.cos(5.25958947836 + 415.5524906121*t)
	Z0 += 0.00000000276*np.cos(3.54425558449 + 525.7588118315*t)
	Z0 += 0.00000000265*np.cos(6.10358507671 + 6836.6452528338*t)
	Z0 += 0.00000000250*np.cos(4.56452895547 + 7477.522860216*t)
	Z0 += 0.00000000317*np.cos(3.85456671343 + 85.8272988312*t)
	Z0 += 0.00000000266*np.cos(2.62926282354 + 7238.67559160*t)
	Z0 += 0.00000000238*np.cos(3.69496049159 + 3340.6124266998*t)
	Z0 += 0.00000000277*np.cos(0.31958662741 + 138.5174968707*t)
	Z0 += 0.00000000262*np.cos(1.34297269105 + 11769.8536931664*t)
	Z0 += 0.00000000263*np.cos(6.22089501237 + 6133.5126528568*t)
	Z0 += 0.00000000241*np.cos(3.32660302434 + 543.9180590962*t)
	Z0 += 0.00000000302*np.cos(2.81139045072 + 1748.016413067*t)
	Z0 += 0.00000000316*np.cos(1.62662805006 + 250908.49012041549*t)
	Z0 += 0.00000000226*np.cos(2.42346415873 + 11371.7046897582*t)
	Z0 += 0.00000000216*np.cos(3.68721275185 + 5849.3641121146*t)
	Z0 += 0.00000000276*np.cos(2.33399767923 + 19651.048481098*t)
	Z0 += 0.00000000230*np.cos(0.36165162947 + 5863.5912061162*t)
	Z0 += 0.00000000200*np.cos(5.86073159059 + 4535.0594369244*t)
	Z0 += 0.00000000277*np.cos(4.65400292395 + 82239.16695779889*t)
	Z0 += 0.00000000199*np.cos(5.05186622555 + 5429.8794682394*t)
	Z0 += 0.00000000198*np.cos(2.49240240273 + 95.9792272178*t)
	Z0 += 0.00000000206*np.cos(3.70556027982 + 10973.55568635*t)
	Z0 += 0.00000000210*np.cos(4.50691909144 + 29088.811415985*t)
	Z0 += 0.00000000186*np.cos(4.39437140248 + 277.0349937414*t)
	Z0 += 0.00000000181*np.cos(6.00294783127 + 4292.3308329504*t)
	Z0 += 0.00000000188*np.cos(0.20392851067 + 1692.1656695024*t)
	Z0 += 0.00000000249*np.cos(0.12900984422 + 154379.79562448629*t)
	Z0 += 0.00000000175*np.cos(5.39840733123 + 1478.8665740644*t)
	Z0 += 0.00000000242*np.cos(0.43270824867 + 533.6231183577*t)
	Z0 += 0.00000000167*np.cos(6.27348370813 + 10988.808157535*t)
	Z0 += 0.00000000183*np.cos(3.19836584401 + 16730.4636895958*t)
	Z0 += 0.00000000225*np.cos(3.18339652605 + 18875.525869774*t)
	Z0 += 0.00000000192*np.cos(0.87192032514 + 77375.95720492408*t)
	Z0 += 0.00000000188*np.cos(2.22746128596 + 41654.9631159678*t)
	Z0 += 0.00000000179*np.cos(5.79528713551 + 956.2891559706*t)
	Z0 += 0.00000000160*np.cos(5.20207795189 + 5481.2549188676*t)
	Z0 += 0.00000000192*np.cos(3.89678943865 + 17789.845619785*t)
	Z0 += 0.00000000214*np.cos(4.08171403539 + 337.8142631964*t)
	Z0 += 0.00000000161*np.cos(3.79231132145 + 490.3340891794*t)
	Z0 += 0.00000000146*np.cos(0.92939894424 + 114.3991069134*t)
	Z0 += 0.00000000169*np.cos(5.02858629838 + 20426.571092422*t)
	Z0 += 0.00000000170*np.cos(6.26857937202 + 1581.959348283*t)
	Z0 += 0.00000000157*np.cos(0.79065950021 + 1265.5674786264*t)
	Z0 += 0.00000000184*np.cos(3.75465072369 + 23581.2581773176*t)
	Z0 += 0.00000000160*np.cos(4.53897529970 + 18477.1087646123*t)
	Z0 += 0.00000000126*np.cos(1.69446958184 + 15110.4661198662*t)
	Z0 += 0.00000000149*np.cos(1.55306832217 + 10021.8372800994*t)
	Z0 += 0.00000000154*np.cos(0.00941929392 + 735.8765135318*t)
	Z0 += 0.00000000129*np.cos(5.30043284887 + 351.8165923087*t)
	Z0 += 0.00000000117*np.cos(4.81725910872 + 625.6701923124*t)
	Z0 += 0.00000000118*np.cos(2.73268114062 + 18849.2275499742*t)
	Z0 += 0.00000000123*np.cos(2.55361087146 + 12592.4500197826*t)
	Z0 += 0.00000000113*np.cos(3.04973288935 + 532.8723588323*t)
	Z0 += 0.00000000116*np.cos(0.92093201468 + 526.5095713569*t)
	Z0 += 0.00000000113*np.cos(6.07178776726 + 6709.6740408674*t)
	Z0 += 0.00000000129*np.cos(1.11079063120 + 33.6796175129*t)
	Z0 += 0.00000000130*np.cos(3.94161517411 + 7330.8231617461*t)
	Z0 += 0.00000000110*np.cos(3.51203379263 + 18052.9295431578*t)
	Z0 += 0.00000000147*np.cos(4.63371971408 + 22805.7355659936*t)
	Z0 += 0.00000000113*np.cos(1.20711498905 + 14919.0178537546*t)
	Z0 += 0.00000000108*np.cos(3.76359880753 + 14314.1681130498*t)
	Z0 += 0.00000000148*np.cos(0.65447253687 + 95480.9471841745*t)
	Z0 += 0.00000000121*np.cos(3.13748782783 + 14712.317116458*t)
	Z0 += 0.00000000107*np.cos(3.52070197299 + 1375.7737998458*t)
	Z0 += 0.00000000119*np.cos(5.92110458985 + 33019.0211122046*t)
	Z0 += 0.00000000124*np.cos(2.93638421840 + 32217.2001810808*t)
	Z0 += 0.00000000117*np.cos(3.65065271640 + 45585.1728121874*t)
	Z0 += 0.00000000127*np.cos(4.74596574209 + 49515.382508407*t)
	Z0 += 0.00000000120*np.cos(1.04211499785 + 6915.8595893046*t)
	Z0 += 0.00000000120*np.cos(5.60638811846 + 5650.2921106782*t)
	Z0 += 0.00000000127*np.cos(2.70766997307 + 12352.8526045448*t)
	Z0 += 0.00000000113*np.cos(5.39691616452 + 5235.3285382367*t)
	Z0 += 0.00000000097*np.cos(1.07908724794 + 9917.6968745098*t)
	Z0 += 0.00000000123*np.cos(5.15992792934 + 27511.4678735372*t)
	Z0 += 0.00000000099*np.cos(4.45774681732 + 4933.2084403326*t)
	Z0 += 0.00000000095*np.cos(4.92440852569 + 4.4534181249*t)
	Z0 += 0.00000000106*np.cos(2.29924580245 + 111.4301614968*t)
	Z0 += 0.00000000087*np.cos(3.93637812950 + 17654.7805397496*t)
	Z0 += 0.00000000122*np.cos(2.23956068680 + 83997.09113559539*t)
	Z0 += 0.00000000103*np.cos(3.99294762314 + 70.3281804424*t)
	Z0 += 0.00000000085*np.cos(4.12867184796 + 1596.1864422846*t)
	Z0 += 0.00000000102*np.cos(3.97386522171 + 10818.1352869158*t)
	Z0 += 0.00000000084*np.cos(4.21241958885 + 22779.4372461938*t)
	Z0 += 0.00000000103*np.cos(4.63519841733 + 1349.8674096588*t)
	Z0 += 0.00000000085*np.cos(6.03717451925 + 127.4717966068*t)
	Z0 += 0.00000000081*np.cos(4.01655240430 + 1592.5960136328*t)
	Z0 += 0.00000000092*np.cos(3.24182657569 + 78051.5857313169*t)
	Z0 += 0.00000000078*np.cos(1.90056477405 + 52175.8062831484*t)
	Z0 += 0.00000000081*np.cos(5.75718254218 + 78.7137518304*t)
	Z0 += 0.00000000094*np.cos(4.33873972800 + 36147.4098773004*t)
	Z0 += 0.00000000076*np.cos(2.83897554420 + 17260.1546546904*t)
	Z0 += 0.00000000100*np.cos(6.07733097102 + 26735.9452622132*t)
	Z0 += 0.00000000078*np.cos(0.72462427283 + 12779.4507954208*t)
	Z0 += 0.00000000086*np.cos(5.26029638250 + 28313.288804661*t)
	Z0 += 0.00000000093*np.cos(4.31900620254 + 44809.6502008634*t)
	Z0 += 0.00000000076*np.cos(4.37868021510 + 146.594251718*t)
	Z0 += 0.00000000076*np.cos(6.22743405935 + 13521.7514415914*t)
	Z0 += 0.00000000081*np.cos(2.16420552322 + 13095.8426650774*t)
	Z0 += 0.00000000100*np.cos(1.38002787119 + 28286.9904848612*t)
	Z0 += 0.00000000073*np.cos(5.74180456867 + 440.8252848776*t)
	Z0 += 0.00000000072*np.cos(1.55820597747 + 6256.7775301916*t)
	Z0 += 0.00000000082*np.cos(4.95202664555 + 10575.4066829418*t)
	Z0 += 0.00000000082*np.cos(1.69647647075 + 1990.745017041*t)
	Z0 += 0.00000000096*np.cos(6.16038106485 + 24356.7807886416*t)
	Z0 += 0.00000000094*np.cos(2.55599744292 + 70.8494453042*t)
	Z0 += 0.00000000075*np.cos(2.29836095644 + 3634.6210245184*t)
	Z0 += 0.00000000075*np.cos(2.66367876557 + 16200.7727245012*t)
	Z0 += 0.00000000087*np.cos(0.26630214764 + 31441.6775697568*t)
	Z0 += 0.00000000080*np.cos(5.00001604436 + 150192.21439800429*t)
	Z0 += 0.00000000079*np.cos(0.01398391548 + 90617.7374312997*t)
	Z0 += 0.00000000074*np.cos(6.17414394369 + 137.0330241624*t)
	Z0 += 0.00000000065*np.cos(4.13140277621 + 210.8514148832*t)
	Z0 += 0.00000000064*np.cos(6.21657611750 + 215.7467759928*t)
	Z0 += 0.00000000066*np.cos(4.90503958113 + 222.8603229936*t)
	Z0 += 0.00000000050*np.cos(0.81093625490 + 3.9321532631*t)
	Z0 += 0.00000000055*np.cos(2.96642314550 + 1169.5882514086*t)
	Z0 += 0.00000000046*np.cos(0.75603425226 + 214.2623032845*t)
	Z0 += 0.00000000054*np.cos(5.59738773448 + 161338.5000008705*t)
	Z0 += 0.00000000047*np.cos(5.59856718264 + 422.6660376129*t)
	Z0 += 0.00000000043*np.cos(0.99886063885 + 437.6438911399*t)
	Z0 += 0.00000000042*np.cos(4.06841238442 + 42.5864537627*t)
	Z0 += 0.00000000047*np.cos(3.95753360395 + 109.9456887885*t)
	Z0 += 0.00000000055*np.cos(5.81384971899 + 1045.1548361876*t)
	Z0 += 0.00000000056*np.cos(2.60133794851 + 73188.3759784421*t)
	Z0 += 0.00000000055*np.cos(5.81483150022 + 143233.51002162008*t)
	Z0 += 0.00000000054*np.cos(3.38482031504 + 323049.11878710288*t)
	Z0 += 0.00000000039*np.cos(4.38780950886 + 942.062061969*t)
	Z0 += 0.00000000047*np.cos(3.30738241951 + 212.3358875915*t)
	Z0 += 0.00000000039*np.cos(3.63042667673 + 213.3472795478*t)
	Z0 += 0.00000000038*np.cos(0.54320017724 + 299.1263942692*t)
	Z0 += 0.00000000039*np.cos(5.79384191199 + 380.12776796*t)
	return Z0




def Earth_Z1 (t): # 186 terms of order 1

	Z1 = 0.
	Z1 += 0.00227821750*np.cos(3.41372504278 + 6283.0758499914*t)
	Z1 += 0.00005562680
	Z1 += 0.00001903177*np.cos(3.37061270964 + 12566.1516999828*t)
	Z1 += 0.00000544630*np.cos(1.80421440984 + 213.299095438*t)
	Z1 += 0.00000384140*np.cos(4.65958886012 + 529.6909650946*t)
	Z1 += 0.00000037294*np.cos(5.40133589632 + 206.1855484372*t)
	Z1 += 0.00000028944*np.cos(4.93245710560 + 220.4126424388*t)
	Z1 += 0.00000028635*np.cos(3.15447649004 + 74.7815985673*t)
	Z1 += 0.00000025027*np.cos(3.65872330367 + 426.598190876*t)
	Z1 += 0.00000023859*np.cos(3.32836261978 + 18849.2275499742*t)
	Z1 += 0.00000018840*np.cos(5.67845947411 + 1059.3819301892*t)
	Z1 += 0.00000013746*np.cos(1.71298046603 + 536.8045120954*t)
	Z1 += 0.00000012168*np.cos(2.31196328906 + 522.5774180938*t)
	Z1 += 0.00000008671*np.cos(1.82289925035 + 5223.6939198022*t)
	Z1 += 0.00000007767*np.cos(3.88787435832 + 5507.5532386674*t)
	Z1 += 0.00000008010*np.cos(5.28413417446 + 38.1330356378*t)
	Z1 += 0.00000007063*np.cos(5.19303169379 + 2352.8661537718*t)
	Z1 += 0.00000007090*np.cos(2.32907317990 + 83996.84731811189*t)
	Z1 += 0.00000004978*np.cos(4.29826949554 + 419.4846438752*t)
	Z1 += 0.00000003894*np.cos(2.15568517178 + 6279.5527316424*t)
	Z1 += 0.00000004283*np.cos(6.12577128204 + 7.1135470008*t)
	Z1 += 0.00000003892*np.cos(1.53021064904 + 6286.5989683404*t)
	Z1 += 0.00000003789*np.cos(4.90064455071 + 10213.285546211*t)
	Z1 += 0.00000002586*np.cos(3.01944725018 + 639.897286314*t)
	Z1 += 0.00000002131*np.cos(4.06053382034 + 433.7117378768*t)
	Z1 += 0.00000002165*np.cos(6.23220223547 + 7860.4193924392*t)
	Z1 += 0.00000002084*np.cos(5.84682067018 + 1577.3435424478*t)
	Z1 += 0.00000001959*np.cos(1.42270916062 + 12036.4607348882*t)
	Z1 += 0.00000001560*np.cos(3.28261094599 + 316.3918696566*t)
	Z1 += 0.00000001396*np.cos(0.50057569258 + 6309.3741697912*t)
	Z1 += 0.00000001584*np.cos(1.81185253086 + 5856.4776591154*t)
	Z1 += 0.00000001493*np.cos(1.75695182457 + 5884.9268465832*t)
	Z1 += 0.00000001713*np.cos(6.04661123493 + 398.1490034082*t)
	Z1 += 0.00000001573*np.cos(2.20074999518 + 9437.762934887*t)
	Z1 += 0.00000001503*np.cos(3.94648902715 + 4705.7323075436*t)
	Z1 += 0.00000001041*np.cos(2.94815263534 + 6256.7775301916*t)
	Z1 += 0.00000001111*np.cos(6.13174127393 + 1589.0728952838*t)
	Z1 += 0.00000000983*np.cos(2.24865863102 + 6681.2248533996*t)
	Z1 += 0.00000001029*np.cos(5.86675536556 + 149.5631971346*t)
	Z1 += 0.00000001150*np.cos(2.43940396435 + 775.522611324*t)
	Z1 += 0.00000001171*np.cos(0.74619691355 + 6812.766815086*t)
	Z1 += 0.00000000881*np.cos(1.86103443124 + 3930.2096962196*t)
	Z1 += 0.00000000775*np.cos(4.79688880139 + 227.5261894396*t)
	Z1 += 0.00000000739*np.cos(2.12600457660 + 1066.49547719*t)
	Z1 += 0.00000000696*np.cos(1.45896954690 + 11790.6290886588*t)
	Z1 += 0.00000000645*np.cos(1.62570263847 + 1052.2683831884*t)
	Z1 += 0.00000000732*np.cos(1.60348898963 + 4694.0029547076*t)
	Z1 += 0.00000000542*np.cos(1.44488755125 + 110.2063212194*t)
	Z1 += 0.00000000533*np.cos(2.34579176940 + 76.2660712756*t)
	Z1 += 0.00000000487*np.cos(0.04282116718 + 11506.7697697936*t)
	Z1 += 0.00000000632*np.cos(4.34207925908 + 5753.3848848968*t)
	Z1 += 0.00000000584*np.cos(3.11517364836 + 709.9330485583*t)
	Z1 += 0.00000000583*np.cos(3.92560802577 + 12168.0026965746*t)
	Z1 += 0.00000000409*np.cos(4.63047700185 + 796.2980068164*t)
	Z1 += 0.00000000403*np.cos(1.25691345472 + 36.6485629295*t)
	Z1 += 0.00000000483*np.cos(5.74980419879 + 17789.845619785*t)
	Z1 += 0.00000000405*np.cos(1.97558286872 + 6283.0085396886*t)
	Z1 += 0.00000000405*np.cos(1.53147989887 + 6283.14316029419*t)
	Z1 += 0.00000000352*np.cos(4.79823464785 + 39.6175083461*t)
	Z1 += 0.00000000354*np.cos(3.28490469609 + 25132.3033999656*t)
	Z1 += 0.00000000417*np.cos(3.63631064623 + 13367.9726311066*t)
	Z1 += 0.00000000446*np.cos(5.55248874462 + 199.0720014364*t)
	Z1 += 0.00000000367*np.cos(1.55081387384 + 18073.7049386502*t)
	Z1 += 0.00000000368*np.cos(5.32358181908 + 103.0927742186*t)
	Z1 += 0.00000000302*np.cos(5.15335876647 + 632.7837393132*t)
	Z1 += 0.00000000343*np.cos(2.32388226037 + 515.463871093*t)
	Z1 += 0.00000000284*np.cos(0.15061211477 + 3738.761430108*t)
	Z1 += 0.00000000295*np.cos(2.75399172194 + 14143.4952424306*t)
	Z1 += 0.00000000288*np.cos(2.98400521096 + 6275.9623029906*t)
	Z1 += 0.00000000250*np.cos(0.42640065085 + 7079.3738568078*t)
	Z1 += 0.00000000251*np.cos(2.81315684448 + 6290.1893969922*t)
	Z1 += 0.00000000338*np.cos(2.55274440586 + 7058.5984613154*t)
	Z1 += 0.00000000258*np.cos(5.99544147559 + 14.2270940016*t)
	Z1 += 0.00000000230*np.cos(2.54182122331 + 7084.8967811152*t)
	Z1 += 0.00000000266*np.cos(0.49468027720 + 73.297125859*t)
	Z1 += 0.00000000251*np.cos(5.58497774438 + 217.2312487011*t)
	Z1 += 0.00000000212*np.cos(4.71778046808 + 6496.3749454294*t)
	Z1 += 0.00000000210*np.cos(5.87638250776 + 210.1177017003*t)
	Z1 += 0.00000000200*np.cos(1.60953815793 + 543.9180590962*t)
	Z1 += 0.00000000205*np.cos(2.38357660053 + 853.196381752*t)
	Z1 += 0.00000000188*np.cos(3.17403855561 + 5486.777843175*t)
	Z1 += 0.00000000216*np.cos(2.95054003179 + 22003.9146348698*t)
	Z1 += 0.00000000186*np.cos(4.63128120913 + 209.3669421749*t)
	Z1 += 0.00000000166*np.cos(3.25384215179 + 647.0108333148*t)
	Z1 += 0.00000000188*np.cos(4.45601446980 + 216.4804891757*t)
	Z1 += 0.00000000165*np.cos(1.19407165511 + 5643.1785636774*t)
	Z1 += 0.00000000196*np.cos(4.68462471621 + 167283.76158766549*t)
	Z1 += 0.00000000162*np.cos(2.94100342992 + 15720.8387848784*t)
	Z1 += 0.00000000189*np.cos(5.09534739493 + 17298.1823273262*t)
	Z1 += 0.00000000147*np.cos(4.91154015633 + 202.2533951741*t)
	Z1 += 0.00000000149*np.cos(5.23057852418 + 11769.8536931664*t)
	Z1 += 0.00000000150*np.cos(1.65291444016 + 3128.3887650958*t)
	Z1 += 0.00000000148*np.cos(6.00943832296 + 949.1756089698*t)
	Z1 += 0.00000000143*np.cos(3.70203142149 + 323.5054166574*t)
	Z1 += 0.00000000143*np.cos(5.48362795500 + 10977.078804699*t)
	Z1 += 0.00000000144*np.cos(3.81203756929 + 6262.300454499*t)
	Z1 += 0.00000000143*np.cos(5.97809021355 + 6303.8512454838*t)
	Z1 += 0.00000000140*np.cos(0.83132381305 + 735.8765135318*t)
	Z1 += 0.00000000136*np.cos(4.97038154072 + 4136.9104335162*t)
	Z1 += 0.00000000163*np.cos(2.00627600582 + 5230.807466803*t)
	Z1 += 0.00000000130*np.cos(4.41428061934 + 6127.6554505572*t)
	Z1 += 0.00000000122*np.cos(3.13394683057 + 1194.4470102246*t)
	Z1 += 0.00000000131*np.cos(4.24961399629 + 6282.0955289232*t)
	Z1 += 0.00000000131*np.cos(5.54051222995 + 6284.0561710596*t)
	Z1 += 0.00000000122*np.cos(5.67146512225 + 117.3198682202*t)
	Z1 += 0.00000000128*np.cos(1.81481667421 + 3340.6124266998*t)
	Z1 += 0.00000000161*np.cos(3.32421999691 + 6283.3196674749*t)
	Z1 += 0.00000000128*np.cos(4.35489873365 + 25934.1243310894*t)
	Z1 += 0.00000000113*np.cos(4.42578862670 + 19651.048481098*t)
	Z1 += 0.00000000107*np.cos(2.97447343520 + 8827.3902698748*t)
	Z1 += 0.00000000107*np.cos(0.41198538606 + 5481.2549188676*t)
	Z1 += 0.00000000131*np.cos(2.29167404623 + 3154.6870848956*t)
	Z1 += 0.00000000139*np.cos(0.84923405785 + 6069.7767545534*t)
	Z1 += 0.00000000100*np.cos(2.78745027781 + 1.4844727083*t)
	Z1 += 0.00000000109*np.cos(3.21932289821 + 801.8209311238*t)
	Z1 += 0.00000000115*np.cos(3.71248897285 + 11856.2186514245*t)
	Z1 += 0.00000000086*np.cos(2.78714560645 + 5216.5803728014*t)
	Z1 += 0.00000000116*np.cos(1.07208569199 + 12352.8526045448*t)
	Z1 += 0.00000000085*np.cos(4.74199868968 + 8429.2412664666*t)
	Z1 += 0.00000000112*np.cos(5.29899379351 + 2544.3144198834*t)
	Z1 += 0.00000000084*np.cos(4.30248448955 + 1162.4747044078*t)
	Z1 += 0.00000000096*np.cos(5.20691825399 + 17260.1546546904*t)
	Z1 += 0.00000000077*np.cos(4.22942639128 + 95.9792272178*t)
	Z1 += 0.00000000079*np.cos(0.36636125409 + 11.0457002639*t)
	Z1 += 0.00000000075*np.cos(1.47982807612 + 525.7588118315*t)
	Z1 += 0.00000000074*np.cos(4.51170584596 + 8635.9420037632*t)
	Z1 += 0.00000000097*np.cos(5.50959692365 + 29864.334027309*t)
	Z1 += 0.00000000094*np.cos(0.25007575444 + 21228.3920235458*t)
	Z1 += 0.00000000076*np.cos(1.24245643745 + 532.8723588323*t)
	Z1 += 0.00000000096*np.cos(0.86129378681 + 63.7358983034*t)
	Z1 += 0.00000000071*np.cos(2.75365102566 + 526.5095713569*t)
	Z1 += 0.00000000082*np.cos(3.01994555641 + 20426.571092422*t)
	Z1 += 0.00000000071*np.cos(0.47420303374 + 2146.1654164752*t)
	Z1 += 0.00000000074*np.cos(1.27647360807 + 4164.311989613*t)
	Z1 += 0.00000000071*np.cos(0.43437193243 + 2118.7638603784*t)
	Z1 += 0.00000000075*np.cos(0.73893922793 + 9225.539273283*t)
	Z1 += 0.00000000065*np.cos(1.39694123605 + 12569.6748183318*t)
	Z1 += 0.00000000063*np.cos(3.98868546710 + 440.8252848776*t)
	Z1 += 0.00000000061*np.cos(2.62473045895 + 533.6231183577*t)
	Z1 += 0.00000000074*np.cos(2.20184828895 + 37724.7534197482*t)
	Z1 += 0.00000000054*np.cos(1.42941204449 + 85.8272988312*t)
	Z1 += 0.00000000057*np.cos(3.98493436395 + 309.2783226558*t)
	Z1 += 0.00000000058*np.cos(5.36736393336 + 11015.1064773348*t)
	Z1 += 0.00000000069*np.cos(3.56483879750 + 4535.0594369244*t)
	Z1 += 0.00000000064*np.cos(2.05206957553 + 12562.6285816338*t)
	Z1 += 0.00000000051*np.cos(0.39392917326 + 742.9900605326*t)
	Z1 += 0.00000000049*np.cos(4.84482792493 + 956.2891559706*t)
	Z1 += 0.00000000056*np.cos(4.14424591372 + 5088.6288397668*t)
	Z1 += 0.00000000061*np.cos(0.63918772258 + 33794.5437235286*t)
	Z1 += 0.00000000049*np.cos(6.20603791837 + 12559.038152982*t)
	Z1 += 0.00000000059*np.cos(4.92457810620 + 71430.69561812909*t)
	Z1 += 0.00000000058*np.cos(1.68201284430 + 25158.6017197654*t)
	Z1 += 0.00000000051*np.cos(5.03600618727 + 5863.5912061162*t)
	Z1 += 0.00000000047*np.cos(0.30276119177 + 11371.7046897582*t)
	Z1 += 0.00000000050*np.cos(0.77635440262 + 26.2983197998*t)
	Z1 += 0.00000000043*np.cos(2.55616001516 + 1596.1864422846*t)
	Z1 += 0.00000000041*np.cos(1.87344929139 + 1748.016413067*t)
	Z1 += 0.00000000041*np.cos(5.91861144924 + 23581.2581773176*t)
	Z1 += 0.00000000055*np.cos(1.37242658028 + 7342.4577801806*t)
	Z1 += 0.00000000053*np.cos(1.47750772846 + 18319.5365848796*t)
	Z1 += 0.00000000042*np.cos(0.11693102263 + 23543.23050468179*t)
	Z1 += 0.00000000045*np.cos(5.18332998014 + 16496.3613962024*t)
	Z1 += 0.00000000045*np.cos(1.69577010458 + 6702.5604938666*t)
	Z1 += 0.00000000050*np.cos(3.62740835096 + 41654.9631159678*t)
	Z1 += 0.00000000050*np.cos(0.12043698146 + 29088.811415985*t)
	Z1 += 0.00000000039*np.cos(2.15562950918 + 4933.2084403326*t)
	Z1 += 0.00000000048*np.cos(5.37118742490 + 7477.522860216*t)
	Z1 += 0.00000000040*np.cos(3.02033323932 + 10447.3878396044*t)
	Z1 += 0.00000000045*np.cos(6.10982446357 + 8031.0922630584*t)
	Z1 += 0.00000000036*np.cos(0.55224025396 + 625.6701923124*t)
	Z1 += 0.00000000043*np.cos(4.08726331262 + 156137.47598479928*t)
	Z1 += 0.00000000032*np.cos(6.09025731476 + 64809.80550494129*t)
	Z1 += 0.00000000039*np.cos(2.77790342477 + 35.1640902212*t)
	Z1 += 0.00000000030*np.cos(4.35442775962 + 412.3710968744*t)
	Z1 += 0.00000000038*np.cos(5.38040433295 + 224.3447957019*t)
	Z1 += 0.00000000035*np.cos(1.26816443678 + 1045.1548361876*t)
	Z1 += 0.00000000031*np.cos(0.64597904023 + 70.8494453042*t)
	Z1 += 0.00000000036*np.cos(1.74852565178 + 1581.959348283*t)
	Z1 += 0.00000000026*np.cos(3.58372397053 + 41.1019810544*t)
	Z1 += 0.00000000030*np.cos(3.31574729193 + 138.5174968707*t)
	Z1 += 0.00000000024*np.cos(1.14783906654 + 71.8126531507*t)
	Z1 += 0.00000000022*np.cos(1.56359401952 + 78.7137518304*t)
	Z1 += 0.00000000022*np.cos(1.22800274368 + 1169.5882514086*t)
	Z1 += 0.00000000024*np.cos(0.09566124749 + 277.0349937414*t)
	Z1 += 0.00000000019*np.cos(1.46315634551 + 215.7467759928*t)
	Z1 += 0.00000000018*np.cos(6.15872883408 + 942.062061969*t)
	return Z1*t




def Earth_Z2 (t): # 96 terms of order 2

	Z2 = 0.
	Z2 += 0.00009721959*np.cos(5.15233725915 + 6283.0758499914*t)
	Z2 -= 0.00000351179
	Z2 += 0.00000067136*np.cos(0.64403888586 + 12566.1516999828*t)
	Z2 += 0.00000037478*np.cos(3.23028568613 + 213.299095438*t)
	Z2 += 0.00000027175*np.cos(6.14777250369 + 529.6909650946*t)
	Z2 += 0.00000008616*np.cos(0.77209239310 + 206.1855484372*t)
	Z2 += 0.00000005511*np.cos(3.23377546695 + 220.4126424388*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	Z2 += 0.00000002169*np.cos(1.07314429736 + 18849.2275499742*t)
	Z2 += 0.00000002272*np.cos(4.09618627765 + 522.5774180938*t)
	Z2 += 0.00000001982*np.cos(2.34242027589 + 426.598190876*t)
	Z2 += 0.00000001212*np.cos(5.20410318593 + 1059.3819301892*t)
	Z2 += 0.00000001662*np.cos(1.62746869551 + 84334.66158130829*t)
	Z2 += 0.00000000743*np.cos(6.08844686068 + 419.4846438752*t)
	Z2 += 0.00000000641*np.cos(4.89317483950 + 74.7815985673*t)
	Z2 += 0.00000000635*np.cos(3.51985338656 + 6279.5527316424*t)
	Z2 += 0.00000000527*np.cos(2.28325191846 + 433.7117378768*t)
	Z2 += 0.00000000497*np.cos(4.39514302236 + 7.1135470008*t)
	Z2 += 0.00000000492*np.cos(2.41382223971 + 1047.7473117547*t)
	Z2 += 0.00000000347*np.cos(6.16127984865 + 5223.6939198022*t)
	Z2 += 0.00000000300*np.cos(3.09602587558 + 227.5261894396*t)
	Z2 += 0.00000000322*np.cos(0.37660897389 + 6286.5989683404*t)
	Z2 += 0.00000000302*np.cos(4.06770618987 + 83996.84731811189*t)
	Z2 += 0.00000000314*np.cos(2.37089871705 + 5507.5532386674*t)
	Z2 += 0.00000000294*np.cos(1.18226869992 + 639.897286314*t)
	Z2 += 0.00000000242*np.cos(1.64810071161 + 7860.4193924392*t)
	Z2 += 0.00000000229*np.cos(0.50869157074 + 2352.8661537718*t)
	Z2 += 0.00000000173*np.cos(0.49687224658 + 1066.49547719*t)
	Z2 += 0.00000000197*np.cos(0.14307235609 + 10213.285546211*t)
	Z2 += 0.00000000184*np.cos(0.95286916137 + 199.0720014364*t)
	Z2 += 0.00000000149*np.cos(4.90906266305 + 316.3918696566*t)
	Z2 += 0.00000000170*np.cos(5.28668290523 + 6256.7775301916*t)
	Z2 += 0.00000000125*np.cos(3.13799899281 + 5884.9268465832*t)
	Z2 += 0.00000000119*np.cos(4.09508225076 + 515.463871093*t)
	Z2 += 0.00000000118*np.cos(3.85466055344 + 1577.3435424478*t)
	Z2 += 0.00000000106*np.cos(3.65846401642 + 1052.2683831884*t)
	Z2 += 0.00000000123*np.cos(4.17102530625 + 6309.3741697912*t)
	Z2 += 0.00000000089*np.cos(1.65074757807 + 4705.7323075436*t)
	Z2 += 0.00000000096*np.cos(5.26405470160 + 1589.0728952838*t)
	Z2 += 0.00000000085*np.cos(6.16812793384 + 543.9180590962*t)
	Z2 += 0.00000000079*np.cos(4.29766380692 + 14.2270940016*t)
	Z2 += 0.00000000090*np.cos(4.13333302298 + 5753.3848848968*t)
	Z2 += 0.00000000068*np.cos(1.33776656115 + 210.1177017003*t)
	Z2 += 0.00000000067*np.cos(0.30879908581 + 775.522611324*t)
	Z2 += 0.00000000088*np.cos(2.93230657226 + 12036.4607348882*t)
	Z2 += 0.00000000065*np.cos(6.02619905507 + 6812.766815086*t)
	Z2 += 0.00000000067*np.cos(1.15131045651 + 25132.3033999656*t)
	Z2 += 0.00000000065*np.cos(2.72055837855 + 6127.6554505572*t)
	Z2 += 0.00000000062*np.cos(0.78482367183 + 6438.4962494256*t)
	Z2 += 0.00000000057*np.cos(1.49017558261 + 11506.7697697936*t)
	Z2 += 0.00000000065*np.cos(5.05560764351 + 38.1330356378*t)
	Z2 += 0.00000000056*np.cos(4.55921214755 + 5486.777843175*t)
	Z2 += 0.00000000058*np.cos(1.55728577024 + 103.0927742186*t)
	Z2 += 0.00000000075*np.cos(0.84213523741 + 167621.57585086189*t)
	Z2 += 0.00000000069*np.cos(1.21340931171 + 398.1490034082*t)
	Z2 += 0.00000000050*np.cos(1.42158496561 + 647.0108333148*t)
	Z2 += 0.00000000047*np.cos(5.28931662006 + 7079.3738568078*t)
	Z2 += 0.00000000044*np.cos(3.09697268535 + 11790.6290886588*t)
	Z2 += 0.00000000057*np.cos(6.15295833679 + 12194.0329146209*t)
	Z2 += 0.00000000042*np.cos(1.14028846687 + 217.2312487011*t)
	Z2 += 0.00000000053*np.cos(2.67570413760 + 216.4804891757*t)
	Z2 += 0.00000000040*np.cos(2.70069983169 + 10988.808157535*t)
	Z2 += 0.00000000036*np.cos(0.32483893578 + 6681.2248533996*t)
	Z2 += 0.00000000046*np.cos(3.38617099014 + 156475.2902479957*t)
	Z2 += 0.00000000033*np.cos(1.26266496002 + 6290.1893969922*t)
	Z2 += 0.00000000033*np.cos(2.25067065498 + 6275.9623029906*t)
	Z2 += 0.00000000031*np.cos(4.21025720942 + 110.2063212194*t)
	Z2 += 0.00000000032*np.cos(2.90595681986 + 796.2980068164*t)
	Z2 += 0.00000000029*np.cos(6.18539185721 + 632.7837393132*t)
	Z2 += 0.00000000028*np.cos(2.23145809257 + 440.8252848776*t)
	Z2 += 0.00000000033*np.cos(0.42157783312 + 853.196381752*t)
	Z2 += 0.00000000023*np.cos(4.86623778952 + 3738.761430108*t)
	Z2 += 0.00000000025*np.cos(3.95236444346 + 117.3198682202*t)
	Z2 += 0.00000000025*np.cos(4.85403147726 + 709.9330485583*t)
	Z2 += 0.00000000021*np.cos(6.22275008403 + 6069.7767545534*t)
	Z2 += 0.00000000024*np.cos(5.83690442827 + 6282.0955289232*t)
	Z2 += 0.00000000024*np.cos(3.95322179797 + 6284.0561710596*t)
	Z2 += 0.00000000022*np.cos(3.46618662246 + 4136.9104335162*t)
	Z2 += 0.00000000025*np.cos(2.78460430400 + 209.3669421749*t)
	Z2 += 0.00000000021*np.cos(3.58048145762 + 6496.3749454294*t)
	Z2 += 0.00000000025*np.cos(5.59503085104 + 7058.5984613154*t)
	Z2 += 0.00000000019*np.cos(1.62978232282 + 1194.4470102246*t)
	Z2 += 0.00000000021*np.cos(5.74317740279 + 532.8723588323*t)
	Z2 += 0.00000000018*np.cos(1.87060868220 + 323.5054166574*t)
	Z2 += 0.00000000024*np.cos(5.40715542605 + 12168.0026965746*t)
	Z2 += 0.00000000017*np.cos(4.58615737180 + 526.5095713569*t)
	Z2 += 0.00000000017*np.cos(6.02623550832 + 95.9792272178*t)
	Z2 += 0.00000000016*np.cos(6.02211293999 + 412.3710968744*t)
	Z2 += 0.00000000015*np.cos(0.00767394500 + 202.2533951741*t)
	Z2 += 0.00000000012*np.cos(2.50603952514 + 149.5631971346*t)
	Z2 += 0.00000000013*np.cos(5.75707842894 + 525.7588118315*t)
	Z2 += 0.00000000011*np.cos(2.77607629936 + 73.297125859*t)
	Z2 += 0.00000000011*np.cos(0.99969948118 + 1596.1864422846*t)
	Z2 += 0.00000000012*np.cos(3.07376705363 + 1045.1548361876*t)
	Z2 += 0.00000000011*np.cos(0.01879438470 + 309.2783226558*t)
	Z2 += 0.00000000010*np.cos(4.70919553736 + 533.6231183577*t)
	return Z2*t*t




def Earth_Z3 (t): # 40 terms of order 3

	Z3 = 0.
	Z3 += 0.00000276077*np.cos(0.59413258730 + 6283.0758499914*t)
	Z3 -= 0.00000026789
	Z3 += 0.00000001810*np.cos(0.11612262117 + 12566.1516999828*t)
	Z3 += 0.00000001302*np.cos(4.84806136860 + 213.299095438*t)
	Z3 += 0.00000001364*np.cos(2.43564490971 + 206.1855484372*t)
	Z3 += 0.00000000920*np.cos(1.65069146673 + 529.6909650946*t)
	Z3 += 0.00000000716*np.cos(1.50799790954 + 220.4126424388*t)
	Z3 += 0.00000000423*np.cos(4.54129218357 + 536.8045120954*t)
	Z3 += 0.00000000282*np.cos(5.95440671732 + 522.5774180938*t)
	Z3 += 0.00000000113*np.cos(5.66152847225 + 18849.2275499742*t)
	Z3 += 0.00000000090*np.cos(0.51819099535 + 433.7117378768*t)
	Z3 += 0.00000000094*np.cos(1.55249614896 + 419.4846438752*t)
	Z3 += 0.00000000079*np.cos(1.38892285542 + 227.5261894396*t)
	Z3 += 0.00000000094*np.cos(0.17438010106 + 426.598190876*t)
	Z3 += 0.00000000048*np.cos(3.11903200545 + 1059.3819301892*t)
	Z3 += 0.00000000056*np.cos(5.02765554835 + 6279.5527316424*t)
	Z3 += 0.00000000050*np.cos(2.64433369691 + 199.0720014364*t)
	Z3 += 0.00000000042*np.cos(2.65785543548 + 7.1135470008*t)
	Z3 += 0.00000000028*np.cos(5.89394518040 + 515.463871093*t)
	Z3 += 0.00000000027*np.cos(5.17159300173 + 1066.49547719*t)
	Z3 += 0.00000000024*np.cos(4.43334493389 + 543.9180590962*t)
	Z3 += 0.00000000026*np.cos(5.61220088462 + 639.897286314*t)
	Z3 += 0.00000000024*np.cos(0.41571093398 + 83996.84731811189*t)
	Z3 += 0.00000000019*np.cos(5.99007646261 + 6256.7775301916*t)
	Z3 += 0.00000000018*np.cos(3.80004734567 + 6309.3741697912*t)
	Z3 += 0.00000000018*np.cos(0.02154769101 + 74.7815985673*t)
	Z3 += 0.00000000018*np.cos(1.21049250774 + 6127.6554505572*t)
	Z3 += 0.00000000018*np.cos(2.29734567137 + 6438.4962494256*t)
	Z3 += 0.00000000017*np.cos(2.57902262762 + 14.2270940016*t)
	Z3 += 0.00000000013*np.cos(3.07320748125 + 210.1177017003*t)
	Z3 += 0.00000000015*np.cos(4.72881467263 + 6286.5989683404*t)
	Z3 += 0.00000000012*np.cos(5.68952008926 + 1052.2683831884*t)
	Z3 += 0.00000000011*np.cos(0.06567554803 + 316.3918696566*t)
	Z3 += 0.00000000011*np.cos(5.88691938543 + 647.0108333148*t)
	Z3 += 0.00000000011*np.cos(1.48347223110 + 709.9330485583*t)
	Z3 += 0.00000000009*np.cos(0.49541679064 + 440.8252848776*t)
	Z3 += 0.00000000007*np.cos(4.01090297903 + 1589.0728952838*t)
	Z3 += 0.00000000008*np.cos(0.88032790118 + 216.4804891757*t)
	Z3 += 0.00000000006*np.cos(6.21088176821 + 38.1330356378*t)
	Z3 += 0.00000000007*np.cos(3.28974856542 + 103.0927742186*t)
	return Z3*t*t*t




def Earth_Z4 (t): # 22 terms of order 4

	Z4 = 0.
	Z4 += 0.00000005751*np.cos(2.27069090892 + 6283.0758499914*t)
	Z4 += 0.00000001315
	Z4 += 0.00000000164*np.cos(4.10546661445 + 206.1855484372*t)
	Z4 += 0.00000000072*np.cos(6.04348211714 + 220.4126424388*t)
	Z4 += 0.00000000070*np.cos(6.10651561968 + 213.299095438*t)
	Z4 += 0.00000000060*np.cos(4.26712050846 + 12566.1516999828*t)
	Z4 += 0.00000000044*np.cos(2.79536133222 + 536.8045120954*t)
	Z4 += 0.00000000026*np.cos(1.66128176108 + 522.5774180938*t)
	Z4 += 0.00000000016*np.cos(5.95724279756 + 227.5261894396*t)
	Z4 += 0.00000000011*np.cos(4.33140895473 + 199.0720014364*t)
	Z4 += 0.00000000012*np.cos(5.02489197754 + 433.7117378768*t)
	Z4 += 0.00000000008*np.cos(3.36029048603 + 419.4846438752*t)
	Z4 += 0.00000000006*np.cos(1.39462759175 + 515.463871093*t)
	Z4 += 0.00000000006*np.cos(4.13914011953 + 18849.2275499742*t)
	Z4 += 0.00000000005*np.cos(2.67511593664 + 543.9180590962*t)
	Z4 += 0.00000000004*np.cos(4.65054077397 + 529.6909650946*t)
	Z4 += 0.00000000005*np.cos(0.84308705203 + 1047.7473117547*t)
	Z4 += 0.00000000005*np.cos(4.82245392155 + 426.598190876*t)
	Z4 += 0.00000000005*np.cos(0.05711572303 + 84334.66158130829*t)
	Z4 += 0.00000000003*np.cos(0.96348403857 + 7.1135470008*t)
	Z4 += 0.00000000003*np.cos(0.80949781331 + 14.2270940016*t)
	Z4 += 0.00000000003*np.cos(3.63118822382 + 1066.49547719*t)
	return Z4*t*t*t*t




def Earth_Z5 (t): # 8 terms of order 5

	Z5 = 0.
	Z5 += 0.00000000114*np.cos(4.31169156923 + 6283.0758499914*t)
	Z5 += 0.00000000039
	Z5 += 0.00000000015*np.cos(5.75563126750 + 206.1855484372*t)
	Z5 += 0.00000000005*np.cos(4.29978807671 + 220.4126424388*t)
	Z5 += 0.00000000003*np.cos(0.96254361103 + 536.8045120954*t)
	Z5 += 0.00000000002*np.cos(3.96773929080 + 522.5774180938*t)
	Z5 += 0.00000000002*np.cos(4.22112932205 + 227.5261894396*t)
	Z5 += 0.00000000002*np.cos(6.02426931559 + 199.0720014364*t)
	return Z5*t*t*t*t*t





def Mars_X0 (t): # 1572 terms of order 0

	X0 = 0.
	X0 += 1.51769887405*np.cos(6.20403346548 + 3340.6124266998*t)
	X0 -= 0.19473570996
	X0 += 0.07070917372*np.cos(0.25870338552 + 6681.2248533996*t)
	X0 += 0.00494196754*np.cos(0.59669127752 + 10021.8372800994*t)
	X0 += 0.00482151285*np.cos(3.74021439144 + 529.6909650946*t)
	X0 += 0.00271094292*np.cos(4.01586959956 + 213.299095438*t)
	X0 += 0.00155429009*np.cos(2.17051900894 + 38.1330356378*t)
	X0 += 0.00083777640*np.cos(2.33969868905 + 74.7815985673*t)
	X0 += 0.00040938237*np.cos(0.93473307419 + 13362.4497067992*t)
	X0 += 0.00021067199*np.cos(1.80435656154 + 3337.0893083508*t)
	X0 += 0.00021041626*np.cos(1.17895619474 + 3344.1355450488*t)
	X0 += 0.00021794152*np.cos(4.45100162839 + 1059.3819301892*t)
	X0 += 0.00006774107*np.cos(3.61785048282 + 3340.5951730476*t)
	X0 += 0.00006774060*np.cos(5.64862211431 + 3340.629680352*t)
	X0 += 0.00008226069*np.cos(1.86843519535 + 2281.2304965106*t)
	X0 += 0.00005469046*np.cos(1.13324429003 + 2942.4634232916*t)
	X0 += 0.00007117418*np.cos(3.35582835022 + 426.598190876*t)
	X0 += 0.00004817134*np.cos(1.85091045536 + 3738.761430108*t)
	X0 += 0.00004937579*np.cos(4.43241440654 + 5621.8429232104*t)
	X0 += 0.00005276260*np.cos(2.33148083116 + 6151.533888305*t)
	X0 += 0.00003636667*np.cos(6.11397592106 + 796.2980068164*t)
	X0 += 0.00003725823*np.cos(1.27280182943 + 16703.062133499*t)
	X0 += 0.00003729746*np.cos(1.21398323637 + 398.1490034082*t)
	X0 += 0.00002368513*np.cos(2.96841895360 + 2544.3144198834*t)
	X0 += 0.00002397865*np.cos(0.63553674054 + 3149.1641605882*t)
	X0 += 0.00002274646*np.cos(2.35708328853 + 3532.0606928114*t)
	X0 += 0.00001977579*np.cos(2.14087826110 + 6677.7017350506*t)
	X0 += 0.00002229176*np.cos(1.69588962513 + 3340.545116397*t)
	X0 += 0.00002229117*np.cos(1.28739323821 + 3340.6797370026*t)
	X0 += 0.00001980977*np.cos(4.76060234423 + 1589.0728952838*t)
	X0 += 0.00002241010*np.cos(4.82218655311 + 8962.4553499102*t)
	X0 += 0.00001677693*np.cos(3.14442612046 + 5884.9268465832*t)
	X0 += 0.00001630482*np.cos(0.24117974845 + 4136.9104335162*t)
	X0 += 0.00001935640*np.cos(1.01281554555 + 206.1855484372*t)
	X0 += 0.00001958162*np.cos(1.51914544555 + 6684.7479717486*t)
	X0 += 0.00001882589*np.cos(3.89281844329 + 220.4126424388*t)
	X0 += 0.00001899230*np.cos(4.79118006044 + 149.5631971346*t)
	X0 += 0.00001878785*np.cos(1.68734377004 + 6283.0758499914*t)
	X0 += 0.00001378470*np.cos(2.18011900021 + 1751.539531416*t)
	X0 += 0.00001289804*np.cos(4.70970778621 + 1194.4470102246*t)
	X0 += 0.00001468124*np.cos(1.87869730543 + 3870.3033917944*t)
	X0 += 0.00001290170*np.cos(0.43596325296 + 2810.9214616052*t)
	X0 += 0.00001395167*np.cos(3.86838914853 + 522.5774180938*t)
	X0 += 0.00001202216*np.cos(0.79285185429 + 76.2660712756*t)
	X0 += 0.00001364897*np.cos(0.47624575868 + 536.8045120954*t)
	X0 += 0.00000819458*np.cos(5.15884167649 + 4399.994356889*t)
	X0 += 0.00000708712*np.cos(4.69562713369 + 5486.777843175*t)
	X0 += 0.00000719048*np.cos(2.91145340412 + 191.4482661116*t)
	X0 += 0.00000702848*np.cos(4.67590003722 + 2146.1654164752*t)
	X0 += 0.00000720121*np.cos(2.65539067862 + 9492.1463150048*t)
	X0 += 0.00000813685*np.cos(3.25483611884 + 36.6485629295*t)
	X0 += 0.00000631186*np.cos(3.95569679737 + 6681.2075997474*t)
	X0 += 0.00000767074*np.cos(4.22743731914 + 39.6175083461*t)
	X0 += 0.00000631186*np.cos(5.98646842887 + 6681.2421070518*t)
	X0 += 0.00000582287*np.cos(3.95295967777 + 3185.1920272656*t)
	X0 += 0.00000555568*np.cos(5.32014604077 + 3496.032826134*t)
	X0 += 0.00000624717*np.cos(0.27933568181 + 73.297125859*t)
	X0 += 0.00000492190*np.cos(2.17606530808 + 7079.3738568078*t)
	X0 += 0.00000535122*np.cos(3.30310120139 + 1592.5960136328*t)
	X0 += 0.00000417652*np.cos(5.30163601083 + 3341.592747768*t)
	X0 += 0.00000417769*np.cos(3.96482796919 + 3339.6321056316*t)
	X0 += 0.00000370752*np.cos(5.08127148188 + 8432.7643848156*t)
	X0 += 0.00000360028*np.cos(1.61089122901 + 20043.6745601988*t)
	X0 += 0.00000353036*np.cos(3.88678429649 + 6254.6266625236*t)
	X0 += 0.00000352079*np.cos(5.17043717929 + 12303.06777661*t)
	X0 += 0.00000321578*np.cos(1.94644283196 + 3553.9115221378*t)
	X0 += 0.00000346042*np.cos(6.16404119331 + 5088.6288397668*t)
	X0 += 0.00000301924*np.cos(0.98460899560 + 3127.3133312618*t)
	X0 += 0.00000307060*np.cos(0.00966130243 + 1748.016413067*t)
	X0 += 0.00000289548*np.cos(3.01109781662 + 639.897286314*t)
	X0 += 0.00000304330*np.cos(6.18453486751 + 419.4846438752*t)
	X0 += 0.00000260116*np.cos(1.89587348902 + 1990.745017041*t)
	X0 += 0.00000274183*np.cos(4.89858667877 + 110.2063212194*t)
	X0 += 0.00000313875*np.cos(5.10651966600 + 4535.0594369244*t)
	X0 += 0.00000271815*np.cos(1.94925691995 + 6467.9257579616*t)
	X0 += 0.00000223359*np.cos(3.55354563068 + 3319.8370312074*t)
	X0 += 0.00000221615*np.cos(5.71282076784 + 3361.3878221922*t)
	X0 += 0.00000234058*np.cos(2.03750130921 + 9623.6882766912*t)
	X0 += 0.00000211903*np.cos(4.91970637585 + 2118.7638603784*t)
	X0 += 0.00000207708*np.cos(2.03373205181 + 6681.1575430968*t)
	X0 += 0.00000205217*np.cos(1.85790835685 + 10025.3603984484*t)
	X0 += 0.00000207851*np.cos(2.47841996435 + 10018.3141617504*t)
	X0 += 0.00000253068*np.cos(1.39828863887 + 2914.0142358238*t)
	X0 += 0.00000215528*np.cos(5.79667265099 + 316.3918696566*t)
	X0 += 0.00000218718*np.cos(0.97547090194 + 6489.776587288*t)
	X0 += 0.00000190381*np.cos(1.28527355998 + 4690.4798363586*t)
	X0 += 0.00000207708*np.cos(1.62523566496 + 6681.2921637024*t)
	X0 += 0.00000196392*np.cos(5.31221470494 + 103.0927742186*t)
	X0 += 0.00000178814*np.cos(2.54776084181 + 1221.8485663214*t)
	X0 += 0.00000157307*np.cos(0.48852895157 + 2388.8940204492*t)
	X0 += 0.00000177177*np.cos(4.27081023055 + 2957.7158944766*t)
	X0 += 0.00000147711*np.cos(2.47588653124 + 7210.9158184942*t)
	X0 += 0.00000164710*np.cos(0.57591122272 + 7477.522860216*t)
	X0 += 0.00000168450*np.cos(5.06929034077 + 3723.508958923*t)
	X0 += 0.00000126166*np.cos(2.64309008334 + 4292.3308329504*t)
	X0 += 0.00000161231*np.cos(1.53118234358 + 1349.8674096588*t)
	X0 += 0.00000135146*np.cos(0.12922395244 + 7903.073419721*t)
	X0 += 0.00000146849*np.cos(4.41614407590 + 3337.021998048*t)
	X0 += 0.00000146211*np.cos(4.84723563341 + 3344.2028553516*t)
	X0 += 0.00000119425*np.cos(4.65545643220 + 11773.3768115154*t)
	X0 += 0.00000144098*np.cos(5.36305248386 + 2787.0430238574*t)
	X0 += 0.00000112328*np.cos(0.07498207309 + 3205.5473466644*t)
	X0 += 0.00000118125*np.cos(5.18570866097 + 4929.6853219836*t)
	X0 += 0.00000112305*np.cos(3.45701462628 + 3333.498879699*t)
	X0 += 0.00000106788*np.cos(2.91050878748 + 3475.6775067352*t)
	X0 += 0.00000125116*np.cos(3.97421380472 + 3894.1818295422*t)
	X0 += 0.00000115996*np.cos(2.34467702892 + 632.7837393132*t)
	X0 += 0.00000120319*np.cos(3.40966066157 + 9225.539273283*t)
	X0 += 0.00000136802*np.cos(2.00004829755 + 1.4844727083*t)
	X0 += 0.00000097207*np.cos(2.99865676561 + 951.7184062506*t)
	X0 += 0.00000106515*np.cos(5.50162815365 + 382.8965322232*t)
	X0 += 0.00000125429*np.cos(1.20223756443 + 1066.49547719*t)
	X0 += 0.00000094433*np.cos(3.80552493439 + 1052.2683831884*t)
	X0 += 0.00000096090*np.cos(5.81819224527 + 3347.7259737006*t)
	X0 += 0.00000088763*np.cos(2.98692015057 + 12832.7587417046*t)
	X0 += 0.00000088424*np.cos(0.46788407862 + 3097.88382272579*t)
	X0 += 0.00000115240*np.cos(5.86554297015 + 155.4203994342*t)
	X0 += 0.00000080693*np.cos(2.54262499897 + 3583.3410306738*t)
	X0 += 0.00000094077*np.cos(4.97076329120 + 7.1135470008*t)
	X0 += 0.00000085394*np.cos(3.68553580935 + 4933.2084403326*t)
	X0 += 0.00000084575*np.cos(0.98139044515 + 6674.1113063988*t)
	X0 += 0.00000098850*np.cos(3.24207878297 + 433.7117378768*t)
	X0 += 0.00000103046*np.cos(3.17830954472 + 1162.4747044078*t)
	X0 += 0.00000072879*np.cos(4.43895846428 + 553.5694028424*t)
	X0 += 0.00000073967*np.cos(5.89004738022 + 3767.2106175758*t)
	X0 += 0.00000092023*np.cos(4.26113870399 + 9595.2390892234*t)
	X0 += 0.00000066160*np.cos(0.94815285206 + 3.523118349*t)
	X0 += 0.00000073608*np.cos(5.48570032991 + 7740.6067835888*t)
	X0 += 0.00000066213*np.cos(2.34472269926 + 2700.7151403858*t)
	X0 += 0.00000069810*np.cos(5.73677959672 + 5092.1519581158*t)
	X0 += 0.00000054167*np.cos(4.29292954610 + 6525.8044539654*t)
	X0 += 0.00000066184*np.cos(0.04131920152 + 10021.8545337516*t)
	X0 += 0.00000051348*np.cos(1.31398523429 + 949.1756089698*t)
	X0 += 0.00000049919*np.cos(5.09299800813 + 3312.163239232*t)
	X0 += 0.00000049213*np.cos(4.17306140605 + 3369.0616141676*t)
	X0 += 0.00000047370*np.cos(5.51507270323 + 15643.6802033098*t)
	X0 += 0.00000063481*np.cos(0.27107636373 + 846.0828347512*t)
	X0 += 0.00000066184*np.cos(4.29373287721 + 10021.8200264472*t)
	X0 += 0.00000063793*np.cos(5.79810121165 + 148.0787244263*t)
	X0 += 0.00000058772*np.cos(0.68454863730 + 224.3447957019*t)
	X0 += 0.00000057875*np.cos(5.05744124530 + 6041.3275670856*t)
	X0 += 0.00000053324*np.cos(2.50863035758 + 10419.9862835076*t)
	X0 += 0.00000038940*np.cos(5.63973862939 + 6682.2051744678*t)
	X0 += 0.00000043109*np.cos(2.71319075118 + 3325.3599555148*t)
	X0 += 0.00000042867*np.cos(0.27117433127 + 3355.8648978848*t)
	X0 += 0.00000048698*np.cos(5.09899941910 + 2274.1169495098*t)
	X0 += 0.00000046383*np.cos(1.73717073020 + 2288.3440435114*t)
	X0 += 0.00000036267*np.cos(1.94902928841 + 23384.2869868986*t)
	X0 += 0.00000050165*np.cos(2.14736989820 + 4562.4609930212*t)
	X0 += 0.00000044704*np.cos(4.31072201688 + 3077.528503327*t)
	X0 += 0.00000031936*np.cos(4.22847752010 + 5628.9564702112*t)
	X0 += 0.00000033826*np.cos(2.14280999100 + 242.728603974*t)
	X0 += 0.00000032584*np.cos(5.11554630054 + 2648.454825473*t)
	X0 += 0.00000031516*np.cos(2.26487927217 + 5331.3574437408*t)
	X0 += 0.00000036134*np.cos(2.27592727288 + 9808.5381846614*t)
	X0 += 0.00000037824*np.cos(4.58891701161 + 35.1640902212*t)
	X0 += 0.00000031150*np.cos(1.37429681895 + 63.7358983034*t)
	X0 += 0.00000039073*np.cos(4.30379109135 + 6680.2445323314*t)
	X0 += 0.00000029903*np.cos(0.50914323279 + 7373.3824546264*t)
	X0 += 0.00000032386*np.cos(5.44057780617 + 7875.6718636242*t)
	X0 += 0.00000038513*np.cos(2.35130225277 + 6894.5239488376*t)
	X0 += 0.00000040052*np.cos(4.95360412434 + 3603.6963500726*t)
	X0 += 0.00000030679*np.cos(4.19722029443 + 11.0457002639*t)
	X0 += 0.00000027675*np.cos(2.38007622196 + 12964.300703391*t)
	X0 += 0.00000029415*np.cos(1.41703966406 + 5614.7293762096*t)
	X0 += 0.00000029883*np.cos(4.05954052924 + 1692.1656695024*t)
	X0 += 0.00000029811*np.cos(5.42002217767 + 3178.1457905676*t)
	X0 += 0.00000026263*np.cos(3.88406335289 + 1581.959348283*t)
	X0 += 0.00000027624*np.cos(1.51598253003 + 8429.2412664666*t)
	X0 += 0.00000027780*np.cos(3.76684820301 + 3503.079062832*t)
	X0 += 0.00000024077*np.cos(2.77490729346 + 853.196381752*t)
	X0 += 0.00000023774*np.cos(3.79283688871 + 3320.257107301*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000023576*np.cos(5.47254185738 + 3360.96774609859*t)
	X0 += 0.00000028132*np.cos(3.70750796008 + 151.0476698429*t)
	X0 += 0.00000022361*np.cos(4.86113133643 + 15113.9892382152*t)
	X0 += 0.00000022690*np.cos(2.19469301612 + 13365.9728251482*t)
	X0 += 0.00000024893*np.cos(2.94802556560 + 692.1576012268*t)
	X0 += 0.00000021831*np.cos(1.96164672611 + 10021.9045904022*t)
	X0 += 0.00000023782*np.cos(3.76207354349 + 227.5261894396*t)
	X0 += 0.00000021452*np.cos(3.90485002116 + 6660.4494579072*t)
	X0 += 0.00000025193*np.cos(0.35005183307 + 3335.0895023924*t)
	X0 += 0.00000021831*np.cos(2.37014311295 + 10021.7699697966*t)
	X0 += 0.00000025135*np.cos(2.63045826824 + 3346.1353510072*t)
	X0 += 0.00000022753*np.cos(1.31299329202 + 9830.3890139878*t)
	X0 += 0.00000023267*np.cos(0.46827104623 + 85.8272988312*t)
	X0 += 0.00000022744*np.cos(1.67012539714 + 71.8126531507*t)
	X0 += 0.00000020575*np.cos(0.90645437334 + 6438.4962494256*t)
	X0 += 0.00000024954*np.cos(2.47676946948 + 1648.4467571974*t)
	X0 += 0.00000019324*np.cos(0.97030055777 + 3329.97576135*t)
	X0 += 0.00000019241*np.cos(2.01197452147 + 3351.2490920496*t)
	X0 += 0.00000023600*np.cos(6.05705050939 + 10713.9948813262*t)
	X0 += 0.00000017286*np.cos(0.90425997403 + 6872.6731195112*t)
	X0 += 0.00000019863*np.cos(5.26277662529 + 9381.9399937854*t)
	X0 += 0.00000023245*np.cos(2.81335780702 + 1758.6530784168*t)
	X0 += 0.00000017302*np.cos(5.28125791066 + 742.9900605326*t)
	X0 += 0.00000018911*np.cos(1.70838297719 + 3863.1898447936*t)
	X0 += 0.00000019594*np.cos(1.20290770391 + 2818.035008606*t)
	X0 += 0.00000023014*np.cos(2.81461106664 + 13358.9265884502*t)
	X0 += 0.00000022286*np.cos(3.93734569173 + 2.9689454166*t)
	X0 += 0.00000020716*np.cos(6.04882555598 + 6702.000248892*t)
	X0 += 0.00000017630*np.cos(0.77500497806 + 3074.005384978*t)
	X0 += 0.00000021283*np.cos(0.36889274817 + 2707.8286873866*t)
	X0 += 0.00000020026*np.cos(4.02923197304 + 209.3669421749*t)
	X0 += 0.00000021789*np.cos(0.10801807790 + 77.7505439839*t)
	X0 += 0.00000016342*np.cos(4.60982335717 + 6298.3283211764*t)
	X0 += 0.00000019681*np.cos(0.87544248531 + 217.2312487011*t)
	X0 += 0.00000022491*np.cos(3.05082771617 + 8031.0922630584*t)
	X0 += 0.00000016318*np.cos(2.90860348903 + 10551.528245194*t)
	X0 += 0.00000019075*np.cos(5.91973929854 + 202.2533951741*t)
	X0 += 0.00000016107*np.cos(2.52814803336 + 735.8765135318*t)
	X0 += 0.00000017705*np.cos(0.90939692872 + 10818.1352869158*t)
	X0 += 0.00000016950*np.cos(1.49290558048 + 1596.1864422846*t)
	X0 += 0.00000016242*np.cos(2.21265902746 + 3607.2194684216*t)
	X0 += 0.00000017360*np.cos(3.01137661271 + 138.5174968707*t)
	X0 += 0.00000016533*np.cos(2.14796846234 + 6158.6474353058*t)
	X0 += 0.00000019312*np.cos(5.67131104636 + 6836.6452528338*t)
	X0 += 0.00000014994*np.cos(1.03985219202 + 6531.661656265*t)
	X0 += 0.00000014342*np.cos(2.39106240306 + 1478.8665740644*t)
	X0 += 0.00000015089*np.cos(4.00435666151 + 515.463871093*t)
	X0 += 0.00000017187*np.cos(5.02091584362 + 11243.6858464208*t)
	X0 += 0.00000013658*np.cos(0.95367846073 + 7064.1213856228*t)
	X0 += 0.00000013547*np.cos(5.18592691748 + 6684.8152820514*t)
	X0 += 0.00000015670*np.cos(4.46631838197 + 3333.5661900018*t)
	X0 += 0.00000017068*np.cos(2.99316325540 + 323.5054166574*t)
	X0 += 0.00000016212*np.cos(0.84608813575 + 5729.506447149*t)
	X0 += 0.00000016254*np.cos(5.63862628078 + 6144.4203413042*t)
	X0 += 0.00000016776*np.cos(3.21915143967 + 4032.7700279266*t)
	X0 += 0.00000013925*np.cos(4.61081158788 + 12935.8515159232*t)
	X0 += 0.00000013204*np.cos(2.85464406974 + 956.2891559706*t)
	X0 += 0.00000016781*np.cos(2.44831081494 + 3973.396166013*t)
	X0 += 0.00000012720*np.cos(2.28483212376 + 3336.7310913418*t)
	X0 += 0.00000012703*np.cos(0.69084968319 + 3344.4937620578*t)
	X0 += 0.00000015246*np.cos(5.27637617538 + 5459.3762870782*t)
	X0 += 0.00000014286*np.cos(0.57434628738 + 10404.7338123226*t)
	X0 += 0.00000013737*np.cos(5.70954873985 + 6127.6554505572*t)
	X0 += 0.00000012994*np.cos(3.50514987766 + 8827.3902698748*t)
	X0 += 0.00000012310*np.cos(3.32813422481 + 2487.4160449478*t)
	X0 += 0.00000012133*np.cos(4.87509657472 + 3980.5097130138*t)
	X0 += 0.00000012110*np.cos(4.63788633296 + 3281.2385647862*t)
	X0 += 0.00000013767*np.cos(4.75090697315 + 6677.6344247478*t)
	X0 += 0.00000011758*np.cos(4.61782311507 + 3399.9862886134*t)
	X0 += 0.00000011916*np.cos(5.44422183383 + 1744.4259844152*t)
	X0 += 0.00000013640*np.cos(5.59411674318 + 3415.3940252671*t)
	X0 += 0.00000012925*np.cos(4.67854321339 + 7632.9432596502*t)
	X0 += 0.00000013026*np.cos(3.93047583551 + 11769.8536931664*t)
	X0 += 0.00000011412*np.cos(3.55488173063 + 11371.7046897582*t)
	X0 += 0.00000011148*np.cos(5.52272711776 + 8270.2977486834*t)
	X0 += 0.00000011153*np.cos(3.25807789781 + 6816.289933435*t)
	X0 += 0.00000011351*np.cos(4.98057415035 + 4989.0591838972*t)
	X0 += 0.00000012966*np.cos(4.66632646085 + 8969.568896911*t)
	X0 += 0.00000013281*np.cos(3.70325148510 + 3265.8308281325*t)
	X0 += 0.00000013932*np.cos(0.43513047926 + 6546.1597733642*t)
	X0 += 0.00000013694*np.cos(4.65145546794 + 3347.6586633978*t)
	X0 += 0.00000011229*np.cos(1.18029367551 + 199.0720014364*t)
	X0 += 0.00000010824*np.cos(0.88978834814 + 3316.733988952*t)
	X0 += 0.00000010722*np.cos(2.08650180598 + 3364.4908644476*t)
	X0 += 0.00000013330*np.cos(1.73633967849 + 8955.3418029094*t)
	X0 += 0.00000010768*np.cos(3.32549049401 + 16173.3711684044*t)
	X0 += 0.00000013163*np.cos(6.21762554655 + 6688.3384004004*t)
	X0 += 0.00000011418*np.cos(0.88286540120 + 3237.5196524812*t)
	X0 += 0.00000010500*np.cos(0.34443936109 + 543.9180590962*t)
	X0 += 0.00000012130*np.cos(2.00651433041 + 3443.7052009184*t)
	X0 += 0.00000009287*np.cos(6.03988322239 + 3304.5845600224*t)
	X0 += 0.00000011267*np.cos(0.61071260601 + 525.7588118315*t)
	X0 += 0.00000009160*np.cos(3.21863721466 + 3376.6402933772*t)
	X0 += 0.00000011121*np.cos(3.72464071334 + 533.6231183577*t)
	X0 += 0.00000008926*np.cos(4.01851361248 + 8273.8208670324*t)
	X0 += 0.00000009314*np.cos(3.91047150173 + 14584.2982731206*t)
	X0 += 0.00000012215*np.cos(1.30873077067 + 10014.7237330986*t)
	X0 += 0.00000011535*np.cos(3.38250705677 + 3024.2205570432*t)
	X0 += 0.00000008906*np.cos(0.93197483563 + 3341.0325027934*t)
	X0 += 0.00000008906*np.cos(2.04371438516 + 3340.19235060619*t)
	X0 += 0.00000010160*np.cos(1.10193057562 + 1375.7737998458*t)
	X0 += 0.00000010563*np.cos(4.76088157461 + 10973.55568635*t)
	X0 += 0.00000009728*np.cos(2.26828152965 + 135.0650800354*t)
	X0 += 0.00000010504*np.cos(0.14052500788 + 10213.285546211*t)
	X0 += 0.00000008125*np.cos(0.08684877067 + 5828.0284716476*t)
	X0 += 0.00000007830*np.cos(3.37196781134 + 162.4666361322*t)
	X0 += 0.00000010475*np.cos(5.87139389943 + 3657.0042963564*t)
	X0 += 0.00000008273*np.cos(1.36018120251 + 6604.958782124*t)
	X0 += 0.00000010423*np.cos(2.32096503578 + 12168.0026965746*t)
	X0 += 0.00000007365*np.cos(0.74165927300 + 3760.097070575*t)
	X0 += 0.00000007447*np.cos(4.28662713398 + 1861.7458526354*t)
	X0 += 0.00000007185*np.cos(3.51955509534 + 216.4804891757*t)
	X0 += 0.00000008951*np.cos(3.64574332393 + 12566.1516999828*t)
	X0 += 0.00000007300*np.cos(0.37690059591 + 13362.4669604514*t)
	X0 += 0.00000007015*np.cos(1.38855213071 + 210.1177017003*t)
	X0 += 0.00000007123*np.cos(2.45133618223 + 415.5524906121*t)
	X0 += 0.00000007546*np.cos(4.17104317176 + 3134.4268782626*t)
	X0 += 0.00000009008*np.cos(4.88604280960 + 6784.3176276182*t)
	X0 += 0.00000007320*np.cos(4.63241620258 + 13362.432453147*t)
	X0 += 0.00000006835*np.cos(4.36919710114 + 117.3198682202*t)
	X0 += 0.00000006861*np.cos(3.80050446208 + 3169.9395560806*t)
	X0 += 0.00000008149*np.cos(2.72974838905 + 2921.1277828246*t)
	X0 += 0.00000007236*np.cos(5.08483662864 + 3546.797975137*t)
	X0 += 0.00000008579*np.cos(5.84551720825 + 5099.2655051166*t)
	X0 += 0.00000007567*np.cos(3.44029907335 + 3209.0704650134*t)
	X0 += 0.00000007164*np.cos(3.96689749027 + 1265.5674786264*t)
	X0 += 0.00000007609*np.cos(5.08371147556 + 3304.0070613956*t)
	X0 += 0.00000006467*np.cos(0.02249536614 + 10184.3039162316*t)
	X0 += 0.00000007516*np.cos(2.88089303559 + 6923.9534573736*t)
	X0 += 0.00000006807*np.cos(0.13521095675 + 7234.794256242*t)
	X0 += 0.00000006446*np.cos(5.78384184406 + 3341.0423098265*t)
	X0 += 0.00000006446*np.cos(3.48151772817 + 3340.1825435731*t)
	X0 += 0.00000006514*np.cos(2.78645432045 + 1118.7557921028*t)
	X0 += 0.00000006453*np.cos(5.46308741155 + 3511.285297319*t)
	X0 += 0.00000007475*np.cos(4.17838652821 + 3377.217792004*t)
	X0 += 0.00000006409*np.cos(6.18677106785 + 10575.4066829418*t)
	X0 += 0.00000007656*np.cos(5.81604841460 + 11081.2192102886*t)
	X0 += 0.00000006039*np.cos(0.72624360734 + 640.8776073822*t)
	X0 += 0.00000006850*np.cos(5.82614287106 + 3472.1543883862*t)
	X0 += 0.00000006803*np.cos(4.24835021117 + 2221.856634597*t)
	X0 += 0.00000005974*np.cos(2.84025495512 + 13760.5987102074*t)
	X0 += 0.00000006037*np.cos(5.85268725215 + 18984.2926300096*t)
	X0 += 0.00000005383*np.cos(3.18331360539 + 1228.9621133222*t)
	X0 += 0.00000006164*np.cos(2.88411929025 + 647.0108333148*t)
	X0 += 0.00000006832*np.cos(3.87277522484 + 6606.4432548323*t)
	X0 += 0.00000006244*np.cos(5.44473078234 + 70.8494453042*t)
	X0 += 0.00000005381*np.cos(1.74289410001 + 2766.267628365*t)
	X0 += 0.00000006944*np.cos(5.43820006019 + 8329.671610597*t)
	X0 += 0.00000005618*np.cos(2.04973538018 + 2699.7348193176*t)
	X0 += 0.00000005178*np.cos(3.38284373136 + 3274.1250177854*t)
	X0 += 0.00000005132*np.cos(1.40127317485 + 3914.9572250346*t)
	X0 += 0.00000006070*np.cos(5.30862163002 + 95.9792272178*t)
	X0 += 0.00000005655*np.cos(4.63277610967 + 9866.4168806652*t)
	X0 += 0.00000005074*np.cos(4.24610777191 + 526.5095713569*t)
	X0 += 0.00000004978*np.cos(0.09070559075 + 532.8723588323*t)
	X0 += 0.00000005030*np.cos(5.87356666210 + 3407.0998356142*t)
	X0 += 0.00000005875*np.cos(2.36907113150 + 78.7137518304*t)
	X0 += 0.00000004800*np.cos(1.93538187506 + 4407.1079038898*t)
	X0 += 0.00000005289*np.cos(0.07864350876 + 13916.0191096416*t)
	X0 += 0.00000006432*np.cos(4.86365370127 + 3296.8935143948*t)
	X0 += 0.00000006214*np.cos(5.76944976140 + 8439.8779318164*t)
	X0 += 0.00000006362*np.cos(4.39850678391 + 3384.3313390048*t)
	X0 += 0.00000006495*np.cos(0.01977871702 + 7107.8230442756*t)
	X0 += 0.00000004782*np.cos(0.76221170409 + 6261.7402095244*t)
	X0 += 0.00000006263*np.cos(5.31414297159 + 1964.838626854*t)
	X0 += 0.00000005038*np.cos(4.00806214098 + 6247.5131155228*t)
	X0 += 0.00000005347*np.cos(4.99024111406 + 14.2270940016*t)
	X0 += 0.00000004557*np.cos(1.53702348618 + 2807.3983432562*t)
	X0 += 0.00000004586*np.cos(4.50717342127 + 6709.6740408674*t)
	X0 += 0.00000006109*np.cos(5.67990095410 + 111.4301614968*t)
	X0 += 0.00000004868*np.cos(5.44478627062 + 4392.8808098882*t)
	X0 += 0.00000004383*np.cos(3.06060537188 + 6665.9723822146*t)
	X0 += 0.00000004389*np.cos(2.60342985448 + 13149.1506113612*t)
	X0 += 0.00000004835*np.cos(5.07151708141 + 14314.1681130498*t)
	X0 += 0.00000005778*np.cos(3.03661567763 + 2178.137722292*t)
	X0 += 0.00000004352*np.cos(2.71002586366 + 10235.1363755374*t)
	X0 += 0.00000004627*np.cos(3.66505491850 + 2803.8079146044*t)
	X0 += 0.00000004372*np.cos(6.12468678269 + 9168.6408983474*t)
	X0 += 0.00000004137*np.cos(1.74921053942 + 574.3447983348*t)
	X0 += 0.00000004316*np.cos(4.84679479800 + 3877.4169387952*t)
	X0 += 0.00000004107*np.cos(4.64137843892 + 10020.8569590312*t)
	X0 += 0.00000003822*np.cos(2.21626693517 + 3490.1756238344*t)
	X0 += 0.00000004992*np.cos(4.86610795801 + 114.3991069134*t)
	X0 += 0.00000004095*np.cos(5.97738996422 + 10022.8176011676*t)
	X0 += 0.00000004288*np.cos(1.51938558324 + 277.0349937414*t)
	X0 += 0.00000005127*np.cos(1.85460173676 + 222.8603229936*t)
	X0 += 0.00000003691*np.cos(0.07794330600 + 6571.0185321802*t)
	X0 += 0.00000004105*np.cos(0.62939165404 + 263.0839233728*t)
	X0 += 0.00000005145*np.cos(3.94142849979 + 2111.6503133776*t)
	X0 += 0.00000004598*np.cos(0.76405567220 + 146.594251718*t)
	X0 += 0.00000003544*np.cos(1.42006590232 + 13517.8701062334*t)
	X0 += 0.00000003496*np.cos(5.77175707487 + 11216.284290324*t)
	X0 += 0.00000003591*np.cos(1.55483371434 + 3873.8265101434*t)
	X0 += 0.00000004567*np.cos(5.47345981316 + 13524.9163429314*t)
	X0 += 0.00000003954*np.cos(5.40431118866 + 6652.7756659318*t)
	X0 += 0.00000004049*np.cos(1.12676329347 + 3981.490034082*t)
	X0 += 0.00000003269*np.cos(2.47578227627 + 6040.3472460174*t)
	X0 += 0.00000003781*np.cos(1.51484025806 + 2906.900688823*t)
	X0 += 0.00000003260*np.cos(2.06519414445 + 8425.6508378148*t)
	X0 += 0.00000003293*np.cos(1.70537885026 + 9779.1086761254*t)
	X0 += 0.00000003767*np.cos(2.28715050291 + 26724.8994135984*t)
	X0 += 0.00000003390*np.cos(5.15091511991 + 18454.601664915*t)
	X0 += 0.00000003325*np.cos(0.39339640639 + 6843.6914895318*t)
	X0 += 0.00000003962*np.cos(1.83390636841 + 6048.4411140864*t)
	X0 += 0.00000003154*np.cos(0.64171873873 + 5202.3582793352*t)
	X0 += 0.00000004019*np.cos(0.60853100264 + 6696.4773245846*t)
	X0 += 0.00000003926*np.cos(1.75260892669 + 266.6070417218*t)
	X0 += 0.00000003610*np.cos(3.30334295631 + 2008.557539159*t)
	X0 += 0.00000003266*np.cos(3.23784244279 + 13936.794505134*t)
	X0 += 0.00000003115*np.cos(1.54066694261 + 5305.4510535538*t)
	X0 += 0.00000003268*np.cos(2.71865882379 + 16304.9131300908*t)
	X0 += 0.00000003904*np.cos(3.77158991980 + 2384.3232707292*t)
	X0 += 0.00000003234*np.cos(3.23642327177 + 5518.7501489918*t)
	X0 += 0.00000003311*np.cos(2.59909525803 + 8671.9698704406*t)
	X0 += 0.00000002846*np.cos(3.36189891871 + 1332.0548875408*t)
	X0 += 0.00000003766*np.cos(5.98631611244 + 14712.317116458*t)
	X0 += 0.00000003754*np.cos(1.04640420137 + 490.3340891794*t)
	X0 += 0.00000002950*np.cos(5.25308946484 + 6944.3087767724*t)
	X0 += 0.00000002717*np.cos(5.76322783552 + 6518.7582172674*t)
	X0 += 0.00000002645*np.cos(5.46777283627 + 5989.0672521728*t)
	X0 += 0.00000002740*np.cos(0.07808443244 + 7910.1869667218*t)
	X0 += 0.00000002707*np.cos(1.80768212748 + 16858.4825329332*t)
	X0 += 0.00000002528*np.cos(1.65347317169 + 13171.0014406876*t)
	X0 += 0.00000003418*np.cos(2.52366884638 + 351.8165923087*t)
	X0 += 0.00000002483*np.cos(3.87260065092 + 3313.210870603*t)
	X0 += 0.00000002477*np.cos(4.75666685518 + 5732.0492444298*t)
	X0 += 0.00000003349*np.cos(0.87562878675 + 10177.2576795336*t)
	X0 += 0.00000002456*np.cos(5.39283487914 + 3368.0139827966*t)
	X0 += 0.00000002623*np.cos(3.15434704817 + 16699.53901514999*t)
	X0 += 0.00000002420*np.cos(1.77947870484 + 3561.0250691386*t)
	X0 += 0.00000002380*np.cos(1.67309028905 + 2125.8774073792*t)
	X0 += 0.00000002416*np.cos(2.30120840231 + 13362.517017102*t)
	X0 += 0.00000002437*np.cos(0.09917053128 + 5724.935697429*t)
	X0 += 0.00000002532*np.cos(4.86333607443 + 6475.0393049624*t)
	X0 += 0.00000003283*np.cos(3.57306497337 + 17277.4069318338*t)
	X0 += 0.00000002577*np.cos(2.89010347717 + 625.6701923124*t)
	X0 += 0.00000002305*np.cos(4.09655242470 + 17924.9106998204*t)
	X0 += 0.00000002334*np.cos(6.00094674252 + 9485.032768004*t)
	X0 += 0.00000002982*np.cos(0.59289983624 + 109.9456887885*t)
	X0 += 0.00000002658*np.cos(4.90685253882 + 3191.0492295652*t)
	X0 += 0.00000002433*np.cos(3.97617962527 + 3171.0322435668*t)
	X0 += 0.00000002399*np.cos(2.63420596512 + 15508.6151232744*t)
	X0 += 0.00000002274*np.cos(2.96629550939 + 6686.747777707*t)
	X0 += 0.00000002448*np.cos(4.59080697271 + 6418.1409300268*t)
	X0 += 0.00000002247*np.cos(2.22209606814 + 3343.3639373108*t)
	X0 += 0.00000002247*np.cos(0.76007819691 + 3337.8609160888*t)
	X0 += 0.00000002300*np.cos(1.05457137869 + 3120.199784261*t)
	X0 += 0.00000002861*np.cos(1.98905363521 + 3342.0968994081*t)
	X0 += 0.00000002836*np.cos(0.98608001394 + 3339.1279539915*t)
	X0 += 0.00000002948*np.cos(1.15362511196 + 6414.6178116778*t)
	X0 += 0.00000002582*np.cos(2.53488965696 + 16706.585251848*t)
	X0 += 0.00000002490*np.cos(5.13908908718 + 12722.5524204852*t)
	X0 += 0.00000002071*np.cos(2.95218926429 + 10596.1820784342*t)
	X0 += 0.00000002194*np.cos(5.25157497709 + 3510.1926098328*t)
	X0 += 0.00000002210*np.cos(0.98734172820 + 533.2140834436*t)
	X0 += 0.00000002346*np.cos(3.35828077447 + 299.1263942692*t)
	X0 += 0.00000002884*np.cos(6.25268747056 + 661.232926781*t)
	X0 += 0.00000002352*np.cos(0.68899979183 + 6675.7019290922*t)
	X0 += 0.00000002171*np.cos(2.82652953748 + 7314.0085927128*t)
	X0 += 0.00000002531*np.cos(3.98315571751 + 15110.4661198662*t)
	X0 += 0.00000001989*np.cos(1.24937409137 + 14158.7477136156*t)
	X0 += 0.00000002741*np.cos(1.36741656084 + 9872.2740829648*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000002051*np.cos(5.80635565702 + 1214.7350193206*t)
	X0 += 0.00000001980*np.cos(3.18993306283 + 16460.33352952499*t)
	X0 += 0.00000002057*np.cos(1.55396572210 + 1545.3539829788*t)
	X0 += 0.00000002016*np.cos(5.80333116821 + 6701.5801727984*t)
	X0 += 0.00000002315*np.cos(0.27491232644 + 1169.5882514086*t)
	X0 += 0.00000001963*np.cos(0.97426402220 + 8542.970706035*t)
	X0 += 0.00000002202*np.cos(5.06011306718 + 20.7753954924*t)
	X0 += 0.00000001921*np.cos(2.25819702736 + 2675.8563815698*t)
	X0 += 0.00000002221*np.cos(4.13094100375 + 6660.8695340008*t)
	X0 += 0.00000001930*np.cos(6.13648468700 + 1272.6810256272*t)
	X0 += 0.00000002185*np.cos(0.10437662983 + 10042.6126755918*t)
	X0 += 0.00000001963*np.cos(4.86879808564 + 6456.8800576977*t)
	X0 += 0.00000001928*np.cos(4.75990099243 + 1795.258443721*t)
	X0 += 0.00000001894*np.cos(1.54747808511 + 792.7748884674*t)
	X0 += 0.00000001887*np.cos(5.72755288130 + 7799.9806455024*t)
	X0 += 0.00000002355*np.cos(2.20727531576 + 6460.8122109608*t)
	X0 += 0.00000001918*np.cos(2.84810154019 + 2945.9865416406*t)
	X0 += 0.00000001856*np.cos(1.97055567397 + 3416.8784979754*t)
	X0 += 0.00000001999*np.cos(3.78408023322 + 3230.4061054804*t)
	X0 += 0.00000001844*np.cos(4.95411775516 + 16276.463942623*t)
	X0 += 0.00000002273*np.cos(4.24795887217 + 10001.061884607*t)
	X0 += 0.00000001863*np.cos(4.41136533550 + 2751.5475996916*t)
	X0 += 0.00000001884*np.cos(0.43882284635 + 13553.8979729108*t)
	X0 += 0.00000002215*np.cos(2.48685102846 + 9499.2598620056*t)
	X0 += 0.00000001805*np.cos(2.35009306355 + 6691.8615187494*t)
	X0 += 0.00000001827*np.cos(2.13792483074 + 12295.9542296092*t)
	X0 += 0.00000002416*np.cos(2.70970478916 + 13362.3823964964*t)
	X0 += 0.00000002281*np.cos(3.85790470815 + 6643.0918177618*t)
	X0 += 0.00000001748*np.cos(4.57086822580 + 5032.7780962022*t)
	X0 += 0.00000001981*np.cos(5.03237475958 + 12310.1813236108*t)
	X0 += 0.00000002102*np.cos(3.23137605134 + 13745.3462390224*t)
	X0 += 0.00000002109*np.cos(2.11504554973 + 7203.8022714934*t)
	X0 += 0.00000001951*np.cos(1.10549385911 + 799.8211251654*t)
	X0 += 0.00000001709*np.cos(1.31732873591 + 2391.43681773*t)
	X0 += 0.00000001700*np.cos(5.65890453825 + 1435.1476617594*t)
	X0 += 0.00000001672*np.cos(2.55075771165 + 6947.8318951214*t)
	X0 += 0.00000002150*np.cos(0.44492585631 + 17256.6315363414*t)
	X0 += 0.00000001651*np.cos(5.91049368296 + 6756.0064519669*t)
	X0 += 0.00000001660*np.cos(4.94561267936 + 9638.9407478762*t)
	X0 += 0.00000001728*np.cos(3.08566237875 + 1045.1548361876*t)
	X0 += 0.00000002136*np.cos(0.46897595624 + 28.4491874678*t)
	X0 += 0.00000001859*np.cos(1.33445554874 + 1905.4647649404*t)
	X0 += 0.00000001663*np.cos(3.83391966792 + 2277.7073781616*t)
	X0 += 0.00000001531*np.cos(0.78845566080 + 4005.3684718298*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001548*np.cos(1.53436911444 + 6578.132079181*t)
	X0 += 0.00000002066*np.cos(2.70339714714 + 13119.72110282519*t)
	X0 += 0.00000001866*np.cos(5.59846790440 + 1039.0266107904*t)
	X0 += 0.00000001555*np.cos(0.27389127072 + 10028.9508271002*t)
	X0 += 0.00000001553*np.cos(3.89950445433 + 4193.8088084518*t)
	X0 += 0.00000001870*np.cos(0.58471003638 + 3113.1362939108*t)
	X0 += 0.00000001486*np.cos(3.88620901938 + 2641.3412784722*t)
	X0 += 0.00000001539*np.cos(5.57331447211 + 65.2203710117*t)
	X0 += 0.00000001462*np.cos(5.69888481518 + 12995.2253778368*t)
	X0 += 0.00000001459*np.cos(5.52526727854 + 2679.3794999188*t)
	X0 += 0.00000001763*np.cos(3.34320851468 + 1155.361157407*t)
	X0 += 0.00000001547*np.cos(1.64100920813 + 13355.3361597984*t)
	X0 += 0.00000001463*np.cos(0.27191881986 + 3318.7615973734*t)
	X0 += 0.00000001463*np.cos(2.71025544519 + 3362.4632560262*t)
	X0 += 0.00000001526*np.cos(0.39781988920 + 664.75604513*t)
	X0 += 0.00000001482*np.cos(5.77895037207 + 2604.735913168*t)
	X0 += 0.00000001867*np.cos(3.32733017397 + 13892.1406718938*t)
	X0 += 0.00000001444*np.cos(5.09058625219 + 10018.2468514476*t)
	X0 += 0.00000001862*np.cos(1.31686189323 + 6670.5881880498*t)
	X0 += 0.00000001428*np.cos(6.05145860944 + 9468.267877257*t)
	X0 += 0.00000001647*np.cos(1.18630860116 + 9070.1188738488*t)
	X0 += 0.00000001515*np.cos(4.40841215958 + 4922.5717749828*t)
	X0 += 0.00000001594*np.cos(3.07253021972 + 440.8252848776*t)
	X0 += 0.00000001468*np.cos(2.48598406210 + 2693.601593385*t)
	X0 += 0.00000001434*np.cos(5.73698962451 + 3283.7140517642*t)
	X0 += 0.00000001552*np.cos(0.75522820685 + 9886.772200064*t)
	X0 += 0.00000001430*np.cos(5.52560820233 + 10025.4277087512*t)
	X0 += 0.00000001604*np.cos(3.48106279055 + 699.2711482276*t)
	X0 += 0.00000001403*np.cos(3.52792942238 + 3397.5108016354*t)
	X0 += 0.00000001364*np.cos(1.47739229350 + 942.062061969*t)
	X0 += 0.00000001404*np.cos(3.59395455131 + 19800.9459562248*t)
	X0 += 0.00000001700*np.cos(2.39699907474 + 3568.0885594888*t)
	X0 += 0.00000001599*np.cos(5.02451840238 + 3212.5935833624*t)
	X0 += 0.00000001492*np.cos(3.59400579441 + 6155.057006654*t)
	X0 += 0.00000001556*np.cos(3.38483926358 + 7895.9598727202*t)
	X0 += 0.00000001469*np.cos(2.62524582215 + 1015.6630178842*t)
	X0 += 0.00000001329*np.cos(3.19680445505 + 3347.2960905739*t)
	X0 += 0.00000001329*np.cos(6.06855511718 + 3333.9287628257*t)
	X0 += 0.00000001503*np.cos(0.26778913449 + 3378.7454623376*t)
	X0 += 0.00000001400*np.cos(3.17228930635 + 589.0648270082*t)
	X0 += 0.00000001522*np.cos(4.24247358440 + 3468.6312700372*t)
	X0 += 0.00000001286*np.cos(1.87463796011 + 3152.68727893721*t)
	X0 += 0.00000001273*np.cos(5.67037587711 + 5625.3660415594*t)
	X0 += 0.00000001424*np.cos(1.87964420034 + 17654.7805397496*t)
	X0 += 0.00000001563*np.cos(4.74033234784 + 6674.1786167016*t)
	X0 += 0.00000001455*np.cos(5.62088037785 + 8799.988713778*t)
	X0 += 0.00000001323*np.cos(0.16177637471 + 1190.9238918756*t)
	X0 += 0.00000001259*np.cos(3.26535416990 + 3742.284548457*t)
	X0 += 0.00000001390*np.cos(6.12238564495 + 412.3710968744*t)
	X0 += 0.00000001344*np.cos(5.40745111036 + 4672.6673142406*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001561*np.cos(5.17810613909 + 3450.8187479192*t)
	X0 += 0.00000001683*np.cos(1.97688854890 + 8646.0634802536*t)
	X0 += 0.00000001272*np.cos(6.25718697284 + 6997.6167230562*t)
	X0 += 0.00000001293*np.cos(5.24149879148 + 10124.930054318*t)
	X0 += 0.00000001223*np.cos(5.74782096857 + 11670.2840372968*t)
	X0 += 0.00000001193*np.cos(1.03222295834 + 6685.1061887576*t)
	X0 += 0.00000001312*np.cos(4.28066683487 + 3.9321532631*t)
	X0 += 0.00000001172*np.cos(3.48929365073 + 1485.9801210652*t)
	X0 += 0.00000001175*np.cos(3.46873404944 + 4076.4889402316*t)
	X0 += 0.00000001162*np.cos(4.24715359301 + 2324.9494088156*t)
	X0 += 0.00000001326*np.cos(5.55836614171 + 5835.1420186484*t)
	X0 += 0.00000001344*np.cos(3.54114655197 + 59.3738619136*t)
	X0 += 0.00000001120*np.cos(6.09785937216 + 15.252471185*t)
	X0 += 0.00000001483*np.cos(1.40459440941 + 210.8514148832*t)
	X0 += 0.00000001205*np.cos(4.89787234183 + 6688.2710900976*t)
	X0 += 0.00000001472*np.cos(3.48774945967 + 215.7467759928*t)
	X0 += 0.00000001102*np.cos(3.98443103901 + 6364.832983743*t)
	X0 += 0.00000001171*np.cos(5.20713779345 + 2771.7905526724*t)
	X0 += 0.00000001128*np.cos(4.98003069870 + 6621.850991486*t)
	X0 += 0.00000001111*np.cos(5.02485508851 + 19402.7969528166*t)
	X0 += 0.00000001312*np.cos(5.17135511580 + 3311.18291816379*t)
	X0 += 0.00000001312*np.cos(4.09400445643 + 3370.0419352358*t)
	X0 += 0.00000001148*np.cos(4.63535326098 + 1063.3140834523*t)
	X0 += 0.00000001233*np.cos(3.49018510996 + 66.4874089144*t)
	X0 += 0.00000001398*np.cos(4.37138512888 + 9588.1255422226*t)
	X0 += 0.00000001101*np.cos(5.78990851346 + 3774.3241645766*t)
	X0 += 0.00000001166*np.cos(3.86709010828 + 4885.9664096786*t)
	X0 += 0.00000001229*np.cos(2.53764879683 + 3145.6410422392*t)
	X0 += 0.00000001335*np.cos(5.02147392519 + 4459.3682188026*t)
	X0 += 0.00000001071*np.cos(3.00909064842 + 7255.5696517344*t)
	X0 += 0.00000001183*np.cos(3.15461838319 + 17395.2197347258*t)
	X0 += 0.00000001266*np.cos(5.61560028687 + 6887.4104018368*t)
	X0 += 0.00000001072*np.cos(3.28943407731 + 6148.010769956*t)
	X0 += 0.00000001066*np.cos(5.94379242263 + 1197.9701285736*t)
	X0 += 0.00000001062*np.cos(1.63761668363 + 131.5419616864*t)
	X0 += 0.00000001116*np.cos(6.06452026137 + 5618.3198048614*t)
	X0 += 0.00000001222*np.cos(4.54203439135 + 3184.2117061974*t)
	X0 += 0.00000001186*np.cos(3.10594561435 + 2284.7536148596*t)
	X0 += 0.00000001366*np.cos(5.96542605959 + 225.8292684102*t)
	X0 += 0.00000001116*np.cos(5.86192558592 + 11610.9101753832*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001218*np.cos(3.59655099027 + 10156.9023601348*t)
	X0 += 0.00000001087*np.cos(3.97307934350 + 5642.1982426092*t)
	X0 += 0.00000001053*np.cos(4.99965634200 + 14054.607308026*t)
	X0 += 0.00000001022*np.cos(0.96352485877 + 145.6310438715*t)
	X0 += 0.00000001422*np.cos(2.40975714524 + 152.5321425512*t)
	X0 += 0.00000001029*np.cos(2.87672671885 + 422.6660376129*t)
	X0 += 0.00000001193*np.cos(2.62619989298 + 6677.3435180416*t)
	X0 += 0.00000001102*np.cos(5.26420035459 + 7321.1221397136*t)
	X0 += 0.00000001153*np.cos(5.41879361902 + 6740.5987153132*t)
	X0 += 0.00000001069*np.cos(2.27857059569 + 9389.0535407862*t)
	X0 += 0.00000000990*np.cos(5.95411082482 + 3181.6689089166*t)
	X0 += 0.00000001146*np.cos(4.72384240476 + 3497.0131472022*t)
	X0 += 0.00000000991*np.cos(1.49574201602 + 4140.4335518652*t)
	X0 += 0.00000001269*np.cos(5.19931704623 + 3188.7151456146*t)
	X0 += 0.00000001220*np.cos(5.17708743476 + 6034.2140200848*t)
	X0 += 0.00000000977*np.cos(1.05449261588 + 3361.9480671668*t)
	X0 += 0.00000000977*np.cos(1.92768164917 + 3319.2767862328*t)
	X0 += 0.00000000978*np.cos(1.63172143816 + 11766.2632645146*t)
	X0 += 0.00000001351*np.cos(1.69299027486 + 9945.5712088238*t)
	X0 += 0.00000001167*np.cos(0.99889492369 + 9602.3526362242*t)
	X0 += 0.00000001030*np.cos(4.17831293451 + 12721.572099417*t)
	X0 += 0.00000001020*np.cos(3.68167586259 + 2538.2485042536*t)
	X0 += 0.00000000955*np.cos(0.46765822817 + 309.2783226558*t)
	X0 += 0.00000000979*np.cos(2.33360006154 + 84.3428261229*t)
	X0 += 0.00000001347*np.cos(3.63309297765 + 19513.9835951042*t)
	X0 += 0.00000001240*np.cos(2.54570206463 + 3302.479391062*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000000957*np.cos(0.10887247031 + 6645.1969867222*t)
	X0 += 0.00000001075*np.cos(0.57961253778 + 212.3358875915*t)
	X0 += 0.00000001070*np.cos(4.31120526838 + 214.2623032845*t)
	X0 += 0.00000000943*np.cos(0.62298659929 + 3344.152798701*t)
	X0 += 0.00000000943*np.cos(5.50078031935 + 3337.0720546986*t)
	X0 += 0.00000000929*np.cos(3.64733196616 + 4001.8453534808*t)
	X0 += 0.00000001121*np.cos(0.39414293182 + 9065.5481241288*t)
	X0 += 0.00000001244*np.cos(2.87441597074 + 184.7272873558*t)
	X0 += 0.00000000960*np.cos(4.05565096298 + 3909.4343007272*t)
	X0 += 0.00000000908*np.cos(3.63883407052 + 3326.3853326982*t)
	X0 += 0.00000000956*np.cos(0.18458081832 + 20809.4676246452*t)
	X0 += 0.00000000910*np.cos(5.91297097098 + 931.3630868518*t)
	X0 += 0.00000000943*np.cos(1.24836664366 + 3337.106562003*t)
	X0 += 0.00000000943*np.cos(4.87540027498 + 3344.11829139661*t)
	X0 += 0.00000000938*np.cos(3.56693392724 + 9380.9596727172*t)
	X0 += 0.00000001177*np.cos(3.67253107095 + 2301.58581590939*t)
	X0 += 0.00000000888*np.cos(0.45676454811 + 36.6053653042*t)
	X0 += 0.00000001098*np.cos(2.95983802473 + 137.0330241624*t)
	X0 += 0.00000000886*np.cos(0.02869348414 + 8013.2797409404*t)
	X0 += 0.00000001115*np.cos(4.62962731246 + 16062.1845261168*t)
	X0 += 0.00000000889*np.cos(3.98790631605 + 213.2509113282*t)
	X0 += 0.00000000889*np.cos(0.90251570889 + 213.3472795478*t)
	X0 += 0.00000000867*np.cos(0.71131990196 + 7380.4960016272*t)
	X0 += 0.00000000967*np.cos(4.34960561312 + 11614.4332937322*t)
	X0 += 0.00000000879*np.cos(5.66441531374 + 3354.8395207014*t)
	X0 += 0.00000000878*np.cos(3.61953632544 + 169.580183133*t)
	X0 += 0.00000000856*np.cos(2.38006031197 + 6705.1032911474*t)
	X0 += 0.00000001200*np.cos(5.49938290386 + 2970.9126107594*t)
	X0 += 0.00000001039*np.cos(1.92430461310 + 4936.7988689844*t)
	X0 += 0.00000000966*np.cos(0.43635654362 + 8958.9322315612*t)
	X0 += 0.00000001018*np.cos(1.39692983525 + 2597.6223661672*t)
	X0 += 0.00000000868*np.cos(4.22723847251 + 9947.0556815321*t)
	X0 += 0.00000000888*np.cos(6.02934983569 + 170.6728706192*t)
	X0 += 0.00000000890*np.cos(0.04475975272 + 6747.712262314*t)
	X0 += 0.00000000873*np.cos(0.50718226570 + 2067.9314010726*t)
	X0 += 0.00000000834*np.cos(2.38508120043 + 6680.804777306*t)
	X0 += 0.00000000958*np.cos(3.07864166176 + 2409.249339848*t)
	X0 += 0.00000000814*np.cos(4.96978756082 + 16703.0448798468*t)
	X0 += 0.00000001043*np.cos(4.06756024984 + 3492.509707785*t)
	X0 += 0.00000000814*np.cos(0.71737388513 + 16703.07938715119*t)
	X0 += 0.00000000819*np.cos(0.57163728715 + 529.6427809848*t)
	X0 += 0.00000000819*np.cos(3.76946397274 + 529.7391492044*t)
	X0 += 0.00000000811*np.cos(2.26915207928 + 288.0806940053*t)
	X0 += 0.00000000821*np.cos(1.45532635718 + 3358.4249488178*t)
	X0 += 0.00000000821*np.cos(1.52684790788 + 3322.7999045818*t)
	X0 += 0.00000001006*np.cos(0.32808498663 + 9654.612951137*t)
	X0 += 0.00000000872*np.cos(3.47010951505 + 3232.9489027612*t)
	X0 += 0.00000000890*np.cos(6.08153339531 + 8965.9784682592*t)
	X0 += 0.00000000848*np.cos(5.36530370202 + 11780.4903585162*t)
	X0 += 0.00000001004*np.cos(4.86111370518 + 16335.8378045366*t)
	X0 += 0.00000000792*np.cos(0.96216543926 + 7100.7094972748*t)
	X0 += 0.00000001037*np.cos(4.27554240329 + 527.2432845398*t)
	X0 += 0.00000000779*np.cos(3.28803155951 + 3499.555944483*t)
	X0 += 0.00000001031*np.cos(0.06363683037 + 532.1386456494*t)
	X0 += 0.00000000841*np.cos(5.80835389420 + 3448.2759506384*t)
	X0 += 0.00000000797*np.cos(4.06306935733 + 203.7378678824*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000788*np.cos(6.15064642009 + 14421.8316369884*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000000835*np.cos(4.64636271875 + 3929.677253708*t)
	X0 += 0.00000000799*np.cos(1.71609142624 + 2540.7913015344*t)
	X0 += 0.00000001000*np.cos(1.28921002636 + 1055.4497769261*t)
	X0 += 0.00000000935*np.cos(4.58890893949 + 437.6438911399*t)
	X0 += 0.00000001014*np.cos(5.93632751077 + 8859.3625756916*t)
	X0 += 0.00000001009*np.cos(1.23105531513 + 6657.3464156518*t)
	X0 += 0.00000000734*np.cos(5.35841388096 + 112.9146342051*t)
	X0 += 0.00000001030*np.cos(3.76563035339 + 3710.3122426402*t)
	X0 += 0.00000000787*np.cos(5.30046515807 + 3308.640120883*t)
	X0 += 0.00000000787*np.cos(3.96489441416 + 3372.5847325166*t)
	X0 += 0.00000000725*np.cos(6.20615375090 + 3229.4257844122*t)
	X0 += 0.00000000825*np.cos(5.84109202593 + 3253.30422216*t)
	X0 += 0.00000000740*np.cos(5.37852418407 + 1062.9050485382*t)
	X0 += 0.00000000864*np.cos(3.56004399666 + 6717.252720077*t)
	X0 += 0.00000000729*np.cos(5.39810036362 + 22743.4093795164*t)
	X0 += 0.00000000819*np.cos(3.40537028007 + 802.3639224462*t)
	X0 += 0.00000000694*np.cos(3.05917580830 + 3451.7990689874*t)
	X0 += 0.00000000694*np.cos(2.00903556842 + 628.8515860501*t)
	X0 += 0.00000000692*np.cos(3.93969787894 + 3067.9394693482*t)
	X0 += 0.00000000730*np.cos(2.57787085198 + 6016.4688082696*t)
	X0 += 0.00000000691*np.cos(5.21607448399 + 4356.275444584*t)
	X0 += 0.00000000795*np.cos(3.42431058119 + 3427.9206312396*t)
	X0 += 0.00000000707*np.cos(3.96444184834 + 20597.2439630412*t)
	X0 += 0.00000000729*np.cos(3.83003983643 + 15906.7641266826*t)
	X0 += 0.00000000950*np.cos(2.18428036051 + 20199.094959633*t)
	X0 += 0.00000000723*np.cos(5.49722551141 + 3735.238311759*t)
	X0 += 0.00000000667*np.cos(0.37126610848 + 7270.2896804078*t)
	X0 += 0.00000000854*np.cos(2.68545229893 + 2075.0449480734*t)
	X0 += 0.00000000720*np.cos(5.37203321727 + 3264.3463554242*t)
	X0 += 0.00000000926*np.cos(2.97025862788 + 160.6088973985*t)
	X0 += 0.00000000651*np.cos(6.09020535330 + 17468.8551979454*t)
	X0 += 0.00000000826*np.cos(3.32684274495 + 838.9692877504*t)
	X0 += 0.00000000790*np.cos(3.21398808141 + 10264.5658840734*t)
	X0 += 0.00000000649*np.cos(2.61484086982 + 860.3099287528*t)
	X0 += 0.00000000652*np.cos(3.12935966774 + 3212.6608936652*t)
	X0 += 0.00000000649*np.cos(4.05814434604 + 5938.234792867*t)
	X0 += 0.00000000675*np.cos(5.98880437085 + 15664.03552270859*t)
	X0 += 0.00000000741*np.cos(1.01496778921 + 1073.6090241908*t)
	X0 += 0.00000000659*np.cos(0.49287296501 + 22345.2603761082*t)
	X0 += 0.00000000633*np.cos(3.17232018582 + 17101.2111369072*t)
	X0 += 0.00000000646*np.cos(2.89002668668 + 485.9720527896*t)
	X0 += 0.00000000686*np.cos(4.18019464026 + 1437.1756141986*t)
	X0 += 0.00000000631*np.cos(5.34431180258 + 3329.5667264359*t)
	X0 += 0.00000000631*np.cos(3.92104776965 + 3351.6581269637*t)
	X0 += 0.00000000631*np.cos(0.15035258857 + 3343.1552239806*t)
	X0 += 0.00000000834*np.cos(1.27334165090 + 6681.6449294932*t)
	X0 += 0.00000000853*np.cos(0.52003136040 + 24150.080051345*t)
	X0 += 0.00000000619*np.cos(6.13397500805 + 3468.5639597344*t)
	X0 += 0.00000000779*np.cos(6.20446939192 + 22324.9050567094*t)
	X0 += 0.00000000683*np.cos(6.06333470888 + 3336.6802734367*t)
	X0 += 0.00000000683*np.cos(3.20202486335 + 3344.5445799629*t)
	X0 += 0.00000000613*np.cos(0.62422045381 + 430.5303441391*t)
	X0 += 0.00000000600*np.cos(2.64922528930 + 3338.069629419*t)
	X0 += 0.00000000692*np.cos(2.83117936839 + 9.5612275556*t)
	X0 += 0.00000000621*np.cos(0.40499338312 + 10448.4354709754*t)
	X0 += 0.00000000832*np.cos(2.20242516999 + 380.12776796*t)
	X0 += 0.00000000707*np.cos(0.86804066577 + 1699.2792165032*t)
	X0 += 0.00000000706*np.cos(4.51954003602 + 6717.8302187038*t)
	X0 += 0.00000000616*np.cos(6.01148018963 + 20.3553193988*t)
	X0 += 0.00000000588*np.cos(2.22654252843 + 6357.7194367422*t)
	X0 += 0.00000000628*np.cos(5.60511337877 + 3193.8007401762*t)
	X0 += 0.00000000704*np.cos(2.61366884585 + 3547.3131639964*t)
	X0 += 0.00000000575*np.cos(1.10923040341 + 3528.5375744624*t)
	X0 += 0.00000000602*np.cos(6.12196613719 + 6681.6547365263*t)
	X0 += 0.00000000672*np.cos(1.12165707971 + 6666.997759398*t)
	X0 += 0.00000000691*np.cos(1.16386423121 + 6679.7403806913*t)
	X0 += 0.00000000581*np.cos(2.98813744301 + 5490.300961524*t)
	X0 += 0.00000000644*np.cos(1.94493731078 + 4289.7880356696*t)
	X0 += 0.00000000607*np.cos(4.43563939259 + 18451.07854656599*t)
	X0 += 0.00000000583*np.cos(4.47298961595 + 8226.5788363784*t)
	X0 += 0.00000000726*np.cos(2.91832718034 + 6019.9919266186*t)
	X0 += 0.00000000639*np.cos(3.15793381912 + 12.5301729722*t)
	X0 += 0.00000000587*np.cos(5.01648676427 + 2171.0241752912*t)
	X0 += 0.00000000599*np.cos(0.38463092695 + 423.4167971383*t)
	X0 += 0.00000000610*np.cos(0.51823731379 + 9911.63095888*t)
	X0 += 0.00000000648*np.cos(2.64885452513 + 4133.3873151672*t)
	X0 += 0.00000000648*np.cos(3.43475812975 + 528.7277572481*t)
	X0 += 0.00000000646*np.cos(0.90574398043 + 530.6541729411*t)
	X0 += 0.00000000602*np.cos(4.20897598542 + 2854.6403739102*t)
	X0 += 0.00000000600*np.cos(4.73583940116 + 6724.9437657046*t)
	X0 += 0.00000000606*np.cos(2.45518551356 + 401.6721217572*t)
	X0 += 0.00000000613*np.cos(3.89660700480 + 6549.6828917132*t)
	X0 += 0.00000000536*np.cos(5.25877052470 + 3613.2853840514*t)
	X0 += 0.00000000634*np.cos(4.14005244900 + 6510.5519827804*t)
	X0 += 0.00000000620*np.cos(2.73565451839 + 2149.6885348242*t)
	X0 += 0.00000000554*np.cos(2.33553669625 + 394.6258850592*t)
	X0 += 0.00000000567*np.cos(4.17188733055 + 1685.0521225016*t)
	X0 += 0.00000000602*np.cos(3.81964202131 + 6680.7949702729*t)
	X0 += 0.00000000573*np.cos(3.67929304297 + 1574.8458012822*t)
	X0 += 0.00000000676*np.cos(0.15809413709 + 19004.6479494084*t)
	X0 += 0.00000000702*np.cos(6.04600603759 + 43.718912305*t)
	X0 += 0.00000000522*np.cos(3.84057547649 + 3341.7930693519*t)
	X0 += 0.00000000522*np.cos(5.42478409574 + 3339.4317840477*t)
	X0 += 0.00000000533*np.cos(5.24914312775 + 4039.8835749274*t)
	X0 += 0.00000000538*np.cos(6.04102038970 + 127.4717966068*t)
	X0 += 0.00000000553*np.cos(3.69265541501 + 3487.4241132234*t)
	X0 += 0.00000000715*np.cos(1.53240537508 + 4503.0871311076*t)
	X0 += 0.00000000509*np.cos(2.23251368203 + 8116.372515159*t)
	X0 += 0.00000000672*np.cos(3.08200615608 + 221.3758502853*t)
	X0 += 0.00000000511*np.cos(2.84475025859 + 16489.763038061*t)
	X0 += 0.00000000566*np.cos(2.70414246898 + 728.762966531*t)
	X0 += 0.00000000543*np.cos(4.52630986182 + 1596.1191319818*t)
	X0 += 0.00000000640*np.cos(5.62224402692 + 1641.3332101966*t)
	X0 += 0.00000000637*np.cos(0.43174002743 + 3133.9116894032*t)
	X0 += 0.00000000490*np.cos(2.97472409276 + 71.6002048296*t)
	X0 += 0.00000000500*np.cos(5.72569791561 + 11250.7993934216*t)
	X0 += 0.00000000639*np.cos(2.24611646652 + 3116.2676309979*t)
	X0 += 0.00000000509*np.cos(5.97801633911 + 6812.766815086*t)
	X0 += 0.00000000489*np.cos(3.06702523150 + 13575.7488022372*t)
	X0 += 0.00000000535*np.cos(4.96839537782 + 9072.6616711296*t)
	X0 += 0.00000000536*np.cos(0.22943192463 + 3198.4337996636*t)
	X0 += 0.00000000619*np.cos(4.96805088979 + 13207.029307365*t)
	X0 += 0.00000000476*np.cos(0.22242794163 + 6850.8050365326*t)
	X0 += 0.00000000475*np.cos(5.62964593507 + 12323.4230960088*t)
	X0 += 0.00000000527*np.cos(6.00961327639 + 3289.33208883739*t)
	X0 += 0.00000000527*np.cos(3.25574629584 + 3391.89276456221*t)
	X0 += 0.00000000491*np.cos(1.41447645810 + 3288.352111787*t)
	X0 += 0.00000000491*np.cos(1.56769780695 + 3392.8727416126*t)
	X0 += 0.00000000649*np.cos(1.32346646305 + 22.0914005278*t)
	X0 += 0.00000000471*np.cos(4.83320292258 + 77.962992305*t)
	X0 += 0.00000000633*np.cos(2.67463316712 + 5085.038411115*t)
	X0 += 0.00000000623*np.cos(2.85969660852 + 330.6189636582*t)
	X0 += 0.00000000467*np.cos(3.47228897303 + 5749.8617665478*t)
	X0 += 0.00000000473*np.cos(3.22546086486 + 4296.9015826704*t)
	X0 += 0.00000000489*np.cos(2.81861982191 + 23.8784377478*t)
	X0 += 0.00000000652*np.cos(2.72637797985 + 388.4651552382*t)
	X0 += 0.00000000483*np.cos(5.34340560368 + 3346.6783423296*t)
	X0 += 0.00000000483*np.cos(3.92195396855 + 3334.54651107*t)
	X0 += 0.00000000460*np.cos(1.30162811155 + 2281.2477501628*t)
	X0 += 0.00000000460*np.cos(5.55404178724 + 2281.2132428584*t)
	X0 += 0.00000000604*np.cos(0.33192898022 + 2373.6415492642*t)
	X0 += 0.00000000500*np.cos(5.13403373442 + 3.5904286518*t)
	X0 += 0.00000000456*np.cos(4.28478904313 + 8962.4726035624*t)
	X0 += 0.00000000456*np.cos(2.25401741164 + 8962.438096258*t)
	X0 += 0.00000000468*np.cos(2.07609656896 + 227.476132789*t)
	X0 += 0.00000000456*np.cos(5.37224883784 + 11140.5930722022*t)
	X0 += 0.00000000506*np.cos(2.75253411801 + 3482.791053736*t)
	X0 += 0.00000000453*np.cos(3.59225016346 + 2957.7331481288*t)
	X0 += 0.00000000633*np.cos(0.33861758809 + 2963.238818784*t)
	X0 += 0.00000000502*np.cos(4.62394688433 + 5562.4690612968*t)
	X0 += 0.00000000574*np.cos(5.66932742997 + 87.3117715395*t)
	X0 += 0.00000000604*np.cos(4.34031313242 + 3370.1042450032*t)
	X0 += 0.00000000604*np.cos(4.92504643981 + 3311.1206083964*t)
	X0 += 0.00000000501*np.cos(3.19333781608 + 2973.3880977374*t)
	X0 += 0.00000000448*np.cos(4.97947122194 + 13361.469385731*t)
	X0 += 0.00000000500*np.cos(2.53823457541 + 4819.4790007642*t)
	X0 += 0.00000000517*np.cos(0.40478673929 + 3535.5838111604*t)
	X0 += 0.00000000440*np.cos(4.69261655966 + 3564.9572224017*t)
	X0 += 0.00000000605*np.cos(1.98317483331 + 984.6003316219*t)
	X0 += 0.00000000541*np.cos(3.08246188636 + 72.3339180125*t)
	X0 += 0.00000000481*np.cos(6.20073949182 + 2494.5295919486*t)
	X0 += 0.00000000468*np.cos(3.63933137782 + 1854.6323056346*t)
	X0 += 0.00000000477*np.cos(5.99645045824 + 4379.6390374902*t)
	X0 += 0.00000000468*np.cos(5.32421286728 + 4186.695261451*t)
	X0 += 0.00000000430*np.cos(1.74068392340 + 4716.3862265456*t)
	X0 += 0.00000000486*np.cos(3.22416128411 + 382.879278571*t)
	X0 += 0.00000000486*np.cos(6.15985349823 + 3017.1070100424*t)
	X0 += 0.00000000473*np.cos(1.58270299229 + 2295.4575905122*t)
	X0 += 0.00000000561*np.cos(0.07727661747 + 4271.9755135516*t)
	X0 += 0.00000000467*np.cos(5.34128135139 + 212.7778305762*t)
	X0 += 0.00000000466*np.cos(5.83324087524 + 213.8203602998*t)
	X0 += 0.00000000438*np.cos(5.08540730003 + 1368.660252845*t)
	X0 += 0.00000000423*np.cos(3.86495066196 + 7366.2689076256*t)
	X0 += 0.00000000456*np.cos(3.39763687697 + 10006.5848089144*t)
	X0 += 0.00000000539*np.cos(2.16593861972 + 3185.2593375684*t)
	X0 += 0.00000000420*np.cos(3.46957754355 + 5753.3848848968*t)
	X0 += 0.00000000418*np.cos(2.75937640828 + 429.7795846137*t)
	X0 += 0.00000000558*np.cos(5.31907263521 + 4555.3474460204*t)
	X0 += 0.00000000546*np.cos(4.81957800358 + 6637.5059410946*t)
	X0 += 0.00000000412*np.cos(3.44279945540 + 2480.302497947*t)
	X0 += 0.00000000433*np.cos(4.06813058765 + 3376.1751611684*t)
	X0 += 0.00000000433*np.cos(5.19722898458 + 3305.0496922312*t)
	X0 += 0.00000000423*np.cos(0.94668022805 + 10037.0897512844*t)
	X0 += 0.00000000481*np.cos(1.03096497224 + 6685.1570066627*t)
	X0 += 0.00000000422*np.cos(5.46293451808 + 9374.8264467846*t)
	X0 += 0.00000000402*np.cos(1.79269566106 + 6151.5511419572*t)
	X0 += 0.00000000402*np.cos(6.04510933675 + 6151.5166346528*t)
	X0 += 0.00000000423*np.cos(3.58342380203 + 5483.254724826*t)
	X0 += 0.00000000403*np.cos(5.64429159047 + 3723.4917052708*t)
	X0 += 0.00000000430*np.cos(1.85452102379 + 2655.5683724738*t)
	X0 += 0.00000000398*np.cos(4.95155912622 + 15806.146839442*t)
	X0 += 0.00000000481*np.cos(5.12886978063 + 9797.4924843975*t)
	X0 += 0.00000000477*np.cos(3.72133708668 + 6614.7374444852*t)
	X0 += 0.00000000398*np.cos(5.88751420420 + 23539.7073863328*t)
	X0 += 0.00000000487*np.cos(2.28517115642 + 1655.5603041982*t)
	X0 += 0.00000000555*np.cos(2.64204069171 + 3717.9860346156*t)
	X0 += 0.00000000425*np.cos(5.57148739497 + 7218.029365495*t)
	X0 += 0.00000000391*np.cos(3.40113572996 + 2142.6422981262*t)
	X0 += 0.00000000486*np.cos(4.84700116898 + 10050.2864675672*t)
	X0 += 0.00000000387*np.cos(2.86599014807 + 18849.2275499742*t)
	X0 += 0.00000000412*np.cos(0.16244075037 + 2547.8375382324*t)
	X0 += 0.00000000398*np.cos(4.39213965028 + 21265.5231265202*t)
	X0 += 0.00000000404*np.cos(5.22642617943 + 6644.6194880954*t)
	X0 += 0.00000000414*np.cos(2.26881914667 + 7747.7203305896*t)
	X0 += 0.00000000498*np.cos(5.67868360175 + 12509.2533250472*t)
	X0 += 0.00000000378*np.cos(2.64779087849 + 9801.4246376606*t)
	X0 += 0.00000000511*np.cos(4.91405448075 + 77.2292791221*t)
	X0 += 0.00000000427*np.cos(5.92154870681 + 905.4566966648*t)
	X0 += 0.00000000437*np.cos(1.90267249585 + 5881.4037282342*t)
	X0 += 0.00000000368*np.cos(1.75512352528 + 912.5702436656*t)
	X0 += 0.00000000520*np.cos(0.92503823923 + 3495.9655158312*t)
	X0 += 0.00000000441*np.cos(1.82874447797 + 2277.2983432475*t)
	X0 += 0.00000000367*np.cos(5.98732751616 + 8564.306346502*t)
	X0 += 0.00000000384*np.cos(0.64251152112 + 340.7708920448*t)
	X0 += 0.00000000388*np.cos(1.53417071545 + 18606.4989460002*t)
	X0 += 0.00000000436*np.cos(5.31667755006 + 1903.4368125012*t)
	X0 += 0.00000000398*np.cos(5.06921695985 + 3826.5844794894*t)
	X0 += 0.00000000363*np.cos(1.41903182152 + 5888.4499649322*t)
	X0 += 0.00000000441*np.cos(5.31541881274 + 4142.976349146*t)
	X0 += 0.00000000429*np.cos(5.04278490313 + 2285.1626497737*t)
	X0 += 0.00000000502*np.cos(2.89985394281 + 1765.7666254176*t)
	X0 += 0.00000000415*np.cos(4.78022286670 + 0.9803210682*t)
	X0 += 0.00000000374*np.cos(2.30167430662 + 25287.7237993998*t)
	X0 += 0.00000000359*np.cos(5.01487522235 + 5085.1057214178*t)
	X0 += 0.00000000477*np.cos(4.55805347389 + 1329.51209026*t)
	X0 += 0.00000000470*np.cos(5.45120104784 + 21795.21409161479*t)
	X0 += 0.00000000372*np.cos(1.43435867925 + 6314.0005244372*t)
	X0 += 0.00000000351*np.cos(5.70642746558 + 6851.8977240188*t)
	X0 += 0.00000000346*np.cos(3.46248777629 + 20735.83216142559*t)
	X0 += 0.00000000452*np.cos(2.07880491518 + 6106.8800550648*t)
	X0 += 0.00000000344*np.cos(0.65068647382 + 16894.5103996106*t)
	X0 += 0.00000000432*np.cos(6.00026910363 + 10721.108428327*t)
	X0 += 0.00000000364*np.cos(2.28651674734 + 6682.7093261079*t)
	X0 += 0.00000000363*np.cos(3.43072832179 + 27682.1407441564*t)
	X0 += 0.00000000343*np.cos(1.42188954644 + 2435.155730035*t)
	X0 += 0.00000000452*np.cos(2.64364626735 + 4307.5833041354*t)
	X0 += 0.00000000457*np.cos(1.95175594362 + 21947.11137270*t)
	X0 += 0.00000000354*np.cos(2.54868316520 + 62.2514255951*t)
	X0 += 0.00000000346*np.cos(5.34426955778 + 18052.9295431578*t)
	X0 += 0.00000000395*np.cos(3.93999186550 + 52.6901980395*t)
	X0 += 0.00000000351*np.cos(4.37551100665 + 5452.2627400774*t)
	X0 += 0.00000000468*np.cos(5.41577295140 + 5244.049239201*t)
	X0 += 0.00000000386*np.cos(1.07126796902 + 5511.636601991*t)
	X0 += 0.00000000344*np.cos(3.95436427366 + 5636.070017212*t)
	X0 += 0.00000000434*np.cos(1.89640980600 + 7214.4389368432*t)
	X0 += 0.00000000333*np.cos(3.01713296302 + 1883.0814931024*t)
	X0 += 0.00000000395*np.cos(5.73856202838 + 9993.3880926316*t)
	X0 += 0.00000000406*np.cos(2.27584736071 + 350.3321196004*t)
	X0 += 0.00000000351*np.cos(1.69786249501 + 13212.8865096646*t)
	X0 += 0.00000000331*np.cos(0.85002011574 + 25685.872802808*t)
	X0 += 0.00000000327*np.cos(5.61960069444 + 3353.85419909779*t)
	X0 += 0.00000000327*np.cos(3.64575887779 + 3327.3706543018*t)
	X0 += 0.00000000422*np.cos(3.91288097624 + 23141.5583829246*t)
	X0 += 0.00000000396*np.cos(1.99989177453 + 145.1097790097*t)
	X0 += 0.00000000447*np.cos(0.03231232062 + 13363.4300278674*t)
	X0 += 0.00000000389*np.cos(2.62527245368 + 30065.5118402982*t)
	X0 += 0.00000000360*np.cos(5.62003938434 + 7696.8878712838*t)
	X0 += 0.00000000395*np.cos(3.32438313830 + 3337.1566186536*t)
	X0 += 0.00000000385*np.cos(6.13244198192 + 909.8187330546*t)
	X0 += 0.00000000338*np.cos(6.08218637594 + 14556.8967170238*t)
	X0 += 0.00000000344*np.cos(6.13564952381 + 146.8116865236*t)
	X0 += 0.00000000408*np.cos(1.39299721966 + 11883.5831327348*t)
	X0 += 0.00000000366*np.cos(5.24290558594 + 8982.810669309*t)
	X0 += 0.00000000384*np.cos(5.87249757638 + 7733.493236588*t)
	X0 += 0.00000000352*np.cos(5.77288434437 + 14128.2427712456*t)
	X0 += 0.00000000335*np.cos(4.32457058810 + 3060.8259223474*t)
	X0 += 0.00000000388*np.cos(4.44896509079 + 568.8218740274*t)
	X0 += 0.00000000316*np.cos(0.87910526351 + 3440.1820825694*t)
	X0 += 0.00000000316*np.cos(2.10306900154 + 3241.0427708302*t)
	X0 += 0.00000000355*np.cos(1.45980558865 + 7322.1024607818*t)
	X0 += 0.00000000354*np.cos(2.21314787069 + 4606.1799053262*t)
	X0 += 0.00000000311*np.cos(2.88232671968 + 36.0278666774*t)
	X0 += 0.00000000310*np.cos(0.93049157656 + 6453.7487206106*t)
	X0 += 0.00000000309*np.cos(5.01156668552 + 1744.493294718*t)
	X0 += 0.00000000300*np.cos(3.78833306333 + 1987.221898692*t)
	X0 += 0.00000000313*np.cos(3.62090724113 + 234.6397364404*t)
	X0 += 0.00000000299*np.cos(5.63008167210 + 10284.9212034722*t)
	X0 += 0.00000000382*np.cos(1.81523910449 + 186.2117600641*t)
	X0 += 0.00000000380*np.cos(3.85628097313 + 1461.0540519464*t)
	X0 += 0.00000000294*np.cos(3.49253072198 + 20040.15144184979*t)
	X0 += 0.00000000313*np.cos(2.87459690276 + 6286.5989683404*t)
	X0 += 0.00000000296*np.cos(1.12829662810 + 15265.8865193004*t)
	X0 += 0.00000000307*np.cos(1.51056904066 + 9755.2302383776*t)
	X0 += 0.00000000306*np.cos(6.04593408110 + 8756.269801473*t)
	X0 += 0.00000000393*np.cos(3.05426132167 + 19645.5255567906*t)
	X0 += 0.00000000292*np.cos(0.99823300732 + 20618.0193585336*t)
	X0 += 0.00000000307*np.cos(2.44116831682 + 1471.7530270636*t)
	X0 += 0.00000000328*np.cos(5.65545524347 + 3283.80916453*t)
	X0 += 0.00000000328*np.cos(3.60990432876 + 3397.4156888696*t)
	X0 += 0.00000000349*np.cos(2.66323218421 + 5408.5438277724*t)
	X0 += 0.00000000400*np.cos(1.38752434540 + 454.9093665273*t)
	X0 += 0.00000000360*np.cos(6.18194085240 + 685.044054226*t)
	X0 += 0.00000000289*np.cos(3.03452497225 + 24341.5283174566*t)
	X0 += 0.00000000291*np.cos(2.47822451317 + 11986.6759069534*t)
	X0 += 0.00000000314*np.cos(4.21854332735 + 9983.7042444616*t)
	X0 += 0.00000000372*np.cos(4.82853244691 + 3.1813937377*t)
	X0 += 0.00000000339*np.cos(1.83011385698 + 3856.0762977928*t)
	X0 += 0.00000000339*np.cos(1.15206040807 + 2825.1485556068*t)
	X0 += 0.00000000383*np.cos(4.85732660755 + 2921.6880277992*t)
	X0 += 0.00000000311*np.cos(5.32153691075 + 2060.8178540718*t)
	X0 += 0.00000000302*np.cos(0.20821199425 + 12825.6451947038*t)
	X0 += 0.00000000286*np.cos(2.52935183562 + 279.7865043524*t)
	X0 += 0.00000000382*np.cos(2.75070755631 + 3267.3153008408*t)
	X0 += 0.00000000382*np.cos(0.23146670874 + 3413.9095525588*t)
	X0 += 0.00000000304*np.cos(4.94290577295 + 3620.3989310522*t)
	X0 += 0.00000000279*np.cos(6.01035218252 + 7167.1969061892*t)
	X0 += 0.00000000331*np.cos(5.02435559950 + 16063.164847185*t)
	X0 += 0.00000000329*np.cos(3.13549589139 + 10706.8813343254*t)
	X0 += 0.00000000283*np.cos(2.78335440325 + 12839.8722887054*t)
	X0 += 0.00000000282*np.cos(2.30154816582 + 596.178374009*t)
	X0 += 0.00000000283*np.cos(6.10276906215 + 9859.3706439672*t)
	X0 += 0.00000000304*np.cos(3.83786604384 + 5621.8601768626*t)
	X0 += 0.00000000308*np.cos(2.68902321898 + 362.8622925726*t)
	X0 += 0.00000000280*np.cos(1.99086077526 + 16511.6138673874*t)
	X0 += 0.00000000335*np.cos(0.71030115582 + 200.7689224658*t)
	X0 += 0.00000000311*np.cos(4.44573637765 + 297.6419215609*t)
	X0 += 0.00000000264*np.cos(4.18346044185 + 2938.9403049426*t)
	X0 += 0.00000000289*np.cos(1.92464337356 + 529.1697002328*t)
	X0 += 0.00000000366*np.cos(2.92406939426 + 604.4725636619*t)
	X0 += 0.00000000288*np.cos(2.41719522186 + 530.2122299564*t)
	X0 += 0.00000000325*np.cos(5.09647854302 + 2267.003402509*t)
	X0 += 0.00000000314*np.cos(1.84357518690 + 108.4612160802*t)
	X0 += 0.00000000262*np.cos(4.93101522736 + 3936.7908007088*t)
	X0 += 0.00000000269*np.cos(4.46038699829 + 2744.4340526908*t)
	X0 += 0.00000000258*np.cos(4.05781923499 + 5195.2447323344*t)
	X0 += 0.00000000261*np.cos(1.51463312703 + 1279.794572628*t)
	X0 += 0.00000000262*np.cos(4.15566435137 + 1258.4539316256*t)
	X0 += 0.00000000304*np.cos(1.80709441235 + 5621.8256695582*t)
	X0 += 0.00000000271*np.cos(5.41787864949 + 3336.0416769798*t)
	X0 += 0.00000000271*np.cos(3.84748092274 + 3345.1831764198*t)
	X0 += 0.00000000251*np.cos(3.72595297988 + 3337.5093844444*t)
	X0 += 0.00000000251*np.cos(5.53940659235 + 3343.7154689552*t)
	X0 += 0.00000000251*np.cos(4.94262467913 + 9758.7533567266*t)
	X0 += 0.00000000255*np.cos(1.40204343749 + 8166.1573430938*t)
	X0 += 0.00000000305*np.cos(2.93351381201 + 12012.5822971404*t)
	X0 += 0.00000000267*np.cos(2.53115640127 + 6830.7880505342*t)
	X0 += 0.00000000290*np.cos(2.87280676776 + 20047.1976785478*t)
	X0 += 0.00000000268*np.cos(3.04782864984 + 16702.9948231962*t)
	X0 += 0.00000000250*np.cos(2.52509673305 + 9698.331863442*t)
	X0 += 0.00000000250*np.cos(1.90792798203 + 206.7007372966*t)
	X0 += 0.00000000325*np.cos(5.19161338170 + 5223.6939198022*t)
	X0 += 0.00000000246*np.cos(5.47040036393 + 15650.7937503106*t)
	X0 += 0.00000000247*np.cos(1.02711909982 + 10016.314355792*t)
	X0 += 0.00000000274*np.cos(1.54026728979 + 565.1156877467*t)
	X0 += 0.00000000256*np.cos(3.14761311872 + 1727.6610936682*t)
	X0 += 0.00000000268*np.cos(0.19545433539 + 140.001969579*t)
	X0 += 0.00000000276*np.cos(0.25330294459 + 6670.1791531357*t)
	X0 += 0.00000000320*np.cos(0.32229958420 + 703.6331846174*t)
	X0 += 0.00000000321*np.cos(0.33443990553 + 11904.9187732018*t)
	X0 += 0.00000000243*np.cos(0.44342371962 + 1062.5633239269*t)
	X0 += 0.00000000248*np.cos(0.09445957496 + 210.3783341312*t)
	X0 += 0.00000000248*np.cos(4.79327801971 + 216.2198567448*t)
	X0 += 0.00000000239*np.cos(5.48924135437 + 4694.0029547076*t)
	X0 += 0.00000000323*np.cos(0.19078991314 + 17085.9586657222*t)
	X0 += 0.00000000241*np.cos(3.24545153339 + 37.611770776*t)
	X0 += 0.00000000250*np.cos(4.16248987175 + 1250.8301963008*t)
	X0 += 0.00000000255*np.cos(4.90697050745 + 153.4953503977*t)
	X0 += 0.00000000258*np.cos(4.26017972975 + 9488.6231966558*t)
	X0 += 0.00000000248*np.cos(5.11028885968 + 5430.3946570988*t)
	X0 += 0.00000000269*np.cos(3.40949811009 + 3866.7802734454*t)
	X0 += 0.00000000248*np.cos(3.35507631239 + 21548.9623692918*t)
	X0 += 0.00000000237*np.cos(3.72326482255 + 212.5483359126*t)
	X0 += 0.00000000265*np.cos(4.47706550812 + 3053.6500655792*t)
	X0 += 0.00000000240*np.cos(3.30477326315 + 10027.3602044068*t)
	X0 += 0.00000000252*np.cos(0.39861936276 + 1442.2612087602*t)
	X0 += 0.00000000321*np.cos(4.39948566918 + 3759.5368256004*t)
	X0 += 0.00000000319*np.cos(5.16188908240 + 9815.6517316622*t)
	X0 += 0.00000000251*np.cos(5.09258201655 + 4996.172730898*t)
	X0 += 0.00000000251*np.cos(0.30797289315 + 2790.5661422064*t)
	X0 += 0.00000000236*np.cos(1.16575065097 + 214.0498549634*t)
	X0 += 0.00000000326*np.cos(5.77584210418 + 3707.8367556622*t)
	X0 += 0.00000000236*np.cos(4.23871934676 + 38.6543004996*t)
	X0 += 0.00000000234*np.cos(3.19518041867 + 5.5229243074*t)
	X0 += 0.00000000252*np.cos(4.61065643475 + 209.106309744*t)
	X0 += 0.00000000311*np.cos(1.28359118800 + 3391.4448860056*t)
	X0 += 0.00000000311*np.cos(1.69858307705 + 3289.779967394*t)
	X0 += 0.00000000230*np.cos(3.19673604492 + 10654.6210194126*t)
	X0 += 0.00000000292*np.cos(0.94159319004 + 3050.1269472302*t)
	X0 += 0.00000000235*np.cos(3.67396491403 + 5945.3483398678*t)
	X0 += 0.00000000301*np.cos(3.92363660385 + 9495.6694333538*t)
	X0 += 0.00000000238*np.cos(3.24637215696 + 6566.8257464862*t)
	X0 += 0.00000000247*np.cos(0.27272991614 + 217.491881132*t)
	X0 += 0.00000000226*np.cos(4.13525718252 + 1868.8593996362*t)
	X0 += 0.00000000226*np.cos(1.47633059250 + 26482.1708096244*t)
	X0 += 0.00000000225*np.cos(3.38119852586 + 223.5940361765*t)
	X0 += 0.00000000225*np.cos(3.08572061461 + 8749.1562544722*t)
	X0 += 0.00000000312*np.cos(5.79379290810 + 4403.517475238*t)
	X0 += 0.00000000224*np.cos(5.51904045547 + 38.084851528*t)
	X0 += 0.00000000248*np.cos(0.28758278932 + 4025.6564809258*t)
	X0 += 0.00000000223*np.cos(1.96313876697 + 38.1812197476*t)
	X0 += 0.00000000222*np.cos(2.77571943902 + 1835.3246176068*t)
	X0 += 0.00000000289*np.cos(2.22892326730 + 6901.6374958384*t)
	X0 += 0.00000000244*np.cos(3.78617592414 + 5349.1699658588*t)
	X0 += 0.00000000268*np.cos(2.63933226300 + 16703.1294438018*t)
	X0 += 0.00000000221*np.cos(0.14023240804 + 5820.9149246468*t)
	X0 += 0.00000000220*np.cos(4.31591174490 + 6511.6446702666*t)
	X0 += 0.00000000221*np.cos(2.65317035374 + 28628.3362260996*t)
	X0 += 0.00000000224*np.cos(1.51015445842 + 3542.8658218739*t)
	X0 += 0.00000000224*np.cos(1.47201980663 + 3138.3590315257*t)
	X0 += 0.00000000234*np.cos(1.63110110036 + 17499.3601403154*t)
	X0 += 0.00000000233*np.cos(1.29817926717 + 2814.4445799542*t)
	X0 += 0.00000000229*np.cos(3.43841964101 + 7586.6815500644*t)
	X0 += 0.00000000218*np.cos(1.17569842797 + 6283.0931036436*t)
	X0 += 0.00000000218*np.cos(5.42811210366 + 6283.0585963392*t)
	X0 += 0.00000000220*np.cos(4.76795289662 + 3987.6232600146*t)
	X0 += 0.00000000250*np.cos(0.35926935365 + 4569.574540022*t)
	X0 += 0.00000000245*np.cos(4.21060733239 + 173.9422195228*t)
	X0 += 0.00000000276*np.cos(4.17681654313 + 19146.7592661418*t)
	X0 += 0.00000000290*np.cos(3.77728541747 + 24889.5747959916*t)
	X0 += 0.00000000215*np.cos(0.44293995073 + 13383.2251022916*t)
	X0 += 0.00000000226*np.cos(4.11036906370 + 9278.8472195668*t)
	X0 += 0.00000000220*np.cos(0.55898410417 + 1802.3719907218*t)
	X0 += 0.00000000216*np.cos(4.73186620361 + 1484.9324896942*t)
	X0 += 0.00000000266*np.cos(5.48398122109 + 16865.5287696312*t)
	X0 += 0.00000000220*np.cos(6.16562235845 + 10081.211142013*t)
	X0 += 0.00000000211*np.cos(0.32806954610 + 12199.9750023914*t)
	X0 += 0.00000000212*np.cos(1.71640241592 + 2392.4171387982*t)
	X0 += 0.00000000213*np.cos(1.85863025152 + 8852.2490286908*t)
	X0 += 0.00000000234*np.cos(0.55106604784 + 74.2603337055*t)
	X0 += 0.00000000233*np.cos(0.98887023825 + 75.3028634291*t)
	X0 += 0.00000000237*np.cos(4.78828856124 + 3627.57478782039*t)
	X0 += 0.00000000220*np.cos(2.11900337312 + 6530.1771835567*t)
	X0 += 0.00000000271*np.cos(5.46357121828 + 1879.5583747534*t)
	X0 += 0.00000000249*np.cos(4.15415677649 + 3084.6420503278*t)
	X0 += 0.00000000263*np.cos(0.61040728538 + 4531.5363185754*t)
	X0 += 0.00000000252*np.cos(4.61076732703 + 3382.1632176846*t)
	X0 += 0.00000000252*np.cos(4.65459224520 + 3299.061635715*t)
	X0 += 0.00000000239*np.cos(3.20969165945 + 3344.068234746*t)
	X0 += 0.00000000245*np.cos(0.72828250886 + 5415.6573747732*t)
	X0 += 0.00000000262*np.cos(2.04018754229 + 3631.0979061694*t)
	X0 += 0.00000000206*np.cos(3.37175065629 + 7082.8969751568*t)
	X0 += 0.00000000210*np.cos(1.09820249005 + 6678.4733427886*t)
	X0 += 0.00000000255*np.cos(3.12461702046 + 1994.26813539*t)
	X0 += 0.00000000274*np.cos(0.08218879095 + 12306.590894959*t)
	X0 += 0.00000000223*np.cos(4.70596581354 + 3336.25039031*t)
	X0 += 0.00000000223*np.cos(4.55939375869 + 3344.9744630896*t)
	X0 += 0.00000000255*np.cos(0.57687651969 + 2942.4806769438*t)
	X0 += 0.00000000224*np.cos(3.09499220473 + 6533.1461289733*t)
	X0 += 0.00000000247*np.cos(0.56642494969 + 252.6559713532*t)
	X0 += 0.00000000204*np.cos(2.43235400749 + 15636.566656309*t)
	X0 += 0.00000000277*np.cos(5.82784264481 + 12465.5344127422*t)
	X0 += 0.00000000204*np.cos(0.84533704687 + 18.1592472647*t)
	X0 += 0.00000000201*np.cos(0.64407263170 + 9360.6043533184*t)
	X0 += 0.00000000282*np.cos(1.41766310537 + 563.6312150384*t)
	X0 += 0.00000000200*np.cos(4.36647250597 + 5617.9107699473*t)
	X0 += 0.00000000199*np.cos(4.83225730856 + 3029.7716278314*t)
	X0 += 0.00000000243*np.cos(5.80727046187 + 9329.6796788726*t)
	X0 += 0.00000000210*np.cos(4.11232561432 + 28230.18722269139*t)
	X0 += 0.00000000209*np.cos(0.61702908361 + 4845.9002357928*t)
	X0 += 0.00000000197*np.cos(2.72488864890 + 3436.5916539176*t)
	X0 += 0.00000000197*np.cos(0.25728561615 + 3244.633199482*t)
	X0 += 0.00000000244*np.cos(2.15306679937 + 4981.9456368964*t)
	X0 += 0.00000000200*np.cos(1.77158830078 + 8742.0427074714*t)
	X0 += 0.00000000207*np.cos(5.75479453376 + 142.4496501338*t)
	X0 += 0.00000000226*np.cos(4.97789108625 + 2428.0421830342*t)
	X0 += 0.00000000231*np.cos(4.21063730317 + 6653.8232973028*t)
	X0 += 0.00000000213*np.cos(1.25314316353 + 5625.7750764735*t)
	X0 += 0.00000000204*np.cos(0.27721513871 + 417.0369633204*t)
	X0 += 0.00000000198*np.cos(5.49218659041 + 3094.36070437679*t)
	X0 += 0.00000000195*np.cos(4.23402090499 + 66.70484372*t)
	X0 += 0.00000000223*np.cos(4.58369899094 + 13341.6743113068*t)
	X0 += 0.00000000211*np.cos(5.13588313603 + 37.1698277913*t)
	X0 += 0.00000000200*np.cos(1.29969484450 + 194.9713844606*t)
	X0 += 0.00000000191*np.cos(0.79284041095 + 3752.9835235742*t)
	X0 += 0.00000000191*np.cos(2.18933385410 + 2928.2413298254*t)
	X0 += 0.00000000236*np.cos(4.40014218317 + 151.8972810852*t)
	X0 += 0.00000000212*np.cos(0.12583581747 + 4538.5825552734*t)
	X0 += 0.00000000192*np.cos(3.57878803630 + 3315.7536678838*t)
	X0 += 0.00000000192*np.cos(5.68657153593 + 3365.4711855158*t)
	X0 += 0.00000000226*np.cos(5.11122130646 + 3596.5828030718*t)
	X0 += 0.00000000231*np.cos(4.57994360527 + 2011.1003364398*t)
	X0 += 0.00000000220*np.cos(5.61438064276 + 367.2243289624*t)
	X0 += 0.00000000189*np.cos(2.94640552324 + 18208.349942592*t)
	X0 += 0.00000000255*np.cos(4.82929019537 + 2942.4461696394*t)
	X0 += 0.00000000191*np.cos(2.45356219299 + 10544.4146981932*t)
	X0 += 0.00000000227*np.cos(5.15751336106 + 207.8824694666*t)
	X0 += 0.00000000205*np.cos(2.24870894157 + 1059.364676537*t)
	X0 += 0.00000000251*np.cos(2.00699090318 + 11236.57229942*t)
	X0 += 0.00000000203*np.cos(2.35104519506 + 39.0962434843*t)
	X0 += 0.00000000242*np.cos(3.32140683721 + 23958.6317852334*t)
	X0 += 0.00000000202*np.cos(4.05217682796 + 207.6700211455*t)
	X0 += 0.00000000200*np.cos(2.06264335128 + 2735.762685995*t)
	X0 += 0.00000000188*np.cos(1.76018994600 + 3363.3809233092*t)
	X0 += 0.00000000188*np.cos(1.22198431905 + 3317.8439300904*t)
	X0 += 0.00000000204*np.cos(5.63575473469 + 5106.3790521174*t)
	X0 += 0.00000000231*np.cos(4.09195306459 + 9093.9973115966*t)
	X0 += 0.00000000184*np.cos(0.25169651319 + 11353.8921676402*t)
	X0 += 0.00000000182*np.cos(2.90199742784 + 5960.0856221934*t)
	X0 += 0.00000000247*np.cos(3.75287740090 + 31022.7531708562*t)
	X0 += 0.00000000219*np.cos(6.03807342488 + 218.7157214094*t)
	X0 += 0.00000000199*np.cos(2.62229622602 + 3890.65871119319*t)
	X0 += 0.00000000182*np.cos(3.22719623115 + 1382.8873468466*t)
	X0 += 0.00000000206*np.cos(5.35930784504 + 88.865680217*t)
	X0 += 0.00000000193*np.cos(4.00281238141 + 7417.1013669314*t)
	X0 += 0.00000000179*np.cos(2.29351099603 + 6382.0984591304*t)
	X0 += 0.00000000181*np.cos(3.44076025740 + 1755.062649765*t)
	X0 += 0.00000000222*np.cos(1.29490505737 + 3070.4149563262*t)
	X0 += 0.00000000178*np.cos(1.75815826780 + 15106.8756912144*t)
	X0 += 0.00000000185*np.cos(4.15018423748 + 508.3503240922*t)
	X0 += 0.00000000177*np.cos(4.43296153727 + 3651.4532255682*t)
	X0 += 0.00000000195*np.cos(0.82662766477 + 218.9281697305*t)
	X0 += 0.00000000213*np.cos(0.75884375260 + 11925.2740926006*t)
	X0 += 0.00000000232*np.cos(5.03524840558 + 3163.918696566*t)
	X0 += 0.00000000232*np.cos(4.23011116665 + 3517.3061568336*t)
	X0 += 0.00000000180*np.cos(0.58769217206 + 3332.5185586308*t)
	X0 += 0.00000000180*np.cos(2.39448209299 + 3348.7062947688*t)
	X0 += 0.00000000179*np.cos(3.77306261408 + 3586.8641490228*t)
	X0 += 0.00000000205*np.cos(4.27948057306 + 1059.3991838414*t)
	X0 += 0.00000000187*np.cos(2.61826471479 + 2619.4731954936*t)
	X0 += 0.00000000176*np.cos(5.47433094670 + 13465.5424810178*t)
	X0 += 0.00000000174*np.cos(6.12894045783 + 10096.6188786667*t)
	X0 += 0.00000000188*np.cos(5.50057971256 + 2574.8193622534*t)
	X0 += 0.00000000175*np.cos(0.98299291721 + 12299.544658261*t)
	X0 += 0.00000000182*np.cos(1.47732423248 + 4288.8077146014*t)
	X0 += 0.00000000177*np.cos(4.71143769968 + 12928.7379689224*t)
	X0 += 0.00000000177*np.cos(0.60448814179 + 2572.7636073512*t)
	X0 += 0.00000000224*np.cos(4.06529944699 + 1056.2005364515*t)
	X0 += 0.00000000210*np.cos(2.56022036127 + 6683.9763640106*t)
	X0 += 0.00000000175*np.cos(5.70361271383 + 6708.6264094964*t)
	X0 += 0.00000000174*np.cos(0.12435272208 + 3155.7625187296*t)
	X0 += 0.00000000169*np.cos(5.11813247600 + 6684.73071809641*t)
	X0 += 0.00000000192*np.cos(5.18570054646 + 11567.1912630782*t)
	X0 += 0.00000000169*np.cos(0.86571880031 + 6684.7652254008*t)
	X0 += 0.00000000207*np.cos(4.46904668742 + 10001.48196070061*t)
	X0 += 0.00000000206*np.cos(1.69988902403 + 187.9251477626*t)
	X0 += 0.00000000231*np.cos(4.69193654586 + 5351.7127631396*t)
	X0 += 0.00000000189*np.cos(1.06067161596 + 2783.5199055084*t)
	X0 += 0.00000000181*np.cos(0.45144430179 + 10191.4174632324*t)
	X0 += 0.00000000172*np.cos(2.96155542160 + 526.7702037878*t)
	X0 += 0.00000000186*np.cos(0.73069210814 + 554.0699874828*t)
	X0 += 0.00000000194*np.cos(2.50663265946 + 28.5718080822*t)
	X0 += 0.00000000219*np.cos(5.87655805703 + 3070.482266629*t)
	X0 += 0.00000000177*np.cos(4.57332885856 + 2978.491289969*t)
	X0 += 0.00000000179*np.cos(3.71447292171 + 17232.7530985936*t)
	X0 += 0.00000000166*np.cos(5.04602150010 + 15121.102785216*t)
	X0 += 0.00000000168*np.cos(5.94252269393 + 1111.642245102*t)
	X0 += 0.00000000169*np.cos(1.38093325803 + 532.6117264014*t)
	X0 += 0.00000000172*np.cos(0.69353998666 + 1505.28780909299*t)
	X0 += 0.00000000163*np.cos(0.28838717250 + 155.3530891314*t)
	X0 += 0.00000000217*np.cos(3.59114151623 + 124.433415221*t)
	X0 += 0.00000000184*np.cos(1.39958801864 + 12942.965062924*t)
	X0 += 0.00000000176*np.cos(1.20681960915 + 525.4981794006*t)
	X0 += 0.00000000172*np.cos(5.60194767636 + 211.8146227297*t)
	X0 += 0.00000000162*np.cos(1.97243550807 + 16695.94858649819*t)
	X0 += 0.00000000199*np.cos(5.68556412360 + 26084.0218062162*t)
	X0 += 0.00000000166*np.cos(5.66442389971 + 20995.3929664494*t)
	X0 += 0.00000000167*np.cos(1.96358825585 + 4775.7600884592*t)
	X0 += 0.00000000200*np.cos(1.68720277112 + 3610.8098970734*t)
	X0 += 0.00000000188*np.cos(2.44893392701 + 2385.3709021002*t)
	X0 += 0.00000000180*np.cos(3.06688556020 + 3649.8907493556*t)
	X0 += 0.00000000168*np.cos(2.00209726633 + 6165.7609823066*t)
	X0 += 0.00000000201*np.cos(5.56223289068 + 3738.7441764558*t)
	X0 += 0.00000000168*np.cos(5.97126496813 + 27.4015560968*t)
	X0 += 0.00000000163*np.cos(0.09102774145 + 21393.5419698576*t)
	X0 += 0.00000000165*np.cos(5.18462129798 + 24491.4257925834*t)
	X0 += 0.00000000163*np.cos(1.72014467993 + 3345.8116178656*t)
	X0 += 0.00000000163*np.cos(1.26202958512 + 3335.413235534*t)
	X0 += 0.00000000188*np.cos(3.44598602635 + 569.0478410098*t)
	X0 += 0.00000000158*np.cos(0.33551046271 + 528.9402055692*t)
	X0 += 0.00000000157*np.cos(4.00545168863 + 530.44172462*t)
	X0 += 0.00000000161*np.cos(3.54247427777 + 272.6729573516*t)
	X0 += 0.00000000199*np.cos(2.40246756842 + 8006.1661939396*t)
	X0 += 0.00000000177*np.cos(1.96147391128 + 8322.5580635962*t)
	X0 += 0.00000000175*np.cos(1.20405833746 + 2757.6135153214*t)
	X0 += 0.00000000214*np.cos(3.94809439016 + 1385.8952763362*t)
	X0 += 0.00000000177*np.cos(0.70756419313 + 32.1951448046*t)
	X0 += 0.00000000171*np.cos(1.64736764034 + 10011.2006147496*t)
	X0 += 0.00000000157*np.cos(6.04186245834 + 31172.650645983*t)
	X0 += 0.00000000198*np.cos(4.06378380988 + 4106.4054911462*t)
	X0 += 0.00000000163*np.cos(2.04239538779 + 13286.1836355236*t)
	X0 += 0.00000000191*np.cos(4.12314886390 + 183.2428146475*t)
	X0 += 0.00000000179*np.cos(1.49110102879 + 5.9378908332*t)
	X0 += 0.00000000155*np.cos(5.55637185637 + 8771.0070837986*t)
	X0 += 0.00000000170*np.cos(5.83704197169 + 305.3461693927*t)
	X0 += 0.00000000151*np.cos(6.02667746519 + 15010.8964639966*t)
	X0 += 0.00000000159*np.cos(0.33316888782 + 4061.751657906*t)
	X0 += 0.00000000169*np.cos(6.19340718678 + 7064.1041319706*t)
	X0 += 0.00000000202*np.cos(4.07695393078 + 4253.1826703654*t)
	X0 += 0.00000000166*np.cos(0.77365213441 + 6719.3578890374*t)
	X0 += 0.00000000149*np.cos(1.16534241475 + 14577.1847261198*t)
	X0 += 0.00000000207*np.cos(1.81656116060 + 73.8183907208*t)
	X0 += 0.00000000163*np.cos(5.84711051841 + 1898.3512179396*t)
	X0 += 0.00000000151*np.cos(5.90185701300 + 10228.0228285366*t)
	X0 += 0.00000000151*np.cos(2.82941538658 + 3525.46233467*t)
	X0 += 0.00000000175*np.cos(1.28027815287 + 217.964961884*t)
	X0 += 0.00000000149*np.cos(1.89551632354 + 3664.1178433572*t)
	X0 += 0.00000000196*np.cos(3.39234316905 + 3610.7425867706*t)
	X0 += 0.00000000167*np.cos(0.38551119237 + 1346.3442913098*t)
	X0 += 0.00000000166*np.cos(2.03194803269 + 5466.489834079*t)
	X0 += 0.00000000167*np.cos(2.89181496866 + 10288.4443218212*t)
	X0 += 0.00000000148*np.cos(4.39633643688 + 519.3960243561*t)
	X0 += 0.00000000147*np.cos(3.63497942528 + 82.8583534146*t)
	X0 += 0.00000000172*np.cos(5.39487275378 + 19617.07636932279*t)
	X0 += 0.00000000147*np.cos(2.18400664980 + 1898.3339642874*t)
	X0 += 0.00000000166*np.cos(2.73543927114 + 6908.7009861886*t)
	X0 += 0.00000000201*np.cos(1.30981921500 + 3738.7786837602*t)
	X0 += 0.00000000146*np.cos(0.62125880196 + 13369.56325380*t)
	X0 += 0.00000000170*np.cos(5.74209007670 + 6677.6844813984*t)
	X0 += 0.00000000147*np.cos(1.87608878363 + 9918.7445058808*t)
	X0 += 0.00000000203*np.cos(2.54569209930 + 453.424893819*t)
	X0 += 0.00000000159*np.cos(2.95197147470 + 3346.4696289994*t)
	X0 += 0.00000000159*np.cos(0.03020279035 + 3334.7552244002*t)
	X0 += 0.00000000191*np.cos(5.96603240618 + 425.1137181677*t)
	X0 += 0.00000000143*np.cos(1.10166083747 + 13227.3846267638*t)
	X0 += 0.00000000164*np.cos(2.07109751188 + 2125.8100970764*t)
	X0 += 0.00000000148*np.cos(3.53096991388 + 414.0680179038*t)
	X0 += 0.00000000189*np.cos(6.14146200362 + 10042.1925994982*t)
	X0 += 0.00000000200*np.cos(0.25134097583 + 1439.5096981492*t)
	X0 += 0.00000000165*np.cos(5.22234420384 + 231.4583427027*t)
	X0 += 0.00000000153*np.cos(4.69199840126 + 3702.7335634306*t)
	X0 += 0.00000000168*np.cos(2.68821315216 + 10032.4739454492*t)
	X0 += 0.00000000151*np.cos(2.48880937989 + 1859.2030553546*t)
	X0 += 0.00000000163*np.cos(1.42062692665 + 2964.8466951296*t)
	X0 += 0.00000000141*np.cos(5.69421526925 + 408.4389436113*t)
	X0 += 0.00000000179*np.cos(0.37975631677 + 2714.9422343874*t)
	X0 += 0.00000000179*np.cos(2.60241794828 + 3966.2826190122*t)
	X0 += 0.00000000140*np.cos(4.86451546343 + 18461.71521191579*t)
	X0 += 0.00000000183*np.cos(0.37676347949 + 6791.431174619*t)
	X0 += 0.00000000150*np.cos(5.20287301062 + 2922.1081038928*t)
	X0 += 0.00000000175*np.cos(5.42596524283 + 5220.1708014532*t)
	X0 += 0.00000000140*np.cos(5.79899062095 + 1538.240435978*t)
	X0 += 0.00000000146*np.cos(1.91278049103 + 2714.9872905026*t)
	X0 += 0.00000000165*np.cos(1.13934061346 + 7345.9808985296*t)
	X0 += 0.00000000191*np.cos(2.19520817629 + 3202.0242283154*t)
	X0 += 0.00000000191*np.cos(0.78696608877 + 3479.2006250842*t)
	X0 += 0.00000000191*np.cos(6.04625942487 + 75.7448064138*t)
	X0 += 0.00000000143*np.cos(0.93308559393 + 9153.9036160218*t)
	X0 += 0.00000000139*np.cos(0.98177816584 + 4878.8528626778*t)
	X0 += 0.00000000160*np.cos(5.46927582744 + 3287.304480416*t)
	X0 += 0.00000000160*np.cos(3.79608374479 + 3393.9203729836*t)
	X0 += 0.00000000193*np.cos(0.22143365956 + 3031.334104044*t)
	X0 += 0.00000000150*np.cos(1.84793747625 + 3897.7049478912*t)
	X0 += 0.00000000182*np.cos(5.61872247851 + 27832.0382192832*t)
	X0 += 0.00000000149*np.cos(3.15621899577 + 533.8837507886*t)
	X0 += 0.00000000144*np.cos(0.96134974857 + 3945.4621674046*t)
	X0 += 0.00000000170*np.cos(1.48967640102 + 6677.71898870279*t)
	X0 += 0.00000000141*np.cos(3.83742737291 + 6279.5527316424*t)
	X0 += 0.00000000155*np.cos(5.68213195490 + 25135.8265183146*t)
	X0 += 0.00000000136*np.cos(2.44961684409 + 12729.665967486*t)
	X0 += 0.00000000188*np.cos(0.01265622712 + 4686.95671800959*t)
	X0 += 0.00000000167*np.cos(5.28314283541 + 8336.7851575978*t)
	X0 += 0.00000000151*np.cos(3.22358745524 + 2281.2978068134*t)
	X0 += 0.00000000151*np.cos(6.20627936335 + 8962.522660213*t)
	X0 += 0.00000000159*np.cos(4.80713616496 + 8958.5231966471*t)
	X0 += 0.00000000157*np.cos(3.61532012746 + 208.633228992*t)
	X0 += 0.00000000168*np.cos(0.17015651337 + 4295.8539512994*t)
	X0 += 0.00000000133*np.cos(4.82759769594 + 21150.8133658836*t)
	X0 += 0.00000000159*np.cos(1.73650436212 + 8966.3875031733*t)
	X0 += 0.00000000151*np.cos(0.33159044302 + 8962.3880396074*t)
	X0 += 0.00000000151*np.cos(3.63208384209 + 2281.1631862078*t)
	X0 += 0.00000000137*np.cos(3.04837973833 + 6703.075682726*t)
	X0 += 0.00000000133*np.cos(6.26949704953 + 12171.5258149236*t)
	X0 += 0.00000000153*np.cos(4.99836680146 + 47.6942631934*t)
	X0 += 0.00000000136*np.cos(5.59365849152 + 8695.8483081884*t)
	X0 += 0.00000000160*np.cos(2.63695807146 + 5401.4302807716*t)
	X0 += 0.00000000140*np.cos(0.39711511870 + 34554.8138636676*t)
	X0 += 0.00000000184*np.cos(2.16301573772 + 1021.2488945514*t)
	X0 += 0.00000000134*np.cos(4.28535760311 + 2472.6787626222*t)
	X0 += 0.00000000135*np.cos(5.15711417667 + 14481.205498902*t)
	X0 += 0.00000000139*np.cos(5.84452648935 + 373.9079928365*t)
	X0 += 0.00000000130*np.cos(4.35532122087 + 529.6737114424*t)
	X0 += 0.00000000133*np.cos(6.07532283158 + 6624.326478464*t)
	X0 += 0.00000000148*np.cos(3.97691997672 + 7050.92466934*t)
	X0 += 0.00000000130*np.cos(4.65934301751 + 7593.7950970652*t)
	X0 += 0.00000000140*np.cos(1.69371671061 + 11456.9849418588*t)
	X0 += 0.00000000130*np.cos(0.10290754518 + 529.7082187468*t)
	X0 += 0.00000000143*np.cos(4.86125646505 + 10014.7910434014*t)
	X0 += 0.00000000154*np.cos(1.51195474378 + 5607.6158292088*t)
	X0 += 0.00000000143*np.cos(5.92681168953 + 3041.4860324306*t)
	X0 += 0.00000000158*np.cos(4.74267595754 + 6092.1600263914*t)
	X0 += 0.00000000138*np.cos(5.61172177506 + 214.7835681463*t)
	X0 += 0.00000000134*np.cos(6.18223447403 + 2954.1927761276*t)
	X0 += 0.00000000129*np.cos(1.54390762080 + 203.0041546995*t)
	X0 += 0.00000000145*np.cos(4.90616424565 + 8373.390522902*t)
	X0 += 0.00000000128*np.cos(5.24161490581 + 479.2883889155*t)
	X0 += 0.00000000173*np.cos(6.07118204441 + 1086.783486286*t)
	X0 += 0.00000000137*np.cos(5.86596713113 + 6137.3067943034*t)
	X0 += 0.00000000167*np.cos(5.43777729955 + 107.6635239386*t)
	X0 += 0.00000000137*np.cos(5.46263047000 + 14580.7751547716*t)
	X0 += 0.00000000130*np.cos(2.37764705674 + 4108.4612460484*t)
	X0 += 0.00000000132*np.cos(2.61918637671 + 4782.87363546*t)
	X0 += 0.00000000123*np.cos(3.36083480955 + 29424.634232916*t)
	X0 += 0.00000000126*np.cos(1.85449654763 + 18447.48811791419*t)
	X0 += 0.00000000127*np.cos(1.92093733385 + 4447.7512323846*t)
	X0 += 0.00000000141*np.cos(1.56398014110 + 3716.37815827*t)
	X0 += 0.00000000124*np.cos(3.53492874819 + 6687.9085172737*t)
	X0 += 0.00000000121*np.cos(0.01062042066 + 3090.7079659576*t)
	X0 += 0.00000000121*np.cos(2.97155384439 + 3590.516887442*t)
	X0 += 0.00000000130*np.cos(2.26702486739 + 654.1243803156*t)
	X0 += 0.00000000122*np.cos(1.08221642068 + 2257.3520587628*t)
	X0 += 0.00000000123*np.cos(4.43212874956 + 6710.6543619356*t)
	X0 += 0.00000000122*np.cos(3.26594164721 + 1236.075660323*t)
	X0 += 0.00000000166*np.cos(5.13636005426 + 6553.2060100622*t)
	X0 += 0.00000000143*np.cos(2.33674585334 + 20206.141196331*t)
	X0 += 0.00000000144*np.cos(1.54442458059 + 4.192785694*t)
	X0 += 0.00000000157*np.cos(0.56952639012 + 8584.6616659008*t)
	X0 += 0.00000000128*np.cos(0.66575049629 + 3600.1732317236*t)
	X0 += 0.00000000128*np.cos(2.31642376876 + 3081.051621676*t)
	X0 += 0.00000000139*np.cos(1.22510407970 + 251.4321310758*t)
	X0 += 0.00000000160*np.cos(5.11540883899 + 265.9892934775*t)
	X0 += 0.00000000119*np.cos(0.92051706257 + 23937.856389741*t)
	X0 += 0.00000000127*np.cos(4.06247504712 + 3759.1167495068*t)
	X0 += 0.00000000143*np.cos(1.09974278396 + 2228.9701815978*t)
	X0 += 0.00000000152*np.cos(5.09265509081 + 3340.6469340042*t)
	X0 += 0.00000000152*np.cos(1.03111182783 + 3340.5779193954*t)
	X0 += 0.00000000126*np.cos(0.88452034949 + 12406.1605508286*t)
	X0 += 0.00000000140*np.cos(1.36708586192 + 2233.473621015*t)
	X0 += 0.00000000137*np.cos(4.79264710956 + 14587.8213914696*t)
	X0 += 0.00000000118*np.cos(4.24522226402 + 7534.4212351516*t)
	X0 += 0.00000000121*np.cos(5.05113331022 + 56.6223513026*t)
	X0 += 0.00000000150*np.cos(5.98252134963 + 8446.9914788172*t)
	X0 += 0.00000000116*np.cos(0.31023473755 + 10338.229149756*t)
	X0 += 0.00000000126*np.cos(5.72234812550 + 4083.6024872324*t)
	X0 += 0.00000000116*np.cos(3.21277912522 + 721.1392312062*t)
	X0 += 0.00000000133*np.cos(1.77116481582 + 3923.6113380782*t)
	X0 += 0.00000000115*np.cos(6.22459411775 + 539.9859058331*t)
	X0 += 0.00000000125*np.cos(0.79695675334 + 9124.9219860424*t)
	X0 += 0.00000000134*np.cos(0.59423378961 + 6659.3740240732*t)
	X0 += 0.00000000133*np.cos(2.32347788867 + 6147.6017350419*t)
	X0 += 0.00000000118*np.cos(5.14268766839 + 19676.4502312364*t)
	X0 += 0.00000000114*np.cos(3.36563651789 + 6534.413166876*t)
	X0 += 0.00000000112*np.cos(5.63276223022 + 1353.3905280078*t)
	X0 += 0.00000000118*np.cos(2.59721745181 + 2185.2512692928*t)
	X0 += 0.00000000139*np.cos(2.53675571989 + 14867.73751589219*t)
	X0 += 0.00000000116*np.cos(3.08292987464 + 3727.032077272*t)
	X0 += 0.00000000112*np.cos(1.08140723902 + 6474.524116103*t)
	X0 += 0.00000000111*np.cos(5.09669528080 + 7277.4032274086*t)
	X0 += 0.00000000111*np.cos(5.06172588434 + 6837.625573902*t)
	X0 += 0.00000000122*np.cos(0.61324340709 + 9161.5273513466*t)
	X0 += 0.00000000114*np.cos(0.09813992796 + 213.1872208534*t)
	X0 += 0.00000000114*np.cos(4.79116773360 + 213.4109700226*t)
	X0 += 0.00000000114*np.cos(1.06936801122 + 3966.237562897*t)
	X0 += 0.00000000116*np.cos(5.17901397340 + 1593.0050485469*t)
	X0 += 0.00000000108*np.cos(4.40272597236 + 27490.6924780448*t)
	X0 += 0.00000000137*np.cos(4.24858996402 + 2214.7430875962*t)
	X0 += 0.00000000129*np.cos(4.66656206914 + 3101.4069410748*t)
	X0 += 0.00000000129*np.cos(4.59879750310 + 3579.8179123248*t)
	X0 += 0.00000000133*np.cos(3.86628532692 + 6738.1232283352*t)
	X0 += 0.00000000123*np.cos(5.10501021239 + 98.8999885246*t)
	X0 += 0.00000000143*np.cos(5.51260292487 + 10787.6303445458*t)
	X0 += 0.00000000146*np.cos(3.29717245103 + 3282.733730696*t)
	X0 += 0.00000000146*np.cos(5.96818712120 + 3398.4911227036*t)
	X0 += 0.00000000116*np.cos(0.64506154486 + 524.0618908021*t)
	X0 += 0.00000000115*np.cos(4.70981861448 + 2501.6431389494*t)
	X0 += 0.00000000130*np.cos(5.51494242208 + 6155.4660415681*t)
	X0 += 0.00000000138*np.cos(0.53531085594 + 604.8497407048*t)
	X0 += 0.00000000115*np.cos(4.54726805499 + 8976.6824439118*t)
	X0 += 0.00000000105*np.cos(5.41363141342 + 17821.81792560179*t)
	X0 += 0.00000000115*np.cos(3.69498632982 + 535.3200393871*t)
	X0 += 0.00000000127*np.cos(0.63003020942 + 540.7366653585*t)
	X0 += 0.00000000104*np.cos(3.25094284849 + 550.0462844934*t)
	X0 += 0.00000000137*np.cos(1.64829531963 + 10.6366653498*t)
	X0 += 0.00000000103*np.cos(0.09569085161 + 31214.2014369678*t)
	X0 += 0.00000000103*np.cos(0.32444738176 + 1059.3146198864*t)
	X0 += 0.00000000110*np.cos(3.63003384125 + 20426.571092422*t)
	X0 += 0.00000000116*np.cos(2.76497516745 + 21000.9158907568*t)
	X0 += 0.00000000124*np.cos(2.96682510796 + 2089.782230399*t)
	X0 += 0.00000000107*np.cos(3.74825241556 + 7075.8507384588*t)
	X0 += 0.00000000109*np.cos(0.75405687887 + 27433.88921587499*t)
	X0 += 0.00000000115*np.cos(3.05294273666 + 7768.0083396856*t)
	X0 += 0.00000000106*np.cos(1.35498268917 + 338.242698983*t)
	X0 += 0.00000000105*np.cos(5.49367983392 + 6961.011357752*t)
	X0 += 0.00000000129*np.cos(3.76517296403 + 3719.98584057399*t)
	X0 += 0.00000000129*np.cos(5.50018660820 + 2961.2390128256*t)
	X0 += 0.00000000122*np.cos(2.69389010184 + 27676.617819849*t)
	X0 += 0.00000000137*np.cos(4.29317120368 + 765.7930644464*t)
	X0 += 0.00000000103*np.cos(2.94392199086 + 369.6998159404*t)
	X0 += 0.00000000115*np.cos(6.24138664661 + 2631.6226244232*t)
	X0 += 0.00000000104*np.cos(6.26045969928 + 31449.8270427518*t)
	X0 += 0.00000000118*np.cos(0.24752969879 + 983.1158589136*t)
	X0 += 0.00000000103*np.cos(5.98380934531 + 4953.5637597314*t)
	X0 += 0.00000000119*np.cos(0.25257145975 + 5813.291189322*t)
	X0 += 0.00000000127*np.cos(5.95846705295 + 2655.501062171*t)
	X0 += 0.00000000101*np.cos(4.76347332672 + 21791.69097326579*t)
	X0 += 0.00000000118*np.cos(0.19804778544 + 525.0250986486*t)
	X0 += 0.00000000138*np.cos(4.81087367911 + 3480.3105662226*t)
	X0 += 0.00000000138*np.cos(4.45448589312 + 3200.914287177*t)
	X0 += 0.00000000100*np.cos(3.71645704441 + 529.851023789*t)
	X0 += 0.00000000100*np.cos(0.62422783083 + 529.5309064002*t)
	X0 += 0.00000000100*np.cos(4.46306796510 + 101011.00013959699*t)
	X0 += 0.00000000102*np.cos(1.31527898088 + 963.4027029714*t)
	X0 += 0.00000000099*np.cos(1.87542989608 + 198.321241911*t)
	X0 += 0.00000000109*np.cos(5.70820863859 + 249.9044607422*t)
	X0 += 0.00000000100*np.cos(2.36720288529 + 2651.977943822*t)
	X0 += 0.00000000112*np.cos(0.61908290347 + 4825.544916394*t)
	X0 += 0.00000000106*np.cos(2.47924429864 + 7899.550301372*t)
	X0 += 0.00000000100*np.cos(0.73142842806 + 3340.6969906548*t)
	X0 += 0.00000000100*np.cos(5.39233849058 + 3340.52786274481*t)
	X0 += 0.00000000099*np.cos(1.07037429534 + 5312.5646005546*t)
	X0 += 0.00000000111*np.cos(1.30109743855 + 80.1982245387*t)
	X0 += 0.00000000103*np.cos(1.54600541491 + 1585.1407420207*t)
	X0 += 0.00000000096*np.cos(4.17152569130 + 213.5115437591*t)
	X0 += 0.00000000096*np.cos(0.71778197027 + 213.0866471169*t)
	X0 += 0.00000000110*np.cos(4.66774204357 + 4179.5817144502*t)
	X0 += 0.00000000119*np.cos(4.24896124568 + 128.0188433374*t)
	X0 += 0.00000000096*np.cos(1.41805272608 + 34363.365597556*t)
	X0 += 0.00000000095*np.cos(4.69553914772 + 3370.49447031*t)
	X0 += 0.00000000095*np.cos(4.56982042451 + 3310.7303830896*t)
	X0 += 0.00000000100*np.cos(5.36079056084 + 1755.4716846791*t)
	X0 += 0.00000000099*np.cos(0.19873228449 + 551.031606097*t)
	X0 += 0.00000000100*np.cos(1.13992481490 + 3340.5623700492*t)
	X0 += 0.00000000100*np.cos(4.98384210374 + 3340.6624833504*t)
	X0 += 0.00000000095*np.cos(2.49148312191 + 1125.8693391036*t)
	X0 += 0.00000000111*np.cos(4.13924061941 + 534.3568315406*t)
	X0 += 0.00000000117*np.cos(1.76475239313 + 524.2743391232*t)
	X0 += 0.00000000098*np.cos(2.55075465694 + 1784.0442797444*t)
	X0 += 0.00000000129*np.cos(4.50550938612 + 4591.4426230006*t)
	X0 += 0.00000000125*np.cos(4.85236761160 + 21.3406410024*t)
	X0 += 0.00000000095*np.cos(5.28465176922 + 327.4375699205*t)
	X0 += 0.00000000115*np.cos(1.84342023983 + 948.1952879016*t)
	X0 += 0.00000000125*np.cos(3.41500530183 + 30227.9784764304*t)
	X0 += 0.00000000096*np.cos(3.69113463475 + 158.9435177832*t)
	X0 += 0.00000000115*np.cos(2.57406093768 + 535.107591066*t)
	X0 += 0.00000000096*np.cos(5.28632356883 + 16975.7350908506*t)
	X0 += 0.00000000117*np.cos(4.34728892724 + 6342.9821544166*t)
	X0 += 0.00000000100*np.cos(2.94090698274 + 195.1398481733*t)
	X0 += 0.00000000118*np.cos(0.67935665521 + 3343.5813721164*t)
	X0 += 0.00000000118*np.cos(2.30281760984 + 3337.6434812832*t)
	X0 += 0.00000000104*np.cos(1.87017877120 + 1971.9521738548*t)
	X0 += 0.00000000105*np.cos(5.51085323879 + 42388.934936307*t)
	X0 += 0.00000000118*np.cos(0.33308541328 + 2523.9591004846*t)
	X0 += 0.00000000102*np.cos(5.06423665932 + 27946.7479799198*t)
	X0 += 0.00000000092*np.cos(0.37931448032 + 24093.2767891752*t)
	X0 += 0.00000000103*np.cos(4.21389346910 + 20235.1228263104*t)
	X0 += 0.00000000106*np.cos(0.48409497986 + 8219.4652893776*t)
	X0 += 0.00000000092*np.cos(1.93921425261 + 6953.8978107512*t)
	X0 += 0.00000000118*np.cos(5.64764411450 + 3396.995612776*t)
	X0 += 0.00000000118*np.cos(3.61771545773 + 3284.2292406236*t)
	X0 += 0.00000000093*np.cos(1.77160363006 + 11506.7697697936*t)
	X0 += 0.00000000096*np.cos(0.06385619665 + 35.685355083*t)
	X0 += 0.00000000094*np.cos(3.17734400558 + 1957.7250798532*t)
	X0 += 0.00000000092*np.cos(1.60745438369 + 34115.1140692746*t)
	X0 += 0.00000000113*np.cos(1.72263005108 + 114.1384744825*t)
	X0 += 0.00000000106*np.cos(3.67532877346 + 10177.1903692308*t)
	X0 += 0.00000000104*np.cos(0.07874415195 + 3149.1814142404*t)
	X0 += 0.00000000093*np.cos(4.56692119429 + 18617.0683010472*t)
	X0 += 0.00000000108*np.cos(3.73875850582 + 2104.5367663768*t)
	X0 += 0.00000000102*np.cos(4.42228976166 + 219.891377577*t)
	X0 += 0.00000000091*np.cos(5.75237351963 + 3532.0434391592*t)
	X0 += 0.00000000094*np.cos(3.91461919551 + 3346.7456526324*t)
	X0 += 0.00000000094*np.cos(5.35074037672 + 3334.4792007672*t)
	X0 += 0.00000000090*np.cos(0.96686807913 + 15746.7729775284*t)
	X0 += 0.00000000091*np.cos(2.71684236561 + 50818.1762027736*t)
	X0 += 0.00000000096*np.cos(1.92198734613 + 10927.2939767642*t)
	X0 += 0.00000000092*np.cos(0.87242130441 + 50021.8781959572*t)
	X0 += 0.00000000110*np.cos(4.01385678858 + 27417.0570148252*t)
	X0 += 0.00000000103*np.cos(6.19913630210 + 1059.449240492*t)
	X0 += 0.00000000089*np.cos(2.21598103655 + 3368.08129309939*t)
	X0 += 0.00000000089*np.cos(0.76619322850 + 3313.1435603002*t)
	X0 += 0.00000000092*np.cos(1.76294266344 + 32509.208972941*t)
	X0 += 0.00000000086*np.cos(2.85915032438 + 228.276948965*t)
	X0 += 0.00000000107*np.cos(0.77642458908 + 4822.021798045*t)
	X0 += 0.00000000086*np.cos(2.15668825323 + 24336.0053931492*t)
	X0 += 0.00000000091*np.cos(1.49995984394 + 3532.0779464636*t)
	X0 += 0.00000000100*np.cos(3.39323367399 + 96.8729990951*t)
	X0 += 0.00000000114*np.cos(1.17888998162 + 30774.5016425748*t)
	X0 += 0.00000000095*np.cos(2.41544015495 + 529.6236547918*t)
	X0 += 0.00000000120*np.cos(1.39317335094 + 3202.0949298291*t)
	X0 += 0.00000000120*np.cos(1.58900091411 + 3479.1299235705*t)
	X0 += 0.00000000086*np.cos(0.63892610093 + 3762.6398678558*t)
	X0 += 0.00000000086*np.cos(2.34324816413 + 2918.5849855438*t)
	X0 += 0.00000000099*np.cos(5.63933737649 + 3222.7996238078*t)
	X0 += 0.00000000099*np.cos(3.62602219574 + 3458.4252295918*t)
	X0 += 0.00000000089*np.cos(3.31658981903 + 22531.09060514659*t)
	X0 += 0.00000000107*np.cos(4.00303304883 + 3369.5940566792*t)
	X0 += 0.00000000107*np.cos(5.26232652340 + 3311.6307967204*t)
	X0 += 0.00000000090*np.cos(4.95208405657 + 4670.1245169598*t)
	X0 += 0.00000000094*np.cos(3.52537110144 + 796.2807531642*t)
	X0 += 0.00000000085*np.cos(4.38854271531 + 809.477469447*t)
	X0 += 0.00000000086*np.cos(2.16630383215 + 987.746272928*t)
	X0 += 0.00000000084*np.cos(4.57392791210 + 4777.7880408984*t)
	X0 += 0.00000000084*np.cos(2.18560642641 + 1107.1388056848*t)
	X0 += 0.00000000084*np.cos(2.61330768505 + 74.7334144575*t)
	X0 += 0.00000000084*np.cos(5.20716850754 + 74.8297826771*t)
	X0 += 0.00000000104*np.cos(4.33115782764 + 3149.146906936*t)
	X0 += 0.00000000116*np.cos(0.77977053917 + 14694.50459434*t)
	X0 += 0.00000000086*np.cos(1.37558388975 + 12410.7313005486*t)
	X0 += 0.00000000114*np.cos(1.15232105885 + 177.8743727859*t)
	X0 += 0.00000000085*np.cos(2.86994886436 + 1619.9975697296*t)
	X0 += 0.00000000109*np.cos(5.59836287202 + 10610.9021071076*t)
	X0 += 0.00000000089*np.cos(1.46102468066 + 3332.9386347244*t)
	X0 += 0.00000000089*np.cos(1.52114958439 + 3348.2862186752*t)
	X0 += 0.00000000084*np.cos(1.33406969455 + 1552.4675299796*t)
	X0 += 0.00000000099*np.cos(4.61468010668 + 24606.13555322*t)
	X0 += 0.00000000084*np.cos(2.49883491772 + 2942.5307335944*t)
	X0 += 0.00000000112*np.cos(3.24631234908 + 14900.6901427772*t)
	X0 += 0.00000000082*np.cos(0.76471194062 + 3330.0430716528*t)
	X0 += 0.00000000082*np.cos(2.21746232443 + 3351.1817817468*t)
	X0 += 0.00000000082*np.cos(2.15560831176 + 22317.79150970859*t)
	X0 += 0.00000000089*np.cos(5.02414670070 + 5355.2358814886*t)
	X0 += 0.00000000087*np.cos(1.13401038923 + 40.5807161926*t)
	X0 += 0.00000000084*np.cos(4.48618455018 + 3083.5944189568*t)
	X0 += 0.00000000084*np.cos(4.77917502205 + 3597.6304344428*t)
	X0 += 0.00000000093*np.cos(1.35537122244 + 8948.2282559086*t)
	X0 += 0.00000000095*np.cos(2.00694376811 + 529.7582753974*t)
	X0 += 0.00000000085*np.cos(0.15626665144 + 1055.8588118402*t)
	X0 += 0.00000000099*np.cos(1.87280470738 + 7906.59653807*t)
	X0 += 0.00000000114*np.cos(2.85738890734 + 3063.5774329584*t)
	X0 += 0.00000000114*np.cos(0.12478535771 + 3617.6474204412*t)
	X0 += 0.00000000090*np.cos(2.28313612434 + 51769.8946090242*t)
	X0 += 0.00000000085*np.cos(4.25324733609 + 54789.936689978*t)
	X0 += 0.00000000086*np.cos(4.98727225433 + 23009.94911093539*t)
	X0 += 0.00000000083*np.cos(3.80459099750 + 20103.0484221124*t)
	X0 += 0.00000000112*np.cos(5.31873185789 + 5295.3295770634*t)
	X0 += 0.00000000081*np.cos(3.33902328234 + 191.2076949102*t)
	X0 += 0.00000000083*np.cos(0.55564877844 + 4029.2469095776*t)
	X0 += 0.00000000093*np.cos(1.06738164563 + 74.5209661364*t)
	X0 += 0.00000000080*np.cos(4.41455828078 + 31570.7996493912*t)
	X0 += 0.00000000081*np.cos(0.73729790566 + 3190.714951573*t)
	X0 += 0.00000000081*np.cos(2.24487635939 + 3490.5099018266*t)
	X0 += 0.00000000096*np.cos(0.23027300186 + 2544.2971662312*t)
	X0 += 0.00000000094*np.cos(5.55614273293 + 796.3152604686*t)
	X0 += 0.00000000093*np.cos(0.46802035326 + 75.0422309982*t)
	X0 += 0.00000000079*np.cos(4.31891477024 + 38.0211610532*t)
	X0 += 0.00000000089*np.cos(5.72126604208 + 6311.5250374592*t)
	X0 += 0.00000000079*np.cos(3.16332905605 + 38.2449102224*t)
	X0 += 0.00000000085*np.cos(0.12415625823 + 14715.840234807*t)
	X0 += 0.00000000080*np.cos(1.40233563562 + 191.9584544356*t)
	X0 += 0.00000000102*np.cos(3.18943570469 + 3524.48201360179*t)
	X0 += 0.00000000102*np.cos(6.07592386754 + 3156.7428397978*t)
	X0 += 0.00000000086*np.cos(2.62365837929 + 13517.8027959306*t)
	X0 += 0.00000000084*np.cos(2.90733130456 + 2942.3961129888*t)
	X0 += 0.00000000084*np.cos(4.30297087103 + 4801.6664786462*t)
	return X0




def Mars_X1 (t): # 966 terms of order 1

	X1 = 0.
	X1 -= 0.00862737448
	X1 += 0.00552437771*np.cos(5.09565872891 + 6681.2248533996*t)
	X1 += 0.00077184951*np.cos(5.43315636209 + 10021.8372800994*t)
	X1 += 0.00020467294*np.cos(5.57051812369 + 3340.6124266998*t)
	X1 += 0.00009589581*np.cos(5.77107234791 + 13362.4497067992*t)
	X1 += 0.00002620610*np.cos(6.22441295122 + 3344.1355450488*t)
	X1 += 0.00002620537*np.cos(3.04172154436 + 3337.0893083508*t)
	X1 += 0.00001506382*np.cos(3.28863699080 + 1059.3819301892*t)
	X1 += 0.00001163612*np.cos(6.10909257097 + 16703.062133499*t)
	X1 += 0.00000823316*np.cos(1.16299346122 + 426.598190876*t)
	X1 += 0.00000775320*np.cos(2.70607668657 + 206.1855484372*t)
	X1 += 0.00000751772*np.cos(2.19150282553 + 220.4126424388*t)
	X1 += 0.00000561169*np.cos(5.56960890900 + 522.5774180938*t)
	X1 += 0.00000549256*np.cos(5.05722360972 + 536.8045120954*t)
	X1 += 0.00000427058*np.cos(2.74008980166 + 2942.4634232916*t)
	X1 += 0.00000381428*np.cos(0.22342431378 + 3738.761430108*t)
	X1 += 0.00000386916*np.cos(5.94232552612 + 5621.8429232104*t)
	X1 += 0.00000395001*np.cos(0.20042939555 + 6684.7479717486*t)
	X1 += 0.00000337356*np.cos(5.21417361076 + 3149.1641605882*t)
	X1 += 0.00000334209*np.cos(2.45910275965 + 3185.1920272656*t)
	X1 += 0.00000318463*np.cos(4.05140251894 + 3532.0606928114*t)
	X1 += 0.00000318426*np.cos(0.52909208916 + 3496.032826134*t)
	X1 += 0.00000312605*np.cos(4.22912280613 + 2544.3144198834*t)
	X1 += 0.00000289251*np.cos(4.61759345454 + 796.2980068164*t)
	X1 += 0.00000260308*np.cos(5.02630754856 + 4136.9104335162*t)
	X1 += 0.00000206733*np.cos(3.21083229673 + 1194.4470102246*t)
	X1 += 0.00000203432*np.cos(3.58220297134 + 1589.0728952838*t)
	X1 += 0.00000140570*np.cos(0.16405101702 + 20043.6745601988*t)
	X1 += 0.00000133819*np.cos(4.64351814551 + 5884.9268465832*t)
	X1 += 0.00000132323*np.cos(3.70094513425 + 4399.994356889*t)
	X1 += 0.00000127123*np.cos(2.81806076447 + 6677.7017350506*t)
	X1 += 0.00000102796*np.cos(6.05672047566 + 5486.777843175*t)
	X1 += 0.00000112591*np.cos(5.89047647024 + 2146.1654164752*t)
	X1 += 0.00000129469*np.cos(1.80477637958 + 1592.5960136328*t)
	X1 += 0.00000101457*np.cos(3.72531913828 + 3341.592747768*t)
	X1 += 0.00000101429*np.cos(5.54115874275 + 3339.6321056316*t)
	X1 += 0.00000089231*np.cos(5.88265350957 + 3870.3033917944*t)
	X1 += 0.00000084359*np.cos(0.39861148409 + 1990.745017041*t)
	X1 += 0.00000077267*np.cos(0.64237838596 + 7079.3738568078*t)
	X1 += 0.00000081615*np.cos(5.65301248357 + 5092.1519581158*t)
	X1 += 0.00000085357*np.cos(1.68626480339 + 419.4846438752*t)
	X1 += 0.00000064069*np.cos(5.27568100391 + 2388.8940204492*t)
	X1 += 0.00000057349*np.cos(0.50336630984 + 10025.3603984484*t)
	X1 += 0.00000057779*np.cos(1.95322424838 + 3097.88382272579*t)
	X1 += 0.00000063709*np.cos(4.30359933795 + 213.299095438*t)
	X1 += 0.00000075338*np.cos(1.25298511750 + 5088.6288397668*t)
	X1 += 0.00000075597*np.cos(3.61161529128 + 4535.0594369244*t)
	X1 += 0.00000057038*np.cos(2.69097269126 + 4690.4798363586*t)
	X1 += 0.00000055693*np.cos(1.22100970149 + 9492.1463150048*t)
	X1 += 0.00000053020*np.cos(1.04990905431 + 3583.3410306738*t)
	X1 += 0.00000070673*np.cos(3.86820111874 + 2787.0430238574*t)
	X1 += 0.00000057595*np.cos(0.75650661572 + 639.897286314*t)
	X1 += 0.00000049103*np.cos(4.08361966579 + 4292.3308329504*t)
	X1 += 0.00000051266*np.cos(4.58705364976 + 191.4482661116*t)
	X1 += 0.00000050596*np.cos(1.40353923768 + 433.7117378768*t)
	X1 += 0.00000054144*np.cos(2.75220168825 + 2957.7158944766*t)
	X1 += 0.00000060338*np.cos(5.44643531231 + 3894.1818295422*t)
	X1 += 0.00000060977*np.cos(1.33676776514 + 1748.016413067*t)
	X1 += 0.00000049313*np.cos(2.50941274343 + 6681.2075997474*t)
	X1 += 0.00000049853*np.cos(0.26909559157 + 3723.508958923*t)
	X1 += 0.00000049313*np.cos(4.54018424365 + 6681.2421070518*t)
	X1 += 0.00000056626*np.cos(1.06789339618 + 155.4203994342*t)
	X1 += 0.00000050925*np.cos(5.81536571173 + 1066.49547719*t)
	X1 += 0.00000047447*np.cos(5.64332397974 + 6489.776587288*t)
	X1 += 0.00000037363*np.cos(0.07393316577 + 3553.9115221378*t)
	X1 += 0.00000043354*np.cos(3.37196729572 + 7.1135470008*t)
	X1 += 0.00000041874*np.cos(2.94784781040 + 1349.8674096588*t)
	X1 += 0.00000036019*np.cos(2.84922399832 + 3127.3133312618*t)
	X1 += 0.00000035314*np.cos(2.80430917536 + 6525.8044539654*t)
	X1 += 0.00000032357*np.cos(4.45790537173 + 951.7184062506*t)
	X1 += 0.00000041885*np.cos(0.51735432395 + 529.6909650946*t)
	X1 += 0.00000032811*np.cos(5.05742629063 + 3333.498879699*t)
	X1 += 0.00000039137*np.cos(5.37813466087 + 7477.522860216*t)
	X1 += 0.00000030785*np.cos(5.41194488124 + 1052.2683831884*t)
	X1 += 0.00000029434*np.cos(5.34740413798 + 6254.6266625236*t)
	X1 += 0.00000029948*np.cos(5.91717139203 + 553.5694028424*t)
	X1 += 0.00000029925*np.cos(2.76885151999 + 149.5631971346*t)
	X1 += 0.00000027640*np.cos(3.75118803663 + 12303.06777661*t)
	X1 += 0.00000027492*np.cos(2.19308010261 + 4933.2084403326*t)
	X1 += 0.00000028209*np.cos(4.24849741016 + 3347.7259737006*t)
	X1 += 0.00000024027*np.cos(2.99666997180 + 2810.9214616052*t)
	X1 += 0.00000021407*np.cos(0.57410988498 + 316.3918696566*t)
	X1 += 0.00000027676*np.cos(3.87446127830 + 2118.7638603784*t)
	X1 += 0.00000021284*np.cos(3.84563390414 + 4929.6853219836*t)
	X1 += 0.00000022160*np.cos(5.38045378366 + 2281.2304965106*t)
	X1 += 0.00000024653*np.cos(0.71737818564 + 382.8965322232*t)
	X1 += 0.00000019368*np.cos(0.65233184104 + 242.728603974*t)
	X1 += 0.00000018990*np.cos(2.06104675595 + 227.5261894396*t)
	X1 += 0.00000018361*np.cos(0.61249454438 + 9623.6882766912*t)
	X1 += 0.00000017087*np.cos(2.30909423712 + 3320.257107301*t)
	X1 += 0.00000016973*np.cos(0.67405360149 + 3360.96774609859*t)
	X1 += 0.00000016990*np.cos(0.50198426834 + 23384.2869868986*t)
	X1 += 0.00000016240*np.cos(0.58693834825 + 6681.1575430968*t)
	X1 += 0.00000017059*np.cos(2.70322688862 + 6674.1113063988*t)
	X1 += 0.00000014616*np.cos(1.92148810610 + 10018.3141617504*t)
	X1 += 0.00000016065*np.cos(4.24982817116 + 3325.3599555148*t)
	X1 += 0.00000016701*np.cos(0.67061213764 + 7210.9158184942*t)
	X1 += 0.00000017710*np.cos(4.03786343224 + 7740.6067835888*t)
	X1 += 0.00000015982*np.cos(5.01800237749 + 3355.8648978848*t)
	X1 += 0.00000016240*np.cos(0.17847274471 + 6681.2921637024*t)
	X1 += 0.00000013777*np.cos(1.54970744605 + 12832.7587417046*t)
	X1 += 0.00000017401*np.cos(5.84783168046 + 76.2660712756*t)
	X1 += 0.00000012859*np.cos(4.15587899834 + 110.2063212194*t)
	X1 += 0.00000014497*np.cos(0.51986042995 + 2274.1169495098*t)
	X1 += 0.00000012485*np.cos(4.09460712678 + 6682.2051744678*t)
	X1 += 0.00000012683*np.cos(0.77128314603 + 5331.3574437408*t)
	X1 += 0.00000012597*np.cos(3.06195567328 + 632.7837393132*t)
	X1 += 0.00000013623*np.cos(0.04061937918 + 2288.3440435114*t)
	X1 += 0.00000012374*np.cos(5.70562636316 + 515.463871093*t)
	X1 += 0.00000013051*np.cos(4.49310483339 + 3767.2106175758*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000011614*np.cos(2.36759996260 + 6438.4962494256*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000014620*np.cos(5.34262285752 + 4562.4609930212*t)
	X1 += 0.00000010305*np.cos(3.95759369406 + 7875.6718636242*t)
	X1 += 0.00000010643*np.cos(3.06544565234 + 5614.7293762096*t)
	X1 += 0.00000010223*np.cos(2.19747174258 + 73.297125859*t)
	X1 += 0.00000012504*np.cos(1.00423358318 + 10419.9862835076*t)
	X1 += 0.00000010339*np.cos(4.87442511701 + 10021.8545337516*t)
	X1 += 0.00000008822*np.cos(1.53728617245 + 3205.5473466644*t)
	X1 += 0.00000009014*np.cos(2.86872754290 + 199.0720014364*t)
	X1 += 0.00000011354*np.cos(0.31954807551 + 6041.3275670856*t)
	X1 += 0.00000008406*np.cos(1.44447794642 + 3475.6775067352*t)
	X1 += 0.00000008667*np.cos(4.92419711400 + 543.9180590962*t)
	X1 += 0.00000010339*np.cos(2.84366026063 + 10021.8200264472*t)
	X1 += 0.00000009717*np.cos(0.73258032600 + 6836.6452528338*t)
	X1 += 0.00000008014*np.cos(4.35110324867 + 2700.7151403858*t)
	X1 += 0.00000007685*np.cos(2.70632154072 + 103.0927742186*t)
	X1 += 0.00000008107*np.cos(0.81975962806 + 13365.9728251482*t)
	X1 += 0.00000007381*np.cos(4.07383581901 + 15643.6802033098*t)
	X1 += 0.00000007807*np.cos(4.22077494831 + 6127.6554505572*t)
	X1 += 0.00000007149*np.cos(3.01341137277 + 949.1756089698*t)
	X1 += 0.00000007035*np.cos(2.52904374075 + 5628.9564702112*t)
	X1 += 0.00000007636*np.cos(4.05071436432 + 1751.539531416*t)
	X1 += 0.00000006720*np.cos(4.61329086936 + 3178.1457905676*t)
	X1 += 0.00000006272*np.cos(3.10587190159 + 6298.3283211764*t)
	X1 += 0.00000006756*np.cos(6.16079126920 + 1596.1864422846*t)
	X1 += 0.00000006332*np.cos(4.65004753478 + 3503.079062832*t)
	X1 += 0.00000006642*np.cos(0.75164539113 + 853.196381752*t)
	X1 += 0.00000006358*np.cos(5.59134223888 + 3316.733988952*t)
	X1 += 0.00000007875*np.cos(5.63977989179 + 5729.506447149*t)
	X1 += 0.00000006284*np.cos(3.67192363783 + 3364.4908644476*t)
	X1 += 0.00000008239*np.cos(4.85475989069 + 8962.4553499102*t)
	X1 += 0.00000006726*np.cos(6.02428284097 + 9830.3890139878*t)
	X1 += 0.00000006038*np.cos(3.27619332020 + 398.1490034082*t)
	X1 += 0.00000007269*np.cos(0.63965217204 + 6894.5239488376*t)
	X1 += 0.00000005538*np.cos(5.78612814784 + 3.523118349*t)
	X1 += 0.00000005158*np.cos(1.94900517603 + 209.3669421749*t)
	X1 += 0.00000005603*np.cos(5.72285881440 + 10818.1352869158*t)
	X1 += 0.00000005079*np.cos(2.96229494906 + 217.2312487011*t)
	X1 += 0.00000005494*np.cos(4.22611242810 + 2648.454825473*t)
	X1 += 0.00000005542*np.cos(0.97325944065 + 1758.6530784168*t)
	X1 += 0.00000004856*np.cos(5.68100531716 + 1581.959348283*t)
	X1 += 0.00000006512*np.cos(5.82435708254 + 6680.2445323314*t)
	X1 += 0.00000004653*np.cos(1.72782369127 + 216.4804891757*t)
	X1 += 0.00000004541*np.cos(3.17727011849 + 210.1177017003*t)
	X1 += 0.00000005502*np.cos(1.39010072925 + 6923.9534573736*t)
	X1 += 0.00000004841*np.cos(0.46251219835 + 6158.6474353058*t)
	X1 += 0.00000004486*np.cos(0.70046720071 + 323.5054166574*t)
	X1 += 0.00000004333*np.cos(0.94382312112 + 12964.300703391*t)
	X1 += 0.00000004233*np.cos(3.49063898076 + 63.7358983034*t)
	X1 += 0.00000004783*np.cos(1.03608770138 + 6144.4203413042*t)
	X1 += 0.00000005162*np.cos(3.32530875253 + 14.2270940016*t)
	X1 += 0.00000004730*np.cos(4.22311630120 + 2914.0142358238*t)
	X1 += 0.00000003970*np.cos(0.34201626027 + 3312.163239232*t)
	X1 += 0.00000003932*np.cos(2.64182103921 + 3369.0616141676*t)
	X1 += 0.00000005131*np.cos(5.75816121607 + 8432.7643848156*t)
	X1 += 0.00000003924*np.cos(5.52177794448 + 640.8776073822*t)
	X1 += 0.00000004288*np.cos(5.22939982526 + 6151.533888305*t)
	X1 += 0.00000004172*np.cos(4.29234914799 + 735.8765135318*t)
	X1 += 0.00000003722*np.cos(4.67114753737 + 3335.0895023924*t)
	X1 += 0.00000003721*np.cos(4.59533823527 + 3346.1353510072*t)
	X1 += 0.00000004830*np.cos(4.64482449524 + 6688.3384004004*t)
	X1 += 0.00000004066*np.cos(4.97310263007 + 4032.7700279266*t)
	X1 += 0.00000003565*np.cos(2.53670247107 + 8273.8208670324*t)
	X1 += 0.00000004116*np.cos(3.14698296281 + 9866.4168806652*t)
	X1 += 0.00000003629*np.cos(1.25762240997 + 3304.5845600224*t)
	X1 += 0.00000003577*np.cos(1.72457020044 + 3376.6402933772*t)
	X1 += 0.00000004006*np.cos(3.50175662034 + 2699.7348193176*t)
	X1 += 0.00000003816*np.cos(2.98894730062 + 8969.568896911*t)
	X1 += 0.00000003417*np.cos(0.51900593403 + 10021.9045904022*t)
	X1 += 0.00000003445*np.cos(4.34972240938 + 85.8272988312*t)
	X1 += 0.00000004071*np.cos(3.46038113099 + 3863.1898447936*t)
	X1 += 0.00000003338*np.cos(2.34738225115 + 11.0457002639*t)
	X1 += 0.00000004326*np.cos(4.09031704505 + 11773.3768115154*t)
	X1 += 0.00000004227*np.cos(5.72754081349 + 2818.035008606*t)
	X1 += 0.00000003928*np.cos(3.43504403516 + 8955.3418029094*t)
	X1 += 0.00000003244*np.cos(6.04240714038 + 526.5095713569*t)
	X1 += 0.00000003567*np.cos(0.89902213787 + 1744.4259844152*t)
	X1 += 0.00000003181*np.cos(4.57837074085 + 532.8723588323*t)
	X1 += 0.00000003163*np.cos(3.19092536309 + 3980.5097130138*t)
	X1 += 0.00000003117*np.cos(3.81812196204 + 3336.7310913418*t)
	X1 += 0.00000003104*np.cos(5.44232475906 + 3344.4937620578*t)
	X1 += 0.00000003427*np.cos(0.92910700550 + 10021.7699697966*t)
	X1 += 0.00000003591*np.cos(0.86470483857 + 647.0108333148*t)
	X1 += 0.00000003818*np.cos(1.63069738341 + 6283.0758499914*t)
	X1 += 0.00000003018*np.cos(1.27275373599 + 10551.528245194*t)
	X1 += 0.00000003094*np.cos(1.78971291511 + 13358.9265884502*t)
	X1 += 0.00000002903*np.cos(4.79566936964 + 525.7588118315*t)
	X1 += 0.00000002930*np.cos(5.29397937918 + 2487.4160449478*t)
	X1 += 0.00000002864*np.cos(5.82538312855 + 533.6231183577*t)
	X1 += 0.00000002876*np.cos(2.69265723530 + 117.3198682202*t)
	X1 += 0.00000002859*np.cos(4.14824445170 + 8270.2977486834*t)
	X1 += 0.00000002833*np.cos(2.05576755359 + 202.2533951741*t)
	X1 += 0.00000002765*np.cos(1.88240993872 + 956.2891559706*t)
	X1 += 0.00000002618*np.cos(4.59592591602 + 1221.8485663214*t)
	X1 += 0.00000003149*np.cos(4.07090669467 + 5459.3762870782*t)
	X1 += 0.00000003452*np.cos(3.58033884806 + 9225.539273283*t)
	X1 += 0.00000002662*np.cos(0.62485553999 + 7632.9432596502*t)
	X1 += 0.00000002528*np.cos(5.78755929713 + 3333.5661900018*t)
	X1 += 0.00000002421*np.cos(5.22954368274 + 8429.2412664666*t)
	X1 += 0.00000002453*np.cos(5.65563006765 + 8031.0922630584*t)
	X1 += 0.00000002458*np.cos(0.21740426116 + 2766.267628365*t)
	X1 += 0.00000003009*np.cos(5.91932692843 + 3981.490034082*t)
	X1 += 0.00000002514*np.cos(0.74093420826 + 95.9792272178*t)
	X1 += 0.00000002328*np.cos(0.84599472286 + 9381.9399937854*t)
	X1 += 0.00000002302*np.cos(2.78381269678 + 1692.1656695024*t)
	X1 += 0.00000002424*np.cos(0.82684290604 + 9808.5381846614*t)
	X1 += 0.00000002276*np.cos(1.56667324357 + 5828.0284716476*t)
	X1 += 0.00000002192*np.cos(0.31892596039 + 4407.1079038898*t)
	X1 += 0.00000002225*np.cos(2.88561251745 + 3914.9572250346*t)
	X1 += 0.00000002514*np.cos(1.88526284735 + 16173.3711684044*t)
	X1 += 0.00000002437*np.cos(4.37264449561 + 11081.2192102886*t)
	X1 += 0.00000002753*np.cos(3.46421789134 + 7064.1213856228*t)
	X1 += 0.00000002044*np.cos(3.91789079559 + 6040.3472460174*t)
	X1 += 0.00000002035*np.cos(3.75853613472 + 742.9900605326*t)
	X1 += 0.00000002055*np.cos(5.42893438245 + 138.5174968707*t)
	X1 += 0.00000002107*np.cos(3.63278010781 + 15113.9892382152*t)
	X1 += 0.00000002669*np.cos(3.69099558382 + 6467.9257579616*t)
	X1 += 0.00000002140*np.cos(3.22050811027 + 3347.6586633978*t)
	X1 += 0.00000001867*np.cos(1.35298978219 + 13760.5987102074*t)
	X1 += 0.00000001717*np.cos(5.21576113138 + 13362.4669604514*t)
	X1 += 0.00000001788*np.cos(2.45204273441 + 6660.4494579072*t)
	X1 += 0.00000001744*np.cos(1.79434186275 + 6816.289933435*t)
	X1 += 0.00000002248*np.cos(2.21497893636 + 7234.794256242*t)
	X1 += 0.00000001717*np.cos(3.18498950602 + 13362.432453147*t)
	X1 += 0.00000001668*np.cos(3.43481125656 + 70.8494453042*t)
	X1 += 0.00000001739*np.cos(3.64902335469 + 3281.2385647862*t)
	X1 += 0.00000002059*np.cos(0.84035144431 + 26724.8994135984*t)
	X1 += 0.00000001638*np.cos(1.82140676523 + 74.7815985673*t)
	X1 += 0.00000001824*np.cos(5.65759439478 + 6247.5131155228*t)
	X1 += 0.00000001569*np.cos(3.26028020530 + 574.3447983348*t)
	X1 += 0.00000001698*np.cos(5.61637635354 + 3399.9862886134*t)
	X1 += 0.00000001570*np.cos(4.37765395011 + 78.7137518304*t)
	X1 += 0.00000002119*np.cos(1.71301547740 + 6872.6731195112*t)
	X1 += 0.00000001947*np.cos(3.75526731879 + 224.3447957019*t)
	X1 += 0.00000001532*np.cos(3.04023559365 + 3877.4169387952*t)
	X1 += 0.00000001628*np.cos(4.45153470682 + 10022.8176011676*t)
	X1 += 0.00000001491*np.cos(1.26055544534 + 440.8252848776*t)
	X1 += 0.00000001807*np.cos(5.37059107698 + 6696.4773245846*t)
	X1 += 0.00000001767*np.cos(2.64991278616 + 6660.8695340008*t)
	X1 += 0.00000001384*np.cos(4.29310139885 + 11216.284290324*t)
	X1 += 0.00000001690*np.cos(4.89931132759 + 7107.8230442756*t)
	X1 += 0.00000001561*np.cos(4.53702050944 + 1045.1548361876*t)
	X1 += 0.00000001473*np.cos(3.94656024828 + 8439.8779318164*t)
	X1 += 0.00000001360*np.cos(2.27641913726 + 3074.005384978*t)
	X1 += 0.00000001302*np.cos(4.55773849708 + 6665.9723822146*t)
	X1 += 0.00000001593*np.cos(1.11307060368 + 8671.9698704406*t)
	X1 += 0.00000001305*np.cos(0.97554521194 + 6701.5801727984*t)
	X1 += 0.00000001657*np.cos(5.40650209199 + 8827.3902698748*t)
	X1 += 0.00000001529*np.cos(0.56980933614 + 3546.797975137*t)
	X1 += 0.00000001527*np.cos(2.39970013340 + 3134.4268782626*t)
	X1 += 0.00000001234*np.cos(1.35920832366 + 1228.9621133222*t)
	X1 += 0.00000001498*np.cos(3.04227517263 + 10014.7237330986*t)
	X1 += 0.00000001367*np.cos(3.02383204600 + 9779.1086761254*t)
	X1 += 0.00000001230*np.cos(0.29260201065 + 11371.7046897582*t)
	X1 += 0.00000001403*np.cos(4.40495727981 + 18984.2926300096*t)
	X1 += 0.00000001219*np.cos(0.70589188231 + 3607.2194684216*t)
	X1 += 0.00000001203*np.cos(1.93922605595 + 3319.8370312074*t)
	X1 += 0.00000001400*np.cos(4.52326043784 + 5099.2655051166*t)
	X1 += 0.00000001148*np.cos(1.04852148563 + 3361.3878221922*t)
	X1 += 0.00000001515*np.cos(4.61278775683 + 6702.000248892*t)
	X1 += 0.00000001157*np.cos(1.07615224761 + 10235.1363755374*t)
	X1 += 0.00000001086*np.cos(3.25980753881 + 12935.8515159232*t)
	X1 += 0.00000001089*np.cos(2.28518675051 + 3169.9395560806*t)
	X1 += 0.00000001068*np.cos(3.73801386165 + 6684.8152820514*t)
	X1 += 0.00000001161*np.cos(4.49256510074 + 625.6701923124*t)
	X1 += 0.00000001340*np.cos(5.45392652944 + 2803.8079146044*t)
	X1 += 0.00000001057*np.cos(0.81408234263 + 10973.55568635*t)
	X1 += 0.00000001071*np.cos(2.45426009627 + 6531.661656265*t)
	X1 += 0.00000001124*np.cos(3.24778689268 + 2906.900688823*t)
	X1 += 0.00000001358*np.cos(4.09029594688 + 1039.0266107904*t)
	X1 += 0.00000001027*np.cos(5.30953853640 + 6261.7402095244*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000001082*np.cos(3.32074909820 + 6677.6344247478*t)
	X1 += 0.00000001020*np.cos(0.69684985470 + 3511.285297319*t)
	X1 += 0.00000001123*np.cos(1.64413797832 + 2921.1277828246*t)
	X1 += 0.00000001024*np.cos(5.63716730083 + 1265.5674786264*t)
	X1 += 0.00000000950*np.cos(0.11609578060 + 2125.8774073792*t)
	X1 += 0.00000000982*np.cos(0.25720172165 + 4989.0591838972*t)
	X1 += 0.00000000977*np.cos(3.76387167528 + 8425.6508378148*t)
	X1 += 0.00000000922*np.cos(4.56445665593 + 9468.267877257*t)
	X1 += 0.00000000916*np.cos(0.04652972552 + 3561.0250691386*t)
	X1 += 0.00000000918*np.cos(0.10710061200 + 13171.0014406876*t)
	X1 += 0.00000001078*np.cos(1.88392074727 + 10575.4066829418*t)
	X1 += 0.00000000887*np.cos(2.35910251121 + 3760.097070575*t)
	X1 += 0.00000000872*np.cos(2.78538821999 + 3120.199784261*t)
	X1 += 0.00000000930*np.cos(5.98147253164 + 9070.1188738488*t)
	X1 += 0.00000000880*np.cos(2.47516759962 + 3313.210870603*t)
	X1 += 0.00000001010*np.cos(1.04763118283 + 3253.30422216*t)
	X1 += 0.00000000870*np.cos(0.50700932774 + 3368.0139827966*t)
	X1 += 0.00000001000*np.cos(4.48123094738 + 9595.2390892234*t)
	X1 += 0.00000000822*np.cos(2.58495071013 + 1861.7458526354*t)
	X1 += 0.00000001079*np.cos(3.25783041382 + 1162.4747044078*t)
	X1 += 0.00000000974*np.cos(1.93461985334 + 3427.9206312396*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000001121*np.cos(1.14643572651 + 16706.585251848*t)
	X1 += 0.00000000790*np.cos(2.77256344629 + 3443.7052009184*t)
	X1 += 0.00000000943*np.cos(1.78153635749 + 151.0476698429*t)
	X1 += 0.00000000790*np.cos(4.02400070641 + 10404.7338123226*t)
	X1 += 0.00000000777*np.cos(1.90608277320 + 9168.6408983474*t)
	X1 += 0.00000000768*np.cos(4.93323770287 + 11769.8536931664*t)
	X1 += 0.00000000965*np.cos(1.55576378944 + 412.3710968744*t)
	X1 += 0.00000000917*np.cos(5.01587421292 + 3340.629680352*t)
	X1 += 0.00000000766*np.cos(2.75563594888 + 12566.1516999828*t)
	X1 += 0.00000000769*np.cos(3.16951506066 + 942.062061969*t)
	X1 += 0.00000000759*np.cos(6.06112515589 + 14158.7477136156*t)
	X1 += 0.00000000769*np.cos(3.45170371859 + 9638.9407478762*t)
	X1 += 0.00000000887*np.cos(4.63271158717 + 1169.5882514086*t)
	X1 += 0.00000000917*np.cos(2.98510265793 + 3340.5951730476*t)
	X1 += 0.00000000800*np.cos(4.79154115035 + 6518.7582172674*t)
	X1 += 0.00000000725*np.cos(3.17641441624 + 6475.0393049624*t)
	X1 += 0.00000000721*np.cos(5.76834431293 + 7903.073419721*t)
	X1 += 0.00000000725*np.cos(6.16104342327 + 1375.7737998458*t)
	X1 += 0.00000000730*np.cos(3.02102816704 + 6709.6740408674*t)
	X1 += 0.00000000925*np.cos(5.09004861088 + 11243.6858464208*t)
	X1 += 0.00000000753*np.cos(5.41546929401 + 5642.1982426092*t)
	X1 += 0.00000000797*np.cos(1.29224453150 + 16304.9131300908*t)
	X1 += 0.00000000689*np.cos(4.67900398399 + 7910.1869667218*t)
	X1 += 0.00000000750*np.cos(6.08088730030 + 3296.8935143948*t)
	X1 += 0.00000000768*np.cos(4.99147918103 + 1155.361157407*t)
	X1 += 0.00000000688*np.cos(5.00398855432 + 10028.9508271002*t)
	X1 += 0.00000000660*np.cos(1.31849975129 + 1214.7350193206*t)
	X1 += 0.00000000737*np.cos(3.18448728107 + 3384.3313390048*t)
	X1 += 0.00000000896*np.cos(5.14258755707 + 2301.58581590939*t)
	X1 += 0.00000000674*np.cos(2.97036744718 + 2807.3983432562*t)
	X1 += 0.00000000845*np.cos(0.83947970783 + 9499.2598620056*t)
	X1 += 0.00000000711*np.cos(3.39057215594 + 71.8126531507*t)
	X1 += 0.00000000627*np.cos(1.11034276522 + 13149.1506113612*t)
	X1 += 0.00000000719*np.cos(4.52061983489 + 77.7505439839*t)
	X1 += 0.00000000633*np.cos(2.81432845663 + 6604.958782124*t)
	X1 += 0.00000000612*np.cos(0.29523233872 + 3237.5196524812*t)
	X1 += 0.00000000710*np.cos(3.89492785518 + 6460.8122109608*t)
	X1 += 0.00000000701*np.cos(0.38714381576 + 3311.18291816379*t)
	X1 += 0.00000000701*np.cos(2.59503044929 + 3370.0419352358*t)
	X1 += 0.00000000727*np.cos(5.69909657510 + 2111.6503133776*t)
	X1 += 0.00000000721*np.cos(3.39819016368 + 12310.1813236108*t)
	X1 += 0.00000000634*np.cos(5.13698921586 + 692.1576012268*t)
	X1 += 0.00000000570*np.cos(4.29687682063 + 2693.601593385*t)
	X1 += 0.00000000572*np.cos(2.30412060804 + 309.2783226558*t)
	X1 += 0.00000000544*np.cos(1.97116952941 + 16699.53901514999*t)
	X1 += 0.00000000573*np.cos(2.69510600136 + 1437.1756141986*t)
	X1 += 0.00000000623*np.cos(1.72892894707 + 10264.5658840734*t)
	X1 += 0.00000000539*np.cos(0.82065219960 + 3490.1756238344*t)
	X1 += 0.00000000557*np.cos(0.85462599459 + 13362.517017102*t)
	X1 += 0.00000000647*np.cos(0.93841423909 + 4392.8808098882*t)
	X1 += 0.00000000618*np.cos(2.21502067098 + 10177.2576795336*t)
	X1 += 0.00000000537*np.cos(0.00969918132 + 3873.8265101434*t)
	X1 += 0.00000000584*np.cos(3.00944725913 + 5085.038411115*t)
	X1 += 0.00000000511*np.cos(3.07543364583 + 13517.8701062334*t)
	X1 += 0.00000000584*np.cos(2.12241430212 + 4193.8088084518*t)
	X1 += 0.00000000506*np.cos(1.37728449479 + 9485.032768004*t)
	X1 += 0.00000000510*np.cos(3.90147691268 + 277.0349937414*t)
	X1 += 0.00000000670*np.cos(5.94569787504 + 6657.3464156518*t)
	X1 += 0.00000000513*np.cos(4.94015312303 + 3232.9489027612*t)
	X1 += 0.00000000489*np.cos(4.17658939709 + 3774.3241645766*t)
	X1 += 0.00000000600*np.cos(3.74402912289 + 2707.8286873866*t)
	X1 += 0.00000000475*np.cos(2.23223934897 + 2178.137722292*t)
	X1 += 0.00000000613*np.cos(4.40036999883 + 5989.0672521728*t)
	X1 += 0.00000000492*np.cos(4.32513664928 + 3448.2759506384*t)
	X1 += 0.00000000486*np.cos(0.82245463791 + 422.6660376129*t)
	X1 += 0.00000000463*np.cos(1.38849137815 + 3229.4257844122*t)
	X1 += 0.00000000533*np.cos(3.77079193810 + 18454.601664915*t)
	X1 += 0.00000000472*np.cos(3.67184386612 + 12295.9542296092*t)
	X1 += 0.00000000546*np.cos(2.99504021759 + 2221.856634597*t)
	X1 += 0.00000000540*np.cos(0.51844562567 + 6034.2140200848*t)
	X1 += 0.00000000444*np.cos(3.95877289512 + 6705.1032911474*t)
	X1 += 0.00000000443*np.cos(1.59365772526 + 3451.7990689874*t)
	X1 += 0.00000000557*np.cos(1.26314936469 + 13362.3823964964*t)
	X1 += 0.00000000449*np.cos(3.38375864721 + 1478.8665740644*t)
	X1 += 0.00000000551*np.cos(3.37214913132 + 263.0839233728*t)
	X1 += 0.00000000494*np.cos(3.48539252825 + 13207.029307365*t)
	X1 += 0.00000000402*np.cos(1.71992380217 + 6571.0185321802*t)
	X1 += 0.00000000413*np.cos(4.34479957368 + 8799.988713778*t)
	X1 += 0.00000000421*np.cos(4.49848554474 + 4379.6390374902*t)
	X1 += 0.00000000391*np.cos(5.30832534377 + 1073.6090241908*t)
	X1 += 0.00000000472*np.cos(0.33922281030 + 4936.7988689844*t)
	X1 += 0.00000000515*np.cos(5.18562869638 + 6675.7019290922*t)
	X1 += 0.00000000477*np.cos(5.07324050899 + 7895.9598727202*t)
	X1 += 0.00000000407*np.cos(1.25884679916 + 3289.33208883739*t)
	X1 += 0.00000000407*np.cos(1.72332746589 + 3391.89276456221*t)
	X1 += 0.00000000374*np.cos(1.92168872074 + 234.6397364404*t)
	X1 += 0.00000000474*np.cos(1.74796870608 + 13892.1406718938*t)
	X1 += 0.00000000478*np.cos(4.16158691668 + 13119.72110282519*t)
	X1 += 0.00000000427*np.cos(2.86195707217 + 11614.4332937322*t)
	X1 += 0.00000000369*np.cos(5.02545575221 + 135.0650800354*t)
	X1 += 0.00000000384*np.cos(5.80577939754 + 6685.1061887576*t)
	X1 += 0.00000000392*np.cos(4.39337463856 + 6843.6914895318*t)
	X1 += 0.00000000384*np.cos(0.93539249733 + 330.6189636582*t)
	X1 += 0.00000000371*np.cos(5.54353838421 + 415.5524906121*t)
	X1 += 0.00000000370*np.cos(1.36094569476 + 3274.1250177854*t)
	X1 += 0.00000000388*np.cos(0.03030103193 + 6048.4411140864*t)
	X1 += 0.00000000363*np.cos(1.24603804228 + 20.3553193988*t)
	X1 += 0.00000000360*np.cos(1.62130663873 + 3407.0998356142*t)
	X1 += 0.00000000345*np.cos(4.59132625278 + 15.252471185*t)
	X1 += 0.00000000347*np.cos(1.29475122047 + 5724.935697429*t)
	X1 += 0.00000000453*np.cos(2.09914090460 + 3113.1362939108*t)
	X1 += 0.00000000389*np.cos(6.08882765883 + 9588.1255422226*t)
	X1 += 0.00000000422*np.cos(2.19336420550 + 19513.9835951042*t)
	X1 += 0.00000000369*np.cos(1.55138745479 + 846.0828347512*t)
	X1 += 0.00000000373*np.cos(6.01149621113 + 10020.8569590312*t)
	X1 += 0.00000000337*np.cos(4.75525977824 + 71.6002048296*t)
	X1 += 0.00000000344*np.cos(5.71003719613 + 12721.572099417*t)
	X1 += 0.00000000324*np.cos(2.28921417158 + 423.4167971383*t)
	X1 += 0.00000000359*np.cos(5.00080130209 + 9380.9596727172*t)
	X1 += 0.00000000375*np.cos(4.47591732608 + 11610.9101753832*t)
	X1 += 0.00000000335*np.cos(4.55690899534 + 2938.9403049426*t)
	X1 += 0.00000000315*np.cos(4.72280053136 + 2384.3232707292*t)
	X1 += 0.00000000340*np.cos(3.64508189959 + 7321.1221397136*t)
	X1 += 0.00000000324*np.cos(3.05393333292 + 77.962992305*t)
	X1 += 0.00000000412*np.cos(0.88247746034 + 3568.0885594888*t)
	X1 += 0.00000000374*np.cos(4.02425919317 + 3415.3940252671*t)
	X1 += 0.00000000310*np.cos(4.70848762021 + 14421.8316369884*t)
	X1 += 0.00000000344*np.cos(0.47873990239 + 1903.4368125012*t)
	X1 += 0.00000000309*np.cos(6.17856568800 + 4569.574540022*t)
	X1 += 0.00000000316*np.cos(0.91375113764 + 429.7795846137*t)
	X1 += 0.00000000364*np.cos(0.59733347069 + 860.3099287528*t)
	X1 += 0.00000000330*np.cos(2.06620388834 + 3318.7615973734*t)
	X1 += 0.00000000330*np.cos(0.91597037671 + 3362.4632560262*t)
	X1 += 0.00000000361*np.cos(2.21089537404 + 2.9689454166*t)
	X1 += 0.00000000346*np.cos(5.60772621945 + 9602.3526362242*t)
	X1 += 0.00000000329*np.cos(4.94303630669 + 10042.6126755918*t)
	X1 += 0.00000000305*np.cos(5.55791649320 + 145.6310438715*t)
	X1 += 0.00000000308*np.cos(4.74792571468 + 16460.33352952499*t)
	X1 += 0.00000000374*np.cos(4.41343415577 + 728.762966531*t)
	X1 += 0.00000000301*np.cos(0.64905373192 + 3340.6797370026*t)
	X1 += 0.00000000328*np.cos(4.85774977140 + 1272.6810256272*t)
	X1 += 0.00000000340*np.cos(4.78541899020 + 22324.9050567094*t)
	X1 += 0.00000000294*np.cos(4.55140151748 + 10596.1820784342*t)
	X1 += 0.00000000390*np.cos(2.10755320496 + 6717.252720077*t)
	X1 += 0.00000000298*np.cos(0.56249511314 + 3416.8784979754*t)
	X1 += 0.00000000291*np.cos(1.54713222563 + 6645.1969867222*t)
	X1 += 0.00000000360*np.cos(0.57790692476 + 5244.049239201*t)
	X1 += 0.00000000399*np.cos(2.01329403322 + 13916.0191096416*t)
	X1 += 0.00000000293*np.cos(3.68949232970 + 2675.8563815698*t)
	X1 += 0.00000000327*np.cos(6.16735333216 + 4459.3682188026*t)
	X1 += 0.00000000383*np.cos(6.13188528401 + 210.8514148832*t)
	X1 += 0.00000000380*np.cos(5.05058792236 + 215.7467759928*t)
	X1 += 0.00000000337*np.cos(5.55760049578 + 162.4666361322*t)
	X1 += 0.00000000304*np.cos(3.91898402784 + 7203.8022714934*t)
	X1 += 0.00000000280*np.cos(1.62615107581 + 3397.5108016354*t)
	X1 += 0.00000000280*np.cos(1.35602318924 + 3283.7140517642*t)
	X1 += 0.00000000275*np.cos(3.08102921005 + 5732.0492444298*t)
	X1 += 0.00000000301*np.cos(1.05608440560 + 3340.545116397*t)
	X1 += 0.00000000284*np.cos(3.95421107268 + 14584.2982731206*t)
	X1 += 0.00000000280*np.cos(3.40896567674 + 6688.2710900976*t)
	X1 += 0.00000000363*np.cos(2.79281358783 + 10001.061884607*t)
	X1 += 0.00000000285*np.cos(2.02354216491 + 14314.1681130498*t)
	X1 += 0.00000000305*np.cos(5.21825469861 + 3265.8308281325*t)
	X1 += 0.00000000259*np.cos(3.13103994929 + 5032.7780962022*t)
	X1 += 0.00000000338*np.cos(5.87862918623 + 148.0787244263*t)
	X1 += 0.00000000255*np.cos(2.25536828287 + 437.6438911399*t)
	X1 += 0.00000000253*np.cos(1.68801838224 + 17101.2111369072*t)
	X1 += 0.00000000251*np.cos(3.23448365420 + 11766.2632645146*t)
	X1 += 0.00000000253*np.cos(3.52319644222 + 16703.0448798468*t)
	X1 += 0.00000000253*np.cos(1.08130162107 + 6947.8318951214*t)
	X1 += 0.00000000278*np.cos(6.24528874374 + 7322.1024607818*t)
	X1 += 0.00000000311*np.cos(5.13228886176 + 838.9692877504*t)
	X1 += 0.00000000253*np.cos(5.55396848472 + 16703.07938715119*t)
	X1 += 0.00000000246*np.cos(2.73029636009 + 3304.0070613956*t)
	X1 += 0.00000000246*np.cos(0.25187790496 + 3377.217792004*t)
	X1 += 0.00000000237*np.cos(2.28726007142 + 3.9321532631*t)
	X1 += 0.00000000239*np.cos(3.57219156566 + 16276.463942623*t)
	X1 += 0.00000000239*np.cos(3.66509719573 + 11780.4903585162*t)
	X1 += 0.00000000266*np.cos(5.06649873732 + 38.1330356378*t)
	X1 += 0.00000000225*np.cos(3.64551843619 + 10018.2468514476*t)
	X1 += 0.00000000234*np.cos(1.60395818860 + 223.5940361765*t)
	X1 += 0.00000000239*np.cos(4.78918105736 + 13936.794505134*t)
	X1 += 0.00000000284*np.cos(2.13762517288 + 10156.9023601348*t)
	X1 += 0.00000000238*np.cos(4.98437875568 + 7255.5696517344*t)
	X1 += 0.00000000231*np.cos(2.49238552982 + 1485.9801210652*t)
	X1 += 0.00000000221*np.cos(5.85413979591 + 508.3503240922*t)
	X1 += 0.00000000243*np.cos(1.17853314043 + 30065.5118402982*t)
	X1 += 0.00000000219*np.cos(2.93870106015 + 5305.4510535538*t)
	X1 += 0.00000000218*np.cos(3.34948255670 + 3029.7716278314*t)
	X1 += 0.00000000240*np.cos(1.35327460265 + 2075.0449480734*t)
	X1 += 0.00000000221*np.cos(5.57663616389 + 4005.3684718298*t)
	X1 += 0.00000000223*np.cos(4.35090669349 + 23.8784377478*t)
	X1 += 0.00000000224*np.cos(4.07746567192 + 10025.4277087512*t)
	X1 += 0.00000000216*np.cos(5.71759573965 + 10037.0897512844*t)
	X1 += 0.00000000213*np.cos(5.27835961911 + 10448.4354709754*t)
	X1 += 0.00000000210*np.cos(1.47694443779 + 4555.3474460204*t)
	X1 += 0.00000000211*np.cos(3.90222929747 + 6944.3087767724*t)
	X1 += 0.00000000215*np.cos(4.18959076854 + 3212.5935833624*t)
	X1 += 0.00000000208*np.cos(2.63675343173 + 2008.557539159*t)
	X1 += 0.00000000234*np.cos(0.76568079767 + 3185.2593375684*t)
	X1 += 0.00000000215*np.cos(6.24541228185 + 1545.3539829788*t)
	X1 += 0.00000000212*np.cos(5.30591163701 + 3230.4061054804*t)
	X1 += 0.00000000253*np.cos(6.20740369502 + 16062.1845261168*t)
	X1 += 0.00000000201*np.cos(1.28338790475 + 1835.3246176068*t)
	X1 += 0.00000000209*np.cos(3.36887494837 + 16858.4825329332*t)
	X1 += 0.00000000198*np.cos(0.22514658211 + 6578.132079181*t)
	X1 += 0.00000000204*np.cos(5.07565396807 + 3468.6312700372*t)
	X1 += 0.00000000213*np.cos(0.67649924264 + 7747.7203305896*t)
	X1 += 0.00000000266*np.cos(5.05292569149 + 2277.7073781616*t)
	X1 += 0.00000000198*np.cos(1.16597531015 + 15508.6151232744*t)
	X1 += 0.00000000193*np.cos(5.91462315638 + 3651.4532255682*t)
	X1 += 0.00000000199*np.cos(2.92332691428 + 17924.9106998204*t)
	X1 += 0.00000000242*np.cos(3.82869102683 + 6621.850991486*t)
	X1 += 0.00000000220*np.cos(2.24714438581 + 3495.9655158312*t)
	X1 += 0.00000000190*np.cos(0.88866953545 + 12323.4230960088*t)
	X1 += 0.00000000192*np.cos(5.22444181613 + 2480.302497947*t)
	X1 += 0.00000000197*np.cos(1.26232029421 + 15664.03552270859*t)
	X1 += 0.00000000189*np.cos(0.28835038064 + 19402.7969528166*t)
	X1 += 0.00000000192*np.cos(4.92154638435 + 14054.607308026*t)
	X1 += 0.00000000183*np.cos(5.56570381896 + 8542.970706035*t)
	X1 += 0.00000000200*np.cos(4.07950076032 + 6677.3435180416*t)
	X1 += 0.00000000249*np.cos(1.63875770688 + 699.2711482276*t)
	X1 += 0.00000000184*np.cos(2.06454534852 + 4845.9002357928*t)
	X1 += 0.00000000183*np.cos(5.88258668238 + 533.2140834436*t)
	X1 += 0.00000000202*np.cos(1.49099779688 + 12012.5822971404*t)
	X1 += 0.00000000177*np.cos(5.39113553042 + 7380.4960016272*t)
	X1 += 0.00000000178*np.cos(0.04214387699 + 6456.8800576977*t)
	X1 += 0.00000000205*np.cos(1.56638102938 + 2945.9865416406*t)
	X1 += 0.00000000239*np.cos(0.56549194814 + 6106.8800550648*t)
	X1 += 0.00000000200*np.cos(2.99049384035 + 10001.48196070061*t)
	X1 += 0.00000000171*np.cos(4.43743888209 + 6756.0064519669*t)
	X1 += 0.00000000182*np.cos(1.09754108002 + 6887.4104018368*t)
	X1 += 0.00000000174*np.cos(3.24224963289 + 6418.1409300268*t)
	X1 += 0.00000000168*np.cos(1.47006471713 + 13575.7488022372*t)
	X1 += 0.00000000184*np.cos(3.93810691590 + 7218.029365495*t)
	X1 += 0.00000000166*np.cos(3.82858624226 + 15650.7937503106*t)
	X1 += 0.00000000168*np.cos(1.24963985652 + 5618.3198048614*t)
	X1 += 0.00000000199*np.cos(2.97222353917 + 430.5303441391*t)
	X1 += 0.00000000212*np.cos(4.80268839794 + 13363.4300278674*t)
	X1 += 0.00000000169*np.cos(0.37714459018 + 2655.5683724738*t)
	X1 += 0.00000000188*np.cos(1.83168099087 + 124.433415221*t)
	X1 += 0.00000000168*np.cos(1.37312305288 + 7314.0085927128*t)
	X1 += 0.00000000173*np.cos(0.50653444879 + 1368.660252845*t)
	X1 += 0.00000000207*np.cos(6.11286992514 + 14712.317116458*t)
	X1 += 0.00000000177*np.cos(5.21096301825 + 6686.747777707*t)
	X1 += 0.00000000166*np.cos(4.99522557947 + 1062.5633239269*t)
	X1 += 0.00000000164*np.cos(2.91444613296 + 3.1813937377*t)
	X1 += 0.00000000192*np.cos(3.27974426286 + 2751.5475996916*t)
	X1 += 0.00000000153*np.cos(4.85804008745 + 3347.2960905739*t)
	X1 += 0.00000000153*np.cos(4.40731948478 + 3333.9287628257*t)
	X1 += 0.00000000174*np.cos(1.61176269489 + 65.2203710117*t)
	X1 += 0.00000000163*np.cos(0.77052245905 + 88.865680217*t)
	X1 += 0.00000000153*np.cos(0.79359507111 + 160.6088973985*t)
	X1 += 0.00000000154*np.cos(1.98358917407 + 3499.555944483*t)
	X1 += 0.00000000151*np.cos(5.45564580430 + 10713.9948813262*t)
	X1 += 0.00000000169*np.cos(1.72784795263 + 19645.5255567906*t)
	X1 += 0.00000000154*np.cos(6.16274455061 + 519.3960243561*t)
	X1 += 0.00000000175*np.cos(0.52130528553 + 8982.810669309*t)
	X1 += 0.00000000188*np.cos(2.80365997800 + 1332.0548875408*t)
	X1 += 0.00000000195*np.cos(0.42819289586 + 6546.1597733642*t)
	X1 += 0.00000000153*np.cos(1.34899298445 + 12722.5524204852*t)
	X1 += 0.00000000158*np.cos(4.60986821977 + 14556.8967170238*t)
	X1 += 0.00000000171*np.cos(4.49567777458 + 1062.9050485382*t)
	X1 += 0.00000000171*np.cos(0.56475191630 + 2391.43681773*t)
	X1 += 0.00000000140*np.cos(5.84592048082 + 1258.4539316256*t)
	X1 += 0.00000000185*np.cos(4.33527974597 + 2409.249339848*t)
	X1 += 0.00000000179*np.cos(6.25811741113 + 20.7753954924*t)
	X1 += 0.00000000143*np.cos(2.17166434379 + 1505.28780909299*t)
	X1 += 0.00000000152*np.cos(0.66722406763 + 9389.0535407862*t)
	X1 += 0.00000000138*np.cos(5.22139410630 + 1055.4497769261*t)
	X1 += 0.00000000148*np.cos(3.00263900859 + 3053.6500655792*t)
	X1 += 0.00000000140*np.cos(0.90450305556 + 6691.8615187494*t)
	X1 += 0.00000000135*np.cos(4.10212923465 + 2604.735913168*t)
	X1 += 0.00000000135*np.cos(5.16323033758 + 4076.4889402316*t)
	X1 += 0.00000000134*np.cos(2.23334811023 + 3191.0492295652*t)
	X1 += 0.00000000177*np.cos(1.67456433042 + 8958.9322315612*t)
	X1 += 0.00000000178*np.cos(1.87772953896 + 2284.7536148596*t)
	X1 += 0.00000000132*np.cos(0.46806671232 + 654.1243803156*t)
	X1 += 0.00000000175*np.cos(4.86229323516 + 8965.9784682592*t)
	X1 += 0.00000000160*np.cos(4.45487960287 + 2494.5295919486*t)
	X1 += 0.00000000138*np.cos(1.47418494330 + 20047.1976785478*t)
	X1 += 0.00000000128*np.cos(0.92352133267 + 9374.8264467846*t)
	X1 += 0.00000000132*np.cos(5.64348485151 + 7366.2689076256*t)
	X1 += 0.00000000134*np.cos(3.33556330332 + 203.0041546995*t)
	X1 += 0.00000000152*np.cos(1.23461889422 + 4672.6673142406*t)
	X1 += 0.00000000173*np.cos(1.67113077977 + 19004.6479494084*t)
	X1 += 0.00000000158*np.cos(5.98697230845 + 3929.677253708*t)
	X1 += 0.00000000126*np.cos(4.78413400650 + 6148.010769956*t)
	X1 += 0.00000000126*np.cos(4.40104234637 + 11670.2840372968*t)
	X1 += 0.00000000133*np.cos(1.12155584770 + 12839.8722887054*t)
	X1 += 0.00000000137*np.cos(5.81509659853 + 6674.1786167016*t)
	X1 += 0.00000000149*np.cos(4.52388789068 + 3077.528503327*t)
	X1 += 0.00000000125*np.cos(1.44691455296 + 36.0278666774*t)
	X1 += 0.00000000146*np.cos(2.09359464470 + 3397.4156888696*t)
	X1 += 0.00000000146*np.cos(0.88857962035 + 3283.80916453*t)
	X1 += 0.00000000157*np.cos(3.39004226467 + 3450.8187479192*t)
	X1 += 0.00000000154*np.cos(5.27624866771 + 12168.0026965746*t)
	X1 += 0.00000000162*np.cos(5.99305553804 + 5518.7501489918*t)
	X1 += 0.00000000126*np.cos(5.23539499383 + 13553.8979729108*t)
	X1 += 0.00000000133*np.cos(6.26348452529 + 3627.57478782039*t)
	X1 += 0.00000000124*np.cos(1.40431448992 + 6593.9166488598*t)
	X1 += 0.00000000120*np.cos(0.17691589754 + 1063.3140834523*t)
	X1 += 0.00000000125*np.cos(3.06728736345 + 18606.4989460002*t)
	X1 += 0.00000000123*np.cos(2.92428130894 + 15906.7641266826*t)
	X1 += 0.00000000117*np.cos(2.48675823285 + 3337.106562003*t)
	X1 += 0.00000000117*np.cos(3.63700868579 + 3344.11829139661*t)
	X1 += 0.00000000147*np.cos(2.64686332853 + 6510.5519827804*t)
	X1 += 0.00000000119*np.cos(2.67568218000 + 15265.8865193004*t)
	X1 += 0.00000000117*np.cos(5.66778031729 + 3344.152798701*t)
	X1 += 0.00000000117*np.cos(0.45598660135 + 3337.0720546986*t)
	X1 += 0.00000000118*np.cos(5.77425794908 + 9886.772200064*t)
	X1 += 0.00000000118*np.cos(4.77280443966 + 551.031606097*t)
	X1 += 0.00000000154*np.cos(2.03792935277 + 3133.9116894032*t)
	X1 += 0.00000000118*np.cos(0.07858750158 + 3317.8439300904*t)
	X1 += 0.00000000118*np.cos(2.90358676347 + 3363.3809233092*t)
	X1 += 0.00000000158*np.cos(3.42513552451 + 0.9803210682*t)
	X1 += 0.00000000117*np.cos(2.63259162370 + 3184.2117061974*t)
	X1 += 0.00000000117*np.cos(0.34958264135 + 3497.0131472022*t)
	X1 += 0.00000000120*np.cos(4.45697558744 + 539.9859058331*t)
	X1 += 0.00000000115*np.cos(3.42928363203 + 6724.9437657046*t)
	X1 += 0.00000000114*np.cos(1.78485255818 + 5820.9149246468*t)
	X1 += 0.00000000114*np.cos(1.36878094205 + 9065.5481241288*t)
	X1 += 0.00000000124*np.cos(4.75081143126 + 2631.6226244232*t)
	X1 += 0.00000000140*np.cos(5.86589845886 + 1056.2005364515*t)
	X1 += 0.00000000118*np.cos(2.00813775574 + 4025.6564809258*t)
	X1 += 0.00000000135*np.cos(4.74860182927 + 3603.6963500726*t)
	X1 += 0.00000000119*np.cos(0.46273681956 + 16511.6138673874*t)
	X1 += 0.00000000155*np.cos(2.36780510491 + 6155.057006654*t)
	X1 += 0.00000000115*np.cos(4.80039490722 + 6997.6167230562*t)
	X1 += 0.00000000111*np.cos(5.69390808885 + 222.8603229936*t)
	X1 += 0.00000000133*np.cos(4.62837772547 + 22.0914005278*t)
	X1 += 0.00000000119*np.cos(3.37046808379 + 4447.7512323846*t)
	X1 += 0.00000000114*np.cos(3.09767238718 + 3987.6232600146*t)
	X1 += 0.00000000110*np.cos(1.50396104090 + 87.30820453981*t)
	X1 += 0.00000000138*np.cos(6.15843764702 + 2233.473621015*t)
	X1 += 0.00000000131*np.cos(0.53786654009 + 6901.6374958384*t)
	X1 += 0.00000000112*np.cos(2.08380141682 + 22345.2603761082*t)
	X1 += 0.00000000108*np.cos(4.30979711000 + 2973.3880977374*t)
	X1 += 0.00000000115*np.cos(2.50244363406 + 36.6053653042*t)
	X1 += 0.00000000108*np.cos(5.05364311472 + 19800.9459562248*t)
	X1 += 0.00000000111*np.cos(3.72624023806 + 6357.7194367422*t)
	X1 += 0.00000000145*np.cos(0.99358639575 + 2060.8178540718*t)
	X1 += 0.00000000112*np.cos(3.97083451330 + 2574.8193622534*t)
	X1 += 0.00000000139*np.cos(0.94728626821 + 3547.3131639964*t)
	X1 += 0.00000000122*np.cos(4.41872868475 + 3346.4696289994*t)
	X1 += 0.00000000122*np.cos(4.84663088748 + 3334.7552244002*t)
	X1 += 0.00000000144*np.cos(1.47900802038 + 299.1263942692*t)
	X1 += 0.00000000119*np.cos(1.32555855483 + 10213.285546211*t)
	X1 += 0.00000000144*np.cos(6.22129817518 + 1905.4647649404*t)
	X1 += 0.00000000140*np.cos(6.09857806608 + 6670.5881880498*t)
	X1 += 0.00000000134*np.cos(3.16966777445 + 21.3406410024*t)
	X1 += 0.00000000100*np.cos(2.58315361675 + 17917.79715281959*t)
	X1 += 0.00000000106*np.cos(3.77034034448 + 13745.3462390224*t)
	X1 += 0.00000000120*np.cos(2.98017967977 + 3370.1042450032*t)
	X1 += 0.00000000120*np.cos(0.00199458528 + 3311.1206083964*t)
	X1 += 0.00000000118*np.cos(2.40172384456 + 6606.4432548323*t)
	X1 += 0.00000000097*np.cos(5.41467539027 + 18.1592472647*t)
	X1 += 0.00000000132*np.cos(5.74618131270 + 3050.1269472302*t)
	X1 += 0.00000000096*np.cos(3.08170402360 + 191.9584544356*t)
	X1 += 0.00000000106*np.cos(5.77400557563 + 2641.3412784722*t)
	X1 += 0.00000000096*np.cos(5.75684065935 + 1118.7557921028*t)
	X1 += 0.00000000101*np.cos(3.76810604314 + 10124.930054318*t)
	X1 += 0.00000000104*np.cos(1.92319744263 + 4296.9015826704*t)
	X1 += 0.00000000111*np.cos(1.28913302911 + 10042.1925994982*t)
	X1 += 0.00000000094*np.cos(1.36125916148 + 17468.8551979454*t)
	X1 += 0.00000000120*np.cos(4.77545420807 + 1574.8458012822*t)
	X1 += 0.00000000094*np.cos(3.31739742370 + 87.3117715395*t)
	X1 += 0.00000000101*np.cos(1.27086316315 + 33.6796175129*t)
	X1 += 0.00000000096*np.cos(4.84024975949 + 10006.5848089144*t)
	X1 += 0.00000000094*np.cos(0.85293916684 + 2679.3794999188*t)
	X1 += 0.00000000108*np.cos(1.41232833732 + 3735.238311759*t)
	X1 += 0.00000000092*np.cos(4.97009844077 + 3707.8367556622*t)
	X1 += 0.00000000097*np.cos(3.70150649705 + 2922.1081038928*t)
	X1 += 0.00000000109*np.cos(3.81691606800 + 11250.7993934216*t)
	X1 += 0.00000000092*np.cos(6.04182543036 + 2540.7913015344*t)
	X1 += 0.00000000126*np.cos(4.88607866833 + 4271.9755135516*t)
	X1 += 0.00000000095*np.cos(0.10422807800 + 59.3738619136*t)
	X1 += 0.00000000110*np.cos(5.54106438691 + 4106.4054911462*t)
	X1 += 0.00000000122*np.cos(0.24302263595 + 84.3428261229*t)
	X1 += 0.00000000115*np.cos(3.52051514601 + 9815.6517316622*t)
	X1 += 0.00000000093*np.cos(3.71904554876 + 2771.7905526724*t)
	X1 += 0.00000000100*np.cos(1.66203445799 + 26887.3660497306*t)
	X1 += 0.00000000104*np.cos(2.35767081244 + 11925.2740926006*t)
	X1 += 0.00000000113*np.cos(0.21883124871 + 4922.5717749828*t)
	X1 += 0.00000000097*np.cos(5.87982327909 + 217.964961884*t)
	X1 += 0.00000000109*np.cos(4.06648304067 + 21795.21409161479*t)
	X1 += 0.00000000096*np.cos(6.11433665301 + 1795.258443721*t)
	X1 += 0.00000000091*np.cos(4.41382868784 + 4049.6022289764*t)
	X1 += 0.00000000086*np.cos(0.86878584025 + 17654.7805397496*t)
	X1 += 0.00000000119*np.cos(3.51878936510 + 3631.0979061694*t)
	X1 += 0.00000000087*np.cos(3.32576161903 + 231.4583427027*t)
	X1 += 0.00000000097*np.cos(1.64179644592 + 72.3339180125*t)
	X1 += 0.00000000089*np.cos(5.45720829907 + 628.8515860501*t)
	X1 += 0.00000000098*np.cos(2.27543509085 + 6768.5330579394*t)
	X1 += 0.00000000095*np.cos(4.80180777978 + 10706.8813343254*t)
	X1 += 0.00000000084*np.cos(0.40663774606 + 3152.68727893721*t)
	X1 += 0.00000000093*np.cos(2.83658856377 + 2538.2485042536*t)
	X1 += 0.00000000088*np.cos(5.00348782624 + 1699.2792165032*t)
	X1 += 0.00000000085*np.cos(1.40832176676 + 16489.763038061*t)
	X1 += 0.00000000094*np.cos(6.05010322728 + 12942.965062924*t)
	X1 += 0.00000000107*np.cos(1.79283820861 + 6286.5989683404*t)
	X1 += 0.00000000081*np.cos(1.26377078095 + 12.5301729722*t)
	X1 += 0.00000000081*np.cos(2.07730423259 + 3326.3853326982*t)
	X1 += 0.00000000081*np.cos(0.90487003246 + 3354.8395207014*t)
	X1 += 0.00000000082*np.cos(5.23339031416 + 1442.2612087602*t)
	X1 += 0.00000000079*np.cos(4.56396980209 + 18208.349942592*t)
	X1 += 0.00000000079*np.cos(3.07988237612 + 4777.7880408984*t)
	X1 += 0.00000000083*np.cos(5.56382700928 + 3759.1167495068*t)
	X1 += 0.00000000085*np.cos(4.56854166929 + 42942.50433914939*t)
	X1 += 0.00000000086*np.cos(3.03921945697 + 127.4717966068*t)
	X1 += 0.00000000079*np.cos(4.26906442068 + 3378.7454623376*t)
	X1 += 0.00000000079*np.cos(4.99629515155 + 3302.479391062*t)
	X1 += 0.00000000080*np.cos(6.17200069363 + 4142.976349146*t)
	X1 += 0.00000000079*np.cos(2.75167670672 + 9947.0556815321*t)
	X1 += 0.00000000109*np.cos(5.81788706036 + 765.7930644464*t)
	X1 += 0.00000000102*np.cos(4.48912094824 + 10721.108428327*t)
	X1 += 0.00000000106*np.cos(3.49629147004 + 21947.11137270*t)
	X1 += 0.00000000087*np.cos(0.74054571271 + 3181.6689089166*t)
	X1 += 0.00000000085*np.cos(5.30523639998 + 208.633228992*t)
	X1 += 0.00000000092*np.cos(0.03551083643 + 2171.0241752912*t)
	X1 += 0.00000000106*np.cos(0.39435918202 + 7214.4389368432*t)
	X1 += 0.00000000080*np.cos(4.89623642688 + 21548.9623692918*t)
	X1 += 0.00000000095*np.cos(3.86710302337 + 1655.5603041982*t)
	X1 += 0.00000000079*np.cos(3.24890951492 + 5562.4690612968*t)
	X1 += 0.00000000090*np.cos(1.80974604093 + 685.044054226*t)
	X1 += 0.00000000077*np.cos(2.05069186337 + 4001.8453534808*t)
	X1 += 0.00000000083*np.cos(2.81952591797 + 18451.07854656599*t)
	X1 += 0.00000000103*np.cos(4.88584162251 + 6279.5527316424*t)
	X1 += 0.00000000076*np.cos(3.67755551442 + 1107.1388056848*t)
	X1 += 0.00000000080*np.cos(4.03019573108 + 1471.7530270636*t)
	X1 += 0.00000000076*np.cos(5.75771357218 + 288.0806940053*t)
	X1 += 0.00000000075*np.cos(2.93994155162 + 6710.6543619356*t)
	X1 += 0.00000000075*np.cos(5.60783359680 + 3528.5375744624*t)
	X1 += 0.00000000100*np.cos(2.80459580595 + 6653.8232973028*t)
	X1 += 0.00000000085*np.cos(4.61572252590 + 3649.8907493556*t)
	X1 += 0.00000000085*np.cos(4.64963704633 + 3031.334104044*t)
	X1 += 0.00000000077*np.cos(5.54299564494 + 3909.4343007272*t)
	X1 += 0.00000000102*np.cos(4.85789296676 + 3282.733730696*t)
	X1 += 0.00000000102*np.cos(4.40746660547 + 3398.4911227036*t)
	X1 += 0.00000000079*np.cos(5.10886333624 + 12725.453434775*t)
	X1 += 0.00000000077*np.cos(0.97230677876 + 20199.02764933019*t)
	X1 += 0.00000000096*np.cos(6.22255663987 + 203.7378678824*t)
	X1 += 0.00000000073*np.cos(5.35302732038 + 13369.56325380*t)
	X1 += 0.00000000097*np.cos(1.78236800999 + 6784.3176276182*t)
	X1 += 0.00000000076*np.cos(2.30483356242 + 42153.969003049*t)
	X1 += 0.00000000092*np.cos(2.49268078499 + 3492.509707785*t)
	X1 += 0.00000000076*np.cos(2.72692408287 + 19403.7772738848*t)
	X1 += 0.00000000080*np.cos(4.32028390750 + 8756.269801473*t)
	X1 += 0.00000000073*np.cos(2.28908779860 + 6364.832983743*t)
	X1 += 0.00000000077*np.cos(2.43358799510 + 6549.6828917132*t)
	X1 += 0.00000000076*np.cos(0.40948960322 + 362.8622925726*t)
	X1 += 0.00000000072*np.cos(3.81559276845 + 302.164775655*t)
	X1 += 0.00000000088*np.cos(1.61112169044 + 7373.3824546264*t)
	X1 += 0.00000000088*np.cos(6.05418512374 + 11883.5831327348*t)
	X1 += 0.00000000076*np.cos(2.05515548312 + 1648.4467571974*t)
	X1 += 0.00000000075*np.cos(1.95113506965 + 525.0250986486*t)
	X1 += 0.00000000093*np.cos(3.37029033662 + 10050.2864675672*t)
	X1 += 0.00000000069*np.cos(3.45210180674 + 45088.6697556246*t)
	X1 += 0.00000000071*np.cos(1.53845739804 + 2067.9314010726*t)
	X1 += 0.00000000077*np.cos(1.09192682751 + 14128.2427712456*t)
	X1 += 0.00000000069*np.cos(4.21368560293 + 114.3991069134*t)
	X1 += 0.00000000068*np.cos(0.64071253014 + 153.4953503977*t)
	X1 += 0.00000000077*np.cos(0.47271097966 + 5466.489834079*t)
	X1 += 0.00000000068*np.cos(0.16388050208 + 9.5612275556*t)
	X1 += 0.00000000068*np.cos(0.99582401938 + 73.8183907208*t)
	X1 += 0.00000000079*np.cos(1.37643636344 + 3329.5667264359*t)
	X1 += 0.00000000079*np.cos(1.60573790161 + 3351.6581269637*t)
	X1 += 0.00000000074*np.cos(4.22088803290 + 25135.8265183146*t)
	X1 += 0.00000000073*np.cos(5.09768244843 + 10177.1903692308*t)
	X1 += 0.00000000067*np.cos(4.84562417862 + 5401.4302807716*t)
	X1 += 0.00000000074*np.cos(5.01417193973 + 15636.566656309*t)
	X1 += 0.00000000069*np.cos(5.04985271939 + 11353.8921676402*t)
	X1 += 0.00000000070*np.cos(1.71545157762 + 20809.4676246452*t)
	X1 += 0.00000000070*np.cos(3.89845786360 + 35707.7100829074*t)
	X1 += 0.00000000076*np.cos(3.13060444340 + 41748.0573289248*t)
	X1 += 0.00000000092*np.cos(6.14040930433 + 3613.2853840514*t)
	X1 += 0.00000000071*np.cos(2.38708525663 + 534.3568315406*t)
	X1 += 0.00000000093*np.cos(2.21933485500 + 8584.6616659008*t)
	X1 += 0.00000000071*np.cos(5.64728262188 + 1279.794572628*t)
	X1 += 0.00000000068*np.cos(3.93351376319 + 25287.7237993998*t)
	X1 += 0.00000000066*np.cos(5.64046802071 + 2011.1003364398*t)
	X1 += 0.00000000088*np.cos(3.09948179111 + 3067.9394693482*t)
	X1 += 0.00000000074*np.cos(2.14829362492 + 3264.3463554242*t)
	X1 += 0.00000000065*np.cos(5.23756710566 + 8859.3625756916*t)
	X1 += 0.00000000069*np.cos(1.59516547033 + 43738.8023459658*t)
	X1 += 0.00000000068*np.cos(4.77227301127 + 44959.5476759902*t)
	X1 += 0.00000000065*np.cos(0.76344895489 + 6708.6264094964*t)
	X1 += 0.00000000090*np.cos(5.15547486786 + 6740.5987153132*t)
	X1 += 0.00000000064*np.cos(4.35344254893 + 9801.4246376606*t)
	X1 += 0.00000000065*np.cos(0.10650340635 + 4140.4335518652*t)
	X1 += 0.00000000079*np.cos(0.61232080062 + 2125.8100970764*t)
	X1 += 0.00000000064*np.cos(0.53528518109 + 75.7448064138*t)
	X1 += 0.00000000087*np.cos(5.05289595532 + 9859.3706439672*t)
	X1 += 0.00000000065*np.cos(0.93949119244 + 6680.804777306*t)
	X1 += 0.00000000064*np.cos(1.91199168938 + 4356.275444584*t)
	X1 += 0.00000000064*np.cos(2.03767686794 + 169.580183133*t)
	X1 += 0.00000000067*np.cos(3.96144093290 + 11236.57229942*t)
	X1 += 0.00000000066*np.cos(1.08249803836 + 3414.213382615*t)
	X1 += 0.00000000066*np.cos(1.89967622669 + 3267.0114707846*t)
	X1 += 0.00000000072*np.cos(1.91502043985 + 16858.41522263039*t)
	X1 += 0.00000000064*np.cos(0.70379327004 + 3193.8007401762*t)
	X1 += 0.00000000064*np.cos(2.27838099501 + 3487.4241132234*t)
	X1 += 0.00000000084*np.cos(3.00203948568 + 43340.6533425576*t)
	X1 += 0.00000000062*np.cos(3.24790025898 + 18461.71521191579*t)
	X1 += 0.00000000068*np.cos(4.85546258492 + 12808.8803039568*t)
	X1 += 0.00000000068*np.cos(1.99986373490 + 6614.7374444852*t)
	X1 += 0.00000000085*np.cos(3.13403835930 + 10730.82708237599*t)
	X1 += 0.00000000066*np.cos(6.17786477200 + 42.5864537627*t)
	X1 += 0.00000000066*np.cos(0.00739681430 + 9997.9588423516*t)
	X1 += 0.00000000061*np.cos(2.88776849923 + 207.8824694666*t)
	X1 += 0.00000000065*np.cos(6.00702384673 + 40796.33892267419*t)
	X1 += 0.00000000060*np.cos(1.33665515740 + 31022.7531708562*t)
	X1 += 0.00000000078*np.cos(4.87574960971 + 5202.3582793352*t)
	X1 += 0.00000000062*np.cos(2.19007422012 + 20040.15144184979*t)
	X1 += 0.00000000062*np.cos(4.40813798952 + 931.3630868518*t)
	X1 += 0.00000000067*np.cos(3.79488721755 + 17256.6315363414*t)
	X1 += 0.00000000063*np.cos(4.58199428968 + 25841.29320224219*t)
	X1 += 0.00000000083*np.cos(1.19841622691 + 40398.189919266*t)
	X1 += 0.00000000060*np.cos(2.02282855033 + 218.7157214094*t)
	X1 += 0.00000000059*np.cos(3.38669312921 + 15121.102785216*t)
	X1 += 0.00000000070*np.cos(0.83559773197 + 52.6901980395*t)
	X1 += 0.00000000063*np.cos(1.57226486603 + 20742.9457084264*t)
	X1 += 0.00000000059*np.cos(1.24623136375 + 408.4389436113*t)
	X1 += 0.00000000060*np.cos(5.59502027006 + 10016.314355792*t)
	X1 += 0.00000000059*np.cos(1.02843579673 + 4039.8835749274*t)
	X1 += 0.00000000077*np.cos(3.19342928141 + 24606.13555322*t)
	X1 += 0.00000000067*np.cos(4.66236805003 + 9329.6796788726*t)
	X1 += 0.00000000067*np.cos(0.58534149028 + 152.5321425512*t)
	X1 += 0.00000000077*np.cos(3.07641411027 + 4775.7600884592*t)
	X1 += 0.00000000064*np.cos(0.87689051214 + 22743.4093795164*t)
	X1 += 0.00000000076*np.cos(0.10784891475 + 77.2292791221*t)
	X1 += 0.00000000080*np.cos(2.57223661352 + 27417.0570148252*t)
	X1 += 0.00000000057*np.cos(0.14845243910 + 12928.7379689224*t)
	X1 += 0.00000000064*np.cos(3.30054842989 + 79.2350166922*t)
	X1 += 0.00000000057*np.cos(6.14189596874 + 3116.2676309979*t)
	X1 += 0.00000000072*np.cos(0.71597283003 + 20213.25474333179*t)
	X1 += 0.00000000062*np.cos(1.28366951998 + 12988.111830836*t)
	X1 += 0.00000000061*np.cos(0.45486168004 + 56.6223513026*t)
	X1 += 0.00000000059*np.cos(1.99226268966 + 5945.3483398678*t)
	X1 += 0.00000000058*np.cos(0.15519898436 + 15423.267560871*t)
	X1 += 0.00000000063*np.cos(2.24244167800 + 9161.5273513466*t)
	X1 += 0.00000000062*np.cos(2.96487774215 + 3357.44462774959*t)
	X1 += 0.00000000062*np.cos(0.01729652290 + 3323.78022565*t)
	X1 += 0.00000000055*np.cos(3.57207397234 + 340.7708920448*t)
	X1 += 0.00000000056*np.cos(3.18297061340 + 2978.491289969*t)
	X1 += 0.00000000056*np.cos(6.08238895883 + 3702.7335634306*t)
	X1 += 0.00000000058*np.cos(0.08427617394 + 45884.967762441*t)
	X1 += 0.00000000055*np.cos(0.16321552353 + 21150.8133658836*t)
	X1 += 0.00000000055*np.cos(5.55880158727 + 12715.4388734844*t)
	X1 += 0.00000000055*np.cos(4.28741629288 + 23539.7073863328*t)
	X1 += 0.00000000055*np.cos(3.08168513239 + 200.7689224658*t)
	X1 += 0.00000000068*np.cos(4.10576652903 + 14867.73751589219*t)
	X1 += 0.00000000076*np.cos(2.25541605095 + 146.594251718*t)
	X1 += 0.00000000060*np.cos(5.32793915897 + 831.8557407496*t)
	X1 += 0.00000000054*np.cos(2.83216128661 + 1.4844727083*t)
	X1 += 0.00000000066*np.cos(5.83578469159 + 618.5566453116*t)
	X1 += 0.00000000054*np.cos(1.14764721709 + 5607.6158292088*t)
	X1 += 0.00000000053*np.cos(4.66773371614 + 6788.8883773382*t)
	X1 += 0.00000000058*np.cos(1.79522116123 + 3412.6681600546*t)
	X1 += 0.00000000058*np.cos(1.18695310382 + 3268.556693345*t)
	X1 += 0.00000000053*np.cos(3.76957096107 + 14481.205498902*t)
	X1 += 0.00000000052*np.cos(4.72089853524 + 6812.766815086*t)
	X1 += 0.00000000054*np.cos(1.09546286956 + 18849.2275499742*t)
	X1 += 0.00000000059*np.cos(0.84746741291 + 5223.6939198022*t)
	X1 += 0.00000000058*np.cos(0.97037460116 + 4.4534181249*t)
	X1 += 0.00000000052*np.cos(1.21145236574 + 4885.9664096786*t)
	X1 += 0.00000000072*np.cos(2.61949743639 + 3339.1279539915*t)
	X1 += 0.00000000072*np.cos(0.36267682866 + 3342.0968994081*t)
	X1 += 0.00000000051*np.cos(1.67605837812 + 45486.81875903279*t)
	X1 += 0.00000000056*np.cos(3.58453638929 + 8742.0427074714*t)
	X1 += 0.00000000051*np.cos(3.56752380688 + 225.8292684102*t)
	X1 += 0.00000000051*np.cos(4.54732927101 + 62.2514255951*t)
	X1 += 0.00000000051*np.cos(0.67722361596 + 16328.72425753579*t)
	X1 += 0.00000000056*np.cos(3.08675956518 + 38252.0245027908*t)
	X1 += 0.00000000051*np.cos(6.16661497571 + 12410.7313005486*t)
	X1 += 0.00000000051*np.cos(2.81432959139 + 8226.5788363784*t)
	X1 += 0.00000000050*np.cos(4.84629478021 + 195.1398481733*t)
	X1 += 0.00000000054*np.cos(3.63357334815 + 2735.762685995*t)
	X1 += 0.00000000050*np.cos(4.57016485329 + 37895.4262903674*t)
	X1 += 0.00000000052*np.cos(0.45515480683 + 24491.4257925834*t)
	X1 += 0.00000000061*np.cos(4.37761588455 + 2655.501062171*t)
	X1 += 0.00000000059*np.cos(5.82888387525 + 12516.366872048*t)
	X1 += 0.00000000050*np.cos(1.66655026369 + 1727.6610936682*t)
	X1 += 0.00000000066*np.cos(5.34326577091 + 24889.5747959916*t)
	X1 += 0.00000000050*np.cos(0.17458517639 + 39048.3225096072*t)
	X1 += 0.00000000050*np.cos(3.27629040044 + 3564.9572224017*t)
	X1 += 0.00000000049*np.cos(2.48409394399 + 20597.2439630412*t)
	X1 += 0.00000000049*np.cos(4.63364250237 + 24341.5283174566*t)
	X1 += 0.00000000052*np.cos(4.61821041475 + 70.3281804424*t)
	X1 += 0.00000000050*np.cos(3.76507954507 + 3742.284548457*t)
	X1 += 0.00000000049*np.cos(4.31351627712 + 350.3321196004*t)
	X1 += 0.00000000048*np.cos(1.55434770619 + 1883.0814931024*t)
	X1 += 0.00000000049*np.cos(3.03989562226 + 55516.4187098482*t)
	X1 += 0.00000000061*np.cos(3.94494596275 + 19617.07636932279*t)
	X1 += 0.00000000048*np.cos(1.52458359680 + 19190.4781784468*t)
	X1 += 0.00000000058*np.cos(5.44186494913 + 6850.8050365326*t)
	X1 += 0.00000000048*np.cos(1.96356727887 + 32765.2466596158*t)
	X1 += 0.00000000047*np.cos(2.93243058228 + 33163.395663024*t)
	X1 += 0.00000000048*np.cos(4.86897928188 + 10191.4174632324*t)
	X1 += 0.00000000051*np.cos(4.70671034765 + 5749.8617665478*t)
	X1 += 0.00000000048*np.cos(3.54075354094 + 8186.5126624926*t)
	X1 += 0.00000000051*np.cos(1.79926614465 + 210.3783341312*t)
	X1 += 0.00000000051*np.cos(3.07938265367 + 216.2198567448*t)
	X1 += 0.00000000056*np.cos(3.12983717848 + 21265.5231265202*t)
	X1 += 0.00000000047*np.cos(0.77055080600 + 11876.469585734*t)
	X1 += 0.00000000047*np.cos(5.80552800681 + 2257.3520587628*t)
	X1 += 0.00000000047*np.cos(0.45636881038 + 17412.0519357756*t)
	X1 += 0.00000000046*np.cos(4.54640434990 + 16865.5287696312*t)
	X1 += 0.00000000052*np.cos(0.28783495350 + 1971.9521738548*t)
	X1 += 0.00000000046*np.cos(1.52797216731 + 44768.0994098786*t)
	X1 += 0.00000000051*np.cos(4.39123984507 + 5408.5438277724*t)
	X1 += 0.00000000049*np.cos(5.92307582908 + 963.4027029714*t)
	X1 += 0.00000000064*np.cos(3.04718021414 + 1329.51209026*t)
	X1 += 0.00000000049*np.cos(4.82698586048 + 41194.4879260824*t)
	X1 += 0.00000000055*np.cos(4.04641676667 + 4403.517475238*t)
	X1 += 0.00000000048*np.cos(0.33955507055 + 14955.045720432*t)
	X1 += 0.00000000053*np.cos(1.27341801656 + 142.4496501338*t)
	X1 += 0.00000000059*np.cos(2.13527332496 + 4289.7880356696*t)
	X1 += 0.00000000048*np.cos(1.20681354241 + 7799.9806455024*t)
	X1 += 0.00000000048*np.cos(0.93062224202 + 1859.2030553546*t)
	X1 += 0.00000000052*np.cos(2.17634391560 + 2963.238818784*t)
	X1 += 0.00000000052*np.cos(0.80583034945 + 3717.9860346156*t)
	X1 += 0.00000000055*np.cos(5.22964407608 + 41236.0387170672*t)
	X1 += 0.00000000060*np.cos(5.46859138107 + 10184.3039162316*t)
	X1 += 0.00000000054*np.cos(1.04311727476 + 1055.8588118402*t)
	X1 += 0.00000000045*np.cos(4.80760215190 + 37.611770776*t)
	X1 += 0.00000000045*np.cos(3.15304645241 + 3973.396166013*t)
	X1 += 0.00000000046*np.cos(0.11011885467 + 5881.4037282342*t)
	X1 += 0.00000000044*np.cos(5.80928344240 + 3436.5916539176*t)
	X1 += 0.00000000044*np.cos(3.45607612983 + 3244.633199482*t)
	X1 += 0.00000000044*np.cos(6.06741551089 + 17499.3601403154*t)
	X1 += 0.00000000050*np.cos(4.51633294079 + 1038.0412891868*t)
	X1 += 0.00000000044*np.cos(5.63991949724 + 524.2743391232*t)
	X1 += 0.00000000045*np.cos(2.74401480845 + 16063.164847185*t)
	X1 += 0.00000000044*np.cos(2.67440279390 + 38.6543004996*t)
	X1 += 0.00000000043*np.cos(5.89567366882 + 97670.38771289718*t)
	X1 += 0.00000000044*np.cos(4.98395147244 + 535.107591066*t)
	X1 += 0.00000000059*np.cos(5.12096194189 + 2523.9591004846*t)
	X1 += 0.00000000053*np.cos(0.56190542057 + 8336.7851575978*t)
	X1 += 0.00000000046*np.cos(1.93691391876 + 48827.4311857326*t)
	X1 += 0.00000000043*np.cos(5.31424179395 + 12199.9750023914*t)
	X1 += 0.00000000045*np.cos(1.21490188964 + 15849.865751747*t)
	X1 += 0.00000000054*np.cos(4.78336772882 + 46283.11676584919*t)
	X1 += 0.00000000046*np.cos(1.35241852548 + 9175.7544453482*t)
	X1 += 0.00000000042*np.cos(5.91236045456 + 12729.665967486*t)
	X1 += 0.00000000043*np.cos(1.90861231305 + 8123.4860621598*t)
	X1 += 0.00000000046*np.cos(1.99777333547 + 2324.9494088156*t)
	X1 += 0.00000000043*np.cos(0.22627419016 + 3826.5844794894*t)
	X1 += 0.00000000043*np.cos(2.75590007489 + 2854.6403739102*t)
	X1 += 0.00000000043*np.cos(4.16006907854 + 74.6697239827*t)
	X1 += 0.00000000042*np.cos(3.52116061372 + 15106.8756912144*t)
	X1 += 0.00000000043*np.cos(3.66062507509 + 74.8934731519*t)
	X1 += 0.00000000042*np.cos(0.81055569531 + 2651.977943822*t)
	X1 += 0.00000000044*np.cos(4.89874695679 + 1685.0521225016*t)
	X1 += 0.00000000049*np.cos(5.77857770467 + 207.6700211455*t)
	X1 += 0.00000000048*np.cos(1.95445508213 + 12825.6451947038*t)
	X1 += 0.00000000052*np.cos(5.96852999978 + 6666.997759398*t)
	X1 += 0.00000000041*np.cos(5.80749281310 + 28230.18722269139*t)
	X1 += 0.00000000041*np.cos(0.71986367040 + 3385.26625994*t)
	X1 += 0.00000000041*np.cos(2.26231059465 + 3295.9585934596*t)
	X1 += 0.00000000043*np.cos(3.41912327203 + 46681.2657692574*t)
	X1 += 0.00000000040*np.cos(1.93891342372 + 20728.71861442479*t)
	X1 += 0.00000000044*np.cos(0.93617830235 + 29698.2875113358*t)
	X1 += 0.00000000049*np.cos(1.81278199589 + 131.4039498699*t)
	X1 += 0.00000000052*np.cos(4.86200797685 + 3382.1632176846*t)
	X1 += 0.00000000052*np.cos(4.40335159538 + 3299.061635715*t)
	X1 += 0.00000000041*np.cos(3.51246679511 + 4670.1245169598*t)
	X1 += 0.00000000055*np.cos(4.06333971351 + 11527.1250891924*t)
	X1 += 0.00000000047*np.cos(2.28831256912 + 109.9456887885*t)
	X1 += 0.00000000046*np.cos(3.58080161750 + 19247.3765533824*t)
	return X1*t




def Mars_X2 (t): # 446 terms of order 2

	X2 = 0.
	X2 += 0.00056368724
	X2 += 0.00022122521*np.cos(3.54372113272 + 6681.2248533996*t)
	X2 += 0.00006091409*np.cos(3.93272649649 + 10021.8372800994*t)
	X2 += 0.00001451998*np.cos(3.64655666460 + 3340.6124266998*t)
	X2 += 0.00001130613*np.cos(4.28827023222 + 13362.4497067992*t)
	X2 += 0.00000182610*np.cos(4.63522660125 + 16703.062133499*t)
	X2 += 0.00000160293*np.cos(4.40406062613 + 206.1855484372*t)
	X2 += 0.00000155633*np.cos(0.48183983171 + 220.4126424388*t)
	X2 += 0.00000168904*np.cos(4.68797825494 + 3344.1355450488*t)
	X2 += 0.00000168384*np.cos(4.57974326642 + 3337.0893083508*t)
	X2 += 0.00000118222*np.cos(0.99338493688 + 522.5774180938*t)
	X2 += 0.00000115842*np.cos(3.35337160144 + 536.8045120954*t)
	X2 += 0.00000094103*np.cos(0.94931392640 + 3185.1920272656*t)
	X2 += 0.00000089578*np.cos(2.03782745090 + 3496.032826134*t)
	X2 += 0.00000075807*np.cos(1.88120888431 + 1059.3819301892*t)
	X2 += 0.00000095744*np.cos(5.56716176279 + 213.299095438*t)
	X2 += 0.00000061862*np.cos(5.63832966050 + 426.598190876*t)
	X2 += 0.00000072281*np.cos(2.16341813847 + 529.6909650946*t)
	X2 += 0.00000040689*np.cos(5.03331696992 + 6684.7479717486*t)
	X2 += 0.00000027549*np.cos(4.97859663329 + 20043.6745601988*t)
	X2 += 0.00000024699*np.cos(3.63560534183 + 3149.1641605882*t)
	X2 += 0.00000023325*np.cos(5.63009151781 + 3532.0606928114*t)
	X2 += 0.00000024321*np.cos(5.77247656014 + 2544.3144198834*t)
	X2 += 0.00000020394*np.cos(3.48794506814 + 4136.9104335162*t)
	X2 += 0.00000018400*np.cos(3.45575979446 + 3097.88382272579*t)
	X2 += 0.00000017395*np.cos(4.34131723760 + 2942.4634232916*t)
	X2 += 0.00000016954*np.cos(5.82560293948 + 3583.3410306738*t)
	X2 += 0.00000015902*np.cos(1.21784323807 + 5621.8429232104*t)
	X2 += 0.00000015422*np.cos(4.94008572158 + 3738.761430108*t)
	X2 += 0.00000016238*np.cos(1.67605938145 + 1194.4470102246*t)
	X2 += 0.00000014232*np.cos(5.82837756444 + 433.7117378768*t)
	X2 += 0.00000013282*np.cos(5.16082361704 + 1990.745017041*t)
	X2 += 0.00000016878*np.cos(2.35542567714 + 2787.0430238574*t)
	X2 += 0.00000012675*np.cos(3.75990218127 + 2388.8940204492*t)
	X2 += 0.00000011826*np.cos(3.08038008170 + 796.2980068164*t)
	X2 += 0.00000015232*np.cos(0.27850117251 + 1592.5960136328*t)
	X2 += 0.00000012328*np.cos(2.14974361562 + 3341.592747768*t)
	X2 += 0.00000011411*np.cos(2.35109776277 + 1589.0728952838*t)
	X2 += 0.00000011303*np.cos(1.30198187106 + 6525.8044539654*t)
	X2 += 0.00000012311*np.cos(0.83471101077 + 3339.6321056316*t)
	X2 += 0.00000012711*np.cos(3.49149798770 + 419.4846438752*t)
	X2 += 0.00000013670*np.cos(2.56874755004 + 155.4203994342*t)
	X2 += 0.00000010589*np.cos(2.17033819409 + 4399.994356889*t)
	X2 += 0.00000014260*np.cos(0.66247586522 + 3894.1818295422*t)
	X2 += 0.00000009461*np.cos(5.56716533452 + 4292.3308329504*t)
	X2 += 0.00000008649*np.cos(4.16531779363 + 4690.4798363586*t)
	X2 += 0.00000011404*np.cos(0.98319348386 + 2146.1654164752*t)
	X2 += 0.00000008129*np.cos(5.35446918646 + 10025.3603984484*t)
	X2 += 0.00000007707*np.cos(0.35647823047 + 227.5261894396*t)
	X2 += 0.00000007991*np.cos(1.31255637184 + 5486.777843175*t)
	X2 += 0.00000008339*np.cos(1.24221111371 + 2957.7158944766*t)
	X2 += 0.00000007395*np.cos(4.89007018279 + 639.897286314*t)
	X2 += 0.00000006947*np.cos(3.90319519868 + 1066.49547719*t)
	X2 += 0.00000007544*np.cos(1.76180463973 + 3723.508958923*t)
	X2 += 0.00000008875*np.cos(2.08456580754 + 4535.0594369244*t)
	X2 += 0.00000008569*np.cos(2.73774413655 + 5088.6288397668*t)
	X2 += 0.00000008179*np.cos(1.68000384711 + 7.1135470008*t)
	X2 += 0.00000006135*np.cos(5.37763512493 + 7079.3738568078*t)
	X2 += 0.00000006874*np.cos(2.67519964091 + 1748.016413067*t)
	X2 += 0.00000006049*np.cos(1.12213947386 + 553.5694028424*t)
	X2 += 0.00000005466*np.cos(0.51945612003 + 1052.2683831884*t)
	X2 += 0.00000005340*np.cos(5.92227683481 + 951.7184062506*t)
	X2 += 0.00000005445*np.cos(5.43458926991 + 242.728603974*t)
	X2 += 0.00000005288*np.cos(6.18849260834 + 5884.9268465832*t)
	X2 += 0.00000005585*np.cos(4.35867442726 + 1349.8674096588*t)
	X2 += 0.00000005027*np.cos(1.12572622612 + 515.463871093*t)
	X2 += 0.00000005051*np.cos(2.18016149522 + 2274.1169495098*t)
	X2 += 0.00000004770*np.cos(0.36305129741 + 3333.498879699*t)
	X2 += 0.00000005307*np.cos(4.06785486332 + 6489.776587288*t)
	X2 += 0.00000004333*np.cos(0.67828219297 + 4933.2084403326*t)
	X2 += 0.00000004470*np.cos(4.63122002595 + 2288.3440435114*t)
	X2 += 0.00000004148*np.cos(2.67721083071 + 3347.7259737006*t)
	X2 += 0.00000003987*np.cos(5.31786407967 + 23384.2869868986*t)
	X2 += 0.00000003806*np.cos(0.70901266883 + 5092.1519581158*t)
	X2 += 0.00000003667*np.cos(4.56283602529 + 199.0720014364*t)
	X2 += 0.00000003796*np.cos(4.08302538124 + 3870.3033917944*t)
	X2 += 0.00000003523*np.cos(3.22103209546 + 543.9180590962*t)
	X2 += 0.00000004621*np.cos(3.86854740775 + 7477.522860216*t)
	X2 += 0.00000003200*np.cos(3.85010217010 + 6438.4962494256*t)
	X2 += 0.00000002521*np.cos(5.54898285357 + 5331.3574437408*t)
	X2 += 0.00000002884*np.cos(2.21782307080 + 382.8965322232*t)
	X2 += 0.00000002413*np.cos(2.12409000894 + 6836.6452528338*t)
	X2 += 0.00000002207*np.cos(5.89775318087 + 9492.1463150048*t)
	X2 += 0.00000002187*np.cos(2.71871082697 + 6127.6554505572*t)
	X2 += 0.00000002008*np.cos(2.54296252495 + 6682.2051744678*t)
	X2 += 0.00000002221*np.cos(4.91976640295 + 6677.7017350506*t)
	X2 += 0.00000001902*np.cos(2.46234315280 + 4929.6853219836*t)
	X2 += 0.00000001953*np.cos(6.12037277662 + 191.4482661116*t)
	X2 += 0.00000001860*np.cos(2.83627035056 + 2118.7638603784*t)
	X2 += 0.00000001728*np.cos(4.75687645108 + 3553.9115221378*t)
	X2 += 0.00000001979*np.cos(0.95853558190 + 6681.2075997474*t)
	X2 += 0.00000001979*np.cos(2.98858272913 + 6681.2421070518*t)
	X2 += 0.00000002141*np.cos(2.54328094713 + 7740.6067835888*t)
	X2 += 0.00000001573*np.cos(4.50508275022 + 3127.3133312618*t)
	X2 += 0.00000001631*np.cos(2.45741148102 + 7875.6718636242*t)
	X2 += 0.00000001962*np.cos(6.17211726959 + 6923.9534573736*t)
	X2 += 0.00000001572*np.cos(1.33560962556 + 8969.568896911*t)
	X2 += 0.00000001559*np.cos(5.18172013638 + 8955.3418029094*t)
	X2 += 0.00000001881*np.cos(4.13165877159 + 5729.506447149*t)
	X2 += 0.00000001347*np.cos(2.19024470415 + 316.3918696566*t)
	X2 += 0.00000001727*np.cos(4.42641584826 + 6674.1113063988*t)
	X2 += 0.00000001405*np.cos(6.22622304401 + 216.4804891757*t)
	X2 += 0.00000001320*np.cos(4.96541286159 + 647.0108333148*t)
	X2 += 0.00000001676*np.cos(5.72375329917 + 2810.9214616052*t)
	X2 += 0.00000001365*np.cos(4.95810524231 + 210.1177017003*t)
	X2 += 0.00000001464*np.cos(5.67833036033 + 13365.9728251482*t)
	X2 += 0.00000001275*np.cos(4.01216375228 + 640.8776073822*t)
	X2 += 0.00000001483*np.cos(1.65051486293 + 9866.4168806652*t)
	X2 += 0.00000001687*np.cos(1.62553064962 + 14.2270940016*t)
	X2 += 0.00000001159*np.cos(1.60356675965 + 6298.3283211764*t)
	X2 += 0.00000001157*np.cos(0.66416438123 + 6254.6266625236*t)
	X2 += 0.00000001402*np.cos(4.97495321039 + 2699.7348193176*t)
	X2 += 0.00000001138*np.cos(0.03863142059 + 12832.7587417046*t)
	X2 += 0.00000001484*np.cos(5.76685527102 + 10419.9862835076*t)
	X2 += 0.00000001093*np.cos(4.21067890946 + 103.0927742186*t)
	X2 += 0.00000001215*np.cos(2.93903722849 + 3767.2106175758*t)
	X2 += 0.00000001077*np.cos(2.14986202491 + 12303.06777661*t)
	X2 += 0.00000000882*np.cos(2.07935042219 + 1751.539531416*t)
	X2 += 0.00000001105*np.cos(5.02445488391 + 7210.9158184942*t)
	X2 += 0.00000000990*np.cos(4.46834463877 + 9830.3890139878*t)
	X2 += 0.00000000950*np.cos(0.25861778749 + 4562.4609930212*t)
	X2 += 0.00000000877*np.cos(4.22488301555 + 10818.1352869158*t)
	X2 += 0.00000000851*np.cos(1.35694652573 + 2281.2304965106*t)
	X2 += 0.00000000938*np.cos(4.40679265580 + 632.7837393132*t)
	X2 += 0.00000000848*np.cos(1.52469724284 + 526.5095713569*t)
	X2 += 0.00000000826*np.cos(2.81425975210 + 532.8723588323*t)
	X2 += 0.00000001036*np.cos(4.41287380431 + 3981.490034082*t)
	X2 += 0.00000000758*np.cos(0.02371551403 + 209.3669421749*t)
	X2 += 0.00000000757*np.cos(5.33473650413 + 9623.6882766912*t)
	X2 += 0.00000000821*np.cos(3.38181893763 + 10021.8545337516*t)
	X2 += 0.00000000734*np.cos(0.75626361104 + 10018.3141617504*t)
	X2 += 0.00000000733*np.cos(4.88186040762 + 217.2312487011*t)
	X2 += 0.00000000817*np.cos(4.83577618183 + 853.196381752*t)
	X2 += 0.00000000688*np.cos(5.79109380413 + 440.8252848776*t)
	X2 += 0.00000000821*np.cos(1.35115496598 + 10021.8200264472*t)
	X2 += 0.00000000685*np.cos(1.03149651000 + 8273.8208670324*t)
	X2 += 0.00000000814*np.cos(4.08251134670 + 6151.533888305*t)
	X2 += 0.00000000646*np.cos(5.31818662100 + 6681.1575430968*t)
	X2 += 0.00000000651*np.cos(2.20345414604 + 398.1490034082*t)
	X2 += 0.00000000633*np.cos(5.38632263801 + 6040.3472460174*t)
	X2 += 0.00000000842*np.cos(3.04071354856 + 6688.3384004004*t)
	X2 += 0.00000000603*np.cos(5.14215709084 + 323.5054166574*t)
	X2 += 0.00000000624*np.cos(0.96146126905 + 117.3198682202*t)
	X2 += 0.00000000812*np.cos(1.96701783661 + 6041.3275670856*t)
	X2 += 0.00000000641*np.cos(4.90029509996 + 6681.2921637024*t)
	X2 += 0.00000000570*np.cos(2.58703838149 + 15643.6802033098*t)
	X2 += 0.00000000549*np.cos(4.81966003612 + 949.1756089698*t)
	X2 += 0.00000000702*np.cos(0.69460527884 + 74.7815985673*t)
	X2 += 0.00000000717*np.cos(3.64604387479 + 3178.1457905676*t)
	X2 += 0.00000000603*np.cos(5.95813695277 + 149.5631971346*t)
	X2 += 0.00000000662*np.cos(5.29879326411 + 6894.5239488376*t)
	X2 += 0.00000000546*np.cos(0.01597529774 + 1045.1548361876*t)
	X2 += 0.00000000545*np.cos(4.98617588325 + 2766.267628365*t)
	X2 += 0.00000000673*np.cos(5.61896089419 + 3503.079062832*t)
	X2 += 0.00000000499*np.cos(2.95394998140 + 110.2063212194*t)
	X2 += 0.00000000510*np.cos(2.48615954177 + 95.9792272178*t)
	X2 += 0.00000000617*np.cos(2.56762538604 + 3253.30422216*t)
	X2 += 0.00000000604*np.cos(6.00696167862 + 735.8765135318*t)
	X2 += 0.00000000596*np.cos(0.41458038468 + 3427.9206312396*t)
	X2 += 0.00000000490*np.cos(2.82889535700 + 525.7588118315*t)
	X2 += 0.00000000488*np.cos(1.51375734651 + 533.6231183577*t)
	X2 += 0.00000000487*np.cos(4.38031296303 + 3914.9572250346*t)
	X2 += 0.00000000477*np.cos(4.13956608042 + 7234.794256242*t)
	X2 += 0.00000000442*np.cos(2.68822569790 + 7632.9432596502*t)
	X2 += 0.00000000438*np.cos(4.38613869498 + 1596.1864422846*t)
	X2 += 0.00000000545*np.cos(1.03912974763 + 6680.2445323314*t)
	X2 += 0.00000000410*np.cos(1.58251527013 + 3980.5097130138*t)
	X2 += 0.00000000561*np.cos(5.66150369412 + 26724.8994135984*t)
	X2 += 0.00000000411*np.cos(5.74366010527 + 12964.300703391*t)
	X2 += 0.00000000449*np.cos(3.27190934034 + 2648.454825473*t)
	X2 += 0.00000000395*np.cos(6.12652819236 + 2700.7151403858*t)
	X2 += 0.00000000495*np.cos(6.06448586655 + 2914.0142358238*t)
	X2 += 0.00000000493*np.cos(2.58878000047 + 1039.0266107904*t)
	X2 += 0.00000000367*np.cos(0.62535956369 + 8962.4553499102*t)
	X2 += 0.00000000369*np.cos(2.74592799154 + 8270.2977486834*t)
	X2 += 0.00000000380*np.cos(2.89275122673 + 11081.2192102886*t)
	X2 += 0.00000000372*np.cos(5.87272930494 + 4032.7700279266*t)
	X2 += 0.00000000338*np.cos(5.22015252880 + 8432.7643848156*t)
	X2 += 0.00000000371*np.cos(5.28554270239 + 7064.1213856228*t)
	X2 += 0.00000000305*np.cos(4.77209265653 + 574.3447983348*t)
	X2 += 0.00000000300*np.cos(2.85385783473 + 5459.3762870782*t)
	X2 += 0.00000000306*np.cos(4.36534167614 + 6872.6731195112*t)
	X2 += 0.00000000326*np.cos(2.91789777501 + 10022.8176011676*t)
	X2 += 0.00000000280*np.cos(2.83230906425 + 11216.284290324*t)
	X2 += 0.00000000333*np.cos(0.28199543333 + 2301.58581590939*t)
	X2 += 0.00000000283*np.cos(6.13788451705 + 13760.5987102074*t)
	X2 += 0.00000000272*np.cos(5.85293220428 + 10551.528245194*t)
	X2 += 0.00000000358*np.cos(5.91039820815 + 8671.9698704406*t)
	X2 += 0.00000000278*np.cos(3.16173504794 + 5828.0284716476*t)
	X2 += 0.00000000268*np.cos(5.30012147929 + 10021.9045904022*t)
	X2 += 0.00000000353*np.cos(5.67450059858 + 63.7358983034*t)
	X2 += 0.00000000263*np.cos(3.04875074455 + 9468.267877257*t)
	X2 += 0.00000000341*np.cos(1.55199717015 + 8031.0922630584*t)
	X2 += 0.00000000315*np.cos(0.38937613087 + 16173.3711684044*t)
	X2 += 0.00000000267*np.cos(6.09793545646 + 625.6701923124*t)
	X2 += 0.00000000270*np.cos(0.56801609869 + 1581.959348283*t)
	X2 += 0.00000000335*np.cos(3.28599535784 + 412.3710968744*t)
	X2 += 0.00000000268*np.cos(0.82005853572 + 2487.4160449478*t)
	X2 += 0.00000000242*np.cos(0.66542784607 + 13358.9265884502*t)
	X2 += 0.00000000245*np.cos(0.65336059003 + 8429.2412664666*t)
	X2 += 0.00000000267*np.cos(5.70853737597 + 10021.7699697966*t)
	X2 += 0.00000000230*np.cos(1.62446688541 + 70.8494453042*t)
	X2 += 0.00000000226*np.cos(0.21648774887 + 234.6397364404*t)
	X2 += 0.00000000246*np.cos(0.23564126000 + 10264.5658840734*t)
	X2 += 0.00000000260*np.cos(0.59900554651 + 5642.1982426092*t)
	X2 += 0.00000000257*np.cos(0.55141837710 + 956.2891559706*t)
	X2 += 0.00000000218*np.cos(6.18732888250 + 78.7137518304*t)
	X2 += 0.00000000285*np.cos(1.73071428119 + 12310.1813236108*t)
	X2 += 0.00000000289*np.cos(4.38737249371 + 9779.1086761254*t)
	X2 += 0.00000000216*np.cos(0.69406612425 + 11.0457002639*t)
	X2 += 0.00000000283*np.cos(2.17198423111 + 85.8272988312*t)
	X2 += 0.00000000210*np.cos(4.87169565788 + 942.062061969*t)
	X2 += 0.00000000266*np.cos(2.96358399628 + 18984.2926300096*t)
	X2 += 0.00000000209*np.cos(1.26589578723 + 5614.7293762096*t)
	X2 += 0.00000000199*np.cos(3.73362043961 + 13362.4669604514*t)
	X2 += 0.00000000199*np.cos(1.70289925386 + 13362.432453147*t)
	X2 += 0.00000000239*np.cos(6.00441886993 + 16706.585251848*t)
	X2 += 0.00000000227*np.cos(5.26494518266 + 73.297125859*t)
	X2 += 0.00000000235*np.cos(1.88541486477 + 36.6485629295*t)
	X2 += 0.00000000252*np.cos(3.28817243007 + 6283.0758499914*t)
	X2 += 0.00000000212*np.cos(3.41540373108 + 7107.8230442756*t)
	X2 += 0.00000000224*np.cos(5.59487510601 + 39.6175083461*t)
	X2 += 0.00000000193*np.cos(4.43872802342 + 9070.1188738488*t)
	X2 += 0.00000000175*np.cos(2.59247166948 + 9381.9399937854*t)
	X2 += 0.00000000228*np.cos(4.22772621951 + 202.2533951741*t)
	X2 += 0.00000000172*np.cos(4.84769425281 + 13171.0014406876*t)
	X2 += 0.00000000187*np.cos(2.86279402460 + 1169.5882514086*t)
	X2 += 0.00000000196*np.cos(1.99723494678 + 13207.029307365*t)
	X2 += 0.00000000167*np.cos(3.64468986986 + 1073.6090241908*t)
	X2 += 0.00000000177*np.cos(1.94927710769 + 9638.9407478762*t)
	X2 += 0.00000000195*np.cos(0.93545523133 + 224.3447957019*t)
	X2 += 0.00000000170*np.cos(2.99514353373 + 4379.6390374902*t)
	X2 += 0.00000000157*np.cos(0.16247582139 + 8827.3902698748*t)
	X2 += 0.00000000155*np.cos(5.48638933162 + 12295.9542296092*t)
	X2 += 0.00000000158*np.cos(0.41813276311 + 1155.361157407*t)
	X2 += 0.00000000205*np.cos(2.22623702131 + 1221.8485663214*t)
	X2 += 0.00000000141*np.cos(2.05881354566 + 742.9900605326*t)
	X2 += 0.00000000148*np.cos(5.75360559500 + 10235.1363755374*t)
	X2 += 0.00000000135*np.cos(0.93601004324 + 138.5174968707*t)
	X2 += 0.00000000141*np.cos(3.42339195893 + 10028.9508271002*t)
	X2 += 0.00000000149*np.cos(3.11048959872 + 76.2660712756*t)
	X2 += 0.00000000139*np.cos(1.20065333201 + 1437.1756141986*t)
	X2 += 0.00000000133*np.cos(1.27948900541 + 508.3503240922*t)
	X2 += 0.00000000131*np.cos(1.82249875902 + 3029.7716278314*t)
	X2 += 0.00000000145*np.cos(4.08945624026 + 309.2783226558*t)
	X2 += 0.00000000134*np.cos(1.93761929722 + 1903.4368125012*t)
	X2 += 0.00000000126*np.cos(5.33539657707 + 330.6189636582*t)
	X2 += 0.00000000126*np.cos(4.18511285279 + 860.3099287528*t)
	X2 += 0.00000000140*np.cos(3.87848331743 + 10575.4066829418*t)
	X2 += 0.00000000160*np.cos(3.76409728390 + 38.1330356378*t)
	X2 += 0.00000000116*np.cos(1.15955870554 + 3651.4532255682*t)
	X2 += 0.00000000121*np.cos(2.84740298536 + 10973.55568635*t)
	X2 += 0.00000000129*np.cos(3.90779149886 + 6696.4773245846*t)
	X2 += 0.00000000117*np.cos(5.84379077675 + 6701.5801727984*t)
	X2 += 0.00000000119*np.cos(3.78788917836 + 9168.6408983474*t)
	X2 += 0.00000000107*np.cos(5.14404131798 + 4407.1079038898*t)
	X2 += 0.00000000114*np.cos(4.75737830221 + 7322.1024607818*t)
	X2 += 0.00000000104*np.cos(3.13487730948 + 6665.9723822146*t)
	X2 += 0.00000000115*np.cos(6.09545736763 + 223.5940361765*t)
	X2 += 0.00000000105*np.cos(1.90361221217 + 11371.7046897582*t)
	X2 += 0.00000000101*np.cos(4.46463007865 + 14158.7477136156*t)
	X2 += 0.00000000110*np.cos(0.21868987814 + 71.6002048296*t)
	X2 += 0.00000000115*np.cos(5.33896891891 + 429.7795846137*t)
	X2 += 0.00000000131*np.cos(1.19699573376 + 6660.8695340008*t)
	X2 += 0.00000000105*np.cos(1.31705960331 + 77.962992305*t)
	X2 += 0.00000000114*np.cos(3.72019854011 + 6518.7582172674*t)
	X2 += 0.00000000127*np.cos(6.12277131240 + 728.762966531*t)
	X2 += 0.00000000108*np.cos(2.10333523773 + 5244.049239201*t)
	X2 += 0.00000000095*np.cos(0.30620246397 + 6816.289933435*t)
	X2 += 0.00000000101*np.cos(6.03126082039 + 11769.8536931664*t)
	X2 += 0.00000000101*np.cos(2.84466352346 + 11773.3768115154*t)
	X2 += 0.00000000088*np.cos(6.06292314661 + 1835.3246176068*t)
	X2 += 0.00000000090*np.cos(5.51420018615 + 17256.6315363414*t)
	X2 += 0.00000000106*np.cos(1.49565452639 + 1162.4747044078*t)
	X2 += 0.00000000102*np.cos(5.20836098548 + 422.6660376129*t)
	X2 += 0.00000000092*np.cos(4.73502476982 + 10014.7237330986*t)
	X2 += 0.00000000083*np.cos(3.76185545661 + 1505.28780909299*t)
	X2 += 0.00000000084*np.cos(0.06183751259 + 124.433415221*t)
	X2 += 0.00000000082*np.cos(3.24275708402 + 6467.9257579616*t)
	X2 += 0.00000000078*np.cos(5.60819903790 + 10404.7338123226*t)
	X2 += 0.00000000096*np.cos(6.09589552170 + 16304.9131300908*t)
	X2 += 0.00000000094*np.cos(5.30244568575 + 9808.5381846614*t)
	X2 += 0.00000000074*np.cos(1.07138930276 + 1265.5674786264*t)
	X2 += 0.00000000076*np.cos(4.22098650571 + 423.4167971383*t)
	X2 += 0.00000000071*np.cos(3.05925118734 + 551.031606097*t)
	X2 += 0.00000000082*np.cos(1.68324374227 + 519.3960243561*t)
	X2 += 0.00000000085*np.cos(0.45449951855 + 4193.8088084518*t)
	X2 += 0.00000000073*np.cos(0.88325190137 + 6660.4494579072*t)
	X2 += 0.00000000091*np.cos(1.87876020582 + 25287.7237993998*t)
	X2 += 0.00000000093*np.cos(6.03033210386 + 20752.6643624754*t)
	X2 += 0.00000000068*np.cos(4.96510846230 + 654.1243803156*t)
	X2 += 0.00000000071*np.cos(2.10260204323 + 15113.9892382152*t)
	X2 += 0.00000000066*np.cos(2.12551225679 + 30376.3526391666*t)
	X2 += 0.00000000067*np.cos(2.69564372543 + 692.1576012268*t)
	X2 += 0.00000000069*np.cos(6.00365908535 + 30065.5118402982*t)
	X2 += 0.00000000065*np.cos(5.49865044582 + 17412.0519357756*t)
	X2 += 0.00000000076*np.cos(0.17812622824 + 9380.9596727172*t)
	X2 += 0.00000000066*np.cos(2.46864705656 + 88.865680217*t)
	X2 += 0.00000000072*np.cos(1.80564509293 + 27035.7402124668*t)
	X2 += 0.00000000063*np.cos(4.77495740709 + 13517.8701062334*t)
	X2 += 0.00000000065*np.cos(3.24454700037 + 2631.6226244232*t)
	X2 += 0.00000000065*np.cos(1.04135638320 + 20199.094959633*t)
	X2 += 0.00000000061*np.cos(1.62141559661 + 12935.8515159232*t)
	X2 += 0.00000000073*np.cos(1.49901280909 + 21.3406410024*t)
	X2 += 0.00000000063*np.cos(5.65699508407 + 13362.517017102*t)
	X2 += 0.00000000058*np.cos(4.77256654994 + 191.9584544356*t)
	X2 += 0.00000000080*np.cos(2.35381700251 + 21795.21409161479*t)
	X2 += 0.00000000064*np.cos(0.59210224706 + 838.9692877504*t)
	X2 += 0.00000000064*np.cos(0.76110443806 + 6768.5330579394*t)
	X2 += 0.00000000073*np.cos(1.22356246246 + 14712.317116458*t)
	X2 += 0.00000000062*np.cos(3.23287490977 + 5989.0672521728*t)
	X2 += 0.00000000064*np.cos(2.62531230776 + 539.9859058331*t)
	X2 += 0.00000000057*np.cos(0.75475068767 + 16699.53901514999*t)
	X2 += 0.00000000064*np.cos(5.15957430521 + 203.0041546995*t)
	X2 += 0.00000000071*np.cos(5.54884103647 + 14128.2427712456*t)
	X2 += 0.00000000056*np.cos(3.23324962674 + 11128.9760857842*t)
	X2 += 0.00000000052*np.cos(4.10828089558 + 11243.6858464208*t)
	X2 += 0.00000000068*np.cos(3.30032043676 + 3340.629680352*t)
	X2 += 0.00000000067*np.cos(4.65098163449 + 2233.473621015*t)
	X2 += 0.00000000064*np.cos(5.71360304099 + 13119.72110282519*t)
	X2 += 0.00000000068*np.cos(1.26993098899 + 3340.5951730476*t)
	X2 += 0.00000000049*np.cos(3.23999076412 + 14421.8316369884*t)
	X2 += 0.00000000050*np.cos(2.88028372970 + 6593.9166488598*t)
	X2 += 0.00000000065*np.cos(5.34149579962 + 6106.8800550648*t)
	X2 += 0.00000000048*np.cos(3.22386624541 + 10177.2576795336*t)
	X2 += 0.00000000050*np.cos(6.02031448574 + 4049.6022289764*t)
	X2 += 0.00000000063*np.cos(4.41039120987 + 22743.4093795164*t)
	X2 += 0.00000000051*np.cos(1.08977299741 + 12721.572099417*t)
	X2 += 0.00000000056*np.cos(5.66089176987 + 9499.2598620056*t)
	X2 += 0.00000000049*np.cos(1.47188446727 + 14584.2982731206*t)
	X2 += 0.00000000056*np.cos(6.06513078770 + 13362.3823964964*t)
	X2 += 0.00000000046*np.cos(5.89343604493 + 13149.1506113612*t)
	X2 += 0.00000000045*np.cos(4.29961594202 + 846.0828347512*t)
	X2 += 0.00000000046*np.cos(3.88547191366 + 145.6310438715*t)
	X2 += 0.00000000051*np.cos(0.76284557905 + 19513.9835951042*t)
	X2 += 0.00000000047*np.cos(2.03226039424 + 7321.1221397136*t)
	X2 += 0.00000000047*np.cos(1.30702855110 + 21265.5231265202*t)
	X2 += 0.00000000047*np.cos(2.87487572007 + 23141.5583829246*t)
	X2 += 0.00000000043*np.cos(3.08890328263 + 8799.988713778*t)
	X2 += 0.00000000043*np.cos(2.18897814596 + 6684.8152820514*t)
	X2 += 0.00000000047*np.cos(3.31818308830 + 1062.5633239269*t)
	X2 += 0.00000000042*np.cos(6.24718113814 + 9485.032768004*t)
	X2 += 0.00000000043*np.cos(2.56622033374 + 6705.1032911474*t)
	X2 += 0.00000000045*np.cos(5.21894773261 + 6843.6914895318*t)
	X2 += 0.00000000053*np.cos(0.96281646589 + 8425.6508378148*t)
	X2 += 0.00000000049*np.cos(2.87124368812 + 4845.9002357928*t)
	X2 += 0.00000000053*np.cos(5.33119034498 + 7903.073419721*t)
	X2 += 0.00000000041*np.cos(0.09690752852 + 16460.33352952499*t)
	X2 += 0.00000000056*np.cos(3.04529553480 + 6702.000248892*t)
	X2 += 0.00000000040*np.cos(0.61605943900 + 14054.607308026*t)
	X2 += 0.00000000043*np.cos(1.52605536241 + 6709.6740408674*t)
	X2 += 0.00000000043*np.cos(1.75785472218 + 6677.6344247478*t)
	X2 += 0.00000000050*np.cos(0.16634326697 + 13892.1406718938*t)
	X2 += 0.00000000039*np.cos(3.68543277913 + 13553.8979729108*t)
	X2 += 0.00000000038*np.cos(1.25489937051 + 1258.4539316256*t)
	X2 += 0.00000000045*np.cos(3.41167094956 + 28230.18722269139*t)
	X2 += 0.00000000052*np.cos(1.41393169635 + 16062.1845261168*t)
	X2 += 0.00000000049*np.cos(4.48594234475 + 6657.3464156518*t)
	X2 += 0.00000000038*np.cos(4.01715778747 + 6531.661656265*t)
	X2 += 0.00000000049*np.cos(3.05979125217 + 11610.9101753832*t)
	X2 += 0.00000000036*np.cos(2.52534740273 + 12323.4230960088*t)
	X2 += 0.00000000036*np.cos(4.69220073966 + 6158.6474353058*t)
	X2 += 0.00000000038*np.cos(1.09153073828 + 11614.4332937322*t)
	X2 += 0.00000000035*np.cos(1.55855229745 + 1692.1656695024*t)
	X2 += 0.00000000038*np.cos(3.33065203106 + 22324.9050567094*t)
	X2 += 0.00000000046*np.cos(0.03302786718 + 3333.5661900018*t)
	X2 += 0.00000000046*np.cos(6.09073905146 + 3347.6586633978*t)
	X2 += 0.00000000036*np.cos(5.46623211848 + 302.164775655*t)
	X2 += 0.00000000040*np.cos(2.10576578753 + 8982.810669309*t)
	X2 += 0.00000000043*np.cos(0.78042917903 + 7255.5696517344*t)
	X2 += 0.00000000034*np.cos(4.19221759757 + 13916.0191096416*t)
	X2 += 0.00000000034*np.cos(5.64744481308 + 277.0349937414*t)
	X2 += 0.00000000037*np.cos(3.11625027243 + 27433.88921587499*t)
	X2 += 0.00000000043*np.cos(2.33975731781 + 18454.601664915*t)
	X2 += 0.00000000042*np.cos(3.27968491376 + 13363.4300278674*t)
	X2 += 0.00000000046*np.cos(6.20852644411 + 25685.872802808*t)
	X2 += 0.00000000042*np.cos(4.41766590611 + 4447.7512323846*t)
	X2 += 0.00000000033*np.cos(1.58447809959 + 4777.7880408984*t)
	X2 += 0.00000000034*np.cos(4.72972168190 + 26084.0218062162*t)
	X2 += 0.00000000032*np.cos(0.47359068270 + 30774.5016425748*t)
	X2 += 0.00000000033*np.cos(4.58693776960 + 18606.4989460002*t)
	X2 += 0.00000000035*np.cos(3.48982518412 + 17654.7805397496*t)
	X2 += 0.00000000036*np.cos(1.40291642973 + 24606.13555322*t)
	X2 += 0.00000000032*np.cos(2.13345131081 + 5099.2655051166*t)
	X2 += 0.00000000035*np.cos(1.28107458867 + 23695.127785767*t)
	X2 += 0.00000000041*np.cos(3.50737470856 + 31570.7996493912*t)
	X2 += 0.00000000033*np.cos(5.09020911058 + 31172.650645983*t)
	X2 += 0.00000000031*np.cos(0.01163916655 + 8186.5126624926*t)
	X2 += 0.00000000030*np.cos(4.86335561218 + 2125.8774073792*t)
	X2 += 0.00000000035*np.cos(1.25631519996 + 1056.2005364515*t)
	X2 += 0.00000000032*np.cos(2.87432086256 + 15664.03552270859*t)
	X2 += 0.00000000031*np.cos(0.53878733876 + 4106.4054911462*t)
	X2 += 0.00000000031*np.cos(2.44338692629 + 2574.8193622534*t)
	X2 += 0.00000000029*np.cos(6.21158248008 + 2803.8079146044*t)
	X2 += 0.00000000039*np.cos(0.20293002946 + 1574.8458012822*t)
	X2 += 0.00000000028*np.cos(1.67663019512 + 12509.2533250472*t)
	X2 += 0.00000000031*np.cos(5.50562593007 + 9225.539273283*t)
	X2 += 0.00000000030*np.cos(2.07590180724 + 16276.463942623*t)
	X2 += 0.00000000030*np.cos(0.66979072957 + 24076.4445881254*t)
	X2 += 0.00000000030*np.cos(3.99443582500 + 1744.4259844152*t)
	X2 += 0.00000000028*np.cos(2.16725568934 + 15650.7937503106*t)
	X2 += 0.00000000036*np.cos(0.12982829645 + 437.6438911399*t)
	X2 += 0.00000000027*np.cos(4.40428978967 + 15265.8865193004*t)
	X2 += 0.00000000029*np.cos(0.28036663014 + 29026.48522950779*t)
	X2 += 0.00000000029*np.cos(3.70344382503 + 33318.8160624582*t)
	X2 += 0.00000000027*np.cos(0.10774552280 + 17101.2111369072*t)
	X2 += 0.00000000027*np.cos(0.45485812543 + 17810.2009391838*t)
	X2 += 0.00000000031*np.cos(3.39518273216 + 1272.6810256272*t)
	X2 += 0.00000000029*np.cos(4.03990214859 + 1758.6530784168*t)
	X2 += 0.00000000027*np.cos(3.47340764254 + 1055.4497769261*t)
	X2 += 0.00000000029*np.cos(1.32325847141 + 618.5566453116*t)
	X2 += 0.00000000026*np.cos(0.25887939770 + 20735.83216142559*t)
	X2 += 0.00000000028*np.cos(6.24637219690 + 1038.0412891868*t)
	X2 += 0.00000000027*np.cos(0.82567085480 + 415.5524906121*t)
	X2 += 0.00000000025*np.cos(0.89364920475 + 20354.5153590672*t)
	X2 += 0.00000000026*np.cos(0.94849562976 + 16066.0658614748*t)
	X2 += 0.00000000033*np.cos(1.67236797949 + 28628.3362260996*t)
	X2 += 0.00000000027*np.cos(3.09588567120 + 26637.59120905859*t)
	X2 += 0.00000000028*np.cos(1.64332966541 + 1485.9801210652*t)
	X2 += 0.00000000027*np.cos(4.83042372893 + 22747.2907148744*t)
	X2 += 0.00000000026*np.cos(2.23319975287 + 5628.9564702112*t)
	X2 += 0.00000000024*np.cos(3.95136673509 + 36659.428489158*t)
	X2 += 0.00000000025*np.cos(0.20244605774 + 21548.9623692918*t)
	X2 += 0.00000000024*np.cos(2.00009707302 + 19402.7969528166*t)
	X2 += 0.00000000034*np.cos(3.20409325901 + 19004.6479494084*t)
	X2 += 0.00000000026*np.cos(5.05893496491 + 430.5303441391*t)
	X2 += 0.00000000024*np.cos(3.54369543262 + 18.1592472647*t)
	X2 += 0.00000000024*np.cos(0.77717557683 + 831.8557407496*t)
	X2 += 0.00000000026*np.cos(3.99199460654 + 11925.2740926006*t)
	X2 += 0.00000000023*np.cos(1.45497436681 + 231.4583427027*t)
	X2 += 0.00000000031*np.cos(5.64870400603 + 2818.035008606*t)
	X2 += 0.00000000025*np.cos(4.93162407170 + 14071.43950907579*t)
	X2 += 0.00000000030*np.cos(3.41289002407 + 29978.2036357584*t)
	X2 += 0.00000000029*np.cos(2.76627287372 + 24093.2767891752*t)
	X2 += 0.00000000028*np.cos(5.02089948874 + 13745.3462390224*t)
	X2 += 0.00000000024*np.cos(0.83608961696 + 3877.4169387952*t)
	X2 += 0.00000000022*np.cos(0.07496012955 + 8439.8779318164*t)
	X2 += 0.00000000025*np.cos(2.24207971146 + 1368.660252845*t)
	X2 += 0.00000000021*np.cos(2.03101495598 + 5085.038411115*t)
	X2 += 0.00000000021*np.cos(5.72791145125 + 447.9388318784*t)
	X2 += 0.00000000021*np.cos(2.71551636844 + 23296.97878235879*t)
	X2 += 0.00000000024*np.cos(0.33554415228 + 10596.1820784342*t)
	X2 += 0.00000000022*np.cos(1.41039428822 + 12722.5524204852*t)
	X2 += 0.00000000021*np.cos(5.62805203791 + 3340.545116397*t)
	X2 += 0.00000000027*np.cos(3.83951649814 + 8584.6616659008*t)
	X2 += 0.00000000022*np.cos(5.50509868914 + 36261.2794857498*t)
	return X2*t*t




def Mars_X3 (t): # 205 terms of order 3

	X3 = 0.
	X3 += 0.00000852006
	X3 += 0.00000560133*np.cos(1.94007552058 + 6681.2248533996*t)
	X3 += 0.00000318062*np.cos(2.39391695789 + 10021.8372800994*t)
	X3 += 0.00000113458*np.cos(2.75680104109 + 3340.6124266998*t)
	X3 += 0.00000088769*np.cos(2.77668742127 + 13362.4497067992*t)
	X3 += 0.00000022035*np.cos(6.11822426048 + 206.1855484372*t)
	X3 += 0.00000021482*np.cos(5.03368299703 + 220.4126424388*t)
	X3 += 0.00000019119*np.cos(3.13835323002 + 16703.062133499*t)
	X3 += 0.00000017277*np.cos(3.54319327296 + 3496.032826134*t)
	X3 += 0.00000017102*np.cos(5.72328990016 + 3185.1920272656*t)
	X3 += 0.00000016291*np.cos(2.71940457791 + 522.5774180938*t)
	X3 += 0.00000015934*np.cos(1.63320186413 + 536.8045120954*t)
	X3 += 0.00000007980*np.cos(3.07682330325 + 3344.1355450488*t)
	X3 += 0.00000007938*np.cos(6.19210789752 + 3337.0893083508*t)
	X3 += 0.00000003600*np.cos(3.49057256397 + 20043.6745601988*t)
	X3 += 0.00000003738*np.cos(4.31798545325 + 3583.3410306738*t)
	X3 += 0.00000003701*np.cos(4.94786426602 + 3097.88382272579*t)
	X3 += 0.00000003063*np.cos(3.80201225520 + 426.598190876*t)
	X3 += 0.00000002871*np.cos(3.51063041661 + 6684.7479717486*t)
	X3 += 0.00000002563*np.cos(4.04702837579 + 433.7117378768*t)
	X3 += 0.00000002396*np.cos(6.08123425918 + 6525.8044539654*t)
	X3 += 0.00000002101*np.cos(4.92786996750 + 227.5261894396*t)
	X3 += 0.00000002057*np.cos(0.39196575830 + 1059.3819301892*t)
	X3 += 0.00000002381*np.cos(2.14011753266 + 3894.1818295422*t)
	X3 += 0.00000002366*np.cos(0.84278889817 + 2787.0430238574*t)
	X3 += 0.00000002217*np.cos(4.10105217005 + 155.4203994342*t)
	X3 += 0.00000001375*np.cos(2.83821817426 + 515.463871093*t)
	X3 += 0.00000001266*np.cos(5.37509106080 + 419.4846438752*t)
	X3 += 0.00000001294*np.cos(0.74157779671 + 4292.3308329504*t)
	X3 += 0.00000001278*np.cos(2.24302936863 + 2388.8940204492*t)
	X3 += 0.00000001161*np.cos(0.92511464092 + 3532.0606928114*t)
	X3 += 0.00000001156*np.cos(2.06329715393 + 3149.1641605882*t)
	X3 += 0.00000001158*np.cos(1.96104793934 + 4136.9104335162*t)
	X3 += 0.00000001038*np.cos(2.26994057258 + 1066.49547719*t)
	X3 += 0.00000001000*np.cos(6.26567671131 + 199.0720014364*t)
	X3 += 0.00000000964*np.cos(1.50782014667 + 543.9180590962*t)
	X3 += 0.00000001026*np.cos(1.02332579752 + 2544.3144198834*t)
	X3 += 0.00000001275*np.cos(0.02482955002 + 7.1135470008*t)
	X3 += 0.00000000999*np.cos(2.40817781393 + 3339.6321056316*t)
	X3 += 0.00000000908*np.cos(5.64113657397 + 4690.4798363586*t)
	X3 += 0.00000000996*np.cos(0.57020320129 + 3341.592747768*t)
	X3 += 0.00000000887*np.cos(3.64548622051 + 1990.745017041*t)
	X3 += 0.00000000778*np.cos(3.86898632712 + 10025.3603984484*t)
	X3 += 0.00000000798*np.cos(3.26335116909 + 3723.508958923*t)
	X3 += 0.00000000794*np.cos(6.01017762336 + 2957.7158944766*t)
	X3 += 0.00000000845*np.cos(2.83708264275 + 639.897286314*t)
	X3 += 0.00000000678*np.cos(2.36507413871 + 1052.2683831884*t)
	X3 += 0.00000000730*np.cos(0.57139245110 + 4535.0594369244*t)
	X3 += 0.00000000625*np.cos(3.83967243505 + 23384.2869868986*t)
	X3 += 0.00000000621*np.cos(5.05943953438 + 1592.5960136328*t)
	X3 += 0.00000000632*np.cos(4.24328042236 + 5088.6288397668*t)
	X3 += 0.00000000600*np.cos(2.38992409628 + 2146.1654164752*t)
	X3 += 0.00000000450*np.cos(3.39897011554 + 3738.761430108*t)
	X3 += 0.00000000449*np.cos(1.93928115298 + 3333.498879699*t)
	X3 += 0.00000000411*np.cos(5.89788210301 + 2942.4634232916*t)
	X3 += 0.00000000419*np.cos(1.08676442942 + 3347.7259737006*t)
	X3 += 0.00000000399*np.cos(0.63956537359 + 4399.994356889*t)
	X3 += 0.00000000373*np.cos(3.38557300464 + 6836.6452528338*t)
	X3 += 0.00000000488*np.cos(4.67092863003 + 6923.9534573736*t)
	X3 += 0.00000000356*np.cos(1.20127683127 + 6127.6554505572*t)
	X3 += 0.00000000397*np.cos(2.50087314910 + 6489.776587288*t)
	X3 += 0.00000000344*np.cos(1.24961127281 + 213.299095438*t)
	X3 += 0.00000000382*np.cos(6.20559320688 + 14.2270940016*t)
	X3 += 0.00000000295*np.cos(2.81028621304 + 5621.8429232104*t)
	X3 += 0.00000000291*np.cos(3.14472957178 + 647.0108333148*t)
	X3 += 0.00000000357*np.cos(0.15120327086 + 9866.4168806652*t)
	X3 += 0.00000000295*np.cos(3.82251899304 + 7079.3738568078*t)
	X3 += 0.00000000346*np.cos(2.35310156551 + 7477.522860216*t)
	X3 += 0.00000000249*np.cos(1.14107482666 + 1589.0728952838*t)
	X3 += 0.00000000237*np.cos(5.19318533864 + 6438.4962494256*t)
	X3 += 0.00000000214*np.cos(0.98789182009 + 6682.2051744678*t)
	X3 += 0.00000000214*np.cos(4.03956747124 + 440.8252848776*t)
	X3 += 0.00000000230*np.cos(4.42377888159 + 216.4804891757*t)
	X3 += 0.00000000219*np.cos(0.47150010549 + 210.1177017003*t)
	X3 += 0.00000000178*np.cos(4.00441831249 + 5331.3574437408*t)
	X3 += 0.00000000163*np.cos(5.43763088786 + 4933.2084403326*t)
	X3 += 0.00000000215*np.cos(2.60375409797 + 5729.506447149*t)
	X3 += 0.00000000154*np.cos(0.93377729776 + 7875.6718636242*t)
	X3 += 0.00000000149*np.cos(0.09387386327 + 6298.3283211764*t)
	X3 += 0.00000000173*np.cos(4.21364045474 + 13365.9728251482*t)
	X3 += 0.00000000129*np.cos(1.79919042809 + 1045.1548361876*t)
	X3 += 0.00000000143*np.cos(2.35553703991 + 7234.794256242*t)
	X3 += 0.00000000154*np.cos(6.09739962901 + 6677.7017350506*t)
	X3 += 0.00000000156*np.cos(1.03056149319 + 7740.6067835888*t)
	X3 += 0.00000000123*np.cos(2.08253199617 + 853.196381752*t)
	X3 += 0.00000000092*np.cos(4.79503944157 + 234.6397364404*t)
	X3 += 0.00000000100*np.cos(2.91327592181 + 9830.3890139878*t)
	X3 += 0.00000000086*np.cos(6.10758245301 + 103.0927742186*t)
	X3 += 0.00000000108*np.cos(4.23921245691 + 10419.9862835076*t)
	X3 += 0.00000000084*np.cos(2.71984208341 + 10818.1352869158*t)
	X3 += 0.00000000091*np.cos(5.48002372488 + 117.3198682202*t)
	X3 += 0.00000000093*np.cos(5.08172811528 + 529.6909650946*t)
	X3 += 0.00000000099*np.cos(4.18630770421 + 26724.8994135984*t)
	X3 += 0.00000000074*np.cos(1.02672478927 + 4929.6853219836*t)
	X3 += 0.00000000074*np.cos(0.93262918684 + 7632.9432596502*t)
	X3 += 0.00000000075*np.cos(2.87101566525 + 1596.1864422846*t)
	X3 += 0.00000000069*np.cos(4.27897139677 + 95.9792272178*t)
	X3 += 0.00000000073*np.cos(6.02905465950 + 632.7837393132*t)
	X3 += 0.00000000077*np.cos(5.03142217150 + 412.3710968744*t)
	X3 += 0.00000000064*np.cos(3.94993325790 + 316.3918696566*t)
	X3 += 0.00000000065*np.cos(5.02060335506 + 10264.5658840734*t)
	X3 += 0.00000000082*np.cos(1.47502451340 + 6688.3384004004*t)
	X3 += 0.00000000061*np.cos(2.88294088094 + 796.2980068164*t)
	X3 += 0.00000000056*np.cos(2.99558443348 + 508.3503240922*t)
	X3 += 0.00000000057*np.cos(1.55246581721 + 9468.267877257*t)
	X3 += 0.00000000057*np.cos(4.79655567701 + 12832.7587417046*t)
	X3 += 0.00000000057*np.cos(3.21328791407 + 7210.9158184942*t)
	X3 += 0.00000000055*np.cos(3.29709092103 + 323.5054166574*t)
	X3 += 0.00000000051*np.cos(5.82726745850 + 8273.8208670324*t)
	X3 += 0.00000000054*np.cos(4.16556830133 + 9492.1463150048*t)
	X3 += 0.00000000048*np.cos(1.97191764285 + 1073.6090241908*t)
	X3 += 0.00000000050*np.cos(0.50123821286 + 13207.029307365*t)
	X3 += 0.00000000044*np.cos(2.82124972690 + 3870.3033917944*t)
	X3 += 0.00000000049*np.cos(5.67213966976 + 6681.2075997474*t)
	X3 += 0.00000000045*np.cos(5.78754564915 + 8031.0922630584*t)
	X3 += 0.00000000056*np.cos(1.48325794833 + 735.8765135318*t)
	X3 += 0.00000000049*np.cos(1.41972425612 + 6681.2421070518*t)
	X3 += 0.00000000046*np.cos(4.10060372779 + 398.1490034082*t)
	X3 += 0.00000000042*np.cos(1.41375480258 + 625.6701923124*t)
	X3 += 0.00000000042*np.cos(1.83928464694 + 10021.8545337516*t)
	X3 += 0.00000000043*np.cos(1.37745223660 + 10022.8176011676*t)
	X3 += 0.00000000039*np.cos(0.30611138474 + 942.062061969*t)
	X3 += 0.00000000037*np.cos(0.19254777844 + 8827.3902698748*t)
	X3 += 0.00000000042*np.cos(6.09184233156 + 10021.8200264472*t)
	X3 += 0.00000000036*np.cos(1.39675249646 + 11081.2192102886*t)
	X3 += 0.00000000035*np.cos(2.96862453735 + 9070.1188738488*t)
	X3 += 0.00000000036*np.cos(4.59308117276 + 209.3669421749*t)
	X3 += 0.00000000033*np.cos(1.01120243621 + 15643.6802033098*t)
	X3 += 0.00000000032*np.cos(6.00543460913 + 2281.2304965106*t)
	X3 += 0.00000000037*np.cos(5.84186470726 + 10018.3141617504*t)
	X3 += 0.00000000031*np.cos(2.46171091539 + 1581.959348283*t)
	X3 += 0.00000000031*np.cos(1.32072373030 + 551.031606097*t)
	X3 += 0.00000000032*np.cos(0.26519734656 + 217.2312487011*t)
	X3 += 0.00000000031*np.cos(1.56543336145 + 1194.4470102246*t)
	X3 += 0.00000000033*np.cos(2.32289510783 + 860.3099287528*t)
	X3 += 0.00000000036*np.cos(3.37855270463 + 7064.1213856228*t)
	X3 += 0.00000000034*np.cos(3.80029922412 + 2810.9214616052*t)
	X3 += 0.00000000036*np.cos(0.21597015085 + 12303.06777661*t)
	X3 += 0.00000000028*np.cos(3.48885797103 + 330.6189636582*t)
	X3 += 0.00000000027*np.cos(3.92096513265 + 149.5631971346*t)
	X3 += 0.00000000029*np.cos(6.05526972992 + 70.8494453042*t)
	X3 += 0.00000000027*np.cos(1.63715408955 + 2118.7638603784*t)
	X3 += 0.00000000028*np.cos(1.74838965252 + 78.7137518304*t)
	X3 += 0.00000000026*np.cos(1.29835056088 + 11216.284290324*t)
	X3 += 0.00000000026*np.cos(3.71876071236 + 9623.6882766912*t)
	X3 += 0.00000000031*np.cos(2.51169108456 + 6680.2445323314*t)
	X3 += 0.00000000029*np.cos(0.48147029137 + 949.1756089698*t)
	X3 += 0.00000000025*np.cos(2.90245233493 + 10575.4066829418*t)
	X3 += 0.00000000025*np.cos(4.58797131637 + 124.433415221*t)
	X3 += 0.00000000033*np.cos(4.30649710462 + 223.5940361765*t)
	X3 += 0.00000000032*np.cos(1.93089098387 + 110.2063212194*t)
	X3 += 0.00000000027*np.cos(6.02243954440 + 21.3406410024*t)
	X3 += 0.00000000025*np.cos(4.61989520769 + 13760.5987102074*t)
	X3 += 0.00000000033*np.cos(4.38991518046 + 8671.9698704406*t)
	X3 += 0.00000000025*np.cos(1.16107900100 + 1169.5882514086*t)
	X3 += 0.00000000024*np.cos(1.53395713354 + 63.7358983034*t)
	X3 += 0.00000000023*np.cos(3.82777479464 + 1349.8674096588*t)
	X3 += 0.00000000027*np.cos(4.53977736871 + 16706.585251848*t)
	X3 += 0.00000000024*np.cos(5.30269642578 + 8432.7643848156*t)
	X3 += 0.00000000028*np.cos(1.56238914694 + 728.762966531*t)
	X3 += 0.00000000024*np.cos(3.16134826622 + 654.1243803156*t)
	X3 += 0.00000000023*np.cos(0.20728622886 + 191.9584544356*t)
	X3 += 0.00000000024*np.cos(1.32036606678 + 8270.2977486834*t)
	X3 += 0.00000000023*np.cos(2.78297162236 + 5486.777843175*t)
	X3 += 0.00000000022*np.cos(2.15937343363 + 1155.361157407*t)
	X3 += 0.00000000021*np.cos(5.90538406185 + 8962.4553499102*t)
	X3 += 0.00000000025*np.cos(3.69837020561 + 6894.5239488376*t)
	X3 += 0.00000000019*np.cos(0.03186061495 + 85.8272988312*t)
	X3 += 0.00000000019*np.cos(5.82090139161 + 951.7184062506*t)
	X3 += 0.00000000019*np.cos(0.95260076413 + 73.297125859*t)
	X3 += 0.00000000022*np.cos(5.27304712373 + 956.2891559706*t)
	X3 += 0.00000000021*np.cos(2.58836852861 + 1748.016413067*t)
	X3 += 0.00000000020*np.cos(0.45032113933 + 9638.9407478762*t)
	X3 += 0.00000000020*np.cos(1.23809651087 + 3767.2106175758*t)
	X3 += 0.00000000024*np.cos(5.89117970906 + 309.2783226558*t)
	X3 += 0.00000000025*np.cos(3.51115533622 + 429.7795846137*t)
	X3 += 0.00000000018*np.cos(2.11942127084 + 6674.1113063988*t)
	X3 += 0.00000000018*np.cos(2.98453883646 + 10177.2576795336*t)
	X3 += 0.00000000021*np.cos(1.55166742516 + 10973.55568635*t)
	X3 += 0.00000000017*np.cos(3.28202056136 + 13171.0014406876*t)
	X3 += 0.00000000024*np.cos(3.53027023690 + 519.3960243561*t)
	X3 += 0.00000000020*np.cos(1.86650914141 + 71.6002048296*t)
	X3 += 0.00000000017*np.cos(4.13765972175 + 88.865680217*t)
	X3 += 0.00000000018*np.cos(3.69940774861 + 5614.7293762096*t)
	X3 += 0.00000000019*np.cos(5.95485140431 + 77.962992305*t)
	X3 += 0.00000000016*np.cos(3.70893898662 + 6681.1575430968*t)
	X3 += 0.00000000016*np.cos(4.99486486759 + 2914.0142358238*t)
	X3 += 0.00000000016*np.cos(0.00550329231 + 202.2533951741*t)
	X3 += 0.00000000016*np.cos(4.02902153406 + 10551.528245194*t)
	X3 += 0.00000000015*np.cos(1.47023666677 + 5459.3762870782*t)
	X3 += 0.00000000020*np.cos(0.77024887951 + 539.9859058331*t)
	X3 += 0.00000000018*np.cos(0.90284270729 + 553.5694028424*t)
	X3 += 0.00000000015*np.cos(5.02720184968 + 224.3447957019*t)
	X3 += 0.00000000016*np.cos(3.30044259977 + 6681.2921637024*t)
	X3 += 0.00000000014*np.cos(1.85591826294 + 10028.9508271002*t)
	X3 += 0.00000000013*np.cos(0.64071359315 + 76.2660712756*t)
	X3 += 0.00000000016*np.cos(0.70623098744 + 203.0041546995*t)
	X3 += 0.00000000014*np.cos(0.24763128548 + 12310.1813236108*t)
	X3 += 0.00000000012*np.cos(0.84507236712 + 302.164775655*t)
	X3 += 0.00000000010*np.cos(5.93147033577 + 5628.9564702112*t)
	X3 += 0.00000000010*np.cos(5.70249322961 + 242.728603974*t)
	X3 += 0.00000000010*np.cos(5.28489326618 + 11.0457002639*t)
	X3 += 0.00000000010*np.cos(3.98008913039 + 36.6485629295*t)
	X3 += 0.00000000013*np.cos(0.37523695539 + 191.4482661116*t)
	X3 += 0.00000000012*np.cos(3.35651610375 + 422.6660376129*t)
	return X3*t*t*t




def Mars_X4 (t):

	X4 = 0.
	X4 -= 0.00000025439
	X4 += 0.00000012260*np.cos(0.83414775886 + 10021.8372800994*t)
	X4 += 0.00000010035*np.cos(0.40425836057 + 6681.2248533996*t)
	X4 += 0.00000005198*np.cos(1.24299509979 + 13362.4497067992*t)
	X4 += 0.00000003431*np.cos(0.85852911695 + 3340.6124266998*t)
	X4 += 0.00000002427*np.cos(5.05444549984 + 3496.032826134*t)
	X4 += 0.00000002418*np.cos(4.21420537167 + 3185.1920272656*t)
	X4 += 0.00000002272*np.cos(1.56364838180 + 206.1855484372*t)
	X4 += 0.00000002236*np.cos(3.28143366276 + 220.4126424388*t)
	X4 += 0.00000001682*np.cos(4.46996330708 + 522.5774180938*t)
	X4 += 0.00000001638*np.cos(6.17513895178 + 536.8045120954*t)
	X4 += 0.00000001497*np.cos(1.62269036988 + 16703.062133499*t)
	X4 += 0.00000000595*np.cos(2.81076120796 + 3583.3410306738*t)
	X4 += 0.00000000592*np.cos(0.17219890479 + 3097.88382272579*t)
	X4 += 0.00000000430*np.cos(3.20713267334 + 227.5261894396*t)
	X4 += 0.00000000382*np.cos(4.57534940813 + 6525.8044539654*t)
	X4 += 0.00000000352*np.cos(1.98630568244 + 20043.6745601988*t)
	X4 += 0.00000000348*np.cos(2.26681787351 + 433.7117378768*t)
	X4 += 0.00000000291*np.cos(4.56956279775 + 515.463871093*t)
	X4 += 0.00000000286*np.cos(5.62185554893 + 2787.0430238574*t)
	X4 += 0.00000000286*np.cos(3.64530816060 + 3894.1818295422*t)
	X4 += 0.00000000206*np.cos(6.05364860885 + 543.9180590962*t)
	X4 += 0.00000000202*np.cos(1.69320982304 + 199.0720014364*t)
	X4 += 0.00000000256*np.cos(1.53997671854 + 3337.0893083508*t)
	X4 += 0.00000000259*np.cos(1.46295781638 + 3344.1355450488*t)
	X4 += 0.00000000151*np.cos(1.94542778624 + 6684.7479717486*t)
	X4 += 0.00000000123*np.cos(0.67135155073 + 1066.49547719*t)
	X4 += 0.00000000128*np.cos(5.25790457100 + 6836.6452528338*t)
	X4 += 0.00000000099*np.cos(0.99265774704 + 419.4846438752*t)
	X4 += 0.00000000113*np.cos(1.85695441801 + 426.598190876*t)
	X4 += 0.00000000080*np.cos(4.55016686641 + 7.1135470008*t)
	X4 += 0.00000000088*np.cos(3.16739635428 + 6923.9534573736*t)
	X4 += 0.00000000071*np.cos(2.34364246842 + 23384.2869868986*t)
	X4 += 0.00000000062*np.cos(4.48609878362 + 14.2270940016*t)
	X4 += 0.00000000056*np.cos(2.35055343144 + 10025.3603984484*t)
	X4 += 0.00000000053*np.cos(4.95103975600 + 1059.3819301892*t)
	X4 += 0.00000000066*np.cos(4.20375595982 + 1052.2683831884*t)
	X4 += 0.00000000050*np.cos(2.28699829686 + 440.8252848776*t)
	X4 += 0.00000000049*np.cos(5.98001416469 + 6127.6554505572*t)
	X4 += 0.00000000063*np.cos(4.93024120102 + 9866.4168806652*t)
	X4 += 0.00000000060*np.cos(0.97558287548 + 639.897286314*t)
	X4 += 0.00000000049*np.cos(1.31593641965 + 647.0108333148*t)
	X4 += 0.00000000034*np.cos(0.39772363794 + 6438.4962494256*t)
	X4 += 0.00000000031*np.cos(6.26226050601 + 213.299095438*t)
	X4 += 0.00000000024*np.cos(3.05754167589 + 234.6397364404*t)
	X4 += 0.00000000023*np.cos(3.61004405073 + 1045.1548361876*t)
	X4 += 0.00000000018*np.cos(0.96034807462 + 6489.776587288*t)
	X4 += 0.00000000014*np.cos(4.76472781912 + 508.3503240922*t)
	X4 += 0.00000000013*np.cos(6.04976474685 + 1589.0728952838*t)
	X4 += 0.00000000015*np.cos(0.82846675812 + 7477.522860216*t)
	X4 += 0.00000000012*np.cos(5.75575668169 + 6682.2051744678*t)
	X4 += 0.00000000012*np.cos(5.37191984330 + 4399.994356889*t)
	X4 += 0.00000000013*np.cos(5.72126392176 + 10177.2576795336*t)
	X4 += 0.00000000014*np.cos(3.82771110265 + 7234.794256242*t)
	X4 += 0.00000000011*np.cos(3.51933198406 + 10264.5658840734*t)
	X4 += 0.00000000011*np.cos(0.54626079593 + 412.3710968744*t)
	X4 += 0.00000000012*np.cos(0.15818608564 + 853.196381752*t)
	X4 += 0.00000000011*np.cos(2.26503455301 + 7079.3738568078*t)
	X4 += 0.00000000010*np.cos(0.31907502124 + 1073.6090241908*t)
	X4 += 0.00000000012*np.cos(1.11898359111 + 5729.506447149*t)
	X4 += 0.00000000013*np.cos(2.72384207552 + 13365.9728251482*t)
	X4 += 0.00000000010*np.cos(1.35560891851 + 1596.1864422846*t)
	X4 += 0.00000000010*np.cos(2.51049102387 + 5331.3574437408*t)
	X4 += 0.00000000011*np.cos(2.67531582625 + 26724.8994135984*t)
	X4 += 0.00000000009*np.cos(4.24672231397 + 21.3406410024*t)
	X4 += 0.00000000011*np.cos(3.71353247018 + 117.3198682202*t)
	X4 += 0.00000000008*np.cos(4.88874609130 + 6298.3283211764*t)
	X4 += 0.00000000008*np.cos(1.50012562224 + 103.0927742186*t)
	X4 += 0.00000000007*np.cos(5.72637498363 + 7875.6718636242*t)
	X4 += 0.00000000007*np.cos(3.90588497604 + 4933.2084403326*t)
	X4 += 0.00000000007*np.cos(6.08752157484 + 95.9792272178*t)
	X4 += 0.00000000007*np.cos(6.27374846424 + 529.6909650946*t)
	X4 += 0.00000000007*np.cos(5.71854398962 + 551.031606097*t)
	X4 += 0.00000000006*np.cos(1.40413206867 + 654.1243803156*t)
	return X4*t*t*t*t




def Mars_X5 (t): # 38 terms of order 5

	X5 = 0.
	X5 += 0.00000000360*np.cos(5.54721578166 + 10021.8372800994*t)
	X5 += 0.00000000274*np.cos(2.70467042100 + 3185.1920272656*t)
	X5 += 0.00000000274*np.cos(0.28001490932 + 3496.032826134*t)
	X5 += 0.00000000240*np.cos(5.97967755050 + 13362.4497067992*t)
	X5 += 0.00000000168*np.cos(3.28069809842 + 206.1855484372*t)
	X5 += 0.00000000167*np.cos(1.52399958265 + 220.4126424388*t)
	X5 += 0.00000000160*np.cos(5.82127895853 + 3340.6124266998*t)
	X5 += 0.00000000126*np.cos(0.07122523863 + 522.5774180938*t)
	X5 += 0.00000000121*np.cos(4.30466267493 + 536.8045120954*t)
	X5 += 0.00000000092*np.cos(0.08533910188 + 16703.062133499*t)
	X5 += 0.00000000077*np.cos(1.68294648354 + 3097.88382272579*t)
	X5 += 0.00000000077*np.cos(1.29922778151 + 3583.3410306738*t)
	X5 += 0.00000000069*np.cos(5.21105165761 + 6681.2248533996*t)
	X5 += 0.00000000064*np.cos(1.46493444949 + 227.5261894396*t)
	X5 -= 0.00000000087
	X5 += 0.00000000049*np.cos(3.06464731556 + 6525.8044539654*t)
	X5 += 0.00000000047*np.cos(0.05687052745 + 515.463871093*t)
	X5 += 0.00000000037*np.cos(0.48304760543 + 433.7117378768*t)
	X5 += 0.00000000032*np.cos(4.26961178617 + 543.9180590962*t)
	X5 += 0.00000000028*np.cos(3.41370273509 + 199.0720014364*t)
	X5 += 0.00000000027*np.cos(0.47343416859 + 20043.6745601988*t)
	X5 += 0.00000000026*np.cos(5.17377669672 + 3894.1818295422*t)
	X5 += 0.00000000026*np.cos(4.09158287551 + 2787.0430238574*t)
	X5 += 0.00000000013*np.cos(0.44755146347 + 6836.6452528338*t)
	X5 += 0.00000000011*np.cos(2.75798781903 + 14.2270940016*t)
	X5 += 0.00000000011*np.cos(5.33499883960 + 1066.49547719*t)
	X5 += 0.00000000013*np.cos(1.66080594610 + 6923.9534573736*t)
	X5 += 0.00000000010*np.cos(0.51443337467 + 440.8252848776*t)
	X5 += 0.00000000006*np.cos(0.38635391847 + 6684.7479717486*t)
	X5 += 0.00000000007*np.cos(3.42143669327 + 9866.4168806652*t)
	X5 += 0.00000000005*np.cos(4.46712294634 + 6127.6554505572*t)
	X5 += 0.00000000007*np.cos(5.80467663011 + 647.0108333148*t)
	X5 += 0.00000000005*np.cos(0.84565489791 + 23384.2869868986*t)
	X5 += 0.00000000004*np.cos(1.88610464642 + 6438.4962494256*t)
	X5 += 0.00000000004*np.cos(0.20088280204 + 1052.2683831884*t)
	X5 += 0.00000000004*np.cos(3.59221465704 + 419.4846438752*t)
	X5 += 0.00000000003*np.cos(5.43212710597 + 639.897286314*t)
	X5 += 0.00000000003*np.cos(1.37528056638 + 234.6397364404*t)
	return X5*t*t*t*t*t




def Mars_Y0 (t): # 1590 terms of order 0

	Y0 = 0.
	Y0 += 1.51558927367*np.cos(4.63212206588 + 3340.6124266998*t)
	Y0 += 0.07064547959*np.cos(4.97051892898 + 6681.2248533996*t)
	Y0 += 0.08689350637
	Y0 += 0.00493872689*np.cos(5.30877806678 + 10021.8372800994*t)
	Y0 += 0.00482218424*np.cos(2.16962356915 + 529.6909650946*t)
	Y0 += 0.00271492455*np.cos(2.44409624683 + 213.299095438*t)
	Y0 += 0.00155437832*np.cos(0.59926749768 + 38.1330356378*t)
	Y0 += 0.00083738369*np.cos(0.76880567376 + 74.7815985673*t)
	Y0 += 0.00040917422*np.cos(5.64698263703 + 13362.4497067992*t)
	Y0 += 0.00021036784*np.cos(0.23240270955 + 3337.0893083508*t)
	Y0 += 0.00021012921*np.cos(5.89022773653 + 3344.1355450488*t)
	Y0 += 0.00021795361*np.cos(2.88000673227 + 1059.3819301892*t)
	Y0 += 0.00006764653*np.cos(4.07671230062 + 3340.629680352*t)
	Y0 += 0.00006764700*np.cos(2.04594066912 + 3340.5951730476*t)
	Y0 += 0.00008346220*np.cos(3.42464704002 + 2281.2304965106*t)
	Y0 += 0.00005400042*np.cos(5.81507793194 + 2942.4634232916*t)
	Y0 += 0.00007124907*np.cos(1.78378681583 + 426.598190876*t)
	Y0 += 0.00004809528*np.cos(0.27875310553 + 3738.761430108*t)
	Y0 += 0.00004849523*np.cos(2.85190987550 + 5621.8429232104*t)
	Y0 += 0.00005263268*np.cos(0.75811089992 + 6151.533888305*t)
	Y0 += 0.00003609527*np.cos(4.53244488294 + 796.2980068164*t)
	Y0 += 0.00003724293*np.cos(5.98516013322 + 16703.062133499*t)
	Y0 += 0.00003805073*np.cos(5.94234296399 + 398.1490034082*t)
	Y0 += 0.00002394490*np.cos(5.34678816191 + 3149.1641605882*t)
	Y0 += 0.00002251027*np.cos(0.76938193892 + 3532.0606928114*t)
	Y0 += 0.00001975769*np.cos(0.56949816579 + 6677.7017350506*t)
	Y0 += 0.00002226030*np.cos(5.99867316288 + 3340.6797370026*t)
	Y0 += 0.00002226089*np.cos(0.12398424247 + 3340.545116397*t)
	Y0 += 0.00001980388*np.cos(3.18938664693 + 1589.0728952838*t)
	Y0 += 0.00001690439*np.cos(1.58331163985 + 5884.9268465832*t)
	Y0 += 0.00002234121*np.cos(3.24909113765 + 8962.4553499102*t)
	Y0 += 0.00001628395*np.cos(4.95250906888 + 4136.9104335162*t)
	Y0 += 0.00001959001*np.cos(5.70640609056 + 206.1855484372*t)
	Y0 += 0.00001956411*np.cos(6.23095843554 + 6684.7479717486*t)
	Y0 += 0.00001885394*np.cos(2.32103716064 + 220.4126424388*t)
	Y0 += 0.00001898728*np.cos(3.22034182982 + 149.5631971346*t)
	Y0 += 0.00001697214*np.cos(0.81869636263 + 2544.3144198834*t)
	Y0 += 0.00001874200*np.cos(0.11372848779 + 6283.0758499914*t)
	Y0 += 0.00001385946*np.cos(3.73437191158 + 1751.539531416*t)
	Y0 += 0.00001439619*np.cos(5.19505958438 + 2810.9214616052*t)
	Y0 += 0.00001281890*np.cos(3.13035275682 + 1194.4470102246*t)
	Y0 += 0.00001469783*np.cos(0.30415060688 + 3870.3033917944*t)
	Y0 += 0.00001575854*np.cos(2.78266835243 + 5092.1519581158*t)
	Y0 += 0.00001398506*np.cos(2.29986358218 + 522.5774180938*t)
	Y0 += 0.00001201901*np.cos(5.50485513560 + 76.2660712756*t)
	Y0 += 0.00001365144*np.cos(5.18887775599 + 536.8045120954*t)
	Y0 += 0.00000819149*np.cos(3.58786440540 + 4399.994356889*t)
	Y0 += 0.00000709907*np.cos(4.50556127152 + 191.4482661116*t)
	Y0 += 0.00000719204*np.cos(1.08354735050 + 9492.1463150048*t)
	Y0 += 0.00000813077*np.cos(1.68393442622 + 36.6485629295*t)
	Y0 += 0.00000630626*np.cos(2.38434217274 + 6681.2075997474*t)
	Y0 += 0.00000767125*np.cos(2.65620459324 + 39.6175083461*t)
	Y0 += 0.00000630626*np.cos(4.41511380423 + 6681.2421070518*t)
	Y0 += 0.00000592563*np.cos(2.82214112368 + 5486.777843175*t)
	Y0 += 0.00000581408*np.cos(2.38087976114 + 3185.1920272656*t)
	Y0 += 0.00000551361*np.cos(3.73720813913 + 3496.032826134*t)
	Y0 += 0.00000628788*np.cos(4.99295631526 + 73.297125859*t)
	Y0 += 0.00000491736*np.cos(0.60462673907 + 7079.3738568078*t)
	Y0 += 0.00000403176*np.cos(3.49532014869 + 8432.7643848156*t)
	Y0 += 0.00000532702*np.cos(1.72629618682 + 1592.5960136328*t)
	Y0 += 0.00000417187*np.cos(2.39288855164 + 3339.6321056316*t)
	Y0 += 0.00000417083*np.cos(3.72975291794 + 3341.592747768*t)
	Y0 += 0.00000392731*np.cos(1.39110771836 + 2146.1654164752*t)
	Y0 += 0.00000359894*np.cos(0.04010740278 + 20043.6745601988*t)
	Y0 += 0.00000352248*np.cos(2.32029465959 + 6254.6266625236*t)
	Y0 += 0.00000351559*np.cos(3.59860692655 + 12303.06777661*t)
	Y0 += 0.00000321064*np.cos(0.37146017150 + 3553.9115221378*t)
	Y0 += 0.00000313108*np.cos(5.61766202779 + 3127.3133312618*t)
	Y0 += 0.00000306435*np.cos(4.56080395869 + 419.4846438752*t)
	Y0 += 0.00000289608*np.cos(1.43857225713 + 639.897286314*t)
	Y0 += 0.00000266755*np.cos(2.88006209994 + 4562.4609930212*t)
	Y0 += 0.00000259253*np.cos(0.32102915510 + 1990.745017041*t)
	Y0 += 0.00000281755*np.cos(3.32970702835 + 110.2063212194*t)
	Y0 += 0.00000313501*np.cos(3.53468286874 + 4535.0594369244*t)
	Y0 += 0.00000265807*np.cos(4.13657205734 + 5088.6288397668*t)
	Y0 += 0.00000271152*np.cos(0.37550883198 + 6467.9257579616*t)
	Y0 += 0.00000223029*np.cos(1.98134328602 + 3319.8370312074*t)
	Y0 += 0.00000221308*np.cos(4.14094711258 + 3361.3878221922*t)
	Y0 += 0.00000233740*np.cos(0.46548637345 + 9623.6882766912*t)
	Y0 += 0.00000212622*np.cos(2.22578594563 + 1748.016413067*t)
	Y0 += 0.00000211788*np.cos(3.34833949913 + 2118.7638603784*t)
	Y0 += 0.00000207526*np.cos(0.46238962685 + 6681.1575430968*t)
	Y0 += 0.00000205079*np.cos(0.28680735926 + 10025.3603984484*t)
	Y0 += 0.00000207717*np.cos(0.90733952000 + 10018.3141617504*t)
	Y0 += 0.00000240367*np.cos(0.27172033698 + 103.0927742186*t)
	Y0 += 0.00000244575*np.cos(2.80556071941 + 2914.0142358238*t)
	Y0 += 0.00000213997*np.cos(4.22065799551 + 316.3918696566*t)
	Y0 += 0.00000218542*np.cos(5.68744233165 + 6489.776587288*t)
	Y0 += 0.00000207526*np.cos(0.05389324000 + 6681.2921637024*t)
	Y0 += 0.00000178369*np.cos(4.10543898205 + 1221.8485663214*t)
	Y0 += 0.00000156876*np.cos(5.19786609301 + 2388.8940204492*t)
	Y0 += 0.00000146513*np.cos(5.54868179527 + 4690.4798363586*t)
	Y0 += 0.00000176877*np.cos(2.69854646339 + 2957.7158944766*t)
	Y0 += 0.00000147659*np.cos(0.90344856519 + 7210.9158184942*t)
	Y0 += 0.00000164583*np.cos(5.28781848597 + 7477.522860216*t)
	Y0 += 0.00000148488*np.cos(3.34244341315 + 3723.508958923*t)
	Y0 += 0.00000146666*np.cos(2.84397856099 + 3337.021998048*t)
	Y0 += 0.00000146054*np.cos(3.27515242640 + 3344.2028553516*t)
	Y0 += 0.00000123680*np.cos(2.52811225465 + 7903.073419721*t)
	Y0 += 0.00000120116*np.cos(3.09142091867 + 11773.3768115154*t)
	Y0 += 0.00000132007*np.cos(3.42890155754 + 1349.8674096588*t)
	Y0 += 0.00000143810*np.cos(3.78998571160 + 2787.0430238574*t)
	Y0 += 0.00000115489*np.cos(1.95561523091 + 3333.498879699*t)
	Y0 += 0.00000111935*np.cos(4.78148495483 + 3205.5473466644*t)
	Y0 += 0.00000118091*np.cos(3.61471499659 + 4929.6853219836*t)
	Y0 += 0.00000106593*np.cos(1.33768476661 + 3475.6775067352*t)
	Y0 += 0.00000140145*np.cos(0.43040340470 + 1.4844727083*t)
	Y0 += 0.00000120156*np.cos(1.83813184657 + 9225.539273283*t)
	Y0 += 0.00000104155*np.cos(0.75138682237 + 4292.3308329504*t)
	Y0 += 0.00000113753*np.cos(0.78998836832 + 632.7837393132*t)
	Y0 += 0.00000101033*np.cos(3.59737322965 + 7.1135470008*t)
	Y0 += 0.00000094737*np.cos(2.23518894194 + 1052.2683831884*t)
	Y0 += 0.00000125440*np.cos(5.91433151879 + 1066.49547719*t)
	Y0 += 0.00000103341*np.cos(0.82609816627 + 382.8965322232*t)
	Y0 += 0.00000095750*np.cos(4.24181219758 + 3347.7259737006*t)
	Y0 += 0.00000088744*np.cos(1.41592655082 + 12832.7587417046*t)
	Y0 += 0.00000110471*np.cos(1.21942577303 + 155.4203994342*t)
	Y0 += 0.00000084990*np.cos(5.11937799314 + 3097.88382272579*t)
	Y0 += 0.00000114691*np.cos(2.26053594900 + 3894.1818295422*t)
	Y0 += 0.00000080587*np.cos(0.97053595716 + 3583.3410306738*t)
	Y0 += 0.00000085293*np.cos(2.11362771170 + 4933.2084403326*t)
	Y0 += 0.00000086745*np.cos(4.75160801779 + 951.7184062506*t)
	Y0 += 0.00000084319*np.cos(5.69047773316 + 6674.1113063988*t)
	Y0 += 0.00000098959*np.cos(1.66981866704 + 433.7117378768*t)
	Y0 += 0.00000103162*np.cos(1.60805952439 + 1162.4747044078*t)
	Y0 += 0.00000074027*np.cos(4.31857883803 + 3767.2106175758*t)
	Y0 += 0.00000068071*np.cos(6.11774649834 + 553.5694028424*t)
	Y0 += 0.00000091809*np.cos(2.68866263038 + 9595.2390892234*t)
	Y0 += 0.00000073606*np.cos(3.91527582136 + 7740.6067835888*t)
	Y0 += 0.00000064894*np.cos(3.02584743891 + 6041.3275670856*t)
	Y0 += 0.00000066771*np.cos(3.82875505983 + 2700.7151403858*t)
	Y0 += 0.00000054123*np.cos(2.72119014356 + 6525.8044539654*t)
	Y0 += 0.00000066161*np.cos(4.75332288251 + 10021.8545337516*t)
	Y0 += 0.00000051069*np.cos(6.02612173008 + 949.1756089698*t)
	Y0 += 0.00000049846*np.cos(3.52262872498 + 3312.163239232*t)
	Y0 += 0.00000049143*np.cos(2.60082752399 + 3369.0616141676*t)
	Y0 += 0.00000063580*np.cos(4.98292232084 + 846.0828347512*t)
	Y0 += 0.00000047251*np.cos(3.94147277349 + 15643.6802033098*t)
	Y0 += 0.00000066161*np.cos(2.72255125102 + 10021.8200264472*t)
	Y0 += 0.00000063713*np.cos(4.22700572791 + 148.0787244263*t)
	Y0 += 0.00000058716*np.cos(5.39653936368 + 224.3447957019*t)
	Y0 += 0.00000053311*np.cos(0.93765731929 + 10419.9862835076*t)
	Y0 += 0.00000046825*np.cos(2.48327781591 + 8429.2412664666*t)
	Y0 += 0.00000038910*np.cos(4.06810437323 + 6682.2051744678*t)
	Y0 += 0.00000038629*np.cos(3.82156635464 + 8031.0922630584*t)
	Y0 += 0.00000043007*np.cos(1.13946411806 + 3325.3599555148*t)
	Y0 += 0.00000049389*np.cos(0.37266734023 + 2274.1169495098*t)
	Y0 += 0.00000042804*np.cos(4.98193512793 + 3355.8648978848*t)
	Y0 += 0.00000045414*np.cos(3.29703568928 + 2288.3440435114*t)
	Y0 += 0.00000036267*np.cos(0.37822711569 + 23384.2869868986*t)
	Y0 += 0.00000039750*np.cos(2.86822975445 + 4032.7700279266*t)
	Y0 += 0.00000044799*np.cos(2.74299278394 + 3077.528503327*t)
	Y0 += 0.00000032518*np.cos(3.54233921193 + 2648.454825473*t)
	Y0 += 0.00000031454*np.cos(2.64713766872 + 5628.9564702112*t)
	Y0 += 0.00000031440*np.cos(0.69172824614 + 5331.3574437408*t)
	Y0 += 0.00000036126*np.cos(0.70225541331 + 9808.5381846614*t)
	Y0 += 0.00000032887*np.cos(0.52877756255 + 242.728603974*t)
	Y0 += 0.00000029779*np.cos(1.13126848611 + 7064.1213856228*t)
	Y0 += 0.00000039043*np.cos(2.73213911386 + 6680.2445323314*t)
	Y0 += 0.00000032361*np.cos(3.86902085523 + 7875.6718636242*t)
	Y0 += 0.00000030949*np.cos(5.83140858910 + 3.523118349*t)
	Y0 += 0.00000038473*np.cos(0.77890834630 + 6894.5239488376*t)
	Y0 += 0.00000040037*np.cos(3.38427304732 + 3603.6963500726*t)
	Y0 += 0.00000034784*np.cos(3.03113665420 + 35.1640902212*t)
	Y0 += 0.00000030421*np.cos(2.62561225828 + 11.0457002639*t)
	Y0 += 0.00000027656*np.cos(0.80781446139 + 12964.300703391*t)
	Y0 += 0.00000027767*np.cos(2.59284816570 + 7373.3824546264*t)
	Y0 += 0.00000029881*np.cos(2.48951800213 + 1692.1656695024*t)
	Y0 += 0.00000027615*np.cos(6.03842471271 + 5614.7293762096*t)
	Y0 += 0.00000027209*np.cos(3.09945915500 + 11243.6858464208*t)
	Y0 += 0.00000029801*np.cos(3.84787907410 + 3178.1457905676*t)
	Y0 += 0.00000026317*np.cos(2.31641027851 + 1581.959348283*t)
	Y0 += 0.00000024064*np.cos(1.20215072556 + 853.196381752*t)
	Y0 += 0.00000028657*np.cos(2.32631705170 + 3503.079062832*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000023678*np.cos(2.22043284741 + 3320.257107301*t)
	Y0 += 0.00000023510*np.cos(3.90077126172 + 3360.96774609859*t)
	Y0 += 0.00000028123*np.cos(2.13665429249 + 151.0476698429*t)
	Y0 += 0.00000027688*np.cos(5.44433605847 + 63.7358983034*t)
	Y0 += 0.00000022360*np.cos(3.29132317156 + 15113.9892382152*t)
	Y0 += 0.00000022672*np.cos(0.62541647411 + 13365.9728251482*t)
	Y0 += 0.00000024697*np.cos(4.51176067682 + 692.1576012268*t)
	Y0 += 0.00000021808*np.cos(0.39209935673 + 10021.9045904022*t)
	Y0 += 0.00000023815*np.cos(2.19051967809 + 227.5261894396*t)
	Y0 += 0.00000021387*np.cos(2.33304379441 + 6660.4494579072*t)
	Y0 += 0.00000021808*np.cos(0.80059574357 + 10021.7699697966*t)
	Y0 += 0.00000025137*np.cos(5.06242825009 + 3335.0895023924*t)
	Y0 += 0.00000025085*np.cos(1.05978392516 + 3346.1353510072*t)
	Y0 += 0.00000024344*np.cos(5.15348656249 + 7632.9432596502*t)
	Y0 += 0.00000022802*np.cos(6.02803412581 + 9830.3890139878*t)
	Y0 += 0.00000023457*np.cos(0.09576335036 + 71.8126531507*t)
	Y0 += 0.00000023256*np.cos(5.18050538435 + 85.8272988312*t)
	Y0 += 0.00000025142*np.cos(4.04165606796 + 1648.4467571974*t)
	Y0 += 0.00000019246*np.cos(5.68073325802 + 3329.97576135*t)
	Y0 += 0.00000019171*np.cos(0.43949269085 + 3351.2490920496*t)
	Y0 += 0.00000018713*np.cos(5.45372592751 + 6438.4962494256*t)
	Y0 += 0.00000017629*np.cos(5.62148452536 + 6872.6731195112*t)
	Y0 += 0.00000023406*np.cos(4.38193206835 + 1758.6530784168*t)
	Y0 += 0.00000019932*np.cos(5.89893308094 + 2818.035008606*t)
	Y0 += 0.00000018896*np.cos(0.12478161870 + 3863.1898447936*t)
	Y0 += 0.00000017229*np.cos(3.71051818168 + 742.9900605326*t)
	Y0 += 0.00000020614*np.cos(1.58112721470 + 10713.9948813262*t)
	Y0 += 0.00000020199*np.cos(3.63716191406 + 9381.9399937854*t)
	Y0 += 0.00000020392*np.cos(1.69497220340 + 10404.7338123226*t)
	Y0 += 0.00000022995*np.cos(1.24532174509 + 13358.9265884502*t)
	Y0 += 0.00000018341*np.cos(4.17761073049 + 11371.7046897582*t)
	Y0 += 0.00000020656*np.cos(4.47723827677 + 6702.000248892*t)
	Y0 += 0.00000022104*np.cos(2.36649230999 + 2.9689454166*t)
	Y0 += 0.00000017462*np.cos(5.47626814223 + 3074.005384978*t)
	Y0 += 0.00000020052*np.cos(2.45637769313 + 209.3669421749*t)
	Y0 += 0.00000021778*np.cos(4.82054635472 + 77.7505439839*t)
	Y0 += 0.00000019538*np.cos(5.36428737888 + 2707.8286873866*t)
	Y0 += 0.00000019691*np.cos(5.58713076986 + 217.2312487011*t)
	Y0 += 0.00000016274*np.cos(1.33418754245 + 10551.528245194*t)
	Y0 += 0.00000016226*np.cos(3.03590297335 + 6298.3283211764*t)
	Y0 += 0.00000017152*np.cos(3.69045512260 + 6836.6452528338*t)
	Y0 += 0.00000017718*np.cos(5.62526789753 + 10818.1352869158*t)
	Y0 += 0.00000016979*np.cos(6.20827580374 + 1596.1864422846*t)
	Y0 += 0.00000016186*np.cos(0.64022063667 + 3607.2194684216*t)
	Y0 += 0.00000015103*np.cos(5.67174037306 + 10973.55568635*t)
	Y0 += 0.00000018552*np.cos(4.31061638297 + 202.2533951741*t)
	Y0 += 0.00000017492*np.cos(1.45131471586 + 138.5174968707*t)
	Y0 += 0.00000016513*np.cos(0.57398291904 + 6158.6474353058*t)
	Y0 += 0.00000014987*np.cos(3.20375305228 + 5099.2655051166*t)
	Y0 += 0.00000014941*np.cos(5.74767895336 + 6531.661656265*t)
	Y0 += 0.00000014344*np.cos(0.82040466305 + 1478.8665740644*t)
	Y0 += 0.00000015153*np.cos(2.43903550842 + 515.463871093*t)
	Y0 += 0.00000014843*np.cos(1.09015534739 + 735.8765135318*t)
	Y0 += 0.00000015679*np.cos(2.89209321078 + 3333.5661900018*t)
	Y0 += 0.00000014418*np.cos(0.21259774344 + 7234.794256242*t)
	Y0 += 0.00000017079*np.cos(1.42324321277 + 323.5054166574*t)
	Y0 += 0.00000013479*np.cos(3.61192484167 + 6684.8152820514*t)
	Y0 += 0.00000016142*np.cos(5.55386288400 + 5729.506447149*t)
	Y0 += 0.00000013923*np.cos(3.03761491100 + 12935.8515159232*t)
	Y0 += 0.00000016080*np.cos(4.06222327337 + 6144.4203413042*t)
	Y0 += 0.00000013220*np.cos(1.28207165806 + 956.2891559706*t)
	Y0 += 0.00000012795*np.cos(0.72051055394 + 3336.7310913418*t)
	Y0 += 0.00000012778*np.cos(5.40972437724 + 3344.4937620578*t)
	Y0 += 0.00000016730*np.cos(0.87141658782 + 3973.396166013*t)
	Y0 += 0.00000015187*np.cos(3.70157240216 + 5459.3762870782*t)
	Y0 += 0.00000013717*np.cos(4.13705109844 + 6127.6554505572*t)
	Y0 += 0.00000012455*np.cos(4.85280703682 + 2487.4160449478*t)
	Y0 += 0.00000012109*np.cos(3.30084266721 + 3980.5097130138*t)
	Y0 += 0.00000012180*np.cos(3.07347183013 + 3281.2385647862*t)
	Y0 += 0.00000013697*np.cos(3.17688013290 + 6677.6344247478*t)
	Y0 += 0.00000011920*np.cos(3.05684725811 + 3399.9862886134*t)
	Y0 += 0.00000012440*np.cos(3.47218242490 + 4989.0591838972*t)
	Y0 += 0.00000011984*np.cos(0.71488214373 + 1744.4259844152*t)
	Y0 += 0.00000013602*np.cos(4.01636834736 + 3415.3940252671*t)
	Y0 += 0.00000013560*np.cos(6.04193914571 + 5085.038411115*t)
	Y0 += 0.00000011119*np.cos(3.94896791447 + 8270.2977486834*t)
	Y0 += 0.00000011077*np.cos(1.67963136830 + 6816.289933435*t)
	Y0 += 0.00000012942*np.cos(3.09428514061 + 8969.568896911*t)
	Y0 += 0.00000010572*np.cos(0.49111944928 + 2921.1277828246*t)
	Y0 += 0.00000012672*np.cos(2.10673786116 + 3265.8308281325*t)
	Y0 += 0.00000013864*np.cos(5.14485151295 + 6546.1597733642*t)
	Y0 += 0.00000013089*np.cos(0.23087557907 + 8955.3418029094*t)
	Y0 += 0.00000013108*np.cos(0.46269227053 + 3443.7052009184*t)
	Y0 += 0.00000011595*np.cos(5.83451477433 + 199.0720014364*t)
	Y0 += 0.00000010887*np.cos(5.60860774504 + 3316.733988952*t)
	Y0 += 0.00000013658*np.cos(3.07674640526 + 3347.6586633978*t)
	Y0 += 0.00000010779*np.cos(0.52098721533 + 3364.4908644476*t)
	Y0 += 0.00000010586*np.cos(3.70485484511 + 5828.0284716476*t)
	Y0 += 0.00000012245*np.cos(1.07572499863 + 135.0650800354*t)
	Y0 += 0.00000010723*np.cos(1.74814138432 + 16173.3711684044*t)
	Y0 += 0.00000013097*np.cos(4.64132274437 + 6688.3384004004*t)
	Y0 += 0.00000011398*np.cos(5.58264073154 + 3237.5196524812*t)
	Y0 += 0.00000009456*np.cos(1.78215703758 + 11769.8536931664*t)
	Y0 += 0.00000009867*np.cos(2.38731218242 + 14584.2982731206*t)
	Y0 += 0.00000010500*np.cos(5.05682781706 + 543.9180590962*t)
	Y0 += 0.00000009346*np.cos(4.47625335129 + 3304.5845600224*t)
	Y0 += 0.00000011269*np.cos(5.32327854746 + 525.7588118315*t)
	Y0 += 0.00000009214*np.cos(1.65436128537 + 3376.6402933772*t)
	Y0 += 0.00000011111*np.cos(2.15386039177 + 533.6231183577*t)
	Y0 += 0.00000008918*np.cos(2.45020419452 + 8273.8208670324*t)
	Y0 += 0.00000012157*np.cos(6.01959905524 + 10014.7237330986*t)
	Y0 += 0.00000011461*np.cos(1.82889516132 + 3024.2205570432*t)
	Y0 += 0.00000008958*np.cos(0.47938419982 + 3340.19235060619*t)
	Y0 += 0.00000008958*np.cos(5.65082995747 + 3341.0325027934*t)
	Y0 += 0.00000010166*np.cos(5.81425336915 + 1375.7737998458*t)
	Y0 += 0.00000010566*np.cos(4.85914109363 + 10213.285546211*t)
	Y0 += 0.00000008219*np.cos(3.15133566986 + 8827.3902698748*t)
	Y0 += 0.00000009305*np.cos(0.78791668509 + 10575.4066829418*t)
	Y0 += 0.00000010555*np.cos(0.77207843626 + 12168.0026965746*t)
	Y0 += 0.00000010404*np.cos(4.29473071484 + 3657.0042963564*t)
	Y0 += 0.00000007752*np.cos(4.94195070566 + 162.4666361322*t)
	Y0 += 0.00000008284*np.cos(6.07424265191 + 6604.958782124*t)
	Y0 += 0.00000007693*np.cos(5.84469694248 + 1861.7458526354*t)
	Y0 += 0.00000007330*np.cos(5.44972077375 + 3760.097070575*t)
	Y0 += 0.00000007196*np.cos(1.94802350337 + 216.4804891757*t)
	Y0 += 0.00000008951*np.cos(2.07336149122 + 12566.1516999828*t)
	Y0 += 0.00000007360*np.cos(5.09396940186 + 13362.4669604514*t)
	Y0 += 0.00000007036*np.cos(6.09743344991 + 210.1177017003*t)
	Y0 += 0.00000007151*np.cos(0.88141185446 + 415.5524906121*t)
	Y0 += 0.00000009027*np.cos(3.31681299907 + 6784.3176276182*t)
	Y0 += 0.00000007581*np.cos(2.57329415226 + 3134.4268782626*t)
	Y0 += 0.00000006868*np.cos(2.79830848948 + 117.3198682202*t)
	Y0 += 0.00000007340*np.cos(3.06011730362 + 13362.432453147*t)
	Y0 += 0.00000006923*np.cos(2.23261982586 + 3169.9395560806*t)
	Y0 += 0.00000007281*np.cos(3.49687859929 + 3546.797975137*t)
	Y0 += 0.00000007255*np.cos(2.38594499181 + 1265.5674786264*t)
	Y0 += 0.00000007558*np.cos(1.86612263411 + 3209.0704650134*t)
	Y0 += 0.00000007302*np.cos(4.88716898503 + 2178.137722292*t)
	Y0 += 0.00000007609*np.cos(3.51290319043 + 3304.0070613956*t)
	Y0 += 0.00000006549*np.cos(4.33945759933 + 1118.7557921028*t)
	Y0 += 0.00000007465*np.cos(1.30260145767 + 6923.9534573736*t)
	Y0 += 0.00000006446*np.cos(4.21304551726 + 3341.0423098265*t)
	Y0 += 0.00000006446*np.cos(1.91072140138 + 3340.1825435731*t)
	Y0 += 0.00000007519*np.cos(2.61412619102 + 3377.217792004*t)
	Y0 += 0.00000006453*np.cos(3.89234671045 + 3511.285297319*t)
	Y0 += 0.00000006210*np.cos(1.34955480867 + 13916.0191096416*t)
	Y0 += 0.00000007639*np.cos(4.24282694614 + 11081.2192102886*t)
	Y0 += 0.00000006940*np.cos(4.25393907229 + 3472.1543883862*t)
	Y0 += 0.00000005874*np.cos(5.41165981323 + 640.8776073822*t)
	Y0 += 0.00000005775*np.cos(1.73266094244 + 10184.3039162316*t)
	Y0 += 0.00000006003*np.cos(1.27473547429 + 13760.5987102074*t)
	Y0 += 0.00000006790*np.cos(2.67648931795 + 2221.856634597*t)
	Y0 += 0.00000006054*np.cos(4.28573981877 + 18984.2926300096*t)
	Y0 += 0.00000005577*np.cos(2.97071984834 + 6843.6914895318*t)
	Y0 += 0.00000005393*np.cos(4.75504693723 + 1228.9621133222*t)
	Y0 += 0.00000006299*np.cos(6.14054511367 + 14314.1681130498*t)
	Y0 += 0.00000006330*np.cos(3.87859376833 + 70.8494453042*t)
	Y0 += 0.00000006835*np.cos(2.30456930250 + 6606.4432548323*t)
	Y0 += 0.00000006855*np.cos(0.22567806033 + 263.0839233728*t)
	Y0 += 0.00000006167*np.cos(1.31162997368 + 647.0108333148*t)
	Y0 += 0.00000006739*np.cos(0.48428328724 + 95.9792272178*t)
	Y0 += 0.00000005362*np.cos(0.17026677933 + 2766.267628365*t)
	Y0 += 0.00000006934*np.cos(3.87163883253 + 8329.671610597*t)
	Y0 += 0.00000005178*np.cos(1.81202672403 + 3274.1250177854*t)
	Y0 += 0.00000005078*np.cos(2.67641304277 + 526.5095713569*t)
	Y0 += 0.00000005616*np.cos(3.05432126136 + 9866.4168806652*t)
	Y0 += 0.00000006375*np.cos(4.15539245029 + 8439.8779318164*t)
	Y0 += 0.00000004977*np.cos(4.80328860665 + 532.8723588323*t)
	Y0 += 0.00000006512*np.cos(3.37621294675 + 4459.3682188026*t)
	Y0 += 0.00000005006*np.cos(4.31127259045 + 3407.0998356142*t)
	Y0 += 0.00000005879*np.cos(0.79782511263 + 78.7137518304*t)
	Y0 += 0.00000006520*np.cos(3.29969103437 + 3296.8935143948*t)
	Y0 += 0.00000004789*np.cos(0.36397268503 + 4407.1079038898*t)
	Y0 += 0.00000006362*np.cos(2.82772481424 + 3384.3313390048*t)
	Y0 += 0.00000005468*np.cos(3.43539764026 + 14.2270940016*t)
	Y0 += 0.00000005692*np.cos(3.59213239655 + 4569.574540022*t)
	Y0 += 0.00000006474*np.cos(4.73026165299 + 7107.8230442756*t)
	Y0 += 0.00000006259*np.cos(0.59256971500 + 1964.838626854*t)
	Y0 += 0.00000005039*np.cos(2.44093002341 + 6247.5131155228*t)
	Y0 += 0.00000004722*np.cos(5.47235333233 + 6261.7402095244*t)
	Y0 += 0.00000004586*np.cos(2.93638012393 + 6709.6740408674*t)
	Y0 += 0.00000006103*np.cos(4.10884733063 + 111.4301614968*t)
	Y0 += 0.00000004872*np.cos(3.87415179950 + 4392.8808098882*t)
	Y0 += 0.00000004383*np.cos(1.48980757344 + 6665.9723822146*t)
	Y0 += 0.00000004390*np.cos(1.03231511278 + 13149.1506113612*t)
	Y0 += 0.00000004312*np.cos(6.19144471077 + 2807.3983432562*t)
	Y0 += 0.00000004360*np.cos(1.15230731273 + 10235.1363755374*t)
	Y0 += 0.00000004314*np.cos(3.26868649565 + 3877.4169387952*t)
	Y0 += 0.00000004046*np.cos(2.20583477320 + 14054.607308026*t)
	Y0 += 0.00000004008*np.cos(3.35863378745 + 574.3447983348*t)
	Y0 += 0.00000004107*np.cos(3.07058211212 + 10020.8569590312*t)
	Y0 += 0.00000004044*np.cos(2.81163214967 + 13517.8701062334*t)
	Y0 += 0.00000003822*np.cos(0.64521458656 + 3490.1756238344*t)
	Y0 += 0.00000004423*np.cos(6.24070525621 + 277.0349937414*t)
	Y0 += 0.00000004992*np.cos(3.29491717942 + 114.3991069134*t)
	Y0 += 0.00000004095*np.cos(4.40659363743 + 10022.8176011676*t)
	Y0 += 0.00000005124*np.cos(0.28334884652 + 222.8603229936*t)
	Y0 += 0.00000003703*np.cos(4.80251536531 + 6571.0185321802*t)
	Y0 += 0.00000004450*np.cos(0.89168729077 + 13524.9163429314*t)
	Y0 += 0.00000005146*np.cos(2.37068975291 + 2111.6503133776*t)
	Y0 += 0.00000004526*np.cos(6.09427525593 + 3191.0492295652*t)
	Y0 += 0.00000004577*np.cos(5.47618219772 + 146.594251718*t)
	Y0 += 0.00000003986*np.cos(0.10375744687 + 6048.4411140864*t)
	Y0 += 0.00000003482*np.cos(4.20107395689 + 11216.284290324*t)
	Y0 += 0.00000003592*np.cos(6.26752744572 + 3873.8265101434*t)
	Y0 += 0.00000003903*np.cos(5.74518224407 + 3914.9572250346*t)
	Y0 += 0.00000004495*np.cos(2.48902481892 + 10177.2576795336*t)
	Y0 += 0.00000003444*np.cos(0.47927514937 + 8425.6508378148*t)
	Y0 += 0.00000004220*np.cos(0.00535283025 + 2699.7348193176*t)
	Y0 += 0.00000003954*np.cos(3.83351128588 + 6652.7756659318*t)
	Y0 += 0.00000003984*np.cos(5.84008311937 + 3981.490034082*t)
	Y0 += 0.00000003410*np.cos(4.75624627275 + 13936.794505134*t)
	Y0 += 0.00000003767*np.cos(0.71635417612 + 26724.8994135984*t)
	Y0 += 0.00000003387*np.cos(3.58149706956 + 18454.601664915*t)
	Y0 += 0.00000003673*np.cos(5.86946694477 + 3.9321532631*t)
	Y0 += 0.00000003961*np.cos(5.31040335152 + 2384.3232707292*t)
	Y0 += 0.00000003109*np.cos(6.13038417362 + 4555.3474460204*t)
	Y0 += 0.00000004007*np.cos(0.19405096418 + 266.6070417218*t)
	Y0 += 0.00000004019*np.cos(5.32092159727 + 6696.4773245846*t)
	Y0 += 0.00000003611*np.cos(1.73280486368 + 2008.557539159*t)
	Y0 += 0.00000003264*np.cos(1.14586868700 + 16304.9131300908*t)
	Y0 += 0.00000003093*np.cos(6.28077187263 + 5305.4510535538*t)
	Y0 += 0.00000003019*np.cos(5.35351440247 + 5202.3582793352*t)
	Y0 += 0.00000003273*np.cos(1.65076758838 + 5518.7501489918*t)
	Y0 += 0.00000002919*np.cos(5.38276078287 + 309.2783226558*t)
	Y0 += 0.00000002877*np.cos(4.90074910311 + 1332.0548875408*t)
	Y0 += 0.00000002905*np.cos(3.25849505328 + 16858.4825329332*t)
	Y0 += 0.00000003297*np.cos(1.02769227988 + 8671.9698704406*t)
	Y0 += 0.00000003761*np.cos(5.75801604585 + 490.3340891794*t)
	Y0 += 0.00000003680*np.cos(2.91690167677 + 2906.900688823*t)
	Y0 += 0.00000002950*np.cos(3.68236929509 + 6944.3087767724*t)
	Y0 += 0.00000003359*np.cos(2.27893480688 + 2803.8079146044*t)
	Y0 += 0.00000002717*np.cos(4.19241426109 + 6518.7582172674*t)
	Y0 += 0.00000002747*np.cos(4.88163693950 + 5724.935697429*t)
	Y0 += 0.00000002645*np.cos(3.89691136061 + 5989.0672521728*t)
	Y0 += 0.00000002528*np.cos(0.08271917291 + 13171.0014406876*t)
	Y0 += 0.00000003425*np.cos(0.95244785238 + 351.8165923087*t)
	Y0 += 0.00000002511*np.cos(5.88222082993 + 533.2140834436*t)
	Y0 += 0.00000002483*np.cos(2.30179531677 + 3313.210870603*t)
	Y0 += 0.00000002456*np.cos(3.82204754724 + 3368.0139827966*t)
	Y0 += 0.00000002623*np.cos(1.58355072138 + 16699.53901514999*t)
	Y0 += 0.00000002405*np.cos(4.84605046787 + 9168.6408983474*t)
	Y0 += 0.00000002398*np.cos(2.56649522216 + 17924.9106998204*t)
	Y0 += 0.00000002423*np.cos(3.17994958247 + 5732.0492444298*t)
	Y0 += 0.00000003339*np.cos(5.12360857553 + 17277.4069318338*t)
	Y0 += 0.00000002380*np.cos(0.10213592195 + 2125.8774073792*t)
	Y0 += 0.00000002435*np.cos(4.41312658080 + 9485.032768004*t)
	Y0 += 0.00000002416*np.cos(0.73041207552 + 13362.517017102*t)
	Y0 += 0.00000002405*np.cos(0.20257003589 + 3561.0250691386*t)
	Y0 += 0.00000002532*np.cos(3.29260787559 + 6475.0393049624*t)
	Y0 += 0.00000002392*np.cos(4.34374406796 + 10596.1820784342*t)
	Y0 += 0.00000002432*np.cos(2.40533150763 + 3171.0322435668*t)
	Y0 += 0.00000002922*np.cos(5.30505468617 + 109.9456887885*t)
	Y0 += 0.00000002274*np.cos(1.39549918259 + 6686.747777707*t)
	Y0 += 0.00000002400*np.cos(4.57758726706 + 4672.6673142406*t)
	Y0 += 0.00000002448*np.cos(3.02028279202 + 6418.1409300268*t)
	Y0 += 0.00000002366*np.cos(1.05045564841 + 15508.6151232744*t)
	Y0 += 0.00000002427*np.cos(0.38892764633 + 6040.3472460174*t)
	Y0 += 0.00000002247*np.cos(0.65129974134 + 3343.3639373108*t)
	Y0 += 0.00000002247*np.cos(5.47246717730 + 3337.8609160888*t)
	Y0 += 0.00000002471*np.cos(1.29713026645 + 625.6701923124*t)
	Y0 += 0.00000002377*np.cos(3.75701877252 + 3510.1926098328*t)
	Y0 += 0.00000002861*np.cos(0.41825730841 + 3342.0968994081*t)
	Y0 += 0.00000002948*np.cos(5.86605020349 + 6414.6178116778*t)
	Y0 += 0.00000002139*np.cos(4.06717048102 + 7799.9806455024*t)
	Y0 += 0.00000002827*np.cos(5.70543977377 + 3339.1279539915*t)
	Y0 += 0.00000002582*np.cos(0.96409333017 + 16706.585251848*t)
	Y0 += 0.00000002546*np.cos(3.54027578863 + 12722.5524204852*t)
	Y0 += 0.00000002160*np.cos(4.92254263405 + 9779.1086761254*t)
	Y0 += 0.00000002100*np.cos(3.35707551610 + 3929.677253708*t)
	Y0 += 0.00000002903*np.cos(4.69260400410 + 661.232926781*t)
	Y0 += 0.00000002222*np.cos(1.26294843768 + 7314.0085927128*t)
	Y0 += 0.00000002345*np.cos(1.78744472133 + 299.1263942692*t)
	Y0 += 0.00000002127*np.cos(5.81675710469 + 3120.199784261*t)
	Y0 += 0.00000002352*np.cos(5.40138877221 + 6675.7019290922*t)
	Y0 += 0.00000002072*np.cos(4.69329841596 + 16460.33352952499*t)
	Y0 += 0.00000002771*np.cos(6.09091685365 + 9872.2740829648*t)
	Y0 += 0.00000001996*np.cos(0.01333352875 + 792.7748884674*t)
	Y0 += 0.00000001980*np.cos(5.95709631826 + 14158.7477136156*t)
	Y0 += 0.00000002065*np.cos(0.49388965272 + 12295.9542296092*t)
	Y0 += 0.00000002328*np.cos(4.98945470018 + 1169.5882514086*t)
	Y0 += 0.00000002016*np.cos(4.23253734433 + 6701.5801727984*t)
	Y0 += 0.00000002042*np.cos(3.11100955297 + 1545.3539829788*t)
	Y0 += 0.00000001975*np.cos(5.70749246997 + 8542.970706035*t)
	Y0 += 0.00000002040*np.cos(1.07943023634 + 1214.7350193206*t)
	Y0 += 0.00000002428*np.cos(1.78991515376 + 17256.6315363414*t)
	Y0 += 0.00000002221*np.cos(2.56014240865 + 6660.8695340008*t)
	Y0 += 0.00000002648*np.cos(2.51945261752 + 15110.4661198662*t)
	Y0 += 0.00000001929*np.cos(4.56673745966 + 1272.6810256272*t)
	Y0 += 0.00000002185*np.cos(4.81676561022 + 10042.6126755918*t)
	Y0 += 0.00000002357*np.cos(0.65442854372 + 6460.8122109608*t)
	Y0 += 0.00000001914*np.cos(2.82746024893 + 2751.5475996916*t)
	Y0 += 0.00000001929*np.cos(3.18934835620 + 1795.258443721*t)
	Y0 += 0.00000001933*np.cos(2.11467335200 + 3230.4061054804*t)
	Y0 += 0.00000001855*np.cos(0.40013387410 + 3416.8784979754*t)
	Y0 += 0.00000001838*np.cos(3.38443937909 + 16276.463942623*t)
	Y0 += 0.00000002273*np.cos(2.67716254538 + 10001.061884607*t)
	Y0 += 0.00000001861*np.cos(1.26573645480 + 2945.9865416406*t)
	Y0 += 0.00000002216*np.cos(0.91630812456 + 9499.2598620056*t)
	Y0 += 0.00000001805*np.cos(0.77929673675 + 6691.8615187494*t)
	Y0 += 0.00000002360*np.cos(2.94494997079 + 14712.317116458*t)
	Y0 += 0.00000002416*np.cos(1.13890846236 + 13362.3823964964*t)
	Y0 += 0.00000002281*np.cos(2.28712289600 + 6643.0918177618*t)
	Y0 += 0.00000001855*np.cos(5.11046704890 + 13553.8979729108*t)
	Y0 += 0.00000001748*np.cos(3.00019460001 + 5032.7780962022*t)
	Y0 += 0.00000001715*np.cos(3.81102983458 + 4039.8835749274*t)
	Y0 += 0.00000001721*np.cos(3.21935371748 + 6456.8800576977*t)
	Y0 += 0.00000001966*np.cos(3.45968546817 + 12310.1813236108*t)
	Y0 += 0.00000002109*np.cos(0.54415878969 + 7203.8022714934*t)
	Y0 += 0.00000001672*np.cos(0.98005371506 + 6947.8318951214*t)
	Y0 += 0.00000002199*np.cos(5.30054419513 + 28.4491874678*t)
	Y0 += 0.00000001702*np.cos(0.53249868858 + 2675.8563815698*t)
	Y0 += 0.00000001669*np.cos(0.92596345981 + 1435.1476617594*t)
	Y0 += 0.00000001651*np.cos(4.33968588892 + 6756.0064519669*t)
	Y0 += 0.00000001660*np.cos(3.37483790709 + 9638.9407478762*t)
	Y0 += 0.00000001892*np.cos(5.79856399350 + 799.8211251654*t)
	Y0 += 0.00000002194*np.cos(3.25078967175 + 20.7753954924*t)
	Y0 += 0.00000002096*np.cos(4.33264269742 + 13119.72110282519*t)
	Y0 += 0.00000001589*np.cos(2.00183365150 + 2494.5295919486*t)
	Y0 += 0.00000001728*np.cos(1.51696851378 + 1045.1548361876*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000001859*np.cos(6.04674502398 + 1905.4647649404*t)
	Y0 += 0.00000001639*np.cos(4.23392283443 + 2679.3794999188*t)
	Y0 += 0.00000001532*np.cos(5.50075240690 + 4005.3684718298*t)
	Y0 += 0.00000001548*np.cos(6.24678563405 + 6578.132079181*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001844*np.cos(4.01089057973 + 1039.0266107904*t)
	Y0 += 0.00000001555*np.cos(4.98628025111 + 10028.9508271002*t)
	Y0 += 0.00000001553*np.cos(2.32867697517 + 4193.8088084518*t)
	Y0 += 0.00000001869*np.cos(5.29702557581 + 3113.1362939108*t)
	Y0 += 0.00000001486*np.cos(2.31499101353 + 2641.3412784722*t)
	Y0 += 0.00000001756*np.cos(1.78471143136 + 1155.361157407*t)
	Y0 += 0.00000001547*np.cos(0.07021288134 + 13355.3361597984*t)
	Y0 += 0.00000001463*np.cos(4.98430780024 + 3318.7615973734*t)
	Y0 += 0.00000001463*np.cos(1.13945911840 + 3362.4632560262*t)
	Y0 += 0.00000001867*np.cos(1.75650236110 + 13892.1406718938*t)
	Y0 += 0.00000001484*np.cos(4.23315329914 + 2604.735913168*t)
	Y0 += 0.00000001444*np.cos(3.51978992540 + 10018.2468514476*t)
	Y0 += 0.00000001862*np.cos(6.02925087361 + 6670.5881880498*t)
	Y0 += 0.00000001434*np.cos(4.87139095958 + 2075.0449480734*t)
	Y0 += 0.00000001428*np.cos(4.47987818809 + 9468.267877257*t)
	Y0 += 0.00000001516*np.cos(2.83788149379 + 4922.5717749828*t)
	Y0 += 0.00000001429*np.cos(1.03218970015 + 12995.2253778368*t)
	Y0 += 0.00000001596*np.cos(1.50060360357 + 440.8252848776*t)
	Y0 += 0.00000001487*np.cos(4.35858219478 + 412.3710968744*t)
	Y0 += 0.00000001637*np.cos(5.89268196003 + 9070.1188738488*t)
	Y0 += 0.00000001434*np.cos(4.16617594484 + 3283.7140517642*t)
	Y0 += 0.00000001552*np.cos(5.46766076359 + 9886.772200064*t)
	Y0 += 0.00000001443*np.cos(5.12250897854 + 19800.9459562248*t)
	Y0 += 0.00000001430*np.cos(3.95481187554 + 10025.4277087512*t)
	Y0 += 0.00000001411*np.cos(5.78666438291 + 7895.9598727202*t)
	Y0 += 0.00000001403*np.cos(1.95715148848 + 3397.5108016354*t)
	Y0 += 0.00000001477*np.cos(5.05923233039 + 664.75604513*t)
	Y0 += 0.00000001371*np.cos(6.16123966003 + 942.062061969*t)
	Y0 += 0.00000001422*np.cos(1.73849339140 + 17395.2197347258*t)
	Y0 += 0.00000001893*np.cos(3.78808072052 + 7255.5696517344*t)
	Y0 += 0.00000001455*np.cos(3.95724694508 + 2693.601593385*t)
	Y0 += 0.00000001700*np.cos(0.82628421144 + 3568.0885594888*t)
	Y0 += 0.00000001599*np.cos(3.45368152649 + 3212.5935833624*t)
	Y0 += 0.00000001492*np.cos(2.02335847018 + 6155.057006654*t)
	Y0 += 0.00000001330*np.cos(4.10649504401 + 5625.3660415594*t)
	Y0 += 0.00000001458*np.cos(4.17345665885 + 1015.6630178842*t)
	Y0 += 0.00000001556*np.cos(5.03343705939 + 699.2711482276*t)
	Y0 += 0.00000001329*np.cos(1.62600812826 + 3347.2960905739*t)
	Y0 += 0.00000001329*np.cos(4.49775879038 + 3333.9287628257*t)
	Y0 += 0.00000001502*np.cos(4.97796968434 + 3378.7454623376*t)
	Y0 += 0.00000001522*np.cos(2.67171739921 + 3468.6312700372*t)
	Y0 += 0.00000001395*np.cos(4.73053455402 + 589.0648270082*t)
	Y0 += 0.00000001286*np.cos(0.30379131125 + 3152.68727893721*t)
	Y0 += 0.00000001428*np.cos(4.17962469716 + 65.2203710117*t)
	Y0 += 0.00000001682*np.cos(6.22849241635 + 4775.7600884592*t)
	Y0 += 0.00000001563*np.cos(3.16953602104 + 6674.1786167016*t)
	Y0 += 0.00000001454*np.cos(4.05003779520 + 8799.988713778*t)
	Y0 += 0.00000001260*np.cos(1.69516681295 + 3742.284548457*t)
	Y0 += 0.00000001361*np.cos(3.13054556500 + 6034.2140200848*t)
	Y0 += 0.00000001702*np.cos(0.42639470325 + 8646.0634802536*t)
	Y0 += 0.00000001307*np.cos(4.86294984681 + 1190.9238918756*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001582*np.cos(3.59667619676 + 3450.8187479192*t)
	Y0 += 0.00000001272*np.cos(4.68635069953 + 6997.6167230562*t)
	Y0 += 0.00000001293*np.cos(3.67069504345 + 10124.930054318*t)
	Y0 += 0.00000001157*np.cos(2.59571504503 + 4885.9664096786*t)
	Y0 += 0.00000001193*np.cos(5.74461193872 + 6685.1061887576*t)
	Y0 += 0.00000001175*np.cos(1.89791109723 + 4076.4889402316*t)
	Y0 += 0.00000001172*np.cos(1.91815417884 + 1485.9801210652*t)
	Y0 += 0.00000001162*np.cos(2.67584368769 + 2324.9494088156*t)
	Y0 += 0.00000001273*np.cos(5.05031878952 + 66.4874089144*t)
	Y0 += 0.00000001127*np.cos(4.03094666313 + 17654.7805397496*t)
	Y0 += 0.00000001325*np.cos(5.10332504416 + 59.3738619136*t)
	Y0 += 0.00000001485*np.cos(6.11611294959 + 210.8514148832*t)
	Y0 += 0.00000001205*np.cos(3.32707601504 + 6688.2710900976*t)
	Y0 += 0.00000001183*np.cos(4.18544310209 + 11670.2840372968*t)
	Y0 += 0.00000001415*np.cos(2.81550588094 + 9588.1255422226*t)
	Y0 += 0.00000001473*np.cos(1.91659379347 + 215.7467759928*t)
	Y0 += 0.00000001112*np.cos(4.50778167602 + 15.252471185*t)
	Y0 += 0.00000001136*np.cos(0.27209358118 + 19402.7969528166*t)
	Y0 += 0.00000001102*np.cos(2.41369298606 + 6364.832983743*t)
	Y0 += 0.00000001104*np.cos(1.71931758367 + 6148.010769956*t)
	Y0 += 0.00000001171*np.cos(3.63619587357 + 2771.7905526724*t)
	Y0 += 0.00000001128*np.cos(3.40922804025 + 6621.850991486*t)
	Y0 += 0.00000001312*np.cos(3.60055878901 + 3311.18291816379*t)
	Y0 += 0.00000001312*np.cos(2.52320812963 + 3370.0419352358*t)
	Y0 += 0.00000001148*np.cos(3.06473482787 + 1063.3140834523*t)
	Y0 += 0.00000001101*np.cos(4.21878444844 + 3774.3241645766*t)
	Y0 += 0.00000001229*np.cos(0.96680072191 + 3145.6410422392*t)
	Y0 += 0.00000001266*np.cos(4.04475782677 + 6887.4104018368*t)
	Y0 += 0.00000001197*np.cos(4.66589167515 + 2284.7536148596*t)
	Y0 += 0.00000001097*np.cos(0.74070558229 + 13745.3462390224*t)
	Y0 += 0.00000001222*np.cos(2.97118716033 + 3184.2117061974*t)
	Y0 += 0.00000001052*np.cos(4.36133521546 + 1197.9701285736*t)
	Y0 += 0.00000001365*np.cos(4.39428439358 + 225.8292684102*t)
	Y0 += 0.00000001116*np.cos(4.29110122176 + 11610.9101753832*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001218*np.cos(2.02574751453 + 10156.9023601348*t)
	Y0 += 0.00000001068*np.cos(5.67373061677 + 12721.572099417*t)
	Y0 += 0.00000001106*np.cos(2.77068073078 + 2597.6223661672*t)
	Y0 += 0.00000001019*np.cos(5.67612773072 + 145.6310438715*t)
	Y0 += 0.00000001093*np.cos(4.53871388488 + 5618.3198048614*t)
	Y0 += 0.00000001421*np.cos(0.83890525684 + 152.5321425512*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001029*np.cos(1.30291490467 + 422.6660376129*t)
	Y0 += 0.00000001024*np.cos(0.06601478472 + 11766.2632645146*t)
	Y0 += 0.00000001193*np.cos(1.05540356619 + 6677.3435180416*t)
	Y0 += 0.00000001102*np.cos(3.69331514825 + 7321.1221397136*t)
	Y0 += 0.00000000990*np.cos(4.38326935686 + 3181.6689089166*t)
	Y0 += 0.00000000992*np.cos(6.20838604911 + 4140.4335518652*t)
	Y0 += 0.00000001146*np.cos(3.15309955963 + 3497.0131472022*t)
	Y0 += 0.00000001269*np.cos(3.62847699186 + 3188.7151456146*t)
	Y0 += 0.00000001009*np.cos(4.15469691601 + 4142.976349146*t)
	Y0 += 0.00000001311*np.cos(0.82653092367 + 3302.479391062*t)
	Y0 += 0.00000001268*np.cos(3.68256833294 + 6740.5987153132*t)
	Y0 += 0.00000001371*np.cos(0.13077559897 + 9945.5712088238*t)
	Y0 += 0.00000001109*np.cos(1.53029152367 + 394.6258850592*t)
	Y0 += 0.00000000977*np.cos(5.76688159627 + 3361.9480671668*t)
	Y0 += 0.00000000977*np.cos(0.35688532238 + 3319.2767862328*t)
	Y0 += 0.00000001185*np.cos(5.73396555500 + 9602.3526362242*t)
	Y0 += 0.00000001013*np.cos(5.48278778939 + 2277.7073781616*t)
	Y0 += 0.00000001020*np.cos(2.11079504561 + 2538.2485042536*t)
	Y0 += 0.00000001079*np.cos(0.61021915360 + 9389.0535407862*t)
	Y0 += 0.00000001347*np.cos(2.06223654324 + 19513.9835951042*t)
	Y0 += 0.00000000977*np.cos(0.76357046359 + 84.3428261229*t)
	Y0 += 0.00000000986*np.cos(1.69206195363 + 20809.4676246452*t)
	Y0 += 0.00000001106*np.cos(0.06094765066 + 3264.3463554242*t)
	Y0 += 0.00000000968*np.cos(4.43227430163 + 931.3630868518*t)
	Y0 += 0.00000001187*np.cos(4.34414977303 + 5835.1420186484*t)
	Y0 += 0.00000000957*np.cos(4.82126145069 + 6645.1969867222*t)
	Y0 += 0.00000001198*np.cos(5.16932600912 + 9065.5481241288*t)
	Y0 += 0.00000001076*np.cos(5.29118995114 + 212.3358875915*t)
	Y0 += 0.00000001071*np.cos(2.73962355675 + 214.2623032845*t)
	Y0 += 0.00000000943*np.cos(5.33537557967 + 3344.152798701*t)
	Y0 += 0.00000000943*np.cos(3.92998399256 + 3337.0720546986*t)
	Y0 += 0.00000000929*np.cos(2.07677392189 + 4001.8453534808*t)
	Y0 += 0.00000001243*np.cos(1.30343744920 + 184.7272873558*t)
	Y0 += 0.00000000960*np.cos(2.48503648557 + 3909.4343007272*t)
	Y0 += 0.00000000909*np.cos(2.06833342083 + 3326.3853326982*t)
	Y0 += 0.00000001071*np.cos(4.54619279368 + 5195.2447323344*t)
	Y0 += 0.00000000943*np.cos(5.96075562405 + 3337.106562003*t)
	Y0 += 0.00000000943*np.cos(3.30460394818 + 3344.11829139661*t)
	Y0 += 0.00000000902*np.cos(5.15672426526 + 169.580183133*t)
	Y0 += 0.00000000888*np.cos(1.43117252150 + 16865.5287696312*t)
	Y0 += 0.00000000919*np.cos(2.04701224910 + 2067.9314010726*t)
	Y0 += 0.00000000884*np.cos(5.16952206002 + 36.6053653042*t)
	Y0 += 0.00000000891*np.cos(2.41639607024 + 213.2509113282*t)
	Y0 += 0.00000000890*np.cos(5.61419511254 + 213.3472795478*t)
	Y0 += 0.00000000879*np.cos(4.09361898695 + 3354.8395207014*t)
	Y0 += 0.00000001201*np.cos(6.09845178677 + 16062.1845261168*t)
	Y0 += 0.00000000963*np.cos(2.78734439237 + 11614.4332937322*t)
	Y0 += 0.00000000856*np.cos(0.80926398517 + 6705.1032911474*t)
	Y0 += 0.00000000969*np.cos(5.16633148001 + 8958.9322315612*t)
	Y0 += 0.00000001200*np.cos(3.92847129115 + 2970.9126107594*t)
	Y0 += 0.00000001039*np.cos(0.35365785785 + 4936.7988689844*t)
	Y0 += 0.00000000897*np.cos(3.73527891349 + 11780.4903585162*t)
	Y0 += 0.00000000995*np.cos(0.26138866358 + 16335.8378045366*t)
	Y0 += 0.00000000868*np.cos(2.65649534956 + 9947.0556815321*t)
	Y0 += 0.00000001041*np.cos(4.23685547840 + 137.0330241624*t)
	Y0 += 0.00000000890*np.cos(4.75712150390 + 6747.712262314*t)
	Y0 += 0.00000001141*np.cos(0.97184844335 + 131.5419616864*t)
	Y0 += 0.00000000834*np.cos(0.81428487363 + 6680.804777306*t)
	Y0 += 0.00000000884*np.cos(1.87315288737 + 3232.9489027612*t)
	Y0 += 0.00000000818*np.cos(5.38279925907 + 9380.9596727172*t)
	Y0 += 0.00000000818*np.cos(4.78663456281 + 8013.2797409404*t)
	Y0 += 0.00000000814*np.cos(3.39899123402 + 16703.0448798468*t)
	Y0 += 0.00000001043*np.cos(2.49681718942 + 3492.509707785*t)
	Y0 += 0.00000000814*np.cos(5.42976286552 + 16703.07938715119*t)
	Y0 += 0.00000000812*np.cos(0.69907573293 + 288.0806940053*t)
	Y0 += 0.00000000819*np.cos(5.28403120371 + 529.6427809848*t)
	Y0 += 0.00000000819*np.cos(2.19867289777 + 529.7391492044*t)
	Y0 += 0.00000000900*np.cos(4.50924525053 + 8965.9784682592*t)
	Y0 += 0.00000000821*np.cos(6.16771533756 + 3358.4249488178*t)
	Y0 += 0.00000000821*np.cos(6.23923688826 + 3322.7999045818*t)
	Y0 += 0.00000000967*np.cos(1.92764202530 + 9654.612951137*t)
	Y0 += 0.00000000792*np.cos(5.67450968586 + 7100.7094972748*t)
	Y0 += 0.00000000779*np.cos(1.71729257907 + 3499.555944483*t)
	Y0 += 0.00000001037*np.cos(2.70514798372 + 527.2432845398*t)
	Y0 += 0.00000000841*np.cos(4.23759405799 + 3448.2759506384*t)
	Y0 += 0.00000001029*np.cos(4.77626567802 + 532.1386456494*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000788*np.cos(4.57983605830 + 14421.8316369884*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000936*np.cos(3.01733724066 + 437.6438911399*t)
	Y0 += 0.00000001000*np.cos(6.00174788672 + 1055.4497769261*t)
	Y0 += 0.00000000836*np.cos(1.41619053095 + 170.6728706192*t)
	Y0 += 0.00000000844*np.cos(3.21239075987 + 4356.275444584*t)
	Y0 += 0.00000000989*np.cos(3.67005329922 + 20199.094959633*t)
	Y0 += 0.00000000900*np.cos(1.00211769457 + 401.6721217572*t)
	Y0 += 0.00000000776*np.cos(2.50668810243 + 203.7378678824*t)
	Y0 += 0.00000001013*np.cos(4.38954237559 + 8859.3625756916*t)
	Y0 += 0.00000001009*np.cos(5.94344429551 + 6657.3464156518*t)
	Y0 += 0.00000000819*np.cos(4.90700253923 + 802.3639224462*t)
	Y0 += 0.00000001030*np.cos(2.19496889171 + 3710.3122426402*t)
	Y0 += 0.00000000734*np.cos(3.78800004602 + 112.9146342051*t)
	Y0 += 0.00000000787*np.cos(3.72966883127 + 3308.640120883*t)
	Y0 += 0.00000000787*np.cos(2.39409808737 + 3372.5847325166*t)
	Y0 += 0.00000000725*np.cos(4.63532264917 + 3229.4257844122*t)
	Y0 += 0.00000000825*np.cos(4.27026639346 + 3253.30422216*t)
	Y0 += 0.00000000838*np.cos(3.66947874674 + 3116.2676309979*t)
	Y0 += 0.00000000864*np.cos(1.98924766986 + 6717.252720077*t)
	Y0 += 0.00000000729*np.cos(0.68449736491 + 22743.4093795164*t)
	Y0 += 0.00000000720*np.cos(5.55705118503 + 20597.2439630412*t)
	Y0 += 0.00000000700*np.cos(3.77746305049 + 3613.2853840514*t)
	Y0 += 0.00000000889*np.cos(3.55978260808 + 7910.1869667218*t)
	Y0 += 0.00000000697*np.cos(0.43842850413 + 628.8515860501*t)
	Y0 += 0.00000000720*np.cos(3.79227419390 + 1062.9050485382*t)
	Y0 += 0.00000000694*np.cos(1.48841585184 + 3451.7990689874*t)
	Y0 += 0.00000000692*np.cos(2.36882551276 + 3067.9394693482*t)
	Y0 += 0.00000000730*np.cos(1.00727748667 + 6016.4688082696*t)
	Y0 += 0.00000000795*np.cos(1.85354458694 + 3427.9206312396*t)
	Y0 += 0.00000000876*np.cos(5.35866130411 + 2391.43681773*t)
	Y0 += 0.00000000723*np.cos(3.92475752469 + 3735.238311759*t)
	Y0 += 0.00000000722*np.cos(2.23341954634 + 15906.7641266826*t)
	Y0 += 0.00000000661*np.cos(3.51665460883 + 7270.2896804078*t)
	Y0 += 0.00000000925*np.cos(1.39948133634 + 160.6088973985*t)
	Y0 += 0.00000000651*np.cos(0.78545063650 + 6357.7194367422*t)
	Y0 += 0.00000000790*np.cos(1.64323479127 + 10264.5658840734*t)
	Y0 += 0.00000000649*np.cos(1.04328215728 + 860.3099287528*t)
	Y0 += 0.00000000652*np.cos(1.55852371558 + 3212.6608936652*t)
	Y0 += 0.00000000711*np.cos(1.63332630369 + 5642.1982426092*t)
	Y0 += 0.00000000634*np.cos(1.60298193598 + 17101.2111369072*t)
	Y0 += 0.00000000740*np.cos(5.72740272247 + 1073.6090241908*t)
	Y0 += 0.00000000742*np.cos(1.23961445295 + 9.5612275556*t)
	Y0 += 0.00000000652*np.cos(4.45799464174 + 485.9720527896*t)
	Y0 += 0.00000000666*np.cos(1.27481108934 + 15664.03552270859*t)
	Y0 += 0.00000000625*np.cos(2.36814325199 + 5938.234792867*t)
	Y0 += 0.00000000639*np.cos(1.93449381766 + 5408.5438277724*t)
	Y0 += 0.00000000875*np.cos(3.77647530400 + 380.12776796*t)
	Y0 += 0.00000000621*np.cos(1.42292756920 + 17468.8551979454*t)
	Y0 += 0.00000000684*np.cos(2.60266690573 + 1437.1756141986*t)
	Y0 += 0.00000000631*np.cos(3.77351547579 + 3329.5667264359*t)
	Y0 += 0.00000000631*np.cos(2.35025144285 + 3351.6581269637*t)
	Y0 += 0.00000000631*np.cos(4.86274156896 + 3343.1552239806*t)
	Y0 += 0.00000000834*np.cos(5.98573063128 + 6681.6449294932*t)
	Y0 += 0.00000000619*np.cos(4.56322346372 + 3468.5639597344*t)
	Y0 += 0.00000000779*np.cos(4.63356167618 + 22324.9050567094*t)
	Y0 += 0.00000000683*np.cos(4.49253838209 + 3336.6802734367*t)
	Y0 += 0.00000000683*np.cos(1.63122853655 + 3344.5445799629*t)
	Y0 += 0.00000000608*np.cos(5.34042465771 + 430.5303441391*t)
	Y0 += 0.00000000600*np.cos(1.07842896250 + 3338.069629419*t)
	Y0 += 0.00000000834*np.cos(2.11901816690 + 24150.080051345*t)
	Y0 += 0.00000000735*np.cos(1.11347228352 + 2409.249339848*t)
	Y0 += 0.00000000621*np.cos(5.11737417220 + 10448.4354709754*t)
	Y0 += 0.00000000707*np.cos(5.58024367459 + 1699.2792165032*t)
	Y0 += 0.00000000776*np.cos(1.37472992157 + 6019.9919266186*t)
	Y0 += 0.00000000706*np.cos(2.94874370922 + 6717.8302187038*t)
	Y0 += 0.00000000698*np.cos(2.06677132854 + 838.9692877504*t)
	Y0 += 0.00000000638*np.cos(3.48875178863 + 3826.5844794894*t)
	Y0 += 0.00000000586*np.cos(5.86003431075 + 3528.5375744624*t)
	Y0 += 0.00000000586*np.cos(2.19200605264 + 22345.2603761082*t)
	Y0 += 0.00000000597*np.cos(5.87197147428 + 2540.7913015344*t)
	Y0 += 0.00000000589*np.cos(3.65950730930 + 7380.4960016272*t)
	Y0 += 0.00000000704*np.cos(1.04297020980 + 3547.3131639964*t)
	Y0 += 0.00000000663*np.cos(0.71782437194 + 2301.58581590939*t)
	Y0 += 0.00000000602*np.cos(4.55116981040 + 6681.6547365263*t)
	Y0 += 0.00000000672*np.cos(5.83404606009 + 6666.997759398*t)
	Y0 += 0.00000000691*np.cos(5.87625321159 + 6679.7403806913*t)
	Y0 += 0.00000000644*np.cos(0.37433972538 + 4289.7880356696*t)
	Y0 += 0.00000000559*np.cos(2.62955480222 + 6314.0005244372*t)
	Y0 += 0.00000000613*np.cos(2.81666478638 + 18451.07854656599*t)
	Y0 += 0.00000000584*np.cos(0.31894691338 + 2171.0241752912*t)
	Y0 += 0.00000000648*np.cos(1.07818407115 + 4133.3873151672*t)
	Y0 += 0.00000000610*np.cos(5.23007688005 + 9911.63095888*t)
	Y0 += 0.00000000598*np.cos(5.09026310864 + 423.4167971383*t)
	Y0 += 0.00000000633*np.cos(1.58661078881 + 12.5301729722*t)
	Y0 += 0.00000000647*np.cos(1.86412144751 + 528.7277572481*t)
	Y0 += 0.00000000716*np.cos(1.72986045966 + 19004.6479494084*t)
	Y0 += 0.00000000646*np.cos(5.61853780158 + 530.6541729411*t)
	Y0 += 0.00000000602*np.cos(2.63805578157 + 2854.6403739102*t)
	Y0 += 0.00000000600*np.cos(3.16504307436 + 6724.9437657046*t)
	Y0 += 0.00000000584*np.cos(2.96924262775 + 8226.5788363784*t)
	Y0 += 0.00000000588*np.cos(2.59221040836 + 1685.0521225016*t)
	Y0 += 0.00000000742*np.cos(3.68753265144 + 2547.8375382324*t)
	Y0 += 0.00000000589*np.cos(1.36560850845 + 20.3553193988*t)
	Y0 += 0.00000000613*np.cos(2.32622469131 + 6549.6828917132*t)
	Y0 += 0.00000000634*np.cos(2.56923863836 + 6510.5519827804*t)
	Y0 += 0.00000000602*np.cos(2.24884569451 + 6680.7949702729*t)
	Y0 += 0.00000000527*np.cos(3.82884166493 + 11140.5930722022*t)
	Y0 += 0.00000000570*np.cos(2.11592750094 + 1574.8458012822*t)
	Y0 += 0.00000000522*np.cos(2.26977914970 + 3341.7930693519*t)
	Y0 += 0.00000000522*np.cos(3.85398776894 + 3339.4317840477*t)
	Y0 += 0.00000000546*np.cos(3.96156394907 + 3193.8007401762*t)
	Y0 += 0.00000000533*np.cos(0.72901836770 + 12323.4230960088*t)
	Y0 += 0.00000000553*np.cos(2.12191066592 + 3487.4241132234*t)
	Y0 += 0.00000000714*np.cos(6.24453003731 + 4503.0871311076*t)
	Y0 += 0.00000000672*np.cos(1.51129840313 + 221.3758502853*t)
	Y0 += 0.00000000584*np.cos(4.99460272910 + 3133.9116894032*t)
	Y0 += 0.00000000649*np.cos(0.91092905161 + 1641.3332101966*t)
	Y0 += 0.00000000511*np.cos(1.27411646883 + 16489.763038061*t)
	Y0 += 0.00000000694*np.cos(4.54072508194 + 43.718912305*t)
	Y0 += 0.00000000542*np.cos(2.95211033167 + 1596.1191319818*t)
	Y0 += 0.00000000490*np.cos(1.40385202337 + 71.6002048296*t)
	Y0 += 0.00000000509*np.cos(4.40726650224 + 6812.766815086*t)
	Y0 += 0.00000000489*np.cos(1.49622890471 + 13575.7488022372*t)
	Y0 += 0.00000000535*np.cos(3.39733194552 + 9072.6616711296*t)
	Y0 += 0.00000000536*np.cos(4.94177551833 + 3198.4337996636*t)
	Y0 += 0.00000000619*np.cos(3.39724967275 + 13207.029307365*t)
	Y0 += 0.00000000473*np.cos(3.26277772078 + 77.962992305*t)
	Y0 += 0.00000000474*np.cos(0.14710048229 + 4246.0691233646*t)
	Y0 += 0.00000000527*np.cos(4.43881694959 + 3289.33208883739*t)
	Y0 += 0.00000000527*np.cos(1.68494996905 + 3391.89276456221*t)
	Y0 += 0.00000000491*np.cos(6.12686543849 + 3288.352111787*t)
	Y0 += 0.00000000491*np.cos(6.28008678733 + 3392.8727416126*t)
	Y0 += 0.00000000648*np.cos(6.03788509546 + 22.0914005278*t)
	Y0 += 0.00000000624*np.cos(1.28974618222 + 330.6189636582*t)
	Y0 += 0.00000000473*np.cos(1.65549875820 + 4296.9015826704*t)
	Y0 += 0.00000000653*np.cos(1.15486761496 + 388.4651552382*t)
	Y0 += 0.00000000533*np.cos(5.15285623089 + 3535.5838111604*t)
	Y0 += 0.00000000483*np.cos(2.35115764175 + 3334.54651107*t)
	Y0 += 0.00000000483*np.cos(3.77260927689 + 3346.6783423296*t)
	Y0 += 0.00000000460*np.cos(2.87294253141 + 2281.2477501628*t)
	Y0 += 0.00000000460*np.cos(0.84217089992 + 2281.2132428584*t)
	Y0 += 0.00000000604*np.cos(5.04411661351 + 2373.6415492642*t)
	Y0 += 0.00000000455*np.cos(2.71347773637 + 8962.4726035624*t)
	Y0 += 0.00000000455*np.cos(0.68270610488 + 8962.438096258*t)
	Y0 += 0.00000000506*np.cos(1.18178617794 + 3482.791053736*t)
	Y0 += 0.00000000520*np.cos(4.81778266341 + 382.879278571*t)
	Y0 += 0.00000000453*np.cos(2.02135344772 + 2957.7331481288*t)
	Y0 += 0.00000000633*np.cos(5.05090698547 + 2963.238818784*t)
	Y0 += 0.00000000532*np.cos(1.20297674206 + 728.762966531*t)
	Y0 += 0.00000000502*np.cos(3.05307431011 + 5562.4690612968*t)
	Y0 += 0.00000000475*np.cos(4.42459668952 + 23.8784377478*t)
	Y0 += 0.00000000574*np.cos(4.09850700417 + 87.3117715395*t)
	Y0 += 0.00000000604*np.cos(2.76951680562 + 3370.1042450032*t)
	Y0 += 0.00000000604*np.cos(3.35425011302 + 3311.1206083964*t)
	Y0 += 0.00000000448*np.cos(3.40867489514 + 13361.469385731*t)
	Y0 += 0.00000000500*np.cos(0.96736492114 + 4819.4790007642*t)
	Y0 += 0.00000000440*np.cos(3.12274959821 + 3564.9572224017*t)
	Y0 += 0.00000000604*np.cos(0.41299096165 + 984.6003316219*t)
	Y0 += 0.00000000541*np.cos(1.50869067477 + 72.3339180125*t)
	Y0 += 0.00000000442*np.cos(0.45808507261 + 227.476132789*t)
	Y0 += 0.00000000477*np.cos(4.42611192431 + 4379.6390374902*t)
	Y0 += 0.00000000492*np.cos(3.86744898089 + 11250.7993934216*t)
	Y0 += 0.00000000476*np.cos(3.15928705457 + 2295.4575905122*t)
	Y0 += 0.00000000468*np.cos(3.75342375537 + 4186.695261451*t)
	Y0 += 0.00000000430*np.cos(0.16981325181 + 4716.3862265456*t)
	Y0 += 0.00000000505*np.cos(5.41670810903 + 3495.9655158312*t)
	Y0 += 0.00000000468*np.cos(3.76982493207 + 212.7778305762*t)
	Y0 += 0.00000000450*np.cos(0.92683652577 + 8116.372515159*t)
	Y0 += 0.00000000561*np.cos(4.79003110975 + 4271.9755135516*t)
	Y0 += 0.00000000466*np.cos(4.26202338577 + 213.8203602998*t)
	Y0 += 0.00000000422*np.cos(1.90347011233 + 5753.3848848968*t)
	Y0 += 0.00000000456*np.cos(1.82684055018 + 10006.5848089144*t)
	Y0 += 0.00000000422*np.cos(4.38918966666 + 5223.6939198022*t)
	Y0 += 0.00000000539*np.cos(0.59509723540 + 3185.2593375684*t)
	Y0 += 0.00000000425*np.cos(6.16545314121 + 5888.4499649322*t)
	Y0 += 0.00000000419*np.cos(1.18672277137 + 429.7795846137*t)
	Y0 += 0.00000000436*np.cos(1.02599155499 + 23539.7073863328*t)
	Y0 += 0.00000000423*np.cos(5.23795043183 + 340.7708920448*t)
	Y0 += 0.00000000478*np.cos(4.03784097782 + 5095.6750764648*t)
	Y0 += 0.00000000443*np.cos(5.24107173006 + 1854.6323056346*t)
	Y0 += 0.00000000475*np.cos(4.30595945262 + 6850.8050365326*t)
	Y0 += 0.00000000433*np.cos(3.62643265779 + 3305.0496922312*t)
	Y0 += 0.00000000433*np.cos(2.49733426085 + 3376.1751611684*t)
	Y0 += 0.00000000410*np.cos(5.02461670016 + 2480.302497947*t)
	Y0 += 0.00000000558*np.cos(6.20652192769 + 4025.6564809258*t)
	Y0 += 0.00000000423*np.cos(5.65906920843 + 10037.0897512844*t)
	Y0 += 0.00000000481*np.cos(5.74335395262 + 6685.1570066627*t)
	Y0 += 0.00000000402*np.cos(0.22199197504 + 6151.5511419572*t)
	Y0 += 0.00000000402*np.cos(4.47440565072 + 6151.5166346528*t)
	Y0 += 0.00000000425*np.cos(2.89229866320 + 21265.5231265202*t)
	Y0 += 0.00000000430*np.cos(0.28354344501 + 2655.5683724738*t)
	Y0 += 0.00000000531*np.cos(3.22678253563 + 6637.5059410946*t)
	Y0 += 0.00000000477*np.cos(2.15054075988 + 6614.7374444852*t)
	Y0 += 0.00000000395*np.cos(1.29871885769 + 18849.2275499742*t)
	Y0 += 0.00000000555*np.cos(1.07136034497 + 3717.9860346156*t)
	Y0 += 0.00000000425*np.cos(4.00058546704 + 7218.029365495*t)
	Y0 += 0.00000000456*np.cos(3.63646339661 + 9374.8264467846*t)
	Y0 += 0.00000000392*np.cos(4.13330005973 + 3723.4917052708*t)
	Y0 += 0.00000000430*np.cos(4.01774033971 + 7696.8878712838*t)
	Y0 += 0.00000000486*np.cos(3.27620484219 + 10050.2864675672*t)
	Y0 += 0.00000000413*np.cos(4.62181012252 + 7483.5887758458*t)
	Y0 += 0.00000000403*np.cos(3.03715170877 + 18606.4989460002*t)
	Y0 += 0.00000000388*np.cos(4.53563064046 + 8564.306346502*t)
	Y0 += 0.00000000394*np.cos(0.17224799893 + 4981.9456368964*t)
	Y0 += 0.00000000487*np.cos(3.89276175312 + 1655.5603041982*t)
	Y0 += 0.00000000404*np.cos(3.65562985264 + 6644.6194880954*t)
	Y0 += 0.00000000382*np.cos(0.83080012585 + 3017.1070100424*t)
	Y0 += 0.00000000414*np.cos(0.69798224448 + 7747.7203305896*t)
	Y0 += 0.00000000395*np.cos(3.55436765622 + 1368.660252845*t)
	Y0 += 0.00000000376*np.cos(1.97925827985 + 20735.83216142559*t)
	Y0 += 0.00000000378*np.cos(1.07650858210 + 9801.4246376606*t)
	Y0 += 0.00000000432*np.cos(1.20025313626 + 905.4566966648*t)
	Y0 += 0.00000000448*np.cos(3.40168164363 + 2277.2983432475*t)
	Y0 += 0.00000000511*np.cos(3.34354440535 + 77.2292791221*t)
	Y0 += 0.00000000366*np.cos(3.33686353957 + 912.5702436656*t)
	Y0 += 0.00000000437*np.cos(0.33111846337 + 2285.1626497737*t)
	Y0 += 0.00000000491*np.cos(3.39044076994 + 3.1813937377*t)
	Y0 += 0.00000000364*np.cos(0.19370376341 + 15806.146839442*t)
	Y0 += 0.00000000509*np.cos(4.47318747635 + 1765.7666254176*t)
	Y0 += 0.00000000424*np.cos(0.31309571718 + 5881.4037282342*t)
	Y0 += 0.00000000475*np.cos(2.97743590747 + 1329.51209026*t)
	Y0 += 0.00000000363*np.cos(2.53252878777 + 25685.872802808*t)
	Y0 += 0.00000000379*np.cos(5.77822316957 + 7366.2689076256*t)
	Y0 += 0.00000000355*np.cos(2.42667156551 + 5636.070017212*t)
	Y0 += 0.00000000475*np.cos(3.89107293655 + 21795.21409161479*t)
	Y0 += 0.00000000351*np.cos(4.13578832624 + 6851.8977240188*t)
	Y0 += 0.00000000452*np.cos(0.50803184514 + 6106.8800550648*t)
	Y0 += 0.00000000344*np.cos(5.37144778531 + 16894.5103996106*t)
	Y0 += 0.00000000364*np.cos(0.71572042055 + 6682.7093261079*t)
	Y0 += 0.00000000388*np.cos(2.20834855471 + 20618.0193585336*t)
	Y0 += 0.00000000343*np.cos(6.13470925292 + 2435.155730035*t)
	Y0 += 0.00000000452*np.cos(1.07313020826 + 4307.5833041354*t)
	Y0 += 0.00000000339*np.cos(4.53065010744 + 1883.0814931024*t)
	Y0 += 0.00000000361*np.cos(5.00906964184 + 27682.1407441564*t)
	Y0 += 0.00000000351*np.cos(2.80463066915 + 5452.2627400774*t)
	Y0 += 0.00000000413*np.cos(0.42041417925 + 145.1097790097*t)
	Y0 += 0.00000000335*np.cos(0.80197784093 + 15636.566656309*t)
	Y0 += 0.00000000336*np.cos(5.60932577353 + 127.4717966068*t)
	Y0 += 0.00000000434*np.cos(0.32563509977 + 7214.4389368432*t)
	Y0 += 0.00000000395*np.cos(4.16776570158 + 9993.3880926316*t)
	Y0 += 0.00000000352*np.cos(2.61512238463 + 1250.8301963008*t)
	Y0 += 0.00000000409*np.cos(0.70233676711 + 350.3321196004*t)
	Y0 += 0.00000000394*np.cos(3.54014449716 + 9797.4924843975*t)
	Y0 += 0.00000000327*np.cos(4.04880436765 + 3353.85419909779*t)
	Y0 += 0.00000000327*np.cos(2.07496255099 + 3327.3706543018*t)
	Y0 += 0.00000000351*np.cos(0.12561529818 + 13212.8865096646*t)
	Y0 += 0.00000000415*np.cos(3.58472859131 + 21947.11137270*t)
	Y0 += 0.00000000447*np.cos(4.74470130101 + 13363.4300278674*t)
	Y0 += 0.00000000336*np.cos(2.93237714822 + 0.9803210682*t)
	Y0 += 0.00000000389*np.cos(1.05447612688 + 30065.5118402982*t)
	Y0 += 0.00000000361*np.cos(1.50116564732 + 5749.8617665478*t)
	Y0 += 0.00000000444*np.cos(0.28150228175 + 8982.810669309*t)
	Y0 += 0.00000000395*np.cos(1.75358681150 + 3337.1566186536*t)
	Y0 += 0.00000000327*np.cos(4.40197406437 + 146.8116865236*t)
	Y0 += 0.00000000383*np.cos(4.56297720194 + 909.8187330546*t)
	Y0 += 0.00000000320*np.cos(4.04485044014 + 25287.7237993998*t)
	Y0 += 0.00000000339*np.cos(4.51129199209 + 14556.8967170238*t)
	Y0 += 0.00000000389*np.cos(4.52937583175 + 18052.9295431578*t)
	Y0 += 0.00000000408*np.cos(6.10449821431 + 11883.5831327348*t)
	Y0 += 0.00000000384*np.cos(4.30166402202 + 7733.493236588*t)
	Y0 += 0.00000000335*np.cos(2.75369658972 + 3060.8259223474*t)
	Y0 += 0.00000000344*np.cos(0.16236119441 + 568.8218740274*t)
	Y0 += 0.00000000314*np.cos(2.59903777963 + 15265.8865193004*t)
	Y0 += 0.00000000355*np.cos(6.17242188932 + 7322.1024607818*t)
	Y0 += 0.00000000316*np.cos(5.59149424389 + 3440.1820825694*t)
	Y0 += 0.00000000316*np.cos(0.53227267475 + 3241.0427708302*t)
	Y0 += 0.00000000354*np.cos(0.64235154390 + 4606.1799053262*t)
	Y0 += 0.00000000375*np.cos(0.23620758788 + 108.4612160802*t)
	Y0 += 0.00000000310*np.cos(5.64297192066 + 6453.7487206106*t)
	Y0 += 0.00000000317*np.cos(2.40423598623 + 2973.3880977374*t)
	Y0 += 0.00000000300*np.cos(2.21725287793 + 1987.221898692*t)
	Y0 += 0.00000000313*np.cos(2.04966851954 + 234.6397364404*t)
	Y0 += 0.00000000299*np.cos(4.05930436366 + 10284.9212034722*t)
	Y0 += 0.00000000342*np.cos(1.05396519831 + 14128.2427712456*t)
	Y0 += 0.00000000379*np.cos(2.27965866856 + 1461.0540519464*t)
	Y0 += 0.00000000382*np.cos(0.24418522119 + 186.2117600641*t)
	Y0 += 0.00000000294*np.cos(1.92173439518 + 20040.15144184979*t)
	Y0 += 0.00000000360*np.cos(3.42990211925 + 16063.164847185*t)
	Y0 += 0.00000000313*np.cos(1.30391208259 + 6286.5989683404*t)
	Y0 += 0.00000000307*np.cos(6.22295802105 + 9755.2302383776*t)
	Y0 += 0.00000000306*np.cos(4.47697327581 + 8756.269801473*t)
	Y0 += 0.00000000361*np.cos(1.45253410618 + 685.044054226*t)
	Y0 += 0.00000000392*np.cos(1.48127453453 + 19645.5255567906*t)
	Y0 += 0.00000000328*np.cos(2.03910800196 + 3397.4156888696*t)
	Y0 += 0.00000000328*np.cos(4.08465891668 + 3283.80916453*t)
	Y0 += 0.00000000316*np.cos(2.32828995492 + 5621.8601768626*t)
	Y0 += 0.00000000397*np.cos(5.55627760256 + 23141.5583829246*t)
	Y0 += 0.00000000294*np.cos(1.44129558600 + 5483.254724826*t)
	Y0 += 0.00000000291*np.cos(0.90595258507 + 11986.6759069534*t)
	Y0 += 0.00000000307*np.cos(2.00013192821 + 8749.1562544722*t)
	Y0 += 0.00000000314*np.cos(2.64774700056 + 9983.7042444616*t)
	Y0 += 0.00000000340*np.cos(3.83856139387 + 12509.2533250472*t)
	Y0 += 0.00000000339*np.cos(0.25931753019 + 3856.0762977928*t)
	Y0 += 0.00000000339*np.cos(5.86444938845 + 2825.1485556068*t)
	Y0 += 0.00000000283*np.cos(3.01099503487 + 5244.049239201*t)
	Y0 += 0.00000000383*np.cos(3.28640230880 + 2921.6880277992*t)
	Y0 += 0.00000000282*np.cos(3.52940833364 + 5106.3790521174*t)
	Y0 += 0.00000000302*np.cos(4.91996410033 + 12825.6451947038*t)
	Y0 += 0.00000000287*np.cos(2.38824152806 + 194.9713844606*t)
	Y0 += 0.00000000310*np.cos(0.61972171326 + 2060.8178540718*t)
	Y0 += 0.00000000382*np.cos(1.17991122952 + 3267.3153008408*t)
	Y0 += 0.00000000382*np.cos(4.94385568912 + 3413.9095525588*t)
	Y0 += 0.00000000304*np.cos(3.37219185052 + 3620.3989310522*t)
	Y0 += 0.00000000285*np.cos(4.10904023674 + 279.7865043524*t)
	Y0 += 0.00000000316*np.cos(0.29751832342 + 5621.8256695582*t)
	Y0 += 0.00000000283*np.cos(1.21247425709 + 12839.8722887054*t)
	Y0 += 0.00000000296*np.cos(3.06136390749 + 187.9251477626*t)
	Y0 += 0.00000000283*np.cos(4.53197273536 + 9859.3706439672*t)
	Y0 += 0.00000000281*np.cos(3.88336320291 + 596.178374009*t)
	Y0 += 0.00000000308*np.cos(1.11858229845 + 362.8622925726*t)
	Y0 += 0.00000000288*np.cos(0.91165100893 + 1471.7530270636*t)
	Y0 += 0.00000000280*np.cos(0.42006444847 + 16511.6138673874*t)
	Y0 += 0.00000000298*np.cos(0.08485122631 + 11236.57229942*t)
	Y0 += 0.00000000311*np.cos(2.87485251647 + 297.6419215609*t)
	Y0 += 0.00000000289*np.cos(0.35271915498 + 529.1697002328*t)
	Y0 += 0.00000000289*np.cos(0.84527308658 + 530.2122299564*t)
	Y0 += 0.00000000285*np.cos(0.56726195027 + 206.7007372966*t)
	Y0 += 0.00000000366*np.cos(1.35412421660 + 604.4725636619*t)
	Y0 += 0.00000000282*np.cos(0.06832834990 + 62.2514255951*t)
	Y0 += 0.00000000300*np.cos(3.90419594378 + 5820.9149246468*t)
	Y0 += 0.00000000321*np.cos(0.39004570182 + 2267.003402509*t)
	Y0 += 0.00000000261*np.cos(1.23435301369 + 20206.141196331*t)
	Y0 += 0.00000000316*np.cos(1.01160877914 + 5490.300961524*t)
	Y0 += 0.00000000263*np.cos(4.77643040513 + 52.6901980395*t)
	Y0 += 0.00000000261*np.cos(6.22536803454 + 1279.794572628*t)
	Y0 += 0.00000000257*np.cos(2.63966270921 + 1258.4539316256*t)
	Y0 += 0.00000000271*np.cos(3.84708232270 + 3336.0416769798*t)
	Y0 += 0.00000000271*np.cos(2.27668459594 + 3345.1831764198*t)
	Y0 += 0.00000000259*np.cos(2.83680935134 + 2744.4340526908*t)
	Y0 += 0.00000000268*np.cos(5.19560766387 + 2149.6885348242*t)
	Y0 += 0.00000000251*np.cos(2.15515665308 + 3337.5093844444*t)
	Y0 += 0.00000000251*np.cos(3.96861026556 + 3343.7154689552*t)
	Y0 += 0.00000000251*np.cos(3.37137074296 + 9758.7533567266*t)
	Y0 += 0.00000000251*np.cos(1.54323704062 + 1903.4368125012*t)
	Y0 += 0.00000000291*np.cos(4.03266591834 + 367.2243289624*t)
	Y0 += 0.00000000250*np.cos(0.13361485614 + 2142.6422981262*t)
	Y0 += 0.00000000267*np.cos(0.96036007447 + 6830.7880505342*t)
	Y0 += 0.00000000306*np.cos(1.35986909253 + 12012.5822971404*t)
	Y0 += 0.00000000255*np.cos(3.17215031285 + 12928.7379689224*t)
	Y0 += 0.00000000290*np.cos(1.30201044096 + 20047.1976785478*t)
	Y0 += 0.00000000268*np.cos(1.47703232305 + 16702.9948231962*t)
	Y0 += 0.00000000324*np.cos(5.37496427957 + 200.7689224658*t)
	Y0 += 0.00000000250*np.cos(0.95280868140 + 9698.331863442*t)
	Y0 += 0.00000000246*np.cos(3.89830112418 + 15650.7937503106*t)
	Y0 += 0.00000000247*np.cos(5.73950808020 + 10016.314355792*t)
	Y0 += 0.00000000257*np.cos(3.56657939800 + 5430.3946570988*t)
	Y0 += 0.00000000255*np.cos(4.87354006866 + 21548.9623692918*t)
	Y0 += 0.00000000269*np.cos(1.11468463011 + 36.0278666774*t)
	Y0 += 0.00000000275*np.cos(6.25194576299 + 565.1156877467*t)
	Y0 += 0.00000000269*np.cos(4.90534085198 + 140.001969579*t)
	Y0 += 0.00000000255*np.cos(2.82393072524 + 26482.1708096244*t)
	Y0 += 0.00000000321*np.cos(5.03461670419 + 703.6331846174*t)
	Y0 += 0.00000000255*np.cos(1.56711743342 + 1727.6610936682*t)
	Y0 += 0.00000000276*np.cos(4.96569192497 + 6670.1791531357*t)
	Y0 += 0.00000000320*np.cos(5.04391570277 + 11904.9187732018*t)
	Y0 += 0.00000000249*np.cos(4.80534758404 + 210.3783341312*t)
	Y0 += 0.00000000248*np.cos(3.22187918056 + 216.2198567448*t)
	Y0 += 0.00000000243*np.cos(5.15609899738 + 1062.5633239269*t)
	Y0 += 0.00000000336*np.cos(6.10975677385 + 454.9093665273*t)
	Y0 += 0.00000000240*np.cos(1.67381717935 + 37.611770776*t)
	Y0 += 0.00000000280*np.cos(5.37126197378 + 5401.4302807716*t)
	Y0 += 0.00000000237*np.cos(2.15132956903 + 212.5483359126*t)
	Y0 += 0.00000000255*np.cos(3.33122871209 + 153.4953503977*t)
	Y0 += 0.00000000258*np.cos(2.68846300150 + 9488.6231966558*t)
	Y0 += 0.00000000269*np.cos(1.83867958993 + 3866.7802734454*t)
	Y0 += 0.00000000265*np.cos(2.90618128587 + 3053.6500655792*t)
	Y0 += 0.00000000240*np.cos(1.73397693635 + 10027.3602044068*t)
	Y0 += 0.00000000321*np.cos(2.82885605337 + 3759.5368256004*t)
	Y0 += 0.00000000319*np.cos(3.59122436698 + 9815.6517316622*t)
	Y0 += 0.00000000236*np.cos(5.87788994285 + 214.0498549634*t)
	Y0 += 0.00000000251*np.cos(5.02021336588 + 2790.5661422064*t)
	Y0 += 0.00000000322*np.cos(4.83706419059 + 17085.9586657222*t)
	Y0 += 0.00000000326*np.cos(4.20517834971 + 3707.8367556622*t)
	Y0 += 0.00000000236*np.cos(2.66792286959 + 38.6543004996*t)
	Y0 += 0.00000000252*np.cos(3.03988883560 + 209.106309744*t)
	Y0 += 0.00000000311*np.cos(5.99598016839 + 3391.4448860056*t)
	Y0 += 0.00000000311*np.cos(0.12778675025 + 3289.779967394*t)
	Y0 += 0.00000000272*np.cos(4.72506446876 + 10706.8813343254*t)
	Y0 += 0.00000000230*np.cos(1.62590974520 + 10654.6210194126*t)
	Y0 += 0.00000000292*np.cos(5.65389851248 + 3050.1269472302*t)
	Y0 += 0.00000000235*np.cos(2.10330649321 + 5945.3483398678*t)
	Y0 += 0.00000000301*np.cos(2.35277176785 + 9495.6694333538*t)
	Y0 += 0.00000000248*np.cos(4.98513016170 + 217.491881132*t)
	Y0 += 0.00000000227*np.cos(5.71659702017 + 1868.8593996362*t)
	Y0 += 0.00000000233*np.cos(3.39950183393 + 4996.172730898*t)
	Y0 += 0.00000000225*np.cos(2.61344044624 + 2938.9403049426*t)
	Y0 += 0.00000000225*np.cos(1.81041528541 + 223.5940361765*t)
	Y0 += 0.00000000225*np.cos(4.67024091816 + 24341.5283174566*t)
	Y0 += 0.00000000312*np.cos(4.22328014540 + 4403.517475238*t)
	Y0 += 0.00000000224*np.cos(4.82206915571 + 5.5229243074*t)
	Y0 += 0.00000000224*np.cos(3.94824411240 + 38.084851528*t)
	Y0 += 0.00000000223*np.cos(0.39234241482 + 38.1812197476*t)
	Y0 += 0.00000000222*np.cos(1.20460555062 + 1835.3246176068*t)
	Y0 += 0.00000000289*np.cos(0.65812694051 + 6901.6374958384*t)
	Y0 += 0.00000000244*np.cos(2.21530907924 + 5349.1699658588*t)
	Y0 += 0.00000000268*np.cos(1.06853593620 + 16703.1294438018*t)
	Y0 += 0.00000000243*np.cos(1.91517218823 + 1442.2612087602*t)
	Y0 += 0.00000000220*np.cos(2.74511541811 + 6511.6446702666*t)
	Y0 += 0.00000000234*np.cos(0.06116213374 + 17499.3601403154*t)
	Y0 += 0.00000000224*np.cos(6.22254343881 + 3542.8658218739*t)
	Y0 += 0.00000000224*np.cos(6.18440878701 + 3138.3590315257*t)
	Y0 += 0.00000000218*np.cos(5.88781974409 + 6283.0931036436*t)
	Y0 += 0.00000000218*np.cos(3.85704811260 + 6283.0585963392*t)
	Y0 += 0.00000000256*np.cos(6.05446717792 + 151.8972810852*t)
	Y0 += 0.00000000220*np.cos(3.19711314225 + 3987.6232600146*t)
	Y0 += 0.00000000219*np.cos(1.56460932980 + 8584.6616659008*t)
	Y0 += 0.00000000215*np.cos(5.15532893112 + 13383.2251022916*t)
	Y0 += 0.00000000244*np.cos(2.64604748092 + 173.9422195228*t)
	Y0 += 0.00000000215*np.cos(5.16313544064 + 5511.636601991*t)
	Y0 += 0.00000000219*np.cos(5.27028412241 + 1802.3719907218*t)
	Y0 += 0.00000000215*np.cos(2.86756714739 + 5617.9107699473*t)
	Y0 += 0.00000000244*np.cos(5.85362027072 + 2814.4445799542*t)
	Y0 += 0.00000000211*np.cos(0.74742043486 + 19676.4502312364*t)
	Y0 += 0.00000000227*np.cos(2.59606896980 + 9278.8472195668*t)
	Y0 += 0.00000000211*np.cos(5.04144285274 + 12199.9750023914*t)
	Y0 += 0.00000000212*np.cos(0.14538044968 + 2392.4171387982*t)
	Y0 += 0.00000000234*np.cos(5.26336192114 + 74.2603337055*t)
	Y0 += 0.00000000233*np.cos(5.70130722395 + 75.3028634291*t)
	Y0 += 0.00000000237*np.cos(3.21759075914 + 3627.57478782039*t)
	Y0 += 0.00000000287*np.cos(1.05955224588 + 12465.5344127422*t)
	Y0 += 0.00000000220*np.cos(0.54828486823 + 6530.1771835567*t)
	Y0 += 0.00000000263*np.cos(5.32330172342 + 4531.5363185754*t)
	Y0 += 0.00000000249*np.cos(2.58328462618 + 3084.6420503278*t)
	Y0 += 0.00000000252*np.cos(3.03997100024 + 3382.1632176846*t)
	Y0 += 0.00000000252*np.cos(3.08379591840 + 3299.061635715*t)
	Y0 += 0.00000000267*np.cos(5.74809850023 + 5415.6573747732*t)
	Y0 += 0.00000000239*np.cos(1.63889533266 + 3344.068234746*t)
	Y0 += 0.00000000262*np.cos(0.46948508418 + 3631.0979061694*t)
	Y0 += 0.00000000206*np.cos(1.80117058552 + 7082.8969751568*t)
	Y0 += 0.00000000210*np.cos(5.81059147043 + 6678.4733427886*t)
	Y0 += 0.00000000255*np.cos(1.55350830983 + 1994.26813539*t)
	Y0 += 0.00000000210*np.cos(6.25153793027 + 1484.9324896942*t)
	Y0 += 0.00000000274*np.cos(4.79336564976 + 12306.590894959*t)
	Y0 += 0.00000000204*np.cos(0.76733899172 + 6382.0984591304*t)
	Y0 += 0.00000000223*np.cos(3.13516948674 + 3336.25039031*t)
	Y0 += 0.00000000223*np.cos(2.98859743190 + 3344.9744630896*t)
	Y0 += 0.00000000255*np.cos(5.28908452900 + 2942.4806769438*t)
	Y0 += 0.00000000224*np.cos(1.52427347828 + 6533.1461289733*t)
	Y0 += 0.00000000247*np.cos(5.27605423414 + 252.6559713532*t)
	Y0 += 0.00000000233*np.cos(5.90676932856 + 19146.7592661418*t)
	Y0 += 0.00000000203*np.cos(5.54978754111 + 18.1592472647*t)
	Y0 += 0.00000000201*np.cos(5.35533176059 + 9360.6043533184*t)
	Y0 += 0.00000000282*np.cos(6.12964546434 + 563.6312150384*t)
	Y0 += 0.00000000211*np.cos(1.15148869397 + 3890.65871119319*t)
	Y0 += 0.00000000227*np.cos(6.03580433993 + 5625.7750764735*t)
	Y0 += 0.00000000200*np.cos(6.26289082650 + 7586.6815500644*t)
	Y0 += 0.00000000199*np.cos(3.26137019616 + 3029.7716278314*t)
	Y0 += 0.00000000243*np.cos(4.23643794604 + 9329.6796788726*t)
	Y0 += 0.00000000199*np.cos(3.94721644624 + 2089.782230399*t)
	Y0 += 0.00000000250*np.cos(5.43333163998 + 24889.5747959916*t)
	Y0 += 0.00000000224*np.cos(0.66388865647 + 88.865680217*t)
	Y0 += 0.00000000197*np.cos(1.15409232210 + 3436.5916539176*t)
	Y0 += 0.00000000197*np.cos(4.96967459654 + 3244.633199482*t)
	Y0 += 0.00000000223*np.cos(0.34944239276 + 3.5904286518*t)
	Y0 += 0.00000000197*np.cos(0.20677207241 + 15106.8756912144*t)
	Y0 += 0.00000000226*np.cos(3.40580699459 + 2428.0421830342*t)
	Y0 += 0.00000000231*np.cos(2.63984097637 + 6653.8232973028*t)
	Y0 += 0.00000000205*np.cos(4.98750840184 + 417.0369633204*t)
	Y0 += 0.00000000198*np.cos(3.92131152950 + 3094.36070437679*t)
	Y0 += 0.00000000223*np.cos(3.01290266414 + 13341.6743113068*t)
	Y0 += 0.00000000211*np.cos(3.56508711838 + 37.1698277913*t)
	Y0 += 0.00000000198*np.cos(4.43881610804 + 18208.349942592*t)
	Y0 += 0.00000000191*np.cos(5.50522939133 + 3752.9835235742*t)
	Y0 += 0.00000000191*np.cos(0.61853752731 + 2928.2413298254*t)
	Y0 += 0.00000000192*np.cos(3.48407799837 + 15121.102785216*t)
	Y0 += 0.00000000192*np.cos(2.70968461449 + 66.70484372*t)
	Y0 += 0.00000000221*np.cos(0.94687593506 + 3649.8907493556*t)
	Y0 += 0.00000000212*np.cos(4.83879513966 + 4538.5825552734*t)
	Y0 += 0.00000000192*np.cos(2.00799170950 + 3315.7536678838*t)
	Y0 += 0.00000000192*np.cos(4.11577520914 + 3365.4711855158*t)
	Y0 += 0.00000000226*np.cos(3.54050854737 + 3596.5828030718*t)
	Y0 += 0.00000000204*np.cos(2.47411750627 + 207.6700211455*t)
	Y0 += 0.00000000255*np.cos(3.25831289751 + 2942.4461696394*t)
	Y0 += 0.00000000191*np.cos(0.88273497404 + 10544.4146981932*t)
	Y0 += 0.00000000228*np.cos(3.58367417249 + 207.8824694666*t)
	Y0 += 0.00000000203*np.cos(0.77682463263 + 39.0962434843*t)
	Y0 += 0.00000000205*np.cos(0.67759896423 + 1059.364676537*t)
	Y0 += 0.00000000188*np.cos(0.18939361921 + 3363.3809233092*t)
	Y0 += 0.00000000188*np.cos(5.93437329943 + 3317.8439300904*t)
	Y0 += 0.00000000231*np.cos(2.52066042702 + 9093.9973115966*t)
	Y0 += 0.00000000228*np.cos(2.13919737338 + 369.6998159404*t)
	Y0 += 0.00000000182*np.cos(1.33127974270 + 5960.0856221934*t)
	Y0 += 0.00000000220*np.cos(4.46432405157 + 218.7157214094*t)
	Y0 += 0.00000000183*np.cos(1.25274653764 + 4878.8528626778*t)
	Y0 += 0.00000000182*np.cos(1.65755265452 + 1382.8873468466*t)
	Y0 += 0.00000000193*np.cos(2.43223658328 + 7417.1013669314*t)
	Y0 += 0.00000000188*np.cos(0.40235506847 + 2735.762685995*t)
	Y0 += 0.00000000186*np.cos(2.59788381829 + 508.3503240922*t)
	Y0 += 0.00000000189*np.cos(5.13510234469 + 11353.8921676402*t)
	Y0 += 0.00000000180*np.cos(5.03093948829 + 1755.062649765*t)
	Y0 += 0.00000000222*np.cos(6.00721433544 + 3070.4149563262*t)
	Y0 += 0.00000000233*np.cos(3.17507790219 + 5351.7127631396*t)
	Y0 += 0.00000000195*np.cos(5.53819155539 + 218.9281697305*t)
	Y0 += 0.00000000177*np.cos(2.86226760448 + 3651.4532255682*t)
	Y0 += 0.00000000232*np.cos(3.46445207879 + 3163.918696566*t)
	Y0 += 0.00000000232*np.cos(2.65931483985 + 3517.3061568336*t)
	Y0 += 0.00000000176*np.cos(3.48010790145 + 6342.9821544166*t)
	Y0 += 0.00000000180*np.cos(5.30008115245 + 3332.5185586308*t)
	Y0 += 0.00000000180*np.cos(0.82368576619 + 3348.7062947688*t)
	Y0 += 0.00000000179*np.cos(2.20235361692 + 3586.8641490228*t)
	Y0 += 0.00000000185*np.cos(5.05060067762 + 4061.751657906*t)
	Y0 += 0.00000000205*np.cos(2.70837059572 + 1059.3991838414*t)
	Y0 += 0.00000000187*np.cos(1.04746838799 + 2619.4731954936*t)
	Y0 += 0.00000000176*np.cos(3.90353461991 + 13465.5424810178*t)
	Y0 += 0.00000000208*np.cos(2.66589443408 + 4253.1826703654*t)
	Y0 += 0.00000000174*np.cos(4.55814413103 + 10096.6188786667*t)
	Y0 += 0.00000000188*np.cos(3.92958586943 + 2574.8193622534*t)
	Y0 += 0.00000000175*np.cos(5.69635587487 + 12299.544658261*t)
	Y0 += 0.00000000240*np.cos(2.78491358774 + 5085.1057214178*t)
	Y0 += 0.00000000208*np.cos(1.23374873483 + 10721.108428327*t)
	Y0 += 0.00000000242*np.cos(2.13161585563 + 11925.2740926006*t)
	Y0 += 0.00000000173*np.cos(5.89789471349 + 28230.18722269139*t)
	Y0 += 0.00000000177*np.cos(5.31666142975 + 2572.7636073512*t)
	Y0 += 0.00000000178*np.cos(4.08297672654 + 211.8146227297*t)
	Y0 += 0.00000000225*np.cos(1.90849387608 + 23958.6317852334*t)
	Y0 += 0.00000000224*np.cos(2.49436555659 + 1056.2005364515*t)
	Y0 += 0.00000000231*np.cos(5.40468485650 + 31022.7531708562*t)
	Y0 += 0.00000000210*np.cos(0.98942403448 + 6683.9763640106*t)
	Y0 += 0.00000000175*np.cos(4.13281638704 + 6708.6264094964*t)
	Y0 += 0.00000000174*np.cos(4.83665165671 + 3155.7625187296*t)
	Y0 += 0.00000000169*np.cos(3.90681440181 + 4694.0029547076*t)
	Y0 += 0.00000000169*np.cos(3.54733614920 + 6684.73071809641*t)
	Y0 += 0.00000000195*np.cos(0.90841744066 + 28.5718080822*t)
	Y0 += 0.00000000169*np.cos(5.57810778070 + 6684.7652254008*t)
	Y0 += 0.00000000191*np.cos(3.61332015676 + 11567.1912630782*t)
	Y0 += 0.00000000207*np.cos(2.89825036062 + 10001.48196070061*t)
	Y0 += 0.00000000190*np.cos(4.35107066119 + 142.4496501338*t)
	Y0 += 0.00000000185*np.cos(3.07114551783 + 3936.7908007088*t)
	Y0 += 0.00000000189*np.cos(5.77291316706 + 2783.5199055084*t)
	Y0 += 0.00000000197*np.cos(5.75026594358 + 8166.1573430938*t)
	Y0 += 0.00000000203*np.cos(3.16676623170 + 4466.4817658034*t)
	Y0 += 0.00000000171*np.cos(1.38853028989 + 526.7702037878*t)
	Y0 += 0.00000000167*np.cos(5.13944886262 + 158.9435177832*t)
	Y0 += 0.00000000165*np.cos(1.89458907755 + 6566.8257464862*t)
	Y0 += 0.00000000219*np.cos(4.30567311434 + 3070.482266629*t)
	Y0 += 0.00000000177*np.cos(3.00242387112 + 2978.491289969*t)
	Y0 += 0.00000000179*np.cos(2.14367659492 + 17232.7530985936*t)
	Y0 += 0.00000000186*np.cos(5.42678326989 + 554.0699874828*t)
	Y0 += 0.00000000169*np.cos(0.26354444683 + 11456.9849418588*t)
	Y0 += 0.00000000169*np.cos(6.09402587013 + 532.6117264014*t)
	Y0 += 0.00000000217*np.cos(2.01707572818 + 124.433415221*t)
	Y0 += 0.00000000184*np.cos(6.11553659620 + 12942.965062924*t)
	Y0 += 0.00000000214*np.cos(5.24745003905 + 604.8497407048*t)
	Y0 += 0.00000000168*np.cos(1.24832202487 + 1111.642245102*t)
	Y0 += 0.00000000162*np.cos(0.40163918127 + 16695.94858649819*t)
	Y0 += 0.00000000175*np.cos(5.92248308601 + 525.4981794006*t)
	Y0 += 0.00000000167*np.cos(0.42456512338 + 24491.4257925834*t)
	Y0 += 0.00000000200*np.cos(0.11649489032 + 3610.8098970734*t)
	Y0 += 0.00000000188*np.cos(0.87790891193 + 2385.3709021002*t)
	Y0 += 0.00000000185*np.cos(0.38071563992 + 4452.2546718018*t)
	Y0 += 0.00000000170*np.cos(4.45477263786 + 28628.3362260996*t)
	Y0 += 0.00000000168*np.cos(0.43144821098 + 6165.7609823066*t)
	Y0 += 0.00000000201*np.cos(3.99164016173 + 3738.7441764558*t)
	Y0 += 0.00000000188*np.cos(1.10311001587 + 1744.493294718*t)
	Y0 += 0.00000000159*np.cos(3.67101894096 + 14481.205498902*t)
	Y0 += 0.00000000162*np.cos(5.14005106474 + 272.6729573516*t)
	Y0 += 0.00000000156*np.cos(5.01784452685 + 8436.2875031646*t)
	Y0 += 0.00000000158*np.cos(5.04734034343 + 528.9402055692*t)
	Y0 += 0.00000000170*np.cos(5.97804289682 + 4825.544916394*t)
	Y0 += 0.00000000163*np.cos(0.14934835314 + 3345.8116178656*t)
	Y0 += 0.00000000163*np.cos(5.97441856550 + 3335.413235534*t)
	Y0 += 0.00000000157*np.cos(2.43465536306 + 530.44172462*t)
	Y0 += 0.00000000188*np.cos(1.87050370857 + 569.0478410098*t)
	Y0 += 0.00000000165*np.cos(0.42827361678 + 10.6366653498*t)
	Y0 += 0.00000000194*np.cos(2.55166855580 + 183.2428146475*t)
	Y0 += 0.00000000166*np.cos(4.24037747344 + 1898.3512179396*t)
	Y0 += 0.00000000174*np.cos(0.55658276896 + 10787.6303445458*t)
	Y0 += 0.00000000175*np.cos(5.91625467468 + 2757.6135153214*t)
	Y0 += 0.00000000153*np.cos(0.22099888781 + 7447.017917846*t)
	Y0 += 0.00000000184*np.cos(3.91518117795 + 5220.1708014532*t)
	Y0 += 0.00000000214*np.cos(2.37690992241 + 1385.8952763362*t)
	Y0 += 0.00000000171*np.cos(0.07657131354 + 10011.2006147496*t)
	Y0 += 0.00000000163*np.cos(0.47065867853 + 13286.1836355236*t)
	Y0 += 0.00000000152*np.cos(2.34971090866 + 2011.1003364398*t)
	Y0 += 0.00000000154*np.cos(3.98395343557 + 8771.0070837986*t)
	Y0 += 0.00000000151*np.cos(4.45990869608 + 15010.8964639966*t)
	Y0 += 0.00000000178*np.cos(6.20228633181 + 5.9378908332*t)
	Y0 += 0.00000000153*np.cos(5.74866858603 + 9153.9036160218*t)
	Y0 += 0.00000000171*np.cos(4.58339007555 + 21393.5419698576*t)
	Y0 += 0.00000000169*np.cos(4.62232700739 + 7064.1041319706*t)
	Y0 += 0.00000000166*np.cos(5.48604111479 + 6719.3578890374*t)
	Y0 += 0.00000000207*np.cos(0.24572465192 + 73.8183907208*t)
	Y0 += 0.00000000185*np.cos(3.34815986923 + 265.9892934775*t)
	Y0 += 0.00000000151*np.cos(4.33106068620 + 10228.0228285366*t)
	Y0 += 0.00000000151*np.cos(1.25876714050 + 3525.46233467*t)
	Y0 += 0.00000000175*np.cos(5.99371438486 + 217.964961884*t)
	Y0 += 0.00000000149*np.cos(0.32471999674 + 3664.1178433572*t)
	Y0 += 0.00000000196*np.cos(1.82164041147 + 3610.7425867706*t)
	Y0 += 0.00000000166*np.cos(0.46106393944 + 5466.489834079*t)
	Y0 += 0.00000000167*np.cos(1.32101864186 + 10288.4443218212*t)
	Y0 += 0.00000000167*np.cos(5.49820703705 + 5813.291189322*t)
	Y0 += 0.00000000148*np.cos(2.83101653780 + 519.3960243561*t)
	Y0 += 0.00000000147*np.cos(0.61292233753 + 1898.3339642874*t)
	Y0 += 0.00000000166*np.cos(1.16464294435 + 6908.7009861886*t)
	Y0 += 0.00000000172*np.cos(3.82515637777 + 19617.07636932279*t)
	Y0 += 0.00000000146*np.cos(2.06659470489 + 82.8583534146*t)
	Y0 += 0.00000000182*np.cos(4.81327110244 + 8535.8571590342*t)
	Y0 += 0.00000000154*np.cos(2.09016136698 + 1346.3442913098*t)
	Y0 += 0.00000000145*np.cos(5.82715197678 + 14577.1847261198*t)
	Y0 += 0.00000000201*np.cos(6.02241179322 + 3738.7786837602*t)
	Y0 += 0.00000000146*np.cos(5.33364778234 + 13369.56325380*t)
	Y0 += 0.00000000170*np.cos(4.17129374991 + 6677.6844813984*t)
	Y0 += 0.00000000147*np.cos(0.30529245684 + 9918.7445058808*t)
	Y0 += 0.00000000192*np.cos(4.39395898967 + 425.1137181677*t)
	Y0 += 0.00000000159*np.cos(1.38117514790 + 3346.4696289994*t)
	Y0 += 0.00000000159*np.cos(4.74259177074 + 3334.7552244002*t)
	Y0 += 0.00000000144*np.cos(1.48919516907 + 8322.5580635962*t)
	Y0 += 0.00000000149*np.cos(1.96157392100 + 414.0680179038*t)
	Y0 += 0.00000000143*np.cos(5.81404981785 + 13227.3846267638*t)
	Y0 += 0.00000000189*np.cos(4.57066567683 + 10042.1925994982*t)
	Y0 += 0.00000000165*np.cos(3.65136085639 + 231.4583427027*t)
	Y0 += 0.00000000153*np.cos(3.12132749782 + 3702.7335634306*t)
	Y0 += 0.00000000201*np.cos(4.11002299299 + 453.424893819*t)
	Y0 += 0.00000000200*np.cos(4.96476307548 + 1439.5096981492*t)
	Y0 += 0.00000000170*np.cos(6.22747964368 + 5607.6158292088*t)
	Y0 += 0.00000000168*np.cos(1.11741682536 + 10032.4739454492*t)
	Y0 += 0.00000000151*np.cos(0.91764249974 + 1859.2030553546*t)
	Y0 += 0.00000000163*np.cos(6.13290323794 + 2964.8466951296*t)
	Y0 += 0.00000000149*np.cos(5.64340451890 + 12406.1605508286*t)
	Y0 += 0.00000000168*np.cos(5.38234820743 + 27490.6924780448*t)
	Y0 += 0.00000000179*np.cos(5.09214529715 + 2714.9422343874*t)
	Y0 += 0.00000000179*np.cos(1.03162162149 + 3966.2826190122*t)
	Y0 += 0.00000000155*np.cos(4.37389063339 + 4686.95671800959*t)
	Y0 += 0.00000000140*np.cos(3.29233960935 + 18461.71521191579*t)
	Y0 += 0.00000000183*np.cos(5.08915245987 + 6791.431174619*t)
	Y0 += 0.00000000150*np.cos(3.63195159063 + 2922.1081038928*t)
	Y0 += 0.00000000140*np.cos(4.10887314023 + 408.4389436113*t)
	Y0 += 0.00000000146*np.cos(0.34180400613 + 2714.9872905026*t)
	Y0 += 0.00000000165*np.cos(5.85179950459 + 7345.9808985296*t)
	Y0 += 0.00000000191*np.cos(0.62441184949 + 3202.0242283154*t)
	Y0 += 0.00000000191*np.cos(5.49935506915 + 3479.2006250842*t)
	Y0 += 0.00000000191*np.cos(4.47590456732 + 75.7448064138*t)
	Y0 += 0.00000000160*np.cos(3.89847950064 + 3287.304480416*t)
	Y0 += 0.00000000160*np.cos(2.22528741800 + 3393.9203729836*t)
	Y0 += 0.00000000143*np.cos(4.66819102175 + 5298.337506553*t)
	Y0 += 0.00000000193*np.cos(4.93382263995 + 3031.334104044*t)
	Y0 += 0.00000000137*np.cos(1.10831878106 + 1538.240435978*t)
	Y0 += 0.00000000189*np.cos(0.82918253553 + 27832.0382192832*t)
	Y0 += 0.00000000161*np.cos(0.41487404103 + 3897.7049478912*t)
	Y0 += 0.00000000136*np.cos(4.94904122324 + 4665.5537672398*t)
	Y0 += 0.00000000149*np.cos(1.58541955295 + 533.8837507886*t)
	Y0 += 0.00000000146*np.cos(4.58946121962 + 29424.634232916*t)
	Y0 += 0.00000000144*np.cos(5.67407580544 + 3945.4621674046*t)
	Y0 += 0.00000000155*np.cos(4.11300986064 + 25135.8265183146*t)
	Y0 += 0.00000000170*np.cos(6.20206538140 + 6677.71898870279*t)
	Y0 += 0.00000000141*np.cos(2.26693908625 + 6279.5527316424*t)
	Y0 += 0.00000000136*np.cos(5.68923166061 + 4288.8077146014*t)
	Y0 += 0.00000000167*np.cos(3.71126958427 + 8336.7851575978*t)
	Y0 += 0.00000000151*np.cos(4.63496418774 + 8962.522660213*t)
	Y0 += 0.00000000158*np.cos(2.03821572977 + 208.633228992*t)
	Y0 += 0.00000000151*np.cos(4.79490046168 + 2281.2978068134*t)
	Y0 += 0.00000000159*np.cos(3.23471035128 + 8958.5231966471*t)
	Y0 += 0.00000000151*np.cos(5.20339684853 + 2281.1631862078*t)
	Y0 += 0.00000000137*np.cos(1.47758341153 + 6703.075682726*t)
	Y0 += 0.00000000151*np.cos(5.04346057458 + 8962.3880396074*t)
	Y0 += 0.00000000133*np.cos(5.72069663156 + 4295.8539512994*t)
	Y0 += 0.00000000159*np.cos(0.16407854844 + 8966.3875031733*t)
	Y0 += 0.00000000153*np.cos(3.42669369028 + 47.6942631934*t)
	Y0 += 0.00000000137*np.cos(0.73335617283 + 12729.665967486*t)
	Y0 += 0.00000000132*np.cos(4.69707830142 + 12171.5258149236*t)
	Y0 += 0.00000000136*np.cos(4.02213961750 + 8695.8483081884*t)
	Y0 += 0.00000000131*np.cos(6.22770537067 + 203.0041546995*t)
	Y0 += 0.00000000183*np.cos(0.59231255504 + 1021.2488945514*t)
	Y0 += 0.00000000139*np.cos(4.27354999851 + 373.9079928365*t)
	Y0 += 0.00000000132*np.cos(4.38025942738 + 10824.2012025456*t)
	Y0 += 0.00000000130*np.cos(2.78423915943 + 529.6737114424*t)
	Y0 += 0.00000000132*np.cos(5.86985041939 + 2472.6787626222*t)
	Y0 += 0.00000000133*np.cos(4.50452650479 + 6624.326478464*t)
	Y0 += 0.00000000148*np.cos(2.40612364993 + 7050.92466934*t)
	Y0 += 0.00000000130*np.cos(3.08795138602 + 7593.7950970652*t)
	Y0 += 0.00000000160*np.cos(3.35966837618 + 10081.211142013*t)
	Y0 += 0.00000000139*np.cos(4.04425486837 + 214.7835681463*t)
	Y0 += 0.00000000130*np.cos(4.81501079092 + 529.7082187468*t)
	Y0 += 0.00000000143*np.cos(3.29046013826 + 10014.7910434014*t)
	Y0 += 0.00000000158*np.cos(3.17182640229 + 6092.1600263914*t)
	Y0 += 0.00000000133*np.cos(6.23099356596 + 21150.8133658836*t)
	Y0 += 0.00000000148*np.cos(2.44769901406 + 1505.28780909299*t)
	Y0 += 0.00000000137*np.cos(1.98411709382 + 34554.8138636676*t)
	Y0 += 0.00000000134*np.cos(4.61132825315 + 2954.1927761276*t)
	Y0 += 0.00000000129*np.cos(3.37544159152 + 11527.1250891924*t)
	Y0 += 0.00000000145*np.cos(3.33531716268 + 8373.390522902*t)
	Y0 += 0.00000000172*np.cos(1.36733410756 + 1086.783486286*t)
	Y0 += 0.00000000141*np.cos(1.22591570561 + 3041.4860324306*t)
	Y0 += 0.00000000137*np.cos(4.29535110956 + 6137.3067943034*t)
	Y0 += 0.00000000166*np.cos(3.85823242782 + 107.6635239386*t)
	Y0 += 0.00000000127*np.cos(3.67470240475 + 10294.510237451*t)
	Y0 += 0.00000000137*np.cos(3.89019601730 + 14580.7751547716*t)
	Y0 += 0.00000000130*np.cos(0.80714408434 + 4108.4612460484*t)
	Y0 += 0.00000000141*np.cos(2.61333516815 + 5088.2198048527*t)
	Y0 += 0.00000000165*np.cos(3.99987517019 + 8006.1661939396*t)
	Y0 += 0.00000000124*np.cos(4.81729498841 + 10177.1903692308*t)
	Y0 += 0.00000000166*np.cos(1.38695682715 + 305.3461693927*t)
	Y0 += 0.00000000126*np.cos(0.28235988406 + 18447.48811791419*t)
	Y0 += 0.00000000141*np.cos(6.27649569910 + 3716.37815827*t)
	Y0 += 0.00000000124*np.cos(1.96413242139 + 6687.9085172737*t)
	Y0 += 0.00000000121*np.cos(4.72300940105 + 3090.7079659576*t)
	Y0 += 0.00000000121*np.cos(1.40075751759 + 3590.516887442*t)
	Y0 += 0.00000000130*np.cos(0.69748880175 + 654.1243803156*t)
	Y0 += 0.00000000141*np.cos(5.98008002738 + 5096.0841113789*t)
	Y0 += 0.00000000122*np.cos(5.79431680023 + 2257.3520587628*t)
	Y0 += 0.00000000123*np.cos(2.86133242277 + 6710.6543619356*t)
	Y0 += 0.00000000144*np.cos(6.26381421560 + 4.192785694*t)
	Y0 += 0.00000000166*np.cos(3.56556372747 + 6553.2060100622*t)
	Y0 += 0.00000000139*np.cos(5.93780077355 + 251.4321310758*t)
	Y0 += 0.00000000123*np.cos(2.97984792859 + 14591.4118201214*t)
	Y0 += 0.00000000128*np.cos(5.37813947668 + 3600.1732317236*t)
	Y0 += 0.00000000128*np.cos(0.74562744196 + 3081.051621676*t)
	Y0 += 0.00000000121*np.cos(3.73123340759 + 479.2883889155*t)
	Y0 += 0.00000000122*np.cos(4.85419345520 + 1236.075660323*t)
	Y0 += 0.00000000138*np.cos(4.02406657968 + 7167.1969061892*t)
	Y0 += 0.00000000119*np.cos(5.90821338773 + 114.1384744825*t)
	Y0 += 0.00000000127*np.cos(2.49182650403 + 3759.1167495068*t)
	Y0 += 0.00000000143*np.cos(5.81188741430 + 2228.9701815978*t)
	Y0 += 0.00000000152*np.cos(3.52185876402 + 3340.6469340042*t)
	Y0 += 0.00000000152*np.cos(5.74350080821 + 3340.5779193954*t)
	Y0 += 0.00000000140*np.cos(6.07921710613 + 2233.473621015*t)
	Y0 += 0.00000000118*np.cos(2.67439157216 + 7534.4212351516*t)
	Y0 += 0.00000000137*np.cos(3.22022096656 + 14587.8213914696*t)
	Y0 += 0.00000000124*np.cos(2.27970099563 + 9124.9219860424*t)
	Y0 += 0.00000000161*np.cos(3.75731973309 + 4576.6880870228*t)
	Y0 += 0.00000000116*np.cos(5.02262371793 + 10338.229149756*t)
	Y0 += 0.00000000126*np.cos(4.15150267519 + 4083.6024872324*t)
	Y0 += 0.00000000133*np.cos(0.20063412038 + 3923.6113380782*t)
	Y0 += 0.00000000139*np.cos(1.28995256706 + 4782.87363546*t)
	Y0 += 0.00000000122*np.cos(6.02851032493 + 6836.577942531*t)
	Y0 += 0.00000000121*np.cos(2.88286714942 + 4179.5817144502*t)
	Y0 += 0.00000000162*np.cos(5.96659239053 + 8852.2490286908*t)
	Y0 += 0.00000000153*np.cos(3.50724335550 + 49225.5801891408*t)
	Y0 += 0.00000000137*np.cos(1.59056057693 + 8219.4652893776*t)
	Y0 += 0.00000000115*np.cos(4.65379442884 + 539.9859058331*t)
	Y0 += 0.00000000134*np.cos(5.30662276999 + 6659.3740240732*t)
	Y0 += 0.00000000133*np.cos(0.75283219591 + 6147.6017350419*t)
	Y0 += 0.00000000113*np.cos(5.67984864041 + 4782.8908891122*t)
	Y0 += 0.00000000112*np.cos(1.64583106043 + 4106.4054911462*t)
	Y0 += 0.00000000116*np.cos(1.51226089331 + 3727.032077272*t)
	Y0 += 0.00000000115*np.cos(2.23873164969 + 27433.88921587499*t)
	Y0 += 0.00000000111*np.cos(3.49092955755 + 6837.625573902*t)
	Y0 += 0.00000000122*np.cos(4.66180533919 + 4953.5637597314*t)
	Y0 += 0.00000000110*np.cos(4.24429487321 + 2980.5016447382*t)
	Y0 += 0.00000000114*np.cos(3.22069040111 + 213.4109700226*t)
	Y0 += 0.00000000114*np.cos(4.81084790265 + 213.1872208534*t)
	Y0 += 0.00000000129*np.cos(6.17361043988 + 302.164775655*t)
	Y0 += 0.00000000140*np.cos(2.67829796301 + 2214.7430875962*t)
	Y0 += 0.00000000130*np.cos(5.53821276618 + 14267.906403464*t)
	Y0 += 0.00000000116*np.cos(3.61048176759 + 1593.0050485469*t)
	Y0 += 0.00000000114*np.cos(5.78198829675 + 3966.237562897*t)
	Y0 += 0.00000000129*np.cos(3.09576574234 + 3101.4069410748*t)
	Y0 += 0.00000000129*np.cos(3.02800117630 + 3579.8179123248*t)
	Y0 += 0.00000000133*np.cos(2.29548900012 + 6738.1232283352*t)
	Y0 += 0.00000000109*np.cos(3.91214172233 + 6953.8978107512*t)
	Y0 += 0.00000000114*np.cos(4.23798377032 + 13517.8027959306*t)
	Y0 += 0.00000000146*np.cos(4.39739079440 + 3398.4911227036*t)
	Y0 += 0.00000000146*np.cos(1.72637612424 + 3282.733730696*t)
	Y0 += 0.00000000142*np.cos(2.28691321864 + 1879.5583747534*t)
	Y0 += 0.00000000116*np.cos(5.36019004356 + 524.0618908021*t)
	Y0 += 0.00000000115*np.cos(3.13902228769 + 2501.6431389494*t)
	Y0 += 0.00000000130*np.cos(3.94430245099 + 6155.4660415681*t)
	Y0 += 0.00000000123*np.cos(4.36600516245 + 2185.2512692928*t)
	Y0 += 0.00000000112*np.cos(1.26819666087 + 27.4015560968*t)
	Y0 += 0.00000000116*np.cos(2.98356645564 + 8976.6824439118*t)
	Y0 += 0.00000000105*np.cos(3.84139235085 + 17821.81792560179*t)
	Y0 += 0.00000000115*np.cos(2.12419003336 + 535.3200393871*t)
	Y0 += 0.00000000144*np.cos(4.28618515178 + 8446.9914788172*t)
	Y0 += 0.00000000103*np.cos(5.03658750394 + 1059.3146198864*t)
	Y0 += 0.00000000126*np.cos(5.34406107671 + 540.7366653585*t)
	Y0 += 0.00000000107*np.cos(2.17771924213 + 7075.8507384588*t)
	Y0 += 0.00000000105*np.cos(3.92288350713 + 6961.011357752*t)
	Y0 += 0.00000000129*np.cos(2.19437663723 + 3719.98584057399*t)
	Y0 += 0.00000000129*np.cos(3.92939028141 + 2961.2390128256*t)
	Y0 += 0.00000000103*np.cos(4.84437874080 + 550.0462844934*t)
	Y0 += 0.00000000140*np.cos(4.00106611918 + 14867.73751589219*t)
	Y0 += 0.00000000121*np.cos(1.12112792863 + 27676.617819849*t)
	Y0 += 0.00000000136*np.cos(5.86999649219 + 765.7930644464*t)
	Y0 += 0.00000000119*np.cos(4.95824095217 + 983.1158589136*t)
	Y0 += 0.00000000115*np.cos(4.67040651182 + 2631.6226244232*t)
	Y0 += 0.00000000104*np.cos(4.68807983986 + 31449.8270427518*t)
	Y0 += 0.00000000115*np.cos(0.35603129387 + 98.8999885246*t)
	Y0 += 0.00000000127*np.cos(4.38747549084 + 2655.501062171*t)
	Y0 += 0.00000000101*np.cos(3.19137230221 + 21791.69097326579*t)
	Y0 += 0.00000000103*np.cos(6.01933155949 + 18617.0683010472*t)
	Y0 += 0.00000000118*np.cos(4.91950265277 + 525.0250986486*t)
	Y0 += 0.00000000138*np.cos(3.24007735232 + 3480.3105662226*t)
	Y0 += 0.00000000138*np.cos(2.88368956632 + 3200.914287177*t)
	Y0 += 0.00000000102*np.cos(1.89629804705 + 56.6223513026*t)
	Y0 += 0.00000000100*np.cos(2.14566059864 + 529.851023789*t)
	Y0 += 0.00000000100*np.cos(5.33661471676 + 529.5309064002*t)
	Y0 += 0.00000000099*np.cos(6.15309320274 + 4555.4147563232*t)
	Y0 += 0.00000000099*np.cos(0.29530316101 + 198.321241911*t)
	Y0 += 0.00000000102*np.cos(6.02433300674 + 963.4027029714*t)
	Y0 += 0.00000000106*np.cos(0.15103316185 + 32367.0976562076*t)
	Y0 += 0.00000000100*np.cos(0.79624016231 + 2651.977943822*t)
	Y0 += 0.00000000109*np.cos(2.17221801259 + 175.1660598002*t)
	Y0 += 0.00000000100*np.cos(5.44381740844 + 3340.6969906548*t)
	Y0 += 0.00000000100*np.cos(3.82154216379 + 3340.52786274481*t)
	Y0 += 0.00000000108*np.cos(4.12360777653 + 249.9044607422*t)
	Y0 += 0.00000000099*np.cos(5.78300785457 + 5312.5646005546*t)
	Y0 += 0.00000000115*np.cos(4.25203314320 + 21000.9158907568*t)
	Y0 += 0.00000000111*np.cos(6.01414242152 + 80.1982245387*t)
	Y0 += 0.00000000097*np.cos(1.57959120195 + 31214.2014369678*t)
	Y0 += 0.00000000103*np.cos(6.25904312579 + 1585.1407420207*t)
	Y0 += 0.00000000103*np.cos(5.89679813880 + 2125.8100970764*t)
	Y0 += 0.00000000096*np.cos(5.43048994495 + 213.0866471169*t)
	Y0 += 0.00000000096*np.cos(2.60104835880 + 213.5115437591*t)
	Y0 += 0.00000000095*np.cos(3.12474282092 + 3370.49447031*t)
	Y0 += 0.00000000095*np.cos(2.99902409772 + 3310.7303830896*t)
	Y0 += 0.00000000099*np.cos(4.90758830995 + 551.031606097*t)
	Y0 += 0.00000000100*np.cos(5.85231379528 + 3340.5623700492*t)
	Y0 += 0.00000000100*np.cos(3.41304577695 + 3340.6624833504*t)
	Y0 += 0.00000000130*np.cos(1.10368790224 + 26084.0218062162*t)
	Y0 += 0.00000000111*np.cos(2.56844286864 + 534.3568315406*t)
	Y0 += 0.00000000117*np.cos(0.19396627342 + 524.2743391232*t)
	Y0 += 0.00000000102*np.cos(2.99188532210 + 34115.1140692746*t)
	Y0 += 0.00000000098*np.cos(0.97971049082 + 1784.0442797444*t)
	Y0 += 0.00000000101*np.cos(0.76366487468 + 987.746272928*t)
	Y0 += 0.00000000129*np.cos(2.93910550678 + 4591.4426230006*t)
	Y0 += 0.00000000095*np.cos(3.70643398698 + 327.4375699205*t)
	Y0 += 0.00000000099*np.cos(0.66802090434 + 1755.4716846791*t)
	Y0 += 0.00000000124*np.cos(0.43401574548 + 3532.0779464636*t)
	Y0 += 0.00000000098*np.cos(5.40084312405 + 24768.6021893522*t)
	Y0 += 0.00000000104*np.cos(5.47404374073 + 32.1951448046*t)
	Y0 += 0.00000000104*np.cos(0.45494263259 + 25827.9841195414*t)
	Y0 += 0.00000000127*np.cos(3.26672162678 + 21.3406410024*t)
	Y0 += 0.00000000125*np.cos(1.84276822733 + 30227.9784764304*t)
	Y0 += 0.00000000115*np.cos(1.00365590687 + 535.107591066*t)
	Y0 += 0.00000000095*np.cos(3.71389775515 + 16975.7350908506*t)
	Y0 += 0.00000000118*np.cos(5.39174563560 + 3343.5813721164*t)
	Y0 += 0.00000000118*np.cos(0.73202128304 + 3337.6434812832*t)
	Y0 += 0.00000000095*np.cos(0.21486058971 + 11506.7697697936*t)
	Y0 += 0.00000000105*np.cos(3.93832329439 + 42388.934936307*t)
	Y0 += 0.00000000092*np.cos(1.91807045515 + 155.3530891314*t)
	Y0 += 0.00000000118*np.cos(5.04524690579 + 2523.9591004846*t)
	Y0 += 0.00000000124*np.cos(4.68642942116 + 3532.0434391592*t)
	Y0 += 0.00000000092*np.cos(1.46728426349 + 31172.650645983*t)
	Y0 += 0.00000000102*np.cos(3.49211510967 + 27946.7479799198*t)
	Y0 += 0.00000000103*np.cos(2.64209634100 + 20235.1228263104*t)
	Y0 += 0.00000000120*np.cos(4.14012588910 + 4845.9002357928*t)
	Y0 += 0.00000000091*np.cos(5.12604154487 + 14469.588512484*t)
	Y0 += 0.00000000118*np.cos(4.07684778770 + 3396.995612776*t)
	Y0 += 0.00000000118*np.cos(2.04691913094 + 3284.2292406236*t)
	Y0 += 0.00000000112*np.cos(1.33743249046 + 20995.3929664494*t)
	Y0 += 0.00000000096*np.cos(4.77567549605 + 35.685355083*t)
	Y0 += 0.00000000113*np.cos(3.43964396126 + 948.1952879016*t)
	Y0 += 0.00000000104*np.cos(4.79113313233 + 3149.1814142404*t)
	Y0 += 0.00000000100*np.cos(1.97504060165 + 20426.571092422*t)
	Y0 += 0.00000000121*np.cos(2.63871762078 + 30774.5016425748*t)
	Y0 += 0.00000000103*np.cos(2.84917048342 + 219.891377577*t)
	Y0 += 0.00000000111*np.cos(2.18997917347 + 2104.5367663768*t)
	Y0 += 0.00000000094*np.cos(3.66066776842 + 10610.9021071076*t)
	Y0 += 0.00000000112*np.cos(3.12304973052 + 24606.13555322*t)
	Y0 += 0.00000000093*np.cos(4.20565309570 + 99.1606209555*t)
	Y0 += 0.00000000094*np.cos(2.34382286871 + 3346.7456526324*t)
	Y0 += 0.00000000094*np.cos(3.77994404993 + 3334.4792007672*t)
	Y0 += 0.00000000090*np.cos(5.67779575724 + 15746.7729775284*t)
	Y0 += 0.00000000091*np.cos(1.14441655193 + 50818.1762027736*t)
	Y0 += 0.00000000091*np.cos(1.77732756353 + 24093.2767891752*t)
	Y0 += 0.00000000092*np.cos(1.72406156484 + 12892.1326036182*t)
	Y0 += 0.00000000092*np.cos(4.79118378192 + 1957.7250798532*t)
	Y0 += 0.00000000087*np.cos(1.28166497839 + 228.276948965*t)
	Y0 += 0.00000000111*np.cos(2.46277729789 + 27417.0570148252*t)
	Y0 += 0.00000000098*np.cos(0.78906971914 + 24532.9765835682*t)
	Y0 += 0.00000000089*np.cos(0.64518470975 + 3368.08129309939*t)
	Y0 += 0.00000000089*np.cos(5.47858220889 + 3313.1435603002*t)
	Y0 += 0.00000000103*np.cos(4.62809111709 + 1059.449240492*t)
	Y0 += 0.00000000092*np.cos(0.19061509302 + 32509.208972941*t)
	Y0 += 0.00000000086*np.cos(5.37692725135 + 11375.2278081072*t)
	Y0 += 0.00000000100*np.cos(1.82319423846 + 96.8729990951*t)
	Y0 += 0.00000000095*np.cos(0.84451353118 + 529.6236547918*t)
	Y0 += 0.00000000120*np.cos(6.10556233132 + 3202.0949298291*t)
	Y0 += 0.00000000120*np.cos(0.01820458732 + 3479.1299235705*t)
	Y0 += 0.00000000086*np.cos(5.35131508131 + 3762.6398678558*t)
	Y0 += 0.00000000086*np.cos(0.77245183733 + 2918.5849855438*t)
	Y0 += 0.00000000090*np.cos(1.59914115894 + 23546.7536230308*t)
	Y0 += 0.00000000099*np.cos(4.06854104969 + 3222.7996238078*t)
	Y0 += 0.00000000099*np.cos(2.05522586895 + 3458.4252295918*t)
	Y0 += 0.00000000089*np.cos(1.74434664412 + 22531.09060514659*t)
	Y0 += 0.00000000107*np.cos(2.43223672203 + 3369.5940566792*t)
	Y0 += 0.00000000107*np.cos(3.69153019661 + 3311.6307967204*t)
	Y0 += 0.00000000095*np.cos(1.39752616185 + 11560.0777160774*t)
	Y0 += 0.00000000095*np.cos(2.86255032254 + 8186.5126624926*t)
	Y0 += 0.00000000091*np.cos(4.99433536381 + 11876.469585734*t)
	Y0 += 0.00000000090*np.cos(3.38202540962 + 4670.1245169598*t)
	Y0 += 0.00000000106*np.cos(0.31966498575 + 44535.1003527822*t)
	Y0 += 0.00000000094*np.cos(1.95436076350 + 796.2807531642*t)
	Y0 += 0.00000000085*np.cos(5.95986051189 + 809.477469447*t)
	Y0 += 0.00000000085*np.cos(3.63689104790 + 74.8297826771*t)
	Y0 += 0.00000000089*np.cos(1.64580481078 + 6534.413166876*t)
	Y0 += 0.00000000085*np.cos(1.04303023325 + 74.7334144575*t)
	Y0 += 0.00000000084*np.cos(3.00387278181 + 4777.7880408984*t)
	Y0 += 0.00000000104*np.cos(2.76036150084 + 3149.146906936*t)
	Y0 += 0.00000000116*np.cos(5.49068681139 + 14694.50459434*t)
	Y0 += 0.00000000087*np.cos(6.08931791750 + 12410.7313005486*t)
	Y0 += 0.00000000113*np.cos(5.85548952542 + 177.8743727859*t)
	Y0 += 0.00000000089*np.cos(6.17341366104 + 3332.9386347244*t)
	Y0 += 0.00000000089*np.cos(6.23353856478 + 3348.2862186752*t)
	Y0 += 0.00000000087*np.cos(0.07344243508 + 13105.4316990562*t)
	Y0 += 0.00000000083*np.cos(3.79093953875 + 1107.1388056848*t)
	Y0 += 0.00000000115*np.cos(3.71714517813 + 1971.9521738548*t)
	Y0 += 0.00000000084*np.cos(0.92785811250 + 2942.5307335944*t)
	Y0 += 0.00000000082*np.cos(5.47710092100 + 3330.0430716528*t)
	Y0 += 0.00000000082*np.cos(0.64666599764 + 3351.1817817468*t)
	Y0 += 0.00000000112*np.cos(1.67391351043 + 14900.6901427772*t)
	Y0 += 0.00000000082*np.cos(0.58327444061 + 22317.79150970859*t)
	Y0 += 0.00000000085*np.cos(5.99437376237 + 191.9584544356*t)
	Y0 += 0.00000000087*np.cos(5.84639583938 + 40.5807161926*t)
	Y0 += 0.00000000084*np.cos(2.91538822338 + 3083.5944189568*t)
	Y0 += 0.00000000084*np.cos(3.20837869526 + 3597.6304344428*t)
	Y0 += 0.00000000095*np.cos(0.43601714434 + 529.7582753974*t)
	Y0 += 0.00000000085*np.cos(4.86833452232 + 1055.8588118402*t)
	Y0 += 0.00000000114*np.cos(1.28659258054 + 3063.5774329584*t)
	Y0 += 0.00000000114*np.cos(4.83717433810 + 3617.6474204412*t)
	Y0 += 0.00000000085*np.cos(2.68073374708 + 54789.936689978*t)
	Y0 += 0.00000000086*np.cos(3.41488083723 + 23009.94911093539*t)
	Y0 += 0.00000000102*np.cos(4.67254721576 + 131.4039498699*t)
	Y0 += 0.00000000112*np.cos(3.74867220051 + 5295.3295770634*t)
	Y0 += 0.00000000083*np.cos(2.23224723099 + 20103.0484221124*t)
	Y0 += 0.00000000093*np.cos(5.77977069690 + 74.5209661364*t)
	Y0 += 0.00000000081*np.cos(2.93799035242 + 1552.4675299796*t)
	Y0 += 0.00000000081*np.cos(5.44968688605 + 3190.714951573*t)
	Y0 += 0.00000000081*np.cos(0.67408003259 + 3490.5099018266*t)
	Y0 += 0.00000000094*np.cos(3.98513239500 + 796.3152604686*t)
	Y0 += 0.00000000096*np.cos(1.55756600347 + 4049.6022289764*t)
	Y0 += 0.00000000093*np.cos(5.18093640996 + 75.0422309982*t)
	Y0 += 0.00000000080*np.cos(2.87647086515 + 278.5194664497*t)
	Y0 += 0.00000000089*np.cos(1.46011729281 + 191.2076949102*t)
	Y0 += 0.00000000097*np.cos(5.98857826070 + 45494.58142974879*t)
	Y0 += 0.00000000106*np.cos(2.45927282558 + 10191.4174632324*t)
	Y0 += 0.00000000079*np.cos(2.74811848231 + 38.0211610532*t)
	Y0 += 0.00000000086*np.cos(4.76571809299 + 2544.2971662312*t)
	Y0 += 0.00000000089*np.cos(4.15046971529 + 6311.5250374592*t)
	Y0 += 0.00000000079*np.cos(1.59253269036 + 38.2449102224*t)
	Y0 += 0.00000000099*np.cos(1.41761453417 + 19683.5637782372*t)
	Y0 += 0.00000000085*np.cos(4.83661771107 + 14715.840234807*t)
	Y0 += 0.00000000079*np.cos(5.53486573340 + 31979.5180078464*t)
	Y0 += 0.00000000102*np.cos(1.61863937790 + 3524.48201360179*t)
	Y0 += 0.00000000102*np.cos(4.50512754074 + 3156.7428397978*t)
	Y0 += 0.00000000084*np.cos(1.33635449934 + 2942.3961129888*t)
	Y0 += 0.00000000084*np.cos(2.73273226011 + 4801.6664786462*t)
	return Y0




def Mars_Y1 (t): # 993 terms of order 1

	Y1 = 0.
	Y1 -= 0.01427318093
	Y1 += 0.00551063576*np.cos(3.52128320402 + 6681.2248533996*t)
	Y1 += 0.00077091888*np.cos(3.86082685753 + 10021.8372800994*t)
	Y1 += 0.00037310479*np.cos(1.16016958445 + 3340.6124266998*t)
	Y1 += 0.00009582122*np.cos(4.19942354479 + 13362.4497067992*t)
	Y1 += 0.00002617695*np.cos(1.47284555520 + 3337.0893083508*t)
	Y1 += 0.00002611572*np.cos(4.65030772498 + 3344.1355450488*t)
	Y1 += 0.00001505462*np.cos(1.71640125299 + 1059.3819301892*t)
	Y1 += 0.00001162955*np.cos(4.53778503576 + 16703.062133499*t)
	Y1 += 0.00000824978*np.cos(5.87391611892 + 426.598190876*t)
	Y1 += 0.00000779959*np.cos(1.12906192582 + 206.1855484372*t)
	Y1 += 0.00000753085*np.cos(0.61961478496 + 220.4126424388*t)
	Y1 += 0.00000562043*np.cos(4.00005312764 + 522.5774180938*t)
	Y1 += 0.00000549334*np.cos(3.48662006999 + 536.8045120954*t)
	Y1 += 0.00000431990*np.cos(1.20122419783 + 2942.4634232916*t)
	Y1 += 0.00000389982*np.cos(4.38779713561 + 5621.8429232104*t)
	Y1 += 0.00000380122*np.cos(4.93073729444 + 3738.761430108*t)
	Y1 += 0.00000394355*np.cos(4.91119397796 + 6684.7479717486*t)
	Y1 += 0.00000336661*np.cos(3.63990879619 + 3149.1641605882*t)
	Y1 += 0.00000333604*np.cos(0.88647104051 + 3185.1920272656*t)
	Y1 += 0.00000318324*np.cos(2.48122345477 + 3532.0606928114*t)
	Y1 += 0.00000316743*np.cos(5.23316524269 + 3496.032826134*t)
	Y1 += 0.00000311468*np.cos(2.66149474204 + 2544.3144198834*t)
	Y1 += 0.00000283006*np.cos(3.01270555394 + 796.2980068164*t)
	Y1 += 0.00000259715*np.cos(3.45285007540 + 4136.9104335162*t)
	Y1 += 0.00000204277*np.cos(1.62196956205 + 1194.4470102246*t)
	Y1 += 0.00000203146*np.cos(2.00978303868 + 1589.0728952838*t)
	Y1 += 0.00000140506*np.cos(4.87611060370 + 20043.6745601988*t)
	Y1 += 0.00000133054*np.cos(3.06497749499 + 5884.9268465832*t)
	Y1 += 0.00000132221*np.cos(2.12903733409 + 4399.994356889*t)
	Y1 += 0.00000126748*np.cos(1.25031299906 + 6677.7017350506*t)
	Y1 += 0.00000103023*np.cos(4.48653117588 + 5486.777843175*t)
	Y1 += 0.00000128526*np.cos(0.22328095820 + 1592.5960136328*t)
	Y1 += 0.00000101352*np.cos(3.97061208738 + 3339.6321056316*t)
	Y1 += 0.00000101253*np.cos(2.15203295056 + 3341.592747768*t)
	Y1 += 0.00000090029*np.cos(4.30631925657 + 3870.3033917944*t)
	Y1 += 0.00000083977*np.cos(5.10438299040 + 1990.745017041*t)
	Y1 += 0.00000078865*np.cos(3.69323302292 + 2146.1654164752*t)
	Y1 += 0.00000077132*np.cos(5.35293989072 + 7079.3738568078*t)
	Y1 += 0.00000081297*np.cos(4.10751911033 + 5092.1519581158*t)
	Y1 += 0.00000085141*np.cos(0.11489010013 + 419.4846438752*t)
	Y1 += 0.00000063835*np.cos(3.70028305724 + 2388.8940204492*t)
	Y1 += 0.00000057287*np.cos(5.21462580599 + 10025.3603984484*t)
	Y1 += 0.00000056119*np.cos(0.33784373101 + 3097.88382272579*t)
	Y1 += 0.00000069177*np.cos(5.81634207831 + 5088.6288397668*t)
	Y1 += 0.00000075448*np.cos(2.03864215811 + 4535.0594369244*t)
	Y1 += 0.00000055487*np.cos(5.92856755611 + 9492.1463150048*t)
	Y1 += 0.00000052915*np.cos(5.76012128769 + 3583.3410306738*t)
	Y1 += 0.00000070493*np.cos(2.29434635167 + 2787.0430238574*t)
	Y1 += 0.00000057687*np.cos(5.46627318905 + 639.897286314*t)
	Y1 += 0.00000050121*np.cos(0.89975887576 + 4690.4798363586*t)
	Y1 += 0.00000050653*np.cos(6.11457948121 + 433.7117378768*t)
	Y1 += 0.00000054006*np.cos(1.17848219667 + 2957.7158944766*t)
	Y1 += 0.00000049131*np.cos(6.22165192434 + 191.4482661116*t)
	Y1 += 0.00000049195*np.cos(0.93502149184 + 6681.2075997474*t)
	Y1 += 0.00000046173*np.cos(1.93548588356 + 7.1135470008*t)
	Y1 += 0.00000057046*np.cos(3.78172576129 + 3894.1818295422*t)
	Y1 += 0.00000043884*np.cos(2.32328576357 + 4292.3308329504*t)
	Y1 += 0.00000049195*np.cos(2.96579325551 + 6681.2421070518*t)
	Y1 += 0.00000046747*np.cos(4.90372286627 + 3723.508958923*t)
	Y1 += 0.00000053525*np.cos(2.72772193635 + 155.4203994342*t)
	Y1 += 0.00000050928*np.cos(4.24418873708 + 1066.49547719*t)
	Y1 += 0.00000047371*np.cos(4.07058844113 + 6489.776587288*t)
	Y1 += 0.00000037259*np.cos(4.77560729076 + 3553.9115221378*t)
	Y1 += 0.00000049446*np.cos(5.26552893882 + 529.6909650946*t)
	Y1 += 0.00000036147*np.cos(1.35491513022 + 3127.3133312618*t)
	Y1 += 0.00000041915*np.cos(2.20116878635 + 213.299095438*t)
	Y1 += 0.00000035282*np.cos(1.23254843453 + 6525.8044539654*t)
	Y1 += 0.00000033179*np.cos(3.51707222671 + 3333.498879699*t)
	Y1 += 0.00000034809*np.cos(4.18192362595 + 1748.016413067*t)
	Y1 += 0.00000039091*np.cos(3.80640955175 + 7477.522860216*t)
	Y1 += 0.00000030807*np.cos(3.84122209973 + 1052.2683831884*t)
	Y1 += 0.00000029410*np.cos(3.77101802200 + 6254.6266625236*t)
	Y1 += 0.00000029901*np.cos(1.19787611097 + 149.5631971346*t)
	Y1 += 0.00000030407*np.cos(5.07104519098 + 1349.8674096588*t)
	Y1 += 0.00000027239*np.cos(1.35659219412 + 553.5694028424*t)
	Y1 += 0.00000027517*np.cos(2.17565128432 + 12303.06777661*t)
	Y1 += 0.00000027442*np.cos(0.62028270680 + 4933.2084403326*t)
	Y1 += 0.00000028052*np.cos(2.66985509990 + 3347.7259737006*t)
	Y1 += 0.00000025853*np.cos(1.75047537209 + 2810.9214616052*t)
	Y1 += 0.00000027323*np.cos(0.02095781900 + 951.7184062506*t)
	Y1 += 0.00000021401*np.cos(5.29701461619 + 316.3918696566*t)
	Y1 += 0.00000027621*np.cos(2.30197583456 + 2118.7638603784*t)
	Y1 += 0.00000021261*np.cos(2.27370365360 + 4929.6853219836*t)
	Y1 += 0.00000023424*np.cos(2.34960187821 + 382.8965322232*t)
	Y1 += 0.00000019019*np.cos(0.48946385175 + 227.5261894396*t)
	Y1 += 0.00000018679*np.cos(5.30877056453 + 242.728603974*t)
	Y1 += 0.00000018299*np.cos(5.31873037196 + 9623.6882766912*t)
	Y1 += 0.00000017050*np.cos(0.73617668321 + 3320.257107301*t)
	Y1 += 0.00000016932*np.cos(5.38596885509 + 3360.96774609859*t)
	Y1 += 0.00000016989*np.cos(5.21435353899 + 23384.2869868986*t)
	Y1 += 0.00000016202*np.cos(5.29675788446 + 6681.1575430968*t)
	Y1 += 0.00000017035*np.cos(1.13076170583 + 6674.1113063988*t)
	Y1 += 0.00000014564*np.cos(0.35017458981 + 10018.3141617504*t)
	Y1 += 0.00000016726*np.cos(5.37963018761 + 7210.9158184942*t)
	Y1 += 0.00000017704*np.cos(2.46673313442 + 7740.6067835888*t)
	Y1 += 0.00000016030*np.cos(2.67705196127 + 3325.3599555148*t)
	Y1 += 0.00000015941*np.cos(3.44411402721 + 3355.8648978848*t)
	Y1 += 0.00000015088*np.cos(2.42313044286 + 110.2063212194*t)
	Y1 += 0.00000016202*np.cos(4.88823057997 + 6681.2921637024*t)
	Y1 += 0.00000013784*np.cos(6.26149521160 + 12832.7587417046*t)
	Y1 += 0.00000017390*np.cos(4.27687578959 + 76.2660712756*t)
	Y1 += 0.00000012927*np.cos(4.16022928360 + 2281.2304965106*t)
	Y1 += 0.00000016504*np.cos(3.81227944624 + 4562.4609930212*t)
	Y1 += 0.00000014766*np.cos(2.06347095335 + 2274.1169495098*t)
	Y1 += 0.00000012471*np.cos(2.52252246459 + 6682.2051744678*t)
	Y1 += 0.00000012672*np.cos(5.48550960002 + 5331.3574437408*t)
	Y1 += 0.00000012581*np.cos(1.49409639076 + 632.7837393132*t)
	Y1 += 0.00000012413*np.cos(4.14057132118 + 515.463871093*t)
	Y1 += 0.00000013354*np.cos(1.61202229522 + 2288.3440435114*t)
	Y1 += 0.00000013054*np.cos(2.91942689347 + 3767.2106175758*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000010891*np.cos(0.68185023633 + 6438.4962494256*t)
	Y1 += 0.00000010294*np.cos(2.38590207291 + 7875.6718636242*t)
	Y1 += 0.00000009941*np.cos(5.46223635331 + 398.1490034082*t)
	Y1 += 0.00000010388*np.cos(1.43082762360 + 5614.7293762096*t)
	Y1 += 0.00000012500*np.cos(5.71657132706 + 10419.9862835076*t)
	Y1 += 0.00000010164*np.cos(0.62992310390 + 73.297125859*t)
	Y1 += 0.00000010337*np.cos(3.30570903459 + 10021.8545337516*t)
	Y1 += 0.00000009227*np.cos(5.18749993680 + 6836.6452528338*t)
	Y1 += 0.00000008846*np.cos(6.25668148581 + 3205.5473466644*t)
	Y1 += 0.00000009222*np.cos(1.25927718333 + 199.0720014364*t)
	Y1 += 0.00000011308*np.cos(5.02952138409 + 6041.3275670856*t)
	Y1 += 0.00000008356*np.cos(6.14980327580 + 3475.6775067352*t)
	Y1 += 0.00000008663*np.cos(3.35360012494 + 543.9180590962*t)
	Y1 += 0.00000010337*np.cos(1.27493070103 + 10021.8200264472*t)
	Y1 += 0.00000007914*np.cos(1.11325660670 + 103.0927742186*t)
	Y1 += 0.00000007741*np.cos(5.02756320298 + 1751.539531416*t)
	Y1 += 0.00000007737*np.cos(5.74646451299 + 2700.7151403858*t)
	Y1 += 0.00000008096*np.cos(5.53364318065 + 13365.9728251482*t)
	Y1 += 0.00000007402*np.cos(2.50809887388 + 15643.6802033098*t)
	Y1 += 0.00000007789*np.cos(2.64751868576 + 6127.6554505572*t)
	Y1 += 0.00000007147*np.cos(1.44609341809 + 949.1756089698*t)
	Y1 += 0.00000007616*np.cos(3.55216836649 + 6151.533888305*t)
	Y1 += 0.00000006888*np.cos(0.93821376086 + 5628.9564702112*t)
	Y1 += 0.00000006665*np.cos(3.04085693375 + 3178.1457905676*t)
	Y1 += 0.00000006770*np.cos(4.59405247148 + 1596.1864422846*t)
	Y1 += 0.00000006214*np.cos(1.52971949909 + 6298.3283211764*t)
	Y1 += 0.00000006611*np.cos(5.46296206225 + 853.196381752*t)
	Y1 += 0.00000006257*np.cos(3.08467357092 + 3503.079062832*t)
	Y1 += 0.00000006358*np.cos(4.02054439730 + 3316.733988952*t)
	Y1 += 0.00000007832*np.cos(4.06330977332 + 5729.506447149*t)
	Y1 += 0.00000006311*np.cos(2.10530552076 + 3364.4908644476*t)
	Y1 += 0.00000006743*np.cos(4.45650314997 + 9830.3890139878*t)
	Y1 += 0.00000007061*np.cos(3.40544179657 + 8962.4553499102*t)
	Y1 += 0.00000007288*np.cos(5.34922729060 + 6894.5239488376*t)
	Y1 += 0.00000005170*np.cos(0.37516758388 + 209.3669421749*t)
	Y1 += 0.00000005569*np.cos(4.14856676480 + 10818.1352869158*t)
	Y1 += 0.00000005081*np.cos(1.39059455730 + 217.2312487011*t)
	Y1 += 0.00000005485*np.cos(2.65233655309 + 2648.454825473*t)
	Y1 += 0.00000005114*np.cos(5.13541858012 + 8031.0922630584*t)
	Y1 += 0.00000005536*np.cos(2.55163508803 + 1758.6530784168*t)
	Y1 += 0.00000004856*np.cos(4.10977779468 + 1581.959348283*t)
	Y1 += 0.00000006551*np.cos(4.25238620522 + 6680.2445323314*t)
	Y1 += 0.00000004660*np.cos(0.15626149972 + 216.4804891757*t)
	Y1 += 0.00000004553*np.cos(1.60431626596 + 210.1177017003*t)
	Y1 += 0.00000005494*np.cos(6.10090252680 + 6923.9534573736*t)
	Y1 += 0.00000004643*np.cos(1.64332559992 + 7234.794256242*t)
	Y1 += 0.00000004842*np.cos(5.16943706039 + 6158.6474353058*t)
	Y1 += 0.00000004482*np.cos(5.41101616920 + 323.5054166574*t)
	Y1 += 0.00000004542*np.cos(2.44702860525 + 7064.1213856228*t)
	Y1 += 0.00000004336*np.cos(5.65658515228 + 12964.300703391*t)
	Y1 += 0.00000004779*np.cos(5.76036610082 + 6144.4203413042*t)
	Y1 += 0.00000005227*np.cos(1.73074923787 + 14.2270940016*t)
	Y1 += 0.00000004151*np.cos(1.93098926861 + 63.7358983034*t)
	Y1 += 0.00000004652*np.cos(2.63332997018 + 2914.0142358238*t)
	Y1 += 0.00000004580*np.cos(1.41608119487 + 5085.038411115*t)
	Y1 += 0.00000003970*np.cos(5.05439636873 + 3312.163239232*t)
	Y1 += 0.00000005474*np.cos(0.24241650562 + 7632.9432596502*t)
	Y1 += 0.00000004214*np.cos(3.49717782339 + 4032.7700279266*t)
	Y1 += 0.00000003894*np.cos(1.06212840662 + 3369.0616141676*t)
	Y1 += 0.00000003817*np.cos(3.90998982450 + 640.8776073822*t)
	Y1 += 0.00000004144*np.cos(2.71826934826 + 735.8765135318*t)
	Y1 += 0.00000003721*np.cos(3.02454190848 + 3346.1353510072*t)
	Y1 += 0.00000003720*np.cos(3.09809824482 + 3335.0895023924*t)
	Y1 += 0.00000004799*np.cos(3.06592497293 + 6688.3384004004*t)
	Y1 += 0.00000004128*np.cos(1.57312639696 + 9866.4168806652*t)
	Y1 += 0.00000003556*np.cos(0.96329089902 + 8273.8208670324*t)
	Y1 += 0.00000003629*np.cos(5.96999972361 + 3304.5845600224*t)
	Y1 += 0.00000003577*np.cos(0.15378568235 + 3376.6402933772*t)
	Y1 += 0.00000004442*np.cos(2.50701068861 + 11773.3768115154*t)
	Y1 += 0.00000003832*np.cos(1.42518467938 + 8969.568896911*t)
	Y1 += 0.00000003410*np.cos(5.22584770856 + 10021.9045904022*t)
	Y1 += 0.00000003443*np.cos(2.77873462243 + 85.8272988312*t)
	Y1 += 0.00000004071*np.cos(1.88545339582 + 3863.1898447936*t)
	Y1 += 0.00000003884*np.cos(1.89998927465 + 8955.3418029094*t)
	Y1 += 0.00000004357*np.cos(4.12849233981 + 2818.035008606*t)
	Y1 += 0.00000003302*np.cos(0.78944659795 + 11.0457002639*t)
	Y1 += 0.00000003574*np.cos(2.44194831685 + 1744.4259844152*t)
	Y1 += 0.00000003246*np.cos(4.47251198694 + 526.5095713569*t)
	Y1 += 0.00000003180*np.cos(3.00772018402 + 532.8723588323*t)
	Y1 += 0.00000003156*np.cos(1.61783457949 + 3980.5097130138*t)
	Y1 += 0.00000003130*np.cos(3.88131318196 + 3344.4937620578*t)
	Y1 += 0.00000003117*np.cos(2.24732563525 + 3336.7310913418*t)
	Y1 += 0.00000003400*np.cos(5.63288877479 + 10021.7699697966*t)
	Y1 += 0.00000003594*np.cos(5.57561267387 + 647.0108333148*t)
	Y1 += 0.00000003128*np.cos(3.75424825002 + 8432.7643848156*t)
	Y1 += 0.00000003010*np.cos(5.98032518225 + 10551.528245194*t)
	Y1 += 0.00000003084*np.cos(0.21639027416 + 13358.9265884502*t)
	Y1 += 0.00000002934*np.cos(0.51109476282 + 2487.4160449478*t)
	Y1 += 0.00000002903*np.cos(3.22514351914 + 525.7588118315*t)
	Y1 += 0.00000002896*np.cos(1.12069020939 + 117.3198682202*t)
	Y1 += 0.00000002863*np.cos(4.25448918131 + 533.6231183577*t)
	Y1 += 0.00000002876*np.cos(2.58450457222 + 8270.2977486834*t)
	Y1 += 0.00000002838*np.cos(0.45959307618 + 202.2533951741*t)
	Y1 += 0.00000003502*np.cos(1.28355216461 + 5099.2655051166*t)
	Y1 += 0.00000002761*np.cos(0.30940368701 + 956.2891559706*t)
	Y1 += 0.00000003129*np.cos(2.49440075955 + 5459.3762870782*t)
	Y1 += 0.00000003208*np.cos(1.56658459531 + 2699.7348193176*t)
	Y1 += 0.00000002528*np.cos(4.21676297033 + 3333.5661900018*t)
	Y1 += 0.00000002863*np.cos(2.16989496338 + 95.9792272178*t)
	Y1 += 0.00000003353*np.cos(2.01774997575 + 9225.539273283*t)
	Y1 += 0.00000002447*np.cos(4.92763323216 + 2766.267628365*t)
	Y1 += 0.00000002993*np.cos(4.34648489293 + 3981.490034082*t)
	Y1 += 0.00000002323*np.cos(5.60449935667 + 9381.9399937854*t)
	Y1 += 0.00000002315*np.cos(3.69144185016 + 8429.2412664666*t)
	Y1 += 0.00000002297*np.cos(1.21245935813 + 1692.1656695024*t)
	Y1 += 0.00000002186*np.cos(5.03043655370 + 4407.1079038898*t)
	Y1 += 0.00000002333*np.cos(3.51432934451 + 8827.3902698748*t)
	Y1 += 0.00000002510*np.cos(0.31296140818 + 16173.3711684044*t)
	Y1 += 0.00000002391*np.cos(5.51442084031 + 9808.5381846614*t)
	Y1 += 0.00000002153*np.cos(6.04353805522 + 1221.8485663214*t)
	Y1 += 0.00000002428*np.cos(2.80037448528 + 11081.2192102886*t)
	Y1 += 0.00000002711*np.cos(5.83797793809 + 5828.0284716476*t)
	Y1 += 0.00000002044*np.cos(3.86812530423 + 138.5174968707*t)
	Y1 += 0.00000002751*np.cos(2.14536436215 + 6467.9257579616*t)
	Y1 += 0.00000002016*np.cos(2.19445612298 + 742.9900605326*t)
	Y1 += 0.00000002111*np.cos(2.06365035238 + 15113.9892382152*t)
	Y1 += 0.00000002486*np.cos(0.24395631995 + 6283.0758499914*t)
	Y1 += 0.00000002114*np.cos(1.63888168497 + 3347.6586633978*t)
	Y1 += 0.00000001862*np.cos(6.06481817113 + 13760.5987102074*t)
	Y1 += 0.00000001717*np.cos(3.64496480459 + 13362.4669604514*t)
	Y1 += 0.00000001744*np.cos(0.22355971935 + 6816.289933435*t)
	Y1 += 0.00000001781*np.cos(0.87193778743 + 6660.4494579072*t)
	Y1 += 0.00000001699*np.cos(1.87566644469 + 70.8494453042*t)
	Y1 += 0.00000001717*np.cos(1.61419317923 + 13362.432453147*t)
	Y1 += 0.00000001771*np.cos(0.59857555923 + 10973.55568635*t)
	Y1 += 0.00000001856*np.cos(1.06629718188 + 3914.9572250346*t)
	Y1 += 0.00000001668*np.cos(0.60430699219 + 3340.629680352*t)
	Y1 += 0.00000001738*np.cos(2.07820814390 + 3281.2385647862*t)
	Y1 += 0.00000001612*np.cos(5.64202929021 + 3.523118349*t)
	Y1 += 0.00000002059*np.cos(5.55274042469 + 26724.8994135984*t)
	Y1 += 0.00000002154*np.cos(0.15347526650 + 6872.6731195112*t)
	Y1 += 0.00000001831*np.cos(4.08960877991 + 6247.5131155228*t)
	Y1 += 0.00000001698*np.cos(4.04559929798 + 3399.9862886134*t)
	Y1 += 0.00000001570*np.cos(2.80724611689 + 78.7137518304*t)
	Y1 += 0.00000001668*np.cos(4.85673659823 + 3340.5951730476*t)
	Y1 += 0.00000001950*np.cos(2.18129131439 + 224.3447957019*t)
	Y1 += 0.00000001533*np.cos(1.46147125549 + 3877.4169387952*t)
	Y1 += 0.00000001638*np.cos(1.96384800147 + 6040.3472460174*t)
	Y1 += 0.00000001500*np.cos(4.88545461881 + 574.3447983348*t)
	Y1 += 0.00000001628*np.cos(2.88073838002 + 10022.8176011676*t)
	Y1 += 0.00000001493*np.cos(5.97213767442 + 440.8252848776*t)
	Y1 += 0.00000001807*np.cos(3.79979610143 + 6696.4773245846*t)
	Y1 += 0.00000001592*np.cos(4.82870996320 + 2921.1277828246*t)
	Y1 += 0.00000001767*np.cos(1.07911448965 + 6660.8695340008*t)
	Y1 += 0.00000001540*np.cos(2.31576232583 + 8439.8779318164*t)
	Y1 += 0.00000001378*np.cos(2.72606150117 + 11216.284290324*t)
	Y1 += 0.00000001685*np.cos(3.32579486669 + 7107.8230442756*t)
	Y1 += 0.00000001849*np.cos(2.11621487275 + 10575.4066829418*t)
	Y1 += 0.00000001559*np.cos(2.97028792257 + 1045.1548361876*t)
	Y1 += 0.00000001360*np.cos(0.70553844479 + 3074.005384978*t)
	Y1 += 0.00000001302*np.cos(2.98694021349 + 6665.9723822146*t)
	Y1 += 0.00000001305*np.cos(5.68793695675 + 6701.5801727984*t)
	Y1 += 0.00000001584*np.cos(5.82704739199 + 8671.9698704406*t)
	Y1 += 0.00000001379*np.cos(1.15800118386 + 74.7815985673*t)
	Y1 += 0.00000001529*np.cos(5.28219831652 + 3546.797975137*t)
	Y1 += 0.00000001498*np.cos(1.47147884583 + 10014.7237330986*t)
	Y1 += 0.00000001231*np.cos(2.92458380429 + 1228.9621133222*t)
	Y1 += 0.00000001494*np.cos(0.80790809310 + 3134.4268782626*t)
	Y1 += 0.00000001411*np.cos(2.84106148241 + 18984.2926300096*t)
	Y1 += 0.00000001219*np.cos(5.41837474083 + 3607.2194684216*t)
	Y1 += 0.00000001195*np.cos(5.80939850807 + 3361.3878221922*t)
	Y1 += 0.00000001159*np.cos(5.00834942258 + 11371.7046897582*t)
	Y1 += 0.00000001161*np.cos(0.30017004686 + 3319.8370312074*t)
	Y1 += 0.00000001108*np.cos(1.71153266675 + 12935.8515159232*t)
	Y1 += 0.00000001503*np.cos(3.03363878314 + 6702.000248892*t)
	Y1 += 0.00000001157*np.cos(5.78852492425 + 10235.1363755374*t)
	Y1 += 0.00000001089*np.cos(0.71433907378 + 3169.9395560806*t)
	Y1 += 0.00000001068*np.cos(2.16721753485 + 6684.8152820514*t)
	Y1 += 0.00000001093*np.cos(0.92444199357 + 6531.661656265*t)
	Y1 += 0.00000001373*np.cos(2.53168716711 + 1039.0266107904*t)
	Y1 += 0.00000001037*np.cos(1.46452965647 + 4555.3474460204*t)
	Y1 += 0.00000001104*np.cos(1.77456576036 + 4569.574540022*t)
	Y1 += 0.00000001029*np.cos(3.75910353418 + 6261.7402095244*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001057*np.cos(0.79522639484 + 309.2783226558*t)
	Y1 += 0.00000001002*np.cos(0.43098035565 + 9779.1086761254*t)
	Y1 += 0.00000001112*np.cos(2.89652371372 + 625.6701923124*t)
	Y1 += 0.00000001020*np.cos(5.40929385267 + 3511.285297319*t)
	Y1 += 0.00000001063*np.cos(1.72982874710 + 6677.6344247478*t)
	Y1 += 0.00000001026*np.cos(4.06155146814 + 1265.5674786264*t)
	Y1 += 0.00000001245*np.cos(4.07589616535 + 10177.2576795336*t)
	Y1 += 0.00000000950*np.cos(4.82806218316 + 2125.8774073792*t)
	Y1 += 0.00000000993*np.cos(2.20093983157 + 8425.6508378148*t)
	Y1 += 0.00000000938*np.cos(4.81919246949 + 4989.0591838972*t)
	Y1 += 0.00000000922*np.cos(2.99264828336 + 9468.267877257*t)
	Y1 += 0.00000000918*np.cos(4.81951639068 + 13171.0014406876*t)
	Y1 += 0.00000000889*np.cos(4.77878515126 + 3561.0250691386*t)
	Y1 += 0.00000000887*np.cos(0.78830636358 + 3760.097070575*t)
	Y1 += 0.00000000998*np.cos(3.90126093816 + 11769.8536931664*t)
	Y1 += 0.00000000989*np.cos(6.14826697847 + 412.3710968744*t)
	Y1 += 0.00000001056*np.cos(4.56585915944 + 2906.900688823*t)
	Y1 += 0.00000000928*np.cos(4.41590375701 + 9070.1188738488*t)
	Y1 += 0.00000000880*np.cos(0.90436253322 + 3313.210870603*t)
	Y1 += 0.00000001010*np.cos(5.75999052682 + 3253.30422216*t)
	Y1 += 0.00000000870*np.cos(5.21940713846 + 3368.0139827966*t)
	Y1 += 0.00000000967*np.cos(2.95682389977 + 9595.2390892234*t)
	Y1 += 0.00000000825*np.cos(4.16526325583 + 1861.7458526354*t)
	Y1 += 0.00000000819*np.cos(1.28139939096 + 3120.199784261*t)
	Y1 += 0.00000000812*np.cos(0.30945449993 + 9168.6408983474*t)
	Y1 += 0.00000001074*np.cos(1.68311000340 + 1162.4747044078*t)
	Y1 += 0.00000000974*np.cos(0.36385416352 + 3427.9206312396*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000001092*np.cos(4.03195323532 + 2803.8079146044*t)
	Y1 += 0.00000001121*np.cos(5.85882470690 + 16706.585251848*t)
	Y1 += 0.00000000943*np.cos(0.21048093986 + 151.0476698429*t)
	Y1 += 0.00000000771*np.cos(1.58200018736 + 942.062061969*t)
	Y1 += 0.00000000757*np.cos(4.49953469679 + 14158.7477136156*t)
	Y1 += 0.00000000751*np.cos(1.17837342292 + 12566.1516999828*t)
	Y1 += 0.00000000744*np.cos(1.14486727666 + 3443.7052009184*t)
	Y1 += 0.00000000769*np.cos(1.88091883970 + 9638.9407478762*t)
	Y1 += 0.00000000727*np.cos(2.52800596414 + 10404.7338123226*t)
	Y1 += 0.00000000886*np.cos(3.06194121734 + 1169.5882514086*t)
	Y1 += 0.00000000800*np.cos(3.22072343557 + 6518.7582172674*t)
	Y1 += 0.00000000729*np.cos(4.58667469649 + 1375.7737998458*t)
	Y1 += 0.00000000725*np.cos(1.60568151338 + 6475.0393049624*t)
	Y1 += 0.00000000730*np.cos(1.45023184025 + 6709.6740408674*t)
	Y1 += 0.00000000794*np.cos(5.99496548901 + 16304.9131300908*t)
	Y1 += 0.00000000750*np.cos(4.51007684915 + 3296.8935143948*t)
	Y1 += 0.00000000762*np.cos(3.43418344370 + 1155.361157407*t)
	Y1 += 0.00000000688*np.cos(3.43319222752 + 10028.9508271002*t)
	Y1 += 0.00000000737*np.cos(1.61370530514 + 3384.3313390048*t)
	Y1 += 0.00000000646*np.cos(4.99729356736 + 3237.5196524812*t)
	Y1 += 0.00000000712*np.cos(1.82235727085 + 71.8126531507*t)
	Y1 += 0.00000000674*np.cos(1.39940720264 + 2807.3983432562*t)
	Y1 += 0.00000000845*np.cos(5.55182215578 + 9499.2598620056*t)
	Y1 += 0.00000000627*np.cos(5.82304741654 + 13149.1506113612*t)
	Y1 += 0.00000000629*np.cos(2.87628485086 + 1214.7350193206*t)
	Y1 += 0.00000000718*np.cos(2.94974266304 + 77.7505439839*t)
	Y1 += 0.00000000687*np.cos(4.23661989758 + 13517.8701062334*t)
	Y1 += 0.00000000630*np.cos(1.23559488085 + 6604.958782124*t)
	Y1 += 0.00000000710*np.cos(2.32420903412 + 6460.8122109608*t)
	Y1 += 0.00000000701*np.cos(5.09953279615 + 3311.18291816379*t)
	Y1 += 0.00000000701*np.cos(1.02423412249 + 3370.0419352358*t)
	Y1 += 0.00000000727*np.cos(4.12859968267 + 2111.6503133776*t)
	Y1 += 0.00000000716*np.cos(1.82681889911 + 12310.1813236108*t)
	Y1 += 0.00000000633*np.cos(0.43972121001 + 692.1576012268*t)
	Y1 += 0.00000000576*np.cos(2.64908131601 + 13916.0191096416*t)
	Y1 += 0.00000000544*np.cos(0.40037320261 + 16699.53901514999*t)
	Y1 += 0.00000000548*np.cos(2.52376915314 + 3340.6797370026*t)
	Y1 += 0.00000000539*np.cos(3.72942723734 + 2178.137722292*t)
	Y1 += 0.00000000623*np.cos(0.15818615271 + 10264.5658840734*t)
	Y1 += 0.00000000539*np.cos(5.53271145759 + 3490.1756238344*t)
	Y1 += 0.00000000557*np.cos(5.56701497497 + 13362.517017102*t)
	Y1 += 0.00000000563*np.cos(1.10897333902 + 1437.1756141986*t)
	Y1 += 0.00000000536*np.cos(5.69295314880 + 2693.601593385*t)
	Y1 += 0.00000000647*np.cos(5.65118044969 + 4392.8808098882*t)
	Y1 += 0.00000000538*np.cos(4.72229720906 + 3873.8265101434*t)
	Y1 += 0.00000000584*np.cos(0.55159339980 + 4193.8088084518*t)
	Y1 += 0.00000000630*np.cos(2.13231136184 + 11243.6858464208*t)
	Y1 += 0.00000000505*np.cos(6.09305482682 + 9485.032768004*t)
	Y1 += 0.00000000669*np.cos(5.22911771220 + 2707.8286873866*t)
	Y1 += 0.00000000504*np.cos(2.36012441072 + 277.0349937414*t)
	Y1 += 0.00000000670*np.cos(4.37490154824 + 6657.3464156518*t)
	Y1 += 0.00000000491*np.cos(2.60376575150 + 3774.3241645766*t)
	Y1 += 0.00000000513*np.cos(3.36932239157 + 3232.9489027612*t)
	Y1 += 0.00000000590*np.cos(4.86990668927 + 6034.2140200848*t)
	Y1 += 0.00000000577*np.cos(2.26728370057 + 18454.601664915*t)
	Y1 += 0.00000000613*np.cos(2.82948093577 + 5989.0672521728*t)
	Y1 += 0.00000000535*np.cos(3.23990732356 + 5642.1982426092*t)
	Y1 += 0.00000000492*np.cos(2.75437635016 + 3448.2759506384*t)
	Y1 += 0.00000000486*np.cos(5.53252452947 + 422.6660376129*t)
	Y1 += 0.00000000477*np.cos(2.98529100201 + 6843.6914895318*t)
	Y1 += 0.00000000483*np.cos(2.08187058985 + 12295.9542296092*t)
	Y1 += 0.00000000463*np.cos(6.10084466162 + 3229.4257844122*t)
	Y1 += 0.00000000506*np.cos(2.38698988700 + 2301.58581590939*t)
	Y1 += 0.00000000540*np.cos(3.87479718518 + 7903.073419721*t)
	Y1 += 0.00000000546*np.cos(1.42380603644 + 2221.856634597*t)
	Y1 += 0.00000000446*np.cos(4.30997409674 + 6048.4411140864*t)
	Y1 += 0.00000000444*np.cos(2.38797656832 + 6705.1032911474*t)
	Y1 += 0.00000000443*np.cos(0.02289876855 + 3451.7990689874*t)
	Y1 += 0.00000000530*np.cos(5.18892175358 + 7255.5696517344*t)
	Y1 += 0.00000000557*np.cos(5.97553834508 + 13362.3823964964*t)
	Y1 += 0.00000000449*np.cos(1.81656165831 + 1478.8665740644*t)
	Y1 += 0.00000000548*np.cos(2.93176743519 + 3340.545116397*t)
	Y1 += 0.00000000494*np.cos(1.91461298039 + 13207.029307365*t)
	Y1 += 0.00000000402*np.cos(0.14917407616 + 6571.0185321802*t)
	Y1 += 0.00000000413*np.cos(2.77393455325 + 8799.988713778*t)
	Y1 += 0.00000000398*np.cos(1.17032491098 + 7895.9598727202*t)
	Y1 += 0.00000000421*np.cos(2.92811239290 + 4379.6390374902*t)
	Y1 += 0.00000000391*np.cos(3.73837604066 + 1073.6090241908*t)
	Y1 += 0.00000000419*np.cos(0.51900494769 + 135.0650800354*t)
	Y1 += 0.00000000472*np.cos(5.05179451193 + 4936.7988689844*t)
	Y1 += 0.00000000515*np.cos(5.86680894517 + 13119.72110282519*t)
	Y1 += 0.00000000515*np.cos(3.61483236959 + 6675.7019290922*t)
	Y1 += 0.00000000407*np.cos(5.97123577955 + 3289.33208883739*t)
	Y1 += 0.00000000407*np.cos(0.15253113909 + 3391.89276456221*t)
	Y1 += 0.00000000375*np.cos(0.35041804232 + 234.6397364404*t)
	Y1 += 0.00000000474*np.cos(0.17715160287 + 13892.1406718938*t)
	Y1 += 0.00000000385*np.cos(5.77663237032 + 10596.1820784342*t)
	Y1 += 0.00000000366*np.cos(6.20989798780 + 2384.3232707292*t)
	Y1 += 0.00000000384*np.cos(4.23498307074 + 6685.1061887576*t)
	Y1 += 0.00000000373*np.cos(3.98254461376 + 415.5524906121*t)
	Y1 += 0.00000000425*np.cos(1.30634943039 + 11614.4332937322*t)
	Y1 += 0.00000000384*np.cos(5.64976516740 + 330.6189636582*t)
	Y1 += 0.00000000370*np.cos(6.07331404337 + 3274.1250177854*t)
	Y1 += 0.00000000361*np.cos(0.89534079814 + 12721.572099417*t)
	Y1 += 0.00000000400*np.cos(4.53551800839 + 9588.1255422226*t)
	Y1 += 0.00000000356*np.cos(6.03950898739 + 846.0828347512*t)
	Y1 += 0.00000000360*np.cos(0.05053136141 + 3407.0998356142*t)
	Y1 += 0.00000000453*np.cos(0.52827133920 + 3113.1362939108*t)
	Y1 += 0.00000000338*np.cos(0.67656842155 + 9380.9596727172*t)
	Y1 += 0.00000000337*np.cos(3.00609814338 + 15.252471185*t)
	Y1 += 0.00000000422*np.cos(0.62250110261 + 19513.9835951042*t)
	Y1 += 0.00000000353*np.cos(2.87159892794 + 20.3553193988*t)
	Y1 += 0.00000000373*np.cos(4.44069988433 + 10020.8569590312*t)
	Y1 += 0.00000000337*np.cos(3.18444650009 + 71.6002048296*t)
	Y1 += 0.00000000324*np.cos(0.71684229879 + 423.4167971383*t)
	Y1 += 0.00000000433*np.cos(1.36147512776 + 3.9321532631*t)
	Y1 += 0.00000000375*np.cos(2.90507995378 + 11610.9101753832*t)
	Y1 += 0.00000000318*np.cos(6.01470564020 + 5724.935697429*t)
	Y1 += 0.00000000335*np.cos(2.98604214434 + 2938.9403049426*t)
	Y1 += 0.00000000374*np.cos(2.47243769504 + 3415.3940252671*t)
	Y1 += 0.00000000326*np.cos(1.48465704932 + 77.962992305*t)
	Y1 += 0.00000000340*np.cos(2.07425079531 + 7321.1221397136*t)
	Y1 += 0.00000000328*np.cos(6.22461934829 + 16460.33352952499*t)
	Y1 += 0.00000000369*np.cos(2.13551229622 + 14584.2982731206*t)
	Y1 += 0.00000000412*np.cos(5.59494780647 + 3568.0885594888*t)
	Y1 += 0.00000000310*np.cos(3.13767541137 + 14421.8316369884*t)
	Y1 += 0.00000000316*np.cos(5.62533566974 + 429.7795846137*t)
	Y1 += 0.00000000364*np.cos(5.30890025348 + 860.3099287528*t)
	Y1 += 0.00000000330*np.cos(0.49540756155 + 3318.7615973734*t)
	Y1 += 0.00000000330*np.cos(5.62835935709 + 3362.4632560262*t)
	Y1 += 0.00000000350*np.cos(4.05599588288 + 9602.3526362242*t)
	Y1 += 0.00000000329*np.cos(3.37223997989 + 10042.6126755918*t)
	Y1 += 0.00000000304*np.cos(3.98761648250 + 145.6310438715*t)
	Y1 += 0.00000000327*np.cos(3.28894035861 + 1272.6810256272*t)
	Y1 += 0.00000000352*np.cos(0.64575728139 + 2.9689454166*t)
	Y1 += 0.00000000340*np.cos(3.21395005886 + 22324.9050567094*t)
	Y1 += 0.00000000352*np.cos(0.51052280975 + 263.0839233728*t)
	Y1 += 0.00000000390*np.cos(0.53675687816 + 6717.252720077*t)
	Y1 += 0.00000000298*np.cos(5.27506560855 + 3416.8784979754*t)
	Y1 += 0.00000000387*np.cos(3.10555839309 + 7373.3824546264*t)
	Y1 += 0.00000000291*np.cos(6.25952120602 + 6645.1969867222*t)
	Y1 += 0.00000000293*np.cos(2.11849465997 + 2675.8563815698*t)
	Y1 += 0.00000000384*np.cos(4.55881127062 + 210.8514148832*t)
	Y1 += 0.00000000380*np.cos(3.47993786173 + 215.7467759928*t)
	Y1 += 0.00000000346*np.cos(3.68559919908 + 3265.8308281325*t)
	Y1 += 0.00000000282*np.cos(1.51830354780 + 5732.0492444298*t)
	Y1 += 0.00000000360*np.cos(2.88459167183 + 728.762966531*t)
	Y1 += 0.00000000304*np.cos(2.34810025389 + 7203.8022714934*t)
	Y1 += 0.00000000280*np.cos(0.05535474901 + 3397.5108016354*t)
	Y1 += 0.00000000280*np.cos(6.06841216963 + 3283.7140517642*t)
	Y1 += 0.00000000338*np.cos(4.73513321530 + 4459.3682188026*t)
	Y1 += 0.00000000280*np.cos(1.83816934995 + 6688.2710900976*t)
	Y1 += 0.00000000268*np.cos(1.68224981136 + 11766.2632645146*t)
	Y1 += 0.00000000271*np.cos(2.02912231281 + 11780.4903585162*t)
	Y1 += 0.00000000363*np.cos(1.22201726104 + 10001.061884607*t)
	Y1 += 0.00000000265*np.cos(1.44919316453 + 7910.1869667218*t)
	Y1 += 0.00000000274*np.cos(0.01061104159 + 13936.794505134*t)
	Y1 += 0.00000000338*np.cos(4.31589716519 + 148.0787244263*t)
	Y1 += 0.00000000259*np.cos(1.56009469393 + 5032.7780962022*t)
	Y1 += 0.00000000253*np.cos(0.12054819282 + 17101.2111369072*t)
	Y1 += 0.00000000255*np.cos(0.68716361250 + 437.6438911399*t)
	Y1 += 0.00000000253*np.cos(1.95240011543 + 16703.0448798468*t)
	Y1 += 0.00000000253*np.cos(5.79374784837 + 6947.8318951214*t)
	Y1 += 0.00000000278*np.cos(4.67472382984 + 7322.1024607818*t)
	Y1 += 0.00000000252*np.cos(4.72342010347 + 533.2140834436*t)
	Y1 += 0.00000000322*np.cos(0.95155923546 + 162.4666361322*t)
	Y1 += 0.00000000253*np.cos(3.98317215792 + 16703.07938715119*t)
	Y1 += 0.00000000284*np.cos(3.67849455855 + 838.9692877504*t)
	Y1 += 0.00000000243*np.cos(4.59637992289 + 5244.049239201*t)
	Y1 += 0.00000000246*np.cos(1.15950003329 + 3304.0070613956*t)
	Y1 += 0.00000000246*np.cos(4.96426688535 + 3377.217792004*t)
	Y1 += 0.00000000246*np.cos(2.02033156272 + 16276.463942623*t)
	Y1 += 0.00000000235*np.cos(4.67612716033 + 16858.4825329332*t)
	Y1 += 0.00000000239*np.cos(1.58157022935 + 5305.4510535538*t)
	Y1 += 0.00000000225*np.cos(2.07472210939 + 10018.2468514476*t)
	Y1 += 0.00000000234*np.cos(0.03317726903 + 223.5940361765*t)
	Y1 += 0.00000000248*np.cos(2.91218176275 + 2075.0449480734*t)
	Y1 += 0.00000000284*np.cos(0.56682884608 + 10156.9023601348*t)
	Y1 += 0.00000000272*np.cos(5.85412476416 + 14712.317116458*t)
	Y1 += 0.00000000222*np.cos(4.29914928209 + 508.3503240922*t)
	Y1 += 0.00000000231*np.cos(0.92206582002 + 1485.9801210652*t)
	Y1 += 0.00000000226*np.cos(2.11036808486 + 4039.8835749274*t)
	Y1 += 0.00000000243*np.cos(5.89092212082 + 30065.5118402982*t)
	Y1 += 0.00000000218*np.cos(1.77859119613 + 3029.7716278314*t)
	Y1 += 0.00000000221*np.cos(4.00610570086 + 4005.3684718298*t)
	Y1 += 0.00000000216*np.cos(2.67268933641 + 15664.03552270859*t)
	Y1 += 0.00000000228*np.cos(1.42035440998 + 17924.9106998204*t)
	Y1 += 0.00000000224*np.cos(2.50666934513 + 10025.4277087512*t)
	Y1 += 0.00000000216*np.cos(4.14679941286 + 10037.0897512844*t)
	Y1 += 0.00000000213*np.cos(3.70755457019 + 10448.4354709754*t)
	Y1 += 0.00000000265*np.cos(1.64615612331 + 3.1813937377*t)
	Y1 += 0.00000000211*np.cos(2.33158804950 + 6944.3087767724*t)
	Y1 += 0.00000000215*np.cos(2.61875466736 + 3212.5935833624*t)
	Y1 += 0.00000000208*np.cos(1.06606795539 + 2008.557539159*t)
	Y1 += 0.00000000222*np.cos(2.20339233927 + 12323.4230960088*t)
	Y1 += 0.00000000222*np.cos(0.48962551079 + 14314.1681130498*t)
	Y1 += 0.00000000288*np.cos(1.38313040903 + 16062.1845261168*t)
	Y1 += 0.00000000234*np.cos(5.47802199777 + 3185.2593375684*t)
	Y1 += 0.00000000215*np.cos(5.96415874701 + 23.8784377478*t)
	Y1 += 0.00000000213*np.cos(1.54853404609 + 1545.3539829788*t)
	Y1 += 0.00000000201*np.cos(5.99546009327 + 1835.3246176068*t)
	Y1 += 0.00000000198*np.cos(4.93753556250 + 6578.132079181*t)
	Y1 += 0.00000000222*np.cos(0.61578505780 + 3495.9655158312*t)
	Y1 += 0.00000000204*np.cos(3.50489963320 + 3468.6312700372*t)
	Y1 += 0.00000000213*np.cos(5.38883317666 + 7747.7203305896*t)
	Y1 += 0.00000000209*np.cos(3.74698259846 + 3230.4061054804*t)
	Y1 += 0.00000000195*np.cos(3.20214800961 + 1903.4368125012*t)
	Y1 += 0.00000000193*np.cos(4.34393649097 + 3651.4532255682*t)
	Y1 += 0.00000000242*np.cos(2.25789470004 + 6621.850991486*t)
	Y1 += 0.00000000190*np.cos(0.52807642845 + 2480.302497947*t)
	Y1 += 0.00000000182*np.cos(3.98767129842 + 8542.970706035*t)
	Y1 += 0.00000000200*np.cos(2.50870443352 + 6677.3435180416*t)
	Y1 += 0.00000000249*np.cos(3.21268045476 + 699.2711482276*t)
	Y1 += 0.00000000202*np.cos(6.20004176432 + 12012.5822971404*t)
	Y1 += 0.00000000205*np.cos(6.27860457332 + 2945.9865416406*t)
	Y1 += 0.00000000183*np.cos(5.82529586360 + 15508.6151232744*t)
	Y1 += 0.00000000222*np.cos(1.76032428059 + 8982.810669309*t)
	Y1 += 0.00000000239*np.cos(5.27791146118 + 6106.8800550648*t)
	Y1 += 0.00000000200*np.cos(1.41969751355 + 10001.48196070061*t)
	Y1 += 0.00000000171*np.cos(2.86664255530 + 6756.0064519669*t)
	Y1 += 0.00000000181*np.cos(2.37018594067 + 88.865680217*t)
	Y1 += 0.00000000174*np.cos(1.67207569825 + 6418.1409300268*t)
	Y1 += 0.00000000182*np.cos(5.80987770417 + 6887.4104018368*t)
	Y1 += 0.00000000171*np.cos(5.86062733644 + 5618.3198048614*t)
	Y1 += 0.00000000170*np.cos(4.73099425239 + 6456.8800576977*t)
	Y1 += 0.00000000168*np.cos(6.18245369751 + 13575.7488022372*t)
	Y1 += 0.00000000184*np.cos(2.36721526307 + 7218.029365495*t)
	Y1 += 0.00000000166*np.cos(2.25679462872 + 15650.7937503106*t)
	Y1 += 0.00000000199*np.cos(1.40110998613 + 430.5303441391*t)
	Y1 += 0.00000000212*np.cos(3.23189207115 + 13363.4300278674*t)
	Y1 += 0.00000000189*np.cos(0.25718944825 + 124.433415221*t)
	Y1 += 0.00000000169*np.cos(5.08935042454 + 2655.5683724738*t)
	Y1 += 0.00000000168*np.cos(6.08539442812 + 7314.0085927128*t)
	Y1 += 0.00000000174*np.cos(5.22081710422 + 1368.660252845*t)
	Y1 += 0.00000000167*np.cos(3.42353804022 + 1062.5633239269*t)
	Y1 += 0.00000000177*np.cos(3.64016669145 + 6686.747777707*t)
	Y1 += 0.00000000156*np.cos(1.91880783576 + 19402.7969528166*t)
	Y1 += 0.00000000192*np.cos(1.70878546664 + 2751.5475996916*t)
	Y1 += 0.00000000153*np.cos(3.28724376065 + 3347.2960905739*t)
	Y1 += 0.00000000153*np.cos(2.83652315799 + 3333.9287628257*t)
	Y1 += 0.00000000154*np.cos(0.41279284728 + 3499.555944483*t)
	Y1 += 0.00000000152*np.cos(5.50666765279 + 160.6088973985*t)
	Y1 += 0.00000000169*np.cos(0.15684943582 + 19645.5255567906*t)
	Y1 += 0.00000000172*np.cos(0.02323350795 + 65.2203710117*t)
	Y1 += 0.00000000167*np.cos(3.08668060635 + 931.3630868518*t)
	Y1 += 0.00000000195*np.cos(5.14066365776 + 6546.1597733642*t)
	Y1 += 0.00000000154*np.cos(4.59717983879 + 519.3960243561*t)
	Y1 += 0.00000000183*np.cos(4.39590374650 + 1332.0548875408*t)
	Y1 += 0.00000000186*np.cos(1.43141139959 + 4025.6564809258*t)
	Y1 += 0.00000000158*np.cos(3.03919160267 + 14556.8967170238*t)
	Y1 += 0.00000000143*np.cos(3.74906711980 + 13553.8979729108*t)
	Y1 += 0.00000000171*np.cos(2.92431770122 + 1062.9050485382*t)
	Y1 += 0.00000000140*np.cos(2.99678875427 + 8584.6616659008*t)
	Y1 += 0.00000000139*np.cos(3.64890818066 + 1055.4497769261*t)
	Y1 += 0.00000000138*np.cos(4.30414447043 + 1258.4539316256*t)
	Y1 += 0.00000000148*np.cos(1.43175701702 + 3053.6500655792*t)
	Y1 += 0.00000000189*np.cos(2.84693993450 + 2409.249339848*t)
	Y1 += 0.00000000140*np.cos(5.61689203595 + 6691.8615187494*t)
	Y1 += 0.00000000135*np.cos(2.53133290785 + 2604.735913168*t)
	Y1 += 0.00000000135*np.cos(3.59243401079 + 4076.4889402316*t)
	Y1 += 0.00000000175*np.cos(4.87680231442 + 20.7753954924*t)
	Y1 += 0.00000000177*np.cos(0.10410066671 + 8958.9322315612*t)
	Y1 += 0.00000000178*np.cos(3.44819299296 + 2284.7536148596*t)
	Y1 += 0.00000000131*np.cos(0.64621084098 + 3191.0492295652*t)
	Y1 += 0.00000000177*np.cos(4.22515628202 + 4672.6673142406*t)
	Y1 += 0.00000000132*np.cos(5.18037129096 + 654.1243803156*t)
	Y1 += 0.00000000131*np.cos(2.84299146166 + 11670.2840372968*t)
	Y1 += 0.00000000133*np.cos(4.52679079571 + 18606.4989460002*t)
	Y1 += 0.00000000136*np.cos(5.45594231263 + 9374.8264467846*t)
	Y1 += 0.00000000133*np.cos(5.74550598907 + 5195.2447323344*t)
	Y1 += 0.00000000136*np.cos(1.73632400099 + 203.0041546995*t)
	Y1 += 0.00000000175*np.cos(3.29046570107 + 8965.9784682592*t)
	Y1 += 0.00000000161*np.cos(6.02169024946 + 2494.5295919486*t)
	Y1 += 0.00000000138*np.cos(6.18657392368 + 20047.1976785478*t)
	Y1 += 0.00000000128*np.cos(3.58997483094 + 8859.3625756916*t)
	Y1 += 0.00000000126*np.cos(3.21322516874 + 6148.010769956*t)
	Y1 += 0.00000000151*np.cos(2.93942995560 + 3077.528503327*t)
	Y1 += 0.00000000133*np.cos(5.83386254701 + 12839.8722887054*t)
	Y1 += 0.00000000137*np.cos(4.24430027174 + 6674.1786167016*t)
	Y1 += 0.00000000169*np.cos(4.97651092293 + 9389.0535407862*t)
	Y1 += 0.00000000132*np.cos(4.07654693615 + 15265.8865193004*t)
	Y1 += 0.00000000165*np.cos(3.26928756084 + 19004.6479494084*t)
	Y1 += 0.00000000146*np.cos(0.52279831791 + 3397.4156888696*t)
	Y1 += 0.00000000146*np.cos(5.60096860073 + 3283.80916453*t)
	Y1 += 0.00000000153*np.cos(4.43481405976 + 3929.677253708*t)
	Y1 += 0.00000000145*np.cos(3.13103384589 + 13745.3462390224*t)
	Y1 += 0.00000000133*np.cos(4.69278266341 + 3627.57478782039*t)
	Y1 += 0.00000000165*np.cos(1.99476868352 + 3450.8187479192*t)
	Y1 += 0.00000000124*np.cos(6.11670347030 + 6593.9166488598*t)
	Y1 += 0.00000000121*np.cos(4.88476463619 + 1063.3140834523*t)
	Y1 += 0.00000000117*np.cos(0.91596190605 + 3337.106562003*t)
	Y1 += 0.00000000117*np.cos(2.06621235900 + 3344.11829139661*t)
	Y1 += 0.00000000120*np.cos(0.73600487058 + 14054.607308026*t)
	Y1 += 0.00000000147*np.cos(1.07606700174 + 6510.5519827804*t)
	Y1 += 0.00000000117*np.cos(4.09698399049 + 3344.152798701*t)
	Y1 += 0.00000000117*np.cos(5.16837558174 + 3337.0720546986*t)
	Y1 += 0.00000000118*np.cos(4.20346162229 + 9886.772200064*t)
	Y1 += 0.00000000118*np.cos(3.20236689438 + 551.031606097*t)
	Y1 += 0.00000000157*np.cos(5.69136299054 + 5820.9149246468*t)
	Y1 += 0.00000000158*np.cos(4.02596829239 + 1648.4467571974*t)
	Y1 += 0.00000000154*np.cos(0.46704906665 + 3133.9116894032*t)
	Y1 += 0.00000000118*np.cos(3.61740536581 + 169.580183133*t)
	Y1 += 0.00000000118*np.cos(4.79097648197 + 3317.8439300904*t)
	Y1 += 0.00000000118*np.cos(1.33279043667 + 3363.3809233092*t)
	Y1 += 0.00000000120*np.cos(2.88381733148 + 539.9859058331*t)
	Y1 += 0.00000000117*np.cos(5.06197162174 + 3497.0131472022*t)
	Y1 += 0.00000000117*np.cos(1.06179529690 + 3184.2117061974*t)
	Y1 += 0.00000000116*np.cos(1.22222105263 + 15906.7641266826*t)
	Y1 += 0.00000000115*np.cos(1.85848730524 + 6724.9437657046*t)
	Y1 += 0.00000000157*np.cos(0.17397913596 + 12722.5524204852*t)
	Y1 += 0.00000000124*np.cos(3.17983191905 + 2631.6226244232*t)
	Y1 += 0.00000000140*np.cos(4.29359662977 + 1056.2005364515*t)
	Y1 += 0.00000000135*np.cos(3.17789391939 + 3603.6963500726*t)
	Y1 += 0.00000000119*np.cos(5.17512579994 + 16511.6138673874*t)
	Y1 += 0.00000000155*np.cos(0.79719420494 + 6155.057006654*t)
	Y1 += 0.00000000115*np.cos(3.22959858043 + 6997.6167230562*t)
	Y1 += 0.00000000111*np.cos(4.11806246187 + 222.8603229936*t)
	Y1 += 0.00000000111*np.cos(6.21075063523 + 87.30820453981*t)
	Y1 += 0.00000000111*np.cos(6.13183853822 + 9065.5481241288*t)
	Y1 += 0.00000000133*np.cos(3.06193509061 + 22.0914005278*t)
	Y1 += 0.00000000114*np.cos(1.52684026531 + 3987.6232600146*t)
	Y1 += 0.00000000138*np.cos(4.58738400697 + 2233.473621015*t)
	Y1 += 0.00000000131*np.cos(5.25025552048 + 6901.6374958384*t)
	Y1 += 0.00000000145*np.cos(1.83381548553 + 0.9803210682*t)
	Y1 += 0.00000000119*np.cos(3.96125292511 + 1505.28780909299*t)
	Y1 += 0.00000000107*np.cos(2.70035870913 + 2973.3880977374*t)
	Y1 += 0.00000000144*np.cos(2.57852789272 + 2060.8178540718*t)
	Y1 += 0.00000000111*np.cos(2.15559505693 + 6357.7194367422*t)
	Y1 += 0.00000000106*np.cos(0.16426574878 + 12509.2533250472*t)
	Y1 += 0.00000000112*np.cos(2.39983700427 + 2574.8193622534*t)
	Y1 += 0.00000000139*np.cos(5.65976385263 + 3547.3131639964*t)
	Y1 += 0.00000000122*np.cos(2.84793235795 + 3346.4696289994*t)
	Y1 += 0.00000000122*np.cos(3.27583456069 + 3334.7552244002*t)
	Y1 += 0.00000000136*np.cos(1.56582531149 + 21.3406410024*t)
	Y1 += 0.00000000144*np.cos(6.19128577365 + 299.1263942692*t)
	Y1 += 0.00000000144*np.cos(4.64913835608 + 1905.4647649404*t)
	Y1 += 0.00000000138*np.cos(0.09351747310 + 10213.285546211*t)
	Y1 += 0.00000000105*np.cos(2.94616046913 + 10184.3039162316*t)
	Y1 += 0.00000000108*np.cos(1.67634660643 + 302.164775655*t)
	Y1 += 0.00000000140*np.cos(4.52778173929 + 6670.5881880498*t)
	Y1 += 0.00000000102*np.cos(2.83477159707 + 17468.8551979454*t)
	Y1 += 0.00000000101*np.cos(1.41448120448 + 191.9584544356*t)
	Y1 += 0.00000000099*np.cos(1.01104081470 + 17917.79715281959*t)
	Y1 += 0.00000000099*np.cos(2.31748689016 + 10713.9948813262*t)
	Y1 += 0.00000000120*np.cos(1.40938335297 + 3370.1042450032*t)
	Y1 += 0.00000000120*np.cos(4.71438356567 + 3311.1206083964*t)
	Y1 += 0.00000000118*np.cos(0.83092751777 + 6606.4432548323*t)
	Y1 += 0.00000000123*np.cos(3.59177506566 + 11925.2740926006*t)
	Y1 += 0.00000000129*np.cos(1.38615714913 + 7366.2689076256*t)
	Y1 += 0.00000000132*np.cos(4.17530089524 + 3050.1269472302*t)
	Y1 += 0.00000000106*np.cos(4.20303552484 + 2641.3412784722*t)
	Y1 += 0.00000000101*np.cos(2.19730971635 + 10124.930054318*t)
	Y1 += 0.00000000095*np.cos(3.83184038977 + 18.1592472647*t)
	Y1 += 0.00000000126*np.cos(1.43242174074 + 7380.4960016272*t)
	Y1 += 0.00000000098*np.cos(5.71279251280 + 2679.3794999188*t)
	Y1 += 0.00000000098*np.cos(1.64590778764 + 59.3738619136*t)
	Y1 += 0.00000000104*np.cos(0.35230601699 + 4296.9015826704*t)
	Y1 += 0.00000000115*np.cos(2.20406459405 + 11250.7993934216*t)
	Y1 += 0.00000000111*np.cos(6.00152200950 + 10042.1925994982*t)
	Y1 += 0.00000000094*np.cos(1.74801590640 + 87.3117715395*t)
	Y1 += 0.00000000096*np.cos(3.26945343269 + 10006.5848089144*t)
	Y1 += 0.00000000108*np.cos(6.12508679330 + 3735.238311759*t)
	Y1 += 0.00000000093*np.cos(4.23458272510 + 3528.5375744624*t)
	Y1 += 0.00000000119*np.cos(3.20779882655 + 1574.8458012822*t)
	Y1 += 0.00000000092*np.cos(3.39944116355 + 3707.8367556622*t)
	Y1 += 0.00000000097*np.cos(2.13059348085 + 2922.1081038928*t)
	Y1 += 0.00000000127*np.cos(3.31567374097 + 4271.9755135516*t)
	Y1 += 0.00000000097*np.cos(4.65833476763 + 5835.1420186484*t)
	Y1 += 0.00000000094*np.cos(3.19086921862 + 35464.9814789334*t)
	Y1 += 0.00000000113*np.cos(1.01321609658 + 5401.4302807716*t)
	Y1 += 0.00000000122*np.cos(4.95627332740 + 84.3428261229*t)
	Y1 += 0.00000000115*np.cos(1.94984091716 + 9815.6517316622*t)
	Y1 += 0.00000000093*np.cos(2.14810622027 + 2771.7905526724*t)
	Y1 += 0.00000000115*np.cos(4.92888947995 + 21947.11137270*t)
	Y1 += 0.00000000102*np.cos(3.03180744336 + 4049.6022289764*t)
	Y1 += 0.00000000100*np.cos(0.08917971251 + 26887.3660497306*t)
	Y1 += 0.00000000090*np.cos(3.65721451906 + 664.75604513*t)
	Y1 += 0.00000000093*np.cos(0.23047883797 + 10706.8813343254*t)
	Y1 += 0.00000000097*np.cos(4.30891602532 + 217.964961884*t)
	Y1 += 0.00000000113*np.cos(4.93121887014 + 4922.5717749828*t)
	Y1 += 0.00000000097*np.cos(4.54619200720 + 1795.258443721*t)
	Y1 += 0.00000000097*np.cos(1.89933290057 + 17654.7805397496*t)
	Y1 += 0.00000000093*np.cos(6.00441441624 + 33.6796175129*t)
	Y1 += 0.00000000111*np.cos(2.46536345909 + 21795.21409161479*t)
	Y1 += 0.00000000087*np.cos(4.40897064967 + 2540.7913015344*t)
	Y1 += 0.00000000119*np.cos(1.94808743738 + 3631.0979061694*t)
	Y1 += 0.00000000087*np.cos(1.75505290273 + 231.4583427027*t)
	Y1 += 0.00000000097*np.cos(0.07381843439 + 72.3339180125*t)
	Y1 += 0.00000000101*np.cos(1.61168636694 + 2171.0241752912*t)
	Y1 += 0.00000000090*np.cos(3.89285886336 + 628.8515860501*t)
	Y1 += 0.00000000098*np.cos(0.70463876405 + 6768.5330579394*t)
	Y1 += 0.00000000084*np.cos(5.11902672644 + 3152.68727893721*t)
	Y1 += 0.00000000084*np.cos(4.83188308723 + 11527.1250891924*t)
	Y1 += 0.00000000085*np.cos(0.07731863530 + 21548.9623692918*t)
	Y1 += 0.00000000117*np.cos(4.51077566996 + 5518.7501489918*t)
	Y1 += 0.00000000083*np.cos(3.81620714151 + 22345.2603761082*t)
	Y1 += 0.00000000093*np.cos(1.26560426088 + 2538.2485042536*t)
	Y1 += 0.00000000089*np.cos(3.43002043997 + 1699.2792165032*t)
	Y1 += 0.00000000085*np.cos(6.12091736058 + 16489.763038061*t)
	Y1 += 0.00000000092*np.cos(0.03950789229 + 2277.7073781616*t)
	Y1 += 0.00000000085*np.cos(5.91600131489 + 18208.349942592*t)
	Y1 += 0.00000000094*np.cos(4.47767830246 + 12942.965062924*t)
	Y1 += 0.00000000107*np.cos(0.22163493976 + 6286.5989683404*t)
	Y1 += 0.00000000081*np.cos(0.50650790580 + 3326.3853326982*t)
	Y1 += 0.00000000081*np.cos(5.61725901284 + 3354.8395207014*t)
	Y1 += 0.00000000079*np.cos(1.50975699375 + 4777.7880408984*t)
	Y1 += 0.00000000079*np.cos(1.00513556613 + 1118.7557921028*t)
	Y1 += 0.00000000083*np.cos(3.99316690617 + 3759.1167495068*t)
	Y1 += 0.00000000093*np.cos(3.39442497787 + 685.044054226*t)
	Y1 += 0.00000000080*np.cos(5.99267916099 + 12.5301729722*t)
	Y1 += 0.00000000109*np.cos(1.11061888688 + 765.7930644464*t)
	Y1 += 0.00000000079*np.cos(2.69826809389 + 3378.7454623376*t)
	Y1 += 0.00000000079*np.cos(3.42549882475 + 3302.479391062*t)
	Y1 += 0.00000000079*np.cos(1.18088037992 + 9947.0556815321*t)
	Y1 += 0.00000000080*np.cos(0.54798761722 + 1442.2612087602*t)
	Y1 += 0.00000000078*np.cos(5.30952786068 + 26357.675084636*t)
	Y1 += 0.00000000087*np.cos(5.45293469310 + 3181.6689089166*t)
	Y1 += 0.00000000086*np.cos(3.72646183478 + 208.633228992*t)
	Y1 += 0.00000000106*np.cos(5.10677964557 + 7214.4389368432*t)
	Y1 += 0.00000000107*np.cos(5.78696398530 + 4845.9002357928*t)
	Y1 += 0.00000000079*np.cos(1.67795651281 + 5562.4690612968*t)
	Y1 += 0.00000000096*np.cos(1.84507576066 + 11236.57229942*t)
	Y1 += 0.00000000076*np.cos(4.88733161640 + 9.5612275556*t)
	Y1 += 0.00000000083*np.cos(3.97986520401 + 42153.969003049*t)
	Y1 += 0.00000000094*np.cos(5.43325086005 + 1655.5603041982*t)
	Y1 += 0.00000000077*np.cos(4.73669756226 + 38.1330356378*t)
	Y1 += 0.00000000077*np.cos(0.48016044263 + 4001.8453534808*t)
	Y1 += 0.00000000103*np.cos(3.31518454680 + 6279.5527316424*t)
	Y1 += 0.00000000076*np.cos(4.18947022170 + 288.0806940053*t)
	Y1 += 0.00000000075*np.cos(1.36914522483 + 6710.6543619356*t)
	Y1 += 0.00000000100*np.cos(1.23379947915 + 6653.8232973028*t)
	Y1 += 0.00000000085*np.cos(3.04492619910 + 3649.8907493556*t)
	Y1 += 0.00000000085*np.cos(3.07884071954 + 3031.334104044*t)
	Y1 += 0.00000000076*np.cos(3.19773799012 + 20809.4676246452*t)
	Y1 += 0.00000000074*np.cos(5.28765123522 + 1107.1388056848*t)
	Y1 += 0.00000000077*np.cos(3.97237865801 + 3909.4343007272*t)
	Y1 += 0.00000000073*np.cos(2.57751806041 + 42942.50433914939*t)
	Y1 += 0.00000000085*np.cos(3.82359953731 + 42146.20633233299*t)
	Y1 += 0.00000000102*np.cos(3.28709663996 + 3282.733730696*t)
	Y1 += 0.00000000102*np.cos(2.83667027868 + 3398.4911227036*t)
	Y1 += 0.00000000073*np.cos(3.23527061256 + 2067.9314010726*t)
	Y1 += 0.00000000077*np.cos(5.68309610758 + 20199.02764933019*t)
	Y1 += 0.00000000072*np.cos(1.29867546702 + 20206.141196331*t)
	Y1 += 0.00000000082*np.cos(3.69322064361 + 20597.2439630412*t)
	Y1 += 0.00000000073*np.cos(3.78223099359 + 13369.56325380*t)
	Y1 += 0.00000000097*np.cos(0.21157168319 + 6784.3176276182*t)
	Y1 += 0.00000000096*np.cos(4.64169775712 + 203.7378678824*t)
	Y1 += 0.00000000083*np.cos(1.14457241650 + 4447.7512323846*t)
	Y1 += 0.00000000092*np.cos(0.92188445820 + 3492.509707785*t)
	Y1 += 0.00000000076*np.cos(1.15437371557 + 19403.7772738848*t)
	Y1 += 0.00000000073*np.cos(0.71840007075 + 6364.832983743*t)
	Y1 += 0.00000000071*np.cos(1.82715162268 + 15121.102785216*t)
	Y1 += 0.00000000080*np.cos(2.74785809382 + 8756.269801473*t)
	Y1 += 0.00000000077*np.cos(0.86279166830 + 6549.6828917132*t)
	Y1 += 0.00000000076*np.cos(5.12453730610 + 362.8622925726*t)
	Y1 += 0.00000000076*np.cos(2.48257518078 + 1471.7530270636*t)
	Y1 += 0.00000000088*np.cos(4.48241968748 + 11883.5831327348*t)
	Y1 += 0.00000000074*np.cos(4.29411598595 + 2011.1003364398*t)
	Y1 += 0.00000000075*np.cos(0.38132378506 + 525.0250986486*t)
	Y1 += 0.00000000093*np.cos(1.79949400982 + 10050.2864675672*t)
	Y1 += 0.00000000069*np.cos(2.64295754993 + 114.3991069134*t)
	Y1 += 0.00000000081*np.cos(3.29992061540 + 15636.566656309*t)
	Y1 += 0.00000000068*np.cos(3.31942545345 + 4106.4054911462*t)
	Y1 += 0.00000000075*np.cos(1.30266865618 + 7447.017917846*t)
	Y1 += 0.00000000077*np.cos(5.18502579516 + 5466.489834079*t)
	Y1 += 0.00000000068*np.cos(5.35287430069 + 153.4953503977*t)
	Y1 += 0.00000000068*np.cos(5.70841220182 + 73.8183907208*t)
	Y1 += 0.00000000079*np.cos(6.08882534383 + 3329.5667264359*t)
	Y1 += 0.00000000079*np.cos(0.03494157481 + 3351.6581269637*t)
	Y1 += 0.00000000075*np.cos(2.41908956194 + 32124.36905223359*t)
	Y1 += 0.00000000074*np.cos(2.64861748980 + 25135.8265183146*t)
	Y1 += 0.00000000069*np.cos(3.47699248800 + 11353.8921676402*t)
	Y1 += 0.00000000087*np.cos(1.38741665452 + 43340.6533425576*t)
	Y1 += 0.00000000071*np.cos(0.81628722181 + 534.3568315406*t)
	Y1 += 0.00000000066*np.cos(6.18253618298 + 13517.8027959306*t)
	Y1 += 0.00000000071*np.cos(4.07784318430 + 1279.794572628*t)
	Y1 += 0.00000000072*np.cos(5.32558972032 + 25287.7237993998*t)
	Y1 += 0.00000000085*np.cos(0.02377577064 + 1854.6323056346*t)
	Y1 += 0.00000000088*np.cos(1.52868546432 + 3067.9394693482*t)
	Y1 += 0.00000000075*np.cos(2.26613010488 + 15110.4661198662*t)
	Y1 += 0.00000000069*np.cos(0.02278259907 + 43738.8023459658*t)
	Y1 += 0.00000000078*np.cos(5.07801637655 + 34363.365597556*t)
	Y1 += 0.00000000082*np.cos(1.79056505886 + 4885.9664096786*t)
	Y1 += 0.00000000065*np.cos(5.47583793528 + 6708.6264094964*t)
	Y1 += 0.00000000070*np.cos(0.39852574719 + 12725.453434775*t)
	Y1 += 0.00000000090*np.cos(3.58467854106 + 6740.5987153132*t)
	Y1 += 0.00000000065*np.cos(4.81926081363 + 4140.4335518652*t)
	Y1 += 0.00000000064*np.cos(2.78199198599 + 9801.4246376606*t)
	Y1 += 0.00000000064*np.cos(5.24500232218 + 75.7448064138*t)
	Y1 += 0.00000000087*np.cos(3.48209962852 + 9859.3706439672*t)
	Y1 += 0.00000000070*np.cos(5.58621397360 + 35707.7100829074*t)
	Y1 += 0.00000000084*np.cos(4.62280003448 + 3613.2853840514*t)
	Y1 += 0.00000000084*np.cos(3.13048289620 + 5202.3582793352*t)
	Y1 += 0.00000000065*np.cos(5.65188017283 + 6680.804777306*t)
	Y1 += 0.00000000074*np.cos(0.70811376982 + 19800.9459562248*t)
	Y1 += 0.00000000066*np.cos(5.79488701874 + 3414.213382615*t)
	Y1 += 0.00000000066*np.cos(0.32887989990 + 3267.0114707846*t)
	Y1 += 0.00000000064*np.cos(5.41618225042 + 3193.8007401762*t)
	Y1 += 0.00000000064*np.cos(0.70758466822 + 3487.4241132234*t)
	Y1 += 0.00000000080*np.cos(5.83125066323 + 9175.7544453482*t)
	Y1 += 0.00000000069*np.cos(0.45288984585 + 10177.1903692308*t)
	Y1 += 0.00000000078*np.cos(2.47729712704 + 14128.2427712456*t)
	Y1 += 0.00000000068*np.cos(3.28509813085 + 12808.8803039568*t)
	Y1 += 0.00000000068*np.cos(0.42906740811 + 6614.7374444852*t)
	Y1 += 0.00000000062*np.cos(1.67556973000 + 18461.71521191579*t)
	Y1 += 0.00000000066*np.cos(4.60699109440 + 42.5864537627*t)
	Y1 += 0.00000000073*np.cos(4.93443664690 + 10730.82708237599*t)
	Y1 += 0.00000000061*np.cos(1.32159131349 + 207.8824694666*t)
	Y1 += 0.00000000066*np.cos(4.71978579468 + 9997.9588423516*t)
	Y1 += 0.00000000062*np.cos(1.47129847545 + 18451.07854656599*t)
	Y1 += 0.00000000064*np.cos(4.43457293456 + 40796.33892267419*t)
	Y1 += 0.00000000078*np.cos(4.80114448945 + 35309.5610794992*t)
	Y1 += 0.00000000062*np.cos(0.61927789333 + 20040.15144184979*t)
	Y1 += 0.00000000064*np.cos(2.03965634077 + 10787.6303445458*t)
	Y1 += 0.00000000069*np.cos(0.35279777025 + 16858.41522263039*t)
	Y1 += 0.00000000075*np.cos(5.80439292359 + 40398.189919266*t)
	Y1 += 0.00000000059*np.cos(0.45173742414 + 218.7157214094*t)
	Y1 += 0.00000000059*np.cos(5.95742231142 + 408.4389436113*t)
	Y1 += 0.00000000078*np.cos(5.47505498554 + 14867.73751589219*t)
	Y1 += 0.00000000062*np.cos(4.44452076035 + 799.8211251654*t)
	Y1 += 0.00000000063*np.cos(6.28310501390 + 20742.9457084264*t)
	Y1 += 0.00000000061*np.cos(1.46903295029 + 14591.4118201214*t)
	Y1 += 0.00000000060*np.cos(4.02422394326 + 10016.314355792*t)
	Y1 += 0.00000000069*np.cos(0.07133537091 + 10721.108428327*t)
	Y1 += 0.00000000063*np.cos(0.32856760942 + 12082.6551341712*t)
	Y1 += 0.00000000061*np.cos(0.87700826571 + 36.6053653042*t)
	Y1 += 0.00000000080*np.cos(3.82715184041 + 12168.0026965746*t)
	Y1 += 0.00000000068*np.cos(4.35850169699 + 8186.5126624926*t)
	Y1 += 0.00000000067*np.cos(3.09157172324 + 9329.6796788726*t)
	Y1 += 0.00000000064*np.cos(5.61072669942 + 5223.6939198022*t)
	Y1 += 0.00000000064*np.cos(1.96539963912 + 7799.9806455024*t)
	Y1 += 0.00000000058*np.cos(5.32198378648 + 41748.0573289248*t)
	Y1 += 0.00000000078*np.cos(1.64083896570 + 24606.13555322*t)
	Y1 += 0.00000000067*np.cos(5.29778871808 + 152.5321425512*t)
	Y1 += 0.00000000076*np.cos(4.82056450443 + 77.2292791221*t)
	Y1 += 0.00000000057*np.cos(4.85968404475 + 12928.7379689224*t)
	Y1 += 0.00000000080*np.cos(0.99981693234 + 27417.0570148252*t)
	Y1 += 0.00000000063*np.cos(1.72943225747 + 79.2350166922*t)
	Y1 += 0.00000000072*np.cos(0.47301045978 + 24889.5747959916*t)
	Y1 += 0.00000000080*np.cos(1.29024393938 + 14047.4937610252*t)
	Y1 += 0.00000000062*np.cos(2.85518372165 + 12988.111830836*t)
	Y1 += 0.00000000067*np.cos(3.88281422282 + 41427.4869831788*t)
	Y1 += 0.00000000057*np.cos(1.87370499430 + 24491.4257925834*t)
	Y1 += 0.00000000059*np.cos(0.42163716106 + 5945.3483398678*t)
	Y1 += 0.00000000074*np.cos(1.15958679714 + 17395.2197347258*t)
	Y1 += 0.00000000057*np.cos(2.71055933927 + 42544.3553357412*t)
	Y1 += 0.00000000070*np.cos(1.62633648043 + 21265.5231265202*t)
	Y1 += 0.00000000058*np.cos(4.86596352164 + 15423.267560871*t)
	Y1 += 0.00000000062*np.cos(1.39408141536 + 3357.44462774959*t)
	Y1 += 0.00000000062*np.cos(4.72968550328 + 3323.78022565*t)
	Y1 += 0.00000000056*np.cos(1.12816132291 + 16063.164847185*t)
	Y1 += 0.00000000056*np.cos(1.61217428661 + 2978.491289969*t)
	Y1 += 0.00000000056*np.cos(4.51159263204 + 3702.7335634306*t)
	Y1 += 0.00000000058*np.cos(1.36447893952 + 8226.5788363784*t)
	Y1 += 0.00000000055*np.cos(1.48510731583 + 200.7689224658*t)
	Y1 += 0.00000000055*np.cos(3.98578162953 + 12715.4388734844*t)
	Y1 += 0.00000000055*np.cos(2.03729558857 + 340.7708920448*t)
	Y1 += 0.00000000076*np.cos(0.68351123517 + 146.594251718*t)
	Y1 += 0.00000000072*np.cos(1.86379528122 + 127.4717966068*t)
	Y1 += 0.00000000054*np.cos(2.71910253259 + 5607.6158292088*t)
	Y1 += 0.00000000073*np.cos(1.42919585711 + 4775.7600884592*t)
	Y1 += 0.00000000053*np.cos(3.09693738935 + 6788.8883773382*t)
	Y1 += 0.00000000058*np.cos(0.22442483444 + 3412.6681600546*t)
	Y1 += 0.00000000058*np.cos(5.89934208420 + 3268.556693345*t)
	Y1 += 0.00000000053*np.cos(2.19689791795 + 14481.205498902*t)
	Y1 += 0.00000000055*np.cos(3.89290884441 + 831.8557407496*t)
	Y1 += 0.00000000053*np.cos(0.15615144357 + 25841.29320224219*t)
	Y1 += 0.00000000052*np.cos(3.15010220845 + 6812.766815086*t)
	Y1 += 0.00000000053*np.cos(1.40676144190 + 2391.43681773*t)
	Y1 += 0.00000000053*np.cos(0.46935053804 + 44959.5476759902*t)
	Y1 += 0.00000000054*np.cos(5.80670820759 + 18849.2275499742*t)
	Y1 += 0.00000000052*np.cos(4.45343178668 + 45884.967762441*t)
	Y1 += 0.00000000057*np.cos(2.86057303027 + 5408.5438277724*t)
	Y1 += 0.00000000053*np.cos(2.93504488248 + 37895.4262903674*t)
	Y1 += 0.00000000072*np.cos(1.04870110960 + 3339.1279539915*t)
	Y1 += 0.00000000072*np.cos(5.07506580904 + 3342.0968994081*t)
	Y1 += 0.00000000056*np.cos(5.29729400428 + 17660.303464057*t)
	Y1 += 0.00000000054*np.cos(5.90243120665 + 13532.0298899322*t)
	Y1 += 0.00000000060*np.cos(1.10585615388 + 5511.636601991*t)
	Y1 += 0.00000000051*np.cos(1.99163070525 + 225.8292684102*t)
	Y1 += 0.00000000057*np.cos(5.68632410752 + 4.4534181249*t)
	Y1 += 0.00000000052*np.cos(1.45564798177 + 22487.3716928416*t)
	Y1 += 0.00000000055*np.cos(5.86720570151 + 3344.2028553516*t)
	Y1 += 0.00000000051*np.cos(4.59732093524 + 12410.7313005486*t)
	Y1 += 0.00000000059*np.cos(4.32589692662 + 618.5566453116*t)
	Y1 += 0.00000000054*np.cos(1.41387939355 + 21150.8133658836*t)
	Y1 += 0.00000000070*np.cos(6.26592499392 + 40000.04091585779*t)
	Y1 += 0.00000000058*np.cos(1.90611100788 + 29580.05463235019*t)
	Y1 += 0.00000000053*np.cos(3.04286367857 + 70.3281804424*t)
	Y1 += 0.00000000054*np.cos(2.06257459061 + 2735.762685995*t)
	Y1 += 0.00000000056*np.cos(5.51147391507 + 23539.7073863328*t)
	Y1 += 0.00000000049*np.cos(6.08800383828 + 16865.5287696312*t)
	Y1 += 0.00000000061*np.cos(2.80664860295 + 2655.501062171*t)
	Y1 += 0.00000000050*np.cos(0.09542687607 + 1727.6610936682*t)
	Y1 += 0.00000000059*np.cos(4.25647242104 + 12516.366872048*t)
	Y1 += 0.00000000050*np.cos(1.70549407364 + 3564.9572224017*t)
	Y1 += 0.00000000049*np.cos(1.47890962284 + 55516.4187098482*t)
	Y1 += 0.00000000056*np.cos(1.83267921871 + 16328.72425753579*t)
	Y1 += 0.00000000050*np.cos(6.13050078847 + 44768.0994098786*t)
	Y1 += 0.00000000050*np.cos(2.19360927774 + 3742.284548457*t)
	Y1 += 0.00000000048*np.cos(3.12373703961 + 1883.0814931024*t)
	Y1 += 0.00000000068*np.cos(5.14882675659 + 4142.976349146*t)
	Y1 += 0.00000000048*np.cos(2.75851599881 + 350.3321196004*t)
	Y1 += 0.00000000059*np.cos(4.61160954089 + 4356.275444584*t)
	Y1 += 0.00000000061*np.cos(2.37259677368 + 19617.07636932279*t)
	Y1 += 0.00000000048*np.cos(6.23507805833 + 19190.4781784468*t)
	Y1 += 0.00000000055*np.cos(1.90836976863 + 1971.9521738548*t)
	Y1 += 0.00000000065*np.cos(5.33022366023 + 20213.25474333179*t)
	Y1 += 0.00000000051*np.cos(3.13636139120 + 5749.8617665478*t)
	Y1 += 0.00000000058*np.cos(1.55579966471 + 1015.6630178842*t)
	Y1 += 0.00000000053*np.cos(6.07174122305 + 38086.874556479*t)
	Y1 += 0.00000000051*np.cos(0.22846885309 + 210.3783341312*t)
	Y1 += 0.00000000051*np.cos(1.50810894489 + 216.2198567448*t)
	Y1 += 0.00000000048*np.cos(6.09265191924 + 24341.5283174566*t)
	Y1 += 0.00000000047*np.cos(5.48131029950 + 11876.469585734*t)
	Y1 += 0.00000000047*np.cos(4.23447844874 + 2257.3520587628*t)
	Y1 += 0.00000000048*np.cos(0.75363318363 + 3264.3463554242*t)
	Y1 += 0.00000000064*np.cos(1.47602449306 + 1329.51209026*t)
	Y1 += 0.00000000049*np.cos(4.34430964617 + 963.4027029714*t)
	Y1 += 0.00000000055*np.cos(2.47607337246 + 4403.517475238*t)
	Y1 += 0.00000000048*np.cos(5.05047802604 + 14955.045720432*t)
	Y1 += 0.00000000059*np.cos(0.56447699816 + 4289.7880356696*t)
	Y1 += 0.00000000048*np.cos(5.64269937258 + 1859.2030553546*t)
	Y1 += 0.00000000052*np.cos(3.85502826049 + 32765.2466596158*t)
	Y1 += 0.00000000052*np.cos(0.60554758880 + 2963.238818784*t)
	Y1 += 0.00000000052*np.cos(5.51821932984 + 3717.9860346156*t)
	Y1 += 0.00000000052*np.cos(5.97532002180 + 142.4496501338*t)
	Y1 += 0.00000000054*np.cos(5.75638873525 + 1055.8588118402*t)
	Y1 += 0.00000000045*np.cos(3.23715580244 + 37.611770776*t)
	Y1 += 0.00000000045*np.cos(1.58216758277 + 3973.396166013*t)
	Y1 += 0.00000000060*np.cos(3.26313473570 + 46283.11676584919*t)
	Y1 += 0.00000000049*np.cos(2.80004822014 + 31214.2014369678*t)
	Y1 += 0.00000000044*np.cos(2.92943406327 + 62.2514255951*t)
	Y1 += 0.00000000050*np.cos(2.96247842378 + 1038.0412891868*t)
	Y1 += 0.00000000044*np.cos(0.54252101929 + 14469.588512484*t)
	Y1 += 0.00000000046*np.cos(4.82251602641 + 5881.4037282342*t)
	Y1 += 0.00000000044*np.cos(0.39621574967 + 14061.7208550268*t)
	Y1 += 0.00000000044*np.cos(4.23848711560 + 3436.5916539176*t)
	Y1 += 0.00000000044*np.cos(1.88527980304 + 3244.633199482*t)
	Y1 += 0.00000000044*np.cos(4.49857181022 + 17499.3601403154*t)
	Y1 += 0.00000000044*np.cos(4.06912509984 + 524.2743391232*t)
	Y1 += 0.00000000044*np.cos(1.10360628000 + 38.6543004996*t)
	Y1 += 0.00000000058*np.cos(3.38424006936 + 5625.3660415594*t)
	Y1 += 0.00000000045*np.cos(4.80756715462 + 39048.3225096072*t)
	Y1 += 0.00000000043*np.cos(1.18491417532 + 97670.38771289718*t)
	Y1 += 0.00000000044*np.cos(3.41315318980 + 535.107591066*t)
	Y1 += 0.00000000046*np.cos(3.97050301429 + 18052.9295431578*t)
	Y1 += 0.00000000059*np.cos(3.54996675378 + 2523.9591004846*t)
	Y1 += 0.00000000053*np.cos(5.27381050235 + 8336.7851575978*t)
	Y1 += 0.00000000048*np.cos(4.20516196539 + 2125.8100970764*t)
	Y1 += 0.00000000043*np.cos(3.74169704813 + 12199.9750023914*t)
	Y1 += 0.00000000043*np.cos(1.95551974467 + 15106.8756912144*t)
	Y1 += 0.00000000042*np.cos(4.34126456452 + 12729.665967486*t)
	Y1 += 0.00000000043*np.cos(0.33738122272 + 8123.4860621598*t)
	Y1 += 0.00000000042*np.cos(3.26999492630 + 195.1398481733*t)
	Y1 += 0.00000000046*np.cos(0.42675039162 + 2324.9494088156*t)
	Y1 += 0.00000000043*np.cos(4.93866317055 + 3826.5844794894*t)
	Y1 += 0.00000000043*np.cos(1.18510374809 + 2854.6403739102*t)
	Y1 += 0.00000000043*np.cos(2.09042966596 + 74.8934731519*t)
	Y1 += 0.00000000043*np.cos(2.58927275174 + 74.6697239827*t)
	Y1 += 0.00000000049*np.cos(5.73530227247 + 15849.865751747*t)
	Y1 += 0.00000000050*np.cos(0.24741236723 + 131.4039498699*t)
	Y1 += 0.00000000044*np.cos(3.32911228947 + 1685.0521225016*t)
	Y1 += 0.00000000045*np.cos(0.86869575514 + 28230.18722269139*t)
	Y1 += 0.00000000042*np.cos(5.52275728942 + 2651.977943822*t)
	Y1 += 0.00000000049*np.cos(4.20329151784 + 207.6700211455*t)
	Y1 += 0.00000000048*np.cos(0.38320382112 + 12825.6451947038*t)
	Y1 += 0.00000000052*np.cos(4.39773367298 + 6666.997759398*t)
	Y1 += 0.00000000041*np.cos(5.43225265078 + 3385.26625994*t)
	Y1 += 0.00000000041*np.cos(0.69151426786 + 3295.9585934596*t)
	Y1 += 0.00000000050*np.cos(5.89153916228 + 7788.3636590844*t)
	Y1 += 0.00000000045*np.cos(4.22332404514 + 3116.2676309979*t)
	Y1 += 0.00000000048*np.cos(3.25825537595 + 39601.8919124496*t)
	Y1 += 0.00000000040*np.cos(1.42664872496 + 26239.44220565039*t)
	Y1 += 0.00000000043*np.cos(1.84674416334 + 46681.2657692574*t)
	Y1 += 0.00000000040*np.cos(1.11930161769 + 14577.1847261198*t)
	Y1 += 0.00000000048*np.cos(0.71033320787 + 109.9456887885*t)
	Y1 += 0.00000000040*np.cos(4.72158737154 + 2814.4445799542*t)
	Y1 += 0.00000000040*np.cos(0.36674922708 + 20728.71861442479*t)
	Y1 += 0.00000000041*np.cos(1.94224224037 + 4670.1245169598*t)
	Y1 += 0.00000000052*np.cos(3.29121165005 + 3382.1632176846*t)
	Y1 += 0.00000000052*np.cos(2.83255526859 + 3299.061635715*t)
	Y1 += 0.00000000044*np.cos(5.64683761753 + 29698.2875113358*t)
	Y1 += 0.00000000041*np.cos(5.62926912301 + 30220.9322397324*t)
	Y1 += 0.00000000042*np.cos(0.62187667623 + 24076.4445881254*t)
	Y1 += 0.00000000046*np.cos(2.01012132100 + 19247.3765533824*t)
	Y1 += 0.00000000039*np.cos(3.61794457591 + 27433.88921587499*t)
	Y1 += 0.00000000045*np.cos(6.00306408589 + 227.476132789*t)
	return Y1*t




def Mars_Y2 (t): # 444 terms of order 2

	Y2 = 0.
	Y2 -= 0.00035452579
	Y2 += 0.00021950751*np.cos(1.96291594946 + 6681.2248533996*t)
	Y2 += 0.00006075990*np.cos(2.35864321001 + 10021.8372800994*t)
	Y2 += 0.00002571425*np.cos(5.64795745327 + 3340.6124266998*t)
	Y2 += 0.00001129099*np.cos(2.71576248963 + 13362.4497067992*t)
	Y2 += 0.00000182443*np.cos(3.06335050462 + 16703.062133499*t)
	Y2 += 0.00000160849*np.cos(2.83104666823 + 206.1855484372*t)
	Y2 += 0.00000155973*np.cos(5.19309730583 + 220.4126424388*t)
	Y2 += 0.00000168357*np.cos(3.01017878073 + 3337.0893083508*t)
	Y2 += 0.00000167747*np.cos(3.10922702911 + 3344.1355450488*t)
	Y2 += 0.00000118316*np.cos(5.70681506981 + 522.5774180938*t)
	Y2 += 0.00000115781*np.cos(1.78259431361 + 536.8045120954*t)
	Y2 += 0.00000093890*np.cos(5.65913038458 + 3185.1920272656*t)
	Y2 += 0.00000089244*np.cos(0.46137270696 + 3496.032826134*t)
	Y2 += 0.00000075625*np.cos(0.30809373033 + 1059.3819301892*t)
	Y2 += 0.00000103960*np.cos(4.03649382706 + 213.299095438*t)
	Y2 += 0.00000062193*np.cos(4.06412225662 + 426.598190876*t)
	Y2 += 0.00000071900*np.cos(0.61307162988 + 529.6909650946*t)
	Y2 += 0.00000040563*np.cos(3.45931070999 + 6684.7479717486*t)
	Y2 += 0.00000027526*np.cos(3.40697584132 + 20043.6745601988*t)
	Y2 += 0.00000024574*np.cos(2.05709261735 + 3149.1641605882*t)
	Y2 += 0.00000023302*np.cos(4.06054703458 + 3532.0606928114*t)
	Y2 += 0.00000024401*np.cos(4.20197858679 + 2544.3144198834*t)
	Y2 += 0.00000020299*np.cos(1.91147990337 + 4136.9104335162*t)
	Y2 += 0.00000018006*np.cos(1.85198728948 + 3097.88382272579*t)
	Y2 += 0.00000017221*np.cos(2.74161867582 + 2942.4634232916*t)
	Y2 += 0.00000016902*np.cos(4.25136186320 + 3583.3410306738*t)
	Y2 += 0.00000015777*np.cos(5.91718781131 + 5621.8429232104*t)
	Y2 += 0.00000015856*np.cos(0.06841918410 + 1194.4470102246*t)
	Y2 += 0.00000015264*np.cos(3.35254931189 + 3738.761430108*t)
	Y2 += 0.00000014254*np.cos(4.25680464915 + 433.7117378768*t)
	Y2 += 0.00000013171*np.cos(3.57877335400 + 1990.745017041*t)
	Y2 += 0.00000016812*np.cos(0.77954286997 + 2787.0430238574*t)
	Y2 += 0.00000012593*np.cos(2.18013310837 + 2388.8940204492*t)
	Y2 += 0.00000015019*np.cos(4.97047493091 + 1592.5960136328*t)
	Y2 += 0.00000011289*np.cos(6.01290979033 + 6525.8044539654*t)
	Y2 += 0.00000012302*np.cos(5.54713651711 + 3339.6321056316*t)
	Y2 += 0.00000011373*np.cos(0.77777603216 + 1589.0728952838*t)
	Y2 += 0.00000012284*np.cos(0.57411575365 + 3341.592747768*t)
	Y2 += 0.00000011117*np.cos(1.40530378545 + 796.2980068164*t)
	Y2 += 0.00000012723*np.cos(1.91903810105 + 419.4846438752*t)
	Y2 += 0.00000013747*np.cos(5.31116419768 + 3894.1818295422*t)
	Y2 += 0.00000010577*np.cos(0.59752271504 + 4399.994356889*t)
	Y2 += 0.00000012705*np.cos(4.25802747859 + 155.4203994342*t)
	Y2 += 0.00000010098*np.cos(5.47747691225 + 2146.1654164752*t)
	Y2 += 0.00000008863*np.cos(3.88169637617 + 4292.3308329504*t)
	Y2 += 0.00000008121*np.cos(3.78260601575 + 10025.3603984484*t)
	Y2 += 0.00000008120*np.cos(2.48132497663 + 4690.4798363586*t)
	Y2 += 0.00000008061*np.cos(6.02603958883 + 5486.777843175*t)
	Y2 += 0.00000007720*np.cos(5.06798604557 + 227.5261894396*t)
	Y2 += 0.00000007433*np.cos(3.31822028018 + 639.897286314*t)
	Y2 += 0.00000008308*np.cos(5.94980766794 + 2957.7158944766*t)
	Y2 += 0.00000008789*np.cos(0.17466315765 + 7.1135470008*t)
	Y2 += 0.00000006944*np.cos(2.33279970200 + 1066.49547719*t)
	Y2 += 0.00000008863*np.cos(0.51480663563 + 4535.0594369244*t)
	Y2 += 0.00000007306*np.cos(0.15133585090 + 3723.508958923*t)
	Y2 += 0.00000008322*np.cos(1.11264211549 + 5088.6288397668*t)
	Y2 += 0.00000006121*np.cos(3.80547694913 + 7079.3738568078*t)
	Y2 += 0.00000005467*np.cos(5.23241346125 + 1052.2683831884*t)
	Y2 += 0.00000005292*np.cos(2.91159592616 + 553.5694028424*t)
	Y2 += 0.00000005260*np.cos(4.61737050810 + 5884.9268465832*t)
	Y2 += 0.00000005181*np.cos(3.78652084191 + 242.728603974*t)
	Y2 += 0.00000005040*np.cos(5.84239832938 + 515.463871093*t)
	Y2 += 0.00000004788*np.cos(5.08946784428 + 3333.498879699*t)
	Y2 += 0.00000004994*np.cos(3.77687231272 + 2274.1169495098*t)
	Y2 += 0.00000005294*np.cos(2.49424280894 + 6489.776587288*t)
	Y2 += 0.00000004310*np.cos(5.38385773303 + 4933.2084403326*t)
	Y2 += 0.00000004451*np.cos(6.20023805343 + 2288.3440435114*t)
	Y2 += 0.00000004108*np.cos(1.09332741074 + 3347.7259737006*t)
	Y2 += 0.00000003907*np.cos(5.34892103731 + 5092.1519581158*t)
	Y2 += 0.00000004168*np.cos(1.63291442825 + 951.7184062506*t)
	Y2 += 0.00000003986*np.cos(3.74911328925 + 23384.2869868986*t)
	Y2 += 0.00000004160*np.cos(0.01637628167 + 1748.016413067*t)
	Y2 += 0.00000003729*np.cos(2.96611895542 + 199.0720014364*t)
	Y2 += 0.00000003853*np.cos(2.50327269341 + 3870.3033917944*t)
	Y2 += 0.00000003521*np.cos(1.65043749771 + 543.9180590962*t)
	Y2 += 0.00000003509*np.cos(0.57679733808 + 1349.8674096588*t)
	Y2 += 0.00000004609*np.cos(2.29503773584 + 7477.522860216*t)
	Y2 += 0.00000003076*np.cos(2.19921948725 + 6438.4962494256*t)
	Y2 += 0.00000002496*np.cos(3.96886138858 + 5331.3574437408*t)
	Y2 += 0.00000002377*np.cos(0.38140430638 + 6836.6452528338*t)
	Y2 += 0.00000002686*np.cos(3.87569148850 + 382.8965322232*t)
	Y2 += 0.00000002208*np.cos(4.32192232999 + 9492.1463150048*t)
	Y2 += 0.00000002174*np.cos(1.14140386023 + 6127.6554505572*t)
	Y2 += 0.00000002254*np.cos(5.32326617203 + 2281.2304965106*t)
	Y2 += 0.00000002234*np.cos(3.34034105089 + 6677.7017350506*t)
	Y2 += 0.00000002008*np.cos(0.97233813710 + 6682.2051744678*t)
	Y2 += 0.00000001886*np.cos(0.88359569638 + 4929.6853219836*t)
	Y2 += 0.00000001966*np.cos(5.66277094404 + 6681.2075997474*t)
	Y2 += 0.00000001838*np.cos(1.25415083586 + 2118.7638603784*t)
	Y2 += 0.00000001709*np.cos(3.15485228182 + 3553.9115221378*t)
	Y2 += 0.00000001623*np.cos(2.91176858936 + 3127.3133312618*t)
	Y2 += 0.00000001966*np.cos(1.40934384205 + 6681.2421070518*t)
	Y2 += 0.00000002129*np.cos(0.96593329639 + 7740.6067835888*t)
	Y2 += 0.00000001613*np.cos(0.87522364052 + 7875.6718636242*t)
	Y2 += 0.00000001959*np.cos(4.59967067607 + 6923.9534573736*t)
	Y2 += 0.00000001707*np.cos(1.58055507525 + 191.4482661116*t)
	Y2 += 0.00000001563*np.cos(6.04825312520 + 8969.568896911*t)
	Y2 += 0.00000001562*np.cos(3.60601030893 + 8955.3418029094*t)
	Y2 += 0.00000001351*np.cos(0.59351678849 + 316.3918696566*t)
	Y2 += 0.00000001856*np.cos(2.55647948443 + 5729.506447149*t)
	Y2 += 0.00000001727*np.cos(2.85561952146 + 6674.1113063988*t)
	Y2 += 0.00000001409*np.cos(4.65471130275 + 216.4804891757*t)
	Y2 += 0.00000001321*np.cos(3.39383854482 + 647.0108333148*t)
	Y2 += 0.00000001368*np.cos(3.38543777835 + 210.1177017003*t)
	Y2 += 0.00000001467*np.cos(4.10525560389 + 13365.9728251482*t)
	Y2 += 0.00000001717*np.cos(0.02861328541 + 14.2270940016*t)
	Y2 += 0.00000001489*np.cos(0.07763972898 + 9866.4168806652*t)
	Y2 += 0.00000001241*np.cos(2.40154751214 + 640.8776073822*t)
	Y2 += 0.00000001216*np.cos(5.32666382225 + 6254.6266625236*t)
	Y2 += 0.00000001163*np.cos(0.02680352381 + 6298.3283211764*t)
	Y2 += 0.00000001127*np.cos(4.74702347824 + 12832.7587417046*t)
	Y2 += 0.00000001479*np.cos(4.19328625081 + 10419.9862835076*t)
	Y2 += 0.00000001110*np.cos(0.62876661717 + 12303.06777661*t)
	Y2 += 0.00000001201*np.cos(1.35027812980 + 3767.2106175758*t)
	Y2 += 0.00000001277*np.cos(4.14556116975 + 2810.9214616052*t)
	Y2 += 0.00000000996*np.cos(4.74526775741 + 4562.4609930212*t)
	Y2 += 0.00000001177*np.cos(3.11858509884 + 2699.7348193176*t)
	Y2 += 0.00000001107*np.cos(3.43598182944 + 7210.9158184942*t)
	Y2 += 0.00000000980*np.cos(4.10189301724 + 1751.539531416*t)
	Y2 += 0.00000000992*np.cos(2.89543127786 + 9830.3890139878*t)
	Y2 += 0.00000000879*np.cos(2.65396505074 + 10818.1352869158*t)
	Y2 += 0.00000000950*np.cos(2.81842708673 + 632.7837393132*t)
	Y2 += 0.00000000848*np.cos(6.23917434526 + 526.5095713569*t)
	Y2 += 0.00000000806*np.cos(2.96434145307 + 103.0927742186*t)
	Y2 += 0.00000000801*np.cos(3.12247047301 + 7234.794256242*t)
	Y2 += 0.00000000825*np.cos(1.24361863355 + 532.8723588323*t)
	Y2 += 0.00000000761*np.cos(4.73161044526 + 209.3669421749*t)
	Y2 += 0.00000000750*np.cos(5.47332571883 + 10018.3141617504*t)
	Y2 += 0.00000001020*np.cos(2.84383580823 + 3981.490034082*t)
	Y2 += 0.00000000752*np.cos(3.75998155147 + 9623.6882766912*t)
	Y2 += 0.00000000817*np.cos(1.80163831596 + 10021.8545337516*t)
	Y2 += 0.00000000733*np.cos(3.30972792259 + 217.2312487011*t)
	Y2 += 0.00000000980*np.cos(2.36639419833 + 6151.533888305*t)
	Y2 += 0.00000000885*np.cos(0.58376168802 + 110.2063212194*t)
	Y2 += 0.00000000817*np.cos(3.26286812630 + 853.196381752*t)
	Y2 += 0.00000000689*np.cos(4.21955395780 + 440.8252848776*t)
	Y2 += 0.00000000816*np.cos(6.05414506463 + 10021.8200264472*t)
	Y2 += 0.00000000920*np.cos(0.39289007555 + 6041.3275670856*t)
	Y2 += 0.00000000685*np.cos(5.75193209744 + 8273.8208670324*t)
	Y2 += 0.00000000647*np.cos(3.74908813669 + 6681.1575430968*t)
	Y2 += 0.00000000850*np.cos(1.47881746342 + 6688.3384004004*t)
	Y2 += 0.00000000631*np.cos(5.67308971270 + 117.3198682202*t)
	Y2 += 0.00000000600*np.cos(3.56706010534 + 323.5054166574*t)
	Y2 += 0.00000000652*np.cos(3.34981557701 + 6681.2921637024*t)
	Y2 += 0.00000000700*np.cos(1.67530129882 + 7632.9432596502*t)
	Y2 += 0.00000000577*np.cos(1.04070762372 + 15643.6802033098*t)
	Y2 += 0.00000000549*np.cos(3.24495575230 + 949.1756089698*t)
	Y2 += 0.00000000606*np.cos(3.86357846284 + 95.9792272178*t)
	Y2 += 0.00000000726*np.cos(5.43722942949 + 74.7815985673*t)
	Y2 += 0.00000000604*np.cos(4.38406109733 + 149.5631971346*t)
	Y2 += 0.00000000717*np.cos(2.07519839097 + 3178.1457905676*t)
	Y2 += 0.00000000652*np.cos(3.70253626949 + 6894.5239488376*t)
	Y2 += 0.00000000545*np.cos(4.73162468373 + 1045.1548361876*t)
	Y2 += 0.00000000545*np.cos(3.41522137104 + 2766.267628365*t)
	Y2 += 0.00000000673*np.cos(4.04821743411 + 3503.079062832*t)
	Y2 += 0.00000000617*np.cos(0.99680091352 + 3253.30422216*t)
	Y2 += 0.00000000536*np.cos(3.52327599023 + 6040.3472460174*t)
	Y2 += 0.00000000599*np.cos(4.43359462367 + 735.8765135318*t)
	Y2 += 0.00000000596*np.cos(5.12699846907 + 3427.9206312396*t)
	Y2 += 0.00000000490*np.cos(1.25898273127 + 525.7588118315*t)
	Y2 += 0.00000000488*np.cos(6.22654201321 + 533.6231183577*t)
	Y2 += 0.00000000475*np.cos(0.27257730049 + 8031.0922630584*t)
	Y2 += 0.00000000437*np.cos(2.81553406247 + 1596.1864422846*t)
	Y2 += 0.00000000452*np.cos(3.92413733398 + 7064.1213856228*t)
	Y2 += 0.00000000545*np.cos(5.75151872801 + 6680.2445323314*t)
	Y2 += 0.00000000410*np.cos(0.01129204844 + 3980.5097130138*t)
	Y2 += 0.00000000407*np.cos(3.71457448004 + 398.1490034082*t)
	Y2 += 0.00000000561*np.cos(4.09070736733 + 26724.8994135984*t)
	Y2 += 0.00000000449*np.cos(1.70068184172 + 2648.454825473*t)
	Y2 += 0.00000000394*np.cos(4.16793050853 + 12964.300703391*t)
	Y2 += 0.00000000494*np.cos(4.49655447960 + 2914.0142358238*t)
	Y2 += 0.00000000406*np.cos(2.58759397313 + 3914.9572250346*t)
	Y2 += 0.00000000495*np.cos(1.02025723901 + 1039.0266107904*t)
	Y2 += 0.00000000369*np.cos(1.17514057075 + 8270.2977486834*t)
	Y2 += 0.00000000380*np.cos(1.32206670955 + 11081.2192102886*t)
	Y2 += 0.00000000362*np.cos(0.90947170771 + 2700.7151403858*t)
	Y2 += 0.00000000328*np.cos(2.75210171118 + 6872.6731195112*t)
	Y2 += 0.00000000402*np.cos(4.93492106682 + 8962.4553499102*t)
	Y2 += 0.00000000348*np.cos(0.42381697714 + 5614.7293762096*t)
	Y2 += 0.00000000300*np.cos(1.28282479527 + 5459.3762870782*t)
	Y2 += 0.00000000326*np.cos(1.34710144821 + 10022.8176011676*t)
	Y2 += 0.00000000289*np.cos(0.11523060708 + 574.3447983348*t)
	Y2 += 0.00000000277*np.cos(1.25004682191 + 11216.284290324*t)
	Y2 += 0.00000000272*np.cos(4.28209348126 + 10551.528245194*t)
	Y2 += 0.00000000281*np.cos(4.56486810428 + 13760.5987102074*t)
	Y2 += 0.00000000353*np.cos(4.32675452202 + 8671.9698704406*t)
	Y2 += 0.00000000268*np.cos(3.72932515250 + 10021.9045904022*t)
	Y2 += 0.00000000349*np.cos(4.12933332026 + 63.7358983034*t)
	Y2 += 0.00000000297*np.cos(1.37206169767 + 5828.0284716476*t)
	Y2 += 0.00000000263*np.cos(1.47811633236 + 9468.267877257*t)
	Y2 += 0.00000000315*np.cos(5.10166124248 + 16173.3711684044*t)
	Y2 += 0.00000000265*np.cos(2.25319243195 + 2487.4160449478*t)
	Y2 += 0.00000000337*np.cos(1.63942541135 + 412.3710968744*t)
	Y2 += 0.00000000270*np.cos(5.28007746957 + 1581.959348283*t)
	Y2 += 0.00000000271*np.cos(3.92820739547 + 8432.7643848156*t)
	Y2 += 0.00000000260*np.cos(4.50952770985 + 625.6701923124*t)
	Y2 += 0.00000000242*np.cos(5.37781682645 + 13358.9265884502*t)
	Y2 += 0.00000000237*np.cos(0.07292901465 + 70.8494453042*t)
	Y2 += 0.00000000297*np.cos(4.56177638218 + 4032.7700279266*t)
	Y2 += 0.00000000233*np.cos(2.05217226701 + 9779.1086761254*t)
	Y2 += 0.00000000267*np.cos(4.13774104917 + 10021.7699697966*t)
	Y2 += 0.00000000227*np.cos(4.92862031663 + 234.6397364404*t)
	Y2 += 0.00000000246*np.cos(4.94804916890 + 10264.5658840734*t)
	Y2 += 0.00000000219*np.cos(5.43349299793 + 11.0457002639*t)
	Y2 += 0.00000000256*np.cos(5.25900695618 + 956.2891559706*t)
	Y2 += 0.00000000218*np.cos(4.61617873387 + 78.7137518304*t)
	Y2 += 0.00000000285*np.cos(0.15954661286 + 12310.1813236108*t)
	Y2 += 0.00000000283*np.cos(0.60090092021 + 85.8272988312*t)
	Y2 += 0.00000000211*np.cos(3.29348428114 + 942.062061969*t)
	Y2 += 0.00000000244*np.cos(3.99455029761 + 1221.8485663214*t)
	Y2 += 0.00000000266*np.cos(1.39174746943 + 18984.2926300096*t)
	Y2 += 0.00000000199*np.cos(2.16282411281 + 13362.4669604514*t)
	Y2 += 0.00000000199*np.cos(0.13210292707 + 13362.432453147*t)
	Y2 += 0.00000000202*np.cos(4.05984593475 + 2301.58581590939*t)
	Y2 += 0.00000000239*np.cos(4.43362254313 + 16706.585251848*t)
	Y2 += 0.00000000226*np.cos(3.69462756239 + 73.297125859*t)
	Y2 += 0.00000000200*np.cos(5.38904642432 + 8429.2412664666*t)
	Y2 += 0.00000000235*np.cos(0.31453942563 + 36.6485629295*t)
	Y2 += 0.00000000213*np.cos(2.54349021425 + 309.2783226558*t)
	Y2 += 0.00000000212*np.cos(1.84457939183 + 7107.8230442756*t)
	Y2 += 0.00000000226*np.cos(3.49275518587 + 10575.4066829418*t)
	Y2 += 0.00000000224*np.cos(4.02383631251 + 39.6175083461*t)
	Y2 += 0.00000000193*np.cos(2.86847666295 + 9070.1188738488*t)
	Y2 += 0.00000000231*np.cos(2.66318410477 + 202.2533951741*t)
	Y2 += 0.00000000172*np.cos(3.27689792601 + 13171.0014406876*t)
	Y2 += 0.00000000198*np.cos(4.83262833047 + 5642.1982426092*t)
	Y2 += 0.00000000187*np.cos(1.29115653830 + 1169.5882514086*t)
	Y2 += 0.00000000196*np.cos(0.42643861999 + 13207.029307365*t)
	Y2 += 0.00000000167*np.cos(2.07259165182 + 1073.6090241908*t)
	Y2 += 0.00000000177*np.cos(0.37846184022 + 9638.9407478762*t)
	Y2 += 0.00000000196*np.cos(5.64541899687 + 224.3447957019*t)
	Y2 += 0.00000000170*np.cos(1.42477887702 + 4379.6390374902*t)
	Y2 += 0.00000000204*np.cos(5.68029274716 + 10177.2576795336*t)
	Y2 += 0.00000000155*np.cos(3.91618675743 + 12295.9542296092*t)
	Y2 += 0.00000000211*np.cos(1.76754517424 + 6283.0758499914*t)
	Y2 += 0.00000000158*np.cos(5.13689612572 + 1155.361157407*t)
	Y2 += 0.00000000148*np.cos(4.18280926820 + 10235.1363755374*t)
	Y2 += 0.00000000137*np.cos(0.50600690701 + 742.9900605326*t)
	Y2 += 0.00000000135*np.cos(5.63458486706 + 138.5174968707*t)
	Y2 += 0.00000000141*np.cos(1.85259563214 + 10028.9508271002*t)
	Y2 += 0.00000000148*np.cos(1.53909219281 + 76.2660712756*t)
	Y2 += 0.00000000133*np.cos(6.00639174435 + 508.3503240922*t)
	Y2 += 0.00000000136*np.cos(5.89922987098 + 1437.1756141986*t)
	Y2 += 0.00000000131*np.cos(0.25161165723 + 3029.7716278314*t)
	Y2 += 0.00000000126*np.cos(3.76226961231 + 330.6189636582*t)
	Y2 += 0.00000000153*np.cos(1.90910985368 + 10973.55568635*t)
	Y2 += 0.00000000126*np.cos(2.61435997717 + 860.3099287528*t)
	Y2 += 0.00000000116*np.cos(5.87205002685 + 3651.4532255682*t)
	Y2 += 0.00000000158*np.cos(2.17797348306 + 38.1330356378*t)
	Y2 += 0.00000000121*np.cos(5.22121986472 + 3340.629680352*t)
	Y2 += 0.00000000129*np.cos(2.33699517207 + 6696.4773245846*t)
	Y2 += 0.00000000117*np.cos(4.27299444995 + 6701.5801727984*t)
	Y2 += 0.00000000121*np.cos(3.19272980929 + 3340.5951730476*t)
	Y2 += 0.00000000107*np.cos(3.57431869370 + 4407.1079038898*t)
	Y2 += 0.00000000114*np.cos(3.18684723749 + 7322.1024607818*t)
	Y2 += 0.00000000136*np.cos(0.83727417601 + 15113.9892382152*t)
	Y2 += 0.00000000104*np.cos(1.56408098268 + 6665.9723822146*t)
	Y2 += 0.00000000114*np.cos(2.24681555636 + 9168.6408983474*t)
	Y2 += 0.00000000115*np.cos(4.52412782775 + 223.5940361765*t)
	Y2 += 0.00000000101*np.cos(2.89480529792 + 14158.7477136156*t)
	Y2 += 0.00000000100*np.cos(5.74151572110 + 17924.9106998204*t)
	Y2 += 0.00000000110*np.cos(4.93056089704 + 71.6002048296*t)
	Y2 += 0.00000000115*np.cos(3.76754615650 + 429.7795846137*t)
	Y2 += 0.00000000104*np.cos(5.03602136971 + 8827.3902698748*t)
	Y2 += 0.00000000131*np.cos(5.90938471415 + 6660.8695340008*t)
	Y2 += 0.00000000100*np.cos(1.58394187969 + 6467.9257579616*t)
	Y2 += 0.00000000106*np.cos(6.02834271847 + 77.962992305*t)
	Y2 += 0.00000000114*np.cos(2.14940221332 + 6518.7582172674*t)
	Y2 += 0.00000000114*np.cos(1.16549646319 + 11773.3768115154*t)
	Y2 += 0.00000000123*np.cos(4.57966985938 + 728.762966531*t)
	Y2 += 0.00000000095*np.cos(5.01859144435 + 6816.289933435*t)
	Y2 += 0.00000000088*np.cos(4.49180629006 + 1835.3246176068*t)
	Y2 += 0.00000000091*np.cos(0.68664247876 + 9381.9399937854*t)
	Y2 += 0.00000000105*np.cos(6.21526366678 + 1162.4747044078*t)
	Y2 += 0.00000000102*np.cos(3.63292130858 + 422.6660376129*t)
	Y2 += 0.00000000092*np.cos(3.16422844303 + 10014.7237330986*t)
	Y2 += 0.00000000088*np.cos(0.28956834699 + 7255.5696517344*t)
	Y2 += 0.00000000089*np.cos(0.16636618973 + 11371.7046897582*t)
	Y2 += 0.00000000084*np.cos(4.77208861984 + 124.433415221*t)
	Y2 += 0.00000000080*np.cos(4.02168669717 + 10404.7338123226*t)
	Y2 += 0.00000000078*np.cos(2.06677323042 + 27433.88921587499*t)
	Y2 += 0.00000000096*np.cos(4.52498397749 + 16304.9131300908*t)
	Y2 += 0.00000000075*np.cos(2.28006075482 + 9380.9596727172*t)
	Y2 += 0.00000000094*np.cos(3.73226580941 + 9808.5381846614*t)
	Y2 += 0.00000000078*np.cos(5.39451215886 + 1505.28780909299*t)
	Y2 += 0.00000000074*np.cos(4.85473384301 + 1903.4368125012*t)
	Y2 += 0.00000000074*np.cos(4.08123538694 + 88.865680217*t)
	Y2 += 0.00000000076*np.cos(2.63432357020 + 423.4167971383*t)
	Y2 += 0.00000000082*np.cos(1.64454329520 + 20752.6643624754*t)
	Y2 += 0.00000000072*np.cos(0.22271495096 + 19800.9459562248*t)
	Y2 += 0.00000000073*np.cos(5.78330657332 + 1265.5674786264*t)
	Y2 += 0.00000000071*np.cos(1.48891806144 + 551.031606097*t)
	Y2 += 0.00000000085*np.cos(5.16678830189 + 4193.8088084518*t)
	Y2 += 0.00000000073*np.cos(5.59564088175 + 6660.4494579072*t)
	Y2 += 0.00000000081*np.cos(0.13371582190 + 519.3960243561*t)
	Y2 += 0.00000000080*np.cos(0.85355076616 + 13119.72110282519*t)
	Y2 += 0.00000000068*np.cos(3.39472444791 + 654.1243803156*t)
	Y2 += 0.00000000094*np.cos(3.63777789316 + 7903.073419721*t)
	Y2 += 0.00000000075*np.cos(5.77675923540 + 13517.8701062334*t)
	Y2 += 0.00000000067*np.cos(0.10543129344 + 12935.8515159232*t)
	Y2 += 0.00000000066*np.cos(1.89459556834 + 4845.9002357928*t)
	Y2 += 0.00000000067*np.cos(6.03101420173 + 5244.049239201*t)
	Y2 += 0.00000000069*np.cos(4.43286275856 + 30065.5118402982*t)
	Y2 += 0.00000000065*np.cos(2.27540626241 + 12721.572099417*t)
	Y2 += 0.00000000079*np.cos(3.75639786511 + 9225.539273283*t)
	Y2 += 0.00000000070*np.cos(3.03096982456 + 5628.9564702112*t)
	Y2 += 0.00000000065*np.cos(1.67356767606 + 2631.6226244232*t)
	Y2 += 0.00000000072*np.cos(6.15951862716 + 21.3406410024*t)
	Y2 += 0.00000000065*np.cos(5.74828882968 + 20199.094959633*t)
	Y2 += 0.00000000060*np.cos(3.13717737901 + 191.9584544356*t)
	Y2 += 0.00000000063*np.cos(4.08619875728 + 13362.517017102*t)
	Y2 += 0.00000000057*np.cos(3.94042480034 + 27035.7402124668*t)
	Y2 += 0.00000000080*np.cos(0.78152072903 + 21795.21409161479*t)
	Y2 += 0.00000000064*np.cos(5.47349341844 + 6768.5330579394*t)
	Y2 += 0.00000000065*np.cos(3.55971117777 + 203.0041546995*t)
	Y2 += 0.00000000062*np.cos(1.66193360966 + 5989.0672521728*t)
	Y2 += 0.00000000064*np.cos(1.05451249819 + 539.9859058331*t)
	Y2 += 0.00000000061*np.cos(5.33630384952 + 838.9692877504*t)
	Y2 += 0.00000000063*np.cos(1.04268183515 + 14128.2427712456*t)
	Y2 += 0.00000000059*np.cos(4.57660740933 + 25287.7237993998*t)
	Y2 += 0.00000000057*np.cos(5.46713966805 + 16699.53901514999*t)
	Y2 += 0.00000000058*np.cos(1.21995619161 + 27832.0382192832*t)
	Y2 += 0.00000000062*np.cos(5.98946104494 + 8425.6508378148*t)
	Y2 += 0.00000000057*np.cos(1.09390665574 + 17412.0519357756*t)
	Y2 += 0.00000000058*np.cos(2.47846050317 + 22743.4093795164*t)
	Y2 += 0.00000000061*np.cos(0.00617004446 + 3.1813937377*t)
	Y2 += 0.00000000067*np.cos(3.07992916082 + 2233.473621015*t)
	Y2 += 0.00000000060*np.cos(2.73711498745 + 16062.1845261168*t)
	Y2 += 0.00000000049*np.cos(5.08147417610 + 11128.9760857842*t)
	Y2 += 0.00000000049*np.cos(1.66916016303 + 14421.8316369884*t)
	Y2 += 0.00000000050*np.cos(2.94640653891 + 14584.2982731206*t)
	Y2 += 0.00000000057*np.cos(3.23516782078 + 8982.810669309*t)
	Y2 += 0.00000000050*np.cos(1.30948740291 + 6593.9166488598*t)
	Y2 += 0.00000000065*np.cos(3.77065948973 + 6106.8800550648*t)
	Y2 += 0.00000000050*np.cos(4.44975506045 + 4049.6022289764*t)
	Y2 += 0.00000000047*np.cos(3.46367064388 + 302.164775655*t)
	Y2 += 0.00000000050*np.cos(6.04891397878 + 21265.5231265202*t)
	Y2 += 0.00000000056*np.cos(4.09019049345 + 9499.2598620056*t)
	Y2 += 0.00000000056*np.cos(4.49433446090 + 13362.3823964964*t)
	Y2 += 0.00000000046*np.cos(4.32277657100 + 13149.1506113612*t)
	Y2 += 0.00000000045*np.cos(2.73683504159 + 846.0828347512*t)
	Y2 += 0.00000000045*np.cos(4.42820214061 + 8584.6616659008*t)
	Y2 += 0.00000000045*np.cos(2.31642282675 + 145.6310438715*t)
	Y2 += 0.00000000051*np.cos(5.47523455944 + 19513.9835951042*t)
	Y2 += 0.00000000048*np.cos(1.25598529065 + 23141.5583829246*t)
	Y2 += 0.00000000047*np.cos(0.46146406745 + 7321.1221397136*t)
	Y2 += 0.00000000052*np.cos(3.19972838822 + 4447.7512323846*t)
	Y2 += 0.00000000058*np.cos(0.80841286660 + 18454.601664915*t)
	Y2 += 0.00000000043*np.cos(1.51803973261 + 8799.988713778*t)
	Y2 += 0.00000000043*np.cos(0.61818181916 + 6684.8152820514*t)
	Y2 += 0.00000000046*np.cos(0.99074391135 + 10713.9948813262*t)
	Y2 += 0.00000000047*np.cos(1.74738635330 + 1062.5633239269*t)
	Y2 += 0.00000000042*np.cos(4.67651911489 + 9485.032768004*t)
	Y2 += 0.00000000050*np.cos(5.47854915740 + 8186.5126624926*t)
	Y2 += 0.00000000043*np.cos(0.99542400694 + 6705.1032911474*t)
	Y2 += 0.00000000047*np.cos(3.65366177977 + 12323.4230960088*t)
	Y2 += 0.00000000048*np.cos(0.80944904899 + 10596.1820784342*t)
	Y2 += 0.00000000048*np.cos(1.24802855734 + 16460.33352952499*t)
	Y2 += 0.00000000056*np.cos(1.47449920800 + 6702.000248892*t)
	Y2 += 0.00000000043*np.cos(6.23844434280 + 6709.6740408674*t)
	Y2 += 0.00000000040*np.cos(2.13905875018 + 13553.8979729108*t)
	Y2 += 0.00000000043*np.cos(0.18705839538 + 6677.6344247478*t)
	Y2 += 0.00000000043*np.cos(3.41309849056 + 7373.3824546264*t)
	Y2 += 0.00000000050*np.cos(4.87873224736 + 13892.1406718938*t)
	Y2 += 0.00000000048*np.cos(2.99107811521 + 17654.7805397496*t)
	Y2 += 0.00000000046*np.cos(3.14760491945 + 3.9321532631*t)
	Y2 += 0.00000000038*np.cos(4.13769543996 + 15664.03552270859*t)
	Y2 += 0.00000000038*np.cos(0.87505173893 + 3340.6797370026*t)
	Y2 += 0.00000000038*np.cos(5.98916947033 + 1258.4539316256*t)
	Y2 += 0.00000000044*np.cos(4.36036807845 + 25685.872802808*t)
	Y2 += 0.00000000049*np.cos(2.91514601795 + 6657.3464156518*t)
	Y2 += 0.00000000038*np.cos(2.44636146068 + 6531.661656265*t)
	Y2 += 0.00000000038*np.cos(0.17112950159 + 5099.2655051166*t)
	Y2 += 0.00000000049*np.cos(1.48899492537 + 11610.9101753832*t)
	Y2 += 0.00000000037*np.cos(5.99921778091 + 18606.4989460002*t)
	Y2 += 0.00000000036*np.cos(3.12140441287 + 6158.6474353058*t)
	Y2 += 0.00000000038*np.cos(5.80724401811 + 11614.4332937322*t)
	Y2 += 0.00000000035*np.cos(6.26763450664 + 1692.1656695024*t)
	Y2 += 0.00000000038*np.cos(1.75887029490 + 22324.9050567094*t)
	Y2 += 0.00000000045*np.cos(4.50061115897 + 30376.3526391666*t)
	Y2 += 0.00000000035*np.cos(5.17758129009 + 20735.83216142559*t)
	Y2 += 0.00000000038*np.cos(2.84376159594 + 10213.285546211*t)
	Y2 += 0.00000000046*np.cos(4.74541684756 + 3333.5661900018*t)
	Y2 += 0.00000000046*np.cos(4.51994272467 + 3347.6586633978*t)
	Y2 += 0.00000000043*np.cos(1.88067652530 + 31570.7996493912*t)
	Y2 += 0.00000000042*np.cos(1.70888858696 + 13363.4300278674*t)
	Y2 += 0.00000000033*np.cos(4.03936498647 + 277.0349937414*t)
	Y2 += 0.00000000036*np.cos(3.06997899410 + 26084.0218062162*t)
	Y2 += 0.00000000033*np.cos(0.01439307540 + 4777.7880408984*t)
	Y2 += 0.00000000036*np.cos(6.11394649079 + 24606.13555322*t)
	Y2 += 0.00000000039*np.cos(1.28072614128 + 3340.545116397*t)
	Y2 += 0.00000000037*np.cos(4.59423799549 + 19004.6479494084*t)
	Y2 += 0.00000000030*np.cos(5.15711969407 + 8439.8779318164*t)
	Y2 += 0.00000000030*np.cos(3.29256356524 + 2125.8774073792*t)
	Y2 += 0.00000000035*np.cos(5.96755475967 + 1056.2005364515*t)
	Y2 += 0.00000000031*np.cos(5.25117631915 + 4106.4054911462*t)
	Y2 += 0.00000000031*np.cos(0.87259059949 + 2574.8193622534*t)
	Y2 += 0.00000000031*np.cos(0.98186586659 + 28230.18722269139*t)
	Y2 += 0.00000000028*np.cos(0.10419361626 + 12509.2533250472*t)
	Y2 += 0.00000000029*np.cos(0.50244127169 + 16276.463942623*t)
	Y2 += 0.00000000039*np.cos(4.91039224856 + 1574.8458012822*t)
	Y2 += 0.00000000035*np.cos(0.12378304174 + 3.523118349*t)
	Y2 += 0.00000000030*np.cos(5.37981269791 + 24076.4445881254*t)
	Y2 += 0.00000000034*np.cos(4.37235683472 + 11769.8536931664*t)
	Y2 += 0.00000000028*np.cos(0.59603557040 + 15650.7937503106*t)
	Y2 += 0.00000000036*np.cos(4.84158532799 + 437.6438911399*t)
	Y2 += 0.00000000027*np.cos(6.26048737681 + 11527.1250891924*t)
	Y2 += 0.00000000028*np.cos(1.90040914464 + 1055.4497769261*t)
	Y2 += 0.00000000027*np.cos(1.20265931007 + 20809.4676246452*t)
	Y2 += 0.00000000027*np.cos(4.82118994609 + 17101.2111369072*t)
	Y2 += 0.00000000031*np.cos(1.82502538910 + 1272.6810256272*t)
	Y2 += 0.00000000031*np.cos(3.11642365383 + 19402.7969528166*t)
	Y2 += 0.00000000034*np.cos(0.07900082872 + 28628.3362260996*t)
	Y2 += 0.00000000026*np.cos(1.55966729504 + 21548.9623692918*t)
	Y2 += 0.00000000030*np.cos(5.04089195924 + 11925.2740926006*t)
	Y2 += 0.00000000027*np.cos(4.68673408301 + 1038.0412891868*t)
	Y2 += 0.00000000026*np.cos(4.11559858625 + 13916.0191096416*t)
	Y2 += 0.00000000031*np.cos(3.85373149878 + 6843.6914895318*t)
	Y2 += 0.00000000026*np.cos(5.44448128332 + 13745.3462390224*t)
	Y2 += 0.00000000026*np.cos(2.52360223364 + 16066.0658614748*t)
	Y2 += 0.00000000029*np.cos(0.08375583590 + 1485.9801210652*t)
	Y2 += 0.00000000027*np.cos(6.07872663556 + 618.5566453116*t)
	Y2 += 0.00000000028*np.cos(5.50723877314 + 15265.8865193004*t)
	Y2 += 0.00000000026*np.cos(5.52380000200 + 415.5524906121*t)
	Y2 += 0.00000000025*np.cos(3.73793787048 + 23695.127785767*t)
	Y2 += 0.00000000032*np.cos(4.88973346842 + 20597.2439630412*t)
	Y2 += 0.00000000026*np.cos(6.04122572180 + 12722.5524204852*t)
	Y2 += 0.00000000026*np.cos(3.49078871449 + 430.5303441391*t)
	Y2 += 0.00000000024*np.cos(1.99820614050 + 18.1592472647*t)
	Y2 += 0.00000000025*np.cos(4.91085018100 + 29026.48522950779*t)
	Y2 += 0.00000000023*np.cos(6.16563076611 + 231.4583427027*t)
	Y2 += 0.00000000023*np.cos(5.58098323545 + 831.8557407496*t)
	Y2 += 0.00000000023*np.cos(2.87587036440 + 31172.650645983*t)
	Y2 += 0.00000000022*np.cos(0.59265034235 + 22747.2907148744*t)
	Y2 += 0.00000000026*np.cos(0.10826980097 + 21947.11137270*t)
	Y2 += 0.00000000022*np.cos(5.95022215185 + 16858.4825329332*t)
	Y2 += 0.00000000024*np.cos(5.54824366988 + 3877.4169387952*t)
	Y2 += 0.00000000024*np.cos(0.26293436197 + 23539.7073863328*t)
	Y2 += 0.00000000021*np.cos(4.15712645283 + 447.9388318784*t)
	Y2 += 0.00000000024*np.cos(0.66675947895 + 1368.660252845*t)
	Y2 += 0.00000000020*np.cos(5.70175704295 + 10.2949407385*t)
	Y2 += 0.00000000021*np.cos(5.54933439149 + 1744.4259844152*t)
	Y2 += 0.00000000020*np.cos(0.82610997828 + 33318.8160624582*t)
	return Y2*t*t




def Mars_Y3 (t): # 203 terms of order 3

	Y3 = 0.
	Y3 += 0.00001451417
	Y3 += 0.00000548277*np.cos(0.33360423382 + 6681.2248533996*t)
	Y3 += 0.00000316422*np.cos(0.81609547752 + 10021.8372800994*t)
	Y3 += 0.00000121864*np.cos(4.21281448757 + 3340.6124266998*t)
	Y3 += 0.00000088558*np.cos(1.20276993071 + 13362.4497067992*t)
	Y3 += 0.00000022088*np.cos(4.54598360855 + 206.1855484372*t)
	Y3 += 0.00000021546*np.cos(3.46116671016 + 220.4126424388*t)
	Y3 += 0.00000019088*np.cos(1.56560410465 + 16703.062133499*t)
	Y3 += 0.00000017293*np.cos(1.97503775578 + 3496.032826134*t)
	Y3 += 0.00000017050*np.cos(4.14879086475 + 3185.1920272656*t)
	Y3 += 0.00000016300*np.cos(1.14934178921 + 522.5774180938*t)
	Y3 += 0.00000015923*np.cos(0.06221071687 + 536.8045120954*t)
	Y3 += 0.00000007913*np.cos(4.62482643997 + 3337.0893083508*t)
	Y3 += 0.00000007879*np.cos(1.48801834339 + 3344.1355450488*t)
	Y3 += 0.00000003598*np.cos(1.91971055963 + 20043.6745601988*t)
	Y3 += 0.00000003724*np.cos(2.74263177823 + 3583.3410306738*t)
	Y3 += 0.00000003706*np.cos(3.37952847105 + 3097.88382272579*t)
	Y3 += 0.00000003093*np.cos(2.22514436528 + 426.598190876*t)
	Y3 += 0.00000002859*np.cos(1.93515168613 + 6684.7479717486*t)
	Y3 += 0.00000002568*np.cos(2.47493921494 + 433.7117378768*t)
	Y3 += 0.00000002392*np.cos(4.50849572151 + 6525.8044539654*t)
	Y3 += 0.00000002105*np.cos(3.35595521974 + 227.5261894396*t)
	Y3 += 0.00000002041*np.cos(5.09904909662 + 1059.3819301892*t)
	Y3 += 0.00000002389*np.cos(0.57456638903 + 3894.1818295422*t)
	Y3 += 0.00000002357*np.cos(5.54957319553 + 2787.0430238574*t)
	Y3 += 0.00000002125*np.cos(5.75979360774 + 155.4203994342*t)
	Y3 += 0.00000001378*np.cos(1.27086042787 + 515.463871093*t)
	Y3 += 0.00000001266*np.cos(3.80209162712 + 419.4846438752*t)
	Y3 += 0.00000001301*np.cos(5.46343073746 + 4292.3308329504*t)
	Y3 += 0.00000001265*np.cos(0.65832369520 + 2388.8940204492*t)
	Y3 += 0.00000001160*np.cos(5.63751190575 + 3532.0606928114*t)
	Y3 += 0.00000001144*np.cos(0.47525689968 + 3149.1641605882*t)
	Y3 += 0.00000001140*np.cos(0.36648108968 + 4136.9104335162*t)
	Y3 += 0.00000001363*np.cos(4.63636570705 + 7.1135470008*t)
	Y3 += 0.00000001013*np.cos(4.67704889552 + 199.0720014364*t)
	Y3 += 0.00000001037*np.cos(0.69915801725 + 1066.49547719*t)
	Y3 += 0.00000001033*np.cos(5.74652285578 + 2544.3144198834*t)
	Y3 += 0.00000000964*np.cos(6.22045145850 + 543.9180590962*t)
	Y3 += 0.00000000999*np.cos(0.83738148713 + 3339.6321056316*t)
	Y3 += 0.00000000903*np.cos(4.06289414325 + 4690.4798363586*t)
	Y3 += 0.00000000993*np.cos(5.28170605059 + 3341.592747768*t)
	Y3 += 0.00000000866*np.cos(2.03957182186 + 1990.745017041*t)
	Y3 += 0.00000000780*np.cos(2.29915840069 + 10025.3603984484*t)
	Y3 += 0.00000000795*np.cos(1.68810281929 + 3723.508958923*t)
	Y3 += 0.00000000849*np.cos(1.26670686968 + 639.897286314*t)
	Y3 += 0.00000000781*np.cos(4.42878840709 + 2957.7158944766*t)
	Y3 += 0.00000000678*np.cos(0.79554783130 + 1052.2683831884*t)
	Y3 += 0.00000000626*np.cos(2.26722464083 + 23384.2869868986*t)
	Y3 += 0.00000000718*np.cos(5.26216518522 + 4535.0594369244*t)
	Y3 += 0.00000000630*np.cos(2.66594816549 + 5088.6288397668*t)
	Y3 += 0.00000000619*np.cos(0.87185440690 + 2146.1654164752*t)
	Y3 += 0.00000000591*np.cos(3.41961730120 + 1592.5960136328*t)
	Y3 += 0.00000000450*np.cos(0.35535293147 + 3333.498879699*t)
	Y3 += 0.00000000426*np.cos(1.74413244329 + 3738.761430108*t)
	Y3 += 0.00000000411*np.cos(4.29235402771 + 2942.4634232916*t)
	Y3 += 0.00000000413*np.cos(5.78184272155 + 3347.7259737006*t)
	Y3 += 0.00000000398*np.cos(5.34760414214 + 4399.994356889*t)
	Y3 += 0.00000000372*np.cos(1.83526632397 + 6836.6452528338*t)
	Y3 += 0.00000000489*np.cos(3.10015454635 + 6923.9534573736*t)
	Y3 += 0.00000000356*np.cos(5.91358813779 + 6127.6554505572*t)
	Y3 += 0.00000000399*np.cos(0.93216820629 + 6489.776587288*t)
	Y3 += 0.00000000392*np.cos(4.59101411052 + 14.2270940016*t)
	Y3 += 0.00000000291*np.cos(1.57357745396 + 647.0108333148*t)
	Y3 += 0.00000000280*np.cos(1.14071288830 + 5621.8429232104*t)
	Y3 += 0.00000000357*np.cos(4.86358566470 + 9866.4168806652*t)
	Y3 += 0.00000000293*np.cos(2.25152589204 + 7079.3738568078*t)
	Y3 += 0.00000000338*np.cos(0.77428089130 + 7477.522860216*t)
	Y3 += 0.00000000248*np.cos(5.85725743749 + 1589.0728952838*t)
	Y3 += 0.00000000238*np.cos(3.64302943603 + 6438.4962494256*t)
	Y3 += 0.00000000214*np.cos(5.70028080048 + 6682.2051744678*t)
	Y3 += 0.00000000214*np.cos(2.46865385667 + 440.8252848776*t)
	Y3 += 0.00000000231*np.cos(2.85226310193 + 216.4804891757*t)
	Y3 += 0.00000000220*np.cos(5.18394074276 + 210.1177017003*t)
	Y3 += 0.00000000176*np.cos(2.42829974834 + 5331.3574437408*t)
	Y3 += 0.00000000215*np.cos(1.03281362505 + 5729.506447149*t)
	Y3 += 0.00000000157*np.cos(3.81392312629 + 4933.2084403326*t)
	Y3 += 0.00000000153*np.cos(5.64157477710 + 7875.6718636242*t)
	Y3 += 0.00000000149*np.cos(4.80621690834 + 6298.3283211764*t)
	Y3 += 0.00000000173*np.cos(2.64284412795 + 13365.9728251482*t)
	Y3 += 0.00000000129*np.cos(0.22762324749 + 1045.1548361876*t)
	Y3 += 0.00000000144*np.cos(0.84473821034 + 7234.794256242*t)
	Y3 += 0.00000000156*np.cos(5.74300569044 + 7740.6067835888*t)
	Y3 += 0.00000000142*np.cos(4.53500950354 + 6677.7017350506*t)
	Y3 += 0.00000000123*np.cos(0.51351773704 + 853.196381752*t)
	Y3 += 0.00000000137*np.cos(2.15435863260 + 529.6909650946*t)
	Y3 += 0.00000000092*np.cos(3.22442461302 + 234.6397364404*t)
	Y3 += 0.00000000100*np.cos(1.34247959502 + 9830.3890139878*t)
	Y3 += 0.00000000087*np.cos(4.52965482365 + 103.0927742186*t)
	Y3 += 0.00000000108*np.cos(2.66869708217 + 10419.9862835076*t)
	Y3 += 0.00000000083*np.cos(5.73181738271 + 4929.6853219836*t)
	Y3 += 0.00000000092*np.cos(3.90819414656 + 117.3198682202*t)
	Y3 += 0.00000000084*np.cos(1.14929842944 + 10818.1352869158*t)
	Y3 += 0.00000000085*np.cos(5.57189606315 + 95.9792272178*t)
	Y3 += 0.00000000094*np.cos(2.25901632919 + 213.299095438*t)
	Y3 += 0.00000000099*np.cos(2.61551137742 + 26724.8994135984*t)
	Y3 += 0.00000000076*np.cos(5.73955552897 + 7632.9432596502*t)
	Y3 += 0.00000000075*np.cos(1.30082808866 + 1596.1864422846*t)
	Y3 += 0.00000000084*np.cos(3.85936136739 + 796.2980068164*t)
	Y3 += 0.00000000078*np.cos(4.96547279129 + 110.2063212194*t)
	Y3 += 0.00000000071*np.cos(4.48281367743 + 632.7837393132*t)
	Y3 += 0.00000000076*np.cos(3.40988387446 + 412.3710968744*t)
	Y3 += 0.00000000064*np.cos(2.39566214965 + 316.3918696566*t)
	Y3 += 0.00000000065*np.cos(3.44980702826 + 10264.5658840734*t)
	Y3 += 0.00000000082*np.cos(6.18741349378 + 6688.3384004004*t)
	Y3 += 0.00000000057*np.cos(6.26483235290 + 9468.267877257*t)
	Y3 += 0.00000000057*np.cos(3.22569928236 + 12832.7587417046*t)
	Y3 += 0.00000000056*np.cos(1.44254805098 + 508.3503240922*t)
	Y3 += 0.00000000057*np.cos(1.64237063245 + 7210.9158184942*t)
	Y3 += 0.00000000056*np.cos(2.67589330508 + 9492.1463150048*t)
	Y3 += 0.00000000053*np.cos(5.43922764587 + 398.1490034082*t)
	Y3 += 0.00000000055*np.cos(1.71252125469 + 323.5054166574*t)
	Y3 += 0.00000000051*np.cos(4.25693864007 + 8273.8208670324*t)
	Y3 += 0.00000000048*np.cos(0.40111970766 + 1073.6090241908*t)
	Y3 += 0.00000000050*np.cos(2.51240818090 + 1194.4470102246*t)
	Y3 += 0.00000000050*np.cos(5.21362719324 + 13207.029307365*t)
	Y3 += 0.00000000044*np.cos(5.38376440301 + 12303.06777661*t)
	Y3 += 0.00000000047*np.cos(4.01504004134 + 6681.2075997474*t)
	Y3 += 0.00000000043*np.cos(1.11183270113 + 3870.3033917944*t)
	Y3 += 0.00000000056*np.cos(6.19540120033 + 735.8765135318*t)
	Y3 += 0.00000000047*np.cos(6.04581305192 + 6681.2421070518*t)
	Y3 += 0.00000000046*np.cos(4.32857993306 + 8031.0922630584*t)
	Y3 += 0.00000000042*np.cos(6.13276553266 + 625.6701923124*t)
	Y3 += 0.00000000042*np.cos(0.26848832014 + 10021.8545337516*t)
	Y3 += 0.00000000043*np.cos(6.08984121699 + 10022.8176011676*t)
	Y3 += 0.00000000037*np.cos(4.08178891841 + 1349.8674096588*t)
	Y3 += 0.00000000039*np.cos(5.02961841371 + 942.062061969*t)
	Y3 += 0.00000000042*np.cos(4.52104600477 + 10021.8200264472*t)
	Y3 += 0.00000000035*np.cos(4.87091729626 + 8827.3902698748*t)
	Y3 += 0.00000000036*np.cos(6.10910831551 + 11081.2192102886*t)
	Y3 += 0.00000000036*np.cos(3.01279484364 + 209.3669421749*t)
	Y3 += 0.00000000035*np.cos(1.39789454098 + 9070.1188738488*t)
	Y3 += 0.00000000033*np.cos(5.71992391629 + 15643.6802033098*t)
	Y3 += 0.00000000037*np.cos(4.27106838047 + 10018.3141617504*t)
	Y3 += 0.00000000031*np.cos(0.88356246900 + 1581.959348283*t)
	Y3 += 0.00000000031*np.cos(6.03310463140 + 551.031606097*t)
	Y3 += 0.00000000032*np.cos(4.98300318004 + 217.2312487011*t)
	Y3 += 0.00000000033*np.cos(0.75212348383 + 860.3099287528*t)
	Y3 += 0.00000000031*np.cos(5.50269500344 + 951.7184062506*t)
	Y3 += 0.00000000037*np.cos(1.88071119483 + 7064.1213856228*t)
	Y3 += 0.00000000030*np.cos(4.51763020093 + 70.8494453042*t)
	Y3 += 0.00000000027*np.cos(2.35184788494 + 149.5631971346*t)
	Y3 += 0.00000000028*np.cos(1.91930691377 + 330.6189636582*t)
	Y3 += 0.00000000027*np.cos(0.05305218851 + 2118.7638603784*t)
	Y3 += 0.00000000028*np.cos(0.17790568355 + 78.7137518304*t)
	Y3 += 0.00000000026*np.cos(6.01108995623 + 11216.284290324*t)
	Y3 += 0.00000000027*np.cos(4.37487614145 + 21.3406410024*t)
	Y3 += 0.00000000026*np.cos(1.55191904155 + 10575.4066829418*t)
	Y3 += 0.00000000031*np.cos(0.94089475776 + 6680.2445323314*t)
	Y3 += 0.00000000029*np.cos(5.17540731322 + 949.1756089698*t)
	Y3 += 0.00000000026*np.cos(2.14397962255 + 9623.6882766912*t)
	Y3 += 0.00000000025*np.cos(3.02081007506 + 124.433415221*t)
	Y3 += 0.00000000033*np.cos(2.73570572399 + 223.5940361765*t)
	Y3 += 0.00000000028*np.cos(4.00361922136 + 8432.7643848156*t)
	Y3 += 0.00000000025*np.cos(3.04909888089 + 13760.5987102074*t)
	Y3 += 0.00000000025*np.cos(5.88306502494 + 1169.5882514086*t)
	Y3 += 0.00000000033*np.cos(2.81930816477 + 8671.9698704406*t)
	Y3 += 0.00000000025*np.cos(5.31993147893 + 8962.4553499102*t)
	Y3 += 0.00000000024*np.cos(6.25389986741 + 63.7358983034*t)
	Y3 += 0.00000000024*np.cos(4.81432332838 + 191.9584544356*t)
	Y3 += 0.00000000028*np.cos(0.01012773075 + 728.762966531*t)
	Y3 += 0.00000000030*np.cos(0.63584180471 + 553.5694028424*t)
	Y3 += 0.00000000027*np.cos(2.96898104191 + 16706.585251848*t)
	Y3 += 0.00000000024*np.cos(1.59054971444 + 654.1243803156*t)
	Y3 += 0.00000000026*np.cos(3.11614471488 + 1748.016413067*t)
	Y3 += 0.00000000030*np.cos(4.35202882411 + 309.2783226558*t)
	Y3 += 0.00000000022*np.cos(0.58430377684 + 1155.361157407*t)
	Y3 += 0.00000000024*np.cos(6.03259958940 + 8270.2977486834*t)
	Y3 += 0.00000000025*np.cos(2.12757387882 + 6894.5239488376*t)
	Y3 += 0.00000000020*np.cos(5.79574932921 + 88.865680217*t)
	Y3 += 0.00000000023*np.cos(3.64404039148 + 956.2891559706*t)
	Y3 += 0.00000000019*np.cos(4.74503190924 + 85.8272988312*t)
	Y3 += 0.00000000020*np.cos(5.94324542589 + 3767.2106175758*t)
	Y3 += 0.00000000019*np.cos(5.66498805054 + 73.297125859*t)
	Y3 += 0.00000000020*np.cos(5.16271011972 + 9638.9407478762*t)
	Y3 += 0.00000000018*np.cos(2.62494525957 + 2281.2304965106*t)
	Y3 += 0.00000000025*np.cos(1.94036276937 + 429.7795846137*t)
	Y3 += 0.00000000018*np.cos(0.54862494405 + 6674.1113063988*t)
	Y3 += 0.00000000017*np.cos(1.71122423456 + 13171.0014406876*t)
	Y3 += 0.00000000024*np.cos(1.95947716237 + 519.3960243561*t)
	Y3 += 0.00000000020*np.cos(0.29570924626 + 71.6002048296*t)
	Y3 += 0.00000000019*np.cos(1.19709776876 + 5486.777843175*t)
	Y3 += 0.00000000023*np.cos(0.12198032175 + 10973.55568635*t)
	Y3 += 0.00000000016*np.cos(2.13814265982 + 6681.1575430968*t)
	Y3 += 0.00000000018*np.cos(4.38365354248 + 77.962992305*t)
	Y3 += 0.00000000017*np.cos(5.90592241107 + 242.728603974*t)
	Y3 += 0.00000000019*np.cos(0.71454311343 + 2810.9214616052*t)
	Y3 += 0.00000000016*np.cos(4.70914310164 + 202.2533951741*t)
	Y3 += 0.00000000016*np.cos(2.45822520726 + 10551.528245194*t)
	Y3 += 0.00000000015*np.cos(6.18242140747 + 5459.3762870782*t)
	Y3 += 0.00000000020*np.cos(5.48263393467 + 539.9859058331*t)
	Y3 += 0.00000000016*np.cos(3.45867068386 + 224.3447957019*t)
	Y3 += 0.00000000015*np.cos(5.26771574252 + 302.164775655*t)
	Y3 += 0.00000000016*np.cos(1.72964627298 + 6681.2921637024*t)
	Y3 += 0.00000000014*np.cos(0.28512193614 + 10028.9508271002*t)
	Y3 += 0.00000000014*np.cos(5.35318240788 + 76.2660712756*t)
	Y3 += 0.00000000013*np.cos(1.74759770781 + 10177.2576795336*t)
	Y3 += 0.00000000014*np.cos(5.31424135483 + 191.4482661116*t)
	Y3 += 0.00000000017*np.cos(5.40518600219 + 203.0041546995*t)
	Y3 += 0.00000000011*np.cos(3.87206824630 + 11.0457002639*t)
	Y3 += 0.00000000014*np.cos(4.95938607846 + 12310.1813236108*t)
	Y3 += 0.00000000011*np.cos(3.23427487345 + 8429.2412664666*t)
	Y3 += 0.00000000011*np.cos(1.66323689163 + 382.8965322232*t)
	Y3 += 0.00000000010*np.cos(2.40929335654 + 36.6485629295*t)
	return Y3*t*t*t




def Mars_Y4 (t): # 75 terms of order 4

	Y4 = 0.
	Y4 += 0.00000012136*np.cos(5.53171096923 + 10021.8372800994*t)
	Y4 += 0.00000014623
	Y4 += 0.00000009397*np.cos(5.00023134055 + 6681.2248533996*t)
	Y4 += 0.00000003728*np.cos(2.31744309373 + 3340.6124266998*t)
	Y4 += 0.00000005176*np.cos(5.94994449818 + 13362.4497067992*t)
	Y4 += 0.00000002424*np.cos(3.48212983820 + 3496.032826134*t)
	Y4 += 0.00000002408*np.cos(2.63869857743 + 3185.1920272656*t)
	Y4 += 0.00000002278*np.cos(6.27388903010 + 206.1855484372*t)
	Y4 += 0.00000002245*np.cos(1.70782913671 + 220.4126424388*t)
	Y4 += 0.00000001682*np.cos(2.89988955370 + 522.5774180938*t)
	Y4 += 0.00000001636*np.cos(4.60365551069 + 536.8045120954*t)
	Y4 += 0.00000001495*np.cos(0.04984648713 + 16703.062133499*t)
	Y4 += 0.00000000596*np.cos(4.88542666193 + 3097.88382272579*t)
	Y4 += 0.00000000591*np.cos(1.23338318291 + 3583.3410306738*t)
	Y4 += 0.00000000431*np.cos(1.63508563664 + 227.5261894396*t)
	Y4 += 0.00000000380*np.cos(2.99761351607 + 6525.8044539654*t)
	Y4 += 0.00000000354*np.cos(0.41910666274 + 20043.6745601988*t)
	Y4 += 0.00000000349*np.cos(0.69586528581 + 433.7117378768*t)
	Y4 += 0.00000000291*np.cos(3.00165310731 + 515.463871093*t)
	Y4 += 0.00000000286*np.cos(2.07451183380 + 3894.1818295422*t)
	Y4 += 0.00000000285*np.cos(4.04744586305 + 2787.0430238574*t)
	Y4 += 0.00000000206*np.cos(4.48461122025 + 543.9180590962*t)
	Y4 += 0.00000000204*np.cos(0.11049991144 + 199.0720014364*t)
	Y4 += 0.00000000253*np.cos(6.13013788772 + 3344.1355450488*t)
	Y4 += 0.00000000256*np.cos(6.25236569892 + 3337.0893083508*t)
	Y4 += 0.00000000152*np.cos(0.37871347738 + 6684.7479717486*t)
	Y4 += 0.00000000123*np.cos(5.38340390628 + 1066.49547719*t)
	Y4 += 0.00000000128*np.cos(3.68714753439 + 6836.6452528338*t)
	Y4 += 0.00000000099*np.cos(5.70623543947 + 419.4846438752*t)
	Y4 += 0.00000000117*np.cos(0.28020890432 + 426.598190876*t)
	Y4 += 0.00000000096*np.cos(2.80306869168 + 7.1135470008*t)
	Y4 += 0.00000000088*np.cos(1.59660002748 + 6923.9534573736*t)
	Y4 += 0.00000000071*np.cos(0.77284614163 + 23384.2869868986*t)
	Y4 += 0.00000000061*np.cos(2.82818345895 + 14.2270940016*t)
	Y4 += 0.00000000056*np.cos(0.77975710465 + 10025.3603984484*t)
	Y4 += 0.00000000052*np.cos(3.37268534533 + 1059.3819301892*t)
	Y4 += 0.00000000066*np.cos(2.63263056615 + 1052.2683831884*t)
	Y4 += 0.00000000050*np.cos(0.71576934216 + 440.8252848776*t)
	Y4 += 0.00000000049*np.cos(4.40921783790 + 6127.6554505572*t)
	Y4 += 0.00000000063*np.cos(3.35944487422 + 9866.4168806652*t)
	Y4 += 0.00000000059*np.cos(5.69532892910 + 639.897286314*t)
	Y4 += 0.00000000049*np.cos(6.02940323662 + 647.0108333148*t)
	Y4 += 0.00000000034*np.cos(5.11011261832 + 6438.4962494256*t)
	Y4 += 0.00000000028*np.cos(0.26064157330 + 213.299095438*t)
	Y4 += 0.00000000024*np.cos(1.48209397973 + 234.6397364404*t)
	Y4 += 0.00000000023*np.cos(2.06131193005 + 1045.1548361876*t)
	Y4 += 0.00000000018*np.cos(5.67273705500 + 6489.776587288*t)
	Y4 += 0.00000000014*np.cos(3.25423631036 + 508.3503240922*t)
	Y4 += 0.00000000013*np.cos(4.48491117264 + 1589.0728952838*t)
	Y4 += 0.00000000015*np.cos(5.54124089005 + 7477.522860216*t)
	Y4 += 0.00000000012*np.cos(4.18496035489 + 6682.2051744678*t)
	Y4 += 0.00000000012*np.cos(3.79977496971 + 4399.994356889*t)
	Y4 += 0.00000000013*np.cos(4.15046759496 + 10177.2576795336*t)
	Y4 += 0.00000000014*np.cos(2.25691477586 + 7234.794256242*t)
	Y4 += 0.00000000011*np.cos(1.94853565727 + 10264.5658840734*t)
	Y4 += 0.00000000011*np.cos(5.24080280774 + 412.3710968744*t)
	Y4 += 0.00000000012*np.cos(4.87116288717 + 853.196381752*t)
	Y4 += 0.00000000011*np.cos(0.69449787915 + 7079.3738568078*t)
	Y4 += 0.00000000010*np.cos(5.03146150255 + 1073.6090241908*t)
	Y4 += 0.00000000012*np.cos(5.83137257150 + 5729.506447149*t)
	Y4 += 0.00000000013*np.cos(1.15304574873 + 13365.9728251482*t)
	Y4 += 0.00000000010*np.cos(1.05727005468 + 95.9792272178*t)
	Y4 += 0.00000000010*np.cos(6.06799555020 + 1596.1864422846*t)
	Y4 += 0.00000000010*np.cos(5.71091802020 + 529.6909650946*t)
	Y4 += 0.00000000010*np.cos(0.93942138709 + 5331.3574437408*t)
	Y4 += 0.00000000011*np.cos(1.10451949945 + 26724.8994135984*t)
	Y4 += 0.00000000008*np.cos(3.31794976450 + 6298.3283211764*t)
	Y4 += 0.00000000009*np.cos(2.76384051230 + 21.3406410024*t)
	Y4 += 0.00000000007*np.cos(4.15606002322 + 7875.6718636242*t)
	Y4 += 0.00000000007*np.cos(2.33508864924 + 4933.2084403326*t)
	Y4 += 0.00000000008*np.cos(6.23072779166 + 103.0927742186*t)
	Y4 += 0.00000000010*np.cos(2.05522879011 + 117.3198682202*t)
	Y4 += 0.00000000007*np.cos(3.08813888762 + 110.2063212194*t)
	Y4 += 0.00000000007*np.cos(4.14773765350 + 551.031606097*t)
	Y4 += 0.00000000006*np.cos(6.11652071967 + 654.1243803156*t)
	return Y4*t*t*t*t




def Mars_Y5 (t): # 38 terms of order 5

	Y5 = 0.
	Y5 += 0.00000000353*np.cos(3.94830849426 + 10021.8372800994*t)
	Y5 += 0.00000000274*np.cos(4.99240388971 + 3496.032826134*t)
	Y5 += 0.00000000272*np.cos(1.12308951649 + 3185.1920272656*t)
	Y5 += 0.00000000238*np.cos(4.40065412405 + 13362.4497067992*t)
	Y5 += 0.00000000168*np.cos(1.70751121627 + 206.1855484372*t)
	Y5 += 0.00000000168*np.cos(6.23113008656 + 220.4126424388*t)
	Y5 += 0.00000000151*np.cos(1.08010493938 + 3340.6124266998*t)
	Y5 += 0.00000000126*np.cos(4.78360062168 + 522.5774180938*t)
	Y5 -= 0.00000000170
	Y5 += 0.00000000121*np.cos(2.73213408225 + 536.8045120954*t)
	Y5 += 0.00000000093*np.cos(4.81201084553 + 16703.062133499*t)
	Y5 += 0.00000000077*np.cos(0.11215015675 + 3097.88382272579*t)
	Y5 += 0.00000000077*np.cos(6.01161676189 + 3583.3410306738*t)
	Y5 += 0.00000000065*np.cos(6.17991345652 + 227.5261894396*t)
	Y5 += 0.00000000059*np.cos(2.67997407478 + 6681.2248533996*t)
	Y5 += 0.00000000049*np.cos(1.49385098876 + 6525.8044539654*t)
	Y5 += 0.00000000047*np.cos(4.76645839063 + 515.463871093*t)
	Y5 += 0.00000000038*np.cos(5.19126826175 + 433.7117378768*t)
	Y5 += 0.00000000032*np.cos(2.69880941648 + 543.9180590962*t)
	Y5 += 0.00000000027*np.cos(5.18582314898 + 20043.6745601988*t)
	Y5 += 0.00000000027*np.cos(1.88223142168 + 199.0720014364*t)
	Y5 += 0.00000000026*np.cos(3.60298036992 + 3894.1818295422*t)
	Y5 += 0.00000000026*np.cos(2.52078654872 + 2787.0430238574*t)
	Y5 += 0.00000000013*np.cos(5.15994044385 + 6836.6452528338*t)
	Y5 += 0.00000000011*np.cos(1.18187733048 + 14.2270940016*t)
	Y5 += 0.00000000011*np.cos(3.76420251280 + 1066.49547719*t)
	Y5 += 0.00000000013*np.cos(0.09000961930 + 6923.9534573736*t)
	Y5 += 0.00000000010*np.cos(5.22684912304 + 440.8252848776*t)
	Y5 += 0.00000000006*np.cos(5.09874289885 + 6684.7479717486*t)
	Y5 += 0.00000000007*np.cos(1.85064036647 + 9866.4168806652*t)
	Y5 += 0.00000000005*np.cos(2.89632661954 + 6127.6554505572*t)
	Y5 += 0.00000000007*np.cos(4.23388483049 + 647.0108333148*t)
	Y5 += 0.00000000005*np.cos(5.55804387830 + 23384.2869868986*t)
	Y5 += 0.00000000004*np.cos(0.31530831962 + 6438.4962494256*t)
	Y5 += 0.00000000004*np.cos(4.91327178242 + 1052.2683831884*t)
	Y5 += 0.00000000004*np.cos(2.02140363828 + 419.4846438752*t)
	Y5 += 0.00000000003*np.cos(3.88823715659 + 639.897286314*t)
	Y5 += 0.00000000003*np.cos(6.08770400766 + 234.6397364404*t)
	return Y5*t*t*t*t*t




def Mars_Z0 (t): # 404 terms of order 0

	Z0 = 0.
	Z0 += 0.04901205639*np.cos(3.76712324293 + 3340.6124266998*t)
	Z0 += 0.00659516885
	Z0 += 0.00228333831*np.cos(4.10544022266 + 6681.2248533996*t)
	Z0 += 0.00015958402*np.cos(4.44367058261 + 10021.8372800994*t)
	Z0 += 0.00011803129*np.cos(0.45922638235 + 213.299095438*t)
	Z0 += 0.00011012894*np.cos(0.39307428990 + 529.6909650946*t)
	Z0 += 0.00004801930*np.cos(4.58262362363 + 38.1330356378*t)
	Z0 += 0.00001321976*np.cos(4.78186604114 + 13362.4497067992*t)
	Z0 += 0.00001130585*np.cos(5.75854380515 + 74.7815985673*t)
	Z0 += 0.00000679660*np.cos(5.65109977813 + 3337.0893083508*t)
	Z0 += 0.00000679219*np.cos(5.02527030899 + 3344.1355450488*t)
	Z0 += 0.00000531140*np.cos(3.86748390045 + 2281.2304965106*t)
	Z0 += 0.00000443650*np.cos(1.58511946273 + 1059.3819301892*t)
	Z0 += 0.00000301376*np.cos(5.99676838171 + 426.598190876*t)
	Z0 += 0.00000218762*np.cos(1.18094849702 + 3340.5951730476*t)
	Z0 += 0.00000218761*np.cos(3.21172012852 + 3340.629680352*t)
	Z0 += 0.00000152333*np.cos(6.08109566130 + 6151.533888305*t)
	Z0 += 0.00000146631*np.cos(5.09927022855 + 398.1490034082*t)
	Z0 += 0.00000152443*np.cos(2.13254535850 + 5621.8429232104*t)
	Z0 += 0.00000120328*np.cos(5.12010663983 + 16703.062133499*t)
	Z0 += 0.00000126016*np.cos(3.67803475473 + 796.2980068164*t)
	Z0 += 0.00000116766*np.cos(4.86913583010 + 2942.4634232916*t)
	Z0 += 0.00000112925*np.cos(5.76548397681 + 3738.761430108*t)
	Z0 += 0.00000094338*np.cos(3.70945651427 + 206.1855484372*t)
	Z0 += 0.00000081761*np.cos(0.33704188871 + 220.4126424388*t)
	Z0 += 0.00000074290*np.cos(2.43508234938 + 8962.4553499102*t)
	Z0 += 0.00000071989*np.cos(5.54217679275 + 3340.545116397*t)
	Z0 += 0.00000068644*np.cos(5.54532471548 + 6283.0758499914*t)
	Z0 += 0.00000071987*np.cos(5.13368040597 + 3340.6797370026*t)
	Z0 += 0.00000063219*np.cos(5.36590967098 + 6684.7479717486*t)
	Z0 += 0.00000075858*np.cos(4.51645136094 + 3149.1641605882*t)
	Z0 += 0.00000063502*np.cos(4.16748385740 + 1751.539531416*t)
	Z0 += 0.00000063828*np.cos(5.98786823499 + 6677.7017350506*t)
	Z0 += 0.00000059355*np.cos(0.72879549961 + 5884.9268465832*t)
	Z0 += 0.00000050332*np.cos(1.96033823263 + 2810.9214616052*t)
	Z0 += 0.00000049616*np.cos(2.11296039316 + 1589.0728952838*t)
	Z0 += 0.00000051292*np.cos(2.64769056433 + 2914.0142358238*t)
	Z0 += 0.00000044615*np.cos(5.88956380171 + 3532.0606928114*t)
	Z0 += 0.00000045526*np.cos(2.27415776311 + 1194.4470102246*t)
	Z0 += 0.00000045098*np.cos(4.08200115074 + 4136.9104335162*t)
	Z0 += 0.00000040233*np.cos(0.43178323417 + 522.5774180938*t)
	Z0 += 0.00000033148*np.cos(2.01609063016 + 5486.777843175*t)
	Z0 += 0.00000030856*np.cos(3.41662901377 + 536.8045120954*t)
	Z0 += 0.00000033968*np.cos(0.46851841759 + 2544.3144198834*t)
	Z0 += 0.00000027697*np.cos(5.54319865094 + 191.4482661116*t)
	Z0 += 0.00000030473*np.cos(4.98782051819 + 3870.3033917944*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000025107*np.cos(1.90049463354 + 149.5631971346*t)
	Z0 += 0.00000023112*np.cos(1.07197693861 + 7.1135470008*t)
	Z0 += 0.00000022262*np.cos(0.19101027284 + 9492.1463150048*t)
	Z0 += 0.00000021566*np.cos(2.45059201892 + 3333.498879699*t)
	Z0 += 0.00000019445*np.cos(3.36733718353 + 5088.6288397668*t)
	Z0 += 0.00000022415*np.cos(2.80792353370 + 3496.032826134*t)
	Z0 += 0.00000019109*np.cos(0.86825937304 + 1592.5960136328*t)
	Z0 += 0.00000024101*np.cos(2.57371991774 + 4399.994356889*t)
	Z0 += 0.00000020382*np.cos(3.55004736979 + 6681.2421070518*t)
	Z0 += 0.00000019409*np.cos(3.19792759578 + 76.2660712756*t)
	Z0 += 0.00000019188*np.cos(1.51640815942 + 3185.1920272656*t)
	Z0 += 0.00000020382*np.cos(1.51927573830 + 6681.2075997474*t)
	Z0 += 0.00000014700*np.cos(1.56227576202 + 110.2063212194*t)
	Z0 += 0.00000013488*np.cos(2.86475891587 + 3341.592747768*t)
	Z0 += 0.00000013492*np.cos(1.52791184830 + 3339.6321056316*t)
	Z0 += 0.00000011777*np.cos(4.79772279974 + 3553.9115221378*t)
	Z0 += 0.00000012741*np.cos(6.05559229749 + 7079.3738568078*t)
	Z0 += 0.00000011907*np.cos(1.65033513222 + 6254.6266625236*t)
	Z0 += 0.00000011511*np.cos(2.75835305381 + 12303.06777661*t)
	Z0 += 0.00000011629*np.cos(5.45832237690 + 20043.6745601988*t)
	Z0 += 0.00000010504*np.cos(2.26694979515 + 316.3918696566*t)
	Z0 += 0.00000010048*np.cos(2.70644507479 + 419.4846438752*t)
	Z0 += 0.00000011780*np.cos(4.75307421274 + 4690.4798363586*t)
	Z0 += 0.00000008746*np.cos(1.07533372055 + 9225.539273283*t)
	Z0 += 0.00000009300*np.cos(5.74426412364 + 1990.745017041*t)
	Z0 += 0.00000009010*np.cos(5.91031650213 + 9623.6882766912*t)
	Z0 += 0.00000009437*np.cos(5.42630453280 + 639.897286314*t)
	Z0 += 0.00000009099*np.cos(4.14734627288 + 3127.3133312618*t)
	Z0 += 0.00000008399*np.cos(2.65942772730 + 4535.0594369244*t)
	Z0 += 0.00000011208*np.cos(2.64763421097 + 8432.7643848156*t)
	Z0 += 0.00000008425*np.cos(5.67806346712 + 6467.9257579616*t)
	Z0 += 0.00000007879*np.cos(6.16301318418 + 4292.3308329504*t)
	Z0 += 0.00000008040*np.cos(3.77010741170 + 73.297125859*t)
	Z0 += 0.00000006986*np.cos(1.31599425886 + 3894.1818295422*t)
	Z0 += 0.00000007013*np.cos(4.83160093113 + 6489.776587288*t)
	Z0 += 0.00000006707*np.cos(5.47201048198 + 6681.2921637024*t)
	Z0 += 0.00000008732*np.cos(5.94456391651 + 5092.1519581158*t)
	Z0 += 0.00000006427*np.cos(6.10941025846 + 4562.4609930212*t)
	Z0 += 0.00000008234*np.cos(3.68630710748 + 2700.7151403858*t)
	Z0 += 0.00000007214*np.cos(1.11647593098 + 3319.8370312074*t)
	Z0 += 0.00000006128*np.cos(4.51741845562 + 1221.8485663214*t)
	Z0 += 0.00000006627*np.cos(5.70488581385 + 10025.3603984484*t)
	Z0 += 0.00000006712*np.cos(0.04223488375 + 10018.3141617504*t)
	Z0 += 0.00000007157*np.cos(3.27593626835 + 3361.3878221922*t)
	Z0 += 0.00000005667*np.cos(1.84572324920 + 2957.7158944766*t)
	Z0 += 0.00000006707*np.cos(5.88050686882 + 6681.1575430968*t)
	Z0 += 0.00000005096*np.cos(2.58887167453 + 103.0927742186*t)
	Z0 += 0.00000004916*np.cos(2.93046960145 + 2787.0430238574*t)
	Z0 += 0.00000004722*np.cos(2.41041908083 + 3344.2028553516*t)
	Z0 += 0.00000004742*np.cos(1.97920373919 + 3337.021998048*t)
	Z0 += 0.00000004597*np.cos(4.41002877977 + 7477.522860216*t)
	Z0 += 0.00000005894*np.cos(2.37544303737 + 2118.7638603784*t)
	Z0 += 0.00000005433*np.cos(4.33760555117 + 2388.8940204492*t)
	Z0 += 0.00000004194*np.cos(5.86775522337 + 433.7117378768*t)
	Z0 += 0.00000004363*np.cos(2.24320799714 + 11773.3768115154*t)
	Z0 += 0.00000004127*np.cos(2.04411881734 + 2146.1654164752*t)
	Z0 += 0.00000003613*np.cos(3.61081984797 + 8429.2412664666*t)
	Z0 += 0.00000003478*np.cos(2.64660968975 + 4929.6853219836*t)
	Z0 += 0.00000003714*np.cos(1.76418965622 + 382.8965322232*t)
	Z0 += 0.00000003331*np.cos(6.17753431621 + 7210.9158184942*t)
	Z0 += 0.00000003580*np.cos(3.90470994536 + 7903.073419721*t)
	Z0 += 0.00000003111*np.cos(2.03406809335 + 155.4203994342*t)
	Z0 += 0.00000003351*np.cos(0.47359753009 + 3475.6775067352*t)
	Z0 += 0.00000003948*np.cos(0.33532528162 + 1.4844727083*t)
	Z0 += 0.00000003025*np.cos(1.91083270977 + 9595.2390892234*t)
	Z0 += 0.00000003493*np.cos(2.25666784516 + 3723.508958923*t)
	Z0 += 0.00000003509*np.cos(3.91758478184 + 3205.5473466644*t)
	Z0 += 0.00000003007*np.cos(0.81247341820 + 2274.1169495098*t)
	Z0 += 0.00000002982*np.cos(3.68257004005 + 2288.3440435114*t)
	Z0 += 0.00000002699*np.cos(5.36817159012 + 632.7837393132*t)
	Z0 += 0.00000002567*np.cos(4.96092533051 + 8031.0922630584*t)
	Z0 += 0.00000002649*np.cos(2.98742483865 + 3767.2106175758*t)
	Z0 += 0.00000002559*np.cos(4.63571839354 + 1066.49547719*t)
	Z0 += 0.00000002322*np.cos(1.23249592342 + 4933.2084403326*t)
	Z0 += 0.00000002733*np.cos(0.51395284395 + 12832.7587417046*t)
	Z0 += 0.00000002136*np.cos(3.88842223350 + 10021.8545337516*t)
	Z0 += 0.00000002136*np.cos(1.85765060200 + 10021.8200264472*t)
	Z0 += 0.00000002772*np.cos(2.43968968772 + 8827.3902698748*t)
	Z0 += 0.00000002162*np.cos(3.01828376513 + 6041.3275670856*t)
	Z0 += 0.00000002091*np.cos(3.80489059877 + 6872.6731195112*t)
	Z0 += 0.00000002233*np.cos(2.94758000961 + 7740.6067835888*t)
	Z0 += 0.00000002614*np.cos(4.45694073527 + 6674.1113063988*t)
	Z0 += 0.00000002255*np.cos(6.11824868545 + 1162.4747044078*t)
	Z0 += 0.00000002513*np.cos(0.10458597053 + 3583.3410306738*t)
	Z0 += 0.00000001861*np.cos(4.13522134185 + 1349.8674096588*t)
	Z0 += 0.00000001728*np.cos(2.95584201533 + 12168.0026965746*t)
	Z0 += 0.00000001783*np.cos(3.14608208810 + 846.0828347512*t)
	Z0 += 0.00000001840*np.cos(0.20978853293 + 4032.7700279266*t)
	Z0 += 0.00000001669*np.cos(5.50497155791 + 951.7184062506*t)
	Z0 += 0.00000001566*np.cos(1.99768150464 + 202.2533951741*t)
	Z0 += 0.00000001911*np.cos(2.94107630035 + 1748.016413067*t)
	Z0 += 0.00000001442*np.cos(1.87731237490 + 3077.528503327*t)
	Z0 += 0.00000001589*np.cos(1.73601297200 + 3369.0616141676*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001379*np.cos(0.09013023527 + 10419.9862835076*t)
	Z0 += 0.00000001392*np.cos(0.27504136647 + 3325.3599555148*t)
	Z0 += 0.00000001580*np.cos(4.48665176300 + 3.523118349*t)
	Z0 += 0.00000001766*np.cos(1.85661467458 + 6525.8044539654*t)
	Z0 += 0.00000001292*np.cos(2.51829136056 + 3603.6963500726*t)
	Z0 += 0.00000001297*np.cos(5.48481699939 + 11371.7046897582*t)
	Z0 += 0.00000001613*np.cos(0.62341029242 + 553.5694028424*t)
	Z0 += 0.00000001384*np.cos(4.11719633248 + 3355.8648978848*t)
	Z0 += 0.00000001261*np.cos(1.86730474733 + 6680.2445323314*t)
	Z0 += 0.00000001610*np.cos(2.65671079949 + 3312.163239232*t)
	Z0 += 0.00000001274*np.cos(0.55350948232 + 3191.0492295652*t)
	Z0 += 0.00000001704*np.cos(4.50757815133 + 3097.88382272579*t)
	Z0 += 0.00000001460*np.cos(0.04101454115 + 7632.9432596502*t)
	Z0 += 0.00000001216*np.cos(2.98306649362 + 6836.6452528338*t)
	Z0 += 0.00000001161*np.cos(4.60505013406 + 1648.4467571974*t)
	Z0 += 0.00000001579*np.cos(3.09053337023 + 15643.6802033098*t)
	Z0 += 0.00000001137*np.cos(6.15183461939 + 2.9689454166*t)
	Z0 += 0.00000001118*np.cos(6.05429252683 + 9808.5381846614*t)
	Z0 += 0.00000001376*np.cos(0.81116680514 + 3503.079062832*t)
	Z0 += 0.00000001226*np.cos(4.21385605828 + 949.1756089698*t)
	Z0 += 0.00000001320*np.cos(3.23812050004 + 3347.7259737006*t)
	Z0 += 0.00000001419*np.cos(0.32932000507 + 3264.3463554242*t)
	Z0 += 0.00000001028*np.cos(0.21025596115 + 227.5261894396*t)
	Z0 += 0.00000001103*np.cos(5.79565205719 + 6894.5239488376*t)
	Z0 += 0.00000001257*np.cos(3.20326473314 + 6682.2051744678*t)
	Z0 += 0.00000001004*np.cos(4.71380449727 + 2487.4160449478*t)
	Z0 += 0.00000001014*np.cos(0.55883970461 + 10973.55568635*t)
	Z0 += 0.00000000950*np.cos(2.98201757904 + 3178.1457905676*t)
	Z0 += 0.00000001045*np.cos(0.86029132561 + 1052.2683831884*t)
	Z0 += 0.00000000958*np.cos(1.45300862079 + 12566.1516999828*t)
	Z0 += 0.00000000964*np.cos(5.98684645223 + 242.728603974*t)
	Z0 += 0.00000000925*np.cos(5.46131905325 + 5614.7293762096*t)
	Z0 += 0.00000000935*np.cos(4.94933845312 + 1758.6530784168*t)
	Z0 += 0.00000000983*np.cos(2.64122033139 + 2648.454825473*t)
	Z0 += 0.00000001171*np.cos(5.79646129252 + 23384.2869868986*t)
	Z0 += 0.00000000882*np.cos(0.48413591726 + 209.3669421749*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000000853*np.cos(4.81086337808 + 15110.4661198662*t)
	Z0 += 0.00000000901*np.cos(5.67928823390 + 2921.1277828246*t)
	Z0 += 0.00000001125*np.cos(6.27341969245 + 12964.300703391*t)
	Z0 += 0.00000000844*np.cos(2.97906384874 + 7875.6718636242*t)
	Z0 += 0.00000000811*np.cos(0.19379046862 + 3346.1353510072*t)
	Z0 += 0.00000000812*np.cos(4.19639785587 + 3335.0895023924*t)
	Z0 += 0.00000000909*np.cos(3.41244701373 + 10213.285546211*t)
	Z0 += 0.00000000774*np.cos(1.38696439205 + 7234.794256242*t)
	Z0 += 0.00000000864*np.cos(2.92013522974 + 148.0787244263*t)
	Z0 += 0.00000000742*np.cos(0.37908087243 + 13358.9265884502*t)
	Z0 += 0.00000000846*np.cos(3.60649450344 + 217.2312487011*t)
	Z0 += 0.00000000732*np.cos(5.16784948008 + 9830.3890139878*t)
	Z0 += 0.00000000946*np.cos(1.88936722079 + 5628.9564702112*t)
	Z0 += 0.00000000820*np.cos(4.37824637524 + 7373.3824546264*t)
	Z0 += 0.00000000779*np.cos(3.77257775192 + 63.7358983034*t)
	Z0 += 0.00000000676*np.cos(1.45080754975 + 1692.1656695024*t)
	Z0 += 0.00000000831*np.cos(6.20016431490 + 323.5054166574*t)
	Z0 += 0.00000000785*np.cos(4.59990880607 + 6438.4962494256*t)
	Z0 += 0.00000000668*np.cos(3.61130377946 + 6702.000248892*t)
	Z0 += 0.00000000655*np.cos(2.60002275981 + 11243.6858464208*t)
	Z0 += 0.00000000760*np.cos(3.03501058836 + 3360.96774609859*t)
	Z0 += 0.00000000764*np.cos(4.37581912554 + 11769.8536931664*t)
	Z0 += 0.00000000704*np.cos(5.80908299008 + 10021.9045904022*t)
	Z0 += 0.00000000840*np.cos(6.11799044851 + 5331.3574437408*t)
	Z0 += 0.00000000629*np.cos(1.09880202633 + 14314.1681130498*t)
	Z0 += 0.00000000648*np.cos(1.31807916461 + 1581.959348283*t)
	Z0 += 0.00000000704*np.cos(6.21757937692 + 10021.7699697966*t)
	Z0 += 0.00000000646*np.cos(3.01919436853 + 9381.9399937854*t)
	Z0 += 0.00000000612*np.cos(3.40750819704 + 10713.9948813262*t)
	Z0 += 0.00000000732*np.cos(6.04237219046 + 13365.9728251482*t)
	Z0 += 0.00000000771*np.cos(2.47252701375 + 15113.9892382152*t)
	Z0 += 0.00000000621*np.cos(5.85690842904 + 3351.2490920496*t)
	Z0 += 0.00000000687*np.cos(2.88181717922 + 71.8126531507*t)
	Z0 += 0.00000000767*np.cos(1.35441792357 + 3320.257107301*t)
	Z0 += 0.00000000692*np.cos(1.46718257115 + 6660.4494579072*t)
	Z0 += 0.00000000669*np.cos(0.51352618116 + 7064.1213856228*t)
	Z0 += 0.00000000600*np.cos(5.04547651146 + 692.1576012268*t)
	Z0 += 0.00000000623*np.cos(4.81491846507 + 3329.97576135*t)
	Z0 += 0.00000000661*np.cos(2.79286199869 + 2906.900688823*t)
	Z0 += 0.00000000559*np.cos(1.77674120898 + 742.9900605326*t)
	Z0 += 0.00000000570*np.cos(4.61307898923 + 3074.005384978*t)
	Z0 += 0.00000000524*np.cos(6.05770135572 + 3607.2194684216*t)
	Z0 += 0.00000000516*np.cos(2.43629649577 + 13916.0191096416*t)
	Z0 += 0.00000000507*np.cos(2.02939502894 + 3333.5661900018*t)
	Z0 += 0.00000000605*np.cos(1.93804011864 + 10575.4066829418*t)
	Z0 += 0.00000000479*np.cos(3.05388055553 + 224.3447957019*t)
	Z0 += 0.00000000488*np.cos(4.67812564849 + 5729.506447149*t)
	Z0 += 0.00000000465*np.cos(5.56224766580 + 8955.3418029094*t)
	Z0 += 0.00000000467*np.cos(3.02812406788 + 6144.4203413042*t)
	Z0 += 0.00000000459*np.cos(3.95268976842 + 77.7505439839*t)
	Z0 += 0.00000000524*np.cos(2.17529898104 + 6298.3283211764*t)
	Z0 += 0.00000000575*np.cos(3.85836565065 + 199.0720014364*t)
	Z0 += 0.00000000449*np.cos(4.27905913954 + 6546.1597733642*t)
	Z0 += 0.00000000442*np.cos(2.21279250958 + 3347.6586633978*t)
	Z0 += 0.00000000442*np.cos(0.35835774849 + 18052.9295431578*t)
	Z0 += 0.00000000452*np.cos(4.74868579573 + 5828.0284716476*t)
	Z0 += 0.00000000444*np.cos(2.31126753824 + 6677.6344247478*t)
	Z0 += 0.00000000457*np.cos(2.76482172070 + 5459.3762870782*t)
	Z0 += 0.00000000452*np.cos(2.18667537557 + 12935.8515159232*t)
	Z0 += 0.00000000440*np.cos(2.28024553720 + 8969.568896911*t)
	Z0 += 0.00000000439*np.cos(3.26823913184 + 6127.6554505572*t)
	Z0 += 0.00000000421*np.cos(5.42036909165 + 11.0457002639*t)
	Z0 += 0.00000000450*np.cos(4.97549718782 + 6531.661656265*t)
	Z0 += 0.00000000467*np.cos(5.81074791371 + 6158.6474353058*t)
	Z0 += 0.00000000430*np.cos(4.78793443738 + 3863.1898447936*t)
	Z0 += 0.00000000409*np.cos(1.99836071636 + 3980.5097130138*t)
	Z0 += 0.00000000399*np.cos(4.74255258433 + 10818.1352869158*t)
	Z0 += 0.00000000453*np.cos(6.26634249241 + 14712.317116458*t)
	Z0 += 0.00000000437*np.cos(2.74634913436 + 6684.8152820514*t)
	Z0 += 0.00000000398*np.cos(5.55088274653 + 853.196381752*t)
	Z0 += 0.00000000534*np.cos(0.54255389653 + 515.463871093*t)
	Z0 += 0.00000000400*np.cos(2.77865299135 + 4989.0591838972*t)
	Z0 += 0.00000000506*np.cos(1.18461823734 + 1744.4259844152*t)
	Z0 += 0.00000000438*np.cos(5.18436075568 + 1596.1864422846*t)
	Z0 += 0.00000000385*np.cos(0.88914902748 + 151.0476698429*t)
	Z0 += 0.00000000380*np.cos(4.97818849120 + 10014.7237330986*t)
	Z0 += 0.00000000371*np.cos(3.33405966002 + 10177.2576795336*t)
	Z0 += 0.00000000429*np.cos(1.40544578224 + 14.2270940016*t)
	Z0 += 0.00000000361*np.cos(5.24088703687 + 2178.137722292*t)
	Z0 += 0.00000000400*np.cos(1.62063267593 + 14584.2982731206*t)
	Z0 += 0.00000000403*np.cos(1.82423390219 + 3399.9862886134*t)
	Z0 += 0.00000000410*np.cos(4.54392931383 + 3344.4937620578*t)
	Z0 += 0.00000000418*np.cos(4.88395861492 + 3443.7052009184*t)
	Z0 += 0.00000000341*np.cos(3.76526341028 + 6688.3384004004*t)
	Z0 += 0.00000000387*np.cos(2.20624213901 + 3281.2385647862*t)
	Z0 += 0.00000000328*np.cos(1.60706573380 + 3546.797975137*t)
	Z0 += 0.00000000346*np.cos(5.93876607715 + 3364.4908644476*t)
	Z0 += 0.00000000427*np.cos(0.42766619939 + 10551.528245194*t)
	Z0 += 0.00000000333*np.cos(2.97391198780 + 17256.6315363414*t)
	Z0 += 0.00000000321*np.cos(6.22426544685 + 956.2891559706*t)
	Z0 += 0.00000000351*np.cos(0.89374033083 + 16173.3711684044*t)
	Z0 += 0.00000000319*np.cos(1.05944718196 + 117.3198682202*t)
	Z0 += 0.00000000387*np.cos(5.50555914948 + 3973.396166013*t)
	Z0 += 0.00000000410*np.cos(6.13790219128 + 3336.7310913418*t)
	Z0 += 0.00000000349*np.cos(4.74282066857 + 3316.733988952*t)
	Z0 += 0.00000000354*np.cos(5.82762457026 + 1478.8665740644*t)
	Z0 += 0.00000000312*np.cos(6.24838646568 + 216.4804891757*t)
	Z0 += 0.00000000290*np.cos(5.11770361174 + 647.0108333148*t)
	Z0 += 0.00000000284*np.cos(2.49529211057 + 6784.3176276182*t)
	Z0 += 0.00000000338*np.cos(3.01411006339 + 8270.2977486834*t)
	Z0 += 0.00000000279*np.cos(0.15295518242 + 135.0650800354*t)
	Z0 += 0.00000000290*np.cos(4.30595018325 + 16858.4825329332*t)
	Z0 += 0.00000000314*np.cos(4.10256974515 + 210.1177017003*t)
	Z0 += 0.00000000277*np.cos(3.21266616465 + 8329.671610597*t)
	Z0 += 0.00000000303*np.cos(4.39325865345 + 2818.035008606*t)
	Z0 += 0.00000000302*np.cos(5.76020823903 + 2384.3232707292*t)
	Z0 += 0.00000000360*np.cos(0.81576341528 + 6816.289933435*t)
	Z0 += 0.00000000287*np.cos(5.89677690833 + 3340.19235060619*t)
	Z0 += 0.00000000296*np.cos(1.59458223926 + 309.2783226558*t)
	Z0 += 0.00000000300*np.cos(3.61030466166 + 3304.5845600224*t)
	Z0 += 0.00000000264*np.cos(5.45859266580 + 6604.958782124*t)
	Z0 += 0.00000000330*np.cos(3.81421832191 + 13517.8701062334*t)
	Z0 += 0.00000000298*np.cos(5.25958947836 + 415.5524906121*t)
	Z0 += 0.00000000276*np.cos(3.54425558449 + 525.7588118315*t)
	Z0 += 0.00000000287*np.cos(4.78503735880 + 3341.0325027934*t)
	Z0 += 0.00000000343*np.cos(1.02525479822 + 3230.4061054804*t)
	Z0 += 0.00000000246*np.cos(2.64795288862 + 3304.0070613956*t)
	Z0 += 0.00000000310*np.cos(1.76905174573 + 10404.7338123226*t)
	Z0 += 0.00000000317*np.cos(3.85456671343 + 85.8272988312*t)
	Z0 += 0.00000000241*np.cos(3.33235757149 + 11081.2192102886*t)
	Z0 += 0.00000000277*np.cos(0.31958662741 + 138.5174968707*t)
	Z0 += 0.00000000245*np.cos(1.00254307216 + 3209.0704650134*t)
	Z0 += 0.00000000295*np.cos(0.78856158130 + 3376.6402933772*t)
	Z0 += 0.00000000247*np.cos(4.74687572675 + 9779.1086761254*t)
	Z0 += 0.00000000241*np.cos(1.74832761256 + 3377.217792004*t)
	Z0 += 0.00000000241*np.cos(3.32660302434 + 543.9180590962*t)
	Z0 += 0.00000000264*np.cos(1.82146900201 + 17654.7805397496*t)
	Z0 += 0.00000000274*np.cos(2.60650323538 + 3657.0042963564*t)
	Z0 += 0.00000000238*np.cos(0.43806562773 + 6923.9534573736*t)
	Z0 += 0.00000000227*np.cos(2.88048108848 + 3415.3940252671*t)
	Z0 += 0.00000000300*np.cos(0.70241789966 + 3134.4268782626*t)
	Z0 += 0.00000000237*np.cos(2.19737291235 + 13362.432453147*t)
	Z0 += 0.00000000223*np.cos(4.77142901401 + 1375.7737998458*t)
	Z0 += 0.00000000220*np.cos(1.43836209680 + 6606.4432548323*t)
	Z0 += 0.00000000222*np.cos(3.39627559384 + 3472.1543883862*t)
	Z0 += 0.00000000217*np.cos(2.18530503085 + 20995.3929664494*t)
	Z0 += 0.00000000254*np.cos(2.93819031378 + 5085.038411115*t)
	Z0 += 0.00000000236*np.cos(4.23042638023 + 13362.4669604514*t)
	Z0 += 0.00000000242*np.cos(0.41755696147 + 1861.7458526354*t)
	Z0 += 0.00000000285*np.cos(0.10171887281 + 17085.9586657222*t)
	Z0 += 0.00000000218*np.cos(0.33151885058 + 16304.9131300908*t)
	Z0 += 0.00000000207*np.cos(3.60591178333 + 7107.8230442756*t)
	Z0 += 0.00000000196*np.cos(3.34505476799 + 8439.8779318164*t)
	Z0 += 0.00000000192*np.cos(5.08475415071 + 13119.72110282519*t)
	Z0 += 0.00000000198*np.cos(2.49240240273 + 95.9792272178*t)
	Z0 += 0.00000000269*np.cos(0.19698472851 + 3024.2205570432*t)
	Z0 += 0.00000000186*np.cos(4.39437140248 + 277.0349937414*t)
	Z0 += 0.00000000186*np.cos(1.75940958561 + 2221.856634597*t)
	Z0 += 0.00000000194*np.cos(3.41534671398 + 18984.2926300096*t)
	Z0 += 0.00000000208*np.cos(3.02738720944 + 3511.285297319*t)
	Z0 += 0.00000000204*np.cos(6.00463791835 + 162.4666361322*t)
	Z0 += 0.00000000183*np.cos(3.62962279261 + 9168.6408983474*t)
	Z0 += 0.00000000175*np.cos(4.04165128738 + 3760.097070575*t)
	Z0 += 0.00000000174*np.cos(4.51117927233 + 23539.7073863328*t)
	Z0 += 0.00000000193*np.cos(5.88968824988 + 2803.8079146044*t)
	Z0 += 0.00000000242*np.cos(0.43270824867 + 533.6231183577*t)
	Z0 += 0.00000000190*np.cos(6.17637484900 + 13745.3462390224*t)
	Z0 += 0.00000000208*np.cos(3.34809361979 + 3341.0423098265*t)
	Z0 += 0.00000000198*np.cos(0.97311347960 + 3265.8308281325*t)
	Z0 += 0.00000000205*np.cos(4.20157952693 + 6843.6914895318*t)
	Z0 += 0.00000000222*np.cos(1.37049171707 + 3169.9395560806*t)
	Z0 += 0.00000000183*np.cos(2.19041678580 + 9866.4168806652*t)
	Z0 += 0.00000000225*np.cos(0.32450219510 + 13149.1506113612*t)
	Z0 += 0.00000000211*np.cos(4.38136759956 + 640.8776073822*t)
	Z0 += 0.00000000173*np.cos(3.90520749444 + 5099.2655051166*t)
	Z0 += 0.00000000158*np.cos(2.98574812713 + 13524.9163429314*t)
	Z0 += 0.00000000170*np.cos(3.37406232659 + 15508.6151232744*t)
	Z0 += 0.00000000171*np.cos(4.75570011379 + 6261.7402095244*t)
	Z0 += 0.00000000188*np.cos(5.56241899175 + 16460.33352952499*t)
	Z0 += 0.00000000205*np.cos(5.01940138208 + 1118.7557921028*t)
	Z0 += 0.00000000156*np.cos(3.68058177082 + 13553.8979729108*t)
	Z0 += 0.00000000161*np.cos(3.79231132145 + 490.3340891794*t)
	Z0 += 0.00000000208*np.cos(1.04576950390 + 3340.1825435731*t)
	Z0 += 0.00000000146*np.cos(0.92939894424 + 114.3991069134*t)
	Z0 += 0.00000000156*np.cos(4.90620162208 + 20199.094959633*t)
	Z0 += 0.00000000174*np.cos(5.58778318130 + 2766.267628365*t)
	Z0 += 0.00000000169*np.cos(3.71127165203 + 10184.3039162316*t)
	Z0 += 0.00000000171*np.cos(3.60600294119 + 20597.2439630412*t)
	Z0 += 0.00000000157*np.cos(0.79065950021 + 1265.5674786264*t)
	Z0 += 0.00000000140*np.cos(1.54110979029 + 2111.6503133776*t)
	Z0 += 0.00000000145*np.cos(6.17161140540 + 19800.9459562248*t)
	Z0 += 0.00000000156*np.cos(0.43599559375 + 4459.3682188026*t)
	Z0 += 0.00000000143*np.cos(0.19892133285 + 10235.1363755374*t)
	Z0 += 0.00000000184*np.cos(1.58017928752 + 8273.8208670324*t)
	Z0 += 0.00000000133*np.cos(2.86759235449 + 20618.0193585336*t)
	Z0 += 0.00000000151*np.cos(1.59809012076 + 13892.1406718938*t)
	Z0 += 0.00000000133*np.cos(6.14918807002 + 17277.4069318338*t)
	Z0 += 0.00000000167*np.cos(0.94707767481 + 3274.1250177854*t)
	Z0 += 0.00000000126*np.cos(4.54286582844 + 3914.9572250346*t)
	Z0 += 0.00000000154*np.cos(0.00941929392 + 735.8765135318*t)
	Z0 += 0.00000000145*np.cos(2.88581037055 + 4392.8808098882*t)
	Z0 += 0.00000000165*np.cos(5.44939669734 + 1228.9621133222*t)
	Z0 += 0.00000000124*np.cos(2.73197400851 + 3407.0998356142*t)
	Z0 += 0.00000000145*np.cos(5.65866985683 + 4407.1079038898*t)
	Z0 += 0.00000000129*np.cos(5.30043284887 + 351.8165923087*t)
	Z0 += 0.00000000117*np.cos(4.81725910872 + 625.6701923124*t)
	Z0 += 0.00000000158*np.cos(1.72206104768 + 3296.8935143948*t)
	Z0 += 0.00000000116*np.cos(0.02904609570 + 26482.1708096244*t)
	Z0 += 0.00000000156*np.cos(1.25691413032 + 3384.3313390048*t)
	Z0 += 0.00000000117*np.cos(4.96153079924 + 3981.490034082*t)
	Z0 += 0.00000000113*np.cos(3.04973288935 + 532.8723588323*t)
	Z0 += 0.00000000154*np.cos(2.17255031800 + 1964.838626854*t)
	Z0 += 0.00000000117*np.cos(2.13763640035 + 29424.634232916*t)
	Z0 += 0.00000000129*np.cos(2.20198223551 + 3450.8187479192*t)
	Z0 += 0.00000000116*np.cos(0.92093201468 + 526.5095713569*t)
	Z0 += 0.00000000115*np.cos(5.24850953150 + 3237.5196524812*t)
	Z0 += 0.00000000112*np.cos(6.26358102825 + 2125.8774073792*t)
	Z0 += 0.00000000112*np.cos(4.67861613977 + 2807.3983432562*t)
	Z0 += 0.00000000115*np.cos(0.38603739544 + 12721.572099417*t)
	Z0 += 0.00000000129*np.cos(1.11079063120 + 33.6796175129*t)
	Z0 += 0.00000000113*np.cos(1.36558076768 + 6709.6740408674*t)
	Z0 += 0.00000000144*np.cos(0.22567806033 + 263.0839233728*t)
	Z0 += 0.00000000109*np.cos(5.27187307952 + 5518.7501489918*t)
	Z0 += 0.00000000125*np.cos(2.20397088123 + 30220.9322397324*t)
	Z0 += 0.00000000108*np.cos(6.20219802547 + 6665.9723822146*t)
	Z0 += 0.00000000127*np.cos(2.68652319514 + 7321.1221397136*t)
	Z0 += 0.00000000110*np.cos(0.18586807658 + 29822.7832363242*t)
	Z0 += 0.00000000107*np.cos(0.50226646577 + 22743.4093795164*t)
	Z0 += 0.00000000107*np.cos(3.59856046864 + 5989.0672521728*t)
	Z0 += 0.00000000106*np.cos(5.69966166034 + 33561.5446664322*t)
	Z0 += 0.00000000105*np.cos(3.97375976080 + 9380.9596727172*t)
	Z0 += 0.00000000095*np.cos(4.92440852569 + 4.4534181249*t)
	Z0 += 0.00000000106*np.cos(2.29924580245 + 111.4301614968*t)
	Z0 += 0.00000000103*np.cos(3.99294762314 + 70.3281804424*t)
	Z0 += 0.00000000085*np.cos(6.03717451925 + 127.4717966068*t)
	return Z0




def Mars_Z1 (t): # 273 terms of order 1

	Z1 = 0.
	Z1 += 0.00331842851*np.cos(6.05027773492 + 3340.6124266998*t)
	Z1 -= 0.00047797013
	Z1 += 0.00009896501*np.cos(1.61155844715 + 6681.2248533996*t)
	Z1 += 0.00001700147*np.cos(2.63703242065 + 10021.8372800994*t)
	Z1 += 0.00000544575*np.cos(1.80145347856 + 213.299095438*t)
	Z1 += 0.00000374686*np.cos(4.72268881166 + 529.6909650946*t)
	Z1 += 0.00000240176*np.cos(3.12712303414 + 13362.4497067992*t)
	Z1 += 0.00000114908*np.cos(0.95987621952 + 3337.0893083508*t)
	Z1 += 0.00000045174*np.cos(3.39965147567 + 3344.1355450488*t)
	Z1 += 0.00000041579*np.cos(2.22748839237 + 2281.2304965106*t)
	Z1 += 0.00000031106*np.cos(3.52760107307 + 16703.062133499*t)
	Z1 += 0.00000037294*np.cos(5.40133589632 + 206.1855484372*t)
	Z1 += 0.00000028944*np.cos(4.93245710560 + 220.4126424388*t)
	Z1 += 0.00000028635*np.cos(3.15447649004 + 74.7815985673*t)
	Z1 += 0.00000038808*np.cos(5.94308603611 + 1059.3819301892*t)
	Z1 += 0.00000023537*np.cos(3.65397196617 + 426.598190876*t)
	Z1 += 0.00000022409*np.cos(3.73415090010 + 5621.8429232104*t)
	Z1 += 0.00000016081*np.cos(0.74382156251 + 2942.4634232916*t)
	Z1 += 0.00000014813*np.cos(5.49499542641 + 3340.629680352*t)
	Z1 += 0.00000014813*np.cos(3.46422358566 + 3340.5951730476*t)
	Z1 += 0.00000016942*np.cos(1.91917177965 + 3532.0606928114*t)
	Z1 += 0.00000013490*np.cos(1.69673495675 + 536.8045120954*t)
	Z1 += 0.00000011449*np.cos(6.22900609249 + 2810.9214616052*t)
	Z1 += 0.00000011579*np.cos(0.76965497835 + 398.1490034082*t)
	Z1 += 0.00000012609*np.cos(4.39901271761 + 3496.032826134*t)
	Z1 += 0.00000013077*np.cos(2.01113624837 + 2544.3144198834*t)
	Z1 += 0.00000011945*np.cos(2.28204761113 + 522.5774180938*t)
	Z1 += 0.00000009983*np.cos(6.22961426585 + 3185.1920272656*t)
	Z1 += 0.00000009112*np.cos(3.83699360404 + 6684.7479717486*t)
	Z1 += 0.00000009113*np.cos(3.13081230007 + 3738.761430108*t)
	Z1 += 0.00000008702*np.cos(2.50173196599 + 5884.9268465832*t)
	Z1 += 0.00000009628*np.cos(2.17998735640 + 6151.533888305*t)
	Z1 += 0.00000008141*np.cos(2.28833672455 + 3149.1641605882*t)
	Z1 += 0.00000008010*np.cos(5.28413417446 + 38.1330356378*t)
	Z1 += 0.00000005865*np.cos(1.21189730830 + 6677.7017350506*t)
	Z1 += 0.00000004878*np.cos(4.29048044043 + 419.4846438752*t)
	Z1 += 0.00000005111*np.cos(2.48436031878 + 1751.539531416*t)
	Z1 += 0.00000005432*np.cos(1.11528937942 + 796.2980068164*t)
	Z1 += 0.00000004878*np.cos(1.13276481337 + 3340.6797370026*t)
	Z1 += 0.00000005354*np.cos(2.17844612869 + 4136.9104335162*t)
	Z1 += 0.00000004937*np.cos(4.54706347937 + 8962.4553499102*t)
	Z1 += 0.00000004834*np.cos(1.42578424130 + 6283.0758499914*t)
	Z1 += 0.00000004817*np.cos(0.99936257717 + 2914.0142358238*t)
	Z1 += 0.00000004978*np.cos(0.42028381998 + 1194.4470102246*t)
	Z1 += 0.00000004388*np.cos(4.00376892513 + 5092.1519581158*t)
	Z1 += 0.00000004016*np.cos(3.25291411222 + 3339.6321056316*t)
	Z1 += 0.00000004876*np.cos(1.53898509406 + 3340.545116397*t)
	Z1 += 0.00000004674*np.cos(3.93431019327 + 5486.777843175*t)
	Z1 += 0.00000003606*np.cos(5.74826249892 + 7.1135470008*t)
	Z1 += 0.00000003907*np.cos(3.89954335391 + 20043.6745601988*t)
	Z1 += 0.00000003595*np.cos(5.45219310813 + 1592.5960136328*t)
	Z1 += 0.00000003375*np.cos(3.44635837371 + 2146.1654164752*t)
	Z1 += 0.00000003336*np.cos(5.20503259965 + 5088.6288397668*t)
	Z1 += 0.00000003313*np.cos(2.58038243859 + 3870.3033917944*t)
	Z1 += 0.00000002887*np.cos(2.94891175550 + 3894.1818295422*t)
	Z1 += 0.00000003775*np.cos(0.28510069911 + 1589.0728952838*t)
	Z1 += 0.00000002995*np.cos(0.74761803993 + 4399.994356889*t)
	Z1 += 0.00000002657*np.cos(1.05973335133 + 3341.592747768*t)
	Z1 += 0.00000002425*np.cos(4.10643839121 + 1990.745017041*t)
	Z1 += 0.00000002707*np.cos(0.21082942855 + 4690.4798363586*t)
	Z1 += 0.00000002437*np.cos(1.55037887709 + 4292.3308329504*t)
	Z1 += 0.00000002154*np.cos(1.34196532034 + 2787.0430238574*t)
	Z1 += 0.00000001985*np.cos(4.05464973145 + 433.7117378768*t)
	Z1 += 0.00000002375*np.cos(5.44579536089 + 3127.3133312618*t)
	Z1 += 0.00000001892*np.cos(3.08716660647 + 639.897286314*t)
	Z1 += 0.00000001650*np.cos(4.24815484143 + 3723.508958923*t)
	Z1 += 0.00000001595*np.cos(0.91889240925 + 4535.0594369244*t)
	Z1 += 0.00000001929*np.cos(2.73824451634 + 2388.8940204492*t)
	Z1 += 0.00000001560*np.cos(3.28261094599 + 316.3918696566*t)
	Z1 += 0.00000001444*np.cos(0.15895080264 + 2957.7158944766*t)
	Z1 += 0.00000001405*np.cos(3.64849603977 + 155.4203994342*t)
	Z1 += 0.00000001471*np.cos(4.20495798401 + 10025.3603984484*t)
	Z1 += 0.00000001523*np.cos(4.04272530212 + 7079.3738568078*t)
	Z1 += 0.00000001553*np.cos(5.95800074808 + 3097.88382272579*t)
	Z1 += 0.00000001436*np.cos(3.01319373979 + 6254.6266625236*t)
	Z1 += 0.00000001520*np.cos(4.82580321630 + 3583.3410306738*t)
	Z1 += 0.00000001347*np.cos(1.63836991777 + 191.4482661116*t)
	Z1 += 0.00000001178*np.cos(4.84813144707 + 1748.016413067*t)
	Z1 += 0.00000001068*np.cos(4.78083964620 + 8432.7643848156*t)
	Z1 += 0.00000001207*np.cos(2.94341645482 + 6489.776587288*t)
	Z1 += 0.00000001029*np.cos(5.86675536556 + 149.5631971346*t)
	Z1 += 0.00000000884*np.cos(5.30840180453 + 6681.2075997474*t)
	Z1 += 0.00000000900*np.cos(2.90436997781 + 3553.9115221378*t)
	Z1 += 0.00000000922*np.cos(2.71708263246 + 7477.522860216*t)
	Z1 += 0.00000000884*np.cos(1.05598798263 + 6681.2421070518*t)
	Z1 += 0.00000001004*np.cos(2.08646328422 + 2288.3440435114*t)
	Z1 += 0.00000000821*np.cos(0.50918826840 + 6674.1113063988*t)
	Z1 += 0.00000001013*np.cos(4.01590051998 + 9492.1463150048*t)
	Z1 += 0.00000000969*np.cos(1.31742925335 + 3333.498879699*t)
	Z1 += 0.00000000775*np.cos(4.79688880139 + 227.5261894396*t)
	Z1 += 0.00000000766*np.cos(2.75216606760 + 9225.539273283*t)
	Z1 += 0.00000001056*np.cos(0.30211067524 + 6525.8044539654*t)
	Z1 += 0.00000001046*np.cos(2.79906620797 + 1066.49547719*t)
	Z1 += 0.00000000721*np.cos(4.45548872348 + 4562.4609930212*t)
	Z1 += 0.00000000637*np.cos(2.65140853163 + 2274.1169495098*t)
	Z1 += 0.00000000696*np.cos(3.46051409766 + 382.8965322232*t)
	Z1 += 0.00000000608*np.cos(5.86051939698 + 4933.2084403326*t)
	Z1 += 0.00000000667*np.cos(6.06355547392 + 1349.8674096588*t)
	Z1 += 0.00000000573*np.cos(0.99737613450 + 951.7184062506*t)
	Z1 += 0.00000000591*np.cos(1.92029762929 + 3325.3599555148*t)
	Z1 += 0.00000000599*np.cos(2.35105017113 + 76.2660712756*t)
	Z1 += 0.00000000542*np.cos(1.44488755125 + 110.2063212194*t)
	Z1 += 0.00000000711*np.cos(2.28848181506 + 553.5694028424*t)
	Z1 += 0.00000000515*np.cos(5.51446088347 + 3361.3878221922*t)
	Z1 += 0.00000000541*np.cos(4.53250433908 + 6836.6452528338*t)
	Z1 += 0.00000000546*np.cos(2.64939261840 + 1221.8485663214*t)
	Z1 += 0.00000000578*np.cos(4.59190674427 + 3360.96774609859*t)
	Z1 += 0.00000000511*np.cos(4.39136424744 + 242.728603974*t)
	Z1 += 0.00000000493*np.cos(1.51453356449 + 6467.9257579616*t)
	Z1 += 0.00000000487*np.cos(5.76370767302 + 3205.5473466644*t)
	Z1 += 0.00000000463*np.cos(0.99068109709 + 4929.6853219836*t)
	Z1 += 0.00000000462*np.cos(3.45792563670 + 3319.8370312074*t)
	Z1 += 0.00000000442*np.cos(4.14870457392 + 6041.3275670856*t)
	Z1 += 0.00000000477*np.cos(1.29132635006 + 3347.7259737006*t)
	Z1 += 0.00000000447*np.cos(2.44807015440 + 3355.8648978848*t)
	Z1 += 0.00000000395*np.cos(0.74904985730 + 5614.7293762096*t)
	Z1 += 0.00000000403*np.cos(1.25691345472 + 36.6485629295*t)
	Z1 += 0.00000000516*np.cos(6.08458990599 + 3320.257107301*t)
	Z1 += 0.00000000438*np.cos(1.29035103833 + 7740.6067835888*t)
	Z1 += 0.00000000484*np.cos(4.25897353296 + 23384.2869868986*t)
	Z1 += 0.00000000454*np.cos(1.00892151622 + 2118.7638603784*t)
	Z1 += 0.00000000477*np.cos(0.34212243439 + 2700.7151403858*t)
	Z1 += 0.00000000415*np.cos(0.30661716598 + 12303.06777661*t)
	Z1 += 0.00000000352*np.cos(4.79823464785 + 39.6175083461*t)
	Z1 += 0.00000000435*np.cos(3.69772502222 + 7210.9158184942*t)
	Z1 += 0.00000000388*np.cos(6.25800132393 + 6438.4962494256*t)
	Z1 += 0.00000000469*np.cos(3.94488775543 + 8827.3902698748*t)
	Z1 += 0.00000000446*np.cos(5.55248874462 + 199.0720014364*t)
	Z1 += 0.00000000368*np.cos(5.32358181908 + 103.0927742186*t)
	Z1 += 0.00000000341*np.cos(1.37941086735 + 3767.2106175758*t)
	Z1 += 0.00000000302*np.cos(5.15335876647 + 632.7837393132*t)
	Z1 += 0.00000000341*np.cos(1.49962309683 + 6682.2051744678*t)
	Z1 += 0.00000000343*np.cos(2.32388226037 + 515.463871093*t)
	Z1 += 0.00000000291*np.cos(3.38716490010 + 6681.1575430968*t)
	Z1 += 0.00000000286*np.cos(4.61337372260 + 10419.9862835076*t)
	Z1 += 0.00000000298*np.cos(5.02335774639 + 12832.7587417046*t)
	Z1 += 0.00000000278*np.cos(3.96374902099 + 2921.1277828246*t)
	Z1 += 0.00000000271*np.cos(3.64021714596 + 6680.2445323314*t)
	Z1 += 0.00000000317*np.cos(4.41640100211 + 3337.021998048*t)
	Z1 += 0.00000000316*np.cos(4.84749260614 + 3344.2028553516*t)
	Z1 += 0.00000000258*np.cos(5.99544147559 + 14.2270940016*t)
	Z1 += 0.00000000238*np.cos(1.69500091019 + 6127.6554505572*t)
	Z1 += 0.00000000229*np.cos(1.25926585958 + 7875.6718636242*t)
	Z1 += 0.00000000311*np.cos(4.47336599498 + 5331.3574437408*t)
	Z1 += 0.00000000227*np.cos(2.07959309341 + 10021.8545337516*t)
	Z1 += 0.00000000291*np.cos(2.97870352125 + 6681.2921637024*t)
	Z1 += 0.00000000281*np.cos(5.09122041999 + 7903.073419721*t)
	Z1 += 0.00000000227*np.cos(0.04882339645 + 10021.8200264472*t)
	Z1 += 0.00000000266*np.cos(0.49468027720 + 73.297125859*t)
	Z1 += 0.00000000283*np.cos(3.18659167678 + 9623.6882766912*t)
	Z1 += 0.00000000217*np.cos(3.07439801130 + 5729.506447149*t)
	Z1 += 0.00000000221*np.cos(4.53139041634 + 3312.163239232*t)
	Z1 += 0.00000000251*np.cos(5.58497774438 + 217.2312487011*t)
	Z1 += 0.00000000204*np.cos(4.52559015591 + 12168.0026965746*t)
	Z1 += 0.00000000210*np.cos(5.87638250776 + 210.1177017003*t)
	Z1 += 0.00000000200*np.cos(1.60953815793 + 543.9180590962*t)
	Z1 += 0.00000000207*np.cos(2.80641141402 + 6872.6731195112*t)
	Z1 += 0.00000000219*np.cos(1.31943624453 + 3364.4908644476*t)
	Z1 += 0.00000000211*np.cos(3.18975604764 + 1758.6530784168*t)
	Z1 += 0.00000000187*np.cos(3.39876387294 + 9830.3890139878*t)
	Z1 += 0.00000000239*np.cos(2.84009957640 + 1052.2683831884*t)
	Z1 += 0.00000000225*np.cos(4.53161555673 + 13365.9728251482*t)
	Z1 += 0.00000000240*np.cos(4.10377804654 + 11773.3768115154*t)
	Z1 += 0.00000000186*np.cos(4.63128120913 + 209.3669421749*t)
	Z1 += 0.00000000181*np.cos(5.02103622915 + 6144.4203413042*t)
	Z1 += 0.00000000166*np.cos(3.25384215179 + 647.0108333148*t)
	Z1 += 0.00000000170*np.cos(3.82076107858 + 9595.2390892234*t)
	Z1 += 0.00000000179*np.cos(0.52534002868 + 6298.3283211764*t)
	Z1 += 0.00000000188*np.cos(4.45601446980 + 216.4804891757*t)
	Z1 += 0.00000000197*np.cos(3.29154622691 + 17654.7805397496*t)
	Z1 += 0.00000000173*np.cos(6.17700699189 + 5628.9564702112*t)
	Z1 += 0.00000000185*np.cos(1.76841265719 + 3.523118349*t)
	Z1 += 0.00000000164*np.cos(5.16565812417 + 6923.9534573736*t)
	Z1 += 0.00000000212*np.cos(2.49710874752 + 3503.079062832*t)
	Z1 += 0.00000000191*np.cos(3.06147941687 + 3316.733988952*t)
	Z1 += 0.00000000149*np.cos(3.09964766740 + 10818.1352869158*t)
	Z1 += 0.00000000199*np.cos(3.91203195189 + 6894.5239488376*t)
	Z1 += 0.00000000147*np.cos(4.91154015633 + 202.2533951741*t)
	Z1 += 0.00000000148*np.cos(6.00943832296 + 949.1756089698*t)
	Z1 += 0.00000000143*np.cos(3.70203142149 + 323.5054166574*t)
	Z1 += 0.00000000164*np.cos(0.87273677571 + 2487.4160449478*t)
	Z1 += 0.00000000142*np.cos(0.91426251678 + 2699.7348193176*t)
	Z1 += 0.00000000147*np.cos(1.13949466990 + 8955.3418029094*t)
	Z1 += 0.00000000161*np.cos(1.29304586194 + 15643.6802033098*t)
	Z1 += 0.00000000141*np.cos(0.78662586077 + 10018.3141617504*t)
	Z1 += 0.00000000140*np.cos(0.83132381305 + 735.8765135318*t)
	Z1 += 0.00000000170*np.cos(2.30475590800 + 3346.1353510072*t)
	Z1 += 0.00000000156*np.cos(4.25533461379 + 3475.6775067352*t)
	Z1 += 0.00000000184*np.cos(5.78264875545 + 11769.8536931664*t)
	Z1 += 0.00000000171*np.cos(3.43368780535 + 1596.1864422846*t)
	Z1 += 0.00000000130*np.cos(1.31377876815 + 7632.9432596502*t)
	Z1 += 0.00000000130*np.cos(2.61778742289 + 7234.794256242*t)
	Z1 += 0.00000000152*np.cos(2.12818166833 + 3178.1457905676*t)
	Z1 += 0.00000000122*np.cos(5.67146512225 + 117.3198682202*t)
	Z1 += 0.00000000125*np.cos(0.64246695673 + 9866.4168806652*t)
	Z1 += 0.00000000118*np.cos(1.97713868087 + 6688.3384004004*t)
	Z1 += 0.00000000139*np.cos(1.48720938048 + 14712.317116458*t)
	Z1 += 0.00000000127*np.cos(4.40635089709 + 12964.300703391*t)
	Z1 += 0.00000000130*np.cos(5.22946780555 + 3304.5845600224*t)
	Z1 += 0.00000000140*np.cos(4.09411983665 + 6158.6474353058*t)
	Z1 += 0.00000000110*np.cos(2.96313731510 + 10575.4066829418*t)
	Z1 += 0.00000000108*np.cos(1.42758307106 + 7064.1213856228*t)
	Z1 += 0.00000000116*np.cos(1.77024829602 + 3335.0895023924*t)
	Z1 += 0.00000000103*np.cos(3.53764086090 + 1744.4259844152*t)
	Z1 += 0.00000000100*np.cos(2.78745027781 + 1.4844727083*t)
	Z1 += 0.00000000137*np.cos(3.37678223302 + 1581.959348283*t)
	Z1 += 0.00000000120*np.cos(1.56367501585 + 3336.7310913418*t)
	Z1 += 0.00000000098*np.cos(0.18721764890 + 3980.5097130138*t)
	Z1 += 0.00000000098*np.cos(1.72351303556 + 18052.9295431578*t)
	Z1 += 0.00000000110*np.cos(0.34606761114 + 8969.568896911*t)
	Z1 += 0.00000000100*np.cos(1.71152868829 + 2648.454825473*t)
	Z1 += 0.00000000119*np.cos(2.97602189356 + 640.8776073822*t)
	Z1 += 0.00000000096*np.cos(1.41608119487 + 5085.038411115*t)
	Z1 += 0.00000000089*np.cos(0.38926679495 + 5459.3762870782*t)
	Z1 += 0.00000000082*np.cos(3.96541084548 + 10021.9045904022*t)
	Z1 += 0.00000000084*np.cos(4.30248448955 + 1162.4747044078*t)
	Z1 += 0.00000000084*np.cos(2.77343761472 + 3344.4937620578*t)
	Z1 += 0.00000000080*np.cos(4.57789872343 + 11243.6858464208*t)
	Z1 += 0.00000000081*np.cos(4.51984392790 + 9381.9399937854*t)
	Z1 += 0.00000000077*np.cos(4.22942639128 + 95.9792272178*t)
	Z1 += 0.00000000079*np.cos(0.36636125409 + 11.0457002639*t)
	Z1 += 0.00000000102*np.cos(5.43466097744 + 3376.6402933772*t)
	Z1 += 0.00000000075*np.cos(1.47982807612 + 525.7588118315*t)
	Z1 += 0.00000000076*np.cos(4.59412107241 + 10177.2576795336*t)
	Z1 += 0.00000000074*np.cos(0.46347570603 + 8429.2412664666*t)
	Z1 += 0.00000000078*np.cos(1.36874721918 + 11081.2192102886*t)
	Z1 += 0.00000000076*np.cos(1.24245643745 + 532.8723588323*t)
	Z1 += 0.00000000080*np.cos(5.47863871673 + 3369.0616141676*t)
	Z1 += 0.00000000096*np.cos(0.86129378681 + 63.7358983034*t)
	Z1 += 0.00000000071*np.cos(0.91306168512 + 8270.2977486834*t)
	Z1 += 0.00000000071*np.cos(2.75365102566 + 526.5095713569*t)
	Z1 += 0.00000000072*np.cos(4.45423986754 + 17256.6315363414*t)
	Z1 += 0.00000000097*np.cos(4.31072201688 + 3077.528503327*t)
	Z1 += 0.00000000077*np.cos(5.06342636467 + 1692.1656695024*t)
	Z1 += 0.00000000071*np.cos(4.62498165607 + 10551.528245194*t)
	Z1 += 0.00000000066*np.cos(0.13337760475 + 15110.4661198662*t)
	Z1 += 0.00000000067*np.cos(2.62252809221 + 692.1576012268*t)
	Z1 += 0.00000000080*np.cos(1.32412177054 + 21393.5419698576*t)
	Z1 += 0.00000000065*np.cos(2.49553722094 + 10973.55568635*t)
	Z1 += 0.00000000083*np.cos(3.48044851764 + 13916.0191096416*t)
	Z1 += 0.00000000077*np.cos(0.30886632738 + 3863.1898447936*t)
	Z1 += 0.00000000076*np.cos(6.15364247126 + 8273.8208670324*t)
	Z1 += 0.00000000063*np.cos(3.98868546710 + 440.8252848776*t)
	Z1 += 0.00000000087*np.cos(4.95360412434 + 3603.6963500726*t)
	Z1 += 0.00000000061*np.cos(3.16734182399 + 2766.267628365*t)
	Z1 += 0.00000000061*np.cos(2.62473045895 + 533.6231183577*t)
	Z1 += 0.00000000076*np.cos(4.86164511219 + 20597.2439630412*t)
	Z1 += 0.00000000082*np.cos(4.37174958841 + 10021.7699697966*t)
	Z1 += 0.00000000066*np.cos(0.21946862187 + 8031.0922630584*t)
	Z1 += 0.00000000062*np.cos(3.45689005120 + 13517.8701062334*t)
	Z1 += 0.00000000067*np.cos(3.22378160844 + 853.196381752*t)
	Z1 += 0.00000000077*np.cos(4.77622965669 + 4032.7700279266*t)
	Z1 += 0.00000000069*np.cos(4.07458572512 + 4407.1079038898*t)
	Z1 += 0.00000000057*np.cos(5.01958511504 + 5828.0284716476*t)
	Z1 += 0.00000000074*np.cos(2.77773427484 + 3981.490034082*t)
	Z1 += 0.00000000059*np.cos(2.42227935458 + 12566.1516999828*t)
	Z1 += 0.00000000056*np.cos(3.55730072615 + 10713.9948813262*t)
	Z1 += 0.00000000055*np.cos(6.23004856059 + 3914.9572250346*t)
	Z1 += 0.00000000055*np.cos(5.34452429591 + 13358.9265884502*t)
	Z1 += 0.00000000055*np.cos(0.80155920044 + 11371.7046897582*t)
	Z1 += 0.00000000054*np.cos(1.42941204449 + 85.8272988312*t)
	Z1 += 0.00000000056*np.cos(4.79027072937 + 16173.3711684044*t)
	Z1 += 0.00000000063*np.cos(4.38809621285 + 7373.3824546264*t)
	Z1 += 0.00000000065*np.cos(1.83461015336 + 14314.1681130498*t)
	Z1 += 0.00000000061*np.cos(3.35711733735 + 20995.3929664494*t)
	Z1 += 0.00000000057*np.cos(3.98493436395 + 309.2783226558*t)
	Z1 += 0.00000000054*np.cos(0.51358052231 + 6702.000248892*t)
	Z1 += 0.00000000053*np.cos(6.24589101777 + 20199.094959633*t)
	Z1 += 0.00000000059*np.cos(4.96649103229 + 3191.0492295652*t)
	Z1 += 0.00000000052*np.cos(4.94957858677 + 24734.1543965574*t)
	Z1 += 0.00000000050*np.cos(4.13806710714 + 10213.285546211*t)
	Z1 += 0.00000000051*np.cos(0.39392917326 + 742.9900605326*t)
	Z1 += 0.00000000049*np.cos(4.84482792493 + 956.2891559706*t)
	return Z1*t




def Mars_Z2 (t): # 147 terms of order 2

	Z2 = 0.
	Z2 += 0.00013705355*np.cos(1.04212852598 + 3340.6124266998*t)
	Z2 -= 0.00005933274
	Z2 += 0.00000716728*np.cos(0.12154825255 + 6681.2248533996*t)
	Z2 += 0.00000138514*np.cos(0.78090653399 + 10021.8372800994*t)
	Z2 += 0.00000037556*np.cos(3.22969663577 + 213.299095438*t)
	Z2 += 0.00000026824*np.cos(6.18626318965 + 529.6909650946*t)
	Z2 += 0.00000025745*np.cos(1.39077449077 + 13362.4497067992*t)
	Z2 += 0.00000012181*np.cos(2.58732834908 + 3337.0893083508*t)
	Z2 += 0.00000008616*np.cos(0.77209239310 + 206.1855484372*t)
	Z2 += 0.00000005511*np.cos(3.23377546695 + 220.4126424388*t)
	Z2 += 0.00000004371*np.cos(1.87368859535 + 16703.062133499*t)
	Z2 += 0.00000004536*np.cos(1.36770001683 + 3344.1355450488*t)
	Z2 += 0.00000003737*np.cos(6.00280902795 + 3496.032826134*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	Z2 += 0.00000002587*np.cos(4.62868565055 + 3185.1920272656*t)
	Z2 += 0.00000002239*np.cos(4.95092849019 + 1059.3819301892*t)
	Z2 += 0.00000002272*np.cos(4.09618627765 + 522.5774180938*t)
	Z2 += 0.00000001893*np.cos(2.36062716274 + 426.598190876*t)
	Z2 += 0.00000001722*np.cos(0.98795977798 + 2281.2304965106*t)
	Z2 += 0.00000001615*np.cos(5.66791333096 + 5621.8429232104*t)
	Z2 += 0.00000001520*np.cos(3.54344603378 + 3532.0606928114*t)
	Z2 += 0.00000001037*np.cos(2.63342459156 + 2942.4634232916*t)
	Z2 += 0.00000000905*np.cos(2.04669399323 + 6684.7479717486*t)
	Z2 += 0.00000001041*np.cos(3.88701726221 + 2544.3144198834*t)
	Z2 += 0.00000000770*np.cos(5.10113036277 + 2810.9214616052*t)
	Z2 += 0.00000000688*np.cos(4.59085360596 + 3894.1818295422*t)
	Z2 += 0.00000000713*np.cos(4.16328040173 + 5884.9268465832*t)
	Z2 += 0.00000000743*np.cos(6.08844686068 + 419.4846438752*t)
	Z2 += 0.00000000689*np.cos(2.29465541114 + 20043.6745601988*t)
	Z2 += 0.00000000641*np.cos(4.89317483950 + 74.7815985673*t)
	Z2 += 0.00000000622*np.cos(4.93952624143 + 3339.6321056316*t)
	Z2 += 0.00000000696*np.cos(5.39983895631 + 5486.777843175*t)
	Z2 += 0.00000000567*np.cos(0.51314316796 + 5088.6288397668*t)
	Z2 += 0.00000000610*np.cos(0.49406493231 + 3340.629680352*t)
	Z2 += 0.00000000610*np.cos(4.74647860799 + 3340.5951730476*t)
	Z2 += 0.00000000647*np.cos(1.17822960287 + 3097.88382272579*t)
	Z2 += 0.00000000515*np.cos(0.52495804247 + 3149.1641605882*t)
	Z2 += 0.00000000527*np.cos(2.28325191846 + 433.7117378768*t)
	Z2 += 0.00000000462*np.cos(6.01031568571 + 2787.0430238574*t)
	Z2 += 0.00000000439*np.cos(0.29884669602 + 4136.9104335162*t)
	Z2 += 0.00000000503*np.cos(2.83961174727 + 6677.7017350506*t)
	Z2 += 0.00000000399*np.cos(4.11156780780 + 7.1135470008*t)
	Z2 += 0.00000000446*np.cos(3.21959306381 + 4292.3308329504*t)
	Z2 += 0.00000000393*np.cos(5.15600015824 + 2146.1654164752*t)
	Z2 += 0.00000000384*np.cos(4.87193587713 + 5092.1519581158*t)
	Z2 += 0.00000000390*np.cos(1.91255819503 + 4690.4798363586*t)
	Z2 += 0.00000000374*np.cos(4.80085008370 + 1194.4470102246*t)
	Z2 += 0.00000000430*np.cos(3.34783108483 + 3583.3410306738*t)
	Z2 += 0.00000000375*np.cos(3.66085423366 + 1592.5960136328*t)
	Z2 += 0.00000000337*np.cos(5.84337571937 + 3723.508958923*t)
	Z2 += 0.00000000325*np.cos(2.38085319573 + 1990.745017041*t)
	Z2 += 0.00000000323*np.cos(5.28429586359 + 155.4203994342*t)
	Z2 += 0.00000000300*np.cos(3.09602587558 + 227.5261894396*t)
	Z2 += 0.00000000361*np.cos(0.94089120900 + 2388.8940204492*t)
	Z2 += 0.00000000295*np.cos(5.53803343526 + 3341.592747768*t)
	Z2 += 0.00000000332*np.cos(5.85499743580 + 796.2980068164*t)
	Z2 += 0.00000000342*np.cos(2.58974309074 + 398.1490034082*t)
	Z2 += 0.00000000315*np.cos(1.39878115260 + 3738.761430108*t)
	Z2 += 0.00000000348*np.cos(3.88712290311 + 6151.533888305*t)
	Z2 += 0.00000000257*np.cos(5.22188438508 + 4399.994356889*t)
	Z2 += 0.00000000296*np.cos(5.13307368643 + 1589.0728952838*t)
	Z2 += 0.00000000265*np.cos(0.10458265918 + 1748.016413067*t)
	Z2 += 0.00000000309*np.cos(4.99847336546 + 6525.8044539654*t)
	Z2 += 0.00000000221*np.cos(0.39725518064 + 1066.49547719*t)
	Z2 += 0.00000000222*np.cos(5.92527218350 + 8962.4553499102*t)
	Z2 += 0.00000000212*np.cos(2.47672225613 + 6283.0758499914*t)
	Z2 += 0.00000000201*np.cos(2.41602653811 + 3340.6797370026*t)
	Z2 += 0.00000000202*np.cos(4.74840488839 + 2957.7158944766*t)
	Z2 += 0.00000000245*np.cos(1.22451806258 + 639.897286314*t)
	Z2 += 0.00000000222*np.cos(4.45800445697 + 3333.498879699*t)
	Z2 += 0.00000000190*np.cos(5.71991161418 + 2914.0142358238*t)
	Z2 += 0.00000000187*np.cos(2.55575861239 + 10025.3603984484*t)
	Z2 += 0.00000000201*np.cos(2.82452292485 + 3340.545116397*t)
	Z2 += 0.00000000181*np.cos(5.40590734087 + 4535.0594369244*t)
	Z2 += 0.00000000167*np.cos(0.66523343049 + 2288.3440435114*t)
	Z2 += 0.00000000175*np.cos(1.38046108142 + 1349.8674096588*t)
	Z2 += 0.00000000184*np.cos(0.95286916137 + 199.0720014364*t)
	Z2 += 0.00000000146*np.cos(2.68515136013 + 951.7184062506*t)
	Z2 += 0.00000000144*np.cos(5.14515012962 + 6254.6266625236*t)
	Z2 += 0.00000000147*np.cos(2.71904898461 + 242.728603974*t)
	Z2 += 0.00000000149*np.cos(4.90906266305 + 316.3918696566*t)
	Z2 += 0.00000000149*np.cos(4.80676029564 + 2274.1169495098*t)
	Z2 += 0.00000000129*np.cos(2.21550319598 + 7079.3738568078*t)
	Z2 += 0.00000000118*np.cos(1.29196638351 + 3127.3133312618*t)
	Z2 += 0.00000000119*np.cos(4.09508225076 + 515.463871093*t)
	Z2 += 0.00000000145*np.cos(3.92808522801 + 553.5694028424*t)
	Z2 += 0.00000000119*np.cos(1.55095338268 + 6438.4962494256*t)
	Z2 += 0.00000000104*np.cos(4.20382366423 + 4933.2084403326*t)
	Z2 += 0.00000000102*np.cos(6.08136575732 + 6836.6452528338*t)
	Z2 += 0.00000000122*np.cos(1.15508040838 + 6489.776587288*t)
	Z2 += 0.00000000088*np.cos(2.28726712369 + 6674.1113063988*t)
	Z2 += 0.00000000085*np.cos(6.16812793384 + 543.9180590962*t)
	Z2 += 0.00000000095*np.cos(0.97194852729 + 7477.522860216*t)
	Z2 += 0.00000000098*np.cos(0.37829296009 + 3870.3033917944*t)
	Z2 += 0.00000000100*np.cos(2.67089921368 + 23384.2869868986*t)
	Z2 += 0.00000000079*np.cos(4.29766380692 + 14.2270940016*t)
	Z2 += 0.00000000099*np.cos(6.15770796955 + 3347.7259737006*t)
	Z2 += 0.00000000082*np.cos(0.88675647815 + 1751.539531416*t)
	Z2 += 0.00000000072*np.cos(3.69010658240 + 1052.2683831884*t)
	Z2 += 0.00000000068*np.cos(1.33776656115 + 210.1177017003*t)
	Z2 += 0.00000000077*np.cos(2.58299228393 + 9492.1463150048*t)
	Z2 += 0.00000000064*np.cos(3.82120225839 + 6681.2075997474*t)
	Z2 += 0.00000000064*np.cos(5.85173773053 + 6681.2421070518*t)
	Z2 += 0.00000000061*np.cos(0.07710122678 + 6127.6554505572*t)
	Z2 += 0.00000000065*np.cos(5.05560764351 + 38.1330356378*t)
	Z2 += 0.00000000058*np.cos(1.55728577024 + 103.0927742186*t)
	Z2 += 0.00000000061*np.cos(5.00961469844 + 4562.4609930212*t)
	Z2 += 0.00000000057*np.cos(2.83943419184 + 8955.3418029094*t)
	Z2 += 0.00000000054*np.cos(3.61966169219 + 6923.9534573736*t)
	Z2 += 0.00000000066*np.cos(2.79752228075 + 5331.3574437408*t)
	Z2 += 0.00000000051*np.cos(2.71026300250 + 191.4482661116*t)
	Z2 += 0.00000000067*np.cos(5.17453941928 + 382.8965322232*t)
	Z2 += 0.00000000051*np.cos(5.98427244306 + 6682.2051744678*t)
	Z2 += 0.00000000052*np.cos(1.39967850157 + 5729.506447149*t)
	Z2 += 0.00000000047*np.cos(1.96623457652 + 10419.9862835076*t)
	Z2 += 0.00000000050*np.cos(1.42158496561 + 647.0108333148*t)
	Z2 += 0.00000000043*np.cos(0.76139880953 + 6681.2921637024*t)
	Z2 += 0.00000000050*np.cos(3.77884547078 + 7210.9158184942*t)
	Z2 += 0.00000000042*np.cos(1.14028846687 + 217.2312487011*t)
	Z2 += 0.00000000039*np.cos(5.87950681446 + 7875.6718636242*t)
	Z2 += 0.00000000039*np.cos(1.40731285611 + 3553.9115221378*t)
	Z2 += 0.00000000053*np.cos(2.67570413760 + 216.4804891757*t)
	Z2 += 0.00000000046*np.cos(5.03496308376 + 8969.568896911*t)
	Z2 += 0.00000000051*np.cos(5.75564577567 + 7740.6067835888*t)
	Z2 += 0.00000000037*np.cos(2.30909423712 + 3320.257107301*t)
	Z2 += 0.00000000037*np.cos(0.67405360149 + 3360.96774609859*t)
	Z2 += 0.00000000036*np.cos(5.69385236083 + 4929.6853219836*t)
	Z2 += 0.00000000038*np.cos(2.50888031088 + 10018.3141617504*t)
	Z2 += 0.00000000037*np.cos(4.54908428517 + 9866.4168806652*t)
	Z2 += 0.00000000033*np.cos(5.95090153832 + 6041.3275670856*t)
	Z2 += 0.00000000035*np.cos(2.08435955688 + 2699.7348193176*t)
	Z2 += 0.00000000032*np.cos(0.60244035710 + 640.8776073822*t)
	Z2 += 0.00000000036*np.cos(5.01009549942 + 12303.06777661*t)
	Z2 += 0.00000000034*np.cos(5.99924292309 + 3767.2106175758*t)
	Z2 += 0.00000000035*np.cos(4.24982817116 + 3325.3599555148*t)
	Z2 += 0.00000000031*np.cos(4.21025720942 + 110.2063212194*t)
	Z2 += 0.00000000035*np.cos(5.01800237749 + 3355.8648978848*t)
	Z2 += 0.00000000029*np.cos(3.61321450446 + 10021.8200264472*t)
	Z2 += 0.00000000036*np.cos(2.91699961934 + 13365.9728251482*t)
	Z2 += 0.00000000029*np.cos(5.64395801617 + 10021.8545337516*t)
	Z2 += 0.00000000029*np.cos(6.18539185721 + 632.7837393132*t)
	Z2 += 0.00000000028*np.cos(3.21594452948 + 12832.7587417046*t)
	Z2 += 0.00000000031*np.cos(4.28897734330 + 6298.3283211764*t)
	Z2 += 0.00000000028*np.cos(2.23145809257 + 440.8252848776*t)
	Z2 += 0.00000000033*np.cos(0.42157783312 + 853.196381752*t)
	Z2 += 0.00000000025*np.cos(3.95236444346 + 117.3198682202*t)
	Z2 += 0.00000000025*np.cos(2.78460430400 + 209.3669421749*t)
	return Z2*t*t




def Mars_Z3 (t): # 70 terms of order 3

	Z3 = 0.
	Z3 += 0.00000489822*np.cos(2.06392886831 + 3340.6124266998*t)
	Z3 += 0.00000211337
	Z3 += 0.00000008245*np.cos(4.91827993759 + 6681.2248533996*t)
	Z3 += 0.00000007509*np.cos(5.39641448313 + 10021.8372800994*t)
	Z3 += 0.00000002012*np.cos(5.97751013737 + 13362.4497067992*t)
	Z3 += 0.00000001302*np.cos(4.84806136860 + 213.299095438*t)
	Z3 += 0.00000001364*np.cos(2.43564490971 + 206.1855484372*t)
	Z3 += 0.00000000936*np.cos(1.69954459864 + 529.6909650946*t)
	Z3 += 0.00000000894*np.cos(4.14160765510 + 3337.0893083508*t)
	Z3 += 0.00000000716*np.cos(1.50799790954 + 220.4126424388*t)
	Z3 += 0.00000000738*np.cos(1.31585722361 + 3496.032826134*t)
	Z3 += 0.00000000438*np.cos(0.21206488997 + 16703.062133499*t)
	Z3 += 0.00000000423*np.cos(4.54129218357 + 536.8045120954*t)
	Z3 += 0.00000000433*np.cos(3.01442752205 + 3185.1920272656*t)
	Z3 += 0.00000000282*np.cos(5.95440671732 + 522.5774180938*t)
	Z3 += 0.00000000189*np.cos(6.19720760024 + 3344.1355450488*t)
	Z3 += 0.00000000154*np.cos(2.72447562109 + 3097.88382272579*t)
	Z3 += 0.00000000104*np.cos(6.24240951231 + 3894.1818295422*t)
	Z3 += 0.00000000118*np.cos(5.13964237695 + 3532.0606928114*t)
	Z3 += 0.00000000101*np.cos(3.84221865764 + 2942.4634232916*t)
	Z3 += 0.00000000095*np.cos(0.71711229332 + 5621.8429232104*t)
	Z3 += 0.00000000113*np.cos(5.32734880412 + 2544.3144198834*t)
	Z3 += 0.00000000086*np.cos(0.66972591039 + 20043.6745601988*t)
	Z3 += 0.00000000090*np.cos(0.51819099535 + 433.7117378768*t)
	Z3 += 0.00000000094*np.cos(1.55249614896 + 419.4846438752*t)
	Z3 += 0.00000000079*np.cos(1.38892285542 + 227.5261894396*t)
	Z3 += 0.00000000096*np.cos(1.67496098296 + 3583.3410306738*t)
	Z3 += 0.00000000094*np.cos(0.17438010106 + 426.598190876*t)
	Z3 += 0.00000000067*np.cos(0.38442120869 + 6684.7479717486*t)
	Z3 += 0.00000000065*np.cos(0.30552815689 + 3339.6321056316*t)
	Z3 += 0.00000000057*np.cos(0.60718635813 + 155.4203994342*t)
	Z3 += 0.00000000055*np.cos(4.34004913784 + 2787.0430238574*t)
	Z3 += 0.00000000060*np.cos(4.89147405929 + 4292.3308329504*t)
	Z3 += 0.00000000049*np.cos(0.41339413590 + 2146.1654164752*t)
	Z3 += 0.00000000048*np.cos(3.55422009987 + 4690.4798363586*t)
	Z3 += 0.00000000061*np.cos(3.43120186635 + 6525.8044539654*t)
	Z3 += 0.00000000050*np.cos(2.64433369691 + 199.0720014364*t)
	Z3 += 0.00000000041*np.cos(1.23015429434 + 3723.508958923*t)
	Z3 += 0.00000000042*np.cos(2.65785543548 + 7.1135470008*t)
	Z3 += 0.00000000040*np.cos(2.30430764194 + 5088.6288397668*t)
	Z3 += 0.00000000050*np.cos(2.81423639662 + 1059.3819301892*t)
	Z3 += 0.00000000028*np.cos(4.95849994924 + 3149.1641605882*t)
	Z3 += 0.00000000028*np.cos(5.89394518040 + 515.463871093*t)
	Z3 += 0.00000000027*np.cos(5.17159300173 + 1066.49547719*t)
	Z3 += 0.00000000027*np.cos(5.04320678135 + 4136.9104335162*t)
	Z3 += 0.00000000024*np.cos(4.43334493389 + 543.9180590962*t)
	Z3 += 0.00000000027*np.cos(5.55557540179 + 2388.8940204492*t)
	Z3 += 0.00000000024*np.cos(3.81281177380 + 3341.592747768*t)
	Z3 += 0.00000000026*np.cos(5.61220088462 + 639.897286314*t)
	Z3 += 0.00000000021*np.cos(0.32087488984 + 1990.745017041*t)
	Z3 += 0.00000000019*np.cos(0.93486196404 + 3340.629680352*t)
	Z3 += 0.00000000019*np.cos(5.18727563972 + 3340.5951730476*t)
	Z3 += 0.00000000019*np.cos(3.01047939751 + 2957.7158944766*t)
	Z3 += 0.00000000018*np.cos(0.02154769101 + 74.7815985673*t)
	Z3 += 0.00000000018*np.cos(1.32103617334 + 1592.5960136328*t)
	Z3 += 0.00000000018*np.cos(1.66958194924 + 1194.4470102246*t)
	Z3 += 0.00000000017*np.cos(0.16564148066 + 23384.2869868986*t)
	Z3 += 0.00000000023*np.cos(0.28320385867 + 2281.2304965106*t)
	Z3 += 0.00000000017*np.cos(2.57902262762 + 14.2270940016*t)
	Z3 += 0.00000000018*np.cos(6.04232503139 + 7079.3738568078*t)
	Z3 += 0.00000000018*np.cos(3.82519107334 + 4535.0594369244*t)
	Z3 += 0.00000000018*np.cos(1.08925641141 + 5486.777843175*t)
	Z3 += 0.00000000015*np.cos(5.86641996435 + 5884.9268465832*t)
	Z3 += 0.00000000021*np.cos(2.78318267000 + 398.1490034082*t)
	Z3 += 0.00000000016*np.cos(0.95206290089 + 10025.3603984484*t)
	Z3 += 0.00000000015*np.cos(4.77431089840 + 6489.776587288*t)
	Z3 += 0.00000000015*np.cos(4.15953675017 + 6677.7017350506*t)
	Z3 += 0.00000000015*np.cos(5.82992617855 + 3333.498879699*t)
	Z3 += 0.00000000013*np.cos(3.07320748125 + 210.1177017003*t)
	Z3 += 0.00000000012*np.cos(5.68952008926 + 1052.2683831884*t)
	return Z3*t*t*t




def Mars_Z4 (t): # 27 terms of order 4

	Z4 = 0.
	Z4 += 0.00000015151
	Z4 += 0.00000010395*np.cos(3.33271505543 + 3340.6124266998*t)
	Z4 += 0.00000000256*np.cos(3.76243173590 + 10021.8372800994*t)
	Z4 += 0.00000000201*np.cos(0.78166958626 + 6681.2248533996*t)
	Z4 += 0.00000000164*np.cos(4.10546661445 + 206.1855484372*t)
	Z4 += 0.00000000116*np.cos(2.88209375806 + 3496.032826134*t)
	Z4 += 0.00000000117*np.cos(4.32489294756 + 13362.4497067992*t)
	Z4 += 0.00000000072*np.cos(6.04348211714 + 220.4126424388*t)
	Z4 += 0.00000000070*np.cos(6.10651561968 + 213.299095438*t)
	Z4 += 0.00000000060*np.cos(1.43227319487 + 3185.1920272656*t)
	Z4 += 0.00000000047*np.cos(5.67989354532 + 3337.0893083508*t)
	Z4 += 0.00000000044*np.cos(2.79536133222 + 536.8045120954*t)
	Z4 += 0.00000000033*np.cos(4.85494204968 + 16703.062133499*t)
	Z4 += 0.00000000026*np.cos(1.66128176108 + 522.5774180938*t)
	Z4 += 0.00000000026*np.cos(4.32019018052 + 3097.88382272579*t)
	Z4 += 0.00000000016*np.cos(5.95724279756 + 227.5261894396*t)
	Z4 += 0.00000000015*np.cos(0.04553834693 + 3583.3410306738*t)
	Z4 += 0.00000000011*np.cos(4.33140895473 + 199.0720014364*t)
	Z4 += 0.00000000012*np.cos(5.02489197754 + 433.7117378768*t)
	Z4 += 0.00000000009*np.cos(5.34528843607 + 20043.6745601988*t)
	Z4 += 0.00000000008*np.cos(1.15875671922 + 3894.1818295422*t)
	Z4 += 0.00000000008*np.cos(1.82884997572 + 2787.0430238574*t)
	Z4 += 0.00000000010*np.cos(1.73117485258 + 6525.8044539654*t)
	Z4 += 0.00000000008*np.cos(4.21120519002 + 6684.7479717486*t)
	Z4 += 0.00000000008*np.cos(3.36029048603 + 419.4846438752*t)
	Z4 += 0.00000000006*np.cos(1.39462759175 + 515.463871093*t)
	Z4 += 0.00000000005*np.cos(2.67511593664 + 543.9180590962*t)
	return Z4*t*t*t*t




def Mars_Z5 (t): # 10 terms of order 5

	Z5 = 0.
	Z5 += 0.00000000505*np.cos(4.62558150778 + 3340.6124266998*t)
	Z5 -= 0.00000000077
	Z5 += 0.00000000027*np.cos(5.16649907997 + 6681.2248533996*t)
	Z5 += 0.00000000015*np.cos(4.43919916342 + 3496.032826134*t)
	Z5 += 0.00000000015*np.cos(5.75563126750 + 206.1855484372*t)
	Z5 += 0.00000000006*np.cos(6.16271063962 + 3185.1920272656*t)
	Z5 += 0.00000000005*np.cos(4.29978807671 + 220.4126424388*t)
	Z5 += 0.00000000004*np.cos(1.89844577416 + 10021.8372800994*t)
	Z5 += 0.00000000004*np.cos(2.66634523708 + 13362.4497067992*t)
	Z5 += 0.00000000003*np.cos(0.96254361103 + 536.8045120954*t)
	return Z5*t*t*t*t*t





def Jupiter_X0 (t): # 1083 terms of order 0

	X0 = 0.
	X0 += 5.19167797375*np.cos(0.59945079482 + 529.6909650946*t)
	X0 -= 0.36633268070
	X0 += 0.12581924842*np.cos(0.94911581432 + 1059.3819301892*t)
	X0 += 0.01499237862*np.cos(0.73175554601 + 522.5774180938*t)
	X0 += 0.01474818211*np.cos(3.61736901402 + 536.8045120954*t)
	X0 += 0.00457316096*np.cos(1.29883699143 + 1589.0728952838*t)
	X0 += 0.00302068886*np.cos(5.17370377723 + 7.1135470008*t)
	X0 += 0.00385749947*np.cos(2.01222596811 + 103.0927742186*t)
	X0 += 0.00192562451*np.cos(4.98733787115 + 426.598190876*t)
	X0 += 0.00150783740*np.cos(6.11831671330 + 110.2063212194*t)
	X0 += 0.00144750651*np.cos(5.55980048541 + 632.7837393132*t)
	X0 += 0.00154896097*np.cos(2.17051189575 + 38.1330356378*t)
	X0 += 0.00137575946*np.cos(4.01399498370 + 213.299095438*t)
	X0 += 0.00103396684*np.cos(6.19327175097 + 1052.2683831884*t)
	X0 += 0.00114092461*np.cos(0.01567031739 + 1162.4747044078*t)
	X0 += 0.00072025988*np.cos(3.96117200382 + 1066.49547719*t)
	X0 += 0.00082181886*np.cos(2.33944503932 + 74.7815985673*t)
	X0 += 0.00059429203*np.cos(4.45768709661 + 949.1756089698*t)
	X0 += 0.00068217918*np.cos(3.44053291909 + 846.0828347512*t)
	X0 += 0.00047092829*np.cos(1.43942906349 + 419.4846438752*t)
	X0 += 0.00029905661*np.cos(2.93170826549 + 206.1855484372*t)
	X0 += 0.00026609536*np.cos(4.85102664902 + 323.5054166574*t)
	X0 += 0.00019708639*np.cos(1.64891620821 + 2118.7638603784*t)
	X0 += 0.00016318258*np.cos(1.94286700529 + 316.3918696566*t)
	X0 += 0.00016086488*np.cos(0.87974686945 + 515.463871093*t)
	X0 += 0.00014193776*np.cos(2.07763165706 + 742.9900605326*t)
	X0 += 0.00015178545*np.cos(6.25878811430 + 735.8765135318*t)
	X0 += 0.00011412363*np.cos(3.48145943220 + 543.9180590962*t)
	X0 += 0.00012143698*np.cos(3.75229920148 + 525.7588118315*t)
	X0 += 0.00011984824*np.cos(0.58568596255 + 533.6231183577*t)
	X0 += 0.00008644882*np.cos(3.44286036345 + 639.897286314*t)
	X0 += 0.00008215382*np.cos(5.56679457251 + 1478.8665740644*t)
	X0 += 0.00008685802*np.cos(0.38261930513 + 1692.1656695024*t)
	X0 += 0.00007420564*np.cos(5.98378614130 + 956.2891559706*t)
	X0 += 0.00007509247*np.cos(0.92899131174 + 1265.5674786264*t)
	X0 += 0.00007648488*np.cos(0.14179788518 + 1581.959348283*t)
	X0 += 0.00005313717*np.cos(1.10494056939 + 526.5095713569*t)
	X0 += 0.00005213514*np.cos(3.23235134289 + 532.8723588323*t)
	X0 += 0.00005784803*np.cos(5.03723192214 + 14.2270940016*t)
	X0 += 0.00004618326*np.cos(3.75817737683 + 1375.7737998458*t)
	X0 += 0.00003936106*np.cos(4.30892684064 + 1596.1864422846*t)
	X0 += 0.00004563043*np.cos(2.15085906522 + 95.9792272178*t)
	X0 += 0.00004327077*np.cos(3.89002424313 + 220.4126424388*t)
	X0 += 0.00002951688*np.cos(3.85995854320 + 309.2783226558*t)
	X0 += 0.00002857648*np.cos(6.00878402632 + 117.3198682202*t)
	X0 += 0.00002488143*np.cos(4.20187706224 + 433.7117378768*t)
	X0 += 0.00002672563*np.cos(3.18723991996 + 1169.5882514086*t)
	X0 += 0.00002384137*np.cos(5.96358219365 + 1045.1548361876*t)
	X0 += 0.00001868284*np.cos(0.52057031963 + 1155.361157407*t)
	X0 += 0.00001936427*np.cos(5.91866009507 + 625.6701923124*t)
	X0 += 0.00001630097*np.cos(4.41892602527 + 942.062061969*t)
	X0 += 0.00001440172*np.cos(5.76918543554 + 853.196381752*t)
	X0 += 0.00001516494*np.cos(0.81626038026 + 76.2660712756*t)
	X0 += 0.00001360798*np.cos(1.34765113779 + 1368.660252845*t)
	X0 += 0.00001663482*np.cos(1.94059445684 + 838.9692877504*t)
	X0 += 0.00001032537*np.cos(0.08907922138 + 1795.258443721*t)
	X0 += 0.00001067098*np.cos(5.07387579789 + 149.5631971346*t)
	X0 += 0.00000990516*np.cos(3.08612292420 + 1272.6810256272*t)
	X0 += 0.00000930888*np.cos(3.10022521384 + 199.0720014364*t)
	X0 += 0.00000933612*np.cos(1.99938798806 + 2648.454825473*t)
	X0 += 0.00000858009*np.cos(3.71316873719 + 529.6427809848*t)
	X0 += 0.00000857915*np.cos(0.62779457369 + 529.7391492044*t)
	X0 += 0.00001087247*np.cos(1.13406114807 + 527.2432845398*t)
	X0 += 0.00001079612*np.cos(3.20528367741 + 532.1386456494*t)
	X0 += 0.00000839752*np.cos(4.14398978456 + 3.9321532631*t)
	X0 += 0.00000941768*np.cos(1.57467292003 + 412.3710968744*t)
	X0 += 0.00000931768*np.cos(5.34596957134 + 380.12776796*t)
	X0 += 0.00000665063*np.cos(6.08445124633 + 2008.557539159*t)
	X0 += 0.00000747564*np.cos(4.70874474138 + 330.6189636582*t)
	X0 += 0.00000692649*np.cos(1.33754227289 + 1063.3140834523*t)
	X0 += 0.00000811333*np.cos(3.25488240013 + 36.6485629295*t)
	X0 += 0.00000606163*np.cos(0.11412084921 + 2111.6503133776*t)
	X0 += 0.00000680059*np.cos(0.29377298028 + 528.7277572481*t)
	X0 += 0.00000678173*np.cos(4.04669842391 + 530.6541729411*t)
	X0 += 0.00000764311*np.cos(4.22738498884 + 39.6175083461*t)
	X0 += 0.00000572396*np.cos(0.74312323669 + 2221.856634597*t)
	X0 += 0.00000563762*np.cos(4.06331552135 + 1055.4497769261*t)
	X0 += 0.00000647377*np.cos(5.12508128670 + 984.6003316219*t)
	X0 += 0.00000613227*np.cos(0.27981730970 + 73.297125859*t)
	X0 += 0.00000459723*np.cos(3.82638947289 + 1073.6090241908*t)
	X0 += 0.00000537449*np.cos(0.67271519943 + 1685.0521225016*t)
	X0 += 0.00000507782*np.cos(6.24549107143 + 728.762966531*t)
	X0 += 0.00000404919*np.cos(2.98797080277 + 909.8187330546*t)
	X0 += 0.00000302826*np.cos(4.07250918100 + 1905.4647649404*t)
	X0 += 0.00000412910*np.cos(4.52688796799 + 454.9093665273*t)
	X0 += 0.00000389104*np.cos(6.05998982226 + 604.4725636619*t)
	X0 += 0.00000277414*np.cos(0.65881724776 + 1485.9801210652*t)
	X0 += 0.00000302929*np.cos(5.06489509412 + 529.1697002328*t)
	X0 += 0.00000302537*np.cos(5.56013245851 + 530.2122299564*t)
	X0 += 0.00000385879*np.cos(4.91129214731 + 3.1813937377*t)
	X0 += 0.00000254215*np.cos(3.58455165888 + 1062.5633239269*t)
	X0 += 0.00000244625*np.cos(1.59356787543 + 1258.4539316256*t)
	X0 += 0.00000226848*np.cos(4.65765215856 + 2125.8774073792*t)
	X0 += 0.00000287123*np.cos(2.95650668065 + 305.3461693927*t)
	X0 += 0.00000288864*np.cos(2.01288582181 + 1.4844727083*t)
	X0 += 0.00000224639*np.cos(3.50099817325 + 1699.2792165032*t)
	X0 += 0.00000205851*np.cos(1.03216914658 + 1898.3512179396*t)
	X0 += 0.00000189500*np.cos(1.04127882419 + 508.3503240922*t)
	X0 += 0.00000235354*np.cos(0.92416939424 + 1056.2005364515*t)
	X0 += 0.00000188745*np.cos(5.71463346844 + 99.1606209555*t)
	X0 += 0.00000206908*np.cos(4.01833624142 + 490.3340891794*t)
	X0 += 0.00000178910*np.cos(6.10221913977 + 526.7702037878*t)
	X0 += 0.00000176836*np.cos(4.52323119656 + 532.6117264014*t)
	X0 += 0.00000164532*np.cos(3.47714847114 + 528.9402055692*t)
	X0 += 0.00000164428*np.cos(0.86380550119 + 530.44172462*t)
	X0 += 0.00000191830*np.cos(0.31043364558 + 569.0478410098*t)
	X0 += 0.00000217410*np.cos(5.68326440647 + 453.424893819*t)
	X0 += 0.00000154478*np.cos(1.26243237737 + 519.3960243561*t)
	X0 += 0.00000208112*np.cos(3.39287053066 + 1439.5096981492*t)
	X0 += 0.00000166245*np.cos(3.75639965819 + 227.5261894396*t)
	X0 += 0.00000157870*np.cos(4.32802743718 + 525.4981794006*t)
	X0 += 0.00000143523*np.cos(3.31703643087 + 647.0108333148*t)
	X0 += 0.00000155329*np.cos(0.01448229911 + 533.8837507886*t)
	X0 += 0.00000142903*np.cos(2.39474928383 + 11.0457002639*t)
	X0 += 0.00000194673*np.cos(5.30459820002 + 1021.2488945514*t)
	X0 += 0.00000174912*np.cos(1.21651063074 + 1471.7530270636*t)
	X0 += 0.00000145297*np.cos(4.02621175684 + 302.164775655*t)
	X0 += 0.00000162930*np.cos(0.49071349850 + 2001.4439921582*t)
	X0 += 0.00000144173*np.cos(1.33176686779 + 1788.1448967202*t)
	X0 += 0.00000162873*np.cos(0.56256179898 + 835.0371344873*t)
	X0 += 0.00000120463*np.cos(3.08300146416 + 539.9859058331*t)
	X0 += 0.00000135543*np.cos(3.80015599161 + 540.7366653585*t)
	X0 += 0.00000121698*np.cos(3.78870416955 + 524.0618908021*t)
	X0 += 0.00000119917*np.cos(0.55319582506 + 535.3200393871*t)
	X0 += 0.00000123931*np.cos(3.38834236611 + 983.1158589136*t)
	X0 += 0.00000123677*np.cos(3.34199708319 + 525.0250986486*t)
	X0 += 0.00000104330*np.cos(3.76551670027 + 529.5309064002*t)
	X0 += 0.00000104330*np.cos(0.57516894884 + 529.851023789*t)
	X0 += 0.00000134037*np.cos(0.10262313066 + 1574.8458012822*t)
	X0 += 0.00000104555*np.cos(3.32891948747 + 551.031606097*t)
	X0 += 0.00000114344*np.cos(3.33978613495 + 750.1036075334*t)
	X0 += 0.00000116048*np.cos(0.99764796582 + 534.3568315406*t)
	X0 += 0.00000122688*np.cos(4.90630336311 + 524.2743391232*t)
	X0 += 0.00000102968*np.cos(4.41451543211 + 963.4027029714*t)
	X0 += 0.00000120782*np.cos(5.71565359127 + 535.107591066*t)
	X0 += 0.00000104648*np.cos(3.53719182083 + 224.3447957019*t)
	X0 += 0.00000110530*np.cos(0.32528528527 + 2324.9494088156*t)
	X0 += 0.00000093067*np.cos(0.02724953444 + 1382.8873468466*t)
	X0 += 0.00000093733*np.cos(3.23721821583 + 1802.3719907218*t)
	X0 += 0.00000093554*np.cos(3.03340802500 + 440.8252848776*t)
	X0 += 0.00000096331*np.cos(4.88712179178 + 21.3406410024*t)
	X0 += 0.00000071762*np.cos(5.72663475912 + 415.5524906121*t)
	X0 += 0.00000087496*np.cos(1.66679783619 + 831.8557407496*t)
	X0 += 0.00000072096*np.cos(4.02261318625 + 529.9034134157*t)
	X0 += 0.00000072096*np.cos(0.31807246212 + 529.4785167735*t)
	X0 += 0.00000073548*np.cos(0.73533236562 + 2214.7430875962*t)
	X0 += 0.00000095404*np.cos(5.93817256254 + 35.4247226521*t)
	X0 += 0.00000072139*np.cos(0.26833059020 + 518.6452648307*t)
	X0 += 0.00000072878*np.cos(4.46132747640 + 39.3568759152*t)
	X0 += 0.00000071452*np.cos(5.67202354183 + 511.5317178299*t)
	X0 += 0.00000060011*np.cos(1.64274398708 + 1361.5467058442*t)
	X0 += 0.00000082322*np.cos(2.58316696077 + 531.1754378029*t)
	X0 += 0.00000068707*np.cos(4.98553488860 + 547.8502123593*t)
	X0 += 0.00000074277*np.cos(4.41925598870 + 173.9422195228*t)
	X0 += 0.00000079198*np.cos(1.73075015296 + 528.2064923863*t)
	X0 += 0.00000065451*np.cos(1.02004729709 + 2104.5367663768*t)
	X0 += 0.00000065958*np.cos(0.29867934563 + 2317.8358618148*t)
	X0 += 0.00000055536*np.cos(4.79223936260 + 643.8294395771*t)
	X0 += 0.00000069870*np.cos(5.74691938507 + 148.0787244263*t)
	X0 += 0.00000055262*np.cos(2.27825840796 + 107.0249274817*t)
	X0 += 0.00000052105*np.cos(4.62588942965 + 960.2213092337*t)
	X0 += 0.00000052148*np.cos(1.98729626729 + 1048.3362299253*t)
	X0 += 0.00000051560*np.cos(1.64669499054 + 514.7131115676*t)
	X0 += 0.00000066065*np.cos(0.59752988902 + 230.5645708254*t)
	X0 += 0.00000050111*np.cos(3.13528773297 + 387.2413149608*t)
	X0 += 0.00000049711*np.cos(2.69410661219 + 544.6688186216*t)
	X0 += 0.00000067372*np.cos(1.02825832038 + 1364.7280995819*t)
	X0 += 0.00000050617*np.cos(0.31750972006 + 2641.3412784722*t)
	X0 += 0.00000052715*np.cos(1.48379175765 + 1056.9342496344*t)
	X0 += 0.00000057133*np.cos(0.72237577020 + 92.0470739547*t)
	X0 += 0.00000045698*np.cos(0.23070104259 + 2538.2485042536*t)
	X0 += 0.00000060120*np.cos(3.78022495970 + 1061.829610744*t)
	X0 += 0.00000043674*np.cos(0.36671900326 + 2.4476805548*t)
	X0 += 0.00000049748*np.cos(1.88152542617 + 679.2541622292*t)
	X0 += 0.00000059167*np.cos(0.89478754330 + 494.2662424425*t)
	X0 += 0.00000044499*np.cos(1.08024596826 + 430.5303441391*t)
	X0 += 0.00000058551*np.cos(2.31298999222 + 1057.8974574809*t)
	X0 += 0.00000047067*np.cos(2.35234857561 + 3178.1457905676*t)
	X0 += 0.00000041687*np.cos(0.97719980019 + 1059.430114299*t)
	X0 += 0.00000045598*np.cos(4.91679890859 + 312.4597163935*t)
	X0 += 0.00000046173*np.cos(5.50676597516 + 2428.0421830342*t)
	X0 += 0.00000040142*np.cos(1.53613009421 + 618.5566453116*t)
	X0 += 0.00000048294*np.cos(5.47091338823 + 106.2741679563*t)
	X0 += 0.00000048551*np.cos(5.94316336415 + 1038.0412891868*t)
	X0 += 0.00000039904*np.cos(3.59119482737 + 70.8494453042*t)
	X0 += 0.00000049105*np.cos(4.15096345615 + 523.5406259403*t)
	X0 += 0.00000051698*np.cos(3.46161709042 + 565.1156877467*t)
	X0 += 0.00000037509*np.cos(1.12992183128 + 2751.5475996916*t)
	X0 += 0.00000041687*np.cos(4.06257397973 + 1059.3337460794*t)
	X0 += 0.00000039658*np.cos(2.00248258969 + 1148.2476104062*t)
	X0 += 0.00000041541*np.cos(5.44680900827 + 1514.2912967165*t)
	X0 += 0.00000040916*np.cos(4.62466156885 + 10.2949407385*t)
	X0 += 0.00000040913*np.cos(0.18694472876 + 18.1592472647*t)
	X0 += 0.00000036012*np.cos(2.20109779973 + 1891.2376709388*t)
	X0 += 0.00000044449*np.cos(0.19000018391 + 535.8413042489*t)
	X0 += 0.00000036844*np.cos(5.73755081465 + 529.4303326637*t)
	X0 += 0.00000036844*np.cos(4.88632014089 + 529.9515975255*t)
	X0 += 0.00000034069*np.cos(1.16404842727 + 672.1406152284*t)
	X0 += 0.00000036613*np.cos(4.18935208995 + 934.9485149682*t)
	X0 += 0.00000041452*np.cos(1.77606071152 + 1593.0050485469*t)
	X0 += 0.00000033000*np.cos(3.84595186757 + 522.529233984*t)
	X0 += 0.00000035445*np.cos(0.77567886722 + 522.6256022036*t)
	X0 += 0.00000046145*np.cos(3.74589770529 + 1512.8068240082*t)
	X0 += 0.00000034850*np.cos(4.49564263533 + 1060.3451380357*t)
	X0 += 0.00000032480*np.cos(5.83189707139 + 124.433415221*t)
	X0 += 0.00000044411*np.cos(4.40635138657 + 760.25553592*t)
	X0 += 0.00000030459*np.cos(4.38569932563 + 1585.1407420207*t)
	X0 += 0.00000037824*np.cos(4.58891701161 + 35.1640902212*t)
	X0 += 0.00000034535*np.cos(4.91328831102 + 142.4496501338*t)
	X0 += 0.00000028933*np.cos(1.19798110052 + 121.2520214833*t)
	X0 += 0.00000034151*np.cos(2.93509104577 + 628.8515860501*t)
	X0 += 0.00000029909*np.cos(3.55918899910 + 536.7563279856*t)
	X0 += 0.00000027497*np.cos(0.49110736349 + 536.8526962052*t)
	X0 += 0.00000028394*np.cos(0.99780388701 + 2420.9286360334*t)
	X0 += 0.00000029129*np.cos(4.64629764448 + 422.6660376129*t)
	X0 += 0.00000033061*np.cos(6.08469159790 + 567.8240007324*t)
	X0 += 0.00000027675*np.cos(5.33831999428 + 528.4189407074*t)
	X0 += 0.00000027586*np.cos(5.28551011249 + 530.9629894818*t)
	X0 += 0.00000033966*np.cos(6.20368876731 + 885.4397106664*t)
	X0 += 0.00000028696*np.cos(5.72932042298 + 746.9222137957*t)
	X0 += 0.00000024445*np.cos(2.50670090490 + 99.9113804809*t)
	X0 += 0.00000027889*np.cos(0.03859353899 + 2634.2277314714*t)
	X0 += 0.00000032993*np.cos(0.64338422669 + 1058.4187223427*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000024004*np.cos(5.67806719063 + 523.0986829556*t)
	X0 += 0.00000030583*np.cos(4.71118187651 + 1023.9572075371*t)
	X0 += 0.00000031118*np.cos(0.05397426900 + 437.6438911399*t)
	X0 += 0.00000030281*np.cos(0.86331183831 + 63.7358983034*t)
	X0 += 0.00000027098*np.cos(0.93568939988 + 497.4476361802*t)
	X0 += 0.00000026727*np.cos(3.20464380077 + 1158.5425511447*t)
	X0 += 0.00000022304*np.cos(4.19158626805 + 491.5579294568*t)
	X0 += 0.00000024825*np.cos(0.15973065561 + 1134.1635287565*t)
	X0 += 0.00000021870*np.cos(4.94490217150 + 536.2832472336*t)
	X0 += 0.00000024660*np.cos(0.71366313977 + 2531.1349572528*t)
	X0 += 0.00000022284*np.cos(0.46679621201 + 521.6142102473*t)
	X0 += 0.00000025671*np.cos(5.71444480895 + 636.7158925763*t)
	X0 += 0.00000019591*np.cos(4.17431823492 + 1603.2999892854*t)
	X0 += 0.00000024399*np.cos(6.07393779031 + 299.1263942692*t)
	X0 += 0.00000021305*np.cos(6.08565625589 + 202.2533951741*t)
	X0 += 0.00000023213*np.cos(3.43195395791 + 561.934294009*t)
	X0 += 0.00000023267*np.cos(0.46827104623 + 85.8272988312*t)
	X0 += 0.00000022744*np.cos(1.67012539714 + 71.8126531507*t)
	X0 += 0.00000024685*np.cos(4.22056041469 + 621.7380390493*t)
	X0 += 0.00000019054*np.cos(2.10509472382 + 327.4375699205*t)
	X0 += 0.00000018867*np.cos(2.10875171086 + 5.6290742925*t)
	X0 += 0.00000019676*np.cos(1.99772061272 + 423.4167971383*t)
	X0 += 0.00000021220*np.cos(0.04126045470 + 495.7507151508*t)
	X0 += 0.00000024582*np.cos(5.14527726997 + 860.3099287528*t)
	X0 += 0.00000020285*np.cos(2.60649643877 + 217.2312487011*t)
	X0 += 0.00000018237*np.cos(4.59056549084 + 953.1077622329*t)
	X0 += 0.00000019507*np.cos(1.91029017314 + 1098.7388061044*t)
	X0 += 0.00000020953*np.cos(2.57869987681 + 458.8415197904*t)
	X0 += 0.00000018009*np.cos(3.96639354797 + 24.3790223882*t)
	X0 += 0.00000017586*np.cos(2.02614680916 + 2207.6295405954*t)
	X0 += 0.00000017177*np.cos(2.03437805617 + 1464.6394800628*t)
	X0 += 0.00000017286*np.cos(3.26937441157 + 191.9584544356*t)
	X0 += 0.00000018075*np.cos(1.99928862686 + 600.5404103988*t)
	X0 += 0.00000017873*np.cos(3.86678470802 + 537.7677199419*t)
	X0 += 0.00000020924*np.cos(0.03035795063 + 1166.4068576709*t)
	X0 += 0.00000022286*np.cos(3.93734569173 + 2.9689454166*t)
	X0 += 0.00000016936*np.cos(4.26571329038 + 2435.155730035*t)
	X0 += 0.00000018926*np.cos(4.29407736621 + 563.6312150384*t)
	X0 += 0.00000016624*np.cos(3.85361101962 + 2228.9701815978*t)
	X0 += 0.00000020994*np.cos(4.98103028185 + 88.865680217*t)
	X0 += 0.00000016159*np.cos(0.21846540542 + 1049.0869894507*t)
	X0 += 0.00000019778*np.cos(0.93154236594 + 505.3119427064*t)
	X0 += 0.00000018387*np.cos(3.75284915185 + 1969.2006632438*t)
	X0 += 0.00000016117*np.cos(1.17216875347 + 1677.9385755008*t)
	X0 += 0.00000016272*np.cos(3.90786168126 + 526.9826521089*t)
	X0 += 0.00000016170*np.cos(0.43269852873 + 532.3992780803*t)
	X0 += 0.00000015853*np.cos(3.02589483126 + 501.3797894433*t)
	X0 += 0.00000016073*np.cos(0.59289977863 + 32.2433289144*t)
	X0 += 0.00000015212*np.cos(0.95366780101 + 988.532484885*t)
	X0 += 0.00000015273*np.cos(3.52315111020 + 460.5384408198*t)
	X0 += 0.00000020643*np.cos(4.21375998760 + 209.3669421749*t)
	X0 += 0.00000015831*np.cos(3.98950707166 + 151.0476698429*t)
	X0 += 0.00000018342*np.cos(3.41235746795 + 554.0699874828*t)
	X0 += 0.00000016176*np.cos(2.52644603855 + 4.665866446*t)
	X0 += 0.00000014712*np.cos(5.41386260565 + 1058.8606653274*t)
	X0 += 0.00000014529*np.cos(4.85959006178 + 1070.4276304531*t)
	X0 += 0.00000018464*np.cos(0.16167109877 + 77.7505439839*t)
	X0 += 0.00000017154*np.cos(0.48603059401 + 114.1384744825*t)
	X0 += 0.00000018655*np.cos(4.97897470623 + 1151.4290041439*t)
	X0 += 0.00000018715*np.cos(0.73543500526 + 523.4711899711*t)
	X0 += 0.00000014496*np.cos(1.33864296077 + 558.0021407459*t)
	X0 += 0.00000015859*np.cos(2.97884415831 + 138.5174968707*t)
	X0 += 0.00000015092*np.cos(1.62201170536 + 2015.6710861598*t)
	X0 += 0.00000013768*np.cos(4.48236015474 + 67.6680515665*t)
	X0 += 0.00000017922*np.cos(3.60811042035 + 535.9107402181*t)
	X0 += 0.00000013832*np.cos(1.07361243872 + 1585.8915015461*t)
	X0 += 0.00000014583*np.cos(3.99010215681 + 28.3111756513*t)
	X0 += 0.00000013750*np.cos(2.09722252387 + 450.9772132642*t)
	X0 += 0.00000013536*np.cos(0.76908575684 + 2737.32050569*t)
	X0 += 0.00000013707*np.cos(3.60868435075 + 498.6714764576*t)
	X0 += 0.00000013957*np.cos(3.93496730766 + 1592.2542890215*t)
	X0 += 0.00000013013*np.cos(0.78393846491 + 598.8434893694*t)
	X0 += 0.00000013524*np.cos(5.01956785845 + 2655.5683724738*t)
	X0 += 0.00000014250*np.cos(3.29326648288 + 462.0229135281*t)
	X0 += 0.00000014315*np.cos(5.64097491228 + 1550.939859646*t)
	X0 += 0.00000015356*np.cos(5.69682578495 + 33.9402499438*t)
	X0 += 0.00000012263*np.cos(1.85125474032 + 635.9651330509*t)
	X0 += 0.00000014741*np.cos(1.09335801256 + 945.2434557067*t)
	X0 += 0.00000013719*np.cos(5.63893195637 + 113.3877149571*t)
	X0 += 0.00000012034*np.cos(3.12964294602 + 938.1299087059*t)
	X0 += 0.00000012616*np.cos(0.73397485703 + 560.7104537316*t)
	X0 += 0.00000012686*np.cos(1.52579404870 + 531.387886124*t)
	X0 += 0.00000012686*np.cos(2.81489159967 + 527.9940440652*t)
	X0 += 0.00000011798*np.cos(2.42709371040 + 731.9443602687*t)
	X0 += 0.00000015037*np.cos(4.51296688554 + 155.7829722581*t)
	X0 += 0.00000013428*np.cos(3.15625492155 + 5.4166259714*t)
	X0 += 0.00000013010*np.cos(5.25935589736 + 2744.4340526908*t)
	X0 += 0.00000014712*np.cos(5.90909648145 + 1059.903195051*t)
	X0 += 0.00000011828*np.cos(2.23340715865 + 608.404716925*t)
	X0 += 0.00000011471*np.cos(1.17828159225 + 0.9632078465*t)
	X0 += 0.00000015363*np.cos(1.10456127711 + 381.6122406683*t)
	X0 += 0.00000011186*np.cos(1.62250458708 + 528.2546764961*t)
	X0 += 0.00000011186*np.cos(2.71818106129 + 531.1272536931*t)
	X0 += 0.00000012032*np.cos(0.99005156584 + 597.3590166611*t)
	X0 += 0.00000010863*np.cos(4.64117868734 + 248.7238180901*t)
	X0 += 0.00000013322*np.cos(0.82171739269 + 944.9828232758*t)
	X0 += 0.00000014119*np.cos(0.13240053257 + 378.6432952517*t)
	X0 += 0.00000014298*np.cos(4.58560781567 + 1173.5204046717*t)
	X0 += 0.00000010615*np.cos(6.13511053253 + 629.6023455755*t)
	X0 += 0.00000011694*np.cos(6.10110767151 + 2950.619601128*t)
	X0 += 0.00000010338*np.cos(4.38574439238 + 429.7795846137*t)
	X0 += 0.00000010323*np.cos(1.24104744878 + 605.9570363702*t)
	X0 += 0.00000013781*np.cos(4.55129649335 + 337.732510659*t)
	X0 += 0.00000010145*np.cos(2.78138825669 + 210.1177017003*t)
	X0 += 0.00000009728*np.cos(0.58564087027 + 1159.2933106701*t)
	X0 += 0.00000009732*np.cos(2.62318310146 + 1251.3403846248*t)
	X0 += 0.00000009592*np.cos(1.71806518721 + 1781.0313497194*t)
	X0 += 0.00000009542*np.cos(1.84490363894 + 2524.021410252*t)
	X0 += 0.00000013151*np.cos(4.43614253391 + 1041.2226829245*t)
	X0 += 0.00000010946*np.cos(5.58575024763 + 46.470422916*t)
	X0 += 0.00000009005*np.cos(2.61830190154 + 1165.6560981455*t)
	X0 += 0.00000009077*np.cos(3.85345236239 + 754.0357607965*t)
	X0 += 0.00000008886*np.cos(1.89018107575 + 530.914805372*t)
	X0 += 0.00000008886*np.cos(2.45050457262 + 528.4671248172*t)
	X0 += 0.00000009816*np.cos(4.64751787428 + 69.1525242748*t)
	X0 += 0.00000008893*np.cos(1.64117950395 + 195.1398481733*t)
	X0 += 0.00000009911*np.cos(4.45225741623 + 9.5612275556*t)
	X0 += 0.00000012109*np.cos(4.85223951419 + 1020.025054274*t)
	X0 += 0.00000012231*np.cos(6.14422943214 + 72.0732855816*t)
	X0 += 0.00000011861*np.cos(6.05937783312 + 721.6494195302*t)
	X0 += 0.00000008635*np.cos(0.16436387127 + 1056.4611688824*t)
	X0 += 0.00000010790*np.cos(0.63662383032 + 530.5847369719*t)
	X0 += 0.00000010790*np.cos(3.70406181805 + 528.7971932173*t)
	X0 += 0.00000007989*np.cos(3.82641746989 + 1058.6311706638*t)
	X0 += 0.00000008394*np.cos(2.58792092563 + 525.5463635104*t)
	X0 += 0.00000010592*np.cos(0.63539606039 + 2847.5268269094*t)
	X0 += 0.00000007749*np.cos(1.75600352899 + 521.8266585684*t)
	X0 += 0.00000008309*np.cos(1.75332367881 + 533.8355666788*t)
	X0 += 0.00000009795*np.cos(4.81680434248 + 114.3991069134*t)
	X0 += 0.00000009319*np.cos(1.23585389267 + 483.2205421786*t)
	X0 += 0.00000010339*np.cos(4.58616303508 + 319.5732633943*t)
	X0 += 0.00000007601*np.cos(2.58490717494 + 537.5552716208*t)
	X0 += 0.00000010477*np.cos(3.37774704651 + 456.3938392356*t)
	X0 += 0.00000008635*np.cos(4.87197749696 + 1062.302691496*t)
	X0 += 0.00000007859*np.cos(0.38734430101 + 1064.7985561606*t)
	X0 += 0.00000007602*np.cos(0.36299136019 + 1063.5747158832*t)
	X0 += 0.00000009231*np.cos(5.43148824800 + 8.0767548473*t)
	X0 += 0.00000007989*np.cos(1.21335631002 + 1060.1326897146*t)
	X0 += 0.00000009972*np.cos(2.04366896945 + 685.4739373527*t)
	X0 += 0.00000008026*np.cos(1.98667531129 + 405.2575498736*t)
	X0 += 0.00000007215*np.cos(4.30475971943 + 31.019488637*t)
	X0 += 0.00000007729*np.cos(2.97295947216 + 320.3240229197*t)
	X0 += 0.00000006822*np.cos(2.29868018477 + 166.828672522*t)
	X0 += 0.00000006743*np.cos(2.78685743070 + 1054.7160637432*t)
	X0 += 0.00000007685*np.cos(6.15668649529 + 334.5511169213*t)
	X0 += 0.00000007484*np.cos(0.64173631183 + 952.3570027075*t)
	X0 += 0.00000008440*np.cos(2.58974655797 + 1201.831580323*t)
	X0 += 0.00000006906*np.cos(3.07910623893 + 100.6450936638*t)
	X0 += 0.00000007169*np.cos(0.13492833770 + 842.1506814881*t)
	X0 += 0.00000006629*np.cos(0.53834433594 + 3053.7123753466*t)
	X0 += 0.00000008934*np.cos(0.96120225738 + 602.9880909536*t)
	X0 += 0.00000007767*np.cos(0.09155679295 + 408.4389436113*t)
	X0 += 0.00000007493*np.cos(3.51969165167 + 2332.0629558164*t)
	X0 += 0.00000007136*np.cos(0.03448152668 + 739.8086667949*t)
	X0 += 0.00000006677*np.cos(0.45441778626 + 1912.5783119412*t)
	X0 += 0.00000006322*np.cos(1.02024397349 + 1994.3304451574*t)
	X0 += 0.00000008709*np.cos(3.26440854068 + 576.1613880106*t)
	X0 += 0.00000007535*np.cos(3.00289317558 + 1060.8664028975*t)
	X0 += 0.00000006829*np.cos(2.18322886511 + 284.1485407422*t)
	X0 += 0.00000008600*np.cos(0.67499551222 + 2854.6403739102*t)
	X0 += 0.00000006151*np.cos(4.66705028005 + 1091.6252591036*t)
	X0 += 0.00000007341*np.cos(6.04359053153 + 6.2197751235*t)
	X0 += 0.00000006859*np.cos(4.99347916841 + 945.9942152321*t)
	X0 += 0.00000006730*np.cos(2.13274400504 + 528.0464336919*t)
	X0 += 0.00000006730*np.cos(2.20794164333 + 531.3354964973*t)
	X0 += 0.00000007602*np.cos(4.67235401511 + 1055.1891444952*t)
	X0 += 0.00000006013*np.cos(0.39505360832 + 1035.002907801*t)
	X0 += 0.00000005971*np.cos(4.49604367073 + 498.1983957056*t)
	X0 += 0.00000007321*np.cos(5.96564868559 + 2957.7331481288*t)
	X0 += 0.00000005811*np.cos(3.54915086435 + 216.4804891757*t)
	X0 += 0.00000005831*np.cos(0.91029898197 + 1276.6131788903*t)
	X0 += 0.00000007683*np.cos(4.78953562962 + 247.2393453818*t)
	X0 += 0.00000005605*np.cos(2.83446874702 + 513.2286388593*t)
	X0 += 0.00000005914*np.cos(5.25663173098 + 1053.9653042178*t)
	X0 += 0.00000005507*np.cos(6.11803493365 + 561.1835344836*t)
	X0 += 0.00000005497*np.cos(5.97220710600 + 810.6581120991*t)
	X0 += 0.00000005666*np.cos(1.34586791176 + 1064.0477966352*t)
	X0 += 0.00000005378*np.cos(1.50621701403 + 546.1532913299*t)
	X0 += 0.00000006378*np.cos(4.76469958996 + 1493.093668066*t)
	X0 += 0.00000005234*np.cos(3.23939752237 + 355.7487455718*t)
	X0 += 0.00000006789*np.cos(4.06132305563 + 303.8616966844*t)
	X0 += 0.00000006815*np.cos(3.11788390976 + 1053.7528558967*t)
	X0 += 0.00000005065*np.cos(4.11506105627 + 1059.2218714948*t)
	X0 += 0.00000005099*np.cos(4.22926958912 + 1176.7017984094*t)
	X0 += 0.00000004952*np.cos(1.58008800266 + 2840.4132799086*t)
	X0 += 0.00000005422*np.cos(3.42310480407 + 757.2171545342*t)
	X0 += 0.00000004897*np.cos(5.68226364532 + 245.5424243524*t)
	X0 += 0.00000005382*np.cos(3.62538236868 + 512.4254897072*t)
	X0 += 0.00000004985*np.cos(3.60490329992 + 234.6397364404*t)
	X0 += 0.00000004765*np.cos(1.45902602837 + 2097.423219376*t)
	X0 += 0.00000005065*np.cos(0.92471272365 + 1059.5419888836*t)
	X0 += 0.00000005175*np.cos(5.88453458110 + 3267.0114707846*t)
	X0 += 0.00000005666*np.cos(4.11643761931 + 908.3342603463*t)
	X0 += 0.00000004955*np.cos(3.41906309446 + 1069.6768709277*t)
	X0 += 0.00000005153*np.cos(0.71530340802 + 546.956440482*t)
	X0 += 0.00000004760*np.cos(2.46960565366 + 415.2918581812*t)
	X0 += 0.00000004911*np.cos(1.51731652916 + 512.2824773553*t)
	X0 += 0.00000004553*np.cos(3.05075122003 + 509.2440959695*t)
	X0 += 0.00000006109*np.cos(5.67990095410 + 111.4301614968*t)
	X0 += 0.00000004324*np.cos(1.28993461232 + 550.1378342197*t)
	X0 += 0.00000004652*np.cos(4.74896633148 + 1489.9122743283*t)
	X0 += 0.00000004403*np.cos(2.46826855364 + 1127.0499817557*t)
	X0 += 0.00000004625*np.cos(2.09838701102 + 857.1285350151*t)
	X0 += 0.00000004688*np.cos(0.82987219835 + 504.561183181*t)
	X0 += 0.00000004144*np.cos(3.28540382801 + 970.5162499722*t)
	X0 += 0.00000005736*np.cos(4.94808815046 + 707.5653378805*t)
	X0 += 0.00000004256*np.cos(4.52622489765 + 512.1648572763*t)
	X0 += 0.00000004431*np.cos(6.20712357569 + 519.656656787*t)
	X0 += 0.00000005723*np.cos(0.80521226018 + 1065.0110044817*t)
	X0 += 0.00000004076*np.cos(0.44309694438 + 469.8872200543*t)
	X0 += 0.00000005654*np.cos(3.17912882291 + 280.9671470045*t)
	X0 += 0.00000004761*np.cos(3.08265578516 + 850.0149880143*t)
	X0 += 0.00000005007*np.cos(6.09092690792 + 491.8185618877*t)
	X0 += 0.00000003987*np.cos(2.63449604548 + 447.9388318784*t)
	X0 += 0.00000004311*np.cos(1.91087363576 + 416.3032501375*t)
	X0 += 0.00000004806*np.cos(4.82950723208 + 1289.9465010146*t)
	X0 += 0.00000004127*np.cos(2.41265579129 + 1578.0271950199*t)
	X0 += 0.00000004072*np.cos(6.09764619553 + 547.2170729129*t)
	X0 += 0.00000004414*np.cos(3.50154180015 + 554.8207470082*t)
	X0 += 0.00000004733*np.cos(2.24216539355 + 1087.6931058405*t)
	X0 += 0.00000003900*np.cos(2.34423548886 + 739.0579072695*t)
	X0 += 0.00000004172*np.cos(3.39627466227 + 203.0041546995*t)
	X0 += 0.00000004864*np.cos(0.51744939195 + 3163.918696566*t)
	X0 += 0.00000004002*np.cos(4.87046745482 + 916.9322800554*t)
	X0 += 0.00000004569*np.cos(4.91237033477 + 724.8308132679*t)
	X0 += 0.00000004115*np.cos(5.12865246696 + 1012.9115072732*t)
	X0 += 0.00000003715*np.cos(1.90541997007 + 479.2883889155*t)
	X0 += 0.00000003971*np.cos(5.21041592079 + 1894.4190646765*t)
	X0 += 0.00000004628*np.cos(4.53026378084 + 567.5633683015*t)
	X0 += 0.00000004155*np.cos(5.40151847566 + 782.3469364478*t)
	X0 += 0.00000004429*np.cos(4.90565615927 + 1025.4416802454*t)
	X0 += 0.00000004649*np.cos(4.64759909895 + 105.5404547734*t)
	X0 += 0.00000004166*np.cos(2.66734467932 + 1587.5884225755*t)
	X0 += 0.00000004550*np.cos(3.96931916890 + 237.6781178262*t)
	X0 += 0.00000004232*np.cos(4.10305254748 + 2042.4977891028*t)
	X0 += 0.00000004613*np.cos(4.23969121478 + 295.0512286542*t)
	X0 += 0.00000003608*np.cos(5.64136273905 + 277.0349937414*t)
	X0 += 0.00000003571*np.cos(3.65947912820 + 1080.7225711916*t)
	X0 += 0.00000003544*np.cos(5.95476908217 + 849.2642284889*t)
	X0 += 0.00000004598*np.cos(0.76405567220 + 146.594251718*t)
	X0 += 0.00000003497*np.cos(4.37215725203 + 1059.5943785103*t)
	X0 += 0.00000003507*np.cos(3.90044894199 + 589.4947101349*t)
	X0 += 0.00000003472*np.cos(2.42807639358 + 580.0935412737*t)
	X0 += 0.00000004605*np.cos(2.01079969091 + 391.1734682239*t)
	X0 += 0.00000003415*np.cos(0.93397733419 + 3067.9394693482*t)
	X0 += 0.00000003680*np.cos(2.78358470505 + 547.0994528339*t)
	X0 += 0.00000003974*np.cos(0.64083518043 + 3171.0322435668*t)
	X0 += 0.00000003446*np.cos(5.94538006088 + 1049.8207026336*t)
	X0 += 0.00000003807*np.cos(1.72304764409 + 102.1295663721*t)
	X0 += 0.00000003698*np.cos(4.34881325753 + 326.6868103951*t)
	X0 += 0.00000003345*np.cos(2.01843885286 + 103.1409583284*t)
	X0 += 0.00000003338*np.cos(5.11644597796 + 103.0445901088*t)
	X0 += 0.00000003565*np.cos(5.42059424242 + 81.7521332162*t)
	X0 += 0.00000003497*np.cos(0.66761652789 + 1059.1694818681*t)
	X0 += 0.00000003252*np.cos(0.25412920997 + 3370.1042450032*t)
	X0 += 0.00000003350*np.cos(5.33479619431 + 1077.5411774539*t)
	X0 += 0.00000004028*np.cos(2.14386378215 + 81.0013736908*t)
	X0 += 0.00000003455*np.cos(4.99170171719 + 488.8496164711*t)
	X0 += 0.00000004402*np.cos(4.47865911288 + 987.3086446076*t)
	X0 += 0.00000004179*np.cos(2.21527051149 + 373.9079928365*t)
	X0 += 0.00000003659*np.cos(5.44567820919 + 104.0559820651*t)
	X0 += 0.00000003291*np.cos(0.58946936691 + 97.6761482472*t)
	X0 += 0.00000003303*np.cos(4.42205069017 + 539.7252734022*t)
	X0 += 0.00000003982*np.cos(0.94891503004 + 986.0848043302*t)
	X0 += 0.00000004012*np.cos(2.19807079079 + 668.2084619653*t)
	X0 += 0.00000003967*np.cos(2.90360026128 + 486.4019359163*t)
	X0 += 0.00000003184*np.cos(2.21814040831 + 654.1243803156*t)
	X0 += 0.00000004191*np.cos(5.68692135829 + 351.8165923087*t)
	X0 += 0.00000003955*np.cos(3.61063004152 + 1123.1178284926*t)
	X0 += 0.00000003729*np.cos(5.24253765141 + 977.4867846211*t)
	X0 += 0.00000002958*np.cos(5.96791430978 + 527.6852275245*t)
	X0 += 0.00000002958*np.cos(4.65595664577 + 531.6967026647*t)
	X0 += 0.00000003911*np.cos(1.81273764385 + 306.830642101*t)
	X0 += 0.00000002909*np.cos(4.64604855654 + 522.6892926784*t)
	X0 += 0.00000002909*np.cos(5.97782239901 + 536.6926375108*t)
	X0 += 0.00000003893*np.cos(5.83260636489 + 812.1425848074*t)
	X0 += 0.00000003118*np.cos(5.63216999615 + 570.5323137181*t)
	X0 += 0.00000003463*np.cos(4.17287676793 + 1591.5205758386*t)
	X0 += 0.00000002836*np.cos(1.20731250237 + 1269.4996318895*t)
	X0 += 0.00000003283*np.cos(2.91724442703 + 108.7218485111*t)
	X0 += 0.00000002870*np.cos(1.83388013858 + 1586.625214729*t)
	X0 += 0.00000002796*np.cos(1.24128563131 + 3156.8051495652*t)
	X0 += 0.00000002903*np.cos(5.86858378208 + 504.4181708291*t)
	X0 += 0.00000002725*np.cos(1.62696049996 + 3281.2385647862*t)
	X0 += 0.00000002849*np.cos(2.52315879532 + 1884.124123938*t)
	X0 += 0.00000003556*np.cos(1.43724697553 + 572.9799942729*t)
	X0 += 0.00000002918*np.cos(1.02389618778 + 967.3348562345*t)
	X0 += 0.00000002702*np.cos(2.83822051301 + 78.7137518304*t)
	X0 += 0.00000002661*np.cos(3.41200091519 + 107.7586406646*t)
	X0 += 0.00000003601*np.cos(1.64093908538 + 833.552661779*t)
	X0 += 0.00000002668*np.cos(5.37581667810 + 911.3032057629*t)
	X0 += 0.00000002715*np.cos(4.74043601220 + 554.9637593601*t)
	X0 += 0.00000002622*np.cos(2.45936066033 + 134.5853436076*t)
	X0 += 0.00000002627*np.cos(3.82215257787 + 144.1465711632*t)
	X0 += 0.00000003601*np.cos(2.04227185598 + 991.7138786227*t)
	X0 += 0.00000002821*np.cos(2.63735750033 + 502.8642621516*t)
	X0 += 0.00000002566*np.cos(5.17871233769 + 93.531546663*t)
	X0 += 0.00000003142*np.cos(6.19570189655 + 539.2521926502*t)
	X0 += 0.00000002731*np.cos(6.24416997170 + 522.4655435092*t)
	X0 += 0.00000002731*np.cos(4.37970098385 + 536.91638668*t)
	X0 += 0.00000003175*np.cos(1.25554977339 + 520.129737539*t)
	X0 += 0.00000003337*np.cos(2.55862908493 + 775.233389447*t)
	X0 += 0.00000002456*np.cos(3.04358904051 + 1074.3597837162*t)
	X0 += 0.00000003083*np.cos(4.79549905942 + 3060.8259223474*t)
	X0 += 0.00000002369*np.cos(0.89961386019 + 2310.722314814*t)
	X0 += 0.00000002685*np.cos(1.67677017290 + 556.5176680376*t)
	X0 += 0.00000002456*np.cos(1.99618473941 + 1044.4040766622*t)
	X0 += 0.00000003031*np.cos(4.94699249364 + 521.0929453855*t)
	X0 += 0.00000003031*np.cos(5.67687846191 + 538.2889848037*t)
	X0 += 0.00000002647*np.cos(2.21150970566 + 611.4430983108*t)
	X0 += 0.00000002779*np.cos(4.06587587287 + 1065.6017053127*t)
	X0 += 0.00000003226*np.cos(6.17392127144 + 522.7898664149*t)
	X0 += 0.00000003226*np.cos(4.44994968410 + 536.5920637743*t)
	X0 += 0.00000003100*np.cos(4.48597567816 + 1438.0252254409*t)
	X0 += 0.00000002350*np.cos(4.85021460619 + 285.3723810196*t)
	X0 += 0.00000002947*np.cos(2.57601562056 + 1819.6374661092*t)
	X0 += 0.00000002452*np.cos(2.19106724331 + 1090.4014188262*t)
	X0 += 0.00000002323*np.cos(4.17904065081 + 529.0578256482*t)
	X0 += 0.00000002323*np.cos(0.16164499756 + 530.324104541*t)
	X0 += 0.00000002982*np.cos(0.59289983624 + 109.9456887885*t)
	X0 += 0.00000002337*np.cos(2.52600500225 + 1474.9344208013*t)
	X0 += 0.00000003159*np.cos(0.76090441015 + 457.617679513*t)
	X0 += 0.00000003023*np.cos(2.94123144657 + 526.722019678*t)
	X0 += 0.00000003023*np.cos(1.39945420180 + 532.6599105112*t)
	X0 += 0.00000002627*np.cos(3.80975739889 + 1094.8066528413*t)
	X0 += 0.00000002186*np.cos(2.35390986413 + 162.8965192589*t)
	X0 += 0.00000002177*np.cos(1.28491274387 + 2413.8150890326*t)
	X0 += 0.00000002273*np.cos(1.32684908668 + 1589.1210793936*t)
	X0 += 0.00000002362*np.cos(5.63895709044 + 3583.4033404412*t)
	X0 += 0.00000002201*np.cos(5.72550332247 + 2043.9822618111*t)
	X0 += 0.00000002350*np.cos(3.14771594022 + 902.7051860538*t)
	X0 += 0.00000002837*np.cos(5.47064673260 + 1440.9941708575*t)
	X0 += 0.00000002584*np.cos(2.41036745166 + 2122.6960136415*t)
	X0 += 0.00000002140*np.cos(3.00473448189 + 241.6102710893*t)
	X0 += 0.00000002201*np.cos(0.31427215056 + 376.1956146969*t)
	X0 += 0.00000002216*np.cos(4.40413629466 + 1053.2315910349*t)
	X0 += 0.00000002435*np.cos(5.80690345453 + 3274.1250177854*t)
	X0 += 0.00000002251*np.cos(3.73285596763 + 1067.4586850365*t)
	X0 += 0.00000002781*np.cos(3.62986106775 + 451.9404211107*t)
	X0 += 0.00000002419*np.cos(1.65592259758 + 31.492569389*t)
	X0 += 0.00000002042*np.cos(0.45345339204 + 732.6951197941*t)
	X0 += 0.00000002525*np.cos(5.46312983734 + 373.0142209592*t)
	X0 += 0.00000002747*np.cos(3.74658101391 + 1261.6353253633*t)
	X0 += 0.00000002035*np.cos(5.41793570571 + 523.849442481*t)
	X0 += 0.00000002035*np.cos(5.20593524984 + 535.5324877082*t)
	X0 += 0.00000002366*np.cos(2.81483964657 + 3707.8367556622*t)
	X0 += 0.00000002380*np.cos(4.12001373580 + 429.0458714308*t)
	X0 += 0.00000002298*np.cos(2.51147282142 + 225.8292684102*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000002407*np.cos(1.65593453429 + 824.7421937488*t)
	X0 += 0.00000002223*np.cos(3.54290082979 + 842.9014410135*t)
	X0 += 0.00000002548*np.cos(2.30029523646 + 1128.534454464*t)
	X0 += 0.00000002313*np.cos(3.46887757106 + 145.6310438715*t)
	X0 += 0.00000002358*np.cos(0.28705194880 + 3480.3105662226*t)
	X0 += 0.00000001911*np.cos(1.27847307998 + 501.2367770914*t)
	X0 += 0.00000002560*np.cos(5.75789982732 + 232.0490435337*t)
	X0 += 0.00000001903*np.cos(5.97222852188 + 1254.5217783625*t)
	X0 += 0.00000002480*np.cos(5.94758800259 + 610.6923387854*t)
	X0 += 0.00000002279*np.cos(5.72874534306 + 1482.7987273275*t)
	X0 += 0.00000001873*np.cos(2.16130448423 + 1208.9451273238*t)
	X0 += 0.00000002510*np.cos(3.56542524478 + 601.7642506762*t)
	X0 += 0.00000002186*np.cos(5.05662323853 + 1553.6481726317*t)
	X0 += 0.00000001823*np.cos(0.11309992342 + 111.1695290659*t)
	X0 += 0.00000002024*np.cos(0.75324302754 + 59.8037450403*t)
	X0 += 0.00000001958*np.cos(2.65760348463 + 109.2431133729*t)
	X0 += 0.00000001875*np.cos(4.96409845324 + 1590.0361031303*t)
	X0 += 0.00000002360*np.cos(2.96313117699 + 488.63716815*t)
	X0 += 0.00000002199*np.cos(2.81488304964 + 298.2326223919*t)
	X0 += 0.00000002128*np.cos(0.30012341312 + 821.703812363*t)
	X0 += 0.00000002046*np.cos(3.01987263602 + 1567.7322542814*t)
	X0 += 0.00000001954*np.cos(0.78523241391 + 1415.130675761*t)
	X0 += 0.00000001787*np.cos(5.23586420667 + 1059.6425626201*t)
	X0 += 0.00000001998*np.cos(3.65279516743 + 1432.3961511484*t)
	X0 += 0.00000002173*np.cos(0.53973434031 + 1065.5322693435*t)
	X0 += 0.00000002273*np.cos(4.41222326623 + 1589.024711174*t)
	X0 += 0.00000001887*np.cos(3.53080429283 + 417.0369633204*t)
	X0 += 0.00000001716*np.cos(4.22633880361 + 503.8274699981*t)
	X0 += 0.00000001787*np.cos(4.50113127825 + 56.6223513026*t)
	X0 += 0.00000001851*np.cos(2.94909390732 + 110.2545053292*t)
	X0 += 0.00000001948*np.cos(0.06784201686 + 1446.62324515*t)
	X0 += 0.00000001829*np.cos(0.32427522713 + 1578.7779545453*t)
	X0 += 0.00000002146*np.cos(2.12285077619 + 1363.2436268736*t)
	X0 += 0.00000001744*np.cos(5.75944789009 + 1051.3051753419*t)
	X0 += 0.00000002096*np.cos(1.34830261581 + 570.7447620392*t)
	X0 += 0.00000001608*np.cos(0.11434714708 + 555.5544601911*t)
	X0 += 0.00000001681*np.cos(5.05615470433 + 543.1843459133*t)
	X0 += 0.00000001681*np.cos(5.56771625121 + 516.1975842759*t)
	X0 += 0.00000001656*np.cos(6.18525423988 + 3686.4961146598*t)
	X0 += 0.00000002027*np.cos(1.05859637798 + 50.4025761791*t)
	X0 += 0.00000001607*np.cos(1.86217702449 + 465.9550667912*t)
	X0 += 0.00000001997*np.cos(4.09599188755 + 362.8622925726*t)
	X0 += 0.00000001573*np.cos(0.99918451715 + 3473.1970192218*t)
	X0 += 0.00000001620*np.cos(4.04604445763 + 683.1863154923*t)
	X0 += 0.00000001775*np.cos(3.68378563186 + 1688.2335162393*t)
	X0 += 0.00000001551*np.cos(2.34276361323 + 593.426863398*t)
	X0 += 0.00000001649*np.cos(2.83516671724 + 1354.4331588434*t)
	X0 += 0.00000001607*np.cos(2.36250219357 + 222.8603229936*t)
	X0 += 0.00000001791*np.cos(0.10409422402 + 502.6036297207*t)
	X0 += 0.00000001533*np.cos(0.91717120275 + 1052.3165672982*t)
	X0 += 0.00000001872*np.cos(2.94680344134 + 1141.1340634054*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001597*np.cos(2.27829199459 + 2200.5159935946*t)
	X0 += 0.00000001894*np.cos(1.68941410908 + 229.0800981171*t)
	X0 += 0.00000001950*np.cos(2.53468264013 + 487.1526954417*t)
	X0 += 0.00000001486*np.cos(1.74964460410 + 1518.2234499796*t)
	X0 += 0.00000001691*np.cos(0.69039681436 + 1226.2106027112*t)
	X0 += 0.00000001539*np.cos(5.57331447211 + 65.2203710117*t)
	X0 += 0.00000001466*np.cos(4.96866285281 + 426.5500067662*t)
	X0 += 0.00000001581*np.cos(6.26565156779 + 696.5196376166*t)
	X0 += 0.00000001746*np.cos(4.43362462057 + 1467.8208738005*t)
	X0 += 0.00000001484*np.cos(3.98628996611 + 995.6460318858*t)
	X0 += 0.00000001673*np.cos(4.23659174125 + 556.7783004685*t)
	X0 += 0.00000001573*np.cos(1.54983748502 + 425.6349830295*t)
	X0 += 0.00000001613*np.cos(3.52494290600 + 1268.7488723641*t)
	X0 += 0.00000001696*np.cos(4.04893974553 + 313.2104759189*t)
	X0 += 0.00000001787*np.cos(6.08709488043 + 1059.1212977583*t)
	X0 += 0.00000001459*np.cos(1.86680810334 + 426.6463749858*t)
	X0 += 0.00000001860*np.cos(0.59121810077 + 1160.027023853*t)
	X0 += 0.00000001599*np.cos(0.99304321709 + 1588.1096874373*t)
	X0 += 0.00000001645*np.cos(0.25602007166 + 630.3360587584*t)
	X0 += 0.00000001796*np.cos(2.27748034433 + 424.1505103212*t)
	X0 += 0.00000001802*np.cos(1.81981056283 + 572.2292347475*t)
	X0 += 0.00000001812*np.cos(1.18636472457 + 1340.3490771937*t)
	X0 += 0.00000001340*np.cos(5.68788468184 + 1058.109905802*t)
	X0 += 0.00000001380*np.cos(4.13060050591 + 384.0599212231*t)
	X0 += 0.00000001346*np.cos(0.84106067159 + 1066.5436612998*t)
	X0 += 0.00000001303*np.cos(3.84567508869 + 203.7378678824*t)
	X0 += 0.00000001714*np.cos(2.66549816260 + 1164.9223849626*t)
	X0 += 0.00000001547*np.cos(0.43253240963 + 1097.514965827*t)
	X0 += 0.00000001293*np.cos(2.98651040858 + 394.3548619616*t)
	X0 += 0.00000001329*np.cos(2.37930449726 + 1628.429771199*t)
	X0 += 0.00000001657*np.cos(2.95696862208 + 473.068613792*t)
	X0 += 0.00000001353*np.cos(4.16373125033 + 2498.8916283384*t)
	X0 += 0.00000001375*np.cos(3.98044437537 + 1093.322180133*t)
	X0 += 0.00000001299*np.cos(0.48747523459 + 1357.6145525811*t)
	X0 += 0.00000001302*np.cos(1.30247274619 + 494.4786907636*t)
	X0 += 0.00000001267*np.cos(0.05480522680 + 1162.5228885176*t)
	X0 += 0.00000001321*np.cos(5.18040372739 + 990.2294059144*t)
	X0 += 0.00000001569*np.cos(0.55945561191 + 827.9235874865*t)
	X0 += 0.00000001423*np.cos(3.96899444518 + 1052.2201990786*t)
	X0 += 0.00000001690*np.cos(0.44964896142 + 1696.0978227655*t)
	X0 += 0.00000001234*np.cos(1.89692910755 + 436.1594184316*t)
	X0 += 0.00000001258*np.cos(3.15493584077 + 1162.426520298*t)
	X0 += 0.00000001419*np.cos(3.11149524713 + 1138.0956820196*t)
	X0 += 0.00000001232*np.cos(1.13768047601 + 2730.2069586892*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001393*np.cos(0.44415833192 + 958.7368365254*t)
	X0 += 0.00000001576*np.cos(0.31444350094 + 422.405405182*t)
	X0 += 0.00000001248*np.cos(0.03995118053 + 350.3321196004*t)
	X0 += 0.00000001464*np.cos(3.90911748945 + 1066.4472930802*t)
	X0 += 0.00000001194*np.cos(5.78013067722 + 774.0095491696*t)
	X0 += 0.00000001176*np.cos(5.65250585005 + 632.831923423*t)
	X0 += 0.00000001235*np.cos(1.29434837440 + 1027.1386012748*t)
	X0 += 0.00000001192*np.cos(3.03821340895 + 564.9032394256*t)
	X0 += 0.00000001337*np.cos(5.18329748556 + 427.5613987225*t)
	X0 += 0.00000001581*np.cos(0.42493803144 + 642.3449668688*t)
	X0 += 0.00000001186*np.cos(4.67064465062 + 2114.8317071153*t)
	X0 += 0.00000001340*np.cos(6.03068103344 + 1161.5114965613*t)
	X0 += 0.00000001260*np.cos(2.78493696942 + 633.7469471597*t)
	X0 += 0.00000001309*np.cos(3.48078253389 + 1163.4379122543*t)
	X0 += 0.00000001172*np.cos(2.47238605689 + 632.7355552034*t)
	X0 += 0.00000001120*np.cos(4.59709741934 + 709.0498105888*t)
	X0 += 0.00000001340*np.cos(5.63507440526 + 1060.6539545764*t)
	X0 += 0.00000001483*np.cos(1.40459440941 + 210.8514148832*t)
	X0 += 0.00000001471*np.cos(2.07056839465 + 635.231419868*t)
	X0 += 0.00000001112*np.cos(5.29416320994 + 1065.9742123282*t)
	X0 += 0.00000001108*np.cos(1.26512205010 + 1279.794572628*t)
	X0 += 0.00000001124*np.cos(1.88833997938 + 924.7965865816*t)
	X0 += 0.00000001129*np.cos(0.48786080710 + 915.235359026*t)
	X0 += 0.00000001308*np.cos(1.27136775865 + 913.7508863177*t)
	X0 += 0.00000001398*np.cos(1.23224313252 + 2627.1141844706*t)
	X0 += 0.00000001089*np.cos(5.17678553686 + 946.727928415*t)
	X0 += 0.00000001292*np.cos(1.34832291759 + 981.6313862053*t)
	X0 += 0.00000001132*np.cos(0.51083517505 + 1663.8544938511*t)
	X0 += 0.00000001259*np.cos(5.01927099823 + 1887.3055176757*t)
	X0 += 0.00000001153*np.cos(3.89300870077 + 395.105621487*t)
	X0 += 0.00000001064*np.cos(3.91071393639 + 1304.9243545416*t)
	X0 += 0.00000001202*np.cos(3.61933972889 + 269.9214467406*t)
	X0 += 0.00000001395*np.cos(1.40455747646 + 586.3133163972*t)
	X0 += 0.00000001451*np.cos(2.99312416234 + 244.318584075*t)
	X0 += 0.00000001120*np.cos(0.70794225879 + 103.6140390804*t)
	X0 += 0.00000001302*np.cos(4.07372257135 + 636.9765250072*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001037*np.cos(2.10542832786 + 1798.4398374587*t)
	X0 += 0.00000001026*np.cos(0.69958665556 + 414.0680179038*t)
	X0 += 0.00000001069*np.cos(5.46748862799 + 3899.7952100978*t)
	X0 += 0.00000001025*np.cos(0.81899907032 + 951.6232895246*t)
	X0 += 0.00000001422*np.cos(2.40975714524 + 152.5321425512*t)
	X0 += 0.00000001018*np.cos(2.44177900684 + 623.2225117576*t)
	X0 += 0.00000001172*np.cos(0.11078488057 + 3796.7024358792*t)
	X0 += 0.00000001047*np.cos(3.27708819978 + 177.8743727859*t)
	X0 += 0.00000001076*np.cos(5.08119196367 + 1681.1199692385*t)
	X0 += 0.00000001373*np.cos(1.13869327899 + 4590.910180489*t)
	X0 += 0.00000001300*np.cos(5.45256830638 + 758.7710632117*t)
	X0 += 0.00000001040*np.cos(2.40822308938 + 313.9441891018*t)
	X0 += 0.00000001117*np.cos(0.21068971066 + 102.5715093568*t)
	X0 += 0.00000000998*np.cos(4.87596707271 + 231.4583427027*t)
	X0 += 0.00000001033*np.cos(2.65742933066 + 1028.3624415522*t)
	X0 += 0.00000001022*np.cos(1.35922143520 + 1262.3860848887*t)
	X0 += 0.00000000975*np.cos(1.34801883307 + 665.0270682276*t)
	X0 += 0.00000001358*np.cos(4.62267092406 + 448.6895914038*t)
	X0 += 0.00000000980*np.cos(3.55997020263 + 961.705781942*t)
	X0 += 0.00000001042*np.cos(5.48044556857 + 170.7608257851*t)
	X0 += 0.00000000979*np.cos(2.33360006154 + 84.3428261229*t)
	X0 += 0.00000000955*np.cos(3.71244576511 + 645.3139122854*t)
	X0 += 0.00000001229*np.cos(5.40835035151 + 2004.364753465*t)
	X0 += 0.00000001283*np.cos(3.48533367730 + 252.6559713532*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000001119*np.cos(1.89211462832 + 1901.5326116773*t)
	X0 += 0.00000000950*np.cos(1.31425968942 + 1372.5924061081*t)
	X0 += 0.00000000954*np.cos(4.42643015968 + 215.7467759928*t)
	X0 += 0.00000001075*np.cos(0.57961253778 + 212.3358875915*t)
	X0 += 0.00000001070*np.cos(4.31120526838 + 214.2623032845*t)
	X0 += 0.00000001243*np.cos(4.71981497526 + 670.916774951*t)
	X0 += 0.00000001244*np.cos(2.87441597074 + 184.7272873558*t)
	X0 += 0.00000001099*np.cos(2.80854803975 + 611.5861106627*t)
	X0 += 0.00000001033*np.cos(5.44057825526 + 631.8205314667*t)
	X0 += 0.00000000888*np.cos(0.32570697301 + 1475.6851803267*t)
	X0 += 0.00000000881*np.cos(6.24114441352 + 4002.8879843164*t)
	X0 += 0.00000001098*np.cos(2.95983802473 + 137.0330241624*t)
	X0 += 0.00000001198*np.cos(2.56431700661 + 8521.1198767086*t)
	X0 += 0.00000001005*np.cos(1.02223932744 + 3384.3313390048*t)
	X0 += 0.00000000875*np.cos(1.38649800785 + 701.936263588*t)
	X0 += 0.00000001166*np.cos(1.68053256043 + 1511.3223512999*t)
	X0 += 0.00000000967*np.cos(0.19419846630 + 828.8173593638*t)
	X0 += 0.00000000889*np.cos(3.98790631605 + 213.2509113282*t)
	X0 += 0.00000000889*np.cos(0.90251570889 + 213.3472795478*t)
	X0 += 0.00000001147*np.cos(5.62237625874 + 1390.0008938474*t)
	X0 += 0.00000000873*np.cos(1.78823938585 + 322.0209439491*t)
	X0 += 0.00000001137*np.cos(1.25217878750 + 950.6600816781*t)
	X0 += 0.00000001061*np.cos(5.43420240433 + 1014.1353475506*t)
	X0 += 0.00000001061*np.cos(5.91924764699 + 1052.7896480502*t)
	X0 += 0.00000000907*np.cos(5.72880202106 + 3590.516887442*t)
	X0 += 0.00000000901*np.cos(1.99031678409 + 1482.0479678021*t)
	X0 += 0.00000001186*np.cos(3.87608972833 + 1291.4309737229*t)
	X0 += 0.00000000939*np.cos(4.90767990951 + 1703.2113697663*t)
	X0 += 0.00000001076*np.cos(3.77875560329 + 2861.753920911*t)
	X0 += 0.00000000877*np.cos(2.57720864413 + 357.4456666012*t)
	X0 += 0.00000000988*np.cos(3.77402129077 + 7210.9158184942*t)
	X0 += 0.00000000876*np.cos(2.04445500328 + 2516.9078632512*t)
	X0 += 0.00000001109*np.cos(1.10717230914 + 347.8844390456*t)
	X0 += 0.00000000826*np.cos(1.26237086555 + 20956.2620575166*t)
	X0 += 0.00000000914*np.cos(1.85190163894 + 1031.0707545379*t)
	X0 += 0.00000000997*np.cos(3.87267514750 + 1505.6932770074*t)
	X0 += 0.00000000810*np.cos(0.73866187950 + 3789.5888888784*t)
	X0 += 0.00000001118*np.cos(3.02477319721 + 892.5532576672*t)
	X0 += 0.00000000811*np.cos(2.26915207928 + 288.0806940053*t)
	X0 += 0.00000000883*np.cos(5.67539794824 + 526.1678467456*t)
	X0 += 0.00000000883*np.cos(4.94847300731 + 533.2140834436*t)
	X0 += 0.00000000832*np.cos(0.30355557156 + 348.635198571*t)
	X0 += 0.00000000790*np.cos(6.20154366253 + 106.0135355254*t)
	X0 += 0.00000000974*np.cos(3.07289069716 + 25035.6347583858*t)
	X0 += 0.00000001094*np.cos(4.49536324699 + 447.7958195265*t)
	X0 += 0.00000000787*np.cos(4.25746871915 + 1056.6736172035*t)
	X0 += 0.00000000880*np.cos(6.12038037656 + 1215.1649024473*t)
	X0 += 0.00000000839*np.cos(3.46918687285 + 4686.8894077068*t)
	X0 += 0.00000000965*np.cos(0.47893715886 + 1519.920371009*t)
	X0 += 0.00000001017*np.cos(3.23009565265 + 1019.7644218431*t)
	X0 += 0.00000000929*np.cos(2.33110288801 + 1130.2313754934*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000000951*np.cos(0.17980074695 + 25021.4076643842*t)
	X0 += 0.00000001003*np.cos(6.06276371667 + 112.6540017742*t)
	X0 += 0.00000000849*np.cos(3.78813650143 + 77.962992305*t)
	X0 += 0.00000001038*np.cos(2.60809280601 + 2545.3620512544*t)
	X0 += 0.00000000841*np.cos(3.14891407666 + 643.0786800517*t)
	X0 += 0.00000000778*np.cos(3.23372323101 + 1152.9134768522*t)
	X0 += 0.00000000782*np.cos(2.23832335246 + 1731.5225454176*t)
	X0 += 0.00000001032*np.cos(4.77018575989 + 3075.053016349*t)
	X0 += 0.00000000967*np.cos(3.36244704957 + 1744.8558675419*t)
	X0 += 0.00000000899*np.cos(1.08525568253 + 1053.1621550657*t)
	X0 += 0.00000000742*np.cos(2.00354172793 + 896.4854109303*t)
	X0 += 0.00000000989*np.cos(3.84990051274 + 566.3395280241*t)
	X0 += 0.00000000989*np.cos(0.49078513563 + 493.0424021651*t)
	X0 += 0.00000000742*np.cos(4.21703361262 + 948.2124011233*t)
	X0 += 0.00000000845*np.cos(3.59171270464 + 88.1149206916*t)
	X0 += 0.00000000929*np.cos(5.99864767246 + 110.1581371096*t)
	X0 += 0.00000000734*np.cos(5.35841388096 + 112.9146342051*t)
	X0 += 0.00000000777*np.cos(4.76415100520 + 5092.1519581158*t)
	X0 += 0.00000000766*np.cos(4.59479898800 + 402.2191684878*t)
	X0 += 0.00000000743*np.cos(6.13138764518 + 432.0148168474*t)
	X0 += 0.00000000870*np.cos(2.29117581191 + 537.3257769572*t)
	X0 += 0.00000000870*np.cos(5.19110249005 + 522.056153232*t)
	X0 += 0.00000000789*np.cos(1.67092370151 + 950.1388168163*t)
	X0 += 0.00000000897*np.cos(1.28062307416 + 5746.271337896*t)
	X0 += 0.00000000732*np.cos(5.42943652152 + 1600.1185955477*t)
	X0 += 0.00000000727*np.cos(3.55588420259 + 6011.4455234754*t)
	X0 += 0.00000000774*np.cos(4.89440898129 + 8617.0991039264*t)
	X0 += 0.00000000821*np.cos(5.63594703536 + 98.8999885246*t)
	X0 += 0.00000000765*np.cos(0.45676284977 + 77734.01845962799*t)
	X0 += 0.00000000725*np.cos(5.32450233982 + 172.2452984934*t)
	X0 += 0.00000000780*np.cos(1.36195167956 + 949.12742486*t)
	X0 += 0.00000000736*np.cos(2.50442271554 + 23969.1392811958*t)
	X0 += 0.00000000731*np.cos(5.83268492223 + 2108.4689196399*t)
	X0 += 0.00000000976*np.cos(0.79158818735 + 806.725958836*t)
	X0 += 0.00000000705*np.cos(4.27106025046 + 259.769518354*t)
	X0 += 0.00000000700*np.cos(5.59852494874 + 443.8636662634*t)
	X0 += 0.00000000902*np.cos(2.81720087957 + 3259.1471642584*t)
	X0 += 0.00000000815*np.cos(4.18553627599 + 3377.217792004*t)
	X0 += 0.00000000720*np.cos(5.01892865631 + 878.3261636656*t)
	X0 += 0.00000000705*np.cos(6.12374436623 + 657.1627617014*t)
	X0 += 0.00000000707*np.cos(0.03847974490 + 2218.6752408593*t)
	X0 += 0.00000000930*np.cos(2.49548323460 + 1436.5407527326*t)
	X0 += 0.00000000961*np.cos(4.34057596279 + 6915.8595893046*t)
	X0 += 0.00000000899*np.cos(4.97320917926 + 1570.9136480191*t)
	X0 += 0.00000000682*np.cos(0.26050257479 + 2225.7887878601*t)
	X0 += 0.00000000703*np.cos(1.37324117306 + 738.3241940866*t)
	X0 += 0.00000000764*np.cos(0.99241506715 + 1542.6024723678*t)
	X0 += 0.00000000739*np.cos(5.16398444319 + 131.4039498699*t)
	X0 += 0.00000000810*np.cos(3.48317459389 + 677.7696895209*t)
	X0 += 0.00000000721*np.cos(4.93463062086 + 64.9597385808*t)
	X0 += 0.00000000760*np.cos(0.78917661418 + 297.6419215609*t)
	X0 += 0.00000000784*np.cos(2.54541859576 + 451.7279727896*t)
	X0 += 0.00000000815*np.cos(2.42171652250 + 358.9301393095*t)
	X0 += 0.00000000842*np.cos(0.87893029284 + 369.0820676961*t)
	X0 += 0.00000000926*np.cos(2.97025862788 + 160.6088973985*t)
	X0 += 0.00000000923*np.cos(0.04638867043 + 179.3588454942*t)
	X0 += 0.00000000704*np.cos(0.48325377506 + 718.6110381444*t)
	X0 += 0.00000000702*np.cos(0.20613245347 + 153.4953503977*t)
	X0 += 0.00000000766*np.cos(2.39202105815 + 1834.6153196362*t)
	X0 += 0.00000000652*np.cos(4.16862455550 + 906.849787638*t)
	X0 += 0.00000000827*np.cos(4.33962122071 + 1371.8416465827*t)
	X0 += 0.00000000842*np.cos(3.38856884583 + 157.2674449664*t)
	X0 += 0.00000000792*np.cos(1.49965960928 + 377.1588225434*t)
	X0 += 0.00000000745*np.cos(4.45854548235 + 306.0969289181*t)
	X0 += 0.00000000639*np.cos(0.08156310396 + 650.9429865779*t)
	X0 += 0.00000000845*np.cos(5.93105751480 + 388.4651552382*t)
	X0 += 0.00000000767*np.cos(3.60652184093 + 927.8349679674*t)
	X0 += 0.00000000659*np.cos(5.75971948080 + 4216.1870797544*t)
	X0 += 0.00000000666*np.cos(3.04814223059 + 2439.0878832981*t)
	X0 += 0.00000000638*np.cos(1.13616165325 + 1688.9842757647*t)
	X0 += 0.00000000699*np.cos(3.61170438864 + 999.5781851489*t)
	X0 += 0.00000000848*np.cos(4.72504107277 + 444.7574381407*t)
	X0 += 0.00000000799*np.cos(3.74034594619 + 2274.5468326365*t)
	X0 += 0.00000000787*np.cos(1.20457511279 + 2943.5060541272*t)
	X0 += 0.00000000773*np.cos(1.76065838643 + 3333.9287628257*t)
	X0 += 0.00000000809*np.cos(5.17024953241 + 2431.9743362973*t)
	X0 += 0.00000000783*np.cos(1.81625662691 + 703.6331846174*t)
	X0 += 0.00000000657*np.cos(0.60457512347 + 1724.4089984168*t)
	X0 += 0.00000000805*np.cos(0.09901786383 + 1474.6737883704*t)
	X0 += 0.00000000645*np.cos(0.75334618858 + 1751.539531416*t)
	X0 += 0.00000000661*np.cos(2.90178651891 + 700.4517908797*t)
	X0 += 0.00000000804*np.cos(2.63840522723 + 9676.4810341156*t)
	X0 += 0.00000000670*np.cos(1.36038705887 + 100.1720129118*t)
	X0 += 0.00000000866*np.cos(5.76540229273 + 10846.0692855242*t)
	X0 += 0.00000000650*np.cos(2.73749334371 + 558.1451530978*t)
	X0 += 0.00000000613*np.cos(2.67799935322 + 205.2223405907*t)
	X0 += 0.00000000611*np.cos(3.22738343677 + 4443.713269194*t)
	X0 += 0.00000000726*np.cos(2.09433576268 + 2151.0071892928*t)
	X0 += 0.00000000611*np.cos(0.94365715757 + 127.4717966068*t)
	X0 += 0.00000000792*np.cos(0.24370973638 + 3487.4241132234*t)
	X0 += 0.00000000751*np.cos(5.81390703713 + 446.3113468182*t)
	X0 += 0.00000000853*np.cos(4.28810731162 + 2964.8466951296*t)
	X0 += 0.00000000614*np.cos(3.69080861447 + 6121.6518446948*t)
	X0 += 0.00000000620*np.cos(0.93234202068 + 3046.5988283458*t)
	X0 += 0.00000000607*np.cos(3.04321843475 + 1670.82502850*t)
	X0 += 0.00000000619*np.cos(0.69084255400 + 1144.3154571431*t)
	X0 += 0.00000000596*np.cos(2.57575578891 + 737.3609862401*t)
	X0 += 0.00000000619*np.cos(4.37152142119 + 325.9530972122*t)
	X0 += 0.00000000617*np.cos(3.74485122373 + 920.8644333185*t)
	X0 += 0.00000000591*np.cos(3.48178211131 + 5760.4984318976*t)
	X0 += 0.00000000590*np.cos(5.76615169007 + 3634.6210245184*t)
	X0 += 0.00000000592*np.cos(1.67926794472 + 799.6124118352*t)
	X0 += 0.00000000628*np.cos(3.97268935384 + 1408.0171287602*t)
	X0 += 0.00000000600*np.cos(0.77520117111 + 1909.3969182035*t)
	X0 += 0.00000000588*np.cos(4.88077168579 + 9690.7081281172*t)
	X0 += 0.00000000590*np.cos(4.55773138616 + 627.3671133418*t)
	X0 += 0.00000000611*np.cos(2.00459977476 + 392.6579409322*t)
	X0 += 0.00000000611*np.cos(2.33608587361 + 666.723989257*t)
	X0 += 0.00000000660*np.cos(3.23495727377 + 4312.1663069722*t)
	X0 += 0.00000000579*np.cos(0.23689221312 + 181.806526049*t)
	X0 += 0.00000000723*np.cos(3.17265641927 + 3333.498879699*t)
	X0 += 0.00000000715*np.cos(6.07739111387 + 3347.7259737006*t)
	X0 += 0.00000000604*np.cos(0.54070600496 + 427.1194557378*t)
	X0 += 0.00000000774*np.cos(3.14130625993 + 711.4974911436*t)
	X0 += 0.00000000578*np.cos(0.68382188540 + 881.5075574033*t)
	X0 += 0.00000000643*np.cos(3.30030512509 + 282.4516197128*t)
	X0 += 0.00000000750*np.cos(3.52320056595 + 1818.1529934009*t)
	X0 += 0.00000000733*np.cos(3.98414988751 + 344.7030453079*t)
	X0 += 0.00000000589*np.cos(3.85148384183 + 2005.3761454213*t)
	X0 += 0.00000000613*np.cos(2.03788975303 + 745.4377410874*t)
	X0 += 0.00000000582*np.cos(5.43181986865 + 2953.8009948657*t)
	X0 += 0.00000000754*np.cos(4.23362271932 + 1022.7333672597*t)
	X0 += 0.00000000694*np.cos(4.97705611923 + 1967.7161905355*t)
	X0 += 0.00000000736*np.cos(2.16773979972 + 601.5036182453*t)
	X0 += 0.00000000736*np.cos(2.17294584865 + 457.8783119439*t)
	X0 += 0.00000000585*np.cos(3.31295262517 + 1791.3262904579*t)
	X0 += 0.00000000709*np.cos(4.59740934441 + 3391.4448860056*t)
	X0 += 0.00000000639*np.cos(3.15793381912 + 12.5301729722*t)
	X0 += 0.00000000568*np.cos(2.97493496281 + 4804.209275927*t)
	X0 += 0.00000000749*np.cos(4.31005763443 + 421.93232443*t)
	X0 += 0.00000000613*np.cos(2.48841615646 + 1457.525933062*t)
	X0 += 0.00000000554*np.cos(4.24041493722 + 385.7568422525*t)
	X0 += 0.00000000560*np.cos(4.71045037674 + 420.9691165835*t)
	X0 += 0.00000000580*np.cos(1.24938803404 + 5179.5897827258*t)
	X0 += 0.00000000717*np.cos(1.78237513008 + 90.5626012464*t)
	X0 += 0.00000000743*np.cos(0.89577704031 + 1670.0742689746*t)
	X0 += 0.00000000575*np.cos(1.40738519930 + 1656.7409468503*t)
	X0 += 0.00000000559*np.cos(5.27992199420 + 388.7257876691*t)
	X0 += 0.00000000582*np.cos(4.78436996849 + 5481.7545583808*t)
	X0 += 0.00000000538*np.cos(0.92867899703 + 7564.830720738*t)
	X0 += 0.00000000549*np.cos(2.46772636715 + 6702.5604938666*t)
	X0 += 0.00000000543*np.cos(5.63815178398 + 5062.2699145056*t)
	X0 += 0.00000000566*np.cos(2.72633185556 + 5371.5482371614*t)
	X0 += 0.00000000536*np.cos(0.61517068874 + 4701.1165017084*t)
	X0 += 0.00000000657*np.cos(2.19780034527 + 464.7312265138*t)
	X0 += 0.00000000538*np.cos(3.89155746884 + 10632.7701900862*t)
	X0 += 0.00000000537*np.cos(4.39856777959 + 8734.4189721466*t)
	X0 += 0.00000000601*np.cos(0.02012347688 + 426.0769260142*t)
	X0 += 0.00000000569*np.cos(4.99684898069 + 292.0128472684*t)
	X0 += 0.00000000525*np.cos(2.67460622020 + 76674.63652943878*t)
	X0 += 0.00000000617*np.cos(3.05048033943 + 1560.6187072806*t)
	X0 += 0.00000000516*np.cos(0.26350469761 + 5599.074426601*t)
	X0 += 0.00000000653*np.cos(1.30320179672 + 10110.1927719924*t)
	X0 += 0.00000000587*np.cos(4.62055378117 + 1784.2127434571*t)
	X0 += 0.00000000516*np.cos(0.22590098117 + 104.5772469269*t)
	X0 += 0.00000000606*np.cos(6.05478522396 + 1809.4855377226*t)
	X0 += 0.00000000672*np.cos(3.08200615608 + 221.3758502853*t)
	X0 += 0.00000000507*np.cos(5.07346157197 + 615.5182639258*t)
	X0 += 0.00000000599*np.cos(4.14878473534 + 184.9879197867*t)
	X0 += 0.00000000621*np.cos(2.87138344478 + 119.767548775*t)
	X0 += 0.00000000517*np.cos(5.27593655530 + 6018.5590704762*t)
	X0 += 0.00000000613*np.cos(1.73072364996 + 607.6539573996*t)
	X0 += 0.00000000526*np.cos(5.52886162834 + 207.6700211455*t)
	X0 += 0.00000000516*np.cos(4.76509211090 + 419.4364597654*t)
	X0 += 0.00000000496*np.cos(5.95351653489 + 4319.279853973*t)
	X0 += 0.00000000602*np.cos(0.81687029998 + 680.7386349375*t)
	X0 += 0.00000000611*np.cos(6.04727862794 + 1366.2125722902*t)
	X0 += 0.00000000553*np.cos(5.28124640360 + 208.633228992*t)
	X0 += 0.00000000494*np.cos(0.17691775323 + 536.05375257*t)
	X0 += 0.00000000494*np.cos(1.02217524155 + 523.3281776192*t)
	X0 += 0.00000000579*np.cos(5.57316761468 + 4752.9915918498*t)
	X0 += 0.00000000662*np.cos(4.81579201904 + 1595.2926704073*t)
	X0 += 0.00000000490*np.cos(2.97472409276 + 71.6002048296*t)
	X0 += 0.00000000496*np.cos(4.41325670501 + 2758.6611466924*t)
	X0 += 0.00000000497*np.cos(4.90759130615 + 102.3420146932*t)
	X0 += 0.00000000657*np.cos(1.97073031858 + 2350.8129039121*t)
	X0 += 0.00000000492*np.cos(1.64857690604 + 1365.4788591073*t)
	X0 += 0.00000000495*np.cos(1.74700930048 + 419.532827985*t)
	X0 += 0.00000000536*np.cos(3.92709821161 + 340.7708920448*t)
	X0 += 0.00000000482*np.cos(2.36084828415 + 103.843533744*t)
	X0 += 0.00000000576*np.cos(4.33063045778 + 4841.8572720668*t)
	X0 += 0.00000000636*np.cos(0.80538758266 + 664.2763087022*t)
	X0 += 0.00000000495*np.cos(3.15151552533 + 398.2870152247*t)
	X0 += 0.00000000519*np.cos(5.14436211293 + 398.1440028728*t)
	X0 += 0.00000000488*np.cos(5.53605494571 + 5702.1672008196*t)
	X0 += 0.00000000589*np.cos(1.83918851359 + 2740.5018994277*t)
	X0 += 0.00000000600*np.cos(1.57258402386 + 634.2682120215*t)
	X0 += 0.00000000649*np.cos(1.32346646305 + 22.0914005278*t)
	X0 += 0.00000000515*np.cos(6.13663617559 + 1090.8744995782*t)
	X0 += 0.00000000507*np.cos(4.91055727483 + 2203.6973873323*t)
	X0 += 0.00000000482*np.cos(6.19007011658 + 733.428832977*t)
	X0 += 0.00000000482*np.cos(1.96061162795 + 8631.326197928*t)
	X0 += 0.00000000467*np.cos(0.44909285037 + 5282.6825569444*t)
	X0 += 0.00000000468*np.cos(3.39225847512 + 477.0007670551*t)
	X0 += 0.00000000468*np.cos(0.94842717325 + 582.3811631341*t)
	X0 += 0.00000000553*np.cos(0.44395214498 + 3995.7744373156*t)
	X0 += 0.00000000469*np.cos(0.63364469060 + 1895.1698242019*t)
	X0 += 0.00000000543*np.cos(1.56691595393 + 578.449009871*t)
	X0 += 0.00000000543*np.cos(2.77376969444 + 480.9329203182*t)
	X0 += 0.00000000573*np.cos(1.37924154661 + 1132.6790560482*t)
	X0 += 0.00000000509*np.cos(1.42883658876 + 4863.1979130692*t)
	X0 += 0.00000000543*np.cos(5.97469828305 + 383.0967133766*t)
	X0 += 0.00000000480*np.cos(4.52427818977 + 2132.99095438*t)
	X0 += 0.00000000466*np.cos(0.60089115861 + 2645.2734317353*t)
	X0 += 0.00000000468*np.cos(2.06138965938 + 2047.9144150742*t)
	X0 += 0.00000000463*np.cos(5.78476418255 + 429.5189521828*t)
	X0 += 0.00000000458*np.cos(3.53021126021 + 4127.3213995374*t)
	X0 += 0.00000000563*np.cos(3.95187506851 + 2416.9964827703*t)
	X0 += 0.00000000534*np.cos(4.28040929775 + 843.6351541964*t)
	X0 += 0.00000000471*np.cos(4.45725457382 + 2572.1887541974*t)
	X0 += 0.00000000558*np.cos(2.14288726656 + 594.6507036754*t)
	X0 += 0.00000000588*np.cos(1.67757095757 + 458.090760265*t)
	X0 += 0.00000000482*np.cos(4.23233218604 + 6114.538297694*t)
	X0 += 0.00000000449*np.cos(4.70271243367 + 1221.8485663214*t)
	X0 += 0.00000000625*np.cos(2.89222179667 + 10529.6774158676*t)
	X0 += 0.00000000574*np.cos(5.66932742997 + 87.3117715395*t)
	X0 += 0.00000000447*np.cos(5.40550748355 + 475.3562356524*t)
	X0 += 0.00000000447*np.cos(5.21836347200 + 584.0256945368*t)
	X0 += 0.00000000466*np.cos(3.79998458212 + 632.2624744514*t)
	X0 += 0.00000000466*np.cos(1.71112241331 + 2833.2997329078*t)
	X0 += 0.00000000461*np.cos(0.39395878821 + 1799.1905969841*t)
	X0 += 0.00000000487*np.cos(2.27433915423 + 321.0577361026*t)
	X0 += 0.00000000476*np.cos(2.06167253790 + 5584.8473325994*t)
	X0 += 0.00000000527*np.cos(1.59944448425 + 1336.4169239306*t)
	X0 += 0.00000000447*np.cos(2.42457766252 + 18837.49819713819*t)
	X0 += 0.00000000477*np.cos(1.15122703256 + 3259.8979237838*t)
	X0 += 0.00000000445*np.cos(6.05106056124 + 2535.0671105159*t)
	X0 += 0.00000000541*np.cos(3.08246188636 + 72.3339180125*t)
	X0 += 0.00000000450*np.cos(3.02825599783 + 540.9972977894*t)
	X0 += 0.00000000450*np.cos(4.45402230413 + 518.3846323998*t)
	X0 += 0.00000000607*np.cos(1.47070997908 + 6599.467719648*t)
	X0 += 0.00000000504*np.cos(2.30045636564 + 1990.3982918943*t)
	X0 += 0.00000000595*np.cos(2.15046818706 + 1746.3403402502*t)
	X0 += 0.00000000465*np.cos(3.76774297614 + 1083.7609525774*t)
	X0 += 0.00000000602*np.cos(1.89096655273 + 354.5249052944*t)
	X0 += 0.00000000602*np.cos(2.44971909564 + 704.8570248948*t)
	X0 += 0.00000000579*np.cos(2.28684602417 + 597.5714649822*t)
	X0 += 0.00000000579*np.cos(2.05383962420 + 461.810465207*t)
	X0 += 0.00000000562*np.cos(0.48083792934 + 1858.9943420244*t)
	X0 += 0.00000000464*np.cos(2.03798249125 + 1443.4418514123*t)
	X0 += 0.00000000467*np.cos(5.34128135139 + 212.7778305762*t)
	X0 += 0.00000000480*np.cos(5.15413996768 + 1105.8523531052*t)
	X0 += 0.00000000466*np.cos(5.83324087524 + 213.8203602998*t)
	X0 += 0.00000000555*np.cos(2.41264252030 + 1379.7059531089*t)
	X0 += 0.00000000444*np.cos(4.31471304203 + 420.4478517217*t)
	X0 += 0.00000000597*np.cos(0.38553497717 + 3184.3655656911*t)
	X0 += 0.00000000520*np.cos(6.12913047330 + 5856.4776591154*t)
	X0 += 0.00000000459*np.cos(6.22599901288 + 4113.0943055358*t)
	X0 += 0.00000000442*np.cos(1.08908006468 + 1068.9431577448*t)
	X0 += 0.00000000473*np.cos(5.76062610155 + 1674.0064222377*t)
	X0 += 0.00000000415*np.cos(2.96228935766 + 4760.1051388506*t)
	X0 += 0.00000000432*np.cos(6.00978313661 + 2080.6308247406*t)
	X0 += 0.00000000448*np.cos(0.53354347730 + 10977.078804699*t)
	X0 += 0.00000000531*np.cos(4.97083817755 + 300.6108669775*t)
	X0 += 0.00000000420*np.cos(5.89402802331 + 4745.878044849*t)
	X0 += 0.00000000427*np.cos(5.52450878681 + 3906.9087570986*t)
	X0 += 0.00000000412*np.cos(0.43255499792 + 4105.980758535*t)
	X0 += 0.00000000558*np.cos(1.02987232016 + 2347.8439584955*t)
	X0 += 0.00000000413*np.cos(0.73884800861 + 3782.4753418776*t)
	X0 += 0.00000000504*np.cos(5.29358240575 + 5650.2921106782*t)
	X0 += 0.00000000432*np.cos(1.29567764027 + 1300.9922012785*t)
	X0 += 0.00000000549*np.cos(5.43092120710 + 8837.5117463652*t)
	X0 += 0.00000000463*np.cos(4.32056716770 + 633.305004175*t)
	X0 += 0.00000000465*np.cos(0.07680283209 + 207.1487562837*t)
	X0 += 0.00000000445*np.cos(0.71549866195 + 3700.7232086614*t)
	X0 += 0.00000000397*np.cos(0.11410695116 + 5333.9002410216*t)
	X0 += 0.00000000398*np.cos(2.95189443490 + 9492.1463150048*t)
	X0 += 0.00000000418*np.cos(6.08085042236 + 206.1373643274*t)
	X0 += 0.00000000399*np.cos(3.19412012818 + 1937.7080938548*t)
	X0 += 0.00000000412*np.cos(2.14157958735 + 835.7878940127*t)
	X0 += 0.00000000421*np.cos(3.10101017579 + 6224.7446189134*t)
	X0 += 0.00000000421*np.cos(5.74575098379 + 638.4128136057*t)
	X0 += 0.00000000405*np.cos(5.57114454703 + 2424.8607892965*t)
	X0 += 0.00000000435*np.cos(5.91785408829 + 4429.4861751924*t)
	X0 += 0.00000000508*np.cos(2.07929962372 + 736.8397213783*t)
	X0 += 0.00000000489*np.cos(5.26819416109 + 2424.1100297711*t)
	X0 += 0.00000000474*np.cos(0.35023297708 + 2879.0193962984*t)
	X0 += 0.00000000395*np.cos(3.55410546006 + 3693.6096616606*t)
	X0 += 0.00000000483*np.cos(5.61092293877 + 154.2984995498*t)
	X0 += 0.00000000412*np.cos(3.95817314793 + 83.3796182764*t)
	X0 += 0.00000000482*np.cos(6.21265016851 + 25028.521211385*t)
	X0 += 0.00000000384*np.cos(0.10028038290 + 673.6250879367*t)
	X0 += 0.00000000400*np.cos(2.77460424659 + 2755.4797529547*t)
	X0 += 0.00000000386*np.cos(3.30700195922 + 6327.837393132*t)
	X0 += 0.00000000500*np.cos(0.77202686943 + 1973.1328165069*t)
	X0 += 0.00000000414*np.cos(3.16238841274 + 1244.226837624*t)
	X0 += 0.00000000397*np.cos(5.90798757004 + 50586.73338786459*t)
	X0 += 0.00000000391*np.cos(5.34395815407 + 670.6561425201*t)
	X0 += 0.00000000435*np.cos(2.62532506647 + 1230.1427559743*t)
	X0 += 0.00000000468*np.cos(5.85278677859 + 1970.6851359521*t)
	X0 += 0.00000000493*np.cos(2.80735445681 + 425.1137181677*t)
	X0 += 0.00000000472*np.cos(5.64546266904 + 416.7763308895*t)
	X0 += 0.00000000491*np.cos(2.66311701318 + 601.2911699242*t)
	X0 += 0.00000000511*np.cos(4.91405448075 + 77.2292791221*t)
	X0 += 0.00000000376*np.cos(3.16843571095 + 5908.3527492568*t)
	X0 += 0.00000000451*np.cos(2.86326087284 + 2527.2028039897*t)
	X0 += 0.00000000461*np.cos(0.43280745403 + 9580.5018068978*t)
	X0 += 0.00000000373*np.cos(1.51273456935 + 9264.1099372412*t)
	return X0




def Jupiter_X1 (t): # 499 terms of order 1

	X1 = 0.
	X1 -= 0.00883685325
	X1 += 0.00634691138*np.cos(0.10662162351 + 1059.3819301892*t)
	X1 += 0.00599147916*np.cos(2.42996832550 + 522.5774180938*t)
	X1 += 0.00588595541*np.cos(1.91556289228 + 536.8045120954*t)
	X1 += 0.00081798277*np.cos(3.46668967473 + 7.1135470008*t)
	X1 += 0.00046157824*np.cos(0.45714213541 + 1589.0728952838*t)
	X1 += 0.00032477578*np.cos(1.74648870966 + 1052.2683831884*t)
	X1 += 0.00033859106*np.cos(4.10112469499 + 529.6909650946*t)
	X1 += 0.00031204139*np.cos(2.34698443027 + 1066.49547719*t)
	X1 += 0.00021258131*np.cos(4.36563858679 + 110.2063212194*t)
	X1 += 0.00017292154*np.cos(3.99214003946 + 426.598190876*t)
	X1 += 0.00013566605*np.cos(0.30040958696 + 632.7837393132*t)
	X1 += 0.00012877132*np.cos(2.57490337554 + 515.463871093*t)
	X1 += 0.00009117208*np.cos(1.78082300783 + 543.9180590962*t)
	X1 += 0.00008078237*np.cos(6.16137042548 + 949.1756089698*t)
	X1 += 0.00007139253*np.cos(3.17225778048 + 323.5054166574*t)
	X1 += 0.00003998647*np.cos(4.57586236640 + 206.1855484372*t)
	X1 += 0.00004389657*np.cos(1.14770871584 + 735.8765135318*t)
	X1 += 0.00003395920*np.cos(2.90091460302 + 526.5095713569*t)
	X1 += 0.00003330163*np.cos(1.43691666191 + 532.8723588323*t)
	X1 += 0.00003878456*np.cos(3.33647235000 + 14.2270940016*t)
	X1 += 0.00003041505*np.cos(1.65428068117 + 525.7588118315*t)
	X1 += 0.00002999010*np.cos(2.68376980775 + 533.6231183577*t)
	X1 += 0.00002984688*np.cos(2.59503648367 + 419.4846438752*t)
	X1 += 0.00002416946*np.cos(3.60563658924 + 316.3918696566*t)
	X1 += 0.00002799836*np.cos(4.89523847324 + 103.0927742186*t)
	X1 += 0.00002987393*np.cos(0.80692150498 + 2118.7638603784*t)
	X1 += 0.00001975662*np.cos(5.08913465136 + 956.2891559706*t)
	X1 += 0.00001851910*np.cos(2.76941008977 + 1596.1864422846*t)
	X1 += 0.00001770816*np.cos(0.72643844818 + 742.9900605326*t)
	X1 += 0.00001810452*np.cos(3.84597080211 + 95.9792272178*t)
	X1 += 0.00001532798*np.cos(4.31369306820 + 117.3198682202*t)
	X1 += 0.00001735409*np.cos(2.18944094588 + 220.4126424388*t)
	X1 += 0.00001902258*np.cos(1.85937281972 + 1581.959348283*t)
	X1 += 0.00001572591*np.cos(1.43756120627 + 639.897286314*t)
	X1 += 0.00001630801*np.cos(1.41506089245 + 1045.1548361876*t)
	X1 += 0.00001042283*np.cos(2.52301939233 + 433.7117378768*t)
	X1 += 0.00001054423*np.cos(2.50841911774 + 1265.5674786264*t)
	X1 += 0.00000938933*np.cos(1.34872737253 + 625.6701923124*t)
	X1 += 0.00000838948*np.cos(6.20525196834 + 942.062061969*t)
	X1 += 0.00000984795*np.cos(1.42747117428 + 1169.5882514086*t)
	X1 += 0.00000778368*np.cos(5.49327023651 + 309.2783226558*t)
	X1 += 0.00000764430*np.cos(1.96903995155 + 1155.361157407*t)
	X1 += 0.00000701397*np.cos(4.25771947417 + 213.299095438*t)
	X1 += 0.00000733654*np.cos(0.11449570261 + 1162.4747044078*t)
	X1 += 0.00000537282*np.cos(4.25576469669 + 853.196381752*t)
	X1 += 0.00000498678*np.cos(4.79704266333 + 199.0720014364*t)
	X1 += 0.00000470969*np.cos(5.91214343598 + 1692.1656695024*t)
	X1 += 0.00000499684*np.cos(3.01974904728 + 330.6189636582*t)
	X1 += 0.00000383401*np.cos(2.17144334724 + 1073.6090241908*t)
	X1 += 0.00000428111*np.cos(3.19841041211 + 412.3710968744*t)
	X1 += 0.00000391930*np.cos(6.21042927748 + 1478.8665740644*t)
	X1 += 0.00000312643*np.cos(2.92393433132 + 838.9692877504*t)
	X1 += 0.00000348986*np.cos(1.49922551387 + 728.762966531*t)
	X1 += 0.00000226979*np.cos(2.73841550963 + 508.3503240922*t)
	X1 += 0.00000244366*np.cos(1.76027719292 + 1272.6810256272*t)
	X1 += 0.00000228533*np.cos(2.84897924756 + 1375.7737998458*t)
	X1 += 0.00000221702*np.cos(3.09805705454 + 3.1813937377*t)
	X1 += 0.00000180606*np.cos(3.64990772248 + 1368.660252845*t)
	X1 += 0.00000189311*np.cos(1.15742191077 + 2648.454825473*t)
	X1 += 0.00000173774*np.cos(1.85326355532 + 1062.5633239269*t)
	X1 += 0.00000160702*np.cos(3.02745203358 + 519.3960243561*t)
	X1 += 0.00000144171*np.cos(2.08464258695 + 1055.4497769261*t)
	X1 += 0.00000131179*np.cos(2.97927166281 + 1258.4539316256*t)
	X1 += 0.00000133210*np.cos(2.05756757570 + 227.5261894396*t)
	X1 += 0.00000125509*np.cos(3.31850855112 + 1063.3140834523*t)
	X1 += 0.00000124734*np.cos(1.62030005402 + 551.031606097*t)
	X1 += 0.00000125042*np.cos(1.31558488548 + 539.9859058331*t)
	X1 += 0.00000146566*np.cos(2.72430580528 + 1056.2005364515*t)
	X1 += 0.00000115801*np.cos(3.18147754305 + 2125.8774073792*t)
	X1 += 0.00000145191*np.cos(6.08208149730 + 1485.9801210652*t)
	X1 += 0.00000118295*np.cos(5.96372740992 + 3.9321532631*t)
	X1 += 0.00000103315*np.cos(2.02927559191 + 2111.6503133776*t)
	X1 += 0.00000097151*np.cos(3.83409421799 + 846.0828347512*t)
	X1 += 0.00000091896*np.cos(1.85946731987 + 1699.2792165032*t)
	X1 += 0.00000096362*np.cos(5.70969597388 + 302.164775655*t)
	X1 += 0.00000084324*np.cos(1.28706995009 + 440.8252848776*t)
	X1 += 0.00000106818*np.cos(1.67890803980 + 1574.8458012822*t)
	X1 += 0.00000102682*np.cos(3.17927719978 + 21.3406410024*t)
	X1 += 0.00000078206*np.cos(5.09272772324 + 525.0250986486*t)
	X1 += 0.00000076261*np.cos(1.53020732610 + 647.0108333148*t)
	X1 += 0.00000074807*np.cos(5.52867791022 + 534.3568315406*t)
	X1 += 0.00000058286*np.cos(3.06258933512 + 831.8557407496*t)
	X1 += 0.00000060063*np.cos(6.23965180318 + 2221.856634597*t)
	X1 += 0.00000066496*np.cos(2.28571233730 + 1685.0521225016*t)
	X1 += 0.00000048729*np.cos(5.83820948966 + 2008.557539159*t)
	X1 += 0.00000066589*np.cos(2.63398762312 + 1795.258443721*t)
	X1 += 0.00000046409*np.cos(2.49832684365 + 524.2743391232*t)
	X1 += 0.00000049430*np.cos(2.75657743547 + 963.4027029714*t)
	X1 += 0.00000051891*np.cos(1.37538181177 + 1038.0412891868*t)
	X1 += 0.00000045782*np.cos(1.84235881885 + 535.107591066*t)
	X1 += 0.00000042922*np.cos(3.13241373771 + 618.5566453116*t)
	X1 += 0.00000040582*np.cos(4.83057322611 + 1382.8873468466*t)
	X1 += 0.00000052158*np.cos(1.52495763338 + 750.1036075334*t)
	X1 += 0.00000037951*np.cos(1.27002779619 + 511.5317178299*t)
	X1 += 0.00000047715*np.cos(1.24588453738 + 1471.7530270636*t)
	X1 += 0.00000036522*np.cos(3.08500358340 + 547.8502123593*t)
	X1 += 0.00000035243*np.cos(2.80118853832 + 10.2949407385*t)
	X1 += 0.00000036868*np.cos(1.53995824219 + 526.7702037878*t)
	X1 += 0.00000036602*np.cos(2.80095524257 + 532.6117264014*t)
	X1 += 0.00000033063*np.cos(3.44141312814 + 1361.5467058442*t)
	X1 += 0.00000030104*np.cos(6.00478725838 + 934.9485149682*t)
	X1 += 0.00000030315*np.cos(4.13626861185 + 124.433415221*t)
	X1 += 0.00000027353*np.cos(1.68214165849 + 1802.3719907218*t)
	X1 += 0.00000031803*np.cos(6.10002028762 + 76.2660712756*t)
	X1 += 0.00000025726*np.cos(2.44462088413 + 1898.3512179396*t)
	X1 += 0.00000028221*np.cos(1.23073875427 + 149.5631971346*t)
	X1 += 0.00000025386*np.cos(5.55865505428 + 11.0457002639*t)
	X1 += 0.00000024775*np.cos(2.99327423605 + 99.1606209555*t)
	X1 += 0.00000024465*np.cos(3.43667769249 + 106.2741679563*t)
	X1 += 0.00000027711*np.cos(2.73274666064 + 1788.1448967202*t)
	X1 += 0.00000025167*np.cos(1.80443503539 + 540.7366653585*t)
	X1 += 0.00000029743*np.cos(3.09990944853 + 1905.4647649404*t)
	X1 += 0.00000022193*np.cos(3.59193891077 + 1148.2476104062*t)
	X1 += 0.00000018077*np.cos(3.92504571424 + 909.8187330546*t)
	X1 += 0.00000017089*np.cos(2.56125911732 + 1603.2999892854*t)
	X1 += 0.00000018419*np.cos(4.58300478299 + 107.0249274817*t)
	X1 += 0.00000017538*np.cos(6.04152156093 + 525.4981794006*t)
	X1 += 0.00000017368*np.cos(4.58219668177 + 533.8837507886*t)
	X1 += 0.00000016173*np.cos(4.31252210992 + 99.9113804809*t)
	X1 += 0.00000016048*np.cos(4.96629594332 + 191.9584544356*t)
	X1 += 0.00000015126*np.cos(1.80831479432 + 518.6452648307*t)
	X1 += 0.00000017599*np.cos(4.42076873743 + 18.1592472647*t)
	X1 += 0.00000014850*np.cos(2.08396451995 + 1049.0869894507*t)
	X1 += 0.00000017302*np.cos(0.44591095420 + 88.865680217*t)
	X1 += 0.00000017511*np.cos(3.54451355704 + 860.3099287528*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000011491*np.cos(3.67205052579 + 1891.2376709388*t)
	X1 += 0.00000014699*np.cos(2.85896760650 + 337.732510659*t)
	X1 += 0.00000011691*np.cos(1.50110188157 + 3178.1457905676*t)
	X1 += 0.00000011346*np.cos(1.83391533435 + 2214.7430875962*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000014283*np.cos(2.26128564985 + 2104.5367663768*t)
	X1 += 0.00000009845*np.cos(2.74625743538 + 422.6660376129*t)
	X1 += 0.00000012875*np.cos(1.46315002246 + 721.6494195302*t)
	X1 += 0.00000011042*np.cos(4.75800287074 + 604.4725636619*t)
	X1 += 0.00000009245*np.cos(3.98030194659 + 423.4167971383*t)
	X1 += 0.00000010223*np.cos(2.19747174258 + 73.297125859*t)
	X1 += 0.00000010028*np.cos(5.51845350012 + 497.4476361802*t)
	X1 += 0.00000010134*np.cos(2.26013428987 + 1592.2542890215*t)
	X1 += 0.00000008977*np.cos(2.82550986509 + 224.3447957019*t)
	X1 += 0.00000010955*np.cos(0.52903548097 + 2015.6710861598*t)
	X1 += 0.00000008621*np.cos(3.75608139172 + 1464.6394800628*t)
	X1 += 0.00000008850*np.cos(3.29541292431 + 92.0470739547*t)
	X1 += 0.00000009289*np.cos(5.09598221617 + 561.934294009*t)
	X1 += 0.00000008368*np.cos(2.53484402848 + 1585.1407420207*t)
	X1 += 0.00000010898*np.cos(3.83394926407 + 113.3877149571*t)
	X1 += 0.00000007503*np.cos(2.56175173046 + 415.5524906121*t)
	X1 += 0.00000007458*np.cos(2.96758658527 + 1677.9385755008*t)
	X1 += 0.00000008955*np.cos(5.92443010693 + 454.9093665273*t)
	X1 += 0.00000007356*np.cos(1.90543398464 + 39.3568759152*t)
	X1 += 0.00000007358*np.cos(3.64822485338 + 2655.5683724738*t)
	X1 += 0.00000007628*np.cos(2.37923774129 + 2001.4439921582*t)
	X1 += 0.00000007560*np.cos(1.34359191286 + 636.7158925763*t)
	X1 += 0.00000007709*np.cos(3.65753468748 + 405.2575498736*t)
	X1 += 0.00000007232*np.cos(2.65509662329 + 429.7795846137*t)
	X1 += 0.00000007180*np.cos(1.56368302392 + 629.6023455755*t)
	X1 += 0.00000008090*np.cos(2.87580551450 + 1585.8915015461*t)
	X1 += 0.00000007334*np.cos(5.47944814706 + 530.44172462*t)
	X1 += 0.00000007334*np.cos(5.14442280849 + 528.9402055692*t)
	X1 += 0.00000007210*np.cos(2.24007083388 + 2228.9701815978*t)
	X1 += 0.00000007847*np.cos(4.72291528075 + 114.1384744825*t)
	X1 += 0.00000007507*np.cos(5.38482384423 + 121.2520214833*t)
	X1 += 0.00000006935*np.cos(1.27046739712 + 387.2413149608*t)
	X1 += 0.00000006688*np.cos(4.17557954417 + 1251.3403846248*t)
	X1 += 0.00000006655*np.cos(1.15378992395 + 1158.5425511447*t)
	X1 += 0.00000006413*np.cos(2.31530755529 + 1159.2933106701*t)
	X1 += 0.00000006468*np.cos(0.83651032579 + 1165.6560981455*t)
	X1 += 0.00000006440*np.cos(5.06323216925 + 1048.3362299253*t)
	X1 += 0.00000006851*np.cos(0.22239992232 + 953.1077622329*t)
	X1 += 0.00000006545*np.cos(0.10032284925 + 635.9651330509*t)
	X1 += 0.00000006447*np.cos(4.23801997486 + 983.1158589136*t)
	X1 += 0.00000006823*np.cos(3.41050679015 + 430.5303441391*t)
	X1 += 0.00000005966*np.cos(1.91105006886 + 234.6397364404*t)
	X1 += 0.00000005842*np.cos(2.07614752527 + 1166.4068576709*t)
	X1 += 0.00000006784*np.cos(4.34848431124 + 305.3461693927*t)
	X1 += 0.00000006118*np.cos(2.69445341538 + 312.4597163935*t)
	X1 += 0.00000006009*np.cos(0.10875806681 + 1041.2226829245*t)
	X1 += 0.00000005501*np.cos(1.96764608432 + 70.8494453042*t)
	X1 += 0.00000005973*np.cos(2.76152635468 + 319.5732633943*t)
	X1 += 0.00000005278*np.cos(3.39197523571 + 1781.0313497194*t)
	X1 += 0.00000005231*np.cos(3.55048876434 + 2207.6295405954*t)
	X1 += 0.00000005519*np.cos(3.64099685042 + 1593.0050485469*t)
	X1 += 0.00000005660*np.cos(6.06138104148 + 2538.2485042536*t)
	X1 += 0.00000005189*np.cos(0.91840951510 + 447.9388318784*t)
	X1 += 0.00000005286*np.cos(4.46265843793 + 505.3119427064*t)
	X1 += 0.00000005917*np.cos(4.12240105946 + 458.8415197904*t)
	X1 += 0.00000005475*np.cos(4.37459574652 + 437.6438911399*t)
	X1 += 0.00000004972*np.cos(6.16121278840 + 554.0699874828*t)
	X1 += 0.00000005942*np.cos(3.32585192349 + 512.2824773553*t)
	X1 += 0.00000004807*np.cos(1.83942358294 + 494.2662424425*t)
	X1 += 0.00000005306*np.cos(1.69049375604 + 1069.6768709277*t)
	X1 += 0.00000005203*np.cos(1.87962678140 + 498.6714764576*t)
	X1 += 0.00000005248*np.cos(2.37142451831 + 209.3669421749*t)
	X1 += 0.00000004397*np.cos(2.50129326038 + 565.1156877467*t)
	X1 += 0.00000006007*np.cos(0.30197494591 + 2751.5475996916*t)
	X1 += 0.00000004326*np.cos(2.93617118935 + 672.1406152284*t)
	X1 += 0.00000004605*np.cos(0.94900742336 + 679.2541622292*t)
	X1 += 0.00000004812*np.cos(2.46105930646 + 560.7104537316*t)
	X1 += 0.00000004305*np.cos(3.17292574823 + 1070.4276304531*t)
	X1 += 0.00000004181*np.cos(4.48308381498 + 210.1177017003*t)
	X1 += 0.00000004781*np.cos(0.23036668649 + 600.5404103988*t)
	X1 += 0.00000004547*np.cos(0.82938672629 + 628.8515860501*t)
	X1 += 0.00000004318*np.cos(0.82050097893 + 81.7521332162*t)
	X1 += 0.00000004233*np.cos(3.49063898076 + 63.7358983034*t)
	X1 += 0.00000004623*np.cos(6.18646661174 + 621.7380390493*t)
	X1 += 0.00000004227*np.cos(2.61562626792 + 2420.9286360334*t)
	X1 += 0.00000004148*np.cos(1.91466045368 + 1080.7225711916*t)
	X1 += 0.00000004118*np.cos(1.75036057027 + 216.4804891757*t)
	X1 += 0.00000004125*np.cos(1.85635315002 + 643.8294395771*t)
	X1 += 0.00000003845*np.cos(1.59767120137 + 970.5162499722*t)
	X1 += 0.00000003898*np.cos(5.93876139914 + 1064.0477966352*t)
	X1 += 0.00000003888*np.cos(1.98395494204 + 2641.3412784722*t)
	X1 += 0.00000003853*np.cos(2.59485582430 + 2317.8358618148*t)
	X1 += 0.00000003908*np.cos(1.83944904776 + 746.9222137957*t)
	X1 += 0.00000003880*np.cos(5.29549605002 + 504.561183181*t)
	X1 += 0.00000003963*np.cos(5.18427227117 + 952.3570027075*t)
	X1 += 0.00000003970*np.cos(2.21423593745 + 32.2433289144*t)
	X1 += 0.00000003965*np.cos(1.33979462564 + 501.3797894433*t)
	X1 += 0.00000005052*np.cos(0.57298078948 + 945.9942152321*t)
	X1 += 0.00000004516*np.cos(1.67475369251 + 757.2171545342*t)
	X1 += 0.00000003643*np.cos(5.32837517943 + 554.8207470082*t)
	X1 += 0.00000004896*np.cos(5.94004053227 + 295.0512286542*t)
	X1 += 0.00000003693*np.cos(3.00089138383 + 558.0021407459*t)
	X1 += 0.00000003445*np.cos(4.34972240938 + 85.8272988312*t)
	X1 += 0.00000003360*np.cos(2.96000036043 + 501.2367770914*t)
	X1 += 0.00000003474*np.cos(1.76083171276 + 739.8086667949*t)
	X1 += 0.00000003279*np.cos(0.44621851234 + 654.1243803156*t)
	X1 += 0.00000003343*np.cos(1.48999871352 + 835.0371344873*t)
	X1 += 0.00000004224*np.cos(0.94453455733 + 547.0994528339*t)
	X1 += 0.00000003838*np.cos(3.19193946437 + 1493.093668066*t)
	X1 += 0.00000003214*np.cos(6.21072812865 + 498.1983957056*t)
	X1 += 0.00000003222*np.cos(5.31735340028 + 1912.5783119412*t)
	X1 += 0.00000003214*np.cos(1.26884267335 + 74.7815985673*t)
	X1 += 0.00000003500*np.cos(2.37701863527 + 2428.0421830342*t)
	X1 += 0.00000003525*np.cos(3.81209327046 + 611.4430983108*t)
	X1 += 0.00000003077*np.cos(3.68524717885 + 416.3032501375*t)
	X1 += 0.00000003344*np.cos(3.60197619452 + 6275.9623029906*t)
	X1 += 0.00000002969*np.cos(4.41314329134 + 561.1835344836*t)
	X1 += 0.00000002931*np.cos(2.79773576105 + 1994.3304451574*t)
	X1 += 0.00000003252*np.cos(3.05737388484 + 6290.1893969922*t)
	X1 += 0.00000003128*np.cos(5.02441385652 + 10206.1719992102*t)
	X1 += 0.00000002968*np.cos(2.52815042649 + 597.3590166611*t)
	X1 += 0.00000003023*np.cos(5.26037767653 + 938.1299087059*t)
	X1 += 0.00000003194*np.cos(2.85805260634 + 483.2205421786*t)
	X1 += 0.00000003285*np.cos(2.77010997612 + 202.2533951741*t)
	X1 += 0.00000002931*np.cos(1.32592672247 + 2531.1349572528*t)
	X1 += 0.00000003496*np.cos(5.37662649242 + 1054.7160637432*t)
	X1 += 0.00000002705*np.cos(1.50683837108 + 960.2213092337*t)
	X1 += 0.00000002701*np.cos(1.08016229894 + 1151.4290041439*t)
	X1 += 0.00000003042*np.cos(4.48040916474 + 10220.3990932118*t)
	X1 += 0.00000002720*np.cos(2.58010430587 + 326.6868103951*t)
	X1 += 0.00000002672*np.cos(1.96324696400 + 521.8266585684*t)
	X1 += 0.00000002672*np.cos(2.37743868437 + 537.5552716208*t)
	X1 += 0.00000002609*np.cos(3.40770814407 + 2524.021410252*t)
	X1 += 0.00000002658*np.cos(2.71532856876 + 1061.829610744*t)
	X1 += 0.00000002848*np.cos(2.92219851331 + 1176.7017984094*t)
	X1 += 0.00000002545*np.cos(0.06404673008 + 1098.7388061044*t)
	X1 += 0.00000002658*np.cos(0.64454112605 + 1056.9342496344*t)
	X1 += 0.00000003075*np.cos(1.56267675985 + 462.0229135281*t)
	X1 += 0.00000002804*np.cos(1.45329267833 + 576.1613880106*t)
	X1 += 0.00000003006*np.cos(2.08663728044 + 230.5645708254*t)
	X1 += 0.00000002926*np.cos(5.21865371391 + 203.0041546995*t)
	X1 += 0.00000002663*np.cos(3.13863396084 + 824.7421937488*t)
	X1 += 0.00000002292*np.cos(5.42244624952 + 2324.9494088156*t)
	X1 += 0.00000002330*np.cos(4.18275377368 + 849.2642284889*t)
	X1 += 0.00000002249*np.cos(3.18215049762 + 2097.423219376*t)
	X1 += 0.00000002829*np.cos(4.39325722160 + 320.3240229197*t)
	X1 += 0.00000002226*np.cos(2.97616162753 + 380.12776796*t)
	X1 += 0.00000002199*np.cos(4.91006707252 + 945.2434557067*t)
	X1 += 0.00000002160*np.cos(2.62271075267 + 2737.32050569*t)
	X1 += 0.00000002256*np.cos(2.98060305636 + 1053.9653042178*t)
	X1 += 0.00000002189*np.cos(4.68502028534 + 1514.2912967165*t)
	X1 += 0.00000002506*np.cos(1.90878749378 + 2332.0629558164*t)
	X1 += 0.00000002373*np.cos(5.64858628759 + 523.4711899711*t)
	X1 += 0.00000002373*np.cos(4.97528466796 + 535.9107402181*t)
	X1 += 0.00000002105*np.cos(3.22262200918 + 1059.3337460794*t)
	X1 += 0.00000002055*np.cos(5.42893438245 + 138.5174968707*t)
	X1 += 0.00000002032*np.cos(2.74059165682 + 988.532484885*t)
	X1 += 0.00000002025*np.cos(5.26102962114 + 327.4375699205*t)
	X1 += 0.00000001997*np.cos(1.58652319342 + 504.4181708291*t)
	X1 += 0.00000002033*np.cos(2.03689822537 + 1173.5204046717*t)
	X1 += 0.00000002284*np.cos(2.68820291737 + 528.0464336919*t)
	X1 += 0.00000002284*np.cos(1.65248273100 + 531.3354964973*t)
	X1 += 0.00000002212*np.cos(4.99825994629 + 5230.807466803*t)
	X1 += 0.00000002084*np.cos(5.36574627296 + 490.3340891794*t)
	X1 += 0.00000002111*np.cos(3.74188087574 + 195.1398481733*t)
	X1 += 0.00000002020*np.cos(4.84607190143 + 567.8240007324*t)
	X1 += 0.00000001939*np.cos(2.20836538491 + 1064.7985561606*t)
	X1 += 0.00000001956*np.cos(3.61372537932 + 46.470422916*t)
	X1 += 0.00000001918*np.cos(3.09665939845 + 217.2312487011*t)
	X1 += 0.00000001905*np.cos(3.51155751559 + 1077.5411774539*t)
	X1 += 0.00000001874*np.cos(2.75416274578 + 554.9637593601*t)
	X1 += 0.00000002388*np.cos(4.22825715289 + 334.5511169213*t)
	X1 += 0.00000002112*np.cos(5.51830153786 + 5216.5803728014*t)
	X1 += 0.00000002086*np.cos(3.31238187572 + 1062.302691496*t)
	X1 += 0.00000001830*np.cos(2.12262660621 + 2634.2277314714*t)
	X1 += 0.00000002057*np.cos(0.13888894147 + 9161.0171630226*t)
	X1 += 0.00000001936*np.cos(4.17140698368 + 1884.124123938*t)
	X1 += 0.00000001891*np.cos(5.26006489638 + 569.0478410098*t)
	X1 += 0.00000001776*np.cos(4.34086986629 + 842.1506814881*t)
	X1 += 0.00000001855*np.cos(5.80189856282 + 491.5579294568*t)
	X1 += 0.00000001763*np.cos(6.19379186456 + 67.6680515665*t)
	X1 += 0.00000001966*np.cos(0.65769985595 + 9146.790069021*t)
	X1 += 0.00000001805*np.cos(2.09255580554 + 460.5384408198*t)
	X1 += 0.00000001899*np.cos(1.20368030266 + 142.4496501338*t)
	X1 += 0.00000001684*np.cos(2.53973560527 + 598.8434893694*t)
	X1 += 0.00000001666*np.cos(6.08661752005 + 1058.4187223427*t)
	X1 += 0.00000002105*np.cos(0.13724782964 + 1059.430114299*t)
	X1 += 0.00000001627*np.cos(3.04780369614 + 2840.4132799086*t)
	X1 += 0.00000001637*np.cos(2.20216107241 + 732.6951197941*t)
	X1 += 0.00000001639*np.cos(0.62227037776 + 739.0579072695*t)
	X1 += 0.00000001794*np.cos(5.54837558325 + 1279.794572628*t)
	X1 += 0.00000001910*np.cos(5.80717048495 + 760.25553592*t)
	X1 += 0.00000001570*np.cos(4.37765395011 + 78.7137518304*t)
	X1 += 0.00000001612*np.cos(4.46225131237 + 1354.4331588434*t)
	X1 += 0.00000001620*np.cos(2.24777212731 + 1364.7280995819*t)
	X1 += 0.00000001633*np.cos(3.33686843456 + 2435.155730035*t)
	X1 += 0.00000001521*np.cos(5.37680802629 + 842.9014410135*t)
	X1 += 0.00000001513*np.cos(2.96861199920 + 1269.4996318895*t)
	X1 += 0.00000001437*np.cos(1.72233118576 + 1056.4611688824*t)
	X1 += 0.00000001981*np.cos(4.69659063605 + 1141.1340634054*t)
	X1 += 0.00000001666*np.cos(3.55643756155 + 1060.3451380357*t)
	X1 += 0.00000001687*np.cos(2.00212693898 + 2744.4340526908*t)
	X1 += 0.00000001879*np.cos(3.27103722365 + 528.2064923863*t)
	X1 += 0.00000001879*np.cos(1.06964842472 + 531.1754378029*t)
	X1 += 0.00000001377*np.cos(3.51081916344 + 916.9322800554*t)
	X1 += 0.00000001706*np.cos(0.13943133227 + 724.8308132679*t)
	X1 += 0.00000001498*np.cos(5.40290721741 + 1134.1635287565*t)
	X1 += 0.00000001410*np.cos(0.25813969160 + 1091.6252591036*t)
	X1 += 0.00000001353*np.cos(3.04515689504 + 2413.8150890326*t)
	X1 += 0.00000001520*np.cos(0.66505874837 + 977.4867846211*t)
	X1 += 0.00000001508*np.cos(4.91592370257 + 299.1263942692*t)
	X1 += 0.00000001300*np.cos(0.76466874907 + 1474.9344208013*t)
	X1 += 0.00000001548*np.cos(3.01770323711 + 2310.722314814*t)
	X1 += 0.00000001517*np.cos(3.22669470964 + 1439.5096981492*t)
	X1 += 0.00000001308*np.cos(1.16467021028 + 558.1451530978*t)
	X1 += 0.00000001366*np.cos(4.72026364382 + 1446.62324515*t)
	X1 += 0.00000001435*np.cos(0.26722898141 + 991.7138786227*t)
	X1 += 0.00000001177*np.cos(2.17439866083 + 3053.7123753466*t)
	X1 += 0.00000001147*np.cos(2.74061646897 + 408.4389436113*t)
	X1 += 0.00000001144*np.cos(0.57869563945 + 1482.0479678021*t)
	X1 += 0.00000001323*np.cos(0.45300798060 + 284.1485407422*t)
	X1 += 0.00000001231*np.cos(0.91254979843 + 373.0142209592*t)
	X1 += 0.00000001132*np.cos(5.19504872814 + 1063.5747158832*t)
	X1 += 0.00000001079*np.cos(1.83157506550 + 1482.7987273275*t)
	X1 += 0.00000001252*np.cos(1.06007460213 + 473.068613792*t)
	X1 += 0.00000001242*np.cos(2.96234986087 + 520.129737539*t)
	X1 += 0.00000001242*np.cos(4.51992844109 + 539.2521926502*t)
	X1 += 0.00000001048*np.cos(1.97860689481 + 2950.619601128*t)
	X1 += 0.00000001059*np.cos(6.01027410215 + 2854.6403739102*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000001030*np.cos(5.35593869278 + 850.0149880143*t)
	X1 += 0.00000001166*np.cos(3.23409430529 + 2758.6611466924*t)
	X1 += 0.00000000984*np.cos(1.94169871699 + 536.8526962052*t)
	X1 += 0.00000000984*np.cos(5.54057958497 + 522.529233984*t)
	X1 += 0.00000001015*np.cos(0.51818482403 + 450.9772132642*t)
	X1 += 0.00000001121*np.cos(0.67312913777 + 4164.311989613*t)
	X1 += 0.00000001046*np.cos(3.94166736589 + 2200.5159935946*t)
	X1 += 0.00000000990*np.cos(2.88057760564 + 1969.2006632438*t)
	X1 += 0.00000001126*np.cos(3.23069422690 + 586.3133163972*t)
	X1 += 0.00000001040*np.cos(4.01217628215 + 5223.6939198022*t)
	X1 += 0.00000000910*np.cos(2.32349805206 + 1578.7779545453*t)
	X1 += 0.00000000901*np.cos(2.95403610944 + 248.7238180901*t)
	X1 += 0.00000001017*np.cos(2.10338420584 + 8094.5216858326*t)
	X1 += 0.00000001003*np.cos(5.21184654560 + 1432.3961511484*t)
	X1 += 0.00000000984*np.cos(2.45520540542 + 522.6256022036*t)
	X1 += 0.00000000984*np.cos(5.02707289654 + 536.7563279856*t)
	X1 += 0.00000000868*np.cos(2.78712117765 + 3156.8051495652*t)
	X1 += 0.00000000868*np.cos(2.83878055329 + 622.4887985747*t)
	X1 += 0.00000000981*np.cos(5.31674635570 + 9153.9036160218*t)
	X1 += 0.00000000825*np.cos(3.55062206532 + 4856.0843660684*t)
	X1 += 0.00000000891*np.cos(1.62041956584 + 486.4019359163*t)
	X1 += 0.00000000823*np.cos(3.64278599579 + 5746.271337896*t)
	X1 += 0.00000000807*np.cos(1.70410389099 + 1792.0770499833*t)
	X1 += 0.00000000806*np.cos(0.49831886253 + 1791.3262904579*t)
	X1 += 0.00000000832*np.cos(3.82250366910 + 608.404716925*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000000825*np.cos(0.24972568677 + 8617.0991039264*t)
	X1 += 0.00000000871*np.cos(2.99417344584 + 2730.2069586892*t)
	X1 += 0.00000000797*np.cos(5.51455791977 + 4649.8988176312*t)
	X1 += 0.00000000943*np.cos(1.78153635749 + 151.0476698429*t)
	X1 += 0.00000000767*np.cos(2.28430672508 + 3810.9295298808*t)
	X1 += 0.00000000810*np.cos(0.45334517048 + 3067.9394693482*t)
	X1 += 0.00000000801*np.cos(1.48516614896 + 77204.32749453338*t)
	X1 += 0.00000000914*np.cos(5.99476383093 + 155.7829722581*t)
	X1 += 0.00000000779*np.cos(2.12132825556 + 521.6142102473*t)
	X1 += 0.00000000779*np.cos(5.36095004640 + 537.7677199419*t)
	X1 += 0.00000000754*np.cos(0.53379104114 + 8631.326197928*t)
	X1 += 0.00000000758*np.cos(5.06316213675 + 9676.4810341156*t)
	X1 += 0.00000000926*np.cos(4.69293976330 + 298.2326223919*t)
	X1 += 0.00000000743*np.cos(5.06914451090 + 1059.903195051*t)
	X1 += 0.00000000780*np.cos(0.67747505651 + 605.9570363702*t)
	X1 += 0.00000000799*np.cos(2.72026694542 + 572.9799942729*t)
	X1 += 0.00000000802*np.cos(3.92779096672 + 984.6003316219*t)
	X1 += 0.00000000788*np.cos(4.88134713728 + 1670.82502850*t)
	X1 += 0.00000000956*np.cos(0.73411529838 + 2847.5268269094*t)
	X1 += 0.00000000850*np.cos(3.90109777168 + 775.233389447*t)
	X1 += 0.00000000907*np.cos(4.00563772299 + 453.424893819*t)
	X1 += 0.00000000761*np.cos(4.74587054848 + 902.7051860538*t)
	X1 += 0.00000000975*np.cos(5.83114964136 + 313.2104759189*t)
	X1 += 0.00000000739*np.cos(5.82131571871 + 967.3348562345*t)
	X1 += 0.00000000697*np.cos(1.69211574480 + 2545.3620512544*t)
	X1 += 0.00000000696*np.cos(1.84682173451 + 1475.6851803267*t)
	X1 += 0.00000000684*np.cos(0.30762745277 + 1798.4398374587*t)
	X1 += 0.00000000700*np.cos(4.52736249190 + 487.1526954417*t)
	X1 += 0.00000000700*np.cos(6.09650846364 + 572.2292347475*t)
	X1 += 0.00000000667*np.cos(0.87586274198 + 1012.9115072732*t)
	X1 += 0.00000000792*np.cos(3.22181109709 + 1262.3860848887*t)
	X1 += 0.00000000788*np.cos(0.82832429041 + 100.6450936638*t)
	X1 += 0.00000000679*np.cos(3.67930441077 + 24498.8302462904*t)
	X1 += 0.00000000729*np.cos(0.09481854817 + 4546.8060434126*t)
	X1 += 0.00000000649*np.cos(1.06732867372 + 245.5424243524*t)
	X1 += 0.00000000650*np.cos(1.56301053281 + 1799.1905969841*t)
	X1 += 0.00000000711*np.cos(3.39057215594 + 71.8126531507*t)
	X1 += 0.00000000704*np.cos(0.42034860657 + 5165.3626887242*t)
	X1 += 0.00000000702*np.cos(6.27548233256 + 5062.2699145056*t)
	X1 += 0.00000000652*np.cos(6.25127555163 + 306.0969289181*t)
	X1 += 0.00000000709*np.cos(4.78603512197 + 5069.3834615064*t)
	X1 += 0.00000000719*np.cos(4.52061983489 + 77.7505439839*t)
	X1 += 0.00000000703*np.cos(3.68343139414 + 2274.1169495098*t)
	X1 += 0.00000000702*np.cos(3.18123565462 + 2288.3440435114*t)
	X1 += 0.00000000716*np.cos(0.63230188605 + 3281.2385647862*t)
	X1 += 0.00000000762*np.cos(6.25728499618 + 105.5404547734*t)
	X1 += 0.00000000590*np.cos(1.92983261613 + 3370.1042450032*t)
	X1 += 0.00000000764*np.cos(5.28773291450 + 927.8349679674*t)
	X1 += 0.00000000581*np.cos(2.81040248536 + 827.9235874865*t)
	X1 += 0.00000000606*np.cos(5.48599368984 + 1751.539531416*t)
	X1 += 0.00000000779*np.cos(1.60782156712 + 535.8413042489*t)
	X1 += 0.00000000779*np.cos(5.87445673484 + 523.5406259403*t)
	X1 += 0.00000000576*np.cos(6.06778398672 + 4738.7644978482*t)
	X1 += 0.00000000607*np.cos(2.92319803825 + 2132.99095438*t)
	X1 += 0.00000000733*np.cos(3.02690447783 + 2627.1141844706*t)
	X1 += 0.00000000580*np.cos(5.69157256422 + 731.9443602687*t)
	X1 += 0.00000000744*np.cos(1.33560210315 + 643.0786800517*t)
	X1 += 0.00000000602*np.cos(0.50423273015 + 398.1440028728*t)
	X1 += 0.00000000648*np.cos(1.82180695593 + 3060.8259223474*t)
	X1 += 0.00000000720*np.cos(3.06017179586 + 3075.053016349*t)
	X1 += 0.00000000622*np.cos(0.92043275035 + 4525.4654024102*t)
	X1 += 0.00000000573*np.cos(1.26294752508 + 394.3548619616*t)
	X1 += 0.00000000634*np.cos(1.38493182347 + 469.8872200543*t)
	X1 += 0.00000000559*np.cos(2.49823686446 + 444.7574381407*t)
	X1 += 0.00000000567*np.cos(0.62029159480 + 1887.3055176757*t)
	X1 += 0.00000000564*np.cos(4.09051331205 + 1127.0499817557*t)
	X1 += 0.00000000657*np.cos(5.16807539099 + 3995.7744373156*t)
	X1 += 0.00000000547*np.cos(2.00121500235 + 4127.3213995374*t)
	X1 += 0.00000000623*np.cos(1.38117358736 + 25035.6347583858*t)
	X1 += 0.00000000545*np.cos(1.38456766312 + 810.6581120991*t)
	X1 += 0.00000000729*np.cos(0.24565368997 + 1289.9465010146*t)
	X1 += 0.00000000616*np.cos(1.88334661601 + 25021.4076643842*t)
	X1 += 0.00000000537*np.cos(3.42270018620 + 782.3469364478*t)
	X1 += 0.00000000563*np.cos(1.79181302950 + 1268.7488723641*t)
	X1 += 0.00000000541*np.cos(3.46507829700 + 2516.9078632512*t)
	X1 += 0.00000000744*np.cos(4.03452208325 + 1819.6374661092*t)
	X1 += 0.00000000539*np.cos(1.69741893503 + 614.6244920485*t)
	X1 += 0.00000000534*np.cos(1.45755614268 + 436.8931316145*t)
	X1 += 0.00000000499*np.cos(2.90337229496 + 1688.9842757647*t)
	X1 += 0.00000000493*np.cos(5.43215643529 + 10021.8372800994*t)
	X1 += 0.00000000582*np.cos(4.20670081791 + 1457.525933062*t)
	X1 += 0.00000000546*np.cos(2.95575551132 + 589.4947101349*t)
	X1 += 0.00000000509*np.cos(5.07096917753 + 4686.8894077068*t)
	X1 += 0.00000000500*np.cos(3.11018805781 + 4326.3934009738*t)
	X1 += 0.00000000477*np.cos(5.37668884763 + 4966.2906872878*t)
	X1 += 0.00000000505*np.cos(1.78093917400 + 754.0357607965*t)
	X1 += 0.00000000521*np.cos(0.81875815114 + 69.1525242748*t)
	X1 += 0.00000000609*np.cos(4.73260137898 + 1560.6187072806*t)
	X1 += 0.00000000467*np.cos(2.49269095853 + 3473.1970192218*t)
	X1 += 0.00000000469*np.cos(1.79243927804 + 3267.0114707846*t)
	X1 += 0.00000000507*np.cos(3.49288215577 + 2090.3096723752*t)
	X1 += 0.00000000462*np.cos(2.57741672207 + 3466.083472221*t)
	X1 += 0.00000000457*np.cos(1.44246135943 + 2108.4689196399*t)
	X1 += 0.00000000477*np.cos(6.23689806796 + 3171.0322435668*t)
	X1 += 0.00000000451*np.cos(0.27095202106 + 2107.7181601145*t)
	X1 += 0.00000000450*np.cos(0.66226303752 + 1467.8208738005*t)
	X1 += 0.00000000524*np.cos(0.13691906753 + 1578.0271950199*t)
	X1 += 0.00000000528*np.cos(1.20887479542 + 3693.6096616606*t)
	X1 += 0.00000000451*np.cos(3.31563307770 + 5172.476235725*t)
	X1 += 0.00000000467*np.cos(1.66982290376 + 1489.9122743283*t)
	X1 += 0.00000000462*np.cos(0.76919542272 + 26617.5941066688*t)
	X1 += 0.00000000432*np.cos(5.44107510264 + 4701.1165017084*t)
	X1 += 0.00000000452*np.cos(4.81735477031 + 1550.939859646*t)
	X1 += 0.00000000423*np.cos(5.02783018119 + 2957.7331481288*t)
	X1 += 0.00000000416*np.cos(1.52081652739 + 1261.6353253633*t)
	X1 += 0.00000000423*np.cos(4.52662522567 + 415.2918581812*t)
	X1 += 0.00000000448*np.cos(2.57393421443 + 12036.4607348882*t)
	X1 += 0.00000000514*np.cos(0.65565842899 + 3252.784376783*t)
	X1 += 0.00000000424*np.cos(1.74534057669 + 1254.5217783625*t)
	X1 += 0.00000000487*np.cos(0.27721159194 + 1901.5326116773*t)
	X1 += 0.00000000513*np.cos(4.18308593899 + 1809.4855377226*t)
	X1 += 0.00000000396*np.cos(3.86752813124 + 1020.025054274*t)
	X1 += 0.00000000413*np.cos(2.47786986764 + 1902.2833712027*t)
	X1 += 0.00000000438*np.cos(1.11008336467 + 611.5861106627*t)
	X1 += 0.00000000404*np.cos(3.24709914624 + 2042.4977891028*t)
	X1 += 0.00000000412*np.cos(6.18093909521 + 4863.1979130692*t)
	X1 += 0.00000000379*np.cos(1.72795584183 + 4443.713269194*t)
	X1 += 0.00000000402*np.cos(3.20546587206 + 665.0270682276*t)
	X1 += 0.00000000526*np.cos(1.28579140279 + 3377.217792004*t)
	X1 += 0.00000000409*np.cos(2.96470929082 + 1357.6145525811*t)
	X1 += 0.00000000453*np.cos(4.96226113717 + 4319.279853973*t)
	return X1*t




def Jupiter_X2 (t): # 258 terms of order 2

	X2 = 0.
	X2 += 0.00123746423*np.cos(4.13563340107 + 522.5774180938*t)
	X2 += 0.00121405454*np.cos(0.21155087534 + 536.8045120954*t)
	X2 += 0.00085400287
	X2 += 0.00077611336*np.cos(5.29776152037 + 529.6909650946*t)
	X2 += 0.00041371381*np.cos(5.12291606259 + 1059.3819301892*t)
	X2 += 0.00011437051*np.cos(1.72922178247 + 7.1135470008*t)
	X2 += 0.00007044790*np.cos(0.74164610282 + 1066.49547719*t)
	X2 += 0.00005705577*np.cos(3.63172956803 + 1052.2683831884*t)
	X2 += 0.00005237617*np.cos(4.27483099739 + 515.463871093*t)
	X2 += 0.00004035686*np.cos(5.58417734606 + 1589.0728952838*t)
	X2 += 0.00003702934*np.cos(0.07769815851 + 543.9180590962*t)
	X2 += 0.00001699253*np.cos(2.44298781002 + 110.2063212194*t)
	X2 += 0.00001070085*np.cos(2.35010899461 + 426.598190876*t)
	X2 += 0.00001324360*np.cos(1.63141799079 + 14.2270940016*t)
	X2 += 0.00000887354*np.cos(4.66627288620 + 526.5095713569*t)
	X2 += 0.00000864721*np.cos(5.95596899667 + 532.8723588323*t)
	X2 += 0.00000821861*np.cos(1.96547507467 + 632.7837393132*t)
	X2 += 0.00000993489*np.cos(1.46954824190 + 323.5054166574*t)
	X2 += 0.00000573516*np.cos(1.66925745016 + 949.1756089698*t)
	X2 += 0.00000732548*np.cos(0.37036997871 + 103.0927742186*t)
	X2 += 0.00000571165*np.cos(3.16913200086 + 1045.1548361876*t)
	X2 += 0.00000513766*np.cos(5.97103382730 + 525.7588118315*t)
	X2 += 0.00000511737*np.cos(4.65535000010 + 533.6231183577*t)
	X2 += 0.00000595326*np.cos(2.85992619897 + 735.8765135318*t)
	X2 += 0.00000458095*np.cos(1.24450063952 + 1596.1864422846*t)
	X2 += 0.00000419078*np.cos(2.60893700894 + 117.3198682202*t)
	X2 += 0.00000374331*np.cos(5.55812055549 + 95.9792272178*t)
	X2 += 0.00000360052*np.cos(0.47970495677 + 220.4126424388*t)
	X2 += 0.00000332609*np.cos(6.00008752152 + 2118.7638603784*t)
	X2 += 0.00000302541*np.cos(4.38509706223 + 419.4846438752*t)
	X2 += 0.00000267660*np.cos(6.20372248100 + 206.1855484372*t)
	X2 += 0.00000281748*np.cos(3.71098393973 + 1581.959348283*t)
	X2 += 0.00000264207*np.cos(3.68006415251 + 956.2891559706*t)
	X2 += 0.00000225504*np.cos(0.82261934007 + 433.7117378768*t)
	X2 += 0.00000225413*np.cos(1.67496533291 + 942.062061969*t)
	X2 += 0.00000225321*np.cos(3.03539704422 + 625.6701923124*t)
	X2 += 0.00000196563*np.cos(6.00388843187 + 1169.5882514086*t)
	X2 += 0.00000198993*np.cos(5.94170647332 + 639.897286314*t)
	X2 += 0.00000163461*np.cos(0.52536708370 + 1073.6090241908*t)
	X2 += 0.00000163487*np.cos(5.35441289334 + 316.3918696566*t)
	X2 += 0.00000160655*np.cos(3.59860181227 + 1155.361157407*t)
	X2 += 0.00000137020*np.cos(4.44132545325 + 508.3503240922*t)
	X2 += 0.00000136054*np.cos(0.22240989409 + 199.0720014364*t)
	X2 += 0.00000170215*np.cos(1.32458046755 + 330.6189636582*t)
	X2 += 0.00000116310*np.cos(5.49115238437 + 742.9900605326*t)
	X2 += 0.00000105534*np.cos(2.69679468747 + 853.196381752*t)
	X2 += 0.00000103974*np.cos(0.79141732276 + 309.2783226558*t)
	X2 += 0.00000121703*np.cos(3.11451506987 + 728.762966531*t)
	X2 += 0.00000107890*np.cos(4.63298263701 + 1162.4747044078*t)
	X2 += 0.00000075826*np.cos(4.23522954977 + 1265.5674786264*t)
	X2 += 0.00000074749*np.cos(6.19154062961 + 551.031606097*t)
	X2 += 0.00000085092*np.cos(4.83054979229 + 519.3960243561*t)
	X2 += 0.00000103308*np.cos(4.83509099388 + 412.3710968744*t)
	X2 += 0.00000057862*np.cos(4.11025319311 + 838.9692877504*t)
	X2 += 0.00000067576*np.cos(5.76690496135 + 539.9859058331*t)
	X2 += 0.00000054366*np.cos(0.35559449870 + 227.5261894396*t)
	X2 += 0.00000055783*np.cos(1.31452072722 + 3.1813937377*t)
	X2 += 0.00000055764*np.cos(1.46046269932 + 21.3406410024*t)
	X2 += 0.00000048874*np.cos(0.17659043471 + 1062.5633239269*t)
	X2 += 0.00000038768*np.cos(5.82000577424 + 440.8252848776*t)
	X2 += 0.00000037163*np.cos(4.52114626619 + 1258.4539316256*t)
	X2 += 0.00000036486*np.cos(4.74328055858 + 1692.1656695024*t)
	X2 += 0.00000031826*np.cos(1.72176295859 + 2125.8774073792*t)
	X2 += 0.00000036512*np.cos(4.40434241068 + 1056.2005364515*t)
	X2 += 0.00000039239*np.cos(1.82924115800 + 846.0828347512*t)
	X2 += 0.00000038446*np.cos(3.35522807244 + 1574.8458012822*t)
	X2 += 0.00000028570*np.cos(0.33181498895 + 1055.4497769261*t)
	X2 += 0.00000031863*np.cos(0.28733457947 + 1272.6810256272*t)
	X2 += 0.00000028626*np.cos(3.10372853509 + 1038.0412891868*t)
	X2 += 0.00000029754*np.cos(4.78492231900 + 1485.9801210652*t)
	X2 += 0.00000032377*np.cos(1.11981589204 + 302.164775655*t)
	X2 += 0.00000028363*np.cos(5.40366732937 + 1368.660252845*t)
	X2 += 0.00000022070*np.cos(4.81227665763 + 618.5566453116*t)
	X2 += 0.00000025133*np.cos(0.11303788219 + 2648.454825473*t)
	X2 += 0.00000022232*np.cos(4.51344471821 + 831.8557407496*t)
	X2 += 0.00000023169*np.cos(2.73768310385 + 213.299095438*t)
	X2 += 0.00000019785*np.cos(4.88687522199 + 1063.3140834523*t)
	X2 += 0.00000020494*np.cos(0.25456467022 + 1699.2792165032*t)
	X2 += 0.00000020971*np.cos(6.04582766752 + 647.0108333148*t)
	X2 += 0.00000018023*np.cos(2.01547726194 + 1478.8665740644*t)
	X2 += 0.00000017438*np.cos(1.50924623831 + 1375.7737998458*t)
	X2 += 0.00000015148*np.cos(2.49185231073 + 1471.7530270636*t)
	X2 += 0.00000012898*np.cos(1.52125178978 + 934.9485149682*t)
	X2 += 0.00000014088*np.cos(2.42281118647 + 124.433415221*t)
	X2 += 0.00000012497*np.cos(1.06412961453 + 10.2949407385*t)
	X2 += 0.00000011227*np.cos(3.16762334982 + 511.5317178299*t)
	X2 += 0.00000012698*np.cos(4.01915577164 + 1685.0521225016*t)
	X2 += 0.00000012646*np.cos(1.06991868745 + 963.4027029714*t)
	X2 += 0.00000010726*np.cos(1.17306244783 + 547.8502123593*t)
	X2 += 0.00000012491*np.cos(5.98319150499 + 750.1036075334*t)
	X2 += 0.00000013409*np.cos(3.85947629258 + 2111.6503133776*t)
	X2 += 0.00000010421*np.cos(5.24807030760 + 1361.5467058442*t)
	X2 += 0.00000009114*np.cos(3.32104919206 + 1382.8873468466*t)
	X2 += 0.00000007503*np.cos(0.95949306974 + 1603.2999892854*t)
	X2 += 0.00000007669*np.cos(0.38211083277 + 191.9584544356*t)
	X2 += 0.00000006803*np.cos(1.42920029674 + 106.2741679563*t)
	X2 += 0.00000008018*np.cos(1.16417082031 + 337.732510659*t)
	X2 += 0.00000007180*np.cos(2.21396651005 + 88.865680217*t)
	X2 += 0.00000007501*np.cos(3.11940992015 + 721.6494195302*t)
	X2 += 0.00000006351*np.cos(5.09436133175 + 1148.2476104062*t)
	X2 += 0.00000005564*np.cos(5.17318738796 + 2221.856634597*t)
	X2 += 0.00000005389*np.cos(4.48913154375 + 1795.258443721*t)
	X2 += 0.00000005015*np.cos(6.16326208043 + 99.9113804809*t)
	X2 += 0.00000006318*np.cos(1.94173786698 + 860.3099287528*t)
	X2 += 0.00000005511*np.cos(3.96940469989 + 1049.0869894507*t)
	X2 += 0.00000003926*np.cos(3.73297185232 + 497.4476361802*t)
	X2 += 0.00000003628*np.cos(0.17175885203 + 234.6397364404*t)
	X2 += 0.00000003787*np.cos(0.01979379406 + 1802.3719907218*t)
	X2 += 0.00000003620*np.cos(0.60771427323 + 561.934294009*t)
	X2 += 0.00000004420*np.cos(4.29333151498 + 1788.1448967202*t)
	X2 += 0.00000003522*np.cos(4.66663571790 + 501.2367770914*t)
	X2 += 0.00000003331*np.cos(5.40237223569 + 405.2575498736*t)
	X2 += 0.00000003770*np.cos(2.00527081129 + 113.3877149571*t)
	X2 += 0.00000003174*np.cos(5.47700265929 + 447.9388318784*t)
	X2 += 0.00000003729*np.cos(0.35216371388 + 107.0249274817*t)
	X2 += 0.00000003156*np.cos(4.93060391319 + 1898.3512179396*t)
	X2 += 0.00000002768*np.cos(5.52471966285 + 149.5631971346*t)
	X2 += 0.00000002747*np.cos(2.61017641134 + 81.7521332162*t)
	X2 += 0.00000002715*np.cos(0.94916831416 + 429.7795846137*t)
	X2 += 0.00000003501*np.cos(6.18907958990 + 1069.6768709277*t)
	X2 += 0.00000002669*np.cos(5.59693909051 + 2015.6710861598*t)
	X2 += 0.00000002955*np.cos(0.62556987115 + 1592.2542890215*t)
	X2 += 0.00000002539*np.cos(5.60494624351 + 1251.3403846248*t)
	X2 += 0.00000002751*np.cos(3.64369995490 + 2104.5367663768*t)
	X2 += 0.00000002422*np.cos(1.17292415415 + 99.1606209555*t)
	X2 += 0.00000002434*np.cos(0.16399596747 + 1080.7225711916*t)
	X2 += 0.00000002663*np.cos(1.77758930291 + 1905.4647649404*t)
	X2 += 0.00000002284*np.cos(3.36988966035 + 629.6023455755*t)
	X2 += 0.00000002181*np.cos(0.89424947854 + 422.6660376129*t)
	X2 += 0.00000002155*np.cos(5.42100782463 + 1464.6394800628*t)
	X2 += 0.00000002661*np.cos(1.33519838774 + 295.0512286542*t)
	X2 += 0.00000002234*np.cos(5.28790890289 + 6275.9623029906*t)
	X2 += 0.00000002232*np.cos(1.36343792387 + 6290.1893969922*t)
	X2 += 0.00000002164*np.cos(5.07920518204 + 1891.2376709388*t)
	X2 += 0.00000002060*np.cos(2.18476646961 + 2655.5683724738*t)
	X2 += 0.00000002104*np.cos(4.53279660231 + 2008.557539159*t)
	X2 += 0.00000002124*np.cos(5.77020243349 + 423.4167971383*t)
	X2 += 0.00000001981*np.cos(4.32983209849 + 2001.4439921582*t)
	X2 += 0.00000002094*np.cos(4.87667281813 + 1677.9385755008*t)
	X2 += 0.00000002075*np.cos(0.42762472762 + 10206.1719992102*t)
	X2 += 0.00000002073*np.cos(2.78634226074 + 10220.3990932118*t)
	X2 += 0.00000001764*np.cos(6.26231949488 + 970.5162499722*t)
	X2 += 0.00000002193*np.cos(5.51580717812 + 611.4430983108*t)
	X2 += 0.00000001815*np.cos(5.85865045451 + 558.1451530978*t)
	X2 += 0.00000001804*np.cos(4.14002077710 + 1159.2933106701*t)
	X2 += 0.00000001819*np.cos(5.36199924969 + 1165.6560981455*t)
	X2 += 0.00000001797*np.cos(0.77606737878 + 1585.1407420207*t)
	X2 += 0.00000001719*np.cos(4.75202956126 + 654.1243803156*t)
	X2 += 0.00000001746*np.cos(4.42489693081 + 1585.8915015461*t)
	X2 += 0.00000001558*np.cos(4.80177953016 + 635.9651330509*t)
	X2 += 0.00000001782*np.cos(0.60447629298 + 3178.1457905676*t)
	X2 += 0.00000001753*np.cos(0.13075072508 + 757.2171545342*t)
	X2 += 0.00000001617*np.cos(4.66091090554 + 824.7421937488*t)
	X2 += 0.00000001466*np.cos(4.76542718595 + 2214.7430875962*t)
	X2 += 0.00000001405*np.cos(6.22622304401 + 216.4804891757*t)
	X2 += 0.00000001548*np.cos(2.35342818787 + 945.9942152321*t)
	X2 += 0.00000001383*np.cos(3.30194862701 + 5230.807466803*t)
	X2 += 0.00000001381*np.cos(0.94385809616 + 5216.5803728014*t)
	X2 += 0.00000001392*np.cos(4.04527512446 + 1279.794572628*t)
	X2 += 0.00000001441*np.cos(1.00970871891 + 2228.9701815978*t)
	X2 += 0.00000001266*np.cos(5.08490219855 + 1781.0313497194*t)
	X2 += 0.00000001198*np.cos(0.79239741189 + 326.6868103951*t)
	X2 += 0.00000001220*np.cos(0.92941284572 + 319.5732633943*t)
	X2 += 0.00000001270*np.cos(4.72493577444 + 9161.0171630226*t)
	X2 += 0.00000001268*np.cos(2.36685858376 + 9146.790069021*t)
	X2 += 0.00000001183*np.cos(3.25891705713 + 636.7158925763*t)
	X2 += 0.00000001183*np.cos(5.27685280136 + 416.3032501375*t)
	X2 += 0.00000001176*np.cos(3.08811914225 + 732.6951197941*t)
	X2 += 0.00000001052*np.cos(2.44181827362 + 1493.093668066*t)
	X2 += 0.00000001351*np.cos(2.15891576495 + 5223.6939198022*t)
	X2 += 0.00000001063*np.cos(1.90543102461 + 518.6452648307*t)
	X2 += 0.00000001063*np.cos(5.57684727735 + 540.7366653585*t)
	X2 += 0.00000000985*np.cos(4.92073956203 + 2207.6295405954*t)
	X2 += 0.00000001201*np.cos(5.73229340019 + 3281.2385647862*t)
	X2 += 0.00000000932*np.cos(3.38783806769 + 952.3570027075*t)
	X2 += 0.00000000923*np.cos(5.20698767018 + 909.8187330546*t)
	X2 += 0.00000001036*np.cos(1.44078543733 + 5753.3848848968*t)
	X2 += 0.00000001019*np.cos(0.26639453048 + 1141.1340634054*t)
	X2 += 0.00000000905*np.cos(5.45847375728 + 1158.5425511447*t)
	X2 += 0.00000001118*np.cos(3.04402958717 + 1912.5783119412*t)
	X2 += 0.00000001183*np.cos(2.13753562284 + 953.1077622329*t)
	X2 += 0.00000000889*np.cos(3.32588521405 + 739.8086667949*t)
	X2 += 0.00000000955*np.cos(2.85800828226 + 9683.5945811164*t)
	X2 += 0.00000000966*np.cos(5.05194792689 + 2324.9494088156*t)
	X2 += 0.00000000842*np.cos(2.38621599276 + 3789.5888888784*t)
	X2 += 0.00000001017*np.cos(4.89635261381 + 1994.3304451574*t)
	X2 += 0.00000000869*np.cos(3.35288494645 + 3590.516887442*t)
	X2 += 0.00000001069*np.cos(4.17138356606 + 2943.5060541272*t)
	X2 += 0.00000000935*np.cos(0.84952544347 + 203.0041546995*t)
	X2 += 0.00000000846*np.cos(0.66134264043 + 209.3669421749*t)
	X2 += 0.00000000790*np.cos(4.03005346383 + 1166.4068576709*t)
	X2 += 0.00000000758*np.cos(4.87817386642 + 2531.1349572528*t)
	X2 += 0.00000000958*np.cos(4.54298568578 + 3384.3313390048*t)
	X2 += 0.00000000757*np.cos(4.20699802776 + 2317.8358618148*t)
	X2 += 0.00000000721*np.cos(2.30689818779 + 4694.0029547076*t)
	X2 += 0.00000000722*np.cos(2.13548601248 + 3370.1042450032*t)
	X2 += 0.00000000733*np.cos(4.88186040762 + 217.2312487011*t)
	X2 += 0.00000000989*np.cos(0.16818876297 + 6283.0758499914*t)
	X2 += 0.00000000703*np.cos(1.95208563709 + 2545.3620512544*t)
	X2 += 0.00000000746*np.cos(5.75469098902 + 1884.124123938*t)
	X2 += 0.00000000687*np.cos(6.11227108298 + 210.1177017003*t)
	X2 += 0.00000000723*np.cos(2.26217713250 + 1809.4855377226*t)
	X2 += 0.00000000819*np.cos(2.75819868566 + 3693.6096616606*t)
	X2 += 0.00000000822*np.cos(3.23378371026 + 3899.7952100978*t)
	X2 += 0.00000000656*np.cos(3.72870387447 + 8624.2126509272*t)
	X2 += 0.00000000830*np.cos(3.53694241133 + 3576.2897934404*t)
	X2 += 0.00000000859*np.cos(6.02317529595 + 458.8415197904*t)
	X2 += 0.00000000751*np.cos(5.49597800302 + 3597.6304344428*t)
	X2 += 0.00000000785*np.cos(5.66207723066 + 1354.4331588434*t)
	X2 += 0.00000000781*np.cos(2.87341818659 + 3796.7024358792*t)
	X2 += 0.00000000649*np.cos(4.07754073257 + 2634.2277314714*t)
	X2 += 0.00000000624*np.cos(4.91001561798 + 2097.423219376*t)
	X2 += 0.00000000604*np.cos(4.91506070132 + 2524.021410252*t)
	X2 += 0.00000000661*np.cos(3.32507275831 + 3583.4033404412*t)
	X2 += 0.00000000613*np.cos(4.18463336751 + 2420.9286360334*t)
	X2 += 0.00000000771*np.cos(0.75516833087 + 927.8349679674*t)
	X2 += 0.00000000709*np.cos(4.55137735674 + 2310.722314814*t)
	X2 += 0.00000000716*np.cos(4.35697491108 + 2641.3412784722*t)
	X2 += 0.00000000689*np.cos(4.67112827665 + 2730.2069586892*t)
	X2 += 0.00000000710*np.cos(4.40966446328 + 3803.81598288*t)
	X2 += 0.00000000754*np.cos(4.24897175357 + 3700.7232086614*t)
	X2 += 0.00000000750*np.cos(1.82437535078 + 3149.6916025644*t)
	X2 += 0.00000000761*np.cos(3.61383842024 + 9153.9036160218*t)
	X2 += 0.00000000566*np.cos(1.70094279377 + 2861.753920911*t)
	X2 += 0.00000000719*np.cos(4.60069795363 + 600.5404103988*t)
	X2 += 0.00000000546*np.cos(2.44837702690 + 437.6438911399*t)
	X2 += 0.00000000610*np.cos(5.65650173973 + 1457.525933062*t)
	X2 += 0.00000000725*np.cos(3.32732372233 + 1567.7322542814*t)
	X2 += 0.00000000734*np.cos(5.24445337821 + 1670.82502850*t)
	X2 += 0.00000000744*np.cos(4.46861753073 + 2627.1141844706*t)
	X2 += 0.00000000702*np.cos(0.69460527884 + 74.7815985673*t)
	X2 += 0.00000000554*np.cos(4.83025165057 + 76.2660712756*t)
	X2 += 0.00000000588*np.cos(5.02282873225 + 430.5303441391*t)
	X2 += 0.00000000570*np.cos(5.37315037594 + 2538.2485042536*t)
	X2 += 0.00000000637*np.cos(4.88295448520 + 1987.2168981566*t)
	X2 += 0.00000000588*np.cos(3.76574616668 + 3259.8979237838*t)
	X2 += 0.00000000485*np.cos(4.91636058546 + 2847.5268269094*t)
	X2 += 0.00000000517*np.cos(4.44267372013 + 2303.6087678132*t)
	X2 += 0.00000000608*np.cos(4.88795893503 + 3487.4241132234*t)
	X2 += 0.00000000495*np.cos(3.13813345098 + 3906.9087570986*t)
	X2 += 0.00000000433*np.cos(1.89231240325 + 621.7380390493*t)
	X2 += 0.00000000530*np.cos(2.58988239071 + 547.0994528339*t)
	X2 += 0.00000000530*np.cos(4.89239591125 + 512.2824773553*t)
	X2 += 0.00000000431*np.cos(4.69077182076 + 2833.2997329078*t)
	X2 += 0.00000000537*np.cos(3.26379180918 + 3892.681663097*t)
	X2 += 0.00000000478*np.cos(5.07132599131 + 1593.0050485469*t)
	X2 += 0.00000000574*np.cos(0.15417054480 + 2332.0629558164*t)
	X2 += 0.00000000521*np.cos(3.03066760362 + 4216.1870797544*t)
	X2 += 0.00000000458*np.cos(5.60104673426 + 628.8515860501*t)
	X2 += 0.00000000438*np.cos(5.49355020160 + 2200.5159935946*t)
	X2 += 0.00000000527*np.cos(6.21147753215 + 462.0229135281*t)
	X2 += 0.00000000527*np.cos(4.41239342340 + 597.3590166611*t)
	X2 += 0.00000000506*np.cos(0.50101883015 + 1244.226837624*t)
	X2 += 0.00000000450*np.cos(5.30692494677 + 3914.0223040994*t)
	X2 += 0.00000000511*np.cos(6.03746722439 + 643.0786800517*t)
	X2 += 0.00000000431*np.cos(2.42209558244 + 849.2642284889*t)
	X2 += 0.00000000453*np.cos(2.50871933627 + 4010.0015313172*t)
	X2 += 0.00000000412*np.cos(1.48533922130 + 2758.6611466924*t)
	return X2*t*t




def Jupiter_X3 (t): # 140 terms of order 3

	X3 = 0.
	X3 += 0.00017055031*np.cos(5.86133054086 + 522.5774180938*t)
	X3 += 0.00016697614*np.cos(4.77458774773 + 536.8045120954*t)
	X3 += 0.00003350618
	X3 += 0.00001786132*np.cos(3.56550369113 + 1059.3819301892*t)
	X3 += 0.00001434074*np.cos(5.98502536112 + 515.463871093*t)
	X3 += 0.00001079157*np.cos(5.42531629895 + 1066.49547719*t)
	X3 += 0.00001013242*np.cos(4.64773742759 + 543.9180590962*t)
	X3 += 0.00001074445*np.cos(6.22324523848 + 7.1135470008*t)
	X3 += 0.00000710387*np.cos(5.50680528417 + 1052.2683831884*t)
	X3 += 0.00000260840*np.cos(4.28269837343 + 1589.0728952838*t)
	X3 += 0.00000301436*np.cos(6.19842229802 + 14.2270940016*t)
	X3 += 0.00000134609*np.cos(4.94746836128 + 1045.1548361876*t)
	X3 += 0.00000124290*np.cos(0.37523072266 + 110.2063212194*t)
	X3 += 0.00000095990*np.cos(1.91169126850 + 529.6909650946*t)
	X3 += 0.00000078211*np.cos(6.01357067202 + 1596.1864422846*t)
	X3 += 0.00000076732*np.cos(0.88675910485 + 117.3198682202*t)
	X3 += 0.00000091758*np.cos(6.01068099453 + 323.5054166574*t)
	X3 += 0.00000058133*np.cos(6.15405801099 + 508.3503240922*t)
	X3 += 0.00000058041*np.cos(0.48231460491 + 426.598190876*t)
	X3 += 0.00000051910*np.cos(1.01624689589 + 95.9792272178*t)
	X3 += 0.00000049508*np.cos(5.02600546427 + 220.4126424388*t)
	X3 += 0.00000047020*np.cos(5.14951363778 + 1073.6090241908*t)
	X3 += 0.00000056622*np.cos(4.62378106559 + 735.8765135318*t)
	X3 += 0.00000043114*np.cos(3.75952421063 + 632.7837393132*t)
	X3 += 0.00000041243*np.cos(3.42053691338 + 942.062061969*t)
	X3 += 0.00000035617*np.cos(4.69195154363 + 625.6701923124*t)
	X3 += 0.00000032072*np.cos(5.60330356898 + 1581.959348283*t)
	X3 += 0.00000032287*np.cos(4.46231638389 + 551.031606097*t)
	X3 += 0.00000038596*np.cos(5.90763982054 + 330.6189636582*t)
	X3 += 0.00000031872*np.cos(5.38701829339 + 433.7117378768*t)
	X3 += 0.00000037177*np.cos(2.08431033750 + 103.0927742186*t)
	X3 += 0.00000028376*np.cos(4.76675409874 + 2118.7638603784*t)
	X3 += 0.00000030092*np.cos(3.62306294496 + 949.1756089698*t)
	X3 += 0.00000027428*np.cos(5.99498439483 + 419.4846438752*t)
	X3 += 0.00000026398*np.cos(4.29317416894 + 1169.5882514086*t)
	X3 += 0.00000027814*np.cos(4.77746470785 + 728.762966531*t)
	X3 += 0.00000024486*np.cos(1.94262036501 + 199.0720014364*t)
	X3 += 0.00000022343*np.cos(5.30761798805 + 1155.361157407*t)
	X3 += 0.00000022586*np.cos(2.11933395739 + 956.2891559706*t)
	X3 += 0.00000024897*np.cos(0.38867758331 + 519.3960243561*t)
	X3 += 0.00000017704*np.cos(6.02466461381 + 21.3406410024*t)
	X3 += 0.00000015518*np.cos(4.92737645632 + 227.5261894396*t)
	X3 += 0.00000020475*np.cos(3.91184153310 + 539.9859058331*t)
	X3 += 0.00000019809*np.cos(4.17208579498 + 639.897286314*t)
	X3 += 0.00000013410*np.cos(1.10023588663 + 853.196381752*t)
	X3 += 0.00000016866*np.cos(0.22131400817 + 412.3710968744*t)
	X3 += 0.00000011709*np.cos(4.05023128316 + 440.8252848776*t)
	X3 += 0.00000011923*np.cos(1.34668378677 + 206.1855484372*t)
	X3 += 0.00000009701*np.cos(2.23597448276 + 309.2783226558*t)
	X3 += 0.00000009477*np.cos(4.84358236456 + 1038.0412891868*t)
	X3 += 0.00000008220*np.cos(5.70985975275 + 838.9692877504*t)
	X3 += 0.00000008769*np.cos(0.89310739988 + 316.3918696566*t)
	X3 += 0.00000007455*np.cos(0.24841580448 + 618.5566453116*t)
	X3 += 0.00000008628*np.cos(5.06371375512 + 1574.8458012822*t)
	X3 += 0.00000006842*np.cos(6.20664652445 + 1258.4539316256*t)
	X3 += 0.00000008434*np.cos(0.82504462522 + 213.299095438*t)
	X3 += 0.00000006087*np.cos(6.01853033661 + 831.8557407496*t)
	X3 += 0.00000005946*np.cos(0.25737442463 + 2125.8774073792*t)
	X3 += 0.00000007407*np.cos(2.82917227258 + 302.164775655*t)
	X3 += 0.00000004152*np.cos(5.92593784760 + 1265.5674786264*t)
	X3 += 0.00000004205*np.cos(4.04355451340 + 742.9900605326*t)
	X3 += 0.00000003704*np.cos(3.24831236243 + 934.9485149682*t)
	X3 += 0.00000003801*np.cos(3.41557513392 + 1485.9801210652*t)
	X3 += 0.00000004098*np.cos(0.74383398899 + 124.433415221*t)
	X3 += 0.00000003241*np.cos(4.94814769828 + 1699.2792165032*t)
	X3 += 0.00000002747*np.cos(4.04700205492 + 88.865680217*t)
	X3 += 0.00000002627*np.cos(5.55596838973 + 1062.5633239269*t)
	X3 += 0.00000002768*np.cos(3.57192238064 + 1162.4747044078*t)
	X3 += 0.00000003152*np.cos(4.07491650142 + 647.0108333148*t)
	X3 += 0.00000002460*np.cos(5.24901107627 + 2648.454825473*t)
	X3 += 0.00000002844*np.cos(5.04262208118 + 1272.6810256272*t)
	X3 += 0.00000002575*np.cos(4.12466032895 + 1471.7530270636*t)
	X3 += 0.00000002322*np.cos(5.62530333683 + 1603.2999892854*t)
	X3 += 0.00000002472*np.cos(4.85348496742 + 721.6494195302*t)
	X3 += 0.00000002359*np.cos(5.74424947128 + 337.732510659*t)
	X3 += 0.00000001967*np.cos(0.25692061324 + 611.4430983108*t)
	X3 += 0.00000002177*np.cos(5.64857105083 + 963.4027029714*t)
	X3 += 0.00000002018*np.cos(2.15257668467 + 191.9584544356*t)
	X3 += 0.00000002323*np.cos(0.90656927684 + 1368.660252845*t)
	X3 += 0.00000001680*np.cos(0.06324276128 + 1685.0521225016*t)
	X3 += 0.00000002068*np.cos(0.74233309260 + 1361.5467058442*t)
	X3 += 0.00000001734*np.cos(5.71681506599 + 1055.4497769261*t)
	X3 += 0.00000001717*np.cos(3.76112914123 + 447.9388318784*t)
	X3 += 0.00000001784*np.cos(0.18871768378 + 526.5095713569*t)
	X3 += 0.00000001784*np.cos(1.01037531100 + 532.8723588323*t)
	X3 += 0.00000001995*np.cos(4.58300384095 + 750.1036075334*t)
	X3 += 0.00000001811*np.cos(0.22566389001 + 860.3099287528*t)
	X3 += 0.00000001432*np.cos(4.43308882126 + 81.7521332162*t)
	X3 += 0.00000001393*np.cos(3.58268793739 + 1478.8665740644*t)
	X3 += 0.00000001360*np.cos(0.72191961039 + 1148.2476104062*t)
	X3 += 0.00000001319*np.cos(0.61971681021 + 405.2575498736*t)
	X3 += 0.00000001700*np.cos(4.16965354306 + 1056.2005364515*t)
	X3 += 0.00000001198*np.cos(5.12844111023 + 1375.7737998458*t)
	X3 += 0.00000001000*np.cos(1.68391406249 + 1382.8873468466*t)
	X3 += 0.00000001211*np.cos(4.41389386454 + 1069.6768709277*t)
	X3 += 0.00000000959*np.cos(1.48751125961 + 1677.9385755008*t)
	X3 += 0.00000001013*np.cos(0.73509414390 + 1049.0869894507*t)
	X3 += 0.00000000858*np.cos(4.51563448609 + 2420.9286360334*t)
	X3 += 0.00000000961*np.cos(3.58551760111 + 2097.423219376*t)
	X3 += 0.00000000986*np.cos(5.74810996970 + 2111.6503133776*t)
	X3 += 0.00000000882*np.cos(4.56360027025 + 234.6397364404*t)
	X3 += 0.00000001043*np.cos(4.55359910492 + 1080.7225711916*t)
	X3 += 0.00000000823*np.cos(3.61012761004 + 654.1243803156*t)
	X3 += 0.00000000889*np.cos(3.10427323318 + 295.0512286542*t)
	X3 += 0.00000000868*np.cos(0.26075561298 + 1898.3512179396*t)
	X3 += 0.00000000905*np.cos(3.60441853888 + 1692.1656695024*t)
	X3 += 0.00000000762*np.cos(0.94919223996 + 1251.3403846248*t)
	X3 += 0.00000000862*np.cos(2.09929286649 + 2008.557539159*t)
	X3 += 0.00000000962*np.cos(0.09308039006 + 2317.8358618148*t)
	X3 += 0.00000000832*np.cos(0.14644054564 + 2001.4439921582*t)
	X3 += 0.00000000789*np.cos(6.19434632992 + 2214.7430875962*t)
	X3 += 0.00000000903*np.cos(0.25250598146 + 846.0828347512*t)
	X3 += 0.00000000726*np.cos(4.95426701657 + 2840.4132799086*t)
	X3 += 0.00000000699*np.cos(5.13117531200 + 2524.021410252*t)
	X3 += 0.00000000735*np.cos(4.32136147400 + 1905.4647649404*t)
	X3 += 0.00000000667*np.cos(0.10114093196 + 1788.1448967202*t)
	X3 += 0.00000000684*np.cos(3.61438533975 + 1141.1340634054*t)
	X3 += 0.00000000696*np.cos(3.37226066080 + 2435.155730035*t)
	X3 += 0.00000000692*np.cos(0.64255931050 + 1994.3304451574*t)
	X3 += 0.00000000742*np.cos(0.61562551337 + 533.6231183577*t)
	X3 += 0.00000000742*np.cos(0.58346748141 + 525.7588118315*t)
	X3 += 0.00000000714*np.cos(5.01211566337 + 2015.6710861598*t)
	X3 += 0.00000000594*np.cos(0.66342094559 + 1781.0313497194*t)
	X3 += 0.00000000599*np.cos(3.15618247836 + 2751.5475996916*t)
	X3 += 0.00000000544*np.cos(3.85484227605 + 1802.3719907218*t)
	X3 += 0.00000000636*np.cos(6.15858110426 + 2627.1141844706*t)
	X3 += 0.00000000484*np.cos(5.02743632960 + 2200.5159935946*t)
	X3 += 0.00000000525*np.cos(4.03223001888 + 2221.856634597*t)
	X3 += 0.00000000618*np.cos(6.12607651654 + 2634.2277314714*t)
	X3 += 0.00000000463*np.cos(0.23881154687 + 1464.6394800628*t)
	X3 += 0.00000000477*np.cos(5.94296788958 + 2531.1349572528*t)
	X3 += 0.00000000429*np.cos(4.39269281492 + 2737.32050569*t)
	X3 += 0.00000000478*np.cos(0.30022321250 + 2310.722314814*t)
	X3 += 0.00000000566*np.cos(4.81779203356 + 2332.0629558164*t)
	X3 += 0.00000000417*np.cos(0.89795666781 + 1891.2376709388*t)
	X3 += 0.00000000436*np.cos(5.88250080039 + 2104.5367663768*t)
	X3 += 0.00000000415*np.cos(6.25558191427 + 501.2367770914*t)
	X3 += 0.00000000415*np.cos(1.22669638769 + 558.1451530978*t)
	X3 += 0.00000000412*np.cos(0.92939189489 + 1884.124123938*t)
	X3 += 0.00000000465*np.cos(5.90431132183 + 2943.5060541272*t)
	return X3*t*t*t




def Jupiter_X4 (t): # 59 terms of order 4

	X4 = 0.
	X4 += 0.00001760720*np.cos(1.32863064568 + 522.5774180938*t)
	X4 += 0.00001716208*np.cos(3.03331509801 + 536.8045120954*t)
	X4 += 0.00000303771*np.cos(1.43144429266 + 515.463871093*t)
	X4 += 0.00000216302*np.cos(2.91205595526 + 543.9180590962*t)
	X4 += 0.00000128071*np.cos(3.83023921553 + 1066.49547719*t)
	X4 -= 0.00000160571
	X4 += 0.00000081343*np.cos(4.47957999274 + 7.1135470008*t)
	X4 += 0.00000056005*np.cos(1.80944710241 + 1059.3819301892*t)
	X4 += 0.00000068446*np.cos(1.06498404827 + 1052.2683831884*t)
	X4 += 0.00000050538*np.cos(4.47153935627 + 14.2270940016*t)
	X4 += 0.00000023705*np.cos(0.46845139714 + 1045.1548361876*t)
	X4 += 0.00000015040*np.cos(1.64164559242 + 508.3503240922*t)
	X4 += 0.00000013698*np.cos(2.90817209326 + 1589.0728952838*t)
	X4 += 0.00000010393*np.cos(3.46066767483 + 1073.6090241908*t)
	X4 += 0.00000010460*np.cos(4.49720157210 + 1596.1864422846*t)
	X4 += 0.00000009605*np.cos(4.66560401468 + 110.2063212194*t)
	X4 += 0.00000009850*np.cos(5.49230112198 + 117.3198682202*t)
	X4 += 0.00000007280*np.cos(3.06439988034 + 529.6909650946*t)
	X4 += 0.00000007291*np.cos(2.57695133603 + 551.031606097*t)
	X4 += 0.00000005808*np.cos(2.75694018383 + 95.9792272178*t)
	X4 += 0.00000005282*np.cos(4.19154929039 + 330.6189636582*t)
	X4 += 0.00000005227*np.cos(4.20166339031 + 323.5054166574*t)
	X4 += 0.00000005123*np.cos(5.19044516005 + 942.062061969*t)
	X4 += 0.00000004553*np.cos(0.08961772842 + 728.762966531*t)
	X4 += 0.00000003703*np.cos(3.26663025973 + 220.4126424388*t)
	X4 += 0.00000003511*np.cos(0.36129476314 + 625.6701923124*t)
	X4 += 0.00000003596*np.cos(0.14061655375 + 735.8765135318*t)
	X4 += 0.00000003220*np.cos(3.56536563011 + 199.0720014364*t)
	X4 += 0.00000002953*np.cos(1.74528805009 + 618.5566453116*t)
	X4 += 0.00000002860*np.cos(1.13445966545 + 1581.959348283*t)
	X4 += 0.00000003120*np.cos(3.81985007727 + 103.0927742186*t)
	X4 += 0.00000002704*np.cos(2.39724100359 + 440.8252848776*t)
	X4 += 0.00000003073*np.cos(4.67521947679 + 426.598190876*t)
	X4 += 0.00000002589*np.cos(2.57394462010 + 1169.5882514086*t)
	X4 += 0.00000003345*np.cos(3.28565947310 + 433.7117378768*t)
	X4 += 0.00000002327*np.cos(0.80202919113 + 1155.361157407*t)
	X4 += 0.00000002272*np.cos(1.56364838180 + 206.1855484372*t)
	X4 += 0.00000001846*np.cos(3.22559348098 + 227.5261894396*t)
	X4 += 0.00000002210*np.cos(1.54023802061 + 419.4846438752*t)
	X4 += 0.00000001916*np.cos(1.91460518178 + 412.3710968744*t)
	X4 += 0.00000001600*np.cos(3.33931055087 + 2118.7638603784*t)
	X4 += 0.00000001496*np.cos(0.63527761947 + 1574.8458012822*t)
	X4 += 0.00000001804*np.cos(5.66814046505 + 632.7837393132*t)
	X4 += 0.00000001477*np.cos(0.52953212717 + 831.8557407496*t)
	X4 += 0.00000001187*np.cos(5.73863552700 + 853.196381752*t)
	X4 += 0.00000001316*np.cos(0.52819139641 + 956.2891559706*t)
	X4 += 0.00000001198*np.cos(1.60795245257 + 1258.4539316256*t)
	X4 += 0.00000001531*np.cos(2.60361413382 + 639.897286314*t)
	X4 += 0.00000001324*np.cos(4.57383336198 + 302.164775655*t)
	X4 += 0.00000000953*np.cos(1.76837026543 + 309.2783226558*t)
	X4 += 0.00000001142*np.cos(5.56554949818 + 949.1756089698*t)
	X4 += 0.00000000868*np.cos(0.67942468081 + 1038.0412891868*t)
	X4 += 0.00000000804*np.cos(1.12656034383 + 838.9692877504*t)
	X4 += 0.00000000817*np.cos(0.87495679358 + 742.9900605326*t)
	X4 += 0.00000000890*np.cos(2.70183985725 + 647.0108333148*t)
	X4 += 0.00000000598*np.cos(4.03226522649 + 337.732510659*t)
	X4 += 0.00000000557*np.cos(2.29508710588 + 1485.9801210652*t)
	X4 += 0.00000000451*np.cos(0.61566349461 + 1471.7530270636*t)
	X4 += 0.00000000396*np.cos(3.90384143043 + 1603.2999892854*t)
	return X4*t*t*t*t




def Jupiter_X5 (t): # 11 terms of order 5

	X5 = 0.
	X5 += 0.00000131346*np.cos(3.21284931869 + 522.5774180938*t)
	X5 += 0.00000126628*np.cos(1.16307002134 + 536.8045120954*t)
	X5 += 0.00000048324*np.cos(3.19657723128 + 515.463871093*t)
	X5 += 0.00000034034*np.cos(1.12801913258 + 543.9180590962*t)
	X5 += 0.00000011212*np.cos(2.19340618601 + 1066.49547719*t)
	X5 += 0.00000004060*np.cos(3.34247545563 + 1052.2683831884*t)
	X5 += 0.00000001943*np.cos(1.75237885755 + 1073.6090241908*t)
	X5 += 0.00000001786*np.cos(3.07103740660 + 1045.1548361876*t)
	X5 += 0.00000000886*np.cos(3.25499265714 + 508.3503240922*t)
	X5 += 0.00000000886*np.cos(4.22728564482 + 551.031606097*t)
	X5 += 0.00000000467*np.cos(2.94921347849 + 1596.1864422846*t)
	return X5*t*t*t*t*t




def Jupiter_Y0 (t): # 1064 terms of order 0

	Y0 = 0.
	Y0 += 5.19024510371*np.cos(5.31203160043 + 529.6909650946*t)
	Y0 += 0.12580850775*np.cos(5.66160225641 + 1059.3819301892*t)
	Y0 -= 0.09329801081
	Y0 += 0.01506838468*np.cos(5.43934599781 + 522.5774180938*t)
	Y0 += 0.01474403395*np.cos(2.04679547637 + 536.8045120954*t)
	Y0 += 0.00457314174*np.cos(6.01129093508 + 1589.0728952838*t)
	Y0 += 0.00301069256*np.cos(3.60943303554 + 7.1135470008*t)
	Y0 += 0.00378016915*np.cos(3.53013675622 + 103.0927742186*t)
	Y0 += 0.00190850034*np.cos(3.41807324121 + 426.598190876*t)
	Y0 += 0.00146192922*np.cos(4.62080103783 + 110.2063212194*t)
	Y0 += 0.00139367298*np.cos(4.00075739657 + 632.7837393132*t)
	Y0 += 0.00154904248*np.cos(0.59924790507 + 38.1330356378*t)
	Y0 += 0.00139655050*np.cos(2.41039954154 + 213.299095438*t)
	Y0 += 0.00101901831*np.cos(4.57592165280 + 1052.2683831884*t)
	Y0 += 0.00113934096*np.cos(4.72982346991 + 1162.4747044078*t)
	Y0 += 0.00072021597*np.cos(2.39048430255 + 1066.49547719*t)
	Y0 += 0.00082109296*np.cos(0.76861586597 + 74.7815985673*t)
	Y0 += 0.00058995131*np.cos(2.89529666872 + 949.1756089698*t)
	Y0 += 0.00068308433*np.cos(1.86538762629 + 846.0828347512*t)
	Y0 += 0.00030597479*np.cos(4.58059597562 + 206.1855484372*t)
	Y0 += 0.00027182574*np.cos(3.86962082273 + 419.4846438752*t)
	Y0 += 0.00026615785*np.cos(3.28135958246 + 323.5054166574*t)
	Y0 += 0.00020859553*np.cos(3.79339751809 + 735.8765135318*t)
	Y0 += 0.00019708579*np.cos(0.07818533602 + 2118.7638603784*t)
	Y0 += 0.00018475985*np.cos(0.38014924174 + 316.3918696566*t)
	Y0 += 0.00016340182*np.cos(5.56996543941 + 515.463871093*t)
	Y0 += 0.00014591238*np.cos(0.47749865610 + 742.9900605326*t)
	Y0 += 0.00011409020*np.cos(1.91089175916 + 543.9180590962*t)
	Y0 += 0.00012141842*np.cos(2.18151948736 + 525.7588118315*t)
	Y0 += 0.00011977440*np.cos(5.29687559056 + 533.6231183577*t)
	Y0 += 0.00008616295*np.cos(1.88432673589 + 639.897286314*t)
	Y0 += 0.00008155250*np.cos(4.00303466226 + 1478.8665740644*t)
	Y0 += 0.00008724471*np.cos(5.09607077968 + 1692.1656695024*t)
	Y0 += 0.00007407157*np.cos(4.41139821796 + 956.2891559706*t)
	Y0 += 0.00007612244*np.cos(5.59551514884 + 1265.5674786264*t)
	Y0 += 0.00007771810*np.cos(4.83345042174 + 1581.959348283*t)
	Y0 += 0.00005317804*np.cos(5.81740415262 + 526.5095713569*t)
	Y0 += 0.00005212049*np.cos(1.66178652182 + 532.8723588323*t)
	Y0 += 0.00005779694*np.cos(3.46910255172 + 14.2270940016*t)
	Y0 += 0.00004523994*np.cos(2.18377830705 + 1375.7737998458*t)
	Y0 += 0.00003936117*np.cos(2.73830533792 + 1596.1864422846*t)
	Y0 += 0.00004560167*np.cos(3.71314128422 + 95.9792272178*t)
	Y0 += 0.00004315104*np.cos(2.32571714706 + 220.4126424388*t)
	Y0 += 0.00003233079*np.cos(4.76624918569 + 625.6701923124*t)
	Y0 += 0.00003143497*np.cos(5.59546424392 + 309.2783226558*t)
	Y0 += 0.00002855098*np.cos(4.44236932266 + 117.3198682202*t)
	Y0 += 0.00002493551*np.cos(2.63229075589 + 433.7117378768*t)
	Y0 += 0.00002253179*np.cos(4.28438309510 + 838.9692877504*t)
	Y0 += 0.00002669715*np.cos(1.61858602910 + 1169.5882514086*t)
	Y0 += 0.00002360832*np.cos(4.60394012299 + 1155.361157407*t)
	Y0 += 0.00002407297*np.cos(4.33193163020 + 1045.1548361876*t)
	Y0 += 0.00001446641*np.cos(4.19563248990 + 853.196381752*t)
	Y0 += 0.00001430793*np.cos(3.24847402298 + 942.062061969*t)
	Y0 += 0.00001515123*np.cos(5.52831163402 + 76.2660712756*t)
	Y0 += 0.00001049240*np.cos(4.83710121026 + 1795.258443721*t)
	Y0 += 0.00001068309*np.cos(3.50234523972 + 149.5631971346*t)
	Y0 += 0.00001001392*np.cos(1.50933910971 + 1272.6810256272*t)
	Y0 += 0.00000927798*np.cos(4.69867109058 + 199.0720014364*t)
	Y0 += 0.00000933585*np.cos(0.42886091288 + 2648.454825473*t)
	Y0 += 0.00000857503*np.cos(2.14237483739 + 529.6427809848*t)
	Y0 += 0.00000857409*np.cos(5.34018594971 + 529.7391492044*t)
	Y0 += 0.00001086691*np.cos(5.84673086007 + 527.2432845398*t)
	Y0 += 0.00001078483*np.cos(1.63448489409 + 532.1386456494*t)
	Y0 += 0.00000805858*np.cos(1.68347880812 + 1368.660252845*t)
	Y0 += 0.00000849377*np.cos(5.93008131847 + 3.9321532631*t)
	Y0 += 0.00000979876*np.cos(0.62999505217 + 380.12776796*t)
	Y0 += 0.00000681433*np.cos(4.52942833577 + 2008.557539159*t)
	Y0 += 0.00000669250*np.cos(4.02991800155 + 728.762966531*t)
	Y0 += 0.00000747587*np.cos(3.13900220978 + 330.6189636582*t)
	Y0 += 0.00000622673*np.cos(4.84900709108 + 2111.6503133776*t)
	Y0 += 0.00000693269*np.cos(6.05214054958 + 1063.3140834523*t)
	Y0 += 0.00000810807*np.cos(1.68389354765 + 36.6485629295*t)
	Y0 += 0.00000679349*np.cos(5.00632262220 + 528.7277572481*t)
	Y0 += 0.00000677719*np.cos(2.47630821156 + 530.6541729411*t)
	Y0 += 0.00000764357*np.cos(2.65606240204 + 39.6175083461*t)
	Y0 += 0.00000574772*np.cos(5.46049842798 + 2221.856634597*t)
	Y0 += 0.00000562359*np.cos(2.49305783453 + 1055.4497769261*t)
	Y0 += 0.00000520398*np.cos(4.17408062213 + 412.3710968744*t)
	Y0 += 0.00000646493*np.cos(3.55496427110 + 984.6003316219*t)
	Y0 += 0.00000619706*np.cos(4.99312870911 + 73.297125859*t)
	Y0 += 0.00000455923*np.cos(3.65451578680 + 1471.7530270636*t)
	Y0 += 0.00000459484*np.cos(2.25588184103 + 1073.6090241908*t)
	Y0 += 0.00000409961*np.cos(1.41779564138 + 909.8187330546*t)
	Y0 += 0.00000356786*np.cos(5.38552517683 + 1258.4539316256*t)
	Y0 += 0.00000298994*np.cos(2.48545944253 + 1905.4647649404*t)
	Y0 += 0.00000388085*np.cos(4.49029251429 + 604.4725636619*t)
	Y0 += 0.00000381526*np.cos(3.30809878716 + 3.1813937377*t)
	Y0 += 0.00000303554*np.cos(3.49297365012 + 529.1697002328*t)
	Y0 += 0.00000303162*np.cos(3.98820918869 + 530.2122299564*t)
	Y0 += 0.00000275469*np.cos(5.36300079979 + 1485.9801210652*t)
	Y0 += 0.00000360399*np.cos(2.95684974227 + 454.9093665273*t)
	Y0 += 0.00000254084*np.cos(2.01404102614 + 1062.5633239269*t)
	Y0 += 0.00000263605*np.cos(4.57702219165 + 1574.8458012822*t)
	Y0 += 0.00000226746*np.cos(3.08749062400 + 2125.8774073792*t)
	Y0 += 0.00000313393*np.cos(0.43158674784 + 1.4844727083*t)
	Y0 += 0.00000291780*np.cos(4.55438134440 + 305.3461693927*t)
	Y0 += 0.00000225365*np.cos(1.93114578540 + 1699.2792165032*t)
	Y0 += 0.00000195682*np.cos(5.71184250491 + 508.3503240922*t)
	Y0 += 0.00000233061*np.cos(5.63548274339 + 1056.2005364515*t)
	Y0 += 0.00000206507*np.cos(2.44559206255 + 490.3340891794*t)
	Y0 += 0.00000178668*np.cos(4.53006987831 + 526.7702037878*t)
	Y0 += 0.00000176836*np.cos(2.95243321654 + 532.6117264014*t)
	Y0 += 0.00000172174*np.cos(5.18690898255 + 1898.3512179396*t)
	Y0 += 0.00000164895*np.cos(1.90578911049 + 528.9402055692*t)
	Y0 += 0.00000164428*np.cos(5.57619423730 + 530.44172462*t)
	Y0 += 0.00000191309*np.cos(5.01693530357 + 569.0478410098*t)
	Y0 += 0.00000155253*np.cos(5.96579343456 + 519.3960243561*t)
	Y0 += 0.00000215033*np.cos(0.97247400986 + 453.424893819*t)
	Y0 += 0.00000208029*np.cos(1.82281580042 + 1439.5096981492*t)
	Y0 += 0.00000166318*np.cos(2.18789857891 + 227.5261894396*t)
	Y0 += 0.00000157821*np.cos(2.75764008856 + 525.4981794006*t)
	Y0 += 0.00000143184*np.cos(1.74721580071 + 647.0108333148*t)
	Y0 += 0.00000155330*np.cos(4.72686984010 + 533.8837507886*t)
	Y0 += 0.00000194397*np.cos(3.73461249764 + 1021.2488945514*t)
	Y0 += 0.00000152748*np.cos(5.70508500758 + 302.164775655*t)
	Y0 += 0.00000124507*np.cos(3.45933363747 + 1788.1448967202*t)
	Y0 += 0.00000133665*np.cos(4.63491612092 + 831.8557407496*t)
	Y0 += 0.00000120464*np.cos(1.51220177525 + 539.9859058331*t)
	Y0 += 0.00000136353*np.cos(1.19193117513 + 11.0457002639*t)
	Y0 += 0.00000134210*np.cos(2.22679802479 + 540.7366653585*t)
	Y0 += 0.00000121761*np.cos(2.21859738997 + 524.0618908021*t)
	Y0 += 0.00000119917*np.cos(5.26558272368 + 535.3200393871*t)
	Y0 += 0.00000124308*np.cos(1.81779484703 + 983.1158589136*t)
	Y0 += 0.00000147352*np.cos(2.17702007809 + 1685.0521225016*t)
	Y0 += 0.00000123451*np.cos(1.77578502239 + 525.0250986486*t)
	Y0 += 0.00000117660*np.cos(1.79992315819 + 750.1036075334*t)
	Y0 += 0.00000104330*np.cos(2.19472037548 + 529.5309064002*t)
	Y0 += 0.00000104330*np.cos(5.28755792934 + 529.851023789*t)
	Y0 += 0.00000104709*np.cos(1.75471988531 + 551.031606097*t)
	Y0 += 0.00000119534*np.cos(5.02394121933 + 2324.9494088156*t)
	Y0 += 0.00000116048*np.cos(5.71003552223 + 534.3568315406*t)
	Y0 += 0.00000122687*np.cos(3.33550922454 + 524.2743391232*t)
	Y0 += 0.00000103035*np.cos(2.84300138853 + 963.4027029714*t)
	Y0 += 0.00000120843*np.cos(4.14524856046 + 535.107591066*t)
	Y0 += 0.00000106713*np.cos(4.96094254772 + 99.1606209555*t)
	Y0 += 0.00000105940*np.cos(1.95819770799 + 224.3447957019*t)
	Y0 += 0.00000125536*np.cos(5.60866656844 + 618.5566453116*t)
	Y0 += 0.00000094673*np.cos(1.67982421199 + 1802.3719907218*t)
	Y0 += 0.00000091797*np.cos(4.73071026858 + 1382.8873468466*t)
	Y0 += 0.00000093505*np.cos(1.46454811499 + 440.8252848776*t)
	Y0 += 0.00000111205*np.cos(1.86928344986 + 2001.4439921582*t)
	Y0 += 0.00000096227*np.cos(3.31553309486 + 21.3406410024*t)
	Y0 += 0.00000072096*np.cos(2.45181685946 + 529.9034134157*t)
	Y0 += 0.00000072096*np.cos(5.03046144250 + 529.4785167735*t)
	Y0 += 0.00000095413*np.cos(4.36603562454 + 35.4247226521*t)
	Y0 += 0.00000067561*np.cos(4.99490654468 + 518.6452648307*t)
	Y0 += 0.00000073325*np.cos(4.05750215119 + 511.5317178299*t)
	Y0 += 0.00000061465*np.cos(4.39223731837 + 415.5524906121*t)
	Y0 += 0.00000069844*np.cos(1.59443634281 + 114.1384744825*t)
	Y0 += 0.00000082393*np.cos(1.01105072945 + 531.1754378029*t)
	Y0 += 0.00000059078*np.cos(3.24284112832 + 2104.5367663768*t)
	Y0 += 0.00000068945*np.cos(3.40976028537 + 547.8502123593*t)
	Y0 += 0.00000074228*np.cos(2.84682779853 + 173.9422195228*t)
	Y0 += 0.00000055826*np.cos(3.23356285605 + 643.8294395771*t)
	Y0 += 0.00000063600*np.cos(4.60690964524 + 2214.7430875962*t)
	Y0 += 0.00000076559*np.cos(0.16914007578 + 528.2064923863*t)
	Y0 += 0.00000054010*np.cos(0.38559528823 + 1048.3362299253*t)
	Y0 += 0.00000069660*np.cos(4.17563833875 + 148.0787244263*t)
	Y0 += 0.00000052462*np.cos(3.04351725279 + 960.2213092337*t)
	Y0 += 0.00000054800*np.cos(5.00177597234 + 2641.3412784722*t)
	Y0 += 0.00000051559*np.cos(0.07590374858 + 514.7131115676*t)
	Y0 += 0.00000066311*np.cos(2.16873151551 + 230.5645708254*t)
	Y0 += 0.00000049711*np.cos(1.12330495040 + 544.6688186216*t)
	Y0 += 0.00000051168*np.cos(4.15417169162 + 2428.0421830342*t)
	Y0 += 0.00000048033*np.cos(1.64769682284 + 387.2413149608*t)
	Y0 += 0.00000064548*np.cos(5.74425604097 + 1364.7280995819*t)
	Y0 += 0.00000056419*np.cos(3.19672283659 + 107.0249274817*t)
	Y0 += 0.00000052715*np.cos(6.19618102970 + 1056.9342496344*t)
	Y0 += 0.00000062657*np.cos(2.18566435838 + 92.0470739547*t)
	Y0 += 0.00000046791*np.cos(4.99032278168 + 2538.2485042536*t)
	Y0 += 0.00000060723*np.cos(5.60401294480 + 494.2662424425*t)
	Y0 += 0.00000060019*np.cos(2.20885261687 + 1061.829610744*t)
	Y0 += 0.00000043765*np.cos(1.93541168857 + 2.4476805548*t)
	Y0 += 0.00000049754*np.cos(0.31051950136 + 679.2541622292*t)
	Y0 += 0.00000058551*np.cos(0.74219324450 + 1057.8974574809*t)
	Y0 += 0.00000047066*np.cos(0.78305409047 + 3178.1457905676*t)
	Y0 += 0.00000041687*np.cos(5.68958878057 + 1059.430114299*t)
	Y0 += 0.00000040368*np.cos(4.11954132163 + 1148.2476104062*t)
	Y0 += 0.00000049389*np.cos(4.38369647117 + 1038.0412891868*t)
	Y0 += 0.00000052125*np.cos(1.89237545851 + 565.1156877467*t)
	Y0 += 0.00000044536*np.cos(6.05157084759 + 430.5303441391*t)
	Y0 += 0.00000049041*np.cos(2.58330127182 + 523.5406259403*t)
	Y0 += 0.00000043994*np.cos(3.28606341309 + 312.4597163935*t)
	Y0 += 0.00000039255*np.cos(2.02159491333 + 70.8494453042*t)
	Y0 += 0.00000041687*np.cos(2.49177765294 + 1059.3337460794*t)
	Y0 += 0.00000037225*np.cos(5.83615789846 + 2751.5475996916*t)
	Y0 += 0.00000039989*np.cos(4.94492591486 + 106.2741679563*t)
	Y0 += 0.00000041523*np.cos(3.87602477966 + 1514.2912967165*t)
	Y0 += 0.00000041708*np.cos(3.08131901475 + 10.2949407385*t)
	Y0 += 0.00000048107*np.cos(1.57443805994 + 2317.8358618148*t)
	Y0 += 0.00000040678*np.cos(4.91071405404 + 18.1592472647*t)
	Y0 += 0.00000035790*np.cos(5.85585888690 + 672.1406152284*t)
	Y0 += 0.00000044449*np.cos(4.90238683987 + 535.8413042489*t)
	Y0 += 0.00000036844*np.cos(4.16675448786 + 529.4303326637*t)
	Y0 += 0.00000036844*np.cos(3.31552381410 + 529.9515975255*t)
	Y0 += 0.00000047082*np.cos(2.16479013510 + 1512.8068240082*t)
	Y0 += 0.00000041507*np.cos(0.21319785414 + 1593.0050485469*t)
	Y0 += 0.00000045707*np.cos(5.76601541697 + 39.3568759152*t)
	Y0 += 0.00000032943*np.cos(2.27946726035 + 522.529233984*t)
	Y0 += 0.00000035390*np.cos(5.49210934651 + 522.6256022036*t)
	Y0 += 0.00000032736*np.cos(4.24830882555 + 124.433415221*t)
	Y0 += 0.00000034850*np.cos(2.92484630853 + 1060.3451380357*t)
	Y0 += 0.00000035863*np.cos(4.35046455076 + 1891.2376709388*t)
	Y0 += 0.00000030492*np.cos(2.81576230965 + 1585.1407420207*t)
	Y0 += 0.00000029098*np.cos(5.87348600011 + 121.2520214833*t)
	Y0 += 0.00000030239*np.cos(5.00279271503 + 217.2312487011*t)
	Y0 += 0.00000033535*np.cos(1.40186973712 + 628.8515860501*t)
	Y0 += 0.00000034784*np.cos(3.03113665420 + 35.1640902212*t)
	Y0 += 0.00000029909*np.cos(1.98838991554 + 536.7563279856*t)
	Y0 += 0.00000027497*np.cos(5.20349352400 + 536.8526962052*t)
	Y0 += 0.00000033054*np.cos(4.51359014873 + 567.8240007324*t)
	Y0 += 0.00000027261*np.cos(2.72031348322 + 2420.9286360334*t)
	Y0 += 0.00000028101*np.cos(1.37111796252 + 1361.5467058442*t)
	Y0 += 0.00000031861*np.cos(5.82123598345 + 63.7358983034*t)
	Y0 += 0.00000027675*np.cos(3.76752413844 + 528.4189407074*t)
	Y0 += 0.00000027586*np.cos(3.71471333440 + 530.9629894818*t)
	Y0 += 0.00000033894*np.cos(4.63464333784 + 885.4397106664*t)
	Y0 += 0.00000025302*np.cos(0.69085103669 + 458.8415197904*t)
	Y0 += 0.00000024545*np.cos(4.07153029692 + 99.9113804809*t)
	Y0 += 0.00000032993*np.cos(5.35577320707 + 1058.4187223427*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000023976*np.cos(4.11015501858 + 523.0986829556*t)
	Y0 += 0.00000027158*np.cos(4.04172462614 + 934.9485149682*t)
	Y0 += 0.00000030585*np.cos(3.14036027150 + 1023.9572075371*t)
	Y0 += 0.00000025975*np.cos(4.25064688963 + 636.7158925763*t)
	Y0 += 0.00000031303*np.cos(4.76099302569 + 437.6438911399*t)
	Y0 += 0.00000027098*np.cos(5.64808831952 + 497.4476361802*t)
	Y0 += 0.00000026669*np.cos(1.61201743542 + 1158.5425511447*t)
	Y0 += 0.00000024690*np.cos(4.15165447061 + 746.9222137957*t)
	Y0 += 0.00000027630*np.cos(6.12901028563 + 142.4496501338*t)
	Y0 += 0.00000024824*np.cos(4.87213067968 + 1134.1635287565*t)
	Y0 += 0.00000021870*np.cos(3.37410336472 + 536.2832472336*t)
	Y0 += 0.00000022230*np.cos(5.18596760154 + 521.6142102473*t)
	Y0 += 0.00000023248*np.cos(3.15413339570 + 422.6660376129*t)
	Y0 += 0.00000027936*np.cos(3.40155518417 + 1289.9465010146*t)
	Y0 += 0.00000019758*np.cos(3.57384619762 + 1464.6394800628*t)
	Y0 += 0.00000019591*np.cos(2.60352108738 + 1603.2999892854*t)
	Y0 += 0.00000024397*np.cos(4.50292148947 + 299.1263942692*t)
	Y0 += 0.00000023457*np.cos(0.09576335036 + 71.8126531507*t)
	Y0 += 0.00000024393*np.cos(1.76922514363 + 561.934294009*t)
	Y0 += 0.00000020407*np.cos(2.19002169997 + 209.3669421749*t)
	Y0 += 0.00000018904*np.cos(0.54644235979 + 327.4375699205*t)
	Y0 += 0.00000022716*np.cos(5.17863516688 + 85.8272988312*t)
	Y0 += 0.00000021220*np.cos(4.75366337409 + 495.7507151508*t)
	Y0 += 0.00000018395*np.cos(3.09432236608 + 953.1077622329*t)
	Y0 += 0.00000024519*np.cos(3.57287234365 + 860.3099287528*t)
	Y0 += 0.00000019559*np.cos(0.33422760418 + 1098.7388061044*t)
	Y0 += 0.00000019652*np.cos(0.82367591291 + 835.0371344873*t)
	Y0 += 0.00000018357*np.cos(0.62106608418 + 5.6290742925*t)
	Y0 += 0.00000023520*np.cos(2.68263802863 + 621.7380390493*t)
	Y0 += 0.00000018076*np.cos(0.42845386573 + 600.5404103988*t)
	Y0 += 0.00000017290*np.cos(4.86922116560 + 191.9584544356*t)
	Y0 += 0.00000017517*np.cos(2.68195071531 + 2435.155730035*t)
	Y0 += 0.00000017066*np.cos(2.47355544144 + 491.5579294568*t)
	Y0 += 0.00000017873*np.cos(2.29598514123 + 537.7677199419*t)
	Y0 += 0.00000016951*np.cos(4.03050492549 + 2744.4340526908*t)
	Y0 += 0.00000018236*np.cos(3.95613517708 + 2207.6295405954*t)
	Y0 += 0.00000021575*np.cos(4.69631525985 + 1166.4068576709*t)
	Y0 += 0.00000022104*np.cos(2.36649230999 + 2.9689454166*t)
	Y0 += 0.00000018927*np.cos(2.72326904719 + 563.6312150384*t)
	Y0 += 0.00000021762*np.cos(0.29745260068 + 88.865680217*t)
	Y0 += 0.00000016163*np.cos(4.86951152442 + 1049.0869894507*t)
	Y0 += 0.00000016488*np.cos(2.27763578296 + 2228.9701815978*t)
	Y0 += 0.00000019792*np.cos(5.64210393649 + 505.3119427064*t)
	Y0 += 0.00000018457*np.cos(2.18289841443 + 1969.2006632438*t)
	Y0 += 0.00000015808*np.cos(5.67233344465 + 988.532484885*t)
	Y0 += 0.00000016272*np.cos(2.33706628798 + 526.9826521089*t)
	Y0 += 0.00000016170*np.cos(5.14508663480 + 532.3992780803*t)
	Y0 += 0.00000015841*np.cos(0.56125268750 + 731.9443602687*t)
	Y0 += 0.00000015853*np.cos(1.45510827717 + 501.3797894433*t)
	Y0 += 0.00000016239*np.cos(2.20090269794 + 32.2433289144*t)
	Y0 += 0.00000019490*np.cos(3.99449705530 + 2531.1349572528*t)
	Y0 += 0.00000015691*np.cos(2.48513582725 + 24.3790223882*t)
	Y0 += 0.00000015762*np.cos(2.41995384072 + 151.0476698429*t)
	Y0 += 0.00000018341*np.cos(1.84170602460 + 554.0699874828*t)
	Y0 += 0.00000020372*np.cos(1.38538116490 + 2634.2277314714*t)
	Y0 += 0.00000014994*np.cos(2.01198210400 + 460.5384408198*t)
	Y0 += 0.00000014712*np.cos(3.84306627886 + 1058.8606653274*t)
	Y0 += 0.00000014869*np.cos(5.98368245357 + 558.0021407459*t)
	Y0 += 0.00000018453*np.cos(4.87426042676 + 77.7505439839*t)
	Y0 += 0.00000014439*np.cos(3.28637158278 + 1070.4276304531*t)
	Y0 += 0.00000018929*np.cos(2.03175968425 + 535.9107402181*t)
	Y0 += 0.00000015643*np.cos(0.97730443591 + 4.665866446*t)
	Y0 += 0.00000016231*np.cos(1.40541369418 + 138.5174968707*t)
	Y0 += 0.00000018715*np.cos(5.44782618977 + 523.4711899711*t)
	Y0 += 0.00000017929*np.cos(3.40311830148 + 1151.4290041439*t)
	Y0 += 0.00000013761*np.cos(6.04543388528 + 67.6680515665*t)
	Y0 += 0.00000013749*np.cos(0.52644877498 + 450.9772132642*t)
	Y0 += 0.00000013319*np.cos(2.42538953638 + 2737.32050569*t)
	Y0 += 0.00000013569*np.cos(5.77906642060 + 1585.8915015461*t)
	Y0 += 0.00000014895*np.cos(0.11330960665 + 2015.6710861598*t)
	Y0 += 0.00000013428*np.cos(5.50626546494 + 597.3590166611*t)
	Y0 += 0.00000013707*np.cos(2.03789881373 + 498.6714764576*t)
	Y0 += 0.00000013957*np.cos(2.36417098087 + 1592.2542890215*t)
	Y0 += 0.00000013524*np.cos(3.44876320737 + 2655.5683724738*t)
	Y0 += 0.00000012857*np.cos(5.50739277119 + 598.8434893694*t)
	Y0 += 0.00000014249*np.cos(1.72248779684 + 462.0229135281*t)
	Y0 += 0.00000014314*np.cos(4.07019733205 + 1550.939859646*t)
	Y0 += 0.00000015119*np.cos(5.81156443174 + 760.25553592*t)
	Y0 += 0.00000014774*np.cos(5.80625161615 + 945.2434557067*t)
	Y0 += 0.00000013736*np.cos(4.07129679948 + 113.3877149571*t)
	Y0 += 0.00000012011*np.cos(1.63521325776 + 938.1299087059*t)
	Y0 += 0.00000012753*np.cos(5.44403915759 + 560.7104537316*t)
	Y0 += 0.00000012686*np.cos(6.23818302908 + 531.387886124*t)
	Y0 += 0.00000012686*np.cos(1.24409527288 + 527.9940440652*t)
	Y0 += 0.00000015020*np.cos(6.08208603474 + 155.7829722581*t)
	Y0 += 0.00000015484*np.cos(1.72167500453 + 378.6432952517*t)
	Y0 += 0.00000014712*np.cos(4.33830015465 + 1059.903195051*t)
	Y0 += 0.00000011546*np.cos(0.31915225651 + 635.9651330509*t)
	Y0 += 0.00000011513*np.cos(2.74393569090 + 0.9632078465*t)
	Y0 += 0.00000011629*np.cos(0.67354350592 + 608.404716925*t)
	Y0 += 0.00000011186*np.cos(0.05170826029 + 528.2546764961*t)
	Y0 += 0.00000011186*np.cos(1.14738473449 + 531.1272536931*t)
	Y0 += 0.00000011189*np.cos(4.62167915661 + 629.6023455755*t)
	Y0 += 0.00000011721*np.cos(3.81962472178 + 46.470422916*t)
	Y0 += 0.00000013072*np.cos(4.76911685302 + 5.4166259714*t)
	Y0 += 0.00000010861*np.cos(3.06774497499 + 248.7238180901*t)
	Y0 += 0.00000010767*np.cos(2.81408028040 + 429.7795846137*t)
	Y0 += 0.00000011595*np.cos(5.00879785870 + 210.1177017003*t)
	Y0 += 0.00000013435*np.cos(2.74869166537 + 1041.2226829245*t)
	Y0 += 0.00000012895*np.cos(2.71685060291 + 944.9828232758*t)
	Y0 += 0.00000011192*np.cos(4.39980379850 + 33.9402499438*t)
	Y0 += 0.00000014182*np.cos(3.01202846061 + 1173.5204046717*t)
	Y0 += 0.00000014077*np.cos(5.16982319226 + 1251.3403846248*t)
	Y0 += 0.00000013485*np.cos(2.70711798609 + 381.6122406683*t)
	Y0 += 0.00000010332*np.cos(5.95361308692 + 605.9570363702*t)
	Y0 += 0.00000013791*np.cos(2.97971347845 + 337.732510659*t)
	Y0 += 0.00000013472*np.cos(4.50305810844 + 721.6494195302*t)
	Y0 += 0.00000009741*np.cos(5.19335132324 + 1159.2933106701*t)
	Y0 += 0.00000009875*np.cos(3.12964889470 + 9.5612275556*t)
	Y0 += 0.00000013201*np.cos(5.96637135723 + 28.3111756513*t)
	Y0 += 0.00000009379*np.cos(0.10962671346 + 320.3240229197*t)
	Y0 += 0.00000008980*np.cos(1.05396139591 + 1165.6560981455*t)
	Y0 += 0.00000009071*np.cos(2.27040574511 + 754.0357607965*t)
	Y0 += 0.00000008886*np.cos(0.31938474896 + 530.914805372*t)
	Y0 += 0.00000008886*np.cos(0.87970824582 + 528.4671248172*t)
	Y0 += 0.00000012120*np.cos(3.28130394954 + 1020.025054274*t)
	Y0 += 0.00000008878*np.cos(3.19756714253 + 195.1398481733*t)
	Y0 += 0.00000009323*np.cos(3.63280904935 + 2524.021410252*t)
	Y0 += 0.00000012149*np.cos(4.57844422505 + 72.0732855816*t)
	Y0 += 0.00000008701*np.cos(3.35407914352 + 1781.0313497194*t)
	Y0 += 0.00000008635*np.cos(4.87675285165 + 1056.4611688824*t)
	Y0 += 0.00000009302*np.cos(4.57312893311 + 1567.7322542814*t)
	Y0 += 0.00000010790*np.cos(5.34901281070 + 530.5847369719*t)
	Y0 += 0.00000010790*np.cos(2.13326549126 + 528.7971932173*t)
	Y0 += 0.00000007989*np.cos(2.25562114310 + 1058.6311706638*t)
	Y0 += 0.00000008394*np.cos(1.01712590368 + 525.5463635104*t)
	Y0 += 0.00000007749*np.cos(0.18520987807 + 521.8266585684*t)
	Y0 += 0.00000008309*np.cos(0.18252574301 + 533.8355666788*t)
	Y0 += 0.00000010492*np.cos(3.02062266658 + 319.5732633943*t)
	Y0 += 0.00000009795*np.cos(3.24578427066 + 114.3991069134*t)
	Y0 += 0.00000009455*np.cos(4.42860833187 + 2957.7331481288*t)
	Y0 += 0.00000007601*np.cos(1.01410800239 + 537.5552716208*t)
	Y0 += 0.00000008635*np.cos(3.30118117017 + 1062.302691496*t)
	Y0 += 0.00000007859*np.cos(5.09973182378 + 1064.7985561606*t)
	Y0 += 0.00000007602*np.cos(5.07538034057 + 1063.5747158832*t)
	Y0 += 0.00000008125*np.cos(6.02981549694 + 405.2575498736*t)
	Y0 += 0.00000007989*np.cos(5.92574529041 + 1060.1326897146*t)
	Y0 += 0.00000010154*np.cos(1.81583583759 + 456.3938392356*t)
	Y0 += 0.00000009868*np.cos(5.44091536822 + 2854.6403739102*t)
	Y0 += 0.00000007887*np.cos(3.45839291267 + 2847.5268269094*t)
	Y0 += 0.00000008390*np.cos(1.92118712996 + 2332.0629558164*t)
	Y0 += 0.00000007855*np.cos(4.08738591474 + 739.8086667949*t)
	Y0 += 0.00000009014*np.cos(1.02506603313 + 1201.831580323*t)
	Y0 += 0.00000009295*np.cos(0.67562856870 + 78.7137518304*t)
	Y0 += 0.00000009035*np.cos(1.17767860384 + 2950.619601128*t)
	Y0 += 0.00000007172*np.cos(5.78872895095 + 31.019488637*t)
	Y0 += 0.00000006861*np.cos(1.24455164613 + 1054.7160637432*t)
	Y0 += 0.00000007966*np.cos(4.97522951621 + 842.1506814881*t)
	Y0 += 0.00000007539*np.cos(5.35827249789 + 952.3570027075*t)
	Y0 += 0.00000007674*np.cos(4.58974675290 + 334.5511169213*t)
	Y0 += 0.00000008440*np.cos(5.66460249626 + 483.2205421786*t)
	Y0 += 0.00000006944*np.cos(1.12972621501 + 423.4167971383*t)
	Y0 += 0.00000008658*np.cos(1.03677088830 + 1215.1649024473*t)
	Y0 += 0.00000006766*np.cos(5.18191429441 + 1912.5783119412*t)
	Y0 += 0.00000008924*np.cos(5.67297999466 + 602.9880909536*t)
	Y0 += 0.00000006412*np.cos(2.13183556856 + 3053.7123753466*t)
	Y0 += 0.00000008710*np.cos(1.69359494585 + 576.1613880106*t)
	Y0 += 0.00000007535*np.cos(1.43209684879 + 1060.8664028975*t)
	Y0 += 0.00000006679*np.cos(2.28503170515 + 408.4389436113*t)
	Y0 += 0.00000006823*np.cos(0.60912657611 + 284.1485407422*t)
	Y0 += 0.00000006770*np.cos(5.53650784553 + 69.1525242748*t)
	Y0 += 0.00000006566*np.cos(0.40728171280 + 355.7487455718*t)
	Y0 += 0.00000008559*np.cos(2.16359232622 + 1677.9385755008*t)
	Y0 += 0.00000006912*np.cos(3.40820667177 + 945.9942152321*t)
	Y0 += 0.00000006730*np.cos(0.56194767825 + 528.0464336919*t)
	Y0 += 0.00000006730*np.cos(0.63714531653 + 531.3354964973*t)
	Y0 += 0.00000007602*np.cos(3.10155768831 + 1055.1891444952*t)
	Y0 += 0.00000006013*np.cos(5.10742672906 + 1035.002907801*t)
	Y0 += 0.00000005935*np.cos(2.94453315678 + 498.1983957056*t)
	Y0 += 0.00000007319*np.cos(1.36131082578 + 6.2197751235*t)
	Y0 += 0.00000005949*np.cos(2.57112575530 + 724.8308132679*t)
	Y0 += 0.00000005773*np.cos(1.99331049470 + 216.4804891757*t)
	Y0 += 0.00000005856*np.cos(5.61085624056 + 1276.6131788903*t)
	Y0 += 0.00000007648*np.cos(3.22132265146 + 247.2393453818*t)
	Y0 += 0.00000005605*np.cos(1.26367820429 + 513.2286388593*t)
	Y0 += 0.00000005584*np.cos(3.39988425577 + 100.6450936638*t)
	Y0 += 0.00000005502*np.cos(3.89695891739 + 3060.8259223474*t)
	Y0 += 0.00000005914*np.cos(3.68583540418 + 1053.9653042178*t)
	Y0 += 0.00000005497*np.cos(4.41143963319 + 810.6581120991*t)
	Y0 += 0.00000005507*np.cos(4.54722710597 + 561.1835344836*t)
	Y0 += 0.00000005666*np.cos(6.05825689215 + 1064.0477966352*t)
	Y0 += 0.00000005378*np.cos(6.21859996590 + 546.1532913299*t)
	Y0 += 0.00000006260*np.cos(3.19727825497 + 1493.093668066*t)
	Y0 += 0.00000006793*np.cos(5.62753980255 + 303.8616966844*t)
	Y0 += 0.00000005204*np.cos(3.23894565507 + 1091.6252591036*t)
	Y0 += 0.00000005131*np.cos(2.58192471387 + 1176.7017984094*t)
	Y0 += 0.00000006815*np.cos(1.54708178098 + 1053.7528558967*t)
	Y0 += 0.00000005065*np.cos(2.54426472948 + 1059.2218714948*t)
	Y0 += 0.00000006336*np.cos(2.50077514097 + 908.3342603463*t)
	Y0 += 0.00000004973*np.cos(1.03425894477 + 245.5424243524*t)
	Y0 += 0.00000005470*np.cos(1.85711160191 + 757.2171545342*t)
	Y0 += 0.00000004894*np.cos(0.33758490678 + 775.233389447*t)
	Y0 += 0.00000005382*np.cos(2.05459210213 + 512.4254897072*t)
	Y0 += 0.00000004986*np.cos(2.04169509272 + 234.6397364404*t)
	Y0 += 0.00000005693*np.cos(4.67643220253 + 166.828672522*t)
	Y0 += 0.00000005065*np.cos(5.63710170403 + 1059.5419888836*t)
	Y0 += 0.00000004985*np.cos(3.35221747486 + 2840.4132799086*t)
	Y0 += 0.00000004955*np.cos(1.84826531558 + 1069.6768709277*t)
	Y0 += 0.00000005153*np.cos(5.42768605926 + 546.956440482*t)
	Y0 += 0.00000004749*np.cos(4.04043420885 + 415.2918581812*t)
	Y0 += 0.00000004911*np.cos(6.22971061903 + 512.2824773553*t)
	Y0 += 0.00000004553*np.cos(1.47996204216 + 509.2440959695*t)
	Y0 += 0.00000006103*np.cos(4.10884733063 + 111.4301614968*t)
	Y0 += 0.00000004418*np.cos(3.08681555133 + 2097.423219376*t)
	Y0 += 0.00000004693*np.cos(4.50919332222 + 277.0349937414*t)
	Y0 += 0.00000004358*np.cos(4.98874241019 + 202.2533951741*t)
	Y0 += 0.00000004523*np.cos(6.15421637977 + 611.4430983108*t)
	Y0 += 0.00000004324*np.cos(6.00231606657 + 550.1378342197*t)
	Y0 += 0.00000004417*np.cos(0.89935900799 + 1127.0499817557*t)
	Y0 += 0.00000004688*np.cos(5.54227030903 + 504.561183181*t)
	Y0 += 0.00000004202*np.cos(5.15229838310 + 469.8872200543*t)
	Y0 += 0.00000004894*np.cos(0.30289339863 + 739.0579072695*t)
	Y0 += 0.00000004144*np.cos(1.71461163426 + 970.5162499722*t)
	Y0 += 0.00000005739*np.cos(3.37720444365 + 707.5653378805*t)
	Y0 += 0.00000004256*np.cos(2.95543472060 + 512.1648572763*t)
	Y0 += 0.00000004431*np.cos(4.63633093035 + 519.656656787*t)
	Y0 += 0.00000005723*np.cos(5.51760124056 + 1065.0110044817*t)
	Y0 += 0.00000005589*np.cos(4.77443673434 + 280.9671470045*t)
	Y0 += 0.00000004469*np.cos(0.52405952073 + 857.1285350151*t)
	Y0 += 0.00000004217*np.cos(3.24827021932 + 1489.9122743283*t)
	Y0 += 0.00000004804*np.cos(0.68976934373 + 391.1734682239*t)
	Y0 += 0.00000005007*np.cos(4.52014200146 + 491.8185618877*t)
	Y0 += 0.00000003986*np.cos(1.06372222504 + 447.9388318784*t)
	Y0 += 0.00000003947*np.cos(3.80242096180 + 112.6540017742*t)
	Y0 += 0.00000004072*np.cos(4.52684344190 + 547.2170729129*t)
	Y0 += 0.00000004369*np.cos(1.94834671030 + 554.8207470082*t)
	Y0 += 0.00000004085*np.cos(3.32144080176 + 916.9322800554*t)
	Y0 += 0.00000004733*np.cos(0.67139053204 + 1087.6931058405*t)
	Y0 += 0.00000003995*np.cos(0.85610382030 + 1578.0271950199*t)
	Y0 += 0.00000004301*np.cos(5.07216283379 + 203.0041546995*t)
	Y0 += 0.00000004393*np.cos(5.38198575849 + 3171.0322435668*t)
	Y0 += 0.00000003724*np.cos(0.33312188585 + 479.2883889155*t)
	Y0 += 0.00000004628*np.cos(2.95945654561 + 567.5633683015*t)
	Y0 += 0.00000004429*np.cos(3.33483303210 + 1025.4416802454*t)
	Y0 += 0.00000004166*np.cos(1.09654835252 + 1587.5884225755*t)
	Y0 += 0.00000004233*np.cos(2.53201175338 + 2042.4977891028*t)
	Y0 += 0.00000003711*np.cos(2.98775049023 + 3163.918696566*t)
	Y0 += 0.00000004086*np.cos(2.55427154862 + 237.6781178262*t)
	Y0 += 0.00000004681*np.cos(5.83662690281 + 295.0512286542*t)
	Y0 += 0.00000003571*np.cos(2.08867966814 + 1080.7225711916*t)
	Y0 += 0.00000003544*np.cos(4.38394808666 + 849.2642284889*t)
	Y0 += 0.00000004083*np.cos(3.86948524840 + 782.3469364478*t)
	Y0 += 0.00000003901*np.cos(3.58138051516 + 1894.4190646765*t)
	Y0 += 0.00000004577*np.cos(5.47618219772 + 146.594251718*t)
	Y0 += 0.00000003497*np.cos(2.80136092523 + 1059.5943785103*t)
	Y0 += 0.00000003507*np.cos(2.32962653089 + 589.4947101349*t)
	Y0 += 0.00000003472*np.cos(0.85726515864 + 580.0935412737*t)
	Y0 += 0.00000003680*np.cos(1.21278207938 + 547.0994528339*t)
	Y0 += 0.00000004542*np.cos(6.14690384106 + 105.5404547734*t)
	Y0 += 0.00000003369*np.cos(3.55330457921 + 103.1409583284*t)
	Y0 += 0.00000003630*np.cos(0.69909450749 + 81.7521332162*t)
	Y0 += 0.00000003697*np.cos(2.79029346680 + 326.6868103951*t)
	Y0 += 0.00000003539*np.cos(3.61983213468 + 1012.9115072732*t)
	Y0 += 0.00000003325*np.cos(0.37561309842 + 103.0445901088*t)
	Y0 += 0.00000003987*np.cos(0.97522695807 + 3267.0114707846*t)
	Y0 += 0.00000003497*np.cos(5.38000550828 + 1059.1694818681*t)
	Y0 += 0.00000004054*np.cos(3.71419071011 + 81.0013736908*t)
	Y0 += 0.00000003600*np.cos(4.29558839490 + 3274.1250177854*t)
	Y0 += 0.00000003350*np.cos(3.76399755757 + 1077.5411774539*t)
	Y0 += 0.00000003196*np.cos(5.60457950896 + 3067.9394693482*t)
	Y0 += 0.00000003455*np.cos(3.42091932175 + 488.8496164711*t)
	Y0 += 0.00000003335*np.cos(4.44235745725 + 1049.8207026336*t)
	Y0 += 0.00000003852*np.cos(2.52438607753 + 1065.6017053127*t)
	Y0 += 0.00000003924*np.cos(4.18314006350 + 836.5216071956*t)
	Y0 += 0.00000003619*np.cos(0.69464229610 + 104.0559820651*t)
	Y0 += 0.00000004403*np.cos(2.90782146623 + 987.3086446076*t)
	Y0 += 0.00000004179*np.cos(0.64452088191 + 373.9079928365*t)
	Y0 += 0.00000003691*np.cos(3.23351247093 + 102.1295663721*t)
	Y0 += 0.00000003303*np.cos(2.85125001065 + 539.7252734022*t)
	Y0 += 0.00000003982*np.cos(5.66127902337 + 986.0848043302*t)
	Y0 += 0.00000004012*np.cos(0.62727446399 + 668.2084619653*t)
	Y0 += 0.00000003967*np.cos(1.33281868984 + 486.4019359163*t)
	Y0 += 0.00000003184*np.cos(0.64736841195 + 654.1243803156*t)
	Y0 += 0.00000003012*np.cos(1.97259943071 + 3370.1042450032*t)
	Y0 += 0.00000004190*np.cos(4.11329406406 + 351.8165923087*t)
	Y0 += 0.00000003953*np.cos(2.04087960765 + 1123.1178284926*t)
	Y0 += 0.00000003959*np.cos(3.37764873211 + 306.830642101*t)
	Y0 += 0.00000002943*np.cos(5.66644527612 + 1269.4996318895*t)
	Y0 += 0.00000002958*np.cos(4.39711798299 + 527.6852275245*t)
	Y0 += 0.00000002958*np.cos(3.08516031897 + 531.6967026647*t)
	Y0 += 0.00000003000*np.cos(3.74971900277 + 911.3032057629*t)
	Y0 += 0.00000002909*np.cos(3.07525222975 + 522.6892926784*t)
	Y0 += 0.00000002909*np.cos(4.40702607221 + 536.6926375108*t)
	Y0 += 0.00000003563*np.cos(2.04687487947 + 1994.3304451574*t)
	Y0 += 0.00000003893*np.cos(4.26173750986 + 812.1425848074*t)
	Y0 += 0.00000003118*np.cos(4.06135823006 + 570.5323137181*t)
	Y0 += 0.00000003463*np.cos(2.60209047668 + 1591.5205758386*t)
	Y0 += 0.00000003751*np.cos(3.60628368678 + 977.4867846211*t)
	Y0 += 0.00000003448*np.cos(3.47211094381 + 685.4739373527*t)
	Y0 += 0.00000002870*np.cos(0.26308381178 + 1586.625214729*t)
	Y0 += 0.00000002875*np.cos(4.32622434464 + 504.4181708291*t)
	Y0 += 0.00000003866*np.cos(4.95821738791 + 824.7421937488*t)
	Y0 += 0.00000003556*np.cos(6.14961940524 + 572.9799942729*t)
	Y0 += 0.00000002918*np.cos(5.73628166716 + 967.3348562345*t)
	Y0 += 0.00000002906*np.cos(4.29227546323 + 416.3032501375*t)
	Y0 += 0.00000002909*np.cos(3.95660523001 + 1482.7987273275*t)
	Y0 += 0.00000002672*np.cos(0.87511357041 + 134.5853436076*t)
	Y0 += 0.00000002628*np.cos(0.00847208263 + 3281.2385647862*t)
	Y0 += 0.00000002715*np.cos(3.16963075966 + 554.9637593601*t)
	Y0 += 0.00000002651*np.cos(2.27063793995 + 144.1465711632*t)
	Y0 += 0.00000003601*np.cos(0.47144134781 + 991.7138786227*t)
	Y0 += 0.00000002614*np.cos(0.41964493730 + 93.531546663*t)
	Y0 += 0.00000002855*np.cos(2.03044050467 + 850.0149880143*t)
	Y0 += 0.00000002821*np.cos(1.06657048032 + 502.8642621516*t)
	Y0 += 0.00000003112*np.cos(6.03060444080 + 520.129737539*t)
	Y0 += 0.00000003142*np.cos(4.62490556976 + 539.2521926502*t)
	Y0 += 0.00000002731*np.cos(4.67337364490 + 522.4655435092*t)
	Y0 += 0.00000002731*np.cos(2.80890465706 + 536.91638668*t)
	Y0 += 0.00000003064*np.cos(4.44170325172 + 1884.124123938*t)
	Y0 += 0.00000002441*np.cos(0.83069302598 + 1474.9344208013*t)
	Y0 += 0.00000002456*np.cos(1.47279271371 + 1074.3597837162*t)
	Y0 += 0.00000002439*np.cos(2.08558923005 + 107.7586406646*t)
	Y0 += 0.00000002456*np.cos(0.42538841262 + 1044.4040766622*t)
	Y0 += 0.00000003031*np.cos(3.37619616684 + 521.0929453855*t)
	Y0 += 0.00000003031*np.cos(4.10608213512 + 538.2889848037*t)
	Y0 += 0.00000002590*np.cos(0.16004731508 + 556.5176680376*t)
	Y0 += 0.00000003226*np.cos(4.60312494465 + 522.7898664149*t)
	Y0 += 0.00000003226*np.cos(2.87915335731 + 536.5920637743*t)
	Y0 += 0.00000002363*np.cos(3.28962549381 + 285.3723810196*t)
	Y0 += 0.00000002452*np.cos(0.62028796575 + 1090.4014188262*t)
	Y0 += 0.00000002323*np.cos(2.60824432402 + 529.0578256482*t)
	Y0 += 0.00000002323*np.cos(4.87403397794 + 530.324104541*t)
	Y0 += 0.00000003159*np.cos(5.47332565610 + 457.617679513*t)
	Y0 += 0.00000003023*np.cos(6.11184318218 + 532.6599105112*t)
	Y0 += 0.00000003023*np.cos(1.37043511978 + 526.722019678*t)
	Y0 += 0.00000002393*np.cos(2.85135439551 + 1053.2315910349*t)
	Y0 += 0.00000002997*np.cos(2.91346721535 + 1438.0252254409*t)
	Y0 += 0.00000002922*np.cos(5.30505468617 + 109.9456887885*t)
	Y0 += 0.00000002824*np.cos(1.71227981800 + 108.7218485111*t)
	Y0 += 0.00000002220*np.cos(2.80874155199 + 2413.8150890326*t)
	Y0 += 0.00000002234*np.cos(3.74593385034 + 3377.217792004*t)
	Y0 += 0.00000002627*np.cos(2.23895631422 + 1094.8066528413*t)
	Y0 += 0.00000002477*np.cos(3.21084842387 + 3156.8051495652*t)
	Y0 += 0.00000002273*np.cos(6.03923806707 + 1589.1210793936*t)
	Y0 += 0.00000002190*np.cos(5.77618493519 + 97.6761482472*t)
	Y0 += 0.00000002217*np.cos(4.33373247849 + 1254.5217783625*t)
	Y0 += 0.00000002201*np.cos(4.15471098454 + 2043.9822618111*t)
	Y0 += 0.00000002858*np.cos(3.89745174384 + 1440.9941708575*t)
	Y0 += 0.00000002222*np.cos(4.98725374410 + 376.1956146969*t)
	Y0 += 0.00000002839*np.cos(4.97687573513 + 1140.38330388*t)
	Y0 += 0.00000002926*np.cos(4.39522157497 + 732.6951197941*t)
	Y0 += 0.00000002251*np.cos(2.16205964084 + 1067.4586850365*t)
	Y0 += 0.00000002782*np.cos(5.20073544600 + 451.9404211107*t)
	Y0 += 0.00000002191*np.cos(2.83588669322 + 842.9014410135*t)
	Y0 += 0.00000002512*np.cos(2.04067568304 + 1261.6353253633*t)
	Y0 += 0.00000002217*np.cos(1.56495606058 + 902.7051860538*t)
	Y0 += 0.00000002522*np.cos(0.74750896561 + 373.0142209592*t)
	Y0 += 0.00000002157*np.cos(5.37570047911 + 59.8037450403*t)
	Y0 += 0.00000002035*np.cos(3.84713937892 + 523.849442481*t)
	Y0 += 0.00000002035*np.cos(3.63513892304 + 535.5324877082*t)
	Y0 += 0.00000002769*np.cos(4.85615053084 + 1744.8558675419*t)
	Y0 += 0.00000002366*np.cos(1.24394483245 + 3707.8367556622*t)
	Y0 += 0.00000002100*np.cos(1.97563817578 + 1688.2335162393*t)
	Y0 += 0.00000002309*np.cos(0.94245885300 + 225.8292684102*t)
	Y0 += 0.00000002323*np.cos(1.91722183373 + 145.6310438715*t)
	Y0 += 0.00000002548*np.cos(0.72953715709 + 1128.534454464*t)
	Y0 += 0.00000002054*np.cos(2.72579048544 + 417.0369633204*t)
	Y0 += 0.00000002551*np.cos(1.03971611498 + 232.0490435337*t)
	Y0 += 0.00000001870*np.cos(6.04196842136 + 501.2367770914*t)
	Y0 += 0.00000001894*np.cos(2.66113148974 + 3480.3105662226*t)
	Y0 += 0.00000001851*np.cos(4.86018399563 + 111.1695290659*t)
	Y0 += 0.00000002198*np.cos(2.51049365003 + 429.0458714308*t)
	Y0 += 0.00000001873*np.cos(0.59052322460 + 1208.9451273238*t)
	Y0 += 0.00000002510*np.cos(1.99459673774 + 601.7642506762*t)
	Y0 += 0.00000002186*np.cos(3.48580556450 + 1553.6481726317*t)
	Y0 += 0.00000002291*np.cos(1.45172941088 + 488.63716815*t)
	Y0 += 0.00000001875*np.cos(3.39330212644 + 1590.0361031303*t)
	Y0 += 0.00000001806*np.cos(5.04361493519 + 913.7508863177*t)
	Y0 += 0.00000001962*np.cos(1.12671675097 + 109.2431133729*t)
	Y0 += 0.00000002129*np.cos(5.01243773449 + 821.703812363*t)
	Y0 += 0.00000002196*np.cos(4.38946985073 + 298.2326223919*t)
	Y0 += 0.00000001953*np.cos(5.49728281015 + 1415.130675761*t)
	Y0 += 0.00000001787*np.cos(3.66506787987 + 1059.6425626201*t)
	Y0 += 0.00000002375*np.cos(0.70058711647 + 2122.6960136415*t)
	Y0 += 0.00000002173*np.cos(5.25212332069 + 1065.5322693435*t)
	Y0 += 0.00000001733*np.cos(0.73534814865 + 162.8965192589*t)
	Y0 += 0.00000002273*np.cos(2.84142693944 + 1589.024711174*t)
	Y0 += 0.00000001780*np.cos(4.29158703684 + 1051.3051753419*t)
	Y0 += 0.00000001716*np.cos(2.65555145996 + 503.8274699981*t)
	Y0 += 0.00000001697*np.cos(5.66098967410 + 1052.3165672982*t)
	Y0 += 0.00000001805*np.cos(1.44303434972 + 110.2545053292*t)
	Y0 += 0.00000002101*np.cos(5.11361919665 + 241.6102710893*t)
	Y0 += 0.00000001961*np.cos(4.77832385099 + 1446.62324515*t)
	Y0 += 0.00000002097*np.cos(6.06067607224 + 570.7447620392*t)
	Y0 += 0.00000001983*np.cos(1.63014729241 + 1432.3961511484*t)
	Y0 += 0.00000001608*np.cos(4.82672654056 + 555.5544601911*t)
	Y0 += 0.00000001681*np.cos(3.48535837754 + 543.1843459133*t)
	Y0 += 0.00000001681*np.cos(3.99691992442 + 516.1975842759*t)
	Y0 += 0.00000001997*np.cos(2.52502983932 + 362.8622925726*t)
	Y0 += 0.00000001620*np.cos(2.47519616201 + 683.1863154923*t)
	Y0 += 0.00000001551*np.cos(0.77205866411 + 593.426863398*t)
	Y0 += 0.00000001616*np.cos(0.78868466538 + 222.8603229936*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000002066*np.cos(0.94018645457 + 487.1526954417*t)
	Y0 += 0.00000001791*np.cos(4.81649259864 + 502.6036297207*t)
	Y0 += 0.00000001537*np.cos(0.19658665242 + 1518.2234499796*t)
	Y0 += 0.00000001786*np.cos(5.44001948650 + 1226.2106027112*t)
	Y0 += 0.00000001926*np.cos(3.25933684213 + 229.0800981171*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001531*np.cos(6.10401203198 + 56.6223513026*t)
	Y0 += 0.00000001778*np.cos(1.08217421224 + 1819.6374661092*t)
	Y0 += 0.00000001466*np.cos(3.39789528449 + 426.5500067662*t)
	Y0 += 0.00000001484*np.cos(2.41545761529 + 995.6460318858*t)
	Y0 += 0.00000001446*np.cos(5.86004559959 + 384.0599212231*t)
	Y0 += 0.00000001673*np.cos(2.66578535790 + 556.7783004685*t)
	Y0 += 0.00000001573*np.cos(6.26225606544 + 425.6349830295*t)
	Y0 += 0.00000001701*np.cos(4.91404545818 + 422.405405182*t)
	Y0 += 0.00000001449*np.cos(1.53424605627 + 3686.4961146598*t)
	Y0 += 0.00000001674*np.cos(0.76441019022 + 3583.4033404412*t)
	Y0 += 0.00000001787*np.cos(4.51629855363 + 1059.1212977583*t)
	Y0 += 0.00000001586*np.cos(2.43520096497 + 1052.2201990786*t)
	Y0 += 0.00000001409*np.cos(5.60828366864 + 1474.6737883704*t)
	Y0 += 0.00000001459*np.cos(0.29604013369 + 426.6463749858*t)
	Y0 += 0.00000001859*np.cos(5.87100830303 + 313.2104759189*t)
	Y0 += 0.00000001860*np.cos(5.30369826691 + 1160.027023853*t)
	Y0 += 0.00000001599*np.cos(5.70543219748 + 1588.1096874373*t)
	Y0 += 0.00000001711*np.cos(4.14799014570 + 2200.5159935946*t)
	Y0 += 0.00000001587*np.cos(1.97035308409 + 1268.7488723641*t)
	Y0 += 0.00000001645*np.cos(4.96839068028 + 630.3360587584*t)
	Y0 += 0.00000001796*np.cos(0.70671519409 + 424.1505103212*t)
	Y0 += 0.00000001802*np.cos(0.24899836512 + 572.2292347475*t)
	Y0 += 0.00000001725*np.cos(5.08098401978 + 1696.0978227655*t)
	Y0 += 0.00000001811*np.cos(5.89893866850 + 1340.3490771937*t)
	Y0 += 0.00000001340*np.cos(4.11708835504 + 1058.109905802*t)
	Y0 += 0.00000001497*np.cos(0.46005454389 + 1379.7059531089*t)
	Y0 += 0.00000001346*np.cos(5.55344965198 + 1066.5436612998*t)
	Y0 += 0.00000001313*np.cos(2.87700461514 + 827.9235874865*t)
	Y0 += 0.00000001342*np.cos(6.27866403575 + 1357.6145525811*t)
	Y0 += 0.00000001714*np.cos(1.09477454512 + 1164.9223849626*t)
	Y0 += 0.00000001547*np.cos(5.14492139001 + 1097.514965827*t)
	Y0 += 0.00000001293*np.cos(1.41574901573 + 394.3548619616*t)
	Y0 += 0.00000001287*np.cos(0.09882825148 + 1354.4331588434*t)
	Y0 += 0.00000001329*np.cos(0.80851044182 + 1628.429771199*t)
	Y0 += 0.00000001657*np.cos(1.38619161291 + 473.068613792*t)
	Y0 += 0.00000001353*np.cos(2.59318399768 + 2498.8916283384*t)
	Y0 += 0.00000001375*np.cos(2.40968289321 + 1093.322180133*t)
	Y0 += 0.00000001428*np.cos(4.17962469716 + 65.2203710117*t)
	Y0 += 0.00000001302*np.cos(6.01487381920 + 494.4786907636*t)
	Y0 += 0.00000001266*np.cos(4.76726804915 + 1162.5228885176*t)
	Y0 += 0.00000001234*np.cos(0.32615815170 + 436.1594184316*t)
	Y0 += 0.00000001258*np.cos(1.58421626029 + 1162.426520298*t)
	Y0 += 0.00000001419*np.cos(1.54073590528 + 1138.0956820196*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001394*np.cos(5.15649797570 + 958.7368365254*t)
	Y0 += 0.00000001182*np.cos(0.52974408869 + 465.9550667912*t)
	Y0 += 0.00000001464*np.cos(2.33832116265 + 1066.4472930802*t)
	Y0 += 0.00000001194*np.cos(4.20924518474 + 774.0095491696*t)
	Y0 += 0.00000001176*np.cos(4.08167525357 + 632.831923423*t)
	Y0 += 0.00000001173*np.cos(2.04351153153 + 2964.8466951296*t)
	Y0 += 0.00000001259*np.cos(3.56208851883 + 990.2294059144*t)
	Y0 += 0.00000001170*np.cos(3.49511362481 + 3693.6096616606*t)
	Y0 += 0.00000001235*np.cos(6.00673735479 + 1027.1386012748*t)
	Y0 += 0.00000001192*np.cos(1.46740386940 + 564.9032394256*t)
	Y0 += 0.00000001337*np.cos(3.61253361740 + 427.5613987225*t)
	Y0 += 0.00000001581*np.cos(5.13730579856 + 642.3449668688*t)
	Y0 += 0.00000001186*np.cos(3.09979352325 + 2114.8317071153*t)
	Y0 += 0.00000001451*np.cos(6.06457621411 + 586.3133163972*t)
	Y0 += 0.00000001339*np.cos(4.45996853527 + 1161.5114965613*t)
	Y0 += 0.00000001260*np.cos(1.21410714044 + 633.7469471597*t)
	Y0 += 0.00000001309*np.cos(1.91007772946 + 1163.4379122543*t)
	Y0 += 0.00000001126*np.cos(2.67412440930 + 252.6559713532*t)
	Y0 += 0.00000001332*np.cos(6.07060512898 + 981.6313862053*t)
	Y0 += 0.00000001309*np.cos(2.99122359843 + 3473.1970192218*t)
	Y0 += 0.00000001172*np.cos(0.90155530149 + 632.7355552034*t)
	Y0 += 0.00000001120*np.cos(3.02624536332 + 709.0498105888*t)
	Y0 += 0.00000001485*np.cos(6.11611294959 + 210.8514148832*t)
	Y0 += 0.00000001241*np.cos(5.23044091775 + 269.9214467406*t)
	Y0 += 0.00000001340*np.cos(4.06427807846 + 1060.6539545764*t)
	Y0 += 0.00000001212*np.cos(4.10341889288 + 3590.516887442*t)
	Y0 += 0.00000001112*np.cos(3.72336688315 + 1065.9742123282*t)
	Y0 += 0.00000001156*np.cos(1.65378396735 + 102.5715093568*t)
	Y0 += 0.00000001085*np.cos(5.33439876744 + 414.0680179038*t)
	Y0 += 0.00000001089*np.cos(3.60592628762 + 946.727928415*t)
	Y0 += 0.00000001097*np.cos(4.63894761295 + 350.3321196004*t)
	Y0 += 0.00000001132*np.cos(5.22322415543 + 1663.8544938511*t)
	Y0 += 0.00000001068*np.cos(6.04185185868 + 1279.794572628*t)
	Y0 += 0.00000001131*np.cos(3.61191445945 + 1887.3055176757*t)
	Y0 += 0.00000001473*np.cos(4.12139842857 + 1436.5407527326*t)
	Y0 += 0.00000001045*np.cos(4.22116967617 + 1570.9136480191*t)
	Y0 += 0.00000001302*np.cos(2.50289331551 + 636.9765250072*t)
	Y0 += 0.00000001036*np.cos(0.53491669677 + 1798.4398374587*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001036*np.cos(5.26899994767 + 915.235359026*t)
	Y0 += 0.00000001395*np.cos(0.46166683816 + 635.231419868*t)
	Y0 += 0.00000001137*np.cos(3.27433871912 + 447.7958195265*t)
	Y0 += 0.00000001025*np.cos(5.53132458018 + 951.6232895246*t)
	Y0 += 0.00000001348*np.cos(3.81184021575 + 2004.364753465*t)
	Y0 += 0.00000001421*np.cos(0.83890525684 + 152.5321425512*t)
	Y0 += 0.00000001018*np.cos(0.87095306528 + 623.2225117576*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001021*np.cos(2.67952604782 + 2730.2069586892*t)
	Y0 += 0.00000001428*np.cos(4.58431304902 + 244.318584075*t)
	Y0 += 0.00000001234*np.cos(2.88698069188 + 1467.8208738005*t)
	Y0 += 0.00000001040*np.cos(0.83747359097 + 313.9441891018*t)
	Y0 += 0.00000001369*np.cos(2.70606153896 + 4590.910180489*t)
	Y0 += 0.00000001275*np.cos(0.52108766366 + 1363.2436268736*t)
	Y0 += 0.00000001088*np.cos(1.95292844895 + 2310.722314814*t)
	Y0 += 0.00000000998*np.cos(3.30517183292 + 231.4583427027*t)
	Y0 += 0.00000001033*np.cos(1.08663300387 + 1028.3624415522*t)
	Y0 += 0.00000001000*np.cos(0.35908379113 + 924.7965865816*t)
	Y0 += 0.00000001111*np.cos(2.15462122005 + 103.6140390804*t)
	Y0 += 0.00000001358*np.cos(3.05189802975 + 448.6895914038*t)
	Y0 += 0.00000000980*np.cos(1.98911885489 + 961.705781942*t)
	Y0 += 0.00000000967*np.cos(6.06331792493 + 665.0270682276*t)
	Y0 += 0.00000001219*np.cos(4.14432847094 + 614.6244920485*t)
	Y0 += 0.00000001038*np.cos(0.76497233984 + 170.7608257851*t)
	Y0 += 0.00000000955*np.cos(2.14161353973 + 645.3139122854*t)
	Y0 += 0.00000000977*np.cos(0.76357046359 + 84.3428261229*t)
	Y0 += 0.00000000933*np.cos(5.39590871918 + 1578.7779545453*t)
	Y0 += 0.00000001139*np.cos(4.36540036877 + 1052.7896480502*t)
	Y0 += 0.00000001076*np.cos(5.29118995114 + 212.3358875915*t)
	Y0 += 0.00000001071*np.cos(2.73962355675 + 214.2623032845*t)
	Y0 += 0.00000000927*np.cos(2.34037338177 + 3796.7024358792*t)
	Y0 += 0.00000001243*np.cos(3.14898976422 + 670.916774951*t)
	Y0 += 0.00000001067*np.cos(4.16223201017 + 799.6124118352*t)
	Y0 += 0.00000001035*np.cos(1.28671936236 + 2545.3620512544*t)
	Y0 += 0.00000001048*np.cos(0.38010986538 + 1901.5326116773*t)
	Y0 += 0.00000001243*np.cos(1.30343744920 + 184.7272873558*t)
	Y0 += 0.00000000976*np.cos(6.08656223961 + 700.4517908797*t)
	Y0 += 0.00000001099*np.cos(1.23775171296 + 611.5861106627*t)
	Y0 += 0.00000001033*np.cos(3.86973990762 + 631.8205314667*t)
	Y0 += 0.00000000960*np.cos(6.17390028803 + 4863.1979130692*t)
	Y0 += 0.00000000875*np.cos(1.92996402694 + 4127.3213995374*t)
	Y0 += 0.00000001194*np.cos(4.13143181474 + 8521.1198767086*t)
	Y0 += 0.00000000967*np.cos(4.90660225484 + 828.8173593638*t)
	Y0 += 0.00000001165*np.cos(0.11002151063 + 1511.3223512999*t)
	Y0 += 0.00000001168*np.cos(2.24358551711 + 2861.753920911*t)
	Y0 += 0.00000000891*np.cos(2.41639607024 + 213.2509113282*t)
	Y0 += 0.00000000890*np.cos(5.61419511254 + 213.3472795478*t)
	Y0 += 0.00000001147*np.cos(4.05160358756 + 1390.0008938474*t)
	Y0 += 0.00000000873*np.cos(0.21748412885 + 322.0209439491*t)
	Y0 += 0.00000001137*np.cos(5.96450825373 + 950.6600816781*t)
	Y0 += 0.00000001030*np.cos(2.10311707723 + 395.105621487*t)
	Y0 += 0.00000001156*np.cos(5.01608864815 + 696.5196376166*t)
	Y0 += 0.00000001061*np.cos(3.86340607753 + 1014.1353475506*t)
	Y0 += 0.00000001015*np.cos(5.07749588495 + 3487.4241132234*t)
	Y0 += 0.00000000860*np.cos(1.59524432991 + 1152.9134768522*t)
	Y0 += 0.00000001113*np.cos(6.08107598854 + 3384.3313390048*t)
	Y0 += 0.00000001041*np.cos(4.23685547840 + 137.0330241624*t)
	Y0 += 0.00000000939*np.cos(3.33696304667 + 1703.2113697663*t)
	Y0 += 0.00000000872*np.cos(0.46189921104 + 1482.0479678021*t)
	Y0 += 0.00000000832*np.cos(5.91197785635 + 1688.9842757647*t)
	Y0 += 0.00000000983*np.cos(4.50835013554 + 1475.6851803267*t)
	Y0 += 0.00000000851*np.cos(3.96788690898 + 5702.1672008196*t)
	Y0 += 0.00000001105*np.cos(4.68695669950 + 1366.2125722902*t)
	Y0 += 0.00000000877*np.cos(1.00645136806 + 357.4456666012*t)
	Y0 += 0.00000000987*np.cos(2.20254440780 + 7210.9158184942*t)
	Y0 += 0.00000001109*np.cos(5.81960537254 + 347.8844390456*t)
	Y0 += 0.00000000992*np.cos(4.48964897088 + 4120.2078525366*t)
	Y0 += 0.00000000827*np.cos(5.97494310096 + 20956.2620575166*t)
	Y0 += 0.00000000811*np.cos(5.15913580030 + 5282.6825569444*t)
	Y0 += 0.00000000914*np.cos(0.28107178678 + 1031.0707545379*t)
	Y0 += 0.00000000999*np.cos(2.29914905811 + 1505.6932770074*t)
	Y0 += 0.00000001012*np.cos(4.06912229625 + 1681.1199692385*t)
	Y0 += 0.00000001093*np.cos(1.74052459203 + 761.7400086283*t)
	Y0 += 0.00000000812*np.cos(0.69907573293 + 288.0806940053*t)
	Y0 += 0.00000001118*np.cos(1.45389907306 + 892.5532576672*t)
	Y0 += 0.00000000883*np.cos(4.10460162145 + 526.1678467456*t)
	Y0 += 0.00000000883*np.cos(3.37767668051 + 533.2140834436*t)
	Y0 += 0.00000000980*np.cos(4.65213623657 + 25035.6347583858*t)
	Y0 += 0.00000000787*np.cos(2.68667239235 + 1056.6736172035*t)
	Y0 += 0.00000000787*np.cos(4.43959540351 + 432.0148168474*t)
	Y0 += 0.00000000839*np.cos(5.03969297034 + 4686.8894077068*t)
	Y0 += 0.00000000965*np.cos(5.19162112321 + 1519.920371009*t)
	Y0 += 0.00000001017*np.cos(1.65928462260 + 1019.7644218431*t)
	Y0 += 0.00000000929*np.cos(0.76029521873 + 1130.2313754934*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000781*np.cos(4.82412022465 + 2225.7887878601*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000983*np.cos(2.38789107713 + 1670.0742689746*t)
	Y0 += 0.00000000950*np.cos(1.75053669314 + 25021.4076643842*t)
	Y0 += 0.00000000805*np.cos(1.40011575656 + 215.7467759928*t)
	Y0 += 0.00000000933*np.cos(3.86854645253 + 2516.9078632512*t)
	Y0 += 0.00000000809*np.cos(1.93195701192 + 348.635198571*t)
	Y0 += 0.00000000841*np.cos(1.57805339944 + 643.0786800517*t)
	Y0 += 0.00000000981*np.cos(4.48946441703 + 1288.4620283063*t)
	Y0 += 0.00000000782*np.cos(0.66782646307 + 1731.5225454176*t)
	Y0 += 0.00000000817*np.cos(1.92690312543 + 1372.5924061081*t)
	Y0 += 0.00000001032*np.cos(3.19968565901 + 3075.053016349*t)
	Y0 += 0.00000000793*np.cos(0.03897871144 + 5092.1519581158*t)
	Y0 += 0.00000000899*np.cos(5.79764466292 + 1053.1621550657*t)
	Y0 += 0.00000000742*np.cos(0.43265335833 + 896.4854109303*t)
	Y0 += 0.00000000989*np.cos(2.27910418594 + 566.3395280241*t)
	Y0 += 0.00000000989*np.cos(5.20317411602 + 493.0424021651*t)
	Y0 += 0.00000000839*np.cos(6.03327141522 + 3700.7232086614*t)
	Y0 += 0.00000000742*np.cos(2.64617353154 + 948.2124011233*t)
	Y0 += 0.00000000756*np.cos(0.57260333982 + 172.2452984934*t)
	Y0 += 0.00000000734*np.cos(3.78800004602 + 112.9146342051*t)
	Y0 += 0.00000000766*np.cos(3.02399211768 + 402.2191684878*t)
	Y0 += 0.00000000746*np.cos(0.30715456859 + 745.4377410874*t)
	Y0 += 0.00000000870*np.cos(0.72037948511 + 537.3257769572*t)
	Y0 += 0.00000000870*np.cos(3.62030616326 + 522.056153232*t)
	Y0 += 0.00000000789*np.cos(0.10006236928 + 950.1388168163*t)
	Y0 += 0.00000000732*np.cos(3.85872500330 + 1600.1185955477*t)
	Y0 += 0.00000000725*np.cos(1.11399889356 + 208.633228992*t)
	Y0 += 0.00000000769*np.cos(2.20223682113 + 6011.4455234754*t)
	Y0 += 0.00000000985*np.cos(0.24088992371 + 1262.3860848887*t)
	Y0 += 0.00000000773*np.cos(0.18165556770 + 8617.0991039264*t)
	Y0 += 0.00000000924*np.cos(1.93653062696 + 1818.1529934009*t)
	Y0 += 0.00000000842*np.cos(0.86970638651 + 98.8999885246*t)
	Y0 += 0.00000000735*np.cos(0.33474292280 + 64.9597385808*t)
	Y0 += 0.00000000780*np.cos(6.07428087424 + 949.12742486*t)
	Y0 += 0.00000000736*np.cos(4.07491885224 + 23969.1392811958*t)
	Y0 += 0.00000000865*np.cos(0.10126946188 + 3899.7952100978*t)
	Y0 += 0.00000000707*np.cos(0.60198922161 + 292.0128472684*t)
	Y0 += 0.00000000705*np.cos(2.70032710795 + 259.769518354*t)
	Y0 += 0.00000000712*np.cos(4.70959378269 + 2108.4689196399*t)
	Y0 += 0.00000000739*np.cos(1.72911998093 + 207.6700211455*t)
	Y0 += 0.00000000885*np.cos(2.41352310917 + 77.962992305*t)
	Y0 += 0.00000000901*np.cos(1.24670020211 + 3259.1471642584*t)
	Y0 += 0.00000000712*np.cos(1.23230262093 + 4002.8879843164*t)
	Y0 += 0.00000000705*np.cos(4.55290977470 + 657.1627617014*t)
	Y0 += 0.00000000964*np.cos(2.76604156225 + 6915.8595893046*t)
	Y0 += 0.00000000968*np.cos(5.51964420540 + 806.725958836*t)
	Y0 += 0.00000000889*np.cos(4.95719313311 + 157.2674449664*t)
	Y0 += 0.00000000810*np.cos(1.91237826709 + 677.7696895209*t)
	Y0 += 0.00000000912*np.cos(1.19262236749 + 1791.3262904579*t)
	Y0 += 0.00000000759*np.cos(5.69883291812 + 1542.6024723678*t)
	Y0 += 0.00000000685*np.cos(5.20938711928 + 2218.6752408593*t)
	Y0 += 0.00000000748*np.cos(2.39982571743 + 1997.5118388951*t)
	Y0 += 0.00000000760*np.cos(5.50181256657 + 297.6419215609*t)
	Y0 += 0.00000000804*np.cos(2.91740270997 + 1141.1340634054*t)
	Y0 += 0.00000000856*np.cos(2.44397416548 + 369.0820676961*t)
	Y0 += 0.00000000815*np.cos(0.85095606739 + 358.9301393095*t)
	Y0 += 0.00000000923*np.cos(4.75881563433 + 179.3588454942*t)
	Y0 += 0.00000000925*np.cos(1.39948133634 + 160.6088973985*t)
	Y0 += 0.00000000704*np.cos(5.19559600972 + 718.6110381444*t)
	Y0 += 0.00000000765*np.cos(0.82175084218 + 1834.6153196362*t)
	Y0 += 0.00000000690*np.cos(2.49015304866 + 153.4953503977*t)
	Y0 += 0.00000000743*np.cos(6.05727858122 + 306.0969289181*t)
	Y0 += 0.00000000774*np.cos(3.70232316078 + 2431.9743362973*t)
	Y0 += 0.00000000798*np.cos(3.06786502961 + 377.1588225434*t)
	Y0 += 0.00000000639*np.cos(4.79352132340 + 650.9429865779*t)
	Y0 += 0.00000000644*np.cos(2.20059124309 + 1304.9243545416*t)
	Y0 += 0.00000000844*np.cos(4.36094366237 + 388.4651552382*t)
	Y0 += 0.00000000851*np.cos(3.84069109470 + 2124.9836355019*t)
	Y0 += 0.00000000666*np.cos(1.47762519480 + 2439.0878832981*t)
	Y0 += 0.00000000642*np.cos(1.77466267233 + 4113.0943055358*t)
	Y0 += 0.00000000886*np.cos(4.54581008875 + 110.1581371096*t)
	Y0 += 0.00000000699*np.cos(2.04086900264 + 999.5781851489*t)
	Y0 += 0.00000000848*np.cos(3.15427263274 + 444.7574381407*t)
	Y0 += 0.00000000772*np.cos(0.19013329644 + 3333.9287628257*t)
	Y0 += 0.00000000781*np.cos(2.37931191817 + 2416.9964827703*t)
	Y0 += 0.00000000629*np.cos(1.93229139868 + 181.806526049*t)
	Y0 += 0.00000000820*np.cos(2.58299952484 + 1371.8416465827*t)
	Y0 += 0.00000000634*np.cos(1.62415516807 + 5908.3527492568*t)
	Y0 += 0.00000000639*np.cos(2.75957878564 + 100.1720129118*t)
	Y0 += 0.00000000757*np.cos(0.21224243565 + 703.6331846174*t)
	Y0 += 0.00000000869*np.cos(4.19129690244 + 10846.0692855242*t)
	Y0 += 0.00000000765*np.cos(5.21743833145 + 927.8349679674*t)
	Y0 += 0.00000000650*np.cos(1.16668662255 + 558.1451530978*t)
	Y0 += 0.00000000776*np.cos(1.74660591915 + 711.4974911436*t)
	Y0 += 0.00000000621*np.cos(3.48991816372 + 4539.6924964118*t)
	Y0 += 0.00000000611*np.cos(1.65684132714 + 4443.713269194*t)
	Y0 += 0.00000000751*np.cos(1.10211044043 + 446.3113468182*t)
	Y0 += 0.00000000726*np.cos(0.52382471288 + 2151.0071892928*t)
	Y0 += 0.00000000753*np.cos(2.45390180994 + 88.1149206916*t)
	Y0 += 0.00000000614*np.cos(2.12029152108 + 6121.6518446948*t)
	Y0 += 0.00000000655*np.cos(4.65792094500 + 1809.4855377226*t)
	Y0 += 0.00000000614*np.cos(2.31607307821 + 1144.3154571431*t)
	Y0 += 0.00000000617*np.cos(3.16668523070 + 4856.0843660684*t)
	Y0 += 0.00000000596*np.cos(1.00488460547 + 737.3609862401*t)
	Y0 += 0.00000000619*np.cos(2.80074763053 + 325.9530972122*t)
	Y0 += 0.00000000715*np.cos(5.80133940123 + 385.5443939314*t)
	Y0 += 0.00000000655*np.cos(3.93113809892 + 218.7157214094*t)
	Y0 += 0.00000000617*np.cos(2.17399797113 + 920.8644333185*t)
	Y0 += 0.00000000590*np.cos(1.05345868825 + 3634.6210245184*t)
	Y0 += 0.00000000590*np.cos(2.98689226579 + 627.3671133418*t)
	Y0 += 0.00000000611*np.cos(0.43380344797 + 392.6579409322*t)
	Y0 += 0.00000000611*np.cos(0.76528954681 + 666.723989257*t)
	Y0 += 0.00000000630*np.cos(2.45241625357 + 1751.539531416*t)
	Y0 += 0.00000000716*np.cos(1.61483523862 + 3333.498879699*t)
	Y0 += 0.00000000715*np.cos(4.50654502617 + 3347.7259737006*t)
	Y0 += 0.00000000604*np.cos(5.25312756839 + 427.1194557378*t)
	Y0 += 0.00000000578*np.cos(5.39625376106 + 881.5075574033*t)
	Y0 += 0.00000000602*np.cos(5.73928138925 + 1670.82502850*t)
	Y0 += 0.00000000571*np.cos(1.69274759242 + 1937.7080938548*t)
	Y0 += 0.00000000581*np.cos(3.86128267375 + 2953.8009948657*t)
	Y0 += 0.00000000754*np.cos(2.66282639252 + 1022.7333672597*t)
	Y0 += 0.00000000736*np.cos(0.59694347292 + 601.5036182453*t)
	Y0 += 0.00000000736*np.cos(0.60214952186 + 457.8783119439*t)
	Y0 += 0.00000000693*np.cos(3.40651887511 + 1967.7161905355*t)
	Y0 += 0.00000000692*np.cos(2.79510805820 + 3789.5888888784*t)
	Y0 += 0.00000000561*np.cos(3.91963066988 + 443.8636662634*t)
	Y0 += 0.00000000708*np.cos(3.02690614133 + 3391.4448860056*t)
	Y0 += 0.00000000778*np.cos(3.25499863195 + 90.5626012464*t)
	Y0 += 0.00000000633*np.cos(1.58661078881 + 12.5301729722*t)
	Y0 += 0.00000000554*np.cos(2.66966231964 + 385.7568422525*t)
	Y0 += 0.00000000551*np.cos(5.94541582437 + 4333.5069479746*t)
	Y0 += 0.00000000605*np.cos(4.46112893899 + 835.7878940127*t)
	Y0 += 0.00000000711*np.cos(1.10969378034 + 451.7279727896*t)
	Y0 += 0.00000000560*np.cos(3.13972333555 + 420.9691165835*t)
	Y0 += 0.00000000579*np.cos(5.96205182739 + 5179.5897827258*t)
	Y0 += 0.00000000561*np.cos(0.89037751064 + 6702.5604938666*t)
	Y0 += 0.00000000560*np.cos(2.10160839294 + 4701.1165017084*t)
	Y0 += 0.00000000556*np.cos(4.53953488781 + 4804.209275927*t)
	Y0 += 0.00000000575*np.cos(6.12046354156 + 1656.7409468503*t)
	Y0 += 0.00000000559*np.cos(3.70916861075 + 388.7257876691*t)
	Y0 += 0.00000000538*np.cos(2.49910108716 + 7564.830720738*t)
	Y0 += 0.00000000727*np.cos(5.70737971510 + 344.7030453079*t)
	Y0 += 0.00000000549*np.cos(2.31469925514 + 10632.7701900862*t)
	Y0 += 0.00000000657*np.cos(0.62702555570 + 464.7312265138*t)
	Y0 += 0.00000000615*np.cos(2.00048473575 + 3494.5376602242*t)
	Y0 += 0.00000000601*np.cos(4.73254533330 + 426.0769260142*t)
	Y0 += 0.00000000525*np.cos(4.24507155073 + 76674.63652943878*t)
	Y0 += 0.00000000527*np.cos(5.96328911375 + 8734.4189721466*t)
	Y0 += 0.00000000516*np.cos(4.97616716669 + 5599.074426601*t)
	Y0 += 0.00000000507*np.cos(3.50263074303 + 615.5182639258*t)
	Y0 += 0.00000000672*np.cos(1.51129840313 + 221.3758502853*t)
	Y0 += 0.00000000700*np.cos(5.07945263007 + 3184.3655656911*t)
	Y0 += 0.00000000599*np.cos(2.57804574588 + 184.9879197867*t)
	Y0 += 0.00000000636*np.cos(6.02243533622 + 10110.1927719924*t)
	Y0 += 0.00000000516*np.cos(3.70540463468 + 6018.5590704762*t)
	Y0 += 0.00000000523*np.cos(3.92581999922 + 3906.9087570986*t)
	Y0 += 0.00000000613*np.cos(0.15989670053 + 607.6539573996*t)
	Y0 += 0.00000000583*np.cos(3.35000745890 + 4326.3934009738*t)
	Y0 += 0.00000000521*np.cos(3.87424282467 + 127.4717966068*t)
	Y0 += 0.00000000598*np.cos(0.51769443783 + 115.6229471908*t)
	Y0 += 0.00000000593*np.cos(0.62671244929 + 758.7710632117*t)
	Y0 += 0.00000000602*np.cos(5.52925928036 + 680.7386349375*t)
	Y0 += 0.00000000641*np.cos(5.93127310899 + 421.93232443*t)
	Y0 += 0.00000000496*np.cos(5.50699449790 + 2328.8815620787*t)
	Y0 += 0.00000000674*np.cos(5.14730526260 + 282.4516197128*t)
	Y0 += 0.00000000494*np.cos(4.88930673362 + 536.05375257*t)
	Y0 += 0.00000000494*np.cos(5.73456422193 + 523.3281776192*t)
	Y0 += 0.00000000503*np.cos(0.66237185260 + 1443.4418514123*t)
	Y0 += 0.00000000592*np.cos(0.48058901083 + 106.0135355254*t)
	Y0 += 0.00000000490*np.cos(1.40385202337 + 71.6002048296*t)
	Y0 += 0.00000000606*np.cos(4.74080637045 + 3803.81598288*t)
	Y0 += 0.00000000625*np.cos(1.34524913881 + 119.767548775*t)
	Y0 += 0.00000000657*np.cos(0.40021926878 + 2350.8129039121*t)
	Y0 += 0.00000000527*np.cos(4.42652413951 + 4436.5997221932*t)
	Y0 += 0.00000000662*np.cos(3.06514170953 + 4959.177140287*t)
	Y0 += 0.00000000488*np.cos(3.30536438368 + 419.532827985*t)
	Y0 += 0.00000000636*np.cos(5.51768568959 + 664.2763087022*t)
	Y0 += 0.00000000495*np.cos(1.58075964209 + 398.2870152247*t)
	Y0 += 0.00000000628*np.cos(4.75127425715 + 1560.6187072806*t)
	Y0 += 0.00000000500*np.cos(3.44000835802 + 8631.326197928*t)
	Y0 += 0.00000000474*np.cos(0.04770076651 + 102.3420146932*t)
	Y0 += 0.00000000589*np.cos(0.26867746379 + 2740.5018994277*t)
	Y0 += 0.00000000600*np.cos(0.00176767996 + 634.2682120215*t)
	Y0 += 0.00000000474*np.cos(3.61718578829 + 2203.6973873323*t)
	Y0 += 0.00000000511*np.cos(1.78212255450 + 207.1487562837*t)
	Y0 += 0.00000000648*np.cos(6.03788509546 + 22.0914005278*t)
	Y0 += 0.00000000515*np.cos(4.56583984880 + 1090.8744995782*t)
	Y0 += 0.00000000549*np.cos(0.85225402277 + 701.936263588*t)
	Y0 += 0.00000000468*np.cos(1.82146214833 + 477.0007670551*t)
	Y0 += 0.00000000468*np.cos(5.66081615363 + 582.3811631341*t)
	Y0 += 0.00000000496*np.cos(3.01514968503 + 2758.6611466924*t)
	Y0 += 0.00000000543*np.cos(6.27930493432 + 578.449009871*t)
	Y0 += 0.00000000543*np.cos(1.20297336764 + 480.9329203182*t)
	Y0 += 0.00000000505*np.cos(0.44577011956 + 398.1440028728*t)
	Y0 += 0.00000000480*np.cos(2.53110795595 + 3046.5988283458*t)
	Y0 += 0.00000000573*np.cos(6.09163052699 + 1132.6790560482*t)
	Y0 += 0.00000000468*np.cos(0.18128030054 + 419.4364597654*t)
	Y0 += 0.00000000480*np.cos(2.95348186297 + 2132.99095438*t)
	Y0 += 0.00000000472*np.cos(3.76379829341 + 103.843533744*t)
	Y0 += 0.00000000467*np.cos(0.49089030603 + 2047.9144150742*t)
	Y0 += 0.00000000463*np.cos(4.21399976185 + 429.5189521828*t)
	Y0 += 0.00000000537*np.cos(1.08146351182 + 425.1137181677*t)
	Y0 += 0.00000000472*np.cos(1.62568669915 + 2527.2028039897*t)
	Y0 += 0.00000000451*np.cos(3.62252628618 + 1457.525933062*t)
	Y0 += 0.00000000451*np.cos(2.46062696619 + 10977.078804699*t)
	Y0 += 0.00000000534*np.cos(2.70956518248 + 843.6351541964*t)
	Y0 += 0.00000000471*np.cos(2.88669732848 + 2572.1887541974*t)
	Y0 += 0.00000000558*np.cos(0.57206557222 + 594.6507036754*t)
	Y0 += 0.00000000588*np.cos(0.10679818786 + 458.090760265*t)
	Y0 += 0.00000000464*np.cos(5.97996999324 + 4017.115078318*t)
	Y0 += 0.00000000482*np.cos(2.66182113624 + 6114.538297694*t)
	Y0 += 0.00000000449*np.cos(6.27506282835 + 1221.8485663214*t)
	Y0 += 0.00000000447*np.cos(3.83471115676 + 475.3562356524*t)
	Y0 += 0.00000000447*np.cos(3.64756714520 + 584.0256945368*t)
	Y0 += 0.00000000574*np.cos(4.09850700417 + 87.3117715395*t)
	Y0 += 0.00000000466*np.cos(2.22914602566 + 632.2624744514*t)
	Y0 += 0.00000000624*np.cos(1.32803409508 + 10529.6774158676*t)
	Y0 += 0.00000000487*np.cos(0.70358405204 + 321.0577361026*t)
	Y0 += 0.00000000442*np.cos(6.00134152023 + 109.6850563576*t)
	Y0 += 0.00000000543*np.cos(0.48848038573 + 3914.0223040994*t)
	Y0 += 0.00000000558*np.cos(6.11657983138 + 2199.7652340692*t)
	Y0 += 0.00000000522*np.cos(1.28108103701 + 383.0967133766*t)
	Y0 += 0.00000000442*np.cos(4.84282576196 + 2936.3925071264*t)
	Y0 += 0.00000000524*np.cos(0.03009305276 + 1336.4169239306*t)
	Y0 += 0.00000000450*np.cos(1.45745967104 + 540.9972977894*t)
	Y0 += 0.00000000450*np.cos(2.88322597733 + 518.3846323998*t)
	Y0 += 0.00000000466*np.cos(4.77540191622 + 733.428832977*t)
	Y0 += 0.00000000541*np.cos(1.50869067477 + 72.3339180125*t)
	Y0 += 0.00000000510*np.cos(2.46251099391 + 340.7708920448*t)
	Y0 += 0.00000000465*np.cos(2.19694664935 + 1083.7609525774*t)
	Y0 += 0.00000000605*np.cos(6.19042796666 + 6599.467719648*t)
	Y0 += 0.00000000602*np.cos(0.32017022594 + 354.5249052944*t)
	Y0 += 0.00000000602*np.cos(0.87892276884 + 704.8570248948*t)
	Y0 += 0.00000000437*np.cos(4.92559532055 + 2535.0671105159*t)
	Y0 += 0.00000000468*np.cos(3.76982493207 + 212.7778305762*t)
	Y0 += 0.00000000579*np.cos(0.71604969737 + 597.5714649822*t)
	Y0 += 0.00000000579*np.cos(0.48304329741 + 461.810465207*t)
	Y0 += 0.00000000523*np.cos(3.66903787035 + 2424.1100297711*t)
	Y0 += 0.00000000480*np.cos(3.58335890884 + 1105.8523531052*t)
	Y0 += 0.00000000466*np.cos(4.26202338577 + 213.8203602998*t)
	Y0 += 0.00000000580*np.cos(2.47100192063 + 2100.6046131137*t)
	Y0 += 0.00000000561*np.cos(5.19306998860 + 1858.9943420244*t)
	Y0 += 0.00000000536*np.cos(0.19003665600 + 131.4039498699*t)
	Y0 += 0.00000000442*np.cos(5.80146904507 + 1068.9431577448*t)
	Y0 += 0.00000000419*np.cos(3.18915415915 + 2090.3096723752*t)
	Y0 += 0.00000000432*np.cos(4.43898680981 + 2080.6308247406*t)
	Y0 += 0.00000000415*np.cos(1.39174996628 + 4760.1051388506*t)
	Y0 += 0.00000000451*np.cos(1.43760446178 + 206.1373643274*t)
	Y0 += 0.00000000531*np.cos(3.40017373163 + 300.6108669775*t)
	Y0 += 0.00000000556*np.cos(3.25263620772 + 1595.2926704073*t)
	Y0 += 0.00000000558*np.cos(5.74254657754 + 2347.8439584955*t)
	Y0 += 0.00000000410*np.cos(0.56301185652 + 7.8643065262*t)
	Y0 += 0.00000000493*np.cos(5.04782378272 + 2879.0193962984*t)
	Y0 += 0.00000000551*np.cos(0.72617989359 + 8837.5117463652*t)
	Y0 += 0.00000000432*np.cos(6.00835189765 + 1300.9922012785*t)
	Y0 += 0.00000000429*np.cos(1.26761639656 + 4635.6717236296*t)
	Y0 += 0.00000000545*np.cos(2.06900453375 + 2004.6253858959*t)
	Y0 += 0.00000000463*np.cos(2.74972811778 + 633.305004175*t)
	Y0 += 0.00000000476*np.cos(3.53215098970 + 2833.2997329078*t)
	Y0 += 0.00000000412*np.cos(4.49217479834 + 2542.1806575167*t)
	Y0 += 0.00000000469*np.cos(5.20635692603 + 2274.5468326365*t)
	Y0 += 0.00000000465*np.cos(3.62306788790 + 4010.0015313172*t)
	Y0 += 0.00000000399*np.cos(1.89120860742 + 1621.3162241982*t)
	Y0 += 0.00000000421*np.cos(4.17496784439 + 638.4128136057*t)
	Y0 += 0.00000000483*np.cos(0.89846608938 + 154.2984995498*t)
	Y0 += 0.00000000394*np.cos(4.47940534021 + 2424.8607892965*t)
	Y0 += 0.00000000412*np.cos(2.38738335229 + 83.3796182764*t)
	Y0 += 0.00000000384*np.cos(4.81260634232 + 673.6250879367*t)
	Y0 += 0.00000000480*np.cos(4.83228035316 + 9050.8108418032*t)
	Y0 += 0.00000000400*np.cos(1.20409319679 + 2755.4797529547*t)
	Y0 += 0.00000000499*np.cos(5.48470112681 + 1973.1328165069*t)
	Y0 += 0.00000000391*np.cos(3.77310038627 + 670.6561425201*t)
	Y0 += 0.00000000396*np.cos(1.19425682508 + 50586.73338786459*t)
	Y0 += 0.00000000468*np.cos(4.28224331796 + 1970.6851359521*t)
	Y0 += 0.00000000404*np.cos(1.95147636572 + 6327.837393132*t)
	Y0 += 0.00000000470*np.cos(6.23427028473 + 878.3261636656*t)
	Y0 += 0.00000000393*np.cos(3.49501113951 + 203.7378678824*t)
	Y0 += 0.00000000472*np.cos(0.93318411225 + 416.7763308895*t)
	Y0 += 0.00000000443*np.cos(5.22068474603 + 1987.2168981566*t)
	Y0 += 0.00000000491*np.cos(1.09229246916 + 601.2911699242*t)
	Y0 += 0.00000000503*np.cos(1.62796162151 + 5856.4776591154*t)
	Y0 += 0.00000000511*np.cos(3.34354440535 + 77.2292791221*t)
	Y0 += 0.00000000402*np.cos(1.57660654845 + 177.8743727859*t)
	Y0 += 0.00000000467*np.cos(4.62700522628 + 2654.6746005965*t)
	Y0 += 0.00000000397*np.cos(3.56270803011 + 5371.5482371614*t)
	return Y0




def Jupiter_Y1 (t): # 510 terms of order 1

	Y1 = 0.
	Y1 -= 0.01694792137
	Y1 += 0.00634254247*np.cos(4.81903195356 + 1059.3819301892*t)
	Y1 += 0.00600587150*np.cos(0.85811137383 + 522.5774180938*t)
	Y1 += 0.00588367200*np.cos(0.34491553018 + 536.8045120954*t)
	Y1 += 0.00081289939*np.cos(1.90910271853 + 7.1135470008*t)
	Y1 += 0.00046843519*np.cos(1.91294033052 + 529.6909650946*t)
	Y1 += 0.00046150068*np.cos(5.16955995419 + 1589.0728952838*t)
	Y1 += 0.00032472443*np.cos(0.17640771395 + 1052.2683831884*t)
	Y1 += 0.00031201535*np.cos(0.77624038457 + 1066.49547719*t)
	Y1 += 0.00019475766*np.cos(3.00913152396 + 110.2063212194*t)
	Y1 += 0.00016865586*np.cos(2.45297644533 + 426.598190876*t)
	Y1 += 0.00013690691*np.cos(5.02101628562 + 632.7837393132*t)
	Y1 += 0.00013022204*np.cos(0.98978959368 + 515.463871093*t)
	Y1 += 0.00009113996*np.cos(0.21022418619 + 543.9180590962*t)
	Y1 += 0.00008101295*np.cos(4.58123045927 + 949.1756089698*t)
	Y1 += 0.00007141932*np.cos(1.60339474172 + 323.5054166574*t)
	Y1 += 0.00004284393*np.cos(0.07490444220 + 206.1855484372*t)
	Y1 += 0.00004343053*np.cos(5.85522747181 + 735.8765135318*t)
	Y1 += 0.00003398490*np.cos(1.33033169180 + 526.5095713569*t)
	Y1 += 0.00003328707*np.cos(6.14951855343 + 532.8723588323*t)
	Y1 += 0.00003148193*np.cos(0.98470202558 + 419.4846438752*t)
	Y1 += 0.00003871201*np.cos(1.76872695106 + 14.2270940016*t)
	Y1 += 0.00003041302*np.cos(0.08329755674 + 525.7588118315*t)
	Y1 += 0.00002998620*np.cos(1.11280597644 + 533.6231183577*t)
	Y1 += 0.00002972552*np.cos(3.35303238649 + 103.0927742186*t)
	Y1 += 0.00002325776*np.cos(2.06697271149 + 316.3918696566*t)
	Y1 += 0.00002987340*np.cos(5.51944851941 + 2118.7638603784*t)
	Y1 += 0.00001873488*np.cos(5.32656155620 + 742.9900605326*t)
	Y1 += 0.00001852299*np.cos(1.19908749676 + 1596.1864422846*t)
	Y1 += 0.00001966492*np.cos(3.51895000316 + 956.2891559706*t)
	Y1 += 0.00001805775*np.cos(5.40302012288 + 95.9792272178*t)
	Y1 += 0.00001530303*np.cos(2.74905823262 + 117.3198682202*t)
	Y1 += 0.00001727332*np.cos(0.63018404294 + 220.4126424388*t)
	Y1 += 0.00001883583*np.cos(0.29906423084 + 1581.959348283*t)
	Y1 += 0.00001548330*np.cos(6.17417483830 + 639.897286314*t)
	Y1 += 0.00001635354*np.cos(6.09268929177 + 1045.1548361876*t)
	Y1 += 0.00001259066*np.cos(0.07170674498 + 625.6701923124*t)
	Y1 += 0.00001046522*np.cos(0.95429910486 + 433.7117378768*t)
	Y1 += 0.00001034932*np.cos(0.98276277734 + 1265.5674786264*t)
	Y1 += 0.00000982606*np.cos(6.14294792093 + 1169.5882514086*t)
	Y1 += 0.00000777939*np.cos(4.83569613917 + 942.062061969*t)
	Y1 += 0.00000887150*np.cos(1.10233197165 + 309.2783226558*t)
	Y1 += 0.00000841018*np.cos(0.18382096159 + 1155.361157407*t)
	Y1 += 0.00000767275*np.cos(4.84778882823 + 1162.4747044078*t)
	Y1 += 0.00000540475*np.cos(2.67909225965 + 853.196381752*t)
	Y1 += 0.00000495930*np.cos(0.12111154654 + 199.0720014364*t)
	Y1 += 0.00000482262*np.cos(4.31775203037 + 1692.1656695024*t)
	Y1 += 0.00000509414*np.cos(5.76650209909 + 213.299095438*t)
	Y1 += 0.00000474160*np.cos(0.05025970892 + 838.9692877504*t)
	Y1 += 0.00000499345*np.cos(1.44990415973 + 330.6189636582*t)
	Y1 += 0.00000383407*np.cos(0.60155191685 + 1073.6090241908*t)
	Y1 += 0.00000411452*np.cos(5.82460577896 + 728.762966531*t)
	Y1 += 0.00000411517*np.cos(4.63999513620 + 1478.8665740644*t)
	Y1 += 0.00000232877*np.cos(1.13628632393 + 508.3503240922*t)
	Y1 += 0.00000248894*np.cos(0.16937070980 + 1272.6810256272*t)
	Y1 += 0.00000198612*np.cos(1.38938511239 + 1375.7737998458*t)
	Y1 += 0.00000203584*np.cos(1.40731268482 + 3.1813937377*t)
	Y1 += 0.00000214798*np.cos(6.16959891286 + 412.3710968744*t)
	Y1 += 0.00000181515*np.cos(2.07919235187 + 1368.660252845*t)
	Y1 += 0.00000174255*np.cos(0.28157478059 + 1062.5633239269*t)
	Y1 += 0.00000189109*np.cos(5.86994869354 + 2648.454825473*t)
	Y1 += 0.00000167275*np.cos(0.94404549184 + 1258.4539316256*t)
	Y1 += 0.00000155591*np.cos(2.11474224502 + 3.9321532631*t)
	Y1 += 0.00000161231*np.cos(1.44975727685 + 519.3960243561*t)
	Y1 += 0.00000143962*np.cos(0.51310850188 + 1055.4497769261*t)
	Y1 += 0.00000126626*np.cos(1.74460042480 + 1063.3140834523*t)
	Y1 += 0.00000133214*np.cos(0.48874763105 + 227.5261894396*t)
	Y1 += 0.00000124607*np.cos(0.04993608925 + 551.031606097*t)
	Y1 += 0.00000125376*np.cos(6.02560759682 + 539.9859058331*t)
	Y1 += 0.00000146492*np.cos(1.15160820131 + 1056.2005364515*t)
	Y1 += 0.00000115764*np.cos(1.61098162062 + 2125.8774073792*t)
	Y1 += 0.00000117096*np.cos(5.45594228337 + 1471.7530270636*t)
	Y1 += 0.00000142844*np.cos(0.02657965346 + 1574.8458012822*t)
	Y1 += 0.00000143426*np.cos(4.51346599246 + 1485.9801210652*t)
	Y1 += 0.00000097698*np.cos(0.44121291572 + 2111.6503133776*t)
	Y1 += 0.00000093040*np.cos(0.28789276865 + 1699.2792165032*t)
	Y1 += 0.00000084322*np.cos(6.00202886732 + 440.8252848776*t)
	Y1 += 0.00000099934*np.cos(1.09427323363 + 618.5566453116*t)
	Y1 += 0.00000103259*np.cos(1.14894217998 + 302.164775655*t)
	Y1 += 0.00000102262*np.cos(1.62702424606 + 21.3406410024*t)
	Y1 += 0.00000078185*np.cos(3.52291643865 + 525.0250986486*t)
	Y1 += 0.00000076163*np.cos(6.24219322456 + 647.0108333148*t)
	Y1 += 0.00000074807*np.cos(3.95787987540 + 534.3568315406*t)
	Y1 += 0.00000087844*np.cos(0.18833403824 + 831.8557407496*t)
	Y1 += 0.00000061943*np.cos(4.67305937908 + 2221.856634597*t)
	Y1 += 0.00000053422*np.cos(4.15773861872 + 2008.557539159*t)
	Y1 += 0.00000066890*np.cos(0.70927232633 + 1685.0521225016*t)
	Y1 += 0.00000052789*np.cos(6.10373692289 + 1038.0412891868*t)
	Y1 += 0.00000046409*np.cos(0.92753244625 + 524.2743391232*t)
	Y1 += 0.00000049463*np.cos(1.18264387489 + 963.4027029714*t)
	Y1 += 0.00000045782*np.cos(0.27156053621 + 535.107591066*t)
	Y1 += 0.00000054236*np.cos(0.01818231207 + 750.1036075334*t)
	Y1 += 0.00000056181*np.cos(1.05958309043 + 1795.258443721*t)
	Y1 += 0.00000039365*np.cos(3.24874113885 + 1382.8873468466*t)
	Y1 += 0.00000038663*np.cos(5.95486778331 + 511.5317178299*t)
	Y1 += 0.00000036523*np.cos(1.51420033895 + 547.8502123593*t)
	Y1 += 0.00000035968*np.cos(1.26252623906 + 10.2949407385*t)
	Y1 += 0.00000036868*np.cos(6.25234819034 + 526.7702037878*t)
	Y1 += 0.00000036603*np.cos(1.23015782265 + 532.6117264014*t)
	Y1 += 0.00000030583*np.cos(2.55488946600 + 124.433415221*t)
	Y1 += 0.00000027890*np.cos(0.13975598355 + 1802.3719907218*t)
	Y1 += 0.00000031796*np.cos(4.52920938031 + 76.2660712756*t)
	Y1 += 0.00000030068*np.cos(3.23012337704 + 846.0828347512*t)
	Y1 += 0.00000028063*np.cos(5.95243133202 + 149.5631971346*t)
	Y1 += 0.00000030163*np.cos(1.34324693327 + 1898.3512179396*t)
	Y1 += 0.00000025353*np.cos(0.24938499571 + 540.7366653585*t)
	Y1 += 0.00000022442*np.cos(5.93438363618 + 1148.2476104062*t)
	Y1 += 0.00000026652*np.cos(1.48193861065 + 1905.4647649404*t)
	Y1 += 0.00000022688*np.cos(5.52878572537 + 934.9485149682*t)
	Y1 += 0.00000018196*np.cos(2.37271651784 + 909.8187330546*t)
	Y1 += 0.00000017089*np.cos(0.99046298511 + 1603.2999892854*t)
	Y1 += 0.00000017538*np.cos(4.47072665413 + 525.4981794006*t)
	Y1 += 0.00000017368*np.cos(3.01139900055 + 533.8837507886*t)
	Y1 += 0.00000018148*np.cos(3.41220760474 + 106.2741679563*t)
	Y1 += 0.00000016135*np.cos(5.85989460981 + 99.9113804809*t)
	Y1 += 0.00000019261*np.cos(2.61311520085 + 1361.5467058442*t)
	Y1 += 0.00000016035*np.cos(0.28776467937 + 191.9584544356*t)
	Y1 += 0.00000019603*np.cos(5.81126286038 + 1788.1448967202*t)
	Y1 += 0.00000014673*np.cos(0.17408284113 + 518.6452648307*t)
	Y1 += 0.00000017795*np.cos(2.07321615750 + 88.865680217*t)
	Y1 += 0.00000014747*np.cos(0.47450508591 + 1049.0869894507*t)
	Y1 += 0.00000017293*np.cos(2.89339343720 + 18.1592472647*t)
	Y1 += 0.00000017411*np.cos(1.97394545907 + 860.3099287528*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000011395*np.cos(5.26261384784 + 1464.6394800628*t)
	Y1 += 0.00000011742*np.cos(6.21747545410 + 3178.1457905676*t)
	Y1 += 0.00000014681*np.cos(1.29179190664 + 337.732510659*t)
	Y1 += 0.00000014886*np.cos(4.90997527988 + 107.0249274817*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000011204*np.cos(4.74151565288 + 99.1606209555*t)
	Y1 += 0.00000011669*np.cos(0.86641948321 + 2214.7430875962*t)
	Y1 += 0.00000013929*np.cos(6.17036092151 + 721.6494195302*t)
	Y1 += 0.00000012278*np.cos(5.65264690988 + 2104.5367663768*t)
	Y1 += 0.00000010939*np.cos(0.71222731144 + 1251.3403846248*t)
	Y1 += 0.00000011017*np.cos(3.18646798405 + 604.4725636619*t)
	Y1 += 0.00000011026*np.cos(5.28388535292 + 2015.6710861598*t)
	Y1 += 0.00000008957*np.cos(4.48061869248 + 92.0470739547*t)
	Y1 += 0.00000010164*np.cos(0.62992310390 + 73.297125859*t)
	Y1 += 0.00000010028*np.cos(3.94766857170 + 497.4476361802*t)
	Y1 += 0.00000010134*np.cos(0.68933796308 + 1592.2542890215*t)
	Y1 += 0.00000010812*np.cos(0.05745880472 + 1891.2376709388*t)
	Y1 += 0.00000008987*np.cos(1.18748207226 + 224.3447957019*t)
	Y1 += 0.00000008447*np.cos(0.96776660732 + 1585.1407420207*t)
	Y1 += 0.00000009172*np.cos(3.54380107143 + 561.934294009*t)
	Y1 += 0.00000010215*np.cos(4.40184348382 + 454.9093665273*t)
	Y1 += 0.00000010858*np.cos(2.27877819022 + 113.3877149571*t)
	Y1 += 0.00000008018*np.cos(0.05624075316 + 629.6023455755*t)
	Y1 += 0.00000007531*np.cos(3.92430577039 + 11.0457002639*t)
	Y1 += 0.00000007590*np.cos(3.72659991001 + 39.3568759152*t)
	Y1 += 0.00000007544*np.cos(0.76057765355 + 2228.9701815978*t)
	Y1 += 0.00000007709*np.cos(6.01459194385 + 636.7158925763*t)
	Y1 += 0.00000007357*np.cos(2.07742225960 + 2655.5683724738*t)
	Y1 += 0.00000007231*np.cos(1.08428678941 + 429.7795846137*t)
	Y1 += 0.00000007334*np.cos(3.90865182026 + 530.44172462*t)
	Y1 += 0.00000007334*np.cos(3.57362648170 + 528.9402055692*t)
	Y1 += 0.00000008072*np.cos(1.31940181731 + 1585.8915015461*t)
	Y1 += 0.00000007085*np.cos(5.85909901313 + 1158.5425511447*t)
	Y1 += 0.00000007688*np.cos(0.70634789911 + 2001.4439921582*t)
	Y1 += 0.00000007105*np.cos(3.52235507593 + 1048.3362299253*t)
	Y1 += 0.00000008989*np.cos(4.89939565580 + 114.1384744825*t)
	Y1 += 0.00000007644*np.cos(3.78622130562 + 121.2520214833*t)
	Y1 += 0.00000006822*np.cos(0.88572352734 + 312.4597163935*t)
	Y1 += 0.00000007022*np.cos(4.91750543677 + 953.1077622329*t)
	Y1 += 0.00000006467*np.cos(5.54897627050 + 1165.6560981455*t)
	Y1 += 0.00000006353*np.cos(0.77690107419 + 1159.2933106701*t)
	Y1 += 0.00000006570*np.cos(4.80752283462 + 635.9651330509*t)
	Y1 += 0.00000007531*np.cos(6.26541380179 + 1567.7322542814*t)
	Y1 += 0.00000006510*np.cos(4.52827964645 + 2538.2485042536*t)
	Y1 += 0.00000006279*np.cos(6.20656008315 + 209.3669421749*t)
	Y1 += 0.00000006175*np.cos(2.64912767560 + 983.1158589136*t)
	Y1 += 0.00000005965*np.cos(0.34957712964 + 234.6397364404*t)
	Y1 += 0.00000005841*np.cos(0.50541468252 + 1166.4068576709*t)
	Y1 += 0.00000005767*np.cos(0.02130325225 + 387.2413149608*t)
	Y1 += 0.00000007545*np.cos(1.60239307325 + 405.2575498736*t)
	Y1 += 0.00000005547*np.cos(1.62620023863 + 611.4430983108*t)
	Y1 += 0.00000005671*np.cos(4.94594693828 + 1041.2226829245*t)
	Y1 += 0.00000005516*np.cos(0.37582147283 + 70.8494453042*t)
	Y1 += 0.00000005996*np.cos(1.17778867729 + 319.5732633943*t)
	Y1 += 0.00000005519*np.cos(2.07020506527 + 1593.0050485469*t)
	Y1 += 0.00000005189*np.cos(5.63082164988 + 447.9388318784*t)
	Y1 += 0.00000005286*np.cos(2.89187059401 + 505.3119427064*t)
	Y1 += 0.00000006907*np.cos(6.10591436468 + 305.3461693927*t)
	Y1 += 0.00000005224*np.cos(1.38118993461 + 422.6660376129*t)
	Y1 += 0.00000005836*np.cos(2.54212786208 + 458.8415197904*t)
	Y1 += 0.00000005192*np.cos(2.58979959458 + 423.4167971383*t)
	Y1 += 0.00000005406*np.cos(2.80859538387 + 437.6438911399*t)
	Y1 += 0.00000006380*np.cos(5.07465796092 + 2751.5475996916*t)
	Y1 += 0.00000004972*np.cos(4.59040744235 + 554.0699874828*t)
	Y1 += 0.00000005942*np.cos(1.75506064905 + 512.2824773553*t)
	Y1 += 0.00000004807*np.cos(0.26863943289 + 494.2662424425*t)
	Y1 += 0.00000005306*np.cos(0.11969594807 + 1069.6768709277*t)
	Y1 += 0.00000004645*np.cos(5.07925345397 + 1781.0313497194*t)
	Y1 += 0.00000005477*np.cos(3.44336586906 + 2324.9494088156*t)
	Y1 += 0.00000005203*np.cos(0.30884116137 + 498.6714764576*t)
	Y1 += 0.00000004359*np.cos(1.33181294212 + 672.1406152284*t)
	Y1 += 0.00000004397*np.cos(0.93048360298 + 565.1156877467*t)
	Y1 += 0.00000004611*np.cos(5.66081575236 + 679.2541622292*t)
	Y1 += 0.00000005248*np.cos(5.11443042599 + 945.9942152321*t)
	Y1 += 0.00000004702*np.cos(4.62820043054 + 621.7380390493*t)
	Y1 += 0.00000004812*np.cos(0.89025140400 + 560.7104537316*t)
	Y1 += 0.00000004406*np.cos(2.38746661175 + 81.7521332162*t)
	Y1 += 0.00000004305*np.cos(1.60213165112 + 1070.4276304531*t)
	Y1 += 0.00000004781*np.cos(4.94272065629 + 600.5404103988*t)
	Y1 += 0.00000004126*np.cos(0.17865282295 + 216.4804891757*t)
	Y1 += 0.00000004148*np.cos(0.34385943693 + 1080.7225711916*t)
	Y1 += 0.00000004394*np.cos(5.51741452448 + 628.8515860501*t)
	Y1 += 0.00000004151*np.cos(1.93098926861 + 63.7358983034*t)
	Y1 += 0.00000004092*np.cos(0.27540506225 + 643.8294395771*t)
	Y1 += 0.00000005372*np.cos(5.86592545517 + 2207.6295405954*t)
	Y1 += 0.00000004612*np.cos(3.96539290551 + 32.2433289144*t)
	Y1 += 0.00000003923*np.cos(1.49171539794 + 217.2312487011*t)
	Y1 += 0.00000003845*np.cos(0.02687837620 + 970.5162499722*t)
	Y1 += 0.00000003898*np.cos(4.36796507234 + 1064.0477966352*t)
	Y1 += 0.00000004009*np.cos(3.61406919649 + 952.3570027075*t)
	Y1 += 0.00000005317*np.cos(0.68694460143 + 210.1177017003*t)
	Y1 += 0.00000003880*np.cos(3.72470845935 + 504.561183181*t)
	Y1 += 0.00000004462*np.cos(0.25128459874 + 835.0371344873*t)
	Y1 += 0.00000004619*np.cos(1.72269188587 + 430.5303441391*t)
	Y1 += 0.00000004981*np.cos(1.25438032395 + 295.0512286542*t)
	Y1 += 0.00000004567*np.cos(0.11329133595 + 757.2171545342*t)
	Y1 += 0.00000003965*np.cos(6.05219341010 + 501.3797894433*t)
	Y1 += 0.00000003861*np.cos(0.16362815949 + 746.9222137957*t)
	Y1 += 0.00000003650*np.cos(4.63685741915 + 2420.9286360334*t)
	Y1 += 0.00000003643*np.cos(3.75756954654 + 554.8207470082*t)
	Y1 += 0.00000004160*np.cos(0.45778233334 + 824.7421937488*t)
	Y1 += 0.00000003486*np.cos(0.90717666812 + 2317.8358618148*t)
	Y1 += 0.00000003693*np.cos(1.43008452935 + 558.0021407459*t)
	Y1 += 0.00000003443*np.cos(2.77873462243 + 85.8272988312*t)
	Y1 += 0.00000004073*np.cos(6.15464714899 + 739.8086667949*t)
	Y1 += 0.00000003303*np.cos(1.42720313539 + 501.2367770914*t)
	Y1 += 0.00000003279*np.cos(5.15857465347 + 654.1243803156*t)
	Y1 += 0.00000004224*np.cos(5.65691659614 + 547.0994528339*t)
	Y1 += 0.00000003214*np.cos(4.63994266567 + 498.1983957056*t)
	Y1 += 0.00000003501*np.cos(2.36612663742 + 320.3240229197*t)
	Y1 += 0.00000003703*np.cos(1.63373351464 + 1493.093668066*t)
	Y1 += 0.00000003357*np.cos(2.02753125717 + 6275.9623029906*t)
	Y1 += 0.00000002969*np.cos(2.84233520507 + 561.1835344836*t)
	Y1 += 0.00000003030*np.cos(3.64777234822 + 1912.5783119412*t)
	Y1 += 0.00000003251*np.cos(1.48666767532 + 6290.1893969922*t)
	Y1 += 0.00000003076*np.cos(3.34580219444 + 1677.9385755008*t)
	Y1 += 0.00000002830*np.cos(0.77469965362 + 2641.3412784722*t)
	Y1 += 0.00000003140*np.cos(3.45003804769 + 10206.1719992102*t)
	Y1 += 0.00000003116*np.cos(1.34770723612 + 483.2205421786*t)
	Y1 += 0.00000002968*np.cos(0.95733368724 + 597.3590166611*t)
	Y1 += 0.00000003023*np.cos(3.68951807384 + 938.1299087059*t)
	Y1 += 0.00000003496*np.cos(3.80583016563 + 1054.7160637432*t)
	Y1 += 0.00000002741*np.cos(5.88379306688 + 1151.4290041439*t)
	Y1 += 0.00000003040*np.cos(2.90970123602 + 10220.3990932118*t)
	Y1 += 0.00000002720*np.cos(1.00934911898 + 326.6868103951*t)
	Y1 += 0.00000002672*np.cos(0.39245063721 + 521.8266585684*t)
	Y1 += 0.00000002672*np.cos(0.80664235757 + 537.5552716208*t)
	Y1 += 0.00000002599*np.cos(6.21366855510 + 960.2213092337*t)
	Y1 += 0.00000002658*np.cos(1.14453224197 + 1061.829610744*t)
	Y1 += 0.00000002847*np.cos(1.35110287281 + 1176.7017984094*t)
	Y1 += 0.00000002545*np.cos(4.77646044599 + 1098.7388061044*t)
	Y1 += 0.00000003091*np.cos(0.28283825059 + 2332.0629558164*t)
	Y1 += 0.00000002658*np.cos(5.35693010643 + 1056.9342496344*t)
	Y1 += 0.00000003340*np.cos(0.89694401439 + 2531.1349572528*t)
	Y1 += 0.00000003075*np.cos(6.27508570890 + 462.0229135281*t)
	Y1 += 0.00000002804*np.cos(6.16566371601 + 576.1613880106*t)
	Y1 += 0.00000002994*np.cos(3.65472574100 + 230.5645708254*t)
	Y1 += 0.00000002346*np.cos(3.31946563103 + 945.2434557067*t)
	Y1 += 0.00000002555*np.cos(0.67380935045 + 415.5524906121*t)
	Y1 += 0.00000002339*np.cos(0.00663392327 + 460.5384408198*t)
	Y1 += 0.00000002287*np.cos(4.80075294106 + 2097.423219376*t)
	Y1 += 0.00000002748*np.cos(5.44723105301 + 2524.021410252*t)
	Y1 += 0.00000002330*np.cos(2.61193168127 + 849.2642284889*t)
	Y1 += 0.00000002379*np.cos(6.16267328554 + 202.2533951741*t)
	Y1 += 0.00000003051*np.cos(0.63542797059 + 203.0041546995*t)
	Y1 += 0.00000002256*np.cos(1.40980672956 + 1053.9653042178*t)
	Y1 += 0.00000002189*np.cos(3.11418199665 + 1514.2912967165*t)
	Y1 += 0.00000002373*np.cos(4.07778996079 + 523.4711899711*t)
	Y1 += 0.00000002373*np.cos(3.40448834117 + 535.9107402181*t)
	Y1 += 0.00000002047*np.cos(1.13140977147 + 988.532484885*t)
	Y1 += 0.00000002105*np.cos(1.65182568239 + 1059.3337460794*t)
	Y1 += 0.00000002044*np.cos(3.86812530423 + 138.5174968707*t)
	Y1 += 0.00000002369*np.cos(6.18956428442 + 732.6951197941*t)
	Y1 += 0.00000002015*np.cos(1.84497496112 + 46.470422916*t)
	Y1 += 0.00000002005*np.cos(3.91183410083 + 731.9443602687*t)
	Y1 += 0.00000001997*np.cos(0.01573565092 + 504.4181708291*t)
	Y1 += 0.00000002033*np.cos(0.46619876707 + 1173.5204046717*t)
	Y1 += 0.00000002284*np.cos(1.11740659058 + 528.0464336919*t)
	Y1 += 0.00000002284*np.cos(0.08168640420 + 531.3354964973*t)
	Y1 += 0.00000002226*np.cos(0.29140866606 + 5230.807466803*t)
	Y1 += 0.00000002084*np.cos(3.79496268497 + 490.3340891794*t)
	Y1 += 0.00000002020*np.cos(3.27527557464 + 567.8240007324*t)
	Y1 += 0.00000001939*np.cos(0.63756905811 + 1064.7985561606*t)
	Y1 += 0.00000002346*np.cos(4.61879426619 + 739.0579072695*t)
	Y1 += 0.00000001905*np.cos(1.94076118880 + 1077.5411774539*t)
	Y1 += 0.00000002050*np.cos(5.31232261606 + 195.1398481733*t)
	Y1 += 0.00000001874*np.cos(1.18335705821 + 554.9637593601*t)
	Y1 += 0.00000002388*np.cos(2.65750056379 + 334.5511169213*t)
	Y1 += 0.00000002111*np.cos(0.80586078544 + 5216.5803728014*t)
	Y1 += 0.00000002086*np.cos(1.74158554893 + 1062.302691496*t)
	Y1 += 0.00000002069*np.cos(1.71509396441 + 9161.0171630226*t)
	Y1 += 0.00000001809*np.cos(3.99744410279 + 491.5579294568*t)
	Y1 += 0.00000002002*np.cos(5.91194040806 + 142.4496501338*t)
	Y1 += 0.00000001892*np.cos(3.68925347774 + 569.0478410098*t)
	Y1 += 0.00000001778*np.cos(2.95457611984 + 842.1506814881*t)
	Y1 += 0.00000001773*np.cos(1.30351669897 + 67.6680515665*t)
	Y1 += 0.00000001965*np.cos(2.22838539482 + 9146.790069021*t)
	Y1 += 0.00000001684*np.cos(0.96891211772 + 598.8434893694*t)
	Y1 += 0.00000001666*np.cos(4.51582119325 + 1058.4187223427*t)
	Y1 += 0.00000002105*np.cos(4.84963681002 + 1059.430114299*t)
	Y1 += 0.00000001684*np.cos(4.42252720180 + 2737.32050569*t)
	Y1 += 0.00000001966*np.cos(6.06718677944 + 416.3032501375*t)
	Y1 += 0.00000001570*np.cos(2.80724611689 + 78.7137518304*t)
	Y1 += 0.00000002106*np.cos(6.18783647179 + 1884.124123938*t)
	Y1 += 0.00000001546*np.cos(3.68581978626 + 327.4375699205*t)
	Y1 += 0.00000001508*np.cos(0.57548049059 + 2634.2277314714*t)
	Y1 += 0.00000001493*np.cos(5.35652330214 + 3067.9394693482*t)
	Y1 += 0.00000001554*np.cos(1.65638330653 + 2435.155730035*t)
	Y1 += 0.00000001437*np.cos(0.15153485897 + 1056.4611688824*t)
	Y1 += 0.00000001666*np.cos(1.98564123475 + 1060.3451380357*t)
	Y1 += 0.00000001454*np.cos(4.40160499250 + 2854.6403739102*t)
	Y1 += 0.00000001879*np.cos(1.70024089685 + 528.2064923863*t)
	Y1 += 0.00000001879*np.cos(5.78203740511 + 531.1754378029*t)
	Y1 += 0.00000001693*np.cos(4.87451214007 + 724.8308132679*t)
	Y1 += 0.00000001827*np.cos(1.10955453764 + 1364.7280995819*t)
	Y1 += 0.00000001343*np.cos(1.93869519971 + 916.9322800554*t)
	Y1 += 0.00000001498*np.cos(3.83212858272 + 1134.1635287565*t)
	Y1 += 0.00000001410*np.cos(4.97054926442 + 1091.6252591036*t)
	Y1 += 0.00000001706*np.cos(3.77129732727 + 1279.794572628*t)
	Y1 += 0.00000001520*np.cos(5.37754317175 + 977.4867846211*t)
	Y1 += 0.00000001408*np.cos(1.45754211476 + 1269.4996318895*t)
	Y1 += 0.00000001508*np.cos(3.34515937416 + 299.1263942692*t)
	Y1 += 0.00000001343*np.cos(1.92467316978 + 1354.4331588434*t)
	Y1 += 0.00000001518*np.cos(1.61233888307 + 1439.5096981492*t)
	Y1 += 0.00000001268*np.cos(5.59676667960 + 1474.9344208013*t)
	Y1 += 0.00000001308*np.cos(5.87704730505 + 558.1451530978*t)
	Y1 += 0.00000001365*np.cos(3.14974903366 + 1446.62324515*t)
	Y1 += 0.00000001435*np.cos(4.97958755613 + 991.7138786227*t)
	Y1 += 0.00000001235*np.cos(0.66052761201 + 1475.6851803267*t)
	Y1 += 0.00000001286*np.cos(1.84450047380 + 380.12776796*t)
	Y1 += 0.00000001339*np.cos(0.92704363552 + 2847.5268269094*t)
	Y1 += 0.00000001144*np.cos(5.29136746300 + 1482.0479678021*t)
	Y1 += 0.00000001323*np.cos(5.16544573102 + 284.1485407422*t)
	Y1 += 0.00000001560*np.cos(2.59829890086 + 100.6450936638*t)
	Y1 += 0.00000001145*np.cos(4.47807440609 + 408.4389436113*t)
	Y1 += 0.00000001132*np.cos(3.62425240134 + 1063.5747158832*t)
	Y1 += 0.00000001220*np.cos(2.47481989397 + 373.0142209592*t)
	Y1 += 0.00000001079*np.cos(0.26102705757 + 1482.7987273275*t)
	Y1 += 0.00000001252*np.cos(5.77248253921 + 473.068613792*t)
	Y1 += 0.00000001242*np.cos(1.39155353408 + 520.129737539*t)
	Y1 += 0.00000001242*np.cos(2.94913211429 + 539.2521926502*t)
	Y1 += 0.00000001273*np.cos(4.66529140108 + 842.9014410135*t)
	Y1 += 0.00000001421*np.cos(5.33916221251 + 2840.4132799086*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001306*np.cos(0.67255756115 + 74.7815985673*t)
	Y1 += 0.00000001222*np.cos(3.29271947698 + 1994.3304451574*t)
	Y1 += 0.00000001030*np.cos(3.78515935351 + 850.0149880143*t)
	Y1 += 0.00000000984*np.cos(0.37090239020 + 536.8526962052*t)
	Y1 += 0.00000000984*np.cos(3.96978325817 + 522.529233984*t)
	Y1 += 0.00000001165*np.cos(1.66359385295 + 2758.6611466924*t)
	Y1 += 0.00000001015*np.cos(5.23059949116 + 450.9772132642*t)
	Y1 += 0.00000001029*np.cos(1.56763208573 + 313.2104759189*t)
	Y1 += 0.00000001121*np.cos(2.24402409676 + 4164.311989613*t)
	Y1 += 0.00000000994*np.cos(1.30901040464 + 1969.2006632438*t)
	Y1 += 0.00000000944*np.cos(0.95774392273 + 3163.918696566*t)
	Y1 += 0.00000001047*np.cos(1.76345593121 + 586.3133163972*t)
	Y1 += 0.00000000901*np.cos(1.38329638160 + 248.7238180901*t)
	Y1 += 0.00000000900*np.cos(0.83061588531 + 3480.3105662226*t)
	Y1 += 0.00000000881*np.cos(5.31113210528 + 3384.3313390048*t)
	Y1 += 0.00000001056*np.cos(0.81526253414 + 2545.3620512544*t)
	Y1 += 0.00000001178*np.cos(2.14372062567 + 2428.0421830342*t)
	Y1 += 0.00000001007*np.cos(3.63586452957 + 1432.3961511484*t)
	Y1 += 0.00000001017*np.cos(3.67393791007 + 8094.5216858326*t)
	Y1 += 0.00000000984*np.cos(0.88440907863 + 522.6256022036*t)
	Y1 += 0.00000000984*np.cos(3.45627656974 + 536.7563279856*t)
	Y1 += 0.00000000865*np.cos(0.50216013525 + 2950.619601128*t)
	Y1 += 0.00000000873*np.cos(4.74768173992 + 2413.8150890326*t)
	Y1 += 0.00000000822*np.cos(2.21364343296 + 4539.6924964118*t)
	Y1 += 0.00000000891*np.cos(0.04963796225 + 486.4019359163*t)
	Y1 += 0.00000000832*np.cos(2.25167601382 + 608.404716925*t)
	Y1 += 0.00000001129*np.cos(5.87079751174 + 2200.5159935946*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000000866*np.cos(4.29611856959 + 1141.1340634054*t)
	Y1 += 0.00000000958*np.cos(1.27970555258 + 155.7829722581*t)
	Y1 += 0.00000000825*np.cos(1.82027592583 + 8617.0991039264*t)
	Y1 += 0.00000000785*np.cos(3.70194655878 + 3803.81598288*t)
	Y1 += 0.00000000943*np.cos(0.21048093986 + 151.0476698429*t)
	Y1 += 0.00000000780*np.cos(5.82856731272 + 9153.9036160218*t)
	Y1 += 0.00000000784*np.cos(5.32113346121 + 1791.3262904579*t)
	Y1 += 0.00000000821*np.cos(3.21388542837 + 902.7051860538*t)
	Y1 += 0.00000000781*np.cos(0.97332239037 + 1578.7779545453*t)
	Y1 += 0.00000000766*np.cos(0.71376571141 + 3810.9295298808*t)
	Y1 += 0.00000000949*np.cos(6.26912102192 + 298.2326223919*t)
	Y1 += 0.00000000801*np.cos(3.05567719876 + 77204.32749453338*t)
	Y1 += 0.00000000779*np.cos(0.55053192876 + 521.6142102473*t)
	Y1 += 0.00000000779*np.cos(3.79015371961 + 537.7677199419*t)
	Y1 += 0.00000000755*np.cos(2.10393125979 + 8631.326197928*t)
	Y1 += 0.00000000829*np.cos(3.04136554762 + 2957.7331481288*t)
	Y1 += 0.00000000743*np.cos(3.49834818410 + 1059.903195051*t)
	Y1 += 0.00000000743*np.cos(3.07971309061 + 3274.1250177854*t)
	Y1 += 0.00000000780*np.cos(5.38986403689 + 605.9570363702*t)
	Y1 += 0.00000000799*np.cos(1.14945420076 + 572.9799942729*t)
	Y1 += 0.00000000802*np.cos(2.35695692863 + 984.6003316219*t)
	Y1 += 0.00000000764*np.cos(0.39766128691 + 1792.0770499833*t)
	Y1 += 0.00000000715*np.cos(1.28765336247 + 1688.9842757647*t)
	Y1 += 0.00000000751*np.cos(1.02173203233 + 1670.82502850*t)
	Y1 += 0.00000000850*np.cos(2.33021670338 + 775.233389447*t)
	Y1 += 0.00000000739*np.cos(4.25047385192 + 967.3348562345*t)
	Y1 += 0.00000000702*np.cos(4.47851796652 + 5223.6939198022*t)
	Y1 += 0.00000000726*np.cos(4.13077301998 + 3053.7123753466*t)
	Y1 += 0.00000000848*np.cos(4.81954421072 + 1289.9465010146*t)
	Y1 += 0.00000000701*np.cos(2.88277383921 + 245.5424243524*t)
	Y1 += 0.00000000676*np.cos(2.40793716843 + 2310.722314814*t)
	Y1 += 0.00000000684*np.cos(5.02029969007 + 1798.4398374587*t)
	Y1 += 0.00000000700*np.cos(2.95656616511 + 487.1526954417*t)
	Y1 += 0.00000000700*np.cos(4.52571213685 + 572.2292347475*t)
	Y1 += 0.00000000667*np.cos(5.58820603533 + 1012.9115072732*t)
	Y1 += 0.00000000856*np.cos(5.49062175402 + 3281.2385647862*t)
	Y1 += 0.00000000688*np.cos(4.53443685661 + 5062.2699145056*t)
	Y1 += 0.00000000670*np.cos(2.20829954235 + 398.1440028728*t)
	Y1 += 0.00000000700*np.cos(0.90825418370 + 166.828672522*t)
	Y1 += 0.00000000674*np.cos(3.88153164593 + 4649.8988176312*t)
	Y1 += 0.00000000679*np.cos(5.25022214235 + 24498.8302462904*t)
	Y1 += 0.00000000729*np.cos(4.80748161782 + 4546.8060434126*t)
	Y1 += 0.00000000651*np.cos(1.93840355543 + 4856.0843660684*t)
	Y1 += 0.00000000665*np.cos(1.62103950350 + 306.0969289181*t)
	Y1 += 0.00000000649*np.cos(6.27565603355 + 1799.1905969841*t)
	Y1 += 0.00000000712*np.cos(1.82235727085 + 71.8126531507*t)
	Y1 += 0.00000000704*np.cos(5.13302286395 + 5165.3626887242*t)
	Y1 += 0.00000000748*np.cos(0.93805184360 + 2861.753920911*t)
	Y1 += 0.00000000626*np.cos(0.63607861789 + 3796.7024358792*t)
	Y1 += 0.00000000629*np.cos(3.95200945726 + 3487.4241132234*t)
	Y1 += 0.00000000718*np.cos(2.94974266304 + 77.7505439839*t)
	Y1 += 0.00000000703*np.cos(4.75333752379 + 2288.3440435114*t)
	Y1 += 0.00000000703*np.cos(5.25394837027 + 2274.1169495098*t)
	Y1 += 0.00000000611*np.cos(5.22985008895 + 5746.271337896*t)
	Y1 += 0.00000000630*np.cos(4.03795930066 + 4333.5069479746*t)
	Y1 += 0.00000000606*np.cos(0.77317400848 + 1751.539531416*t)
	Y1 += 0.00000000748*np.cos(1.94530786303 + 1262.3860848887*t)
	Y1 += 0.00000000596*np.cos(2.67910420053 + 3590.516887442*t)
	Y1 += 0.00000000779*np.cos(0.03702524033 + 535.8413042489*t)
	Y1 += 0.00000000779*np.cos(4.30366040804 + 523.5406259403*t)
	Y1 += 0.00000000578*np.cos(0.90023029993 + 3494.5376602242*t)
	Y1 += 0.00000000607*np.cos(1.35240171145 + 2132.99095438*t)
	Y1 += 0.00000000757*np.cos(1.31807608705 + 105.5404547734*t)
	Y1 += 0.00000000744*np.cos(6.04792773935 + 643.0786800517*t)
	Y1 += 0.00000000569*np.cos(4.64485571012 + 4017.115078318*t)
	Y1 += 0.00000000720*np.cos(1.48967021247 + 3075.053016349*t)
	Y1 += 0.00000000586*np.cos(2.03862098556 + 453.424893819*t)
	Y1 += 0.00000000573*np.cos(5.97537798329 + 394.3548619616*t)
	Y1 += 0.00000000634*np.cos(6.09734075114 + 469.8872200543*t)
	Y1 += 0.00000000559*np.cos(0.92746805833 + 444.7574381407*t)
	Y1 += 0.00000000567*np.cos(5.33234912069 + 1887.3055176757*t)
	Y1 += 0.00000000564*np.cos(2.51975095880 + 1127.0499817557*t)
	Y1 += 0.00000000547*np.cos(0.43067657913 + 4127.3213995374*t)
	Y1 += 0.00000000624*np.cos(2.95326482349 + 25035.6347583858*t)
	Y1 += 0.00000000767*np.cos(0.65207644700 + 927.8349679674*t)
	Y1 += 0.00000000701*np.cos(2.35692203971 + 1819.6374661092*t)
	Y1 += 0.00000000650*np.cos(4.97825491434 + 4230.414173756*t)
	Y1 += 0.00000000545*np.cos(6.09686461220 + 810.6581120991*t)
	Y1 += 0.00000000616*np.cos(3.45386363434 + 25021.4076643842*t)
	Y1 += 0.00000000537*np.cos(1.85184528328 + 782.3469364478*t)
	Y1 += 0.00000000541*np.cos(5.13234346501 + 3700.7232086614*t)
	Y1 += 0.00000000543*np.cos(0.02138348498 + 4738.7644978482*t)
	Y1 += 0.00000000526*np.cos(4.37099486824 + 3171.0322435668*t)
	Y1 += 0.00000000524*np.cos(2.47451797434 + 2744.4340526908*t)
	Y1 += 0.00000000630*np.cos(3.30718088155 + 5069.3834615064*t)
	Y1 += 0.00000000534*np.cos(6.16997492577 + 436.8931316145*t)
	Y1 += 0.00000000523*np.cos(2.13983751104 + 3060.8259223474*t)
	Y1 += 0.00000000541*np.cos(0.28060434582 + 1268.7488723641*t)
	Y1 += 0.00000000666*np.cos(6.02394430259 + 4525.4654024102*t)
	Y1 += 0.00000000593*np.cos(5.06338221497 + 4642.7852706304*t)
	Y1 += 0.00000000493*np.cos(3.86164538549 + 10021.8372800994*t)
	Y1 += 0.00000000660*np.cos(5.11501281990 + 3156.8051495652*t)
	Y1 += 0.00000000628*np.cos(0.19896395151 + 1560.6187072806*t)
	Y1 += 0.00000000528*np.cos(2.69043641375 + 3252.784376783*t)
	Y1 += 0.00000000546*np.cos(1.38493599415 + 589.4947101349*t)
	Y1 += 0.00000000509*np.cos(0.35840961831 + 4686.8894077068*t)
	Y1 += 0.00000000505*np.cos(0.21000748847 + 754.0357607965*t)
	Y1 += 0.00000000475*np.cos(5.72911758023 + 1467.8208738005*t)
	Y1 += 0.00000000451*np.cos(4.98362627844 + 2107.7181601145*t)
	Y1 += 0.00000000515*np.cos(5.03293826716 + 3466.083472221*t)
	Y1 += 0.00000000466*np.cos(0.09931185396 + 1489.9122743283*t)
	Y1 += 0.00000000462*np.cos(5.48131535175 + 26617.5941066688*t)
	Y1 += 0.00000000497*np.cos(5.58599824476 + 69.1525242748*t)
	Y1 += 0.00000000600*np.cos(5.56979305057 + 2516.9078632512*t)
	Y1 += 0.00000000442*np.cos(3.42626208754 + 4436.5997221932*t)
	Y1 += 0.00000000557*np.cos(5.97418939930 + 2964.8466951296*t)
	Y1 += 0.00000000433*np.cos(0.72835384240 + 4701.1165017084*t)
	Y1 += 0.00000000452*np.cos(3.24655844352 + 1550.939859646*t)
	Y1 += 0.00000000429*np.cos(4.70606670928 + 4002.8879843164*t)
	Y1 += 0.00000000466*np.cos(5.89934183506 + 3267.0114707846*t)
	Y1 += 0.00000000476*np.cos(4.83733392895 + 447.7958195265*t)
	Y1 += 0.00000000417*np.cos(1.38377742741 + 665.0270682276*t)
	Y1 += 0.00000000573*np.cos(1.05151671334 + 1357.6145525811*t)
	Y1 += 0.00000000417*np.cos(0.72571440164 + 3782.4753418776*t)
	Y1 += 0.00000000423*np.cos(6.09770834441 + 415.2918581812*t)
	Y1 += 0.00000000412*np.cos(2.59026540572 + 3906.9087570986*t)
	Y1 += 0.00000000431*np.cos(0.15413742649 + 2108.4689196399*t)
	Y1 += 0.00000000407*np.cos(0.49985205890 + 4113.0943055358*t)
	Y1 += 0.00000000424*np.cos(0.17482952689 + 1254.5217783625*t)
	Y1 += 0.00000000399*np.cos(5.21078052617 + 1457.525933062*t)
	Y1 += 0.00000000396*np.cos(3.76182057447 + 4966.2906872878*t)
	Y1 += 0.00000000483*np.cos(4.97716778578 + 827.9235874865*t)
	Y1 += 0.00000000487*np.cos(4.98989666228 + 1901.5326116773*t)
	Y1 += 0.00000000398*np.cos(2.98973507663 + 355.7487455718*t)
	Y1 += 0.00000000396*np.cos(2.29671916725 + 1020.025054274*t)
	Y1 += 0.00000000438*np.cos(5.82247234506 + 611.5861106627*t)
	Y1 += 0.00000000412*np.cos(0.90735881784 + 1902.2833712027*t)
	Y1 += 0.00000000409*np.cos(4.03770283879 + 12036.4607348882*t)
	Y1 += 0.00000000404*np.cos(1.67660119073 + 2042.4977891028*t)
	Y1 += 0.00000000412*np.cos(4.61042804541 + 4863.1979130692*t)
	Y1 += 0.00000000379*np.cos(0.15741978894 + 4443.713269194*t)
	Y1 += 0.00000000376*np.cos(0.48003200118 + 614.6244920485*t)
	Y1 += 0.00000000514*np.cos(3.78168900426 + 4752.9915918498*t)
	Y1 += 0.00000000369*np.cos(3.52888759515 + 4120.2078525366*t)
	return Y1*t




def Jupiter_Y2 (t): # 262 terms of order 2

	Y2 = 0.
	Y2 += 0.00123914193*np.cos(2.56495551373 + 522.5774180938*t)
	Y2 += 0.00121340211*np.cos(4.92398747363 + 536.8045120954*t)
	Y2 += 0.00076450198*np.cos(3.75913373191 + 529.6909650946*t)
	Y2 -= 0.00076998857
	Y2 += 0.00041318153*np.cos(3.55228415274 + 1059.3819301892*t)
	Y2 += 0.00011292133*np.cos(0.18554488524 + 7.1135470008*t)
	Y2 += 0.00007044308*np.cos(5.45405276738 + 1066.49547719*t)
	Y2 += 0.00005713988*np.cos(2.05969938998 + 1052.2683831884*t)
	Y2 += 0.00005281117*np.cos(2.69489901888 + 515.463871093*t)
	Y2 += 0.00004035186*np.cos(4.01341034017 + 1589.0728952838*t)
	Y2 += 0.00003701007*np.cos(4.79029127004 + 543.9180590962*t)
	Y2 += 0.00001280839*np.cos(1.47520232403 + 110.2063212194*t)
	Y2 += 0.00000994405*np.cos(0.89475497823 + 426.598190876*t)
	Y2 += 0.00001322342*np.cos(0.05782252396 + 14.2270940016*t)
	Y2 += 0.00000887296*np.cos(3.09675116331 + 526.5095713569*t)
	Y2 += 0.00000863718*np.cos(4.38537604521 + 532.8723588323*t)
	Y2 += 0.00000819498*np.cos(0.37986736437 + 632.7837393132*t)
	Y2 += 0.00000993208*np.cos(6.18583826626 + 323.5054166574*t)
	Y2 += 0.00000572452*np.cos(0.10744883623 + 949.1756089698*t)
	Y2 += 0.00000570935*np.cos(1.57854031086 + 1045.1548361876*t)
	Y2 += 0.00000623517*np.cos(1.29414478219 + 735.8765135318*t)
	Y2 += 0.00000513373*np.cos(4.40000643991 + 525.7588118315*t)
	Y2 += 0.00000511439*np.cos(3.08494935962 + 533.6231183577*t)
	Y2 += 0.00000457877*np.cos(5.95712671606 + 1596.1864422846*t)
	Y2 += 0.00000417596*np.cos(1.04759399465 + 117.3198682202*t)
	Y2 += 0.00000367753*np.cos(2.55698726268 + 419.4846438752*t)
	Y2 += 0.00000372186*np.cos(0.82445685096 + 95.9792272178*t)
	Y2 += 0.00000356691*np.cos(5.20948018395 + 220.4126424388*t)
	Y2 += 0.00000347326*np.cos(2.03233026390 + 206.1855484372*t)
	Y2 += 0.00000332282*np.cos(4.43064743394 + 2118.7638603784*t)
	Y2 += 0.00000263163*np.cos(1.67607893968 + 625.6701923124*t)
	Y2 += 0.00000283010*np.cos(2.13606840886 + 1581.959348283*t)
	Y2 += 0.00000227656*np.cos(5.54050699340 + 433.7117378768*t)
	Y2 += 0.00000261630*np.cos(2.11384211463 + 956.2891559706*t)
	Y2 += 0.00000214908*np.cos(0.20715229894 + 942.062061969*t)
	Y2 += 0.00000195622*np.cos(4.43848619814 + 1169.5882514086*t)
	Y2 += 0.00000168059*np.cos(3.75792135720 + 316.3918696566*t)
	Y2 += 0.00000163951*np.cos(5.23639979738 + 1073.6090241908*t)
	Y2 += 0.00000192427*np.cos(4.40919774179 + 639.897286314*t)
	Y2 += 0.00000169563*np.cos(1.95952861141 + 1155.361157407*t)
	Y2 += 0.00000139781*np.cos(2.84755828617 + 508.3503240922*t)
	Y2 += 0.00000135770*np.cos(3.57555081678 + 742.9900605326*t)
	Y2 += 0.00000135137*np.cos(1.83954198363 + 199.0720014364*t)
	Y2 += 0.00000170191*np.cos(6.03674985923 + 330.6189636582*t)
	Y2 += 0.00000156737*np.cos(4.05468771239 + 213.299095438*t)
	Y2 += 0.00000136696*np.cos(2.96613283740 + 309.2783226558*t)
	Y2 += 0.00000106857*np.cos(1.11158476054 + 853.196381752*t)
	Y2 += 0.00000134785*np.cos(1.30990983053 + 728.762966531*t)
	Y2 += 0.00000112454*np.cos(3.07810446043 + 1162.4747044078*t)
	Y2 += 0.00000096938*np.cos(4.82746486262 + 103.0927742186*t)
	Y2 += 0.00000077442*np.cos(2.62321674807 + 1265.5674786264*t)
	Y2 += 0.00000074683*np.cos(4.62128405037 + 551.031606097*t)
	Y2 += 0.00000084709*np.cos(3.26954755507 + 519.3960243561*t)
	Y2 += 0.00000077754*np.cos(2.07024143046 + 838.9692877504*t)
	Y2 += 0.00000067576*np.cos(4.19610515178 + 539.9859058331*t)
	Y2 += 0.00000054356*np.cos(5.07028204957 + 227.5261894396*t)
	Y2 += 0.00000051093*np.cos(5.91426034557 + 3.1813937377*t)
	Y2 += 0.00000053400*np.cos(1.91345827803 + 412.3710968744*t)
	Y2 += 0.00000055428*np.cos(6.21192121199 + 21.3406410024*t)
	Y2 += 0.00000048874*np.cos(4.88897900689 + 1062.5633239269*t)
	Y2 += 0.00000043068*np.cos(2.73485657482 + 1258.4539316256*t)
	Y2 += 0.00000038739*np.cos(4.25265519830 + 440.8252848776*t)
	Y2 += 0.00000041421*np.cos(2.87269446113 + 618.5566453116*t)
	Y2 += 0.00000037469*np.cos(3.08522051912 + 1692.1656695024*t)
	Y2 += 0.00000031825*np.cos(0.15097091165 + 2125.8774073792*t)
	Y2 += 0.00000036591*np.cos(2.83592966607 + 1056.2005364515*t)
	Y2 += 0.00000043277*np.cos(1.75702652017 + 1574.8458012822*t)
	Y2 += 0.00000032932*np.cos(4.95534262832 + 1272.6810256272*t)
	Y2 += 0.00000028786*np.cos(5.04321322439 + 1055.4497769261*t)
	Y2 += 0.00000036214*np.cos(2.88878659937 + 302.164775655*t)
	Y2 += 0.00000028755*np.cos(1.54567775560 + 1038.0412891868*t)
	Y2 += 0.00000031557*np.cos(2.02145667899 + 831.8557407496*t)
	Y2 += 0.00000029358*np.cos(3.23095760026 + 1485.9801210652*t)
	Y2 += 0.00000025839*np.cos(4.81555513749 + 2648.454825473*t)
	Y2 += 0.00000021631*np.cos(0.89648612124 + 1471.7530270636*t)
	Y2 += 0.00000026179*np.cos(0.24148768969 + 846.0828347512*t)
	Y2 += 0.00000021128*np.cos(4.96775257256 + 1699.2792165032*t)
	Y2 += 0.00000019785*np.cos(3.31607841546 + 1063.3140834523*t)
	Y2 += 0.00000022677*np.cos(3.77541947622 + 1368.660252845*t)
	Y2 += 0.00000021083*np.cos(4.47373827173 + 647.0108333148*t)
	Y2 += 0.00000016107*np.cos(0.54459154986 + 1478.8665740644*t)
	Y2 += 0.00000013890*np.cos(0.38659798495 + 1375.7737998458*t)
	Y2 += 0.00000014230*np.cos(0.84625436419 + 124.433415221*t)
	Y2 += 0.00000012066*np.cos(5.73472992745 + 10.2949407385*t)
	Y2 += 0.00000014561*np.cos(2.27759601573 + 2111.6503133776*t)
	Y2 += 0.00000011227*np.cos(1.59683338999 + 511.5317178299*t)
	Y2 += 0.00000012664*np.cos(5.78004639505 + 963.4027029714*t)
	Y2 += 0.00000010726*np.cos(5.88544476377 + 547.8502123593*t)
	Y2 += 0.00000013226*np.cos(4.53317344901 + 750.1036075334*t)
	Y2 += 0.00000012226*np.cos(2.25243853635 + 1685.0521225016*t)
	Y2 += 0.00000008892*np.cos(1.76003652107 + 1382.8873468466*t)
	Y2 += 0.00000009905*np.cos(0.77307644712 + 934.9485149682*t)
	Y2 += 0.00000007503*np.cos(5.67187992612 + 1603.2999892854*t)
	Y2 += 0.00000007748*np.cos(1.95614847548 + 191.9584544356*t)
	Y2 += 0.00000007293*np.cos(3.90640976229 + 88.865680217*t)
	Y2 += 0.00000008004*np.cos(5.88582537682 + 337.732510659*t)
	Y2 += 0.00000007467*np.cos(1.64289001379 + 721.6494195302*t)
	Y2 += 0.00000006361*np.cos(3.48520810942 + 2221.856634597*t)
	Y2 += 0.00000006799*np.cos(2.80209624655 + 1795.258443721*t)
	Y2 += 0.00000007045*np.cos(4.10613187589 + 1361.5467058442*t)
	Y2 += 0.00000004967*np.cos(1.37584831567 + 99.9113804809*t)
	Y2 += 0.00000006315*np.cos(1.53291580984 + 1148.2476104062*t)
	Y2 += 0.00000006293*np.cos(0.36768353635 + 860.3099287528*t)
	Y2 += 0.00000005574*np.cos(2.44509799385 + 1049.0869894507*t)
	Y2 += 0.00000004189*np.cos(4.77885922079 + 1802.3719907218*t)
	Y2 += 0.00000004812*np.cos(1.98451914225 + 106.2741679563*t)
	Y2 += 0.00000004025*np.cos(2.53347820962 + 1251.3403846248*t)
	Y2 += 0.00000003836*np.cos(1.94088141385 + 1788.1448967202*t)
	Y2 += 0.00000003926*np.cos(2.16218663827 + 497.4476361802*t)
	Y2 += 0.00000003588*np.cos(4.90194555299 + 234.6397364404*t)
	Y2 += 0.00000003620*np.cos(5.32009120194 + 561.934294009*t)
	Y2 += 0.00000003936*np.cos(3.52686641861 + 405.2575498736*t)
	Y2 += 0.00000003522*np.cos(3.09584664057 + 501.2367770914*t)
	Y2 += 0.00000003253*np.cos(3.34106076070 + 611.4430983108*t)
	Y2 += 0.00000003748*np.cos(0.47584176486 + 113.3877149571*t)
	Y2 += 0.00000003174*np.cos(3.90623325381 + 447.9388318784*t)
	Y2 += 0.00000002991*np.cos(1.58678516800 + 2104.5367663768*t)
	Y2 += 0.00000002969*np.cos(4.12345180044 + 2015.6710861598*t)
	Y2 += 0.00000002822*np.cos(3.94568503982 + 149.5631971346*t)
	Y2 += 0.00000002744*np.cos(4.17859800270 + 81.7521332162*t)
	Y2 += 0.00000002799*np.cos(2.65810646470 + 99.1606209555*t)
	Y2 += 0.00000002715*np.cos(5.66151426195 + 429.7795846137*t)
	Y2 += 0.00000002757*np.cos(2.41130408823 + 2008.557539159*t)
	Y2 += 0.00000003501*np.cos(4.61828326310 + 1069.6768709277*t)
	Y2 += 0.00000002750*np.cos(0.88132502339 + 1464.6394800628*t)
	Y2 += 0.00000002955*np.cos(5.33795885153 + 1592.2542890215*t)
	Y2 += 0.00000002434*np.cos(4.87638052191 + 1080.7225711916*t)
	Y2 += 0.00000002380*np.cos(4.20833251941 + 423.4167971383*t)
	Y2 += 0.00000003126*np.cos(1.68541603460 + 1567.7322542814*t)
	Y2 += 0.00000002355*np.cos(2.28604318633 + 824.7421937488*t)
	Y2 += 0.00000002693*np.cos(2.96410442520 + 295.0512286542*t)
	Y2 += 0.00000002197*np.cos(1.74911888013 + 629.6023455755*t)
	Y2 += 0.00000002235*np.cos(3.71696358345 + 6275.9623029906*t)
	Y2 += 0.00000002231*np.cos(6.07590911987 + 6290.1893969922*t)
	Y2 += 0.00000002060*np.cos(0.61396408295 + 2655.5683724738*t)
	Y2 += 0.00000002732*np.cos(3.12540902543 + 1898.3512179396*t)
	Y2 += 0.00000002076*np.cos(5.13986644709 + 10206.1719992102*t)
	Y2 += 0.00000001974*np.cos(2.06571038137 + 1891.2376709388*t)
	Y2 += 0.00000002072*np.cos(1.21562719258 + 10220.3990932118*t)
	Y2 += 0.00000002700*np.cos(0.24738899316 + 107.0249274817*t)
	Y2 += 0.00000001764*np.cos(4.69152887895 + 970.5162499722*t)
	Y2 += 0.00000001958*np.cos(2.42000633557 + 2428.0421830342*t)
	Y2 += 0.00000001815*np.cos(4.28784094353 + 558.1451530978*t)
	Y2 += 0.00000001819*np.cos(3.79128389109 + 1165.6560981455*t)
	Y2 += 0.00000001797*np.cos(5.48847999907 + 1585.1407420207*t)
	Y2 += 0.00000001719*np.cos(3.18125652838 + 654.1243803156*t)
	Y2 += 0.00000001768*np.cos(2.63222494622 + 1159.2933106701*t)
	Y2 += 0.00000001746*np.cos(2.85411229216 + 1585.8915015461*t)
	Y2 += 0.00000001735*np.cos(0.22737646203 + 1905.4647649404*t)
	Y2 += 0.00000001559*np.cos(3.23096370603 + 635.9651330509*t)
	Y2 += 0.00000001781*np.cos(5.31682308345 + 3178.1457905676*t)
	Y2 += 0.00000001753*np.cos(4.84286553509 + 757.2171545342*t)
	Y2 += 0.00000001334*np.cos(2.44302159466 + 2324.9494088156*t)
	Y2 += 0.00000001409*np.cos(4.65471130275 + 216.4804891757*t)
	Y2 += 0.00000001395*np.cos(2.53366287996 + 1279.794572628*t)
	Y2 += 0.00000001384*np.cos(4.87298665741 + 5230.807466803*t)
	Y2 += 0.00000001380*np.cos(2.51452122242 + 5216.5803728014*t)
	Y2 += 0.00000001551*np.cos(0.71019873146 + 945.9942152321*t)
	Y2 += 0.00000001198*np.cos(5.50483020501 + 326.6868103951*t)
	Y2 += 0.00000001220*np.cos(5.64184418834 + 319.5732633943*t)
	Y2 += 0.00000001271*np.cos(0.01278840381 + 9161.0171630226*t)
	Y2 += 0.00000001268*np.cos(3.93752177050 + 9146.790069021*t)
	Y2 += 0.00000001183*np.cos(1.68809878200 + 636.7158925763*t)
	Y2 += 0.00000001273*np.cos(5.69517929111 + 2228.9701815978*t)
	Y2 += 0.00000001310*np.cos(2.10065572721 + 2001.4439921582*t)
	Y2 += 0.00000001162*np.cos(2.39505525199 + 2214.7430875962*t)
	Y2 += 0.00000001234*np.cos(2.08977841036 + 2744.4340526908*t)
	Y2 += 0.00000001247*np.cos(2.21578255427 + 3274.1250177854*t)
	Y2 += 0.00000001057*np.cos(4.25786293090 + 1677.9385755008*t)
	Y2 += 0.00000001051*np.cos(0.87130311109 + 1493.093668066*t)
	Y2 += 0.00000001063*np.cos(0.33463469782 + 518.6452648307*t)
	Y2 += 0.00000001063*np.cos(4.00605095055 + 540.7366653585*t)
	Y2 += 0.00000001137*np.cos(0.75125250543 + 1781.0313497194*t)
	Y2 += 0.00000000985*np.cos(2.22432634276 + 2641.3412784722*t)
	Y2 += 0.00000000963*np.cos(3.27927902413 + 2538.2485042536*t)
	Y2 += 0.00000001262*np.cos(3.63544646876 + 5223.6939198022*t)
	Y2 += 0.00000000939*np.cos(3.69451127868 + 909.8187330546*t)
	Y2 += 0.00000001000*np.cos(2.65378286675 + 210.1177017003*t)
	Y2 += 0.00000000932*np.cos(1.81698627301 + 952.3570027075*t)
	Y2 += 0.00000000905*np.cos(1.75035968766 + 2207.6295405954*t)
	Y2 += 0.00000000904*np.cos(3.88776151360 + 1158.5425511447*t)
	Y2 += 0.00000001102*np.cos(4.15046964897 + 3281.2385647862*t)
	Y2 += 0.00000001183*np.cos(0.56667627747 + 953.1077622329*t)
	Y2 += 0.00000000909*np.cos(3.97386545234 + 5753.3848848968*t)
	Y2 += 0.00000001099*np.cos(1.58755431405 + 1912.5783119412*t)
	Y2 += 0.00000000873*np.cos(4.08070650023 + 1670.82502850*t)
	Y2 += 0.00000000800*np.cos(4.12792698994 + 2751.5475996916*t)
	Y2 += 0.00000000796*np.cos(1.96326433522 + 739.8086667949*t)
	Y2 += 0.00000001077*np.cos(4.20051781444 + 209.3669421749*t)
	Y2 += 0.00000000790*np.cos(2.45933758823 + 1166.4068576709*t)
	Y2 += 0.00000001034*np.cos(3.34912946109 + 3487.4241132234*t)
	Y2 += 0.00000000785*np.cos(2.02597124501 + 416.3032501375*t)
	Y2 += 0.00000000919*np.cos(2.39038740005 + 203.0041546995*t)
	Y2 += 0.00000000761*np.cos(1.08620709767 + 2420.9286360334*t)
	Y2 += 0.00000000837*np.cos(5.40426948233 + 9683.5945811164*t)
	Y2 += 0.00000000738*np.cos(5.96869837348 + 422.6660376129*t)
	Y2 += 0.00000000721*np.cos(3.87768518670 + 4694.0029547076*t)
	Y2 += 0.00000000978*np.cos(4.33162349182 + 2964.8466951296*t)
	Y2 += 0.00000000920*np.cos(1.74204964119 + 3899.7952100978*t)
	Y2 += 0.00000000733*np.cos(3.30972792259 + 217.2312487011*t)
	Y2 += 0.00000000978*np.cos(4.89659129136 + 6283.0758499914*t)
	Y2 += 0.00000000778*np.cos(3.69507849012 + 1354.4331588434*t)
	Y2 += 0.00000000915*np.cos(2.13949682628 + 3576.2897934404*t)
	Y2 += 0.00000000722*np.cos(0.69187773300 + 1809.4855377226*t)
	Y2 += 0.00000000696*np.cos(3.87883551414 + 1987.2168981566*t)
	Y2 += 0.00000000668*np.cos(2.86620871992 + 2854.6403739102*t)
	Y2 += 0.00000000655*np.cos(5.29949318111 + 8624.2126509272*t)
	Y2 += 0.00000000859*np.cos(4.45240229941 + 458.8415197904*t)
	Y2 += 0.00000000826*np.cos(3.58615132269 + 3149.6916025644*t)
	Y2 += 0.00000000781*np.cos(2.40850749460 + 927.8349679674*t)
	Y2 += 0.00000000818*np.cos(2.76219868399 + 3384.3313390048*t)
	Y2 += 0.00000000794*np.cos(4.72021603023 + 2332.0629558164*t)
	Y2 += 0.00000000751*np.cos(3.92545123427 + 3597.6304344428*t)
	Y2 += 0.00000000791*np.cos(1.52573491012 + 3796.7024358792*t)
	Y2 += 0.00000000736*np.cos(1.86637976498 + 3480.3105662226*t)
	Y2 += 0.00000000638*np.cos(0.55679578954 + 2545.3620512544*t)
	Y2 += 0.00000000648*np.cos(1.93188405517 + 3060.8259223474*t)
	Y2 += 0.00000000785*np.cos(2.74220165125 + 732.6951197941*t)
	Y2 += 0.00000000725*np.cos(1.26016666923 + 3789.5888888784*t)
	Y2 += 0.00000000712*np.cos(1.99484788774 + 3590.516887442*t)
	Y2 += 0.00000000595*np.cos(4.19675234613 + 2435.155730035*t)
	Y2 += 0.00000000724*np.cos(1.55082948672 + 1884.124123938*t)
	Y2 += 0.00000000664*np.cos(2.83741922299 + 3046.5988283458*t)
	Y2 += 0.00000000565*np.cos(0.13040432946 + 2861.753920911*t)
	Y2 += 0.00000000719*np.cos(3.02987373443 + 600.5404103988*t)
	Y2 += 0.00000000546*np.cos(0.87761028668 + 437.6438911399*t)
	Y2 += 0.00000000549*np.cos(0.73935228740 + 2634.2277314714*t)
	Y2 += 0.00000000726*np.cos(5.43722942949 + 74.7815985673*t)
	Y2 += 0.00000000555*np.cos(3.26043351918 + 76.2660712756*t)
	Y2 += 0.00000000558*np.cos(5.78011457626 + 1141.1340634054*t)
	Y2 += 0.00000000681*np.cos(5.03391374752 + 9153.9036160218*t)
	Y2 += 0.00000000588*np.cos(3.45206402508 + 430.5303441391*t)
	Y2 += 0.00000000535*np.cos(3.65950530901 + 2303.6087678132*t)
	Y2 += 0.00000000542*np.cos(1.07428391249 + 2833.2997329078*t)
	Y2 += 0.00000000662*np.cos(2.49995354012 + 3700.7232086614*t)
	Y2 += 0.00000000578*np.cos(1.21476916834 + 2524.021410252*t)
	Y2 += 0.00000000619*np.cos(3.11707822296 + 3803.81598288*t)
	Y2 += 0.00000000644*np.cos(1.29355284344 + 3370.1042450032*t)
	Y2 += 0.00000000514*np.cos(1.29667013246 + 3693.6096616606*t)
	Y2 += 0.00000000479*np.cos(0.80014976333 + 1457.525933062*t)
	Y2 += 0.00000000576*np.cos(1.73977731568 + 2317.8358618148*t)
	Y2 += 0.00000000578*np.cos(1.89898756605 + 3892.681663097*t)
	Y2 += 0.00000000566*np.cos(6.16406702320 + 2627.1141844706*t)
	Y2 += 0.00000000433*np.cos(0.32147874689 + 621.7380390493*t)
	Y2 += 0.00000000530*np.cos(1.01908606392 + 547.0994528339*t)
	Y2 += 0.00000000530*np.cos(3.32159958445 + 512.2824773553*t)
	Y2 += 0.00000000429*np.cos(1.73580957288 + 2957.7331481288*t)
	Y2 += 0.00000000478*np.cos(3.50052966452 + 1593.0050485469*t)
	Y2 += 0.00000000508*np.cos(2.12854820616 + 1244.226837624*t)
	Y2 += 0.00000000475*np.cos(5.81122801833 + 3267.0114707846*t)
	Y2 += 0.00000000484*np.cos(0.52920634380 + 2097.423219376*t)
	Y2 += 0.00000000521*np.cos(1.46015655382 + 4216.1870797544*t)
	Y2 += 0.00000000458*np.cos(4.03020978215 + 628.8515860501*t)
	Y2 += 0.00000000424*np.cos(2.34294525821 + 415.5524906121*t)
	Y2 += 0.00000000527*np.cos(4.64068120535 + 462.0229135281*t)
	Y2 += 0.00000000527*np.cos(2.84159709661 + 597.3590166611*t)
	Y2 += 0.00000000450*np.cos(3.73641389697 + 3914.0223040994*t)
	Y2 += 0.00000000511*np.cos(4.46661629527 + 643.0786800517*t)
	Y2 += 0.00000000431*np.cos(0.85126632752 + 849.2642284889*t)
	Y2 += 0.00000000402*np.cos(5.96207457174 + 2730.2069586892*t)
	Y2 += 0.00000000402*np.cos(2.01243830321 + 2531.1349572528*t)
	Y2 += 0.00000000412*np.cos(6.19801347868 + 2758.6611466924*t)
	return Y2*t*t




def Jupiter_Y3 (t): # 136 terms of order 3

	Y3 = 0.
	Y3 += 0.00017069216*np.cos(4.29096907367 + 522.5774180938*t)
	Y3 += 0.00016685430*np.cos(3.20365723177 + 536.8045120954*t)
	Y3 += 0.00004008677
	Y3 += 0.00001780751*np.cos(1.99283006102 + 1059.3819301892*t)
	Y3 += 0.00001442439*np.cos(4.40866193494 + 515.463871093*t)
	Y3 += 0.00001078368*np.cos(3.85452121689 + 1066.49547719*t)
	Y3 += 0.00001012194*np.cos(3.07729472515 + 543.9180590962*t)
	Y3 += 0.00001056925*np.cos(4.70176335380 + 7.1135470008*t)
	Y3 += 0.00000709708*np.cos(3.93734081808 + 1052.2683831884*t)
	Y3 += 0.00000259353*np.cos(2.71566478390 + 1589.0728952838*t)
	Y3 += 0.00000300991*np.cos(4.62152142420 + 14.2270940016*t)
	Y3 += 0.00000134697*np.cos(3.36276638608 + 1045.1548361876*t)
	Y3 += 0.00000142700*np.cos(5.28813557728 + 529.6909650946*t)
	Y3 += 0.00000078211*np.cos(4.44277151970 + 1596.1864422846*t)
	Y3 += 0.00000076444*np.cos(5.61467537902 + 117.3198682202*t)
	Y3 += 0.00000091646*np.cos(4.44623348041 + 323.5054166574*t)
	Y3 += 0.00000058233*np.cos(4.56584817087 + 508.3503240922*t)
	Y3 += 0.00000061115*np.cos(0.26556050313 + 110.2063212194*t)
	Y3 += 0.00000050849*np.cos(2.55648110758 + 95.9792272178*t)
	Y3 += 0.00000048948*np.cos(3.48320727413 + 220.4126424388*t)
	Y3 += 0.00000047020*np.cos(3.57871568016 + 1073.6090241908*t)
	Y3 += 0.00000046194*np.cos(5.49050676035 + 426.598190876*t)
	Y3 += 0.00000056831*np.cos(3.04840022697 + 735.8765135318*t)
	Y3 += 0.00000043313*np.cos(2.24184158741 + 632.7837393132*t)
	Y3 += 0.00000038462*np.cos(3.29258581824 + 625.6701923124*t)
	Y3 += 0.00000040222*np.cos(1.91375009490 + 942.062061969*t)
	Y3 += 0.00000032318*np.cos(4.02515512259 + 1581.959348283*t)
	Y3 += 0.00000033416*np.cos(3.83334136294 + 433.7117378768*t)
	Y3 += 0.00000032288*np.cos(2.89151197781 + 551.031606097*t)
	Y3 += 0.00000038564*np.cos(4.33793526039 + 330.6189636582*t)
	Y3 += 0.00000037944*np.cos(0.52701124335 + 103.0927742186*t)
	Y3 += 0.00000028185*np.cos(3.19464484210 + 2118.7638603784*t)
	Y3 += 0.00000029979*np.cos(2.02000649959 + 949.1756089698*t)
	Y3 += 0.00000028019*np.cos(4.41764181323 + 419.4846438752*t)
	Y3 += 0.00000026377*np.cos(2.75072415591 + 1169.5882514086*t)
	Y3 += 0.00000030311*np.cos(3.07123940662 + 728.762966531*t)
	Y3 += 0.00000025000*np.cos(3.57650009459 + 199.0720014364*t)
	Y3 += 0.00000023237*np.cos(3.72589643043 + 1155.361157407*t)
	Y3 += 0.00000025971*np.cos(4.10711349472 + 206.1855484372*t)
	Y3 += 0.00000022620*np.cos(0.51667171294 + 956.2891559706*t)
	Y3 += 0.00000024897*np.cos(5.10106981596 + 519.3960243561*t)
	Y3 += 0.00000015403*np.cos(3.36468316179 + 227.5261894396*t)
	Y3 += 0.00000020475*np.cos(2.34104128108 + 539.9859058331*t)
	Y3 += 0.00000015785*np.cos(4.86812169747 + 309.2783226558*t)
	Y3 += 0.00000017529*np.cos(4.59245273476 + 21.3406410024*t)
	Y3 += 0.00000014402*np.cos(5.77766242921 + 853.196381752*t)
	Y3 += 0.00000018490*np.cos(2.66058570316 + 639.897286314*t)
	Y3 += 0.00000011709*np.cos(2.47945340780 + 440.8252848776*t)
	Y3 += 0.00000011613*np.cos(4.69526972550 + 618.5566453116*t)
	Y3 += 0.00000010710*np.cos(3.98026635344 + 838.9692877504*t)
	Y3 += 0.00000010142*np.cos(3.88713064979 + 412.3710968744*t)
	Y3 += 0.00000009336*np.cos(3.27628408529 + 1038.0412891868*t)
	Y3 += 0.00000009452*np.cos(3.48158185106 + 1574.8458012822*t)
	Y3 += 0.00000007683*np.cos(4.47752898425 + 1258.4539316256*t)
	Y3 += 0.00000007886*np.cos(3.90593732757 + 831.8557407496*t)
	Y3 += 0.00000007729*np.cos(5.68110789292 + 316.3918696566*t)
	Y3 += 0.00000008180*np.cos(4.57699323815 + 302.164775655*t)
	Y3 += 0.00000008123*np.cos(2.34305389716 + 213.299095438*t)
	Y3 += 0.00000007696*np.cos(1.59660298447 + 742.9900605326*t)
	Y3 += 0.00000005946*np.cos(4.96977386305 + 2125.8774073792*t)
	Y3 += 0.00000003935*np.cos(4.46770507766 + 1265.5674786264*t)
	Y3 += 0.00000004139*np.cos(5.47876936143 + 124.433415221*t)
	Y3 += 0.00000003609*np.cos(1.88146800355 + 1485.9801210652*t)
	Y3 += 0.00000003020*np.cos(3.38305964289 + 1699.2792165032*t)
	Y3 += 0.00000002703*np.cos(5.95865724450 + 88.865680217*t)
	Y3 += 0.00000002627*np.cos(3.98517206294 + 1062.5633239269*t)
	Y3 += 0.00000003157*np.cos(2.49576350509 + 647.0108333148*t)
	Y3 += 0.00000002460*np.cos(3.67829773885 + 2648.454825473*t)
	Y3 += 0.00000002884*np.cos(2.40956971928 + 934.9485149682*t)
	Y3 += 0.00000002322*np.cos(4.05450701004 + 1603.2999892854*t)
	Y3 += 0.00000002359*np.cos(4.17350268052 + 337.732510659*t)
	Y3 += 0.00000002931*np.cos(2.89770912048 + 1471.7530270636*t)
	Y3 += 0.00000002268*np.cos(3.33219652413 + 721.6494195302*t)
	Y3 += 0.00000002859*np.cos(3.66153535064 + 1272.6810256272*t)
	Y3 += 0.00000002014*np.cos(3.64931827217 + 191.9584544356*t)
	Y3 += 0.00000002340*np.cos(5.54448900881 + 1368.660252845*t)
	Y3 += 0.00000002177*np.cos(4.07775459963 + 963.4027029714*t)
	Y3 += 0.00000001747*np.cos(4.72683114179 + 1685.0521225016*t)
	Y3 += 0.00000001640*np.cos(2.35287050678 + 750.1036075334*t)
	Y3 += 0.00000001734*np.cos(4.14601873919 + 1055.4497769261*t)
	Y3 += 0.00000001717*np.cos(2.19035940032 + 447.9388318784*t)
	Y3 += 0.00000001611*np.cos(3.71169443390 + 1788.1448967202*t)
	Y3 += 0.00000001784*np.cos(4.90110666417 + 526.5095713569*t)
	Y3 += 0.00000001784*np.cos(5.72276429138 + 532.8723588323*t)
	Y3 += 0.00000001811*np.cos(4.93808835269 + 860.3099287528*t)
	Y3 += 0.00000001431*np.cos(6.00191758769 + 81.7521332162*t)
	Y3 += 0.00000001354*np.cos(2.56987682828 + 1162.4747044078*t)
	Y3 += 0.00000001306*np.cos(0.17505316696 + 1382.8873468466*t)
	Y3 += 0.00000001341*np.cos(4.03349830399 + 1251.3403846248*t)
	Y3 += 0.00000001261*np.cos(3.24050324812 + 2104.5367663768*t)
	Y3 += 0.00000001700*np.cos(2.59885721626 + 1056.2005364515*t)
	Y3 += 0.00000001425*np.cos(5.76921390026 + 1361.5467058442*t)
	Y3 += 0.00000001117*np.cos(3.59296025283 + 1148.2476104062*t)
	Y3 += 0.00000001252*np.cos(4.12049487660 + 2111.6503133776*t)
	Y3 += 0.00000001061*np.cos(2.42113180503 + 1478.8665740644*t)
	Y3 += 0.00000000987*np.cos(5.56458244351 + 405.2575498736*t)
	Y3 += 0.00000001211*np.cos(2.84309753774 + 1069.6768709277*t)
	Y3 += 0.00000001118*np.cos(5.88365850057 + 611.4430983108*t)
	Y3 += 0.00000001093*np.cos(0.22239904129 + 1141.1340634054*t)
	Y3 += 0.00000001010*np.cos(5.13077933778 + 2097.423219376*t)
	Y3 += 0.00000001116*np.cos(0.00669283260 + 1884.124123938*t)
	Y3 += 0.00000001090*np.cos(2.69229040194 + 1464.6394800628*t)
	Y3 += 0.00000001013*np.cos(5.44748312429 + 1049.0869894507*t)
	Y3 += 0.00000000864*np.cos(3.81824814417 + 1567.7322542814*t)
	Y3 += 0.00000000882*np.cos(2.99288141364 + 234.6397364404*t)
	Y3 += 0.00000000835*np.cos(2.74175210945 + 2008.557539159*t)
	Y3 += 0.00000001043*np.cos(2.98280277812 + 1080.7225711916*t)
	Y3 += 0.00000000823*np.cos(2.03927945733 + 654.1243803156*t)
	Y3 += 0.00000000892*np.cos(4.64080401213 + 295.0512286542*t)
	Y3 += 0.00000000936*np.cos(4.23459087535 + 2207.6295405954*t)
	Y3 += 0.00000000957*np.cos(4.96721583110 + 1994.3304451574*t)
	Y3 += 0.00000000875*np.cos(1.72555259756 + 846.0828347512*t)
	Y3 += 0.00000000961*np.cos(4.80574091270 + 2317.8358618148*t)
	Y3 += 0.00000000831*np.cos(4.85908496939 + 2001.4439921582*t)
	Y3 += 0.00000000671*np.cos(3.09102992950 + 2420.9286360334*t)
	Y3 += 0.00000000670*np.cos(1.58976718357 + 2435.155730035*t)
	Y3 += 0.00000000825*np.cos(4.70761031951 + 1898.3512179396*t)
	Y3 += 0.00000000742*np.cos(5.32801449376 + 533.6231183577*t)
	Y3 += 0.00000000742*np.cos(5.29585646179 + 525.7588118315*t)
	Y3 += 0.00000000779*np.cos(4.43484800953 + 2214.7430875962*t)
	Y3 += 0.00000000735*np.cos(4.60695678136 + 2627.1141844706*t)
	Y3 += 0.00000000693*np.cos(0.82599527101 + 1692.1656695024*t)
	Y3 += 0.00000000678*np.cos(4.77937359684 + 824.7421937488*t)
	Y3 += 0.00000000571*np.cos(1.40932670441 + 2751.5475996916*t)
	Y3 += 0.00000000635*np.cos(3.61905584922 + 2840.4132799086*t)
	Y3 += 0.00000000513*np.cos(3.69018708990 + 1891.2376709388*t)
	Y3 += 0.00000000560*np.cos(3.36476362299 + 1905.4647649404*t)
	Y3 += 0.00000000572*np.cos(2.39114449243 + 1781.0313497194*t)
	Y3 += 0.00000000617*np.cos(4.55555334584 + 2634.2277314714*t)
	Y3 += 0.00000000623*np.cos(4.77211208531 + 2310.722314814*t)
	Y3 += 0.00000000466*np.cos(6.12814355088 + 1375.7737998458*t)
	Y3 += 0.00000000560*np.cos(3.98598190961 + 2524.021410252*t)
	Y3 += 0.00000000577*np.cos(3.52472118762 + 2015.6710861598*t)
	Y3 += 0.00000000523*np.cos(2.55250481076 + 1802.3719907218*t)
	Y3 += 0.00000000415*np.cos(4.68478558747 + 501.2367770914*t)
	Y3 += 0.00000000415*np.cos(5.93908536808 + 558.1451530978*t)
	return Y3*t*t*t




def Jupiter_Y4 (t): # 61 terms of order 4

	Y4 = 0.
	Y4 += 0.00001760963*np.cos(6.04159397216 + 522.5774180938*t)
	Y4 += 0.00001714409*np.cos(1.46206285710 + 536.8045120954*t)
	Y4 += 0.00000304745*np.cos(6.14052526925 + 515.463871093*t)
	Y4 += 0.00000215997*np.cos(1.34301856666 + 543.9180590962*t)
	Y4 += 0.00000127772*np.cos(2.25943354567 + 1066.49547719*t)
	Y4 += 0.00000081836*np.cos(2.84761173980 + 7.1135470008*t)
	Y4 += 0.00000055008*np.cos(0.23109269174 + 1059.3819301892*t)
	Y4 += 0.00000068446*np.cos(5.77736913573 + 1052.2683831884*t)
	Y4 += 0.00000070306
	Y4 += 0.00000050861*np.cos(2.90538809625 + 14.2270940016*t)
	Y4 += 0.00000023665*np.cos(5.19261861053 + 1045.1548361876*t)
	Y4 += 0.00000014962*np.cos(0.08526156115 + 508.3503240922*t)
	Y4 += 0.00000013643*np.cos(1.34331851905 + 1589.0728952838*t)
	Y4 += 0.00000010393*np.cos(1.88986884896 + 1073.6090241908*t)
	Y4 += 0.00000010849*np.cos(2.60493722297 + 529.6909650946*t)
	Y4 += 0.00000010460*np.cos(2.92640289661 + 1596.1864422846*t)
	Y4 += 0.00000010367*np.cos(3.84513840002 + 117.3198682202*t)
	Y4 += 0.00000007291*np.cos(1.00614499991 + 551.031606097*t)
	Y4 += 0.00000005794*np.cos(4.27528856669 + 95.9792272178*t)
	Y4 += 0.00000004975*np.cos(5.73943100781 + 110.2063212194*t)
	Y4 += 0.00000005282*np.cos(2.62080083504 + 330.6189636582*t)
	Y4 += 0.00000005258*np.cos(3.58591321573 + 942.062061969*t)
	Y4 += 0.00000005226*np.cos(2.63091128343 + 323.5054166574*t)
	Y4 += 0.00000004305*np.cos(4.90946848289 + 728.762966531*t)
	Y4 += 0.00000003712*np.cos(1.69419832547 + 220.4126424388*t)
	Y4 += 0.00000003429*np.cos(4.98831951816 + 625.6701923124*t)
	Y4 += 0.00000003596*np.cos(4.85294025637 + 735.8765135318*t)
	Y4 += 0.00000003529*np.cos(5.32266583780 + 199.0720014364*t)
	Y4 += 0.00000002860*np.cos(5.84683747296 + 1581.959348283*t)
	Y4 += 0.00000002704*np.cos(0.82647334354 + 440.8252848776*t)
	Y4 += 0.00000002588*np.cos(1.00323145819 + 1169.5882514086*t)
	Y4 += 0.00000003292*np.cos(1.69549352013 + 433.7117378768*t)
	Y4 += 0.00000002746*np.cos(2.32353716517 + 103.0927742186*t)
	Y4 += 0.00000002278*np.cos(6.27388903010 + 206.1855484372*t)
	Y4 += 0.00000002240*np.cos(5.51871835829 + 1155.361157407*t)
	Y4 += 0.00000001847*np.cos(1.65454592269 + 227.5261894396*t)
	Y4 += 0.00000002210*np.cos(6.25276142495 + 419.4846438752*t)
	Y4 += 0.00000001600*np.cos(1.76857620040 + 2118.7638603784*t)
	Y4 += 0.00000001435*np.cos(3.91857722340 + 426.598190876*t)
	Y4 += 0.00000001804*np.cos(4.09732369920 + 632.7837393132*t)
	Y4 += 0.00000001482*np.cos(0.02887555321 + 302.164775655*t)
	Y4 += 0.00000001400*np.cos(5.34809832156 + 1574.8458012822*t)
	Y4 += 0.00000001540*np.cos(0.75983380154 + 618.5566453116*t)
	Y4 += 0.00000001256*np.cos(0.33648936932 + 309.2783226558*t)
	Y4 += 0.00000001362*np.cos(5.14594131828 + 956.2891559706*t)
	Y4 += 0.00000001187*np.cos(4.16783920020 + 853.196381752*t)
	Y4 += 0.00000001507*np.cos(0.98837376639 + 639.897286314*t)
	Y4 += 0.00000001103*np.cos(5.60146041595 + 412.3710968744*t)
	Y4 += 0.00000001094*np.cos(0.12734228732 + 1258.4539316256*t)
	Y4 += 0.00000001142*np.cos(3.99469727044 + 949.1756089698*t)
	Y4 += 0.00000000852*np.cos(0.81910749925 + 831.8557407496*t)
	Y4 += 0.00000000868*np.cos(5.39175241124 + 1038.0412891868*t)
	Y4 += 0.00000000817*np.cos(2.44564373063 + 742.9900605326*t)
	Y4 += 0.00000000677*np.cos(5.88945439666 + 838.9692877504*t)
	Y4 += 0.00000000890*np.cos(1.13100927652 + 647.0108333148*t)
	Y4 += 0.00000000598*np.cos(2.46152435760 + 337.732510659*t)
	Y4 += 0.00000000556*np.cos(0.72453025284 + 1485.9801210652*t)
	Y4 += 0.00000000451*np.cos(5.32835796642 + 1471.7530270636*t)
	Y4 += 0.00000000498*np.cos(1.06608244072 + 1361.5467058442*t)
	Y4 += 0.00000000468*np.cos(5.07209650650 + 21.3406410024*t)
	Y4 += 0.00000000396*np.cos(2.33304510363 + 1603.2999892854*t)
	return Y4*t*t*t*t




def Jupiter_Y5 (t): # 11 terms of order 5

	Y5 = 0.
	Y5 += 0.00000131345*np.cos(1.64205558615 + 522.5774180938*t)
	Y5 += 0.00000126513*np.cos(5.87372673584 + 536.8045120954*t)
	Y5 += 0.00000048269*np.cos(1.62788936723 + 515.463871093*t)
	Y5 += 0.00000034034*np.cos(5.84040207007 + 543.9180590962*t)
	Y5 += 0.00000011212*np.cos(0.62260985921 + 1066.49547719*t)
	Y5 += 0.00000004060*np.cos(1.77167912883 + 1052.2683831884*t)
	Y5 += 0.00000001943*np.cos(0.18158253075 + 1073.6090241908*t)
	Y5 += 0.00000001786*np.cos(1.50021529990 + 1045.1548361876*t)
	Y5 += 0.00000000886*np.cos(1.68419633034 + 508.3503240922*t)
	Y5 += 0.00000000886*np.cos(2.65648931803 + 551.031606097*t)
	Y5 += 0.00000000467*np.cos(1.37841715169 + 1596.1864422846*t)
	return Y5*t*t*t*t*t




def Jupiter_Z0 (t): # 229 terms of order 0

	Z0 = 0.
	Z0 += 0.11811822789*np.cos(3.55844641987 + 529.6909650946*t)
	Z0 += 0.00857879296
	Z0 += 0.00286288759*np.cos(3.90812239092 + 1059.3819301892*t)
	Z0 += 0.00042347799*np.cos(3.60144639424 + 522.5774180938*t)
	Z0 += 0.00033263796*np.cos(0.30296971930 + 536.8045120954*t)
	Z0 += 0.00010406225*np.cos(4.25764578777 + 1589.0728952838*t)
	Z0 += 0.00007533929*np.cos(0.40110943079 + 213.299095438*t)
	Z0 += 0.00007444124*np.cos(5.24190365992 + 103.0927742186*t)
	Z0 += 0.00006931444*np.cos(1.74968626255 + 7.1135470008*t)
	Z0 += 0.00004791578*np.cos(4.58130928279 + 38.1330356378*t)
	Z0 += 0.00005167573*np.cos(1.62389733122 + 426.598190876*t)
	Z0 += 0.00003790459*np.cos(2.71176055906 + 110.2063212194*t)
	Z0 += 0.00003795419*np.cos(2.16708753358 + 632.7837393132*t)
	Z0 += 0.00002453014*np.cos(2.96909485714 + 1052.2683831884*t)
	Z0 += 0.00002459093*np.cos(2.99891481019 + 1162.4747044078*t)
	Z0 += 0.00002011946*np.cos(2.68549472534 + 419.4846438752*t)
	Z0 += 0.00002161688*np.cos(6.26716569996 + 846.0828347512*t)
	Z0 += 0.00001632059*np.cos(0.64194850627 + 1066.49547719*t)
	Z0 += 0.00001449341*np.cos(1.17106655090 + 949.1756089698*t)
	Z0 += 0.00001100709*np.cos(5.77066159190 + 74.7815985673*t)
	Z0 += 0.00000682966*np.cos(5.13874105936 + 316.3918696566*t)
	Z0 += 0.00000715105*np.cos(1.41095333569 + 323.5054166574*t)
	Z0 += 0.00000549163*np.cos(4.84156474999 + 742.9900605326*t)
	Z0 += 0.00000447403*np.cos(4.60746560365 + 2118.7638603784*t)
	Z0 += 0.00000543085*np.cos(3.69637762250 + 515.463871093*t)
	Z0 += 0.00000483852*np.cos(4.71827938260 + 735.8765135318*t)
	Z0 += 0.00000306262*np.cos(5.84003411417 + 206.1855484372*t)
	Z0 += 0.00000288704*np.cos(0.40266293090 + 525.7588118315*t)
	Z0 += 0.00000254697*np.cos(0.17978065932 + 543.9180590962*t)
	Z0 += 0.00000194948*np.cos(3.35375596127 + 1692.1656695024*t)
	Z0 += 0.00000253012*np.cos(3.57485368311 + 533.6231183577*t)
	Z0 += 0.00000196512*np.cos(2.65527067125 + 956.2891559706*t)
	Z0 += 0.00000154264*np.cos(1.47035156313 + 625.6701923124*t)
	Z0 += 0.00000145972*np.cos(5.96112903396 + 838.9692877504*t)
	Z0 += 0.00000162201*np.cos(3.12160031878 + 1581.959348283*t)
	Z0 += 0.00000140862*np.cos(0.37317672245 + 220.4126424388*t)
	Z0 += 0.00000135779*np.cos(2.23719078755 + 1478.8665740644*t)
	Z0 += 0.00000135220*np.cos(4.03191622905 + 1265.5674786264*t)
	Z0 += 0.00000118621*np.cos(6.19132554294 + 532.8723588323*t)
	Z0 += 0.00000121032*np.cos(4.06252466827 + 526.5095713569*t)
	Z0 += 0.00000113856*np.cos(0.34439775818 + 1375.7737998458*t)
	Z0 += 0.00000133515*np.cos(1.61217437939 + 14.2270940016*t)
	Z0 += 0.00000089331*np.cos(0.98707919437 + 1596.1864422846*t)
	Z0 += 0.00000091761*np.cos(5.29449897295 + 95.9792272178*t)
	Z0 += 0.00000071818*np.cos(2.59926571754 + 117.3198682202*t)
	Z0 += 0.00000064468*np.cos(0.90550872553 + 433.7117378768*t)
	Z0 += 0.00000064121*np.cos(4.63524391670 + 1368.660252845*t)
	Z0 += 0.00000060054*np.cos(1.05875226211 + 942.062061969*t)
	Z0 += 0.00000068585*np.cos(5.68334440823 + 639.897286314*t)
	Z0 += 0.00000054868*np.cos(6.14868344705 + 1169.5882514086*t)
	Z0 += 0.00000046682*np.cos(2.40308545145 + 853.196381752*t)
	Z0 += 0.00000040750*np.cos(5.07892020784 + 309.2783226558*t)
	Z0 += 0.00000054980*np.cos(2.72414041857 + 1045.1548361876*t)
	Z0 += 0.00000039937*np.cos(2.63014962920 + 380.12776796*t)
	Z0 += 0.00000034887*np.cos(3.06644858707 + 412.3710968744*t)
	Z0 += 0.00000026488*np.cos(3.34369636185 + 76.2660712756*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000024753*np.cos(4.09311535367 + 527.2432845398*t)
	Z0 += 0.00000021473*np.cos(5.68324848411 + 1272.6810256272*t)
	Z0 += 0.00000021259*np.cos(4.15648418623 + 1685.0521225016*t)
	Z0 += 0.00000021214*np.cos(4.95749714252 + 2648.454825473*t)
	Z0 += 0.00000019531*np.cos(3.58685387193 + 529.7391492044*t)
	Z0 += 0.00000024578*np.cos(6.16442414965 + 532.1386456494*t)
	Z0 += 0.00000021217*np.cos(4.46071227915 + 1155.361157407*t)
	Z0 += 0.00000021279*np.cos(3.98105217713 + 1795.258443721*t)
	Z0 += 0.00000019533*np.cos(0.38904271302 + 529.6427809848*t)
	Z0 += 0.00000016823*np.cos(2.78122865847 + 149.5631971346*t)
	Z0 += 0.00000019447*np.cos(1.27663598466 + 330.6189636582*t)
	Z0 += 0.00000015440*np.cos(0.72260027140 + 530.6541729411*t)
	Z0 += 0.00000014562*np.cos(5.50135998822 + 1471.7530270636*t)
	Z0 += 0.00000017624*np.cos(1.31667827871 + 3.9321532631*t)
	Z0 += 0.00000013309*np.cos(2.77897533854 + 2008.557539159*t)
	Z0 += 0.00000013206*np.cos(3.64976502017 + 2221.856634597*t)
	Z0 += 0.00000013142*np.cos(0.72687086889 + 1055.4497769261*t)
	Z0 += 0.00000015413*np.cos(4.31958059396 + 1063.3140834523*t)
	Z0 += 0.00000014193*np.cos(3.67387943991 + 2111.6503133776*t)
	Z0 += 0.00000012996*np.cos(1.31000927869 + 453.424893819*t)
	Z0 += 0.00000015482*np.cos(3.25291782438 + 528.7277572481*t)
	Z0 += 0.00000011369*np.cos(6.10506006408 + 199.0720014364*t)
	Z0 += 0.00000010389*np.cos(0.51378228980 + 1073.6090241908*t)
	Z0 += 0.00000012990*np.cos(1.87234255615 + 984.6003316219*t)
	Z0 += 0.00000008875*np.cos(0.13793367408 + 305.3461693927*t)
	Z0 += 0.00000007692*np.cos(5.08407965373 + 1788.1448967202*t)
	Z0 += 0.00000008714*np.cos(1.58825029218 + 3.1813937377*t)
	Z0 += 0.00000008040*np.cos(3.77010741170 + 73.297125859*t)
	Z0 += 0.00000007143*np.cos(4.01912438773 + 2001.4439921582*t)
	Z0 += 0.00000006752*np.cos(5.50960892986 + 1898.3512179396*t)
	Z0 += 0.00000007441*np.cos(1.30439352743 + 618.5566453116*t)
	Z0 += 0.00000006896*np.cos(1.74025919863 + 529.1697002328*t)
	Z0 += 0.00000007365*np.cos(3.26347830221 + 1485.9801210652*t)
	Z0 += 0.00000006518*np.cos(0.90320354569 + 1905.4647649404*t)
	Z0 += 0.00000008347*np.cos(5.96531853825 + 909.8187330546*t)
	Z0 += 0.00000007728*np.cos(4.61604781975 + 728.762966531*t)
	Z0 += 0.00000006887*np.cos(2.23549334986 + 530.2122299564*t)
	Z0 += 0.00000005783*np.cos(6.02338915633 + 831.8557407496*t)
	Z0 += 0.00000005519*np.cos(5.95463109628 + 1.4844727083*t)
	Z0 += 0.00000005788*np.cos(0.26042181508 + 1062.5633239269*t)
	Z0 += 0.00000005581*np.cos(6.17489228666 + 1258.4539316256*t)
	Z0 += 0.00000005154*np.cos(1.33592252764 + 2125.8774073792*t)
	Z0 += 0.00000004916*np.cos(0.18728472832 + 1699.2792165032*t)
	Z0 += 0.00000004649*np.cos(0.26984343469 + 227.5261894396*t)
	Z0 += 0.00000005480*np.cos(3.12818768952 + 604.4725636619*t)
	Z0 += 0.00000004967*np.cos(3.92882210242 + 508.3503240922*t)
	Z0 += 0.00000004994*np.cos(0.03902921434 + 1439.5096981492*t)
	Z0 += 0.00000005269*np.cos(4.06576160798 + 1056.2005364515*t)
	Z0 += 0.00000004221*np.cos(2.57304081485 + 99.1606209555*t)
	Z0 += 0.00000004005*np.cos(2.96062737592 + 526.7702037878*t)
	Z0 += 0.00000003856*np.cos(5.35048236882 + 11.0457002639*t)
	Z0 += 0.00000003959*np.cos(1.38163787157 + 532.6117264014*t)
	Z0 += 0.00000004554*np.cos(0.88779448962 + 490.3340891794*t)
	Z0 += 0.00000004844*np.cos(1.47818569722 + 454.9093665273*t)
	Z0 += 0.00000003683*np.cos(0.33555577415 + 528.9402055692*t)
	Z0 += 0.00000003681*np.cos(4.00539820601 + 530.44172462*t)
	Z0 += 0.00000004295*np.cos(3.45202038167 + 569.0478410098*t)
	Z0 += 0.00000003458*np.cos(4.40401766789 + 519.3960243561*t)
	Z0 += 0.00000003355*np.cos(4.80063248866 + 2104.5367663768*t)
	Z0 += 0.00000003535*np.cos(1.18645749024 + 525.4981794006*t)
	Z0 += 0.00000003477*np.cos(3.15607509055 + 533.8837507886*t)
	Z0 += 0.00000003219*np.cos(5.37130793285 + 2214.7430875962*t)
	Z0 += 0.00000004358*np.cos(2.16300555603 + 1021.2488945514*t)
	Z0 += 0.00000002697*np.cos(6.22459411775 + 539.9859058331*t)
	Z0 += 0.00000003143*np.cos(0.15836271478 + 750.1036075334*t)
	Z0 += 0.00000002916*np.cos(0.40322621398 + 224.3447957019*t)
	Z0 += 0.00000002649*np.cos(3.80434469443 + 2317.8358618148*t)
	Z0 += 0.00000002856*np.cos(0.29274516197 + 983.1158589136*t)
	Z0 += 0.00000002725*np.cos(0.64710955846 + 524.0618908021*t)
	Z0 += 0.00000002623*np.cos(0.25280896703 + 551.031606097*t)
	Z0 += 0.00000002685*np.cos(3.69478866795 + 535.3200393871*t)
	Z0 += 0.00000002939*np.cos(0.64629595693 + 540.7366653585*t)
	Z0 += 0.00000002398*np.cos(4.36615854926 + 2428.0421830342*t)
	Z0 += 0.00000002597*np.cos(1.15824869762 + 963.4027029714*t)
	Z0 += 0.00000002769*np.cos(0.20040217534 + 525.0250986486*t)
	Z0 += 0.00000002336*np.cos(3.71676131146 + 529.851023789*t)
	Z0 += 0.00000002336*np.cos(0.62392433691 + 529.5309064002*t)
	Z0 += 0.00000002491*np.cos(2.84297287947 + 1382.8873468466*t)
	Z0 += 0.00000002598*np.cos(4.13924061941 + 534.3568315406*t)
	Z0 += 0.00000002747*np.cos(1.76471074936 + 524.2743391232*t)
	Z0 += 0.00000002475*np.cos(0.99313692673 + 934.9485149682*t)
	Z0 += 0.00000002704*np.cos(2.57406093768 + 535.107591066*t)
	Z0 += 0.00000002302*np.cos(5.84295144929 + 1148.2476104062*t)
	Z0 += 0.00000002068*np.cos(5.96196623799 + 440.8252848776*t)
	Z0 += 0.00000002012*np.cos(4.95946680265 + 1361.5467058442*t)
	Z0 += 0.00000001987*np.cos(0.18375525793 + 1802.3719907218*t)
	Z0 += 0.00000001934*np.cos(2.82066156035 + 835.0371344873*t)
	Z0 += 0.00000002147*np.cos(5.96724060411 + 1891.2376709388*t)
	Z0 += 0.00000001940*np.cos(3.63687343812 + 2324.9494088156*t)
	Z0 += 0.00000001860*np.cos(5.24230405559 + 2531.1349572528*t)
	Z0 += 0.00000001707*np.cos(5.38883058569 + 302.164775655*t)
	Z0 += 0.00000002152*np.cos(1.74557444220 + 21.3406410024*t)
	Z0 += 0.00000001613*np.cos(3.45966511571 + 529.4785167735*t)
	Z0 += 0.00000001613*np.cos(0.88102053266 + 529.9034134157*t)
	Z0 += 0.00000002134*np.cos(2.79657990895 + 35.4247226521*t)
	Z0 += 0.00000001566*np.cos(1.99768150464 + 202.2533951741*t)
	Z0 += 0.00000001501*np.cos(2.66136644012 + 415.5524906121*t)
	Z0 += 0.00000001593*np.cos(1.37312370449 + 1574.8458012822*t)
	Z0 += 0.00000001510*np.cos(3.41611736454 + 518.6452648307*t)
	Z0 += 0.00000001579*np.cos(3.96836848379 + 2420.9286360334*t)
	Z0 += 0.00000001630*np.cos(1.31973482281 + 39.3568759152*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001598*np.cos(2.53043088824 + 511.5317178299*t)
	Z0 += 0.00000001841*np.cos(5.72475961436 + 531.1754378029*t)
	Z0 += 0.00000001537*np.cos(1.84394223501 + 547.8502123593*t)
	Z0 += 0.00000001771*np.cos(4.87234280655 + 528.2064923863*t)
	Z0 += 0.00000001656*np.cos(1.27834742762 + 173.9422195228*t)
	Z0 += 0.00000001242*np.cos(1.65064670901 + 643.8294395771*t)
	Z0 += 0.00000001236*np.cos(5.41985106155 + 107.0249274817*t)
	Z0 += 0.00000001165*np.cos(1.48429677606 + 960.2213092337*t)
	Z0 += 0.00000001166*np.cos(5.12888892088 + 1048.3362299253*t)
	Z0 += 0.00000001153*np.cos(4.78828764413 + 514.7131115676*t)
	Z0 += 0.00000001153*np.cos(4.22743390789 + 2744.4340526908*t)
	Z0 += 0.00000001478*np.cos(3.73912254261 + 230.5645708254*t)
	Z0 += 0.00000001137*np.cos(6.15183461939 + 2.9689454166*t)
	Z0 += 0.00000001121*np.cos(6.27688038656 + 387.2413149608*t)
	Z0 += 0.00000001112*np.cos(5.83569926578 + 544.6688186216*t)
	Z0 += 0.00000001170*np.cos(1.05508911315 + 1512.8068240082*t)
	Z0 += 0.00000001113*np.cos(5.74217831509 + 3480.3105662226*t)
	Z0 += 0.00000001507*np.cos(4.16985097397 + 1364.7280995819*t)
	Z0 += 0.00000001120*np.cos(5.02238271412 + 1464.6394800628*t)
	Z0 += 0.00000001232*np.cos(2.83088412944 + 2538.2485042536*t)
	Z0 += 0.00000001179*np.cos(4.62538441124 + 1056.9342496344*t)
	Z0 += 0.00000001278*np.cos(3.86396842379 + 92.0470739547*t)
	Z0 += 0.00000001094*np.cos(2.73378417498 + 299.1263942692*t)
	Z0 += 0.00000001345*np.cos(0.63863230611 + 1061.829610744*t)
	Z0 += 0.00000000977*np.cos(3.50831165685 + 2.4476805548*t)
	Z0 += 0.00000001323*np.cos(4.03638019689 + 494.2662424425*t)
	Z0 += 0.00000001310*np.cos(5.45458264580 + 1057.8974574809*t)
	Z0 += 0.00000000966*np.cos(3.51363341772 + 2634.2277314714*t)
	Z0 += 0.00000001053*np.cos(5.49394122920 + 3178.1457905676*t)
	Z0 += 0.00000000984*np.cos(4.22960042766 + 430.5303441391*t)
	Z0 += 0.00000000937*np.cos(3.77590974564 + 2641.3412784722*t)
	Z0 += 0.00000000932*np.cos(4.11879245377 + 1059.430114299*t)
	Z0 += 0.00000000941*np.cos(0.30660455816 + 70.8494453042*t)
	Z0 += 0.00000000925*np.cos(1.29091785470 + 2435.155730035*t)
	Z0 += 0.00000000950*np.cos(3.88567620136 + 3377.217792004*t)
	Z0 += 0.00000001051*np.cos(5.62777473038 + 2207.6295405954*t)
	Z0 += 0.00000001020*np.cos(1.77520625500 + 312.4597163935*t)
	Z0 += 0.00000001031*np.cos(6.05389751096 + 647.0108333148*t)
	Z0 += 0.00000000946*np.cos(4.13718116942 + 1677.9385755008*t)
	Z0 += 0.00000001080*np.cos(2.32932073464 + 106.2741679563*t)
	Z0 += 0.00000000882*np.cos(0.48413591726 + 209.3669421749*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000001086*np.cos(2.80157071056 + 1038.0412891868*t)
	Z0 += 0.00000001158*np.cos(0.32499630540 + 565.1156877467*t)
	Z0 += 0.00000001098*np.cos(1.00937080256 + 523.5406259403*t)
	Z0 += 0.00000000932*np.cos(0.92098132614 + 1059.3337460794*t)
	Z0 += 0.00000000821*np.cos(3.41471589329 + 2950.619601128*t)
	Z0 += 0.00000000929*np.cos(2.30521635468 + 1514.2912967165*t)
	Z0 += 0.00000000915*np.cos(1.48306891526 + 10.2949407385*t)
	Z0 += 0.00000000911*np.cos(3.32547809355 + 18.1592472647*t)
	Z0 += 0.00000000786*np.cos(2.82286526802 + 1134.1635287565*t)
	Z0 += 0.00000000954*np.cos(0.13401891198 + 3906.9087570986*t)
	Z0 += 0.00000000994*np.cos(3.33159283750 + 535.8413042489*t)
	Z0 += 0.00000000792*np.cos(5.10203109941 + 2524.021410252*t)
	Z0 += 0.00000000764*np.cos(5.13454347326 + 26087.9031415742*t)
	Z0 += 0.00000000824*np.cos(1.74472748730 + 529.9515975255*t)
	Z0 += 0.00000000824*np.cos(2.59595816107 + 529.4303326637*t)
	Z0 += 0.00000000762*np.cos(4.30564108086 + 672.1406152284*t)
	Z0 += 0.00000000872*np.cos(5.03498959444 + 679.2541622292*t)
	Z0 += 0.00000000839*np.cos(3.34536065236 + 124.433415221*t)
	Z0 += 0.00000000927*np.cos(4.91765336511 + 1593.0050485469*t)
	Z0 += 0.00000000826*np.cos(5.05738343335 + 2847.5268269094*t)
	Z0 += 0.00000000864*np.cos(2.92013522974 + 148.0787244263*t)
	Z0 += 0.00000000738*np.cos(0.70435921398 + 522.529233984*t)
	Z0 += 0.00000000846*np.cos(3.60649450344 + 217.2312487011*t)
	Z0 += 0.00000000779*np.cos(3.77257775192 + 63.7358983034*t)
	Z0 += 0.00000000687*np.cos(2.88181717922 + 71.8126531507*t)
	Z0 += 0.00000000459*np.cos(3.95268976842 + 77.7505439839*t)
	Z0 += 0.00000000385*np.cos(0.88914902748 + 151.0476698429*t)
	return Z0




def Jupiter_Z1 (t): # 110 terms of order 1

	Z1 = 0.
	Z1 += 0.00406683941*np.cos(1.52699356726 + 529.6909650946*t)
	Z1 += 0.00020287968*np.cos(2.59878263946 + 1059.3819301892*t)
	Z1 += 0.00014411207*np.cos(4.85400100506 + 536.8045120954*t)
	Z1 += 0.00015608009
	Z1 += 0.00012718197*np.cos(5.45536889012 + 522.5774180938*t)
	Z1 += 0.00002105152*np.cos(0.09490717318 + 7.1135470008*t)
	Z1 += 0.00001229252*np.cos(3.14222500244 + 1589.0728952838*t)
	Z1 += 0.00000759894*np.cos(5.27868424641 + 1066.49547719*t)
	Z1 += 0.00000678188*np.cos(4.74893679053 + 1052.2683831884*t)
	Z1 += 0.00000597518*np.cos(1.04783160594 + 110.2063212194*t)
	Z1 += 0.00000569853*np.cos(1.09361359936 + 103.0927742186*t)
	Z1 += 0.00000462322*np.cos(1.82268245458 + 213.299095438*t)
	Z1 += 0.00000430869*np.cos(0.64975951302 + 419.4846438752*t)
	Z1 += 0.00000448049*np.cos(0.50494888408 + 426.598190876*t)
	Z1 += 0.00000351273*np.cos(5.47691402903 + 515.463871093*t)
	Z1 += 0.00000345659*np.cos(2.81234743407 + 632.7837393132*t)
	Z1 += 0.00000211150*np.cos(4.74645680584 + 543.9180590962*t)
	Z1 += 0.00000180138*np.cos(3.91036257165 + 735.8765135318*t)
	Z1 += 0.00000164622*np.cos(2.83484073650 + 949.1756089698*t)
	Z1 += 0.00000196264*np.cos(6.05238005156 + 323.5054166574*t)
	Z1 += 0.00000166199*np.cos(5.96632686544 + 316.3918696566*t)
	Z1 += 0.00000104268*np.cos(1.13013960316 + 1162.4747044078*t)
	Z1 += 0.00000099286*np.cos(1.54499752918 + 206.1855484372*t)
	Z1 += 0.00000078677*np.cos(4.62142072971 + 525.7588118315*t)
	Z1 += 0.00000079813*np.cos(4.38404909104 + 532.8723588323*t)
	Z1 += 0.00000074155*np.cos(5.89524367925 + 526.5095713569*t)
	Z1 += 0.00000093081*np.cos(6.22107140582 + 14.2270940016*t)
	Z1 += 0.00000074957*np.cos(3.57596458602 + 2118.7638603784*t)
	Z1 += 0.00000063605*np.cos(5.76632311254 + 533.6231183577*t)
	Z1 += 0.00000053371*np.cos(4.98736101641 + 220.4126424388*t)
	Z1 += 0.00000051134*np.cos(1.68571094945 + 956.2891559706*t)
	Z1 += 0.00000044815*np.cos(5.69775266875 + 1596.1864422846*t)
	Z1 += 0.00000040568*np.cos(3.71961451563 + 742.9900605326*t)
	Z1 += 0.00000041113*np.cos(0.82174411575 + 95.9792272178*t)
	Z1 += 0.00000037171*np.cos(1.10942550189 + 846.0828347512*t)
	Z1 += 0.00000038912*np.cos(0.92774931850 + 117.3198682202*t)
	Z1 += 0.00000036944*np.cos(3.58385604224 + 625.6701923124*t)
	Z1 += 0.00000035847*np.cos(4.01453279444 + 639.897286314*t)
	Z1 += 0.00000035880*np.cos(4.44075645073 + 1045.1548361876*t)
	Z1 += 0.00000027900*np.cos(3.12885180423 + 74.7815985673*t)
	Z1 += 0.00000028034*np.cos(5.49280837793 + 433.7117378768*t)
	Z1 += 0.00000035616*np.cos(4.87718639945 + 1581.959348283*t)
	Z1 += 0.00000022870*np.cos(2.89593409105 + 942.062061969*t)
	Z1 += 0.00000022917*np.cos(4.39232470827 + 1169.5882514086*t)
	Z1 += 0.00000016848*np.cos(0.84344373522 + 853.196381752*t)
	Z1 += 0.00000012828*np.cos(5.65999760985 + 1265.5674786264*t)
	Z1 += 0.00000014203*np.cos(2.02042807659 + 1692.1656695024*t)
	Z1 += 0.00000013842*np.cos(4.96847316294 + 1155.361157407*t)
	Z1 += 0.00000011455*np.cos(1.71478767851 + 309.2783226558*t)
	Z1 += 0.00000013119*np.cos(5.89605622820 + 330.6189636582*t)
	Z1 += 0.00000008950*np.cos(5.12739425794 + 1073.6090241908*t)
	Z1 += 0.00000009033*np.cos(5.29194839345 + 412.3710968744*t)
	Z1 += 0.00000008110*np.cos(1.63213742325 + 199.0720014364*t)
	Z1 += 0.00000009695*np.cos(1.28201643020 + 1478.8665740644*t)
	Z1 += 0.00000008010*np.cos(5.28413417446 + 38.1330356378*t)
	Z1 += 0.00000007507*np.cos(5.63314626529 + 1375.7737998458*t)
	Z1 += 0.00000005683*np.cos(5.64842716451 + 508.3503240922*t)
	Z1 += 0.00000005065*np.cos(4.61872836521 + 1272.6810256272*t)
	Z1 += 0.00000005122*np.cos(0.78055029480 + 838.9692877504*t)
	Z1 += 0.00000004633*np.cos(3.96963286081 + 2648.454825473*t)
	Z1 += 0.00000004955*np.cos(6.23978525760 + 3.1813937377*t)
	Z1 += 0.00000004144*np.cos(0.27205253609 + 1795.258443721*t)
	Z1 += 0.00000003890*np.cos(4.99485656209 + 1062.5633239269*t)
	Z1 += 0.00000003777*np.cos(3.05073160311 + 618.5566453116*t)
	Z1 += 0.00000003628*np.cos(4.91071799608 + 227.5261894396*t)
	Z1 += 0.00000003598*np.cos(6.16903865449 + 519.3960243561*t)
	Z1 += 0.00000004161*np.cos(4.74241799712 + 728.762966531*t)
	Z1 += 0.00000003341*np.cos(5.15353140865 + 1055.4497769261*t)
	Z1 += 0.00000003019*np.cos(4.80531534819 + 551.031606097*t)
	Z1 += 0.00000002954*np.cos(0.27791550688 + 1063.3140834523*t)
	Z1 += 0.00000002873*np.cos(2.50045321169 + 1485.9801210652*t)
	Z1 += 0.00000002799*np.cos(4.45717734612 + 539.9859058331*t)
	Z1 += 0.00000003281*np.cos(5.86589845886 + 1056.2005364515*t)
	Z1 += 0.00000002592*np.cos(0.03988488946 + 2125.8774073792*t)
	Z1 += 0.00000003120*np.cos(2.61410361290 + 1368.660252845*t)
	Z1 += 0.00000002118*np.cos(4.81552201820 + 1699.2792165032*t)
	Z1 += 0.00000002047*np.cos(4.14126423279 + 1574.8458012822*t)
	Z1 += 0.00000002773*np.cos(2.95912332296 + 3.9321532631*t)
	Z1 += 0.00000002550*np.cos(5.59868792884 + 2111.6503133776*t)
	Z1 += 0.00000001931*np.cos(4.17348249997 + 440.8252848776*t)
	Z1 += 0.00000002088*np.cos(3.37185008818 + 1685.0521225016*t)
	Z1 += 0.00000002021*np.cos(1.47677585678 + 831.8557407496*t)
	Z1 += 0.00000002294*np.cos(0.03769707946 + 21.3406410024*t)
	Z1 += 0.00000001749*np.cos(1.95113506965 + 525.0250986486*t)
	Z1 += 0.00000001626*np.cos(2.21953197234 + 302.164775655*t)
	Z1 += 0.00000001673*np.cos(2.38708525663 + 534.3568315406*t)
	Z1 += 0.00000001462*np.cos(6.17532184467 + 2428.0421830342*t)
	Z1 += 0.00000001518*np.cos(2.54384408415 + 2221.856634597*t)
	Z1 += 0.00000001249*np.cos(0.10131731167 + 1258.4539316256*t)
	Z1 += 0.00000001162*np.cos(1.51415738925 + 2008.557539159*t)
	Z1 += 0.00000001355*np.cos(4.56146817733 + 750.1036075334*t)
	Z1 += 0.00000001038*np.cos(5.63991949724 + 524.2743391232*t)
	Z1 += 0.00000001161*np.cos(4.51697446536 + 1038.0412891868*t)
	Z1 += 0.00000001024*np.cos(4.98395147244 + 535.107591066*t)
	Z1 += 0.00000001029*np.cos(5.86675536556 + 149.5631971346*t)
	Z1 += 0.00000000961*np.cos(2.00070359963 + 1898.3512179396*t)
	Z1 += 0.00000001025*np.cos(2.87748450885 + 2317.8358618148*t)
	Z1 += 0.00000000947*np.cos(1.74384304582 + 2214.7430875962*t)
	Z1 += 0.00000000946*np.cos(1.42332597256 + 1382.8873468466*t)
	Z1 += 0.00000001045*np.cos(3.24587962557 + 2001.4439921582*t)
	Z1 += 0.00000000849*np.cos(4.41162044978 + 511.5317178299*t)
	Z1 += 0.00000000817*np.cos(6.22659623699 + 547.8502123593*t)
	Z1 += 0.00000000904*np.cos(0.20024344532 + 1905.4647649404*t)
	Z1 += 0.00000000788*np.cos(5.94278119191 + 10.2949407385*t)
	Z1 += 0.00000000825*np.cos(4.68155089578 + 526.7702037878*t)
	Z1 += 0.00000000819*np.cos(5.94254789616 + 532.6117264014*t)
	Z1 += 0.00000000692*np.cos(0.27213238919 + 6283.0758499914*t)
	Z1 += 0.00000000533*np.cos(2.34579176940 + 76.2660712756*t)
	Z1 += 0.00000000509*np.cos(5.03126544101 + 10213.285546211*t)
	Z1 += 0.00000000403*np.cos(1.25691345472 + 36.6485629295*t)
	return Z1*t




def Jupiter_Z2 (t): # 66 terms of order 2

	Z2 = 0.
	Z2 += 0.00028608011*np.cos(3.01374191263 + 529.6909650946*t)
	Z2 += 0.00003111783*np.cos(3.13228615794 + 536.8045120954*t)
	Z2 += 0.00002377492*np.cos(0.95574455230 + 522.5774180938*t)
	Z2 += 0.00001308861*np.cos(2.05263727229 + 1059.3819301892*t)
	Z2 += 0.00000897079
	Z2 += 0.00000306143*np.cos(4.64177928721 + 7.1135470008*t)
	Z2 += 0.00000178732*np.cos(3.65484247255 + 1066.49547719*t)
	Z2 += 0.00000123164*np.cos(0.96219856589 + 515.463871093*t)
	Z2 += 0.00000111257*np.cos(0.51687136283 + 1052.2683831884*t)
	Z2 += 0.00000116559*np.cos(2.23097397584 + 1589.0728952838*t)
	Z2 += 0.00000089170*np.cos(3.02653528025 + 543.9180590962*t)
	Z2 += 0.00000042084*np.cos(5.42941345902 + 110.2063212194*t)
	Z2 += 0.00000035844*np.cos(3.22464435305 + 213.299095438*t)
	Z2 += 0.00000032596*np.cos(4.52794508192 + 14.2270940016*t)
	Z2 += 0.00000027447*np.cos(4.35647748680 + 323.5054166574*t)
	Z2 += 0.00000024417*np.cos(5.40925475546 + 103.0927742186*t)
	Z2 += 0.00000020399*np.cos(5.46489631572 + 426.598190876*t)
	Z2 += 0.00000021934*np.cos(2.60158474920 + 532.8723588323*t)
	Z2 += 0.00000018014*np.cos(1.44456471821 + 526.5095713569*t)
	Z2 += 0.00000016331*np.cos(4.92014199019 + 632.7837393132*t)
	Z2 += 0.00000013483*np.cos(6.04258588458 + 419.4846438752*t)
	Z2 += 0.00000013490*np.cos(2.61548577535 + 525.7588118315*t)
	Z2 += 0.00000011558*np.cos(4.14129213477 + 1596.1864422846*t)
	Z2 += 0.00000012105*np.cos(6.21535970722 + 1045.1548361876*t)
	Z2 += 0.00000010929*np.cos(3.31243498718 + 220.4126424388*t)
	Z2 += 0.00000009764*np.cos(2.62828951681 + 95.9792272178*t)
	Z2 += 0.00000010309*np.cos(1.56760288377 + 533.6231183577*t)
	Z2 += 0.00000010688*np.cos(5.53484540215 + 117.3198682202*t)
	Z2 += 0.00000009544*np.cos(2.11960157839 + 316.3918696566*t)
	Z2 += 0.00000009113*np.cos(2.21738563300 + 1162.4747044078*t)
	Z2 += 0.00000010158*np.cos(5.26135095990 + 949.1756089698*t)
	Z2 += 0.00000009129*np.cos(2.58339505278 + 2118.7638603784*t)
	Z2 += 0.00000007323*np.cos(0.32441886121 + 956.2891559706*t)
	Z2 += 0.00000008542*np.cos(6.13497387295 + 735.8765135318*t)
	Z2 += 0.00000006950*np.cos(5.45832467382 + 625.6701923124*t)
	Z2 += 0.00000006236*np.cos(3.80039032040 + 433.7117378768*t)
	Z2 += 0.00000005246*np.cos(0.63975690502 + 1581.959348283*t)
	Z2 += 0.00000005007*np.cos(2.65770851102 + 1169.5882514086*t)
	Z2 += 0.00000004748*np.cos(4.70977300192 + 942.062061969*t)
	Z2 += 0.00000005205*np.cos(2.33054025289 + 639.897286314*t)
	Z2 += 0.00000003581*np.cos(3.61699400753 + 1073.6090241908*t)
	Z2 += 0.00000003300*np.cos(2.99354463879 + 206.1855484372*t)
	Z2 += 0.00000003354*np.cos(5.52814929602 + 853.196381752*t)
	Z2 += 0.00000003068*np.cos(1.29971318791 + 508.3503240922*t)
	Z2 += 0.00000003814*np.cos(4.40868990095 + 330.6189636582*t)
	Z2 += 0.00000002970*np.cos(3.42713067437 + 199.0720014364*t)
	Z2 += 0.00000003018*np.cos(0.40383801301 + 1155.361157407*t)
	Z2 += 0.00000002188*np.cos(3.84244897855 + 309.2783226558*t)
	Z2 += 0.00000002693*np.cos(6.25283437603 + 728.762966531*t)
	Z2 += 0.00000002334*np.cos(1.74516467151 + 412.3710968744*t)
	Z2 += 0.00000001672*np.cos(3.04994797602 + 551.031606097*t)
	Z2 += 0.00000001808*np.cos(3.23458865988 + 1265.5674786264*t)
	Z2 += 0.00000001903*np.cos(1.68895713870 + 519.3960243561*t)
	Z2 += 0.00000001396*np.cos(4.20754455917 + 846.0828347512*t)
	Z2 += 0.00000001325*np.cos(3.40846107083 + 227.5261894396*t)
	Z2 += 0.00000001511*np.cos(2.62531230776 + 539.9859058331*t)
	Z2 += 0.00000001238*np.cos(1.09267310870 + 838.9692877504*t)
	Z2 += 0.00000001248*np.cos(4.45611338081 + 3.1813937377*t)
	Z2 += 0.00000001247*np.cos(4.60205535291 + 21.3406410024*t)
	Z2 += 0.00000001093*np.cos(3.31818308830 + 1062.5633239269*t)
	Z2 += 0.00000001010*np.cos(1.66232831337 + 1692.1656695024*t)
	Z2 += 0.00000000983*np.cos(4.31861095568 + 742.9900605326*t)
	Z2 += 0.00000000852*np.cos(2.67893555103 + 440.8252848776*t)
	Z2 += 0.00000000831*np.cos(1.37955361260 + 1258.4539316256*t)
	Z2 += 0.00000000769*np.cos(2.37777541795 + 1485.9801210652*t)
	Z2 += 0.00000000641*np.cos(4.89317483950 + 74.7815985673*t)
	return Z2*t*t




def Jupiter_Z3 (t): # 30 terms of order 3

	Z3 = 0.
	Z3 += 0.00000963435*np.cos(4.79228412032 + 529.6909650946*t)
	Z3 += 0.00000442821*np.cos(1.39969952998 + 536.8045120954*t)
	Z3 += 0.00000295319*np.cos(2.81281406373 + 522.5774180938*t)
	Z3 += 0.00000111714
	Z3 += 0.00000050665*np.cos(6.26062465904 + 1059.3819301892*t)
	Z3 += 0.00000029100*np.cos(2.75235252681 + 515.463871093*t)
	Z3 += 0.00000028110*np.cos(2.04383406271 + 1066.49547719*t)
	Z3 += 0.00000029345*np.cos(2.85188491466 + 7.1135470008*t)
	Z3 += 0.00000025369*np.cos(1.29175228030 + 543.9180590962*t)
	Z3 += 0.00000013030*np.cos(2.54792743567 + 1052.2683831884*t)
	Z3 += 0.00000007830*np.cos(2.83309311484 + 14.2270940016*t)
	Z3 += 0.00000007174*np.cos(0.86931032544 + 1589.0728952838*t)
	Z3 += 0.00000003080*np.cos(1.89107497845 + 1045.1548361876*t)
	Z3 += 0.00000002863*np.cos(3.43291886790 + 110.2063212194*t)
	Z3 += 0.00000002167*np.cos(4.04923561612 + 419.4846438752*t)
	Z3 += 0.00000001750*np.cos(2.74912623517 + 1596.1864422846*t)
	Z3 += 0.00000001927*np.cos(2.58072071303 + 323.5054166574*t)
	Z3 += 0.00000001757*np.cos(3.91881398005 + 117.3198682202*t)
	Z3 += 0.00000001302*np.cos(4.84806136860 + 213.299095438*t)
	Z3 += 0.00000001300*np.cos(3.01246535740 + 508.3503240922*t)
	Z3 += 0.00000001203*np.cos(4.30217253511 + 95.9792272178*t)
	Z3 += 0.00000001186*np.cos(6.26643492221 + 632.7837393132*t)
	Z3 += 0.00000001194*np.cos(1.76585816710 + 735.8765135318*t)
	Z3 += 0.00000001052*np.cos(2.00792098419 + 1073.6090241908*t)
	Z3 += 0.00000001045*np.cos(0.09455185496 + 639.897286314*t)
	Z3 += 0.00000001131*np.cos(5.41393274707 + 103.0927742186*t)
	Z3 += 0.00000001364*np.cos(2.43564490971 + 206.1855484372*t)
	Z3 += 0.00000000922*np.cos(0.27894425979 + 942.062061969*t)
	Z3 += 0.00000000797*np.cos(1.55035889004 + 625.6701923124*t)
	Z3 += 0.00000000716*np.cos(1.50799790954 + 220.4126424388*t)
	return Z3*t*t*t




def Jupiter_Z4 (t): # 10 terms of order 4

	Z4 = 0.
	Z4 += 0.00000046366*np.cos(5.93695398581 + 536.8045120954*t)
	Z4 += 0.00000027761*np.cos(4.80287441467 + 522.5774180938*t)
	Z4 += 0.00000005858*np.cos(4.53622024534 + 515.463871093*t)
	Z4 += 0.00000005556*np.cos(5.81670859023 + 543.9180590962*t)
	Z4 += 0.00000004183*np.cos(1.50894812038 + 529.6909650946*t)
	Z4 += 0.00000002638*np.cos(0.48959557023 + 1066.49547719*t)
	Z4 += 0.00000001614*np.cos(0.90503544737 + 7.1135470008*t)
	Z4 += 0.00000001549*np.cos(4.58690059715 + 1059.3819301892*t)
	Z4 += 0.00000001490*np.cos(4.51390841743 + 1052.2683831884*t)
	Z4 += 0.00000001130*np.cos(1.32994670268 + 14.2270940016*t)
	return Z4*t*t*t*t




def Jupiter_Z5 (t): # 3 terms of order 5

	Z5 = 0.
	Z5 += 0.00000003446*np.cos(4.10413626462 + 536.8045120954*t)
	Z5 += 0.00000002243*np.cos(0.82614663721 + 522.5774180938*t)
	Z5 += 0.00000001081*np.cos(0.05498457769 + 515.463871093*t)
	return Z5*t*t*t*t*t






def Saturn_X0 (t): # 1651 terms of order 0

	X0 = 0.
	X0 += 9.51366533422*np.cos(0.87441380650 + 213.299095438*t)
	X0 += 0.26404799161*np.cos(0.12391580771 + 426.598190876*t)
	X0 += 0.06758489145*np.cos(4.16767544586 + 206.1855484372*t)
	X0 += 0.06622371284*np.cos(0.75094738122 + 220.4126424388*t)
	X0 += 0.04274172066
	X0 += 0.02335961354*np.cos(2.02227905783 + 7.1135470008*t)
	X0 += 0.01255113414*np.cos(2.17347170552 + 110.2063212194*t)
	X0 += 0.01115372225*np.cos(3.15690865182 + 419.4846438752*t)
	X0 += 0.01097374519*np.cos(5.65753938643 + 639.897286314*t)
	X0 += 0.00716112591*np.cos(2.71151505735 + 316.3918696566*t)
	X0 += 0.00509529043*np.cos(4.95879639669 + 103.0927742186*t)
	X0 += 0.00372789068*np.cos(0.00137750888 + 433.7117378768*t)
	X0 += 0.00149659945*np.cos(2.17071100189 + 38.1330356378*t)
	X0 += 0.00097835080*np.cos(1.01502366873 + 323.5054166574*t)
	X0 += 0.00083256484*np.cos(3.06289145446 + 529.6909650946*t)
	X0 += 0.00080605800*np.cos(5.62066478674 + 11.0457002639*t)
	X0 += 0.00083758534*np.cos(0.62038891091 + 227.5261894396*t)
	X0 += 0.00074267111*np.cos(2.38212789877 + 632.7837393132*t)
	X0 += 0.00070199356*np.cos(0.88789759781 + 209.3669421749*t)
	X0 += 0.00068836111*np.cos(4.01788121810 + 217.2312487011*t)
	X0 += 0.00065601455*np.cos(2.69726244676 + 202.2533951741*t)
	X0 += 0.00058306839*np.cos(2.16048044319 + 224.3447957019*t)
	X0 += 0.00054006503*np.cos(4.90926255487 + 853.196381752*t)
	X0 += 0.00058995712*np.cos(2.33042838103 + 74.7815985673*t)
	X0 += 0.00045542953*np.cos(1.88235196400 + 14.2270940016*t)
	X0 += 0.00038334470*np.cos(4.39817733456 + 199.0720014364*t)
	X0 += 0.00044537354*np.cos(5.60825622208 + 63.7358983034*t)
	X0 += 0.00025158000*np.cos(0.37800583496 + 216.4804891757*t)
	X0 += 0.00024547484*np.cos(4.53150636994 + 210.1177017003*t)
	X0 += 0.00024669930*np.cos(5.60389432714 + 415.5524906121*t)
	X0 += 0.00025485006*np.cos(1.63932503888 + 117.3198682202*t)
	X0 += 0.00024058786*np.cos(5.85571939691 + 522.5774180938*t)
	X0 += 0.00031244965*np.cos(4.62930311280 + 735.8765135318*t)
	X0 += 0.00023365871*np.cos(5.53492454782 + 647.0108333148*t)
	X0 += 0.00023237024*np.cos(0.10474288122 + 149.5631971346*t)
	X0 += 0.00014727416*np.cos(4.67982458404 + 277.0349937414*t)
	X0 += 0.00009943629*np.cos(0.84628173449 + 3.9321532631*t)
	X0 += 0.00012389760*np.cos(4.19747910039 + 490.3340891794*t)
	X0 += 0.00012023054*np.cos(5.66372239094 + 351.8165923087*t)
	X0 += 0.00008207194*np.cos(2.47939755305 + 742.9900605326*t)
	X0 += 0.00009112965*np.cos(4.32466741251 + 1052.2683831884*t)
	X0 += 0.00006717261*np.cos(5.51887462475 + 838.9692877504*t)
	X0 += 0.00007155271*np.cos(2.18154617097 + 95.9792272178*t)
	X0 += 0.00006195302*np.cos(2.44963609645 + 846.0828347512*t)
	X0 += 0.00006322091*np.cos(0.83910039496 + 309.2783226558*t)
	X0 += 0.00006242626*np.cos(0.31189331943 + 536.8045120954*t)
	X0 += 0.00006073312*np.cos(6.15905920767 + 440.8252848776*t)
	X0 += 0.00005342763*np.cos(3.60061388095 + 412.3710968744*t)
	X0 += 0.00005192695*np.cos(4.54584457909 + 210.8514148832*t)
	X0 += 0.00005151002*np.cos(0.34669532534 + 215.7467759928*t)
	X0 += 0.00003791450*np.cos(5.99767294831 + 422.6660376129*t)
	X0 += 0.00003761760*np.cos(3.72112918055 + 212.3358875915*t)
	X0 += 0.00003746363*np.cos(1.16965138821 + 214.2623032845*t)
	X0 += 0.00003113686*np.cos(0.84631897443 + 213.2509113282*t)
	X0 += 0.00003112752*np.cos(4.04410367056 + 213.3472795478*t)
	X0 += 0.00003674488*np.cos(6.08210209796 + 76.2660712756*t)
	X0 += 0.00002987869*np.cos(0.04173236626 + 625.6701923124*t)
	X0 += 0.00004110608*np.cos(5.96149429852 + 137.0330241624*t)
	X0 += 0.00002953858*np.cos(5.39165103860 + 138.5174968707*t)
	X0 += 0.00002904839*np.cos(1.13559078868 + 85.8272988312*t)
	X0 += 0.00002827199*np.cos(0.73271261848 + 330.6189636582*t)
	X0 += 0.00003362357*np.cos(1.42090450141 + 437.6438911399*t)
	X0 += 0.00002633264*np.cos(5.40645069358 + 288.0806940053*t)
	X0 += 0.00002712559*np.cos(0.96814009180 + 203.7378678824*t)
	X0 += 0.00002619094*np.cos(5.49345540359 + 127.4717966068*t)
	X0 += 0.00002527038*np.cos(5.09752990899 + 628.8515860501*t)
	X0 += 0.00002921516*np.cos(4.16131118972 + 1066.49547719*t)
	X0 += 0.00002507576*np.cos(1.49473969257 + 9.5612275556*t)
	X0 += 0.00002469402*np.cos(5.27363716895 + 1155.361157407*t)
	X0 += 0.00002424948*np.cos(3.97128259353 + 222.8603229936*t)
	X0 += 0.00003128610*np.cos(4.05501447962 + 1368.660252845*t)
	X0 += 0.00002308453*np.cos(3.67822395107 + 430.5303441391*t)
	X0 += 0.00002162294*np.cos(3.26942373483 + 340.7708920448*t)
	X0 += 0.00002912305*np.cos(1.76894623285 + 3.1813937377*t)
	X0 += 0.00002094767*np.cos(3.55759987109 + 423.4167971383*t)
	X0 += 0.00002334618*np.cos(5.86791070843 + 388.4651552382*t)
	X0 += 0.00002099584*np.cos(2.04767412721 + 1.4844727083*t)
	X0 += 0.00001634380*np.cos(4.54319346061 + 12.5301729722*t)
	X0 += 0.00001635508*np.cos(2.19968869780 + 212.7778305762*t)
	X0 += 0.00001632293*np.cos(2.69164822165 + 213.8203602998*t)
	X0 += 0.00001499061*np.cos(3.60176796862 + 52.6901980395*t)
	X0 += 0.00001460800*np.cos(5.92457418931 + 429.7795846137*t)
	X0 += 0.00001537964*np.cos(4.78543539924 + 860.3099287528*t)
	X0 += 0.00001465687*np.cos(5.69105697536 + 949.1756089698*t)
	X0 += 0.00001417710*np.cos(5.41419900810 + 350.3321196004*t)
	X0 += 0.00001148005*np.cos(0.19267134900 + 942.062061969*t)
	X0 += 0.00001111390*np.cos(0.47907481744 + 234.6397364404*t)
	X0 += 0.00001070652*np.cos(2.16320626061 + 1059.3819301892*t)
	X0 += 0.00001019407*np.cos(5.00697904753 + 1471.7530270636*t)
	X0 += 0.00001009190*np.cos(1.34289487761 + 265.9892934775*t)
	X0 += 0.00000969675*np.cos(6.06759066262 + 515.463871093*t)
	X0 += 0.00001089142*np.cos(5.82690567831 + 362.8622925726*t)
	X0 += 0.00001092000*np.cos(1.13562597855 + 173.9422195228*t)
	X0 += 0.00001173633*np.cos(3.79592491893 + 1685.0521225016*t)
	X0 += 0.00000867742*np.cos(3.23603399857 + 210.3783341312*t)
	X0 += 0.00001118048*np.cos(3.46624216870 + 703.6331846174*t)
	X0 += 0.00000867705*np.cos(1.65168536612 + 216.2198567448*t)
	X0 += 0.00001150262*np.cos(3.74704110250 + 200.7689224658*t)
	X0 += 0.00000829404*np.cos(0.58167216896 + 212.5483359126*t)
	X0 += 0.00000824797*np.cos(4.30734330456 + 214.0498549634*t)
	X0 += 0.00000881207*np.cos(1.47222342795 + 209.106309744*t)
	X0 += 0.00000864820*np.cos(3.41432256973 + 217.491881132*t)
	X0 += 0.00000789057*np.cos(0.23960587227 + 223.5940361765*t)
	X0 += 0.00001008026*np.cos(1.08825703500 + 225.8292684102*t)
	X0 += 0.00000918163*np.cos(4.86154825531 + 565.1156877467*t)
	X0 += 0.00000729284*np.cos(5.89867315791 + 1265.5674786264*t)
	X0 += 0.00000859722*np.cos(3.70935476561 + 252.6559713532*t)
	X0 += 0.00000780633*np.cos(4.83797898102 + 728.762966531*t)
	X0 += 0.00000787738*np.cos(2.18483184089 + 88.865680217*t)
	X0 += 0.00000710122*np.cos(3.41709207069 + 417.0369633204*t)
	X0 += 0.00000723204*np.cos(1.96639979182 + 956.2891559706*t)
	X0 += 0.00000918243*np.cos(4.57697669021 + 563.6312150384*t)
	X0 += 0.00000798173*np.cos(2.01609262333 + 207.8824694666*t)
	X0 += 0.00000647073*np.cos(2.95872943804 + 99.1606209555*t)
	X0 += 0.00000708337*np.cos(0.91058417437 + 207.6700211455*t)
	X0 += 0.00000768213*np.cos(2.89648077129 + 218.7157214094*t)
	X0 += 0.00000691909*np.cos(3.97719367325 + 218.9281697305*t)
	X0 += 0.00000637987*np.cos(6.22551769213 + 70.8494453042*t)
	X0 += 0.00000613771*np.cos(2.45656955715 + 142.4496501338*t)
	X0 += 0.00000799254*np.cos(1.35390136346 + 22.0914005278*t)
	X0 += 0.00000834067*np.cos(2.96257312203 + 160.6088973985*t)
	X0 += 0.00000786419*np.cos(3.25718375099 + 36.6485629295*t)
	X0 += 0.00000760670*np.cos(1.72547418591 + 21.3406410024*t)
	X0 += 0.00000623804*np.cos(0.35891832074 + 1162.4747044078*t)
	X0 += 0.00000732069*np.cos(4.22603104281 + 39.6175083461*t)
	X0 += 0.00000624442*np.cos(2.79573123394 + 18.1592472647*t)
	X0 += 0.00000698094*np.cos(0.39648451365 + 62.2514255951*t)
	X0 += 0.00000599106*np.cos(3.85684582470 + 554.0699874828*t)
	X0 += 0.00000696536*np.cos(0.57194890610 + 124.433415221*t)
	X0 += 0.00000613050*np.cos(4.42187080646 + 217.964961884*t)
	X0 += 0.00000515941*np.cos(2.58930133364 + 408.4389436113*t)
	X0 += 0.00000580985*np.cos(2.07880379325 + 231.4583427027*t)
	X0 += 0.00000665390*np.cos(2.82434442703 + 425.1137181677*t)
	X0 += 0.00000513325*np.cos(0.39337237558 + 414.0680179038*t)
	X0 += 0.00000656340*np.cos(1.39993424531 + 65.2203710117*t)
	X0 += 0.00000493977*np.cos(0.34470358866 + 302.164775655*t)
	X0 += 0.00000503830*np.cos(6.20414438628 + 1258.4539316256*t)
	X0 += 0.00000530435*np.cos(2.53005245833 + 214.7835681463*t)
	X0 += 0.00000548712*np.cos(0.47707901323 + 208.633228992*t)
	X0 += 0.00000447477*np.cos(4.71542440428 + 203.0041546995*t)
	X0 += 0.00000446305*np.cos(4.74401934346 + 1788.1448967202*t)
	X0 += 0.00000465392*np.cos(5.40750083938 + 654.1243803156*t)
	X0 += 0.00000502185*np.cos(4.37004071521 + 251.4321310758*t)
	X0 += 0.00000517119*np.cos(2.16322117240 + 211.8146227297*t)
	X0 += 0.00000399606*np.cos(3.23973258155 + 213.1872208534*t)
	X0 += 0.00000399606*np.cos(1.64957508001 + 213.4109700226*t)
	X0 += 0.00000379065*np.cos(5.64201395902 + 1581.959348283*t)
	X0 += 0.00000400290*np.cos(3.15876824938 + 404.5067903482*t)
	X0 += 0.00000382164*np.cos(3.77391165053 + 148.0787244263*t)
	X0 += 0.00000389617*np.cos(0.10274106490 + 1478.8665740644*t)
	X0 += 0.00000350293*np.cos(5.00255705341 + 198.321241911*t)
	X0 += 0.00000464864*np.cos(3.54480854933 + 2001.4439921582*t)
	X0 += 0.00000351121*np.cos(5.86405155542 + 98.8999885246*t)
	X0 += 0.00000335788*np.cos(1.02993303771 + 213.5115437591*t)
	X0 += 0.00000335788*np.cos(3.85937462386 + 213.0866471169*t)
	X0 += 0.00000367643*np.cos(4.66054518863 + 114.1384744825*t)
	X0 += 0.00000367304*np.cos(5.88650282265 + 750.1036075334*t)
	X0 += 0.00000454510*np.cos(0.31737474148 + 73.297125859*t)
	X0 += 0.00000318641*np.cos(5.70073398414 + 831.8557407496*t)
	X0 += 0.00000317269*np.cos(6.15399946707 + 228.276948965*t)
	X0 += 0.00000367600*np.cos(5.32149304118 + 151.0476698429*t)
	X0 += 0.00000416098*np.cos(5.91051454266 + 191.2076949102*t)
	X0 += 0.00000319406*np.cos(0.72194326719 + 175.1660598002*t)
	X0 += 0.00000381531*np.cos(1.39616544631 + 312.1990839626*t)
	X0 += 0.00000382800*np.cos(2.56517911849 + 56.6223513026*t)
	X0 += 0.00000402465*np.cos(4.29571195670 + 177.8743727859*t)
	X0 += 0.00000337120*np.cos(2.96241883499 + 479.2883889155*t)
	X0 += 0.00000270298*np.cos(5.13892679265 + 635.9651330509*t)
	X0 += 0.00000268385*np.cos(4.75118314124 + 191.9584544356*t)
	X0 += 0.00000269380*np.cos(1.30301159795 + 278.5194664497*t)
	X0 += 0.00000268854*np.cos(5.66985306128 + 205.2223405907*t)
	X0 += 0.00000315241*np.cos(1.98234278819 + 106.2741679563*t)
	X0 += 0.00000269016*np.cos(2.15203921815 + 327.4375699205*t)
	X0 += 0.00000347502*np.cos(5.76861803456 + 195.1398481733*t)
	X0 += 0.00000347341*np.cos(0.61908132149 + 248.7238180901*t)
	X0 += 0.00000296359*np.cos(1.51933329331 + 10.2949407385*t)
	X0 += 0.00000280829*np.cos(3.77309922396 + 2.4476805548*t)
	X0 += 0.00000252470*np.cos(1.67539597791 + 213.5597278689*t)
	X0 += 0.00000252470*np.cos(3.21391208773 + 213.0384630071*t)
	X0 += 0.00000272534*np.cos(4.54740464703 + 1045.1548361876*t)
	X0 += 0.00000239617*np.cos(5.92707655403 + 1574.8458012822*t)
	X0 += 0.00000224581*np.cos(1.93088202036 + 39.3568759152*t)
	X0 += 0.00000240608*np.cos(5.74777592789 + 221.3758502853*t)
	X0 += 0.00000303332*np.cos(1.08981956452 + 483.2205421786*t)
	X0 += 0.00000221755*np.cos(0.03688590568 + 543.9180590962*t)
	X0 += 0.00000292918*np.cos(3.86514080986 + 424.1505103212*t)
	X0 += 0.00000236937*np.cos(4.96032795425 + 235.3904959658*t)
	X0 += 0.00000234092*np.cos(5.78186298869 + 275.5505210331*t)
	X0 += 0.00000204931*np.cos(4.46341699841 + 842.1506814881*t)
	X0 += 0.00000203518*np.cos(4.48361003131 + 2104.5367663768*t)
	X0 += 0.00000266641*np.cos(3.49646394105 + 121.2520214833*t)
	X0 += 0.00000230862*np.cos(4.03811269085 + 497.4476361802*t)
	X0 += 0.00000202640*np.cos(2.91715278214 + 284.1485407422*t)
	X0 += 0.00000192734*np.cos(5.33529234354 + 1898.3512179396*t)
	X0 += 0.00000217166*np.cos(6.14501268573 + 429.0458714308*t)
	X0 += 0.00000213986*np.cos(2.44871785704 + 8.0767548473*t)
	X0 += 0.00000212877*np.cos(0.67438396717 + 650.9429865779*t)
	X0 += 0.00000215232*np.cos(2.97872772544 + 425.6349830295*t)
	X0 += 0.00000236824*np.cos(3.57393052829 + 219.4494345923*t)
	X0 += 0.00000206993*np.cos(1.14841882856 + 1375.7737998458*t)
	X0 += 0.00000174574*np.cos(3.29077366662 + 426.6463749858*t)
	X0 += 0.00000218159*np.cos(1.64908016840 + 269.9214467406*t)
	X0 += 0.00000169471*np.cos(4.78021413557 + 501.3797894433*t)
	X0 += 0.00000174569*np.cos(0.09297884169 + 426.5500067662*t)
	X0 += 0.00000176368*np.cos(0.50228212449 + 618.5566453116*t)
	X0 += 0.00000163515*np.cos(0.76931838572 + 312.4597163935*t)
	X0 += 0.00000182548*np.cos(1.24685117319 + 210.5907824523*t)
	X0 += 0.00000169016*np.cos(6.21903539006 + 1795.258443721*t)
	X0 += 0.00000188022*np.cos(0.50637735109 + 427.5613987225*t)
	X0 += 0.00000181602*np.cos(3.07716157619 + 84.3428261229*t)
	X0 += 0.00000179530*np.cos(3.64276719183 + 216.0074084237*t)
	X0 += 0.00000166973*np.cos(4.32185770884 + 355.7487455718*t)
	X0 += 0.00000151676*np.cos(4.13754942735 + 213.4591541324*t)
	X0 += 0.00000151676*np.cos(0.75207673924 + 213.1390367436*t)
	X0 += 0.00000151432*np.cos(3.90513456730 + 220.4608265486*t)
	X0 += 0.00000194652*np.cos(5.26736778530 + 488.8496164711*t)
	X0 += 0.00000149055*np.cos(5.67257832801 + 107.0249274817*t)
	X0 += 0.00000191290*np.cos(3.29984174656 + 2317.8358618148*t)
	X0 += 0.00000166449*np.cos(3.40892440053 + 1279.794572628*t)
	X0 += 0.00000180790*np.cos(0.04936208794 + 491.8185618877*t)
	X0 += 0.00000188196*np.cos(1.34108074604 + 207.1487562837*t)
	X0 += 0.00000146618*np.cos(0.72929682140 + 220.364458329*t)
	X0 += 0.00000193237*np.cos(4.19968617237 + 188.9200730498*t)
	X0 += 0.00000137090*np.cos(5.42655130336 + 1148.2476104062*t)
	X0 += 0.00000146331*np.cos(6.12359043156 + 5.4166259714*t)
	X0 += 0.00000185616*np.cos(5.12367952113 + 601.7642506762*t)
	X0 += 0.00000158034*np.cos(3.42936876808 + 179.3588454942*t)
	X0 += 0.00000176989*np.cos(2.59441226782 + 344.7030453079*t)
	X0 += 0.00000159685*np.cos(5.53376678198 + 358.9301393095*t)
	X0 += 0.00000155790*np.cos(4.99237742083 + 289.5651667136*t)
	X0 += 0.00000138147*np.cos(3.19940941173 + 436.1594184316*t)
	X0 += 0.00000125961*np.cos(3.35117964179 + 643.8294395771*t)
	X0 += 0.00000131798*np.cos(2.50083539634 + 212.0270710508*t)
	X0 += 0.00000139279*np.cos(2.71243130336 + 636.7158925763*t)
	X0 += 0.00000122329*np.cos(1.96650577886 + 69.1525242748*t)
	X0 += 0.00000130711*np.cos(2.38850746748 + 214.5711198252*t)
	X0 += 0.00000134225*np.cos(5.65869864230 + 4.665866446*t)
	X0 += 0.00000122431*np.cos(1.70605535564 + 621.7380390493*t)
	X0 += 0.00000116811*np.cos(1.61145832221 + 113.3877149571*t)
	X0 += 0.00000118860*np.cos(5.65033188726 + 1891.2376709388*t)
	X0 += 0.00000156141*np.cos(0.65756469165 + 237.6781178262*t)
	X0 += 0.00000111031*np.cos(1.01598464494 + 206.1373643274*t)
	X0 += 0.00000117765*np.cos(3.75859584496 + 32.2433289144*t)
	X0 += 0.00000129033*np.cos(1.46198971089 + 247.2393453818*t)
	X0 += 0.00000134644*np.cos(2.33574959741 + 78.7137518304*t)
	X0 += 0.00000112790*np.cos(5.44507912303 + 114.3991069134*t)
	X0 += 0.00000108637*np.cos(1.81623475388 + 767.3690829208*t)
	X0 += 0.00000105318*np.cos(5.22706552130 + 5.6290742925*t)
	X0 += 0.00000127653*np.cos(5.12749160961 + 134.5853436076*t)
	X0 += 0.00000126069*np.cos(4.37180806356 + 181.0557665236*t)
	X0 += 0.00000102853*np.cos(1.65813839227 + 67.6680515665*t)
	X0 += 0.00000133601*np.cos(2.75004967414 + 35.4247226521*t)
	X0 += 0.00000110253*np.cos(0.71569456242 + 245.5424243524*t)
	X0 += 0.00000105830*np.cos(1.45649128193 + 219.891377577*t)
	X0 += 0.00000106045*np.cos(4.18483284486 + 206.233732547*t)
	X0 += 0.00000098219*np.cos(0.44587854866 + 144.1465711632*t)
	X0 += 0.00000097708*np.cos(5.02834717765 + 2214.7430875962*t)
	X0 += 0.00000095113*np.cos(5.17002132247 + 643.0786800517*t)
	X0 += 0.00000103912*np.cos(4.03403746860 + 1073.6090241908*t)
	X0 += 0.00000099528*np.cos(1.42298075665 + 426.0769260142*t)
	X0 += 0.00000094974*np.cos(4.23060258384 + 2420.9286360334*t)
	X0 += 0.00000096530*np.cos(6.02923616094 + 447.9388318784*t)
	X0 += 0.00000103745*np.cos(4.30393732262 + 1361.5467058442*t)
	X0 += 0.00000117656*np.cos(2.13405645015 + 1272.6810256272*t)
	X0 += 0.00000088669*np.cos(0.05205130929 + 87.3117715395*t)
	X0 += 0.00000098975*np.cos(1.55639660933 + 4.192785694*t)
	X0 += 0.00000099944*np.cos(2.65997941012 + 14.977853527*t)
	X0 += 0.00000081885*np.cos(3.25181964362 + 20.6069278195*t)
	X0 += 0.00000091321*np.cos(1.93807762123 + 427.1194557378*t)
	X0 += 0.00000091949*np.cos(3.60460364421 + 206.706813299*t)
	X0 += 0.00000100140*np.cos(3.54221048055 + 140.001969579*t)
	X0 += 0.00000079774*np.cos(4.83514091014 + 159.1244246902*t)
	X0 += 0.00000081604*np.cos(4.52557877618 + 525.4981794006*t)
	X0 += 0.00000078549*np.cos(3.24815082664 + 14.0146456805*t)
	X0 += 0.00000081064*np.cos(0.27454326223 + 125.9873238985*t)
	X0 += 0.00000104149*np.cos(0.61449386936 + 1692.1656695024*t)
	X0 += 0.00000074887*np.cos(6.18244095483 + 420.9691165835*t)
	X0 += 0.00000083219*np.cos(4.23693462991 + 153.4953503977*t)
	X0 += 0.00000073767*np.cos(6.06987659127 + 2111.6503133776*t)
	X0 += 0.00000071695*np.cos(2.45500522999 + 630.3360587584*t)
	X0 += 0.00000077164*np.cos(0.90106050331 + 329.7251917809*t)
	X0 += 0.00000071328*np.cos(4.25726845306 + 0.9632078465*t)
	X0 += 0.00000069326*np.cos(5.97750450668 + 212.0752551606*t)
	X0 += 0.00000069326*np.cos(5.19530696709 + 214.5229357154*t)
	X0 += 0.00000076087*np.cos(0.34743859064 + 934.9485149682*t)
	X0 += 0.00000085500*np.cos(1.61924612074 + 54.1746707478*t)
	X0 += 0.00000081874*np.cos(1.59776394951 + 353.301065017*t)
	X0 += 0.00000091120*np.cos(3.81883197984 + 776.9303104764*t)
	X0 += 0.00000086236*np.cos(2.72678012092 + 916.9322800554*t)
	X0 += 0.00000074136*np.cos(4.03125002315 + 92.0470739547*t)
	X0 += 0.00000066131*np.cos(2.35964914519 + 423.6774295692*t)
	X0 += 0.00000071095*np.cos(6.18616583120 + 211.6021744086*t)
	X0 += 0.00000064837*np.cos(4.82949190154 + 6.1503391543*t)
	X0 += 0.00000064147*np.cos(5.15692606934 + 1464.6394800628*t)
	X0 += 0.00000064557*np.cos(0.28622924030 + 184.9879197867*t)
	X0 += 0.00000065853*np.cos(4.35139240808 + 339.2864193365*t)
	X0 += 0.00000080268*np.cos(3.06595567501 + 2634.2277314714*t)
	X0 += 0.00000062412*np.cos(6.02397194169 + 692.5874843535*t)
	X0 += 0.00000062748*np.cos(2.82059120751 + 2.9207613068*t)
	X0 += 0.00000073234*np.cos(1.42030136903 + 286.596221297*t)
	X0 += 0.00000065292*np.cos(5.67801345398 + 617.8058857862*t)
	X0 += 0.00000079482*np.cos(2.77610661994 + 347.8844390456*t)
	X0 += 0.00000070198*np.cos(0.02729113540 + 337.732510659*t)
	X0 += 0.00000059578*np.cos(4.68819841285 + 51.2057253312*t)
	X0 += 0.00000075802*np.cos(1.21580005948 + 46.470422916*t)
	X0 += 0.00000060050*np.cos(5.38312689496 + 2207.6295405954*t)
	X0 += 0.00000068653*np.cos(0.59467909972 + 273.1028404783*t)
	X0 += 0.00000058090*np.cos(3.78005458271 + 416.3032501375*t)
	X0 += 0.00000061437*np.cos(0.73813400987 + 182.279606801*t)
	X0 += 0.00000063517*np.cos(2.40088368245 + 391.1734682239*t)
	X0 += 0.00000076309*np.cos(6.17304532091 + 299.1263942692*t)
	X0 += 0.00000066015*np.cos(4.08036425037 + 778.4147831847*t)
	X0 += 0.00000066706*np.cos(2.56096004731 + 220.9339073006*t)
	X0 += 0.00000066535*np.cos(0.16025744557 + 696.5196376166*t)
	X0 += 0.00000055588*np.cos(1.58539917943 + 387.2413149608*t)
	X0 += 0.00000055245*np.cos(5.78088395279 + 436.8931316145*t)
	X0 += 0.00000054700*np.cos(4.54260230672 + 241.6102710893*t)
	X0 += 0.00000054842*np.cos(1.38489146108 + 518.6452648307*t)
	X0 += 0.00000059023*np.cos(4.97849167437 + 214.9960164674*t)
	X0 += 0.00000053989*np.cos(6.19050578729 + 627.3671133418*t)
	X0 += 0.00000068787*np.cos(3.41306604582 + 116.4260963429*t)
	X0 += 0.00000063336*np.cos(5.07934253747 + 576.1613880106*t)
	X0 += 0.00000054255*np.cos(6.09930467587 + 267.4737661858*t)
	X0 += 0.00000053639*np.cos(3.19637859214 + 128.9562693151*t)
	X0 += 0.00000052275*np.cos(1.93847849121 + 7.065362891*t)
	X0 += 0.00000055800*np.cos(1.92876335537 + 342.2553647531*t)
	X0 += 0.00000069651*np.cos(1.43400464282 + 24.3790223882*t)
	X0 += 0.00000056865*np.cos(1.30791772242 + 444.7574381407*t)
	X0 += 0.00000050883*np.cos(1.18776024585 + 31.019488637*t)
	X0 += 0.00000055380*np.cos(2.97518197987 + 59.8037450403*t)
	X0 += 0.00000050427*np.cos(5.15298120408 + 211.8628068395*t)
	X0 += 0.00000050427*np.cos(6.01983026969 + 214.7353840365*t)
	X0 += 0.00000057131*np.cos(3.96134363403 + 543.0242872189*t)
	X0 += 0.00000049871*np.cos(4.73074363594 + 2531.1349572528*t)
	X0 += 0.00000051909*np.cos(4.30240479689 + 192.6921676185*t)
	X0 += 0.00000063716*np.cos(5.76431815039 + 421.93232443*t)
	X0 += 0.00000047989*np.cos(0.27885843572 + 333.657345044*t)
	X0 += 0.00000060126*np.cos(0.33113202746 + 439.1283638482*t)
	X0 += 0.00000055585*np.cos(5.00242279476 + 221.1634019642*t)
	X0 += 0.00000047716*np.cos(0.39295661784 + 219.6618829134*t)
	X0 += 0.00000049622*np.cos(2.64477814311 + 430.79097657*t)
	X0 += 0.00000061028*np.cos(1.51139637873 + 305.3461693927*t)
	X0 += 0.00000048644*np.cos(3.16627935573 + 96.8729990951*t)
	X0 += 0.00000048710*np.cos(0.89401835270 + 429.5189521828*t)
	X0 += 0.00000046209*np.cos(6.11163535772 + 425.8474313506*t)
	X0 += 0.00000059861*np.cos(3.45284751930 + 487.3651437628*t)
	X0 += 0.00000046524*np.cos(4.14957170333 + 282.4516197128*t)
	X0 += 0.00000046921*np.cos(5.73141451894 + 292.0128472684*t)
	X0 += 0.00000044465*np.cos(3.96656681803 + 2737.32050569*t)
	X0 += 0.00000047450*np.cos(3.08411595023 + 320.3240229197*t)
	X0 += 0.00000055031*np.cos(2.61684051897 + 418.5214360287*t)
	X0 += 0.00000051667*np.cos(1.43451020695 + 1169.5882514086*t)
	X0 += 0.00000055947*np.cos(2.08615281193 + 638.4128136057*t)
	X0 += 0.00000042668*np.cos(0.60521165065 + 421.1815649046*t)
	X0 += 0.00000047761*np.cos(1.51559446603 + 558.0021407459*t)
	X0 += 0.00000053261*np.cos(6.04292842982 + 205.4347889118*t)
	X0 += 0.00000051528*np.cos(5.02718280298 + 199.2844497575*t)
	X0 += 0.00000041663*np.cos(2.50545942767 + 120.358249606*t)
	X0 += 0.00000045564*np.cos(1.25214817820 + 274.0660483248*t)
	X0 += 0.00000048658*np.cos(5.15240257266 + 7.1617311106*t)
	X0 += 0.00000039341*np.cos(1.88905188285 + 458.8415197904*t)
	X0 += 0.00000053435*np.cos(4.49704581652 + 166.828672522*t)
	X0 += 0.00000045109*np.cos(6.06459133840 + 227.3137411185*t)
	X0 += 0.00000046355*np.cos(3.10853382452 + 432.2272651685*t)
	X0 += 0.00000038934*np.cos(2.45431347167 + 264.5048207692*t)
	X0 += 0.00000045774*np.cos(2.33733624110 + 205.6642835754*t)
	X0 += 0.00000051539*np.cos(0.34137373429 + 2008.557539159*t)
	X0 += 0.00000040966*np.cos(4.09903578988 + 1677.9385755008*t)
	X0 += 0.00000037133*np.cos(4.50828997358 + 206.9363079626*t)
	X0 += 0.00000036628*np.cos(3.66787324062 + 427.3489504014*t)
	X0 += 0.00000045029*np.cos(2.03211615844 + 428.0826635843*t)
	X0 += 0.00000038453*np.cos(5.99530036714 + 209.1544938538*t)
	X0 += 0.00000040436*np.cos(0.44978856734 + 233.9060232575*t)
	X0 += 0.00000036768*np.cos(1.91588498975 + 33.9402499438*t)
	X0 += 0.00000037471*np.cos(5.17760705488 + 217.4436970222*t)
	X0 += 0.00000044696*np.cos(3.38722991510 + 6.592282139*t)
	X0 += 0.00000046113*np.cos(4.05104625234 + 214.1928673153*t)
	X0 += 0.00000046113*np.cos(0.83857991425 + 212.4053235607*t)
	X0 += 0.00000037230*np.cos(1.57251793083 + 41.6444977756*t)
	X0 += 0.00000036077*np.cos(4.65554964728 + 867.4234757536*t)
	X0 += 0.00000037353*np.cos(0.06647848989 + 1251.3403846248*t)
	X0 += 0.00000033612*np.cos(1.68789904490 + 181.806526049*t)
	X0 += 0.00000036733*np.cos(1.27611933074 + 77.7505439839*t)
	X0 += 0.00000033393*np.cos(5.90961230058 + 2428.0421830342*t)
	X0 += 0.00000042678*np.cos(3.87972225097 + 135.5485514541*t)
	X0 += 0.00000040487*np.cos(4.57323225888 + 35.1640902212*t)
	X0 += 0.00000035511*np.cos(4.25887033106 + 244.318584075*t)
	X0 += 0.00000036698*np.cos(3.68604101993 + 431.264057322*t)
	X0 += 0.00000039183*np.cos(6.26114342823 + 145.6310438715*t)
	X0 += 0.00000038119*np.cos(6.03029510246 + 319.5732633943*t)
	X0 += 0.00000031092*np.cos(4.88763516295 + 1781.0313497194*t)
	X0 += 0.00000033486*np.cos(2.40982180111 + 28.3111756513*t)
	X0 += 0.00000032066*np.cos(3.33695513399 + 465.9550667912*t)
	X0 += 0.00000032931*np.cos(2.31448463560 + 81.7521332162*t)
	X0 += 0.00000039682*np.cos(0.04631095182 + 738.7972748386*t)
	X0 += 0.00000030271*np.cos(2.89789752283 + 411.620337349*t)
	X0 += 0.00000039377*np.cos(2.19578979946 + 373.9079928365*t)
	X0 += 0.00000030492*np.cos(1.11695305824 + 280.9671470045*t)
	X0 += 0.00000030230*np.cos(5.10287010223 + 2524.021410252*t)
	X0 += 0.00000029377*np.cos(6.18727053498 + 131.5469622218*t)
	X0 += 0.00000028754*np.cos(0.15838275010 + 192.8522263129*t)
	X0 += 0.00000035400*np.cos(2.84750024165 + 381.3516082374*t)
	X0 += 0.00000028194*np.cos(2.46753634930 + 1589.0728952838*t)
	X0 += 0.00000028049*np.cos(2.30566407507 + 131.4039498699*t)
	X0 += 0.00000033973*np.cos(2.82785995951 + 2950.619601128*t)
	X0 += 0.00000035075*np.cos(0.26666716101 + 23.5758732361*t)
	X0 += 0.00000027325*np.cos(0.85706476637 + 60.7669528868*t)
	X0 += 0.00000037615*np.cos(0.10667439867 + 480.7728616238*t)
	X0 += 0.00000027836*np.cos(1.17681685755 + 216.2680408546*t)
	X0 += 0.00000037025*np.cos(0.82458967421 + 2.9689454166*t)
	X0 += 0.00000029306*np.cos(3.55420811269 + 464.7312265138*t)
	X0 += 0.00000027047*np.cos(2.92543208325 + 361.3778198643*t)
	X0 += 0.00000026548*np.cos(1.60414548715 + 405.9912630565*t)
	X0 += 0.00000033781*np.cos(1.31739552237 + 756.3233826569*t)
	X0 += 0.00000033625*np.cos(5.77835881759 + 395.578702239*t)
	X0 += 0.00000026346*np.cos(3.73692388891 + 0.5212648618*t)
	X0 += 0.00000026332*np.cos(4.82433091330 + 16.6747745564*t)
	X0 += 0.00000031111*np.cos(1.40241336085 + 0.7507595254*t)
	X0 += 0.00000029988*np.cos(3.32282928396 + 710.7467316182*t)
	X0 += 0.00000025913*np.cos(3.24693597232 + 244.791664827*t)
	X0 += 0.00000031019*np.cos(2.96059209588 + 129.9194771616*t)
	X0 += 0.00000025546*np.cos(1.68817201260 + 412.5835451955*t)
	X0 += 0.00000025306*np.cos(4.73124302501 + 233.7459645631*t)
	X0 += 0.00000033248*np.cos(1.88178595513 + 162.0933701068*t)
	X0 += 0.00000025984*np.cos(0.44763976287 + 494.2662424425*t)
	X0 += 0.00000026319*np.cos(3.57855185452 + 210.3301500214*t)
	X0 += 0.00000030742*np.cos(1.26199225349 + 454.9093665273*t)
	X0 += 0.00000034122*np.cos(0.40144235206 + 259.769518354*t)
	X0 += 0.00000024741*np.cos(4.44519463302 + 2847.5268269094*t)
	X0 += 0.00000026274*np.cos(0.63012531277 + 45.5766510387*t)
	X0 += 0.00000026934*np.cos(5.50960011212 + 254.9435932136*t)
	X0 += 0.00000033480*np.cos(2.30014654686 + 27.0873353739*t)
	X0 += 0.00000027190*np.cos(5.04012848689 + 214.9436268407*t)
	X0 += 0.00000027190*np.cos(6.13268298688 + 211.6545640353*t)
	X0 += 0.00000024727*np.cos(0.01709959991 + 508.3503240922*t)
	X0 += 0.00000025542*np.cos(5.77362891558 + 681.5417840896*t)
	X0 += 0.00000025645*np.cos(3.86292605935 + 229.9738699944*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000023511*np.cos(0.40578451478 + 212.4959462859*t)
	X0 += 0.00000023511*np.cos(4.48384165181 + 214.1022445901*t)
	X0 += 0.00000024389*np.cos(1.47701184444 + 422.405405182*t)
	X0 += 0.00000027252*np.cos(0.52645996662 + 525.7588118315*t)
	X0 += 0.00000024192*np.cos(0.34568002889 + 420.4478517217*t)
	X0 += 0.00000024075*np.cos(4.67936877608 + 258.8757464767*t)
	X0 += 0.00000022198*np.cos(2.48883901199 + 426.4863162914*t)
	X0 += 0.00000023044*np.cos(5.56570101243 + 184.7272873558*t)
	X0 += 0.00000023225*np.cos(1.32324393739 + 207.0793203145*t)
	X0 += 0.00000021570*np.cos(3.20671772166 + 224.6054281328*t)
	X0 += 0.00000021557*np.cos(2.60337999064 + 432.0148168474*t)
	X0 += 0.00000022198*np.cos(0.89868151046 + 426.7100654606*t)
	X0 += 0.00000022194*np.cos(3.11585618869 + 313.2104759189*t)
	X0 += 0.00000022951*np.cos(4.15499253822 + 92.940845832*t)
	X0 += 0.00000022696*np.cos(1.52974836022 + 223.3334037456*t)
	X0 += 0.00000020721*np.cos(4.42613798459 + 849.2642284889*t)
	X0 += 0.00000022399*np.cos(3.56419461003 + 219.5188705615*t)
	X0 += 0.00000020538*np.cos(3.12930889350 + 106.0135355254*t)
	X0 += 0.00000020697*np.cos(3.65641936807 + 7.6348118626*t)
	X0 += 0.00000023953*np.cos(2.54227282881 + 334.5511169213*t)
	X0 += 0.00000020119*np.cos(2.85963323081 + 357.4456666012*t)
	X0 += 0.00000020403*np.cos(5.22785233718 + 162.8965192589*t)
	X0 += 0.00000020124*np.cos(3.71792305311 + 3053.7123753466*t)
	X0 += 0.00000021218*np.cos(5.34320407656 + 99.9113804809*t)
	X0 += 0.00000021047*np.cos(5.57803326341 + 241.8709035202*t)
	X0 += 0.00000023221*np.cos(1.41165777818 + 731.9443602687*t)
	X0 += 0.00000022942*np.cos(6.27858064760 + 66.70484372*t)
	X0 += 0.00000023601*np.cos(1.54425445590 + 556.5176680376*t)
	X0 += 0.00000022022*np.cos(3.52199956758 + 186.2117600641*t)
	X0 += 0.00000024674*np.cos(4.23392667934 + 46.2097904851*t)
	X0 += 0.00000021263*np.cos(2.38214401101 + 343.2185725996*t)
	X0 += 0.00000018919*np.cos(5.02923982401 + 171.6545976624*t)
	X0 += 0.00000018653*np.cos(0.27903946815 + 426.8106391971*t)
	X0 += 0.00000018677*np.cos(1.33905018859 + 835.0371344873*t)
	X0 += 0.00000018653*np.cos(3.10848105430 + 426.3857425549*t)
	X0 += 0.00000019650*np.cos(3.14857774310 + 561.1835344836*t)
	X0 += 0.00000019470*np.cos(1.81622677733 + 468.2426886516*t)
	X0 += 0.00000022709*np.cos(0.14922934569 + 450.9772132642*t)
	X0 += 0.00000019428*np.cos(2.06974323240 + 392.6579409322*t)
	X0 += 0.00000019902*np.cos(6.07671268686 + 1567.7322542814*t)
	X0 += 0.00000023255*np.cos(6.12070200866 + 593.426863398*t)
	X0 += 0.00000020562*np.cos(5.24399527975 + 963.4027029714*t)
	X0 += 0.00000024128*np.cos(4.61360879470 + 31.492569389*t)
	X0 += 0.00000023733*np.cos(6.07696637504 + 462.0229135281*t)
	X0 += 0.00000020367*np.cos(1.15827997539 + 112.6540017742*t)
	X0 += 0.00000021022*np.cos(3.71064053048 + 402.2191684878*t)
	X0 += 0.00000017689*np.cos(0.34857150254 + 295.0512286542*t)
	X0 += 0.00000024555*np.cos(0.10872457907 + 2324.9494088156*t)
	X0 += 0.00000017958*np.cos(4.21869125792 + 403.0223176399*t)
	X0 += 0.00000019076*np.cos(3.31363778751 + 905.8865797915*t)
	X0 += 0.00000024254*np.cos(4.15960622971 + 141.2258098564*t)
	X0 += 0.00000017651*np.cos(6.25482504132 + 460.5384408198*t)
	X0 += 0.00000018901*np.cos(4.70800912908 + 572.2292347475*t)
	X0 += 0.00000018099*np.cos(6.25077093682 + 230.7075831773*t)
	X0 += 0.00000019787*np.cos(4.92505641767 + 552.5855147745*t)
	X0 += 0.00000018049*np.cos(0.03570372310 + 533.6231183577*t)
	X0 += 0.00000016962*np.cos(1.45723127384 + 555.5544601911*t)
	X0 += 0.00000016956*np.cos(0.00315997618 + 77.962992305*t)
	X0 += 0.00000020486*np.cos(3.29967422946 + 156.6767441354*t)
	X0 += 0.00000018078*np.cos(3.60998206545 + 405.2575498736*t)
	X0 += 0.00000020830*np.cos(3.23444171494 + 175.4266922311*t)
	X0 += 0.00000017268*np.cos(6.09632521803 + 199.9657733137*t)
	X0 += 0.00000017269*np.cos(5.27738844677 + 295.1942410061*t)
	X0 += 0.00000022334*np.cos(4.06244344780 + 423.6292454594*t)
	X0 += 0.00000016403*np.cos(3.22117020453 + 419.532827985*t)
	X0 += 0.00000016425*np.cos(5.61380266494 + 757.2171545342*t)
	X0 += 0.00000016222*np.cos(5.73913129525 + 2744.4340526908*t)
	X0 += 0.00000016318*np.cos(5.86017105828 + 263.7016716171*t)
	X0 += 0.00000016071*np.cos(4.64386469650 + 2097.423219376*t)
	X0 += 0.00000021494*np.cos(3.37089967271 + 206.3979967583*t)
	X0 += 0.00000017985*np.cos(1.33230556245 + 240.3864308119*t)
	X0 += 0.00000016443*np.cos(5.05892064304 + 226.6324175623*t)
	X0 += 0.00000016375*np.cos(3.94799955623 + 1994.3304451574*t)
	X0 += 0.00000018316*np.cos(5.55182171088 + 100.3844612329*t)
	X0 += 0.00000018340*np.cos(4.20303712023 + 152.5321425512*t)
	X0 += 0.00000016934*np.cos(4.98862886836 + 109.2431133729*t)
	X0 += 0.00000015567*np.cos(3.11397734583 + 220.3007678542*t)
	X0 += 0.00000015886*np.cos(4.82943615088 + 2840.4132799086*t)
	X0 += 0.00000016153*np.cos(6.02134998110 + 41.0537969446*t)
	X0 += 0.00000015648*np.cos(3.13768268695 + 211.2933578679*t)
	X0 += 0.00000015648*np.cos(1.75194347964 + 215.3048330081*t)
	X0 += 0.00000018382*np.cos(1.75927606668 + 220.2001941177*t)
	X0 += 0.00000015800*np.cos(0.05620231243 + 419.4364597654*t)
	X0 += 0.00000018947*np.cos(3.07280247332 + 637.4496057592*t)
	X0 += 0.00000017585*np.cos(0.64170468841 + 546.956440482*t)
	X0 += 0.00000020541*np.cos(0.76737119207 + 285.3723810196*t)
	X0 += 0.00000016595*np.cos(4.77020496205 + 364.3467652809*t)
	X0 += 0.00000020842*np.cos(5.73713006436 + 107.7586406646*t)
	X0 += 0.00000017326*np.cos(2.91677167276 + 199.8057146193*t)
	X0 += 0.00000016807*np.cos(2.19119081420 + 172.4577468145*t)
	X0 += 0.00000016383*np.cos(2.67389241000 + 203.8979265768*t)
	X0 += 0.00000018055*np.cos(0.56501731997 + 189.7232222019*t)
	X0 += 0.00000014484*np.cos(2.14147641596 + 110.1581371096*t)
	X0 += 0.00000014822*np.cos(1.69517551415 + 195.7729876197*t)
	X0 += 0.00000014223*np.cos(3.76707137251 + 1055.4497769261*t)
	X0 += 0.00000016395*np.cos(1.73619004969 + 71.8126531507*t)
	X0 += 0.00000019924*np.cos(2.99837598349 + 72.0732855816*t)
	X0 += 0.00000016187*np.cos(0.43883421950 + 409.9234163196*t)
	X0 += 0.00000017991*np.cos(4.36654771461 + 82.8583534146*t)
	X0 += 0.00000014080*np.cos(0.77300407988 + 13.3333221243*t)
	X0 += 0.00000015462*np.cos(2.21494315347 + 222.7002642992*t)
	X0 += 0.00000014446*np.cos(6.00416843077 + 457.617679513*t)
	X0 += 0.00000014016*np.cos(0.92450223186 + 426.8588233069*t)
	X0 += 0.00000015063*np.cos(5.74506051757 + 441.576044403*t)
	X0 += 0.00000014016*np.cos(2.46301834168 + 426.3375584451*t)
	X0 += 0.00000015926*np.cos(1.97285432336 + 226.7924762567*t)
	X0 += 0.00000015979*np.cos(0.88810024478 + 831.1049812242*t)
	X0 += 0.00000015755*np.cos(2.98800853174 + 348.8476468921*t)
	X0 += 0.00000015012*np.cos(1.52188645554 + 220.5245170234*t)
	X0 += 0.00000013982*np.cos(4.83996700203 + 146.594251718*t)
	X0 += 0.00000015689*np.cos(0.75909996739 + 100.6450936638*t)
	X0 += 0.00000014376*np.cos(4.16549809702 + 448.6895914038*t)
	X0 += 0.00000017752*np.cos(4.58997108869 + 702.1487119091*t)
	X0 += 0.00000014393*np.cos(5.33813724334 + 110.2545053292*t)
	X0 += 0.00000015863*np.cos(4.36354784669 + 570.7447620392*t)
	X0 += 0.00000015270*np.cos(2.66501523650 + 81.8951455681*t)
	X0 += 0.00000014810*np.cos(1.68960262833 + 540.7366653585*t)
	X0 += 0.00000014819*np.cos(0.92519710715 + 980.6681783588*t)
	X0 += 0.00000015970*np.cos(2.37623315151 + 111.1695290659*t)
	X0 += 0.00000016413*np.cos(2.75370430496 + 221.8971151471*t)
	X0 += 0.00000014952*np.cos(1.90324601287 + 420.005908737*t)
	X0 += 0.00000013319*np.cos(2.13362682994 + 1905.4647649404*t)
	X0 += 0.00000013830*np.cos(5.00214404734 + 434.6749457233*t)
	X0 += 0.00000017566*np.cos(0.05984250060 + 569.0478410098*t)
	X0 += 0.00000018335*np.cos(6.24789947973 + 170.0100662597*t)
	X0 += 0.00000013407*np.cos(3.18967410776 + 230.8252032563*t)
	X0 += 0.00000012978*np.cos(0.29727985191 + 241.7532834412*t)
	X0 += 0.00000017355*np.cos(2.46418652977 + 50.4025761791*t)
	X0 += 0.00000013266*np.cos(2.39547698030 + 1485.9801210652*t)
	X0 += 0.00000012667*np.cos(4.19939097474 + 3163.918696566*t)
	X0 += 0.00000015794*np.cos(1.66436074053 + 251.1714986449*t)
	X0 += 0.00000013957*np.cos(6.17562483736 + 864.2420820159*t)
	X0 += 0.00000012407*np.cos(4.03761061188 + 97.6761482472*t)
	X0 += 0.00000016676*np.cos(5.57843223379 + 705.1176573257*t)
	X0 += 0.00000016081*np.cos(1.08703049614 + 28.5718080822*t)
	X0 += 0.00000014368*np.cos(2.60363106205 + 3267.0114707846*t)
	X0 += 0.00000012578*np.cos(1.88265912656 + 238.5718897035*t)
	X0 += 0.00000012271*np.cos(0.48456399700 + 326.6868103951*t)
	X0 += 0.00000012803*np.cos(5.56819639491 + 642.3449668688*t)
	X0 += 0.00000013216*np.cos(4.23672824399 + 188.1693135244*t)
	X0 += 0.00000014257*np.cos(5.84367416401 + 42.5382696529*t)
	X0 += 0.00000011400*np.cos(5.32924504172 + 119.767548775*t)
	X0 += 0.00000011397*np.cos(0.34981755484 + 280.003939158*t)
	X0 += 0.00000011206*np.cos(4.12141164216 + 714.6788848813*t)
	X0 += 0.00000014434*np.cos(3.77669276223 + 386.9806825299*t)
	X0 += 0.00000015174*np.cos(4.95078632158 + 256.5881246163*t)
	X0 += 0.00000012006*np.cos(4.20703749198 + 196.6243208816*t)
	X0 += 0.00000011891*np.cos(3.36850071201 + 203.2647871304*t)
	X0 += 0.00000012003*np.cos(2.72468835291 + 254.1404440615*t)
	X0 += 0.00000010842*np.cos(2.54339582028 + 639.9454704238*t)
	X0 += 0.00000013350*np.cos(2.22655107118 + 638.9340784675*t)
	X0 += 0.00000014697*np.cos(2.83603068369 + 432.7485300303*t)
	X0 += 0.00000013429*np.cos(0.66730550149 + 193.655375465*t)
	X0 += 0.00000013740*np.cos(4.38243231529 + 815.0633461142*t)
	X0 += 0.00000012853*np.cos(0.91490823925 + 196.0336200506*t)
	X0 += 0.00000010721*np.cos(5.00859360369 + 17.5261078183*t)
	X0 += 0.00000010504*np.cos(1.77592937092 + 206.2974230218*t)
	X0 += 0.00000011872*np.cos(4.04892295757 + 380.12776796*t)
	X0 += 0.00000010384*np.cos(0.04028185137 + 196.8367692027*t)
	X0 += 0.00000010335*np.cos(1.81611161190 + 201.9927627432*t)
	X0 += 0.00000010842*np.cos(5.62879282141 + 639.8491022042*t)
	X0 += 0.00000012326*np.cos(4.01034471107 + 230.5645708254*t)
	X0 += 0.00000010302*np.cos(2.59865864262 + 107.2855599126*t)
	X0 += 0.00000010608*np.cos(4.61155696629 + 19.1224551112*t)
	X0 += 0.00000013774*np.cos(3.98241715793 + 477.8039162072*t)
	X0 += 0.00000010048*np.cos(3.46209492470 + 3370.1042450032*t)
	X0 += 0.00000009975*np.cos(2.00272027289 + 72.3339180125*t)
	X0 += 0.00000010426*np.cos(1.21400645579 + 820.0592809603*t)
	X0 += 0.00000010793*np.cos(5.79737452042 + 1884.124123938*t)
	X0 += 0.00000013532*np.cos(5.23323144371 + 662.531203563*t)
	X0 += 0.00000009858*np.cos(3.35812510249 + 33.1371007917*t)
	X0 += 0.00000009653*np.cos(3.80389938231 + 406.954470903*t)
	X0 += 0.00000011049*np.cos(0.15327881480 + 397.3932433474*t)
	X0 += 0.00000010104*np.cos(0.97178466245 + 69.3649725959*t)
	X0 += 0.00000009594*np.cos(3.20545283826 + 433.7599219866*t)
	X0 += 0.00000010907*np.cos(6.07476458112 + 186.472392495*t)
	X0 += 0.00000009581*np.cos(3.81967849278 + 606.7601855223*t)
	X0 += 0.00000009652*np.cos(2.94034681034 + 194.1766403268*t)
	X0 += 0.00000011233*np.cos(6.08951773665 + 640.8604941605*t)
	X0 += 0.00000009546*np.cos(2.32156584631 + 219.1406180516*t)
	X0 += 0.00000009885*np.cos(2.70541891569 + 47.6942631934*t)
	X0 += 0.00000009370*np.cos(4.84934406834 + 229.7614216733*t)
	X0 += 0.00000009841*np.cos(2.58842093829 + 135.336103133*t)
	X0 += 0.00000010975*np.cos(0.55243138426 + 395.105621487*t)
	X0 += 0.00000009735*np.cos(0.01733432515 + 433.663553767*t)
	X0 += 0.00000009302*np.cos(1.37432249732 + 143.9341228421*t)
	X0 += 0.00000010066*np.cos(0.49580184666 + 423.8898778903*t)
	X0 += 0.00000012472*np.cos(3.08381939221 + 894.8408795276*t)
	X0 += 0.00000010470*np.cos(5.05300759668 + 240.125798381*t)
	X0 += 0.00000008952*np.cos(0.28590238267 + 140.9651774255*t)
	X0 += 0.00000009711*np.cos(2.61829855861 + 1493.093668066*t)
	X0 += 0.00000011290*np.cos(4.81810471700 + 389.9496279465*t)
	X0 += 0.00000008911*np.cos(1.34026355170 + 19.643719973*t)
	X0 += 0.00000009106*np.cos(0.77871223073 + 238.4288773516*t)
	X0 += 0.00000008732*np.cos(6.24118636509 + 157.6399519819*t)
	X0 += 0.00000010066*np.cos(2.89171872688 + 429.3065038617*t)
	X0 += 0.00000008626*np.cos(6.06935661185 + 526.5095713569*t)
	X0 += 0.00000009374*np.cos(3.36841689456 + 206.0736738526*t)
	X0 += 0.00000009534*np.cos(3.86185711327 + 236.8749686741*t)
	X0 += 0.00000008635*np.cos(5.93764298518 + 824.7421937488*t)
	X0 += 0.00000008477*np.cos(5.54021575940 + 3060.8259223474*t)
	X0 += 0.00000008433*np.cos(3.38649663082 + 426.7582495704*t)
	X0 += 0.00000011180*np.cos(6.17848017138 + 2641.3412784722*t)
	X0 += 0.00000008433*np.cos(0.00102394272 + 426.4381321816*t)
	X0 += 0.00000008439*np.cos(4.51500392041 + 511.5317178299*t)
	X0 += 0.00000009394*np.cos(1.85342014381 + 319.3126309634*t)
	X0 += 0.00000008532*np.cos(4.57615248884 + 3156.8051495652*t)
	X0 += 0.00000008903*np.cos(2.43701935611 + 649.4585138696*t)
	X0 += 0.00000008389*np.cos(1.87155821133 + 232.4215505492*t)
	X0 += 0.00000008246*np.cos(2.28451141169 + 194.3890886479*t)
	X0 += 0.00000008317*np.cos(5.27911046499 + 661.2379273164*t)
	X0 += 0.00000009682*np.cos(6.11176107000 + 472.1748419147*t)
	X0 += 0.00000011219*np.cos(0.89544366061 + 453.6855262499*t)
	X0 += 0.00000008411*np.cos(0.52495950363 + 172.2452984934*t)
	X0 += 0.00000008981*np.cos(0.94573569495 + 187.4356003415*t)
	X0 += 0.00000008032*np.cos(4.50603721871 + 89.7594520943*t)
	X0 += 0.00000008092*np.cos(1.12531278179 + 672.1406152284*t)
	X0 += 0.00000007874*np.cos(4.38115777683 + 2413.8150890326*t)
	X0 += 0.00000007978*np.cos(3.25270512193 + 394.3548619616*t)
	X0 += 0.00000009111*np.cos(5.92051630827 + 167.7224443993*t)
	X0 += 0.00000009885*np.cos(4.36674104280 + 29.2049475286*t)
	X0 += 0.00000007695*np.cos(2.58075308553 + 207.4575728244*t)
	X0 += 0.00000007999*np.cos(5.76892383066 + 255.8373650909*t)
	X0 += 0.00000009820*np.cos(1.99240441120 + 354.5249052944*t)
	X0 += 0.00000010355*np.cos(2.02047870385 + 204.7010757289*t)
	X0 += 0.00000009161*np.cos(1.80605471881 + 594.6507036754*t)
	X0 += 0.00000007700*np.cos(2.75501595675 + 857.1285350151*t)
	X0 += 0.00000007549*np.cos(1.87028277994 + 2221.856634597*t)
	X0 += 0.00000008422*np.cos(4.22541294301 + 502.8642621516*t)
	X0 += 0.00000009659*np.cos(0.66282222487 + 380.3884003909*t)
	X0 += 0.00000008964*np.cos(4.60259246787 + 739.8086667949*t)
	X0 += 0.00000009469*np.cos(5.95763294539 + 495.7507151508*t)
	X0 += 0.00000007922*np.cos(0.32197020343 + 176.6505325085*t)
	X0 += 0.00000009441*np.cos(6.09271231832 + 418.0001711669*t)
	X0 += 0.00000007327*np.cos(2.60511441650 + 232.2091022281*t)
	X0 += 0.00000007299*np.cos(1.29758813796 + 366.7944458357*t)
	X0 += 0.00000008713*np.cos(0.77367091578 + 393.4610900843*t)
	X0 += 0.00000007151*np.cos(5.97877847903 + 313.6835566709*t)
	X0 += 0.00000007097*np.cos(3.86634603871 + 2310.722314814*t)
	X0 += 0.00000007690*np.cos(3.91283672076 + 239.1625905345*t)
	X0 += 0.00000007054*np.cos(6.11435542975 + 384.0599212231*t)
	X0 += 0.00000007298*np.cos(1.74992346676 + 425.3261664888*t)
	X0 += 0.00000009178*np.cos(2.49021644042 + 562.1467423301*t)
	X0 += 0.00000009653*np.cos(6.08815337021 + 112.9146342051*t)
	X0 += 0.00000008400*np.cos(1.51695998773 + 28.4541880032*t)
	X0 += 0.00000007018*np.cos(2.37418304281 + 291.262087743*t)
	X0 += 0.00000008083*np.cos(1.54726535769 + 619.2903584945*t)
	X0 += 0.00000007119*np.cos(4.29731211712 + 325.9530972122*t)
	X0 += 0.00000007298*np.cos(1.63759710678 + 427.8702152632*t)
	X0 += 0.00000008072*np.cos(3.32529933927 + 724.8308132679*t)
	X0 += 0.00000007741*np.cos(0.76022179542 + 84.9335269539*t)
	X0 += 0.00000006935*np.cos(3.25946627477 + 1286.9081196288*t)
	X0 += 0.00000006633*np.cos(4.94232868304 + 268.9582388941*t)
	X0 += 0.00000008880*np.cos(3.02316114149 + 190.4045457581*t)
	X0 += 0.00000006821*np.cos(3.22173264763 + 449.232108125*t)
	X0 += 0.00000008020*np.cos(2.83765342663 + 184.0941479094*t)
	X0 += 0.00000007759*np.cos(0.59545004290 + 343.7398374614*t)
	X0 += 0.00000006349*np.cos(4.28763974443 + 313.9441891018*t)
	X0 += 0.00000006598*np.cos(1.23499026160 + 88.1149206916*t)
	X0 += 0.00000007453*np.cos(2.14642578463 + 128.3655684841*t)
	X0 += 0.00000006299*np.cos(3.53707343862 + 180.1619946463*t)
	X0 += 0.00000006291*np.cos(1.49724070505 + 117.9105690512*t)
	X0 += 0.00000006901*np.cos(4.51033589337 + 249.9476583675*t)
	X0 += 0.00000006082*np.cos(3.98547423322 + 3480.3105662226*t)
	X0 += 0.00000007570*np.cos(3.02872932452 + 990.2294059144*t)
	X0 += 0.00000007221*np.cos(3.65873711017 + 25.6028626656*t)
	X0 += 0.00000006057*np.cos(4.42905421891 + 856.3777754897*t)
	X0 += 0.00000007434*np.cos(4.00728594079 + 25.1297819136*t)
	X0 += 0.00000006039*np.cos(0.10556534688 + 505.3119427064*t)
	X0 += 0.00000007951*np.cos(1.45628295823 + 105.5404547734*t)
	X0 += 0.00000006123*np.cos(1.05416533583 + 328.9220426288*t)
	X0 += 0.00000007410*np.cos(2.80785687723 + 1802.3719907218*t)
	X0 += 0.00000007544*np.cos(5.83384851183 + 909.8187330546*t)
	X0 += 0.00000006330*np.cos(3.88531739474 + 110.7275860812*t)
	X0 += 0.00000006147*np.cos(0.67579092414 + 639.3760214522*t)
	X0 += 0.00000005898*np.cos(1.62352162391 + 843.6351541964*t)
	X0 += 0.00000006028*np.cos(3.32686859305 + 115.6229471908*t)
	X0 += 0.00000006743*np.cos(1.58035790221 + 418.9633790134*t)
	X0 += 0.00000006188*np.cos(0.49567067980 + 739.0579072695*t)
	X0 += 0.00000005894*np.cos(6.06611517396 + 120.9913890524*t)
	X0 += 0.00000006621*np.cos(5.03610613312 + 95.3885263868*t)
	X0 += 0.00000006841*np.cos(2.32904410339 + 141.4864422873*t)
	X0 += 0.00000005992*np.cos(0.19285412187 + 336.8387387817*t)
	X0 += 0.00000007883*np.cos(1.86032213862 + 236.1936451179*t)
	X0 += 0.00000005661*np.cos(2.58262833641 + 123.5396433437*t)
	X0 += 0.00000005819*np.cos(0.09149815737 + 215.9592243139*t)
	X0 += 0.00000005819*np.cos(4.79812800922 + 210.6389665621*t)
	X0 += 0.00000006190*np.cos(3.38729700678 + 109.6850563576*t)
	X0 += 0.00000007742*np.cos(0.34415356371 + 55.6591434561*t)
	X0 += 0.00000005694*np.cos(5.43835853469 + 760.25553592*t)
	X0 += 0.00000007522*np.cos(5.29284930513 + 195.8906076987*t)
	X0 += 0.00000006763*np.cos(1.17534779375 + 1048.3362299253*t)
	X0 += 0.00000005984*np.cos(5.51254229373 + 2200.5159935946*t)
	X0 += 0.00000007444*np.cos(3.03494365469 + 25.2727942655*t)
	X0 += 0.00000005776*np.cos(3.77825555332 + 97.4155158163*t)
	X0 += 0.00000006036*np.cos(0.39078322489 + 769.8167634756*t)
	X0 += 0.00000005771*np.cos(0.05336444936 + 164.5410506616*t)
	X0 += 0.00000006703*np.cos(0.80548964242 + 611.4430983108*t)
	X0 += 0.00000006085*np.cos(0.58940873359 + 433.190473015*t)
	X0 += 0.00000006082*np.cos(1.19286005781 + 640.4185511758*t)
	X0 += 0.00000005677*np.cos(1.79542287271 + 218.4069048687*t)
	X0 += 0.00000005677*np.cos(3.09420329388 + 208.1912860073*t)
	X0 += 0.00000006571*np.cos(2.03293250235 + 1130.2313754934*t)
	X0 += 0.00000006037*np.cos(6.25609827209 + 597.3590166611*t)
	X0 += 0.00000006462*np.cos(5.68467908647 + 369.9758395734*t)
	X0 += 0.00000006508*np.cos(0.80289146979 + 566.600160455*t)
	X0 += 0.00000005024*np.cos(0.18128124566 + 806.725958836*t)
	X0 += 0.00000005596*np.cos(6.00166997853 + 108.7218485111*t)
	X0 += 0.00000005096*np.cos(4.69337848431 + 262.0571402144*t)
	X0 += 0.00000005584*np.cos(4.09591630918 + 200.5564741447*t)
	X0 += 0.00000004890*np.cos(5.53191489233 + 331.2096644892*t)
	X0 += 0.00000004909*np.cos(5.20095693748 + 298.2326223919*t)
	X0 += 0.00000005201*np.cos(2.45613065009 + 746.9222137957*t)
	X0 += 0.00000005769*np.cos(1.28477282445 + 320.5846553506*t)
	X0 += 0.00000005914*np.cos(5.62754393946 + 310.7146112543*t)
	X0 += 0.00000006262*np.cos(1.63342326112 + 850.0149880143*t)
	X0 += 0.00000005900*np.cos(2.28550106807 + 3583.4033404412*t)
	X0 += 0.00000005515*np.cos(5.67488096006 + 551.031606097*t)
	X0 += 0.00000005599*np.cos(4.68574003719 + 58.1068240109*t)
	X0 += 0.00000004849*np.cos(1.54472616566 + 124.5028511902*t)
	X0 += 0.00000006433*np.cos(3.97004927835 + 348.635198571*t)
	X0 += 0.00000004798*np.cos(0.51398456833 + 170.7608257851*t)
	X0 += 0.00000005352*np.cos(1.67434983291 + 604.4725636619*t)
	X0 += 0.00000004977*np.cos(4.78098618763 + 178.086821107*t)
	X0 += 0.00000005019*np.cos(5.07746652322 + 1044.4040766622*t)
	X0 += 0.00000004699*np.cos(5.64438940211 + 439.9315130003*t)
	X0 += 0.00000005132*np.cos(4.99955185305 + 88.7962442478*t)
	X0 += 0.00000005636*np.cos(0.71123925881 + 499.895316735*t)
	X0 += 0.00000005591*np.cos(2.54795843844 + 285.1117485887*t)
	X0 += 0.00000004650*np.cos(4.46967285108 + 271.4059194489*t)
	X0 += 0.00000006065*np.cos(3.67428256045 + 55.1378785943*t)
	X0 += 0.00000005035*np.cos(0.56276653096 + 658.0565335787*t)
	X0 += 0.00000005063*np.cos(1.68875674251 + 774.4826299216*t)
	X0 += 0.00000004622*np.cos(3.21978369593 + 3686.4961146598*t)
	X0 += 0.00000004618*np.cos(5.47461001336 + 634.2682120215*t)
	X0 += 0.00000005322*np.cos(3.30473124435 + 484.7050148869*t)
	X0 += 0.00000005515*np.cos(5.87001298520 + 455.1699989582*t)
	X0 += 0.00000005556*np.cos(1.42370049360 + 486.4019359163*t)
	X0 += 0.00000004834*np.cos(2.10033655923 + 104.0559820651*t)
	X0 += 0.00000004936*np.cos(5.96187000337 + 43.1289704839*t)
	X0 += 0.00000004507*np.cos(5.23081644191 + 732.6951197941*t)
	X0 += 0.00000004459*np.cos(5.51910339097 + 745.277682393*t)
	X0 += 0.00000005599*np.cos(5.57825850766 + 952.0963702766*t)
	X0 += 0.00000005864*np.cos(5.53324867687 + 385.5443939314*t)
	X0 += 0.00000005551*np.cos(4.94468510351 + 493.303034596*t)
	X0 += 0.00000004493*np.cos(5.35984494325 + 3377.217792004*t)
	X0 += 0.00000004770*np.cos(3.19401209745 + 991.7138786227*t)
	X0 += 0.00000004717*np.cos(1.99096492023 + 104.5772469269*t)
	X0 += 0.00000004781*np.cos(3.88757701071 + 504.561183181*t)
	X0 += 0.00000004811*np.cos(4.61942610145 + 327.6982023514*t)
	X0 += 0.00000004442*np.cos(1.62929961065 + 2538.2485042536*t)
	X0 += 0.00000005958*np.cos(4.92614870987 + 25.8634950965*t)
	X0 += 0.00000004453*np.cos(1.49117065737 + 198.4813006054*t)
	X0 += 0.00000004332*np.cos(1.57527271192 + 636.9765250072*t)
	X0 += 0.00000004513*np.cos(2.85438575456 + 26.826702943*t)
	X0 += 0.00000005809*np.cos(4.81932495515 + 254.3528923826*t)
	X0 += 0.00000004384*np.cos(2.84168114097 + 113.1270825262*t)
	X0 += 0.00000004282*np.cos(5.65363400412 + 840.6662087798*t)
	X0 += 0.00000004886*np.cos(3.63166667952 + 201.5196819912*t)
	X0 += 0.00000005016*np.cos(2.09046597167 + 969.6224780949*t)
	X0 += 0.00000005361*np.cos(5.94947162548 + 2957.7331481288*t)
	X0 += 0.00000004205*np.cos(5.66354698683 + 1141.1340634054*t)
	X0 += 0.00000004536*np.cos(2.79117546568 + 958.576777831*t)
	X0 += 0.00000005345*np.cos(4.72267996291 + 305.0855369618*t)
	X0 += 0.00000004627*np.cos(1.25635250543 + 775.233389447*t)
	X0 += 0.00000004067*np.cos(4.95801020752 + 103.1409583284*t)
	X0 += 0.00000004243*np.cos(4.31618117654 + 3473.1970192218*t)
	X0 += 0.00000004845*np.cos(3.84775416722 + 226.0417167313*t)
	X0 += 0.00000004049*np.cos(4.11924182490 + 372.4235201282*t)
	X0 += 0.00000004900*np.cos(2.55288578170 + 376.1956146969*t)
	X0 += 0.00000005025*np.cos(5.95342304346 + 721.6494195302*t)
	X0 += 0.00000004077*np.cos(5.03795321512 + 650.1922270525*t)
	X0 += 0.00000004372*np.cos(4.29308416788 + 225.0785088848*t)
	X0 += 0.00000004173*np.cos(1.85843228263 + 211.0114735776*t)
	X0 += 0.00000004173*np.cos(3.03119388396 + 215.5867172984*t)
	X0 += 0.00000004251*np.cos(0.70715248384 + 771.3012361839*t)
	X0 += 0.00000004060*np.cos(3.39845529642 + 228.1168902706*t)
	X0 += 0.00000004018*np.cos(1.44814155604 + 631.8205314667*t)
	X0 += 0.00000004766*np.cos(5.31180947705 + 424.9012698466*t)
	X0 += 0.00000004146*np.cos(2.86854280828 + 2118.7638603784*t)
	X0 += 0.00000003945*np.cos(5.69539937683 + 337.8019466282*t)
	X0 += 0.00000005029*np.cos(0.09918962647 + 197.257460328*t)
	X0 += 0.00000005430*np.cos(2.20843836599 + 481.7360694703*t)
	X0 += 0.00000005129*np.cos(5.44565533795 + 207.6218370357*t)
	X0 += 0.00000005129*np.cos(5.72715613582 + 218.9763538403*t)
	X0 += 0.00000003855*np.cos(5.22645171016 + 425.3743505986*t)
	X0 += 0.00000003906*np.cos(2.26422119383 + 561.934294009*t)
	X0 += 0.00000003860*np.cos(4.85683625563 + 512.4254897072*t)
	X0 += 0.00000004220*np.cos(4.94104825465 + 102.1295663721*t)
	X0 += 0.00000003855*np.cos(4.44425417057 + 427.8220311534*t)
	X0 += 0.00000004133*np.cos(1.76751139179 + 103.0445901088*t)
	X0 += 0.00000005008*np.cos(3.00713483837 + 17.2654753874*t)
	X0 += 0.00000004043*np.cos(6.12585155815 + 317.3550775031*t)
	X0 += 0.00000003992*np.cos(0.10863881475 + 248.511369769*t)
	X0 += 0.00000003810*np.cos(2.51661775808 + 316.4400537664*t)
	X0 += 0.00000004737*np.cos(1.84385858957 + 913.9633346388*t)
	X0 += 0.00000004500*np.cos(0.17524918916 + 519.3960243561*t)
	X0 += 0.00000003904*np.cos(2.21361301063 + 378.9039276826*t)
	X0 += 0.00000004533*np.cos(2.70360699200 + 187.2755416471*t)
	X0 += 0.00000003961*np.cos(6.02031538242 + 49.7212526229*t)
	X0 += 0.00000003770*np.cos(4.79955563925 + 214.6716935617*t)
	X0 += 0.00000003770*np.cos(0.09007052734 + 211.9264973143*t)
	X0 += 0.00000004880*np.cos(0.60377262547 + 120.5012619579*t)
	X0 += 0.00000003729*np.cos(0.34904169037 + 407.4757357648*t)
	X0 += 0.00000003673*np.cos(1.39200838994 + 668.2084619653*t)
	X0 += 0.00000003788*np.cos(4.13636636049 + 258.5456780766*t)
	X0 += 0.00000003638*np.cos(6.22563045614 + 634.4806603426*t)
	X0 += 0.00000003968*np.cos(5.56983671727 + 398.2870152247*t)
	X0 += 0.00000003571*np.cos(4.16908170855 + 2730.2069586892*t)
	X0 += 0.00000003567*np.cos(5.46257677177 + 623.2225117576*t)
	X0 += 0.00000003562*np.cos(0.28991457103 + 700.6642392008*t)
	X0 += 0.00000003820*np.cos(1.98270616092 + 328.2407190726*t)
	X0 += 0.00000003710*np.cos(3.60752296582 + 22.8945496799*t)
	X0 += 0.00000004542*np.cos(1.45826982445 + 491.5579294568*t)
	X0 += 0.00000003548*np.cos(2.80584934201 + 71.6002048296*t)
	X0 += 0.00000004509*np.cos(4.78400214531 + 229.340730548*t)
	X0 += 0.00000003567*np.cos(0.22693346941 + 48.7580447764*t)
	X0 += 0.00000004753*np.cos(4.82350219524 + 1033.3583763983*t)
	X0 += 0.00000003649*np.cos(3.53826646640 + 444.1242986943*t)
	X0 += 0.00000004339*np.cos(5.05440607437 + 608.877797677*t)
	X0 += 0.00000003452*np.cos(3.19273243429 + 188.0263011725*t)
	X0 += 0.00000004668*np.cos(2.31177528169 + 60.5545045657*t)
	X0 += 0.00000003751*np.cos(2.61178091734 + 1119.1856752295*t)
	X0 += 0.00000003677*np.cos(4.85446825853 + 418.7338843498*t)
	X0 += 0.00000003519*np.cos(5.41450486643 + 707.5653378805*t)
	X0 += 0.00000003496*np.cos(0.40428886685 + 616.3214130779*t)
	X0 += 0.00000004380*np.cos(4.31147715738 + 526.9826521089*t)
	X0 += 0.00000003352*np.cos(0.72463251624 + 691.1030116452*t)
	X0 += 0.00000003359*np.cos(5.44969389586 + 842.9014410135*t)
	X0 += 0.00000004413*np.cos(0.86251574445 + 43.2890291783*t)
	X0 += 0.00000003919*np.cos(4.80852982048 + 141.6988906084*t)
	X0 += 0.00000003858*np.cos(4.90751231957 + 635.231419868*t)
	X0 += 0.00000004154*np.cos(4.98287829121 + 317.8763423649*t)
	X0 += 0.00000003282*np.cos(1.34273841324 + 211.762233103*t)
	X0 += 0.00000003282*np.cos(3.54688775335 + 214.835957773*t)
	X0 += 0.00000003462*np.cos(5.28874398045 + 6275.9623029906*t)
	X0 += 0.00000003329*np.cos(2.94000486288 + 765.8846102125*t)
	X0 += 0.00000003787*np.cos(5.85679753021 + 652.4274592862*t)
	X0 += 0.00000003775*np.cos(5.60221993472 + 316.3436855468*t)
	X0 += 0.00000003196*np.cos(4.55749476039 + 827.9235874865*t)
	X0 += 0.00000003669*np.cos(1.26608108937 + 80.1982245387*t)
	X0 += 0.00000003691*np.cos(0.48718733608 + 194.2885149114*t)
	X0 += 0.00000003467*np.cos(4.32351780506 + 428.2951119054*t)
	X0 += 0.00000004055*np.cos(0.58820420847 + 92.3077063856*t)
	X0 += 0.00000003131*np.cos(5.94102893952 + 306.830642101*t)
	X0 += 0.00000003280*np.cos(0.44836167723 + 10206.1719992102*t)
	X0 += 0.00000003411*np.cos(5.25293859876 + 2516.9078632512*t)
	X0 += 0.00000004132*np.cos(1.72276410779 + 434.2330027386*t)
	X0 += 0.00000003810*np.cos(4.51464393472 + 114.9416236346*t)
	X0 += 0.00000003975*np.cos(4.55663174904 + 101.8689339412*t)
	X0 += 0.00000004288*np.cos(2.13145763000 + 187.6962327724*t)
	X0 += 0.00000003522*np.cos(2.64133662278 + 315.1680293792*t)
	X0 += 0.00000003066*np.cos(3.74972662168 + 167.0893049529*t)
	X0 += 0.00000003242*np.cos(4.09907147245 + 282.6640680339*t)
	X0 += 0.00000003110*np.cos(4.53477861170 + 165.6048322446*t)
	X0 += 0.00000003898*np.cos(5.51287081695 + 318.8395502114*t)
	X0 += 0.00000003396*np.cos(0.34591089696 + 37.8724032069*t)
	X0 += 0.00000003526*np.cos(5.16158818006 + 495.9631634719*t)
	X0 += 0.00000003045*np.cos(1.65993856041 + 2854.6403739102*t)
	X0 += 0.00000003020*np.cos(3.91237540740 + 3796.7024358792*t)
	X0 += 0.00000002986*np.cos(2.56850390941 + 92.7978334801*t)
	X0 += 0.00000003500*np.cos(4.38440462601 + 789.4604834486*t)
	X0 += 0.00000002995*np.cos(2.81664751125 + 91.7864415238*t)
	X0 += 0.00000003539*np.cos(0.99888072542 + 232.942815411*t)
	X0 += 0.00000002920*np.cos(1.23618862034 + 625.8826406335*t)
	X0 += 0.00000002918*np.cos(3.43409170637 + 357.2332182801*t)
	X0 += 0.00000003176*np.cos(5.31403301104 + 281.1795953256*t)
	X0 += 0.00000003438*np.cos(1.70954494565 + 40.8413486235*t)
	X0 += 0.00000003008*np.cos(4.10197187210 + 434.4624974022*t)
	X0 += 0.00000003409*np.cos(4.69167159712 + 77.2292791221*t)
	X0 += 0.00000003572*np.cos(1.37113437514 + 851.7119090437*t)
	X0 += 0.00000003076*np.cos(2.32677490754 + 130.4407420234*t)
	X0 += 0.00000002804*np.cos(4.40192840756 + 425.1619022775*t)
	X0 += 0.00000003278*np.cos(4.40243851704 + 232.3096759646*t)
	X0 += 0.00000002856*np.cos(0.45182720699 + 544.5087599272*t)
	X0 += 0.00000003073*np.cos(5.89479692757 + 3274.1250177854*t)
	X0 += 0.00000003735*np.cos(2.28131065621 + 315.4286618101*t)
	X0 += 0.00000003542*np.cos(2.10431928280 + 239.3226492289*t)
	X0 += 0.00000002887*np.cos(2.09394741374 + 93.531546663*t)
	X0 += 0.00000002753*np.cos(1.91591889937 + 1063.3140834523*t)
	X0 += 0.00000002754*np.cos(3.20876354263 + 620.253566341*t)
	X0 += 0.00000002804*np.cos(5.26877747317 + 428.0344794745*t)
	X0 += 0.00000003749*np.cos(5.48742893669 + 145.4185955504*t)
	X0 += 0.00000003056*np.cos(2.25124826101 + 354.2642728635*t)
	X0 += 0.00000002944*np.cos(1.57941122467 + 42.3258213318*t)
	X0 += 0.00000003422*np.cos(2.77554592584 + 268.4369740323*t)
	X0 += 0.00000002693*np.cos(5.92886276832 + 432.9609783514*t)
	X0 += 0.00000003406*np.cos(6.14851742084 + 498.9321088885*t)
	X0 += 0.00000003270*np.cos(2.70575765331 + 924.0458270562*t)
	X0 += 0.00000003462*np.cos(0.16427456264 + 182.5402392319*t)
	X0 += 0.00000003693*np.cos(2.74095304329 + 238.9019581036*t)
	X0 += 0.00000002752*np.cos(3.53715013471 + 322.0209439491*t)
	X0 += 0.00000003056*np.cos(5.41339084119 + 179.5712938153*t)
	X0 += 0.00000003320*np.cos(2.19510410160 + 122.7364941916*t)
	X0 += 0.00000002722*np.cos(1.90912932797 + 644.090072008*t)
	X0 += 0.00000002640*np.cos(5.38886758602 + 110.9570807448*t)
	X0 += 0.00000002578*np.cos(5.28716556602 + 305.6068018236*t)
	X0 += 0.00000003099*np.cos(5.46033388346 + 699.7010313543*t)
	X0 += 0.00000002579*np.cos(6.17990568201 + 953.1077622329*t)
	X0 += 0.00000002666*np.cos(3.91979516134 + 1080.7225711916*t)
	X0 += 0.00000002603*np.cos(4.71971033929 + 508.4933364441*t)
	X0 += 0.00000002559*np.cos(5.36447720972 + 639.1465267886*t)
	X0 += 0.00000003052*np.cos(5.04923062913 + 541.5398145106*t)
	X0 += 0.00000002581*np.cos(2.63020337570 + 158.9643659958*t)
	X0 += 0.00000002686*np.cos(0.15925446852 + 642.8180476208*t)
	X0 += 0.00000002828*np.cos(3.75586347766 + 256.4280659219*t)
	X0 += 0.00000003364*np.cos(6.07299583147 + 133.1008708993*t)
	X0 += 0.00000002945*np.cos(3.64179989725 + 346.3999663373*t)
	X0 += 0.00000002473*np.cos(1.69595483874 + 109.455561694*t)
	X0 += 0.00000002541*np.cos(3.95256698363 + 2627.1141844706*t)
	X0 += 0.00000002455*np.cos(4.87312623650 + 1049.0869894507*t)
	X0 += 0.00000002558*np.cos(1.52714175495 + 310.9752436852*t)
	X0 += 0.00000002441*np.cos(0.71752432785 + 586.3133163972*t)
	X0 += 0.00000002660*np.cos(3.15325492704 + 443.2729654324*t)
	X0 += 0.00000002430*np.cos(3.16920826862 + 95.2284676924*t)
	X0 += 0.00000002407*np.cos(0.16112430483 + 111.4301614968*t)
	X0 += 0.00000002431*np.cos(1.26439356329 + 235.933012687*t)
	X0 += 0.00000002845*np.cos(2.05201739396 + 531.978586955*t)
	X0 += 0.00000002521*np.cos(2.31197583573 + 451.7279727896*t)
	X0 += 0.00000002393*np.cos(2.81359164609 + 2435.155730035*t)
	X0 += 0.00000002990*np.cos(5.57751092323 + 782.3469364478*t)
	X0 += 0.00000002655*np.cos(5.30662457895 + 440.6128365565*t)
	X0 += 0.00000002369*np.cos(0.84466299231 + 205.9731001161*t)
	X0 += 0.00000002369*np.cos(0.90337052069 + 220.6250907599*t)
	X0 += 0.00000002902*np.cos(1.05411548466 + 514.7131115676*t)
	X0 += 0.00000003238*np.cos(4.15318242424 + 338.4832701844*t)
	X0 += 0.00000002324*np.cos(3.98030953004 + 3046.5988283458*t)
	X0 += 0.00000002589*np.cos(0.03607192436 + 526.7702037878*t)
	X0 += 0.00000002701*np.cos(5.31010726656 + 300.6108669775*t)
	X0 += 0.00000002780*np.cos(4.37370836037 + 173.6815870919*t)
	X0 += 0.00000002707*np.cos(2.11193249903 + 176.3899000776*t)
	X0 += 0.00000002952*np.cos(2.31378455663 + 645.5263606065*t)
	X0 += 0.00000002579*np.cos(3.01647667365 + 768.8535556291*t)
	X0 += 0.00000002253*np.cos(2.22683989192 + 310.1720945331*t)
	X0 += 0.00000002284*np.cos(2.06301575790 + 297.6419215609*t)
	X0 += 0.00000002264*np.cos(2.70110641487 + 104.789695248*t)
	X0 += 0.00000002301*np.cos(3.65558835862 + 263.0203480609*t)
	X0 += 0.00000002531*np.cos(5.13512447782 + 90.5626012464*t)
	X0 += 0.00000002331*np.cos(1.28063056772 + 518.3846323998*t)
	X0 += 0.00000002380*np.cos(0.88280891663 + 151.260118164*t)
	X0 += 0.00000002990*np.cos(4.19616629872 + 1056.2005364515*t)
	X0 += 0.00000002214*np.cos(2.22525274083 + 64.9597385808*t)
	X0 += 0.00000003045*np.cos(1.33956207243 + 485.8806710545*t)
	X0 += 0.00000002520*np.cos(3.36033478916 + 685.4739373527*t)
	X0 += 0.00000002594*np.cos(5.66621296914 + 520.129737539*t)
	X0 += 0.00000002863*np.cos(4.71904318311 + 244.0579516441*t)
	X0 += 0.00000002198*np.cos(1.53245970000 + 945.2434557067*t)
	X0 += 0.00000002811*np.cos(1.38980153585 + 641.3817590223*t)
	X0 += 0.00000002590*np.cos(0.63795679785 + 170.1701249541*t)
	X0 += 0.00000002192*np.cos(5.38214041197 + 1457.525933062*t)
	X0 += 0.00000002177*np.cos(2.60434709441 + 67.8804998876*t)
	X0 += 0.00000002285*np.cos(5.28065763454 + 3693.6096616606*t)
	X0 += 0.00000002386*np.cos(4.37257867425 + 430.7427924602*t)
	X0 += 0.00000002131*np.cos(0.06257344923 + 1382.8873468466*t)
	X0 += 0.00000002457*np.cos(5.75336601172 + 247.0268970607*t)
	X0 += 0.00000002125*np.cos(1.82804301978 + 487.1526954417*t)
	X0 += 0.00000002518*np.cos(6.01723329840 + 1038.0412891868*t)
	X0 += 0.00000002091*np.cos(1.35636529813 + 3171.0322435668*t)
	X0 += 0.00000002102*np.cos(4.35040361644 + 960.2213092337*t)
	X0 += 0.00000002250*np.cos(5.37793316456 + 366.0436863103*t)
	X0 += 0.00000002818*np.cos(0.74477457405 + 837.6972633632*t)
	X0 += 0.00000002261*np.cos(0.51819117829 + 183.2428146475*t)
	X0 += 0.00000002071*np.cos(2.17194520595 + 354.9979860464*t)
	X0 += 0.00000002403*np.cos(2.26992497484 + 452.2010535416*t)
	X0 += 0.00000002384*np.cos(2.06538211924 + 3899.7952100978*t)
	X0 += 0.00000002564*np.cos(3.29999345582 + 427.4919627533*t)
	X0 += 0.00000002136*np.cos(3.54044416897 + 1108.1399749656*t)
	X0 += 0.00000002111*np.cos(5.24419959900 + 422.4535892918*t)
	X0 += 0.00000002308*np.cos(3.09971194846 + 154.979823106*t)
	X0 += 0.00000002409*np.cos(0.88586446483 + 306.0969289181*t)
	X0 += 0.00000002581*np.cos(2.78681732927 + 1041.2226829245*t)
	X0 += 0.00000002016*np.cos(1.08557176939 + 883.7951792637*t)
	X0 += 0.00000002203*np.cos(2.74611438181 + 49.5088043018*t)
	X0 += 0.00000002083*np.cos(4.04786990254 + 275.338072712*t)
	X0 += 0.00000002346*np.cos(5.96958886629 + 447.2051186955*t)
	X0 += 0.00000002490*np.cos(5.97604559832 + 2487.4160449478*t)
	X0 += 0.00000002521*np.cos(0.54835814181 + 927.8349679674*t)
	X0 += 0.00000001993*np.cos(0.73100346778 + 624.919432787*t)
	X0 += 0.00000002652*np.cos(1.01663860481 + 453.424893819*t)
	X0 += 0.00000002467*np.cos(1.16140871474 + 429.5671362926*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000001995*np.cos(5.64222397445 + 409.3327154886*t)
	X0 += 0.00000002513*np.cos(4.76844959033 + 125.1841747464*t)
	X0 += 0.00000002053*np.cos(2.05591891799 + 90.8232336773*t)
	X0 += 0.00000002205*np.cos(3.39623617614 + 170.9732741062*t)
	X0 += 0.00000002207*np.cos(1.51125342980 + 635.70450062*t)
	X0 += 0.00000001873*np.cos(5.39713666127 + 344.8460576598*t)
	X0 += 0.00000002386*np.cos(4.15983782692 + 25234.70675982219*t)
	X0 += 0.00000002258*np.cos(5.14806130138 + 1008.9793540101*t)
	X0 += 0.00000002199*np.cos(3.67407324592 + 784.0438574772*t)
	X0 += 0.00000002564*np.cos(0.08752711773 + 425.7044189987*t)
	X0 += 0.00000001850*np.cos(3.46362842651 + 528.9402055692*t)
	X0 += 0.00000001964*np.cos(2.72517368869 + 40.1600250673*t)
	X0 += 0.00000001952*np.cos(4.34777048454 + 115.8353955119*t)
	X0 += 0.00000002542*np.cos(0.28050831901 + 354.7855377253*t)
	X0 += 0.00000001916*np.cos(3.22097581831 + 102.5715093568*t)
	X0 += 0.00000002296*np.cos(5.31801448840 + 180.8433182025*t)
	X0 += 0.00000002393*np.cos(5.91612529116 + 614.6244920485*t)
	X0 += 0.00000002397*np.cos(0.99397031563 + 1364.7280995819*t)
	X0 += 0.00000001833*np.cos(2.25941996337 + 267.6338248802*t)
	X0 += 0.00000002131*np.cos(3.67200185333 + 103.6140390804*t)
	X0 += 0.00000002098*np.cos(0.08769001353 + 252.9166037841*t)
	X0 += 0.00000002063*np.cos(5.99371300183 + 177.1236132605*t)
	X0 += 0.00000002479*np.cos(5.27883727495 + 631.2992666049*t)
	X0 += 0.00000001811*np.cos(0.88009473694 + 530.44172462*t)
	X0 += 0.00000002017*np.cos(4.33633811733 + 243.3553762285*t)
	X0 += 0.00000001781*np.cos(0.19920025414 + 205.9249160063*t)
	X0 += 0.00000001781*np.cos(1.54883325886 + 220.6732748697*t)
	X0 += 0.00000002268*np.cos(0.06736545150 + 1171.875873269*t)
	X0 += 0.00000002271*np.cos(5.09542141062 + 192.8040422031*t)
	X0 += 0.00000002271*np.cos(6.07739006315 + 233.7941486729*t)
	X0 += 0.00000001785*np.cos(4.70446916733 + 1097.0942747017*t)
	X0 += 0.00000002111*np.cos(4.95171731483 + 670.916774951*t)
	X0 += 0.00000001859*np.cos(1.45447173175 + 1083.7609525774*t)
	X0 += 0.00000001774*np.cos(4.90826773112 + 206.4461808681*t)
	X0 += 0.00000001774*np.cos(3.12295108906 + 220.1520100079*t)
	X0 += 0.00000002018*np.cos(2.80222113517 + 250.2082907984*t)
	X0 += 0.00000002009*np.cos(0.61518299906 + 103.3534066495*t)
	X0 += 0.00000002121*np.cos(5.65835197937 + 799.6124118352*t)
	X0 += 0.00000002292*np.cos(6.18688041096 + 912.4788619305*t)
	X0 += 0.00000001775*np.cos(2.38950039489 + 198.1087935899*t)
	X0 += 0.00000001775*np.cos(5.64171842529 + 228.4893972861*t)
	X0 += 0.00000001744*np.cos(5.54811865717 + 1166.4068576709*t)
	X0 += 0.00000001994*np.cos(0.23060158863 + 5849.3641121146*t)
	X0 += 0.00000001763*np.cos(5.61852245031 + 284.8993002676*t)
	X0 += 0.00000001710*np.cos(4.04740475434 + 1176.7017984094*t)
	X0 += 0.00000002094*np.cos(6.21687355107 + 835.7878940127*t)
	X0 += 0.00000001962*np.cos(1.66381480115 + 9779.5738083342*t)
	X0 += 0.00000002299*np.cos(6.24627458730 + 409.1897031367*t)
	X0 += 0.00000001786*np.cos(4.97887009884 + 346.1875180162*t)
	X0 += 0.00000001703*np.cos(1.00725031850 + 398.1440028728*t)
	X0 += 0.00000002083*np.cos(2.24494666476 + 5216.5803728014*t)
	X0 += 0.00000002072*np.cos(2.05694305195 + 45.2465826386*t)
	X0 += 0.00000001736*np.cos(2.08834850954 + 134.1122628556*t)
	X0 += 0.00000001707*np.cos(4.00371360898 + 1062.5633239269*t)
	X0 += 0.00000001708*np.cos(3.20756177408 + 3120.199784261*t)
	X0 += 0.00000001823*np.cos(5.21279378269 + 657.1627617014*t)
	X0 += 0.00000001792*np.cos(4.15157588985 + 3789.5888888784*t)
	X0 += 0.00000001836*np.cos(2.92694247168 + 644.56315276*t)
	X0 += 0.00000001759*np.cos(2.26827767388 + 2751.5475996916*t)
	X0 += 0.00000001684*np.cos(3.80248371853 + 3362.9906980024*t)
	X0 += 0.00000002081*np.cos(1.45707089705 + 587.2070882745*t)
	X0 += 0.00000001725*np.cos(1.32648620918 + 6290.1893969922*t)
	X0 += 0.00000001760*np.cos(1.05809960446 + 1091.6252591036*t)
	X0 += 0.00000001707*np.cos(2.05213382658 + 98.3574718034*t)
	X0 += 0.00000002178*np.cos(3.29717293610 + 118.0706277456*t)
	X0 += 0.00000002021*np.cos(5.89628715728 + 913.7508863177*t)
	X0 += 0.00000001805*np.cos(2.74507477460 + 1389.1071219701*t)
	X0 += 0.00000001776*np.cos(0.05672546557 + 533.8837507886*t)
	X0 += 0.00000001780*np.cos(1.68202888730 + 9772.4602613334*t)
	X0 += 0.00000001687*np.cos(2.77110409640 + 10220.3990932118*t)
	X0 += 0.00000001942*np.cos(0.62508676865 + 246.4361962297*t)
	X0 += 0.00000001682*np.cos(5.71772687954 + 3590.516887442*t)
	X0 += 0.00000001585*np.cos(2.94676152634 + 4002.8879843164*t)
	X0 += 0.00000001942*np.cos(3.67572077367 + 9146.790069021*t)
	X0 += 0.00000002092*np.cos(5.60181404740 + 629.6023455755*t)
	X0 += 0.00000001930*np.cos(1.68011034900 + 271.61836777*t)
	X0 += 0.00000002109*np.cos(3.48166538243 + 757.8078553652*t)
	X0 += 0.00000002179*np.cos(0.28655950016 + 666.723989257*t)
	X0 += 0.00000001581*np.cos(5.53424328275 + 1159.2933106701*t)
	X0 += 0.00000001856*np.cos(4.17411768121 + 322.6116447801*t)
	X0 += 0.00000001568*np.cos(4.53671740651 + 122.4758617607*t)
	X0 += 0.00000001879*np.cos(5.27290591309 + 134.0640787458*t)
	X0 += 0.00000001594*np.cos(5.13131160823 + 624.3981679252*t)
	X0 += 0.00000001760*np.cos(4.32007497090 + 734.9133056853*t)
	X0 += 0.00000001764*np.cos(6.15149779828 + 560.7104537316*t)
	X0 += 0.00000001662*np.cos(3.01056999288 + 934.1977554428*t)
	X0 += 0.00000001644*np.cos(2.70575030230 + 525.0250986486*t)
	X0 += 0.00000001715*np.cos(5.05042473287 + 709.0498105888*t)
	X0 += 0.00000001878*np.cos(3.19550384063 + 155.7829722581*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001653*np.cos(4.89962084723 + 318.679491517*t)
	X0 += 0.00000001742*np.cos(3.52477579020 + 58.319272332*t)
	X0 += 0.00000001584*np.cos(5.28343542578 + 3767.2106175758*t)
	X0 += 0.00000001503*np.cos(0.64126765918 + 315.8706047948*t)
	X0 += 0.00000001617*np.cos(2.39186277432 + 83.3796182764*t)
	X0 += 0.00000001522*np.cos(5.52609090590 + 406.1513217509*t)
	X0 += 0.00000001505*np.cos(4.00358265141 + 447.0450600011*t)
	X0 += 0.00000001511*np.cos(0.91634243175 + 1748.0372612796*t)
	X0 += 0.00000001830*np.cos(0.63474599912 + 259.5088859231*t)
	X0 += 0.00000001807*np.cos(0.06769453319 + 1193.9672737968*t)
	X0 += 0.00000001856*np.cos(3.57858164701 + 679.2541622292*t)
	X0 += 0.00000001519*np.cos(3.82968892812 + 1144.3154571431*t)
	X0 += 0.00000001498*np.cos(1.98604619754 + 174.6929790482*t)
	X0 += 0.00000001575*np.cos(0.59855315484 + 700.4517908797*t)
	X0 += 0.00000001458*np.cos(2.80570485080 + 415.2918581812*t)
	X0 += 0.00000002009*np.cos(3.89257651333 + 1372.5924061081*t)
	X0 += 0.00000001835*np.cos(5.85413600592 + 245.7548726735*t)
	X0 += 0.00000001577*np.cos(4.21988525964 + 9793.8009023358*t)
	X0 += 0.00000001662*np.cos(2.33876751022 + 1357.6145525811*t)
	X0 += 0.00000001445*np.cos(1.36342810835 + 105.380396079*t)
	X0 += 0.00000002000*np.cos(4.35736030829 + 527.2432845398*t)
	X0 += 0.00000001785*np.cos(1.83848903190 + 736.8397213783*t)
	X0 += 0.00000001645*np.cos(5.17909722343 + 249.4745776155*t)
	X0 += 0.00000001495*np.cos(3.22730936805 + 77623.81213840858*t)
	X0 += 0.00000001503*np.cos(2.59801643048 + 413.8555695827*t)
	X0 += 0.00000001889*np.cos(3.64872229792 + 764.4001375042*t)
	X0 += 0.00000001503*np.cos(3.81614377386 + 4113.0943055358*t)
	X0 += 0.00000001517*np.cos(0.96214801531 + 535.9107402181*t)
	X0 += 0.00000001691*np.cos(4.02435252758 + 1268.7488723641*t)
	X0 += 0.00000001443*np.cos(2.05924697648 + 414.8187774292*t)
	X0 += 0.00000001453*np.cos(1.76200509604 + 608.404716925*t)
	X0 += 0.00000001417*np.cos(2.16805792847 + 103.3052225397*t)
	X0 += 0.00000001491*np.cos(2.71289281505 + 5863.5912061162*t)
	X0 += 0.00000001683*np.cos(4.01621825127 + 6503.4884924302*t)
	X0 += 0.00000001413*np.cos(4.95679658990 + 102.8803258975*t)
	X0 += 0.00000001438*np.cos(3.14372253740 + 550.1378342197*t)
	X0 += 0.00000001473*np.cos(6.03896352146 + 1354.4331588434*t)
	X0 += 0.00000001469*np.cos(0.70970063563 + 1452.8430202735*t)
	X0 += 0.00000001455*np.cos(5.17252529808 + 335.1418177523*t)
	X0 += 0.00000001409*np.cos(4.75328357688 + 4010.0015313172*t)
	X0 += 0.00000001848*np.cos(2.55365760167 + 419.6970921963*t)
	X0 += 0.00000001756*np.cos(2.17515099562 + 2707.8286873866*t)
	X0 += 0.00000001572*np.cos(5.11604878686 + 2090.3096723752*t)
	X0 += 0.00000001590*np.cos(0.88427818489 + 701.936263588*t)
	X0 += 0.00000001587*np.cos(5.49941870322 + 148.3393568572*t)
	X0 += 0.00000001391*np.cos(4.51136204527 + 812.9457339595*t)
	X0 += 0.00000001433*np.cos(5.96031312341 + 184.8449074348*t)
	X0 += 0.00000001770*np.cos(2.76997068745 + 610.6923387854*t)
	X0 += 0.00000001926*np.cos(4.60411263717 + 416.5638825684*t)
	X0 += 0.00000001512*np.cos(4.28907569036 + 428.2427222787*t)
	X0 += 0.00000001491*np.cos(6.19797514101 + 5746.271337896*t)
	X0 += 0.00000001891*np.cos(5.00794934593 + 1165.3954657146*t)
	X0 += 0.00000001759*np.cos(4.58582597435 + 200.0352092829*t)
	X0 += 0.00000001759*np.cos(3.44539284583 + 226.5629815931*t)
	X0 += 0.00000001507*np.cos(3.03240096716 + 728.0122070056*t)
	X0 += 0.00000001601*np.cos(5.43891433341 + 10433.6981886498*t)
	X0 += 0.00000001400*np.cos(0.26014578065 + 1950.2906564537*t)
	X0 += 0.00000001481*np.cos(1.32266089239 + 9676.4810341156*t)
	X0 += 0.00000001607*np.cos(1.30401533687 + 1645.6952465864*t)
	X0 += 0.00000001338*np.cos(0.32385668589 + 551.1010420662*t)
	X0 += 0.00000001369*np.cos(2.97642894950 + 2015.6710861598*t)
	X0 += 0.00000001684*np.cos(3.65255547244 + 2733.3883524269*t)
	X0 += 0.00000001377*np.cos(4.02534099039 + 183.5516311882*t)
	X0 += 0.00000001377*np.cos(0.86428517620 + 243.0465596878*t)
	X0 += 0.00000001545*np.cos(5.17617889881 + 469.7271613599*t)
	X0 += 0.00000001328*np.cos(4.26613234444 + 168.0525127994*t)
	X0 += 0.00000001329*np.cos(2.62043662585 + 1321.4390704036*t)
	X0 += 0.00000001832*np.cos(2.64902483032 + 1070.4276304531*t)
	X0 += 0.00000001714*np.cos(6.08300926304 + 79.1868325824*t)
	X0 += 0.00000001384*np.cos(0.51883875319 + 718.6110381444*t)
	X0 += 0.00000001293*np.cos(0.73720210492 + 443.8636662634*t)
	X0 += 0.00000001445*np.cos(5.54776352818 + 1546.5346256309*t)
	X0 += 0.00000001758*np.cos(3.53138641234 + 452.4616859725*t)
	X0 += 0.00000001323*np.cos(0.57163734440 + 1182.9215735329*t)
	X0 += 0.00000001464*np.cos(4.41309699814 + 359.893347156*t)
	X0 += 0.00000001376*np.cos(0.61103736579 + 535.3200393871*t)
	X0 += 0.00000001562*np.cos(5.38874817106 + 1116.0042814918*t)
	X0 += 0.00000001664*np.cos(4.95290022994 + 102.980899634*t)
	X0 += 0.00000001452*np.cos(0.95391083866 + 316.6525020875*t)
	X0 += 0.00000001371*np.cos(5.90092829407 + 1230.1427559743*t)
	X0 += 0.00000001287*np.cos(5.11643818914 + 1378.0614217062*t)
	X0 += 0.00000001540*np.cos(2.64182135460 + 2810.9214616052*t)
	X0 += 0.00000001306*np.cos(3.46049602472 + 118.8737768977*t)
	X0 += 0.00000001265*np.cos(1.74539951256 + 313.4711083498*t)
	X0 += 0.00000001458*np.cos(3.04954375653 + 9352.9756174582*t)
	X0 += 0.00000001268*np.cos(6.19011285620 + 945.9942152321*t)
	X0 += 0.00000001255*np.cos(4.69031464511 + 1365.4788591073*t)
	X0 += 0.00000001435*np.cos(5.66075669352 + 1112.0721282287*t)
	X0 += 0.00000001665*np.cos(0.62988746649 + 163.5778428151*t)
	X0 += 0.00000001357*np.cos(6.27754029215 + 2638.1598847345*t)
	X0 += 0.00000001500*np.cos(6.15789721114 + 253.4591205053*t)
	X0 += 0.00000001563*np.cos(1.45149048546 + 3391.4448860056*t)
	X0 += 0.00000001642*np.cos(2.81880394943 + 59.2824801785*t)
	X0 += 0.00000001594*np.cos(0.44695442950 + 109.3125493421*t)
	X0 += 0.00000001470*np.cos(5.32258746756 + 2693.601593385*t)
	X0 += 0.00000001254*np.cos(0.01314124764 + 1670.82502850*t)
	X0 += 0.00000001229*np.cos(2.75441751465 + 2321.0172555525*t)
	X0 += 0.00000001299*np.cos(3.73723007418 + 100.1720129118*t)
	X0 += 0.00000001378*np.cos(2.65430765160 + 1248.1419445446*t)
	X0 += 0.00000001579*np.cos(4.87543328136 + 1477.5945496772*t)
	X0 += 0.00000001343*np.cos(4.05019503298 + 973.554631358*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001249*np.cos(4.48467456107 + 1257.7031721002*t)
	X0 += 0.00000001409*np.cos(3.73682854833 + 321.0577361026*t)
	X0 += 0.00000001267*np.cos(5.32582018884 + 114.8721876654*t)
	X0 += 0.00000001279*np.cos(0.62790063934 + 208.8938614229*t)
	X0 += 0.00000001279*np.cos(1.12013287366 + 217.7043294531*t)
	X0 += 0.00000001360*np.cos(2.94106637275 + 731.6837278378*t)
	X0 += 0.00000001292*np.cos(2.58482128116 + 95.0160193713*t)
	X0 += 0.00000001208*np.cos(1.32714482271 + 115.8835796217*t)
	X0 += 0.00000001204*np.cos(1.73422906473 + 532.6117264014*t)
	X0 += 0.00000001405*np.cos(5.51459382206 + 959.2099172774*t)
	X0 += 0.00000001492*np.cos(0.02061853237 + 745.9108218394*t)
	X0 += 0.00000001445*np.cos(4.87232535693 + 3149.6916025644*t)
	X0 += 0.00000001329*np.cos(3.78290919728 + 1226.2106027112*t)
	X0 += 0.00000001522*np.cos(0.18915606181 + 347.4113582936*t)
	X0 += 0.00000001621*np.cos(0.27051123464 + 25455.119402261*t)
	X0 += 0.00000001224*np.cos(2.09537326016 + 3067.9394693482*t)
	X0 += 0.00000001244*np.cos(1.25777650062 + 3487.4241132234*t)
	X0 += 0.00000001329*np.cos(0.53441781539 + 680.0573113813*t)
	X0 += 0.00000001450*np.cos(0.82068686253 + 25558.2121764796*t)
	X0 += 0.00000001360*np.cos(3.69759181292 + 670.4960838257*t)
	X0 += 0.00000001352*np.cos(3.75966450307 + 529.8028396792*t)
	X0 += 0.00000001236*np.cos(4.30743406740 + 539.0921339558*t)
	X0 += 0.00000001173*np.cos(2.82545343063 + 1383.6904959987*t)
	X0 += 0.00000001187*np.cos(1.03835064531 + 1394.7361962626*t)
	X0 += 0.00000001153*np.cos(5.83618369598 + 476.3194434989*t)
	X0 += 0.00000001176*np.cos(2.90357853330 + 251.9052118278*t)
	X0 += 0.00000001245*np.cos(4.65507327128 + 293.4973199767*t)
	X0 += 0.00000001285*np.cos(3.93504441733 + 4105.980758535*t)
	X0 += 0.00000001273*np.cos(0.55887711001 + 165.3441998137*t)
	X0 += 0.00000001392*np.cos(0.02252934590 + 5860.4098123785*t)
	X0 += 0.00000001357*np.cos(3.35598838973 + 101.6083015103*t)
	X0 += 0.00000001366*np.cos(5.22724394155 + 673.8375362578*t)
	X0 += 0.00000001211*np.cos(2.29834110056 + 270.8152186179*t)
	X0 += 0.00000001212*np.cos(1.82608292863 + 878.3261636656*t)
	X0 += 0.00000001180*np.cos(5.71255685193 + 774.0095491696*t)
	X0 += 0.00000001371*np.cos(3.12199503993 + 5852.5455058523*t)
	X0 += 0.00000001373*np.cos(4.47969866574 + 880.023084695*t)
	X0 += 0.00000001263*np.cos(1.72556296863 + 1696.0978227655*t)
	X0 += 0.00000001147*np.cos(5.23261055240 + 2047.9144150742*t)
	X0 += 0.00000001139*np.cos(4.25515435685 + 199.0238173266*t)
	X0 += 0.00000001139*np.cos(3.77606446333 + 227.5743735494*t)
	X0 += 0.00000001350*np.cos(3.52655624885 + 25440.89230825939*t)
	X0 += 0.00000001402*np.cos(0.27389279785 + 310.7627953641*t)
	X0 += 0.00000001177*np.cos(1.82815189392 + 303.0585475323*t)
	X0 += 0.00000001164*np.cos(3.52320292409 + 913.0001267923*t)
	X0 += 0.00000001180*np.cos(5.67582372815 + 272.5815756165*t)
	X0 += 0.00000001392*np.cos(5.39039322418 + 383.3091616977*t)
	X0 += 0.00000001228*np.cos(6.14895042777 + 91.4563731237*t)
	X0 += 0.00000001154*np.cos(0.40787574864 + 2040.8008680734*t)
	X0 += 0.00000001129*np.cos(5.00161734286 + 12.7426212933*t)
	X0 += 0.00000001431*np.cos(3.53246978944 + 1467.0701142751*t)
	X0 += 0.00000001126*np.cos(3.79660314533 + 848.530515306*t)
	X0 += 0.00000001513*np.cos(0.39925684800 + 1147.4968508808*t)
	X0 += 0.00000001153*np.cos(5.17505063686 + 1773.9178027186*t)
	X0 += 0.00000001128*np.cos(1.71769229719 + 976.7360250957*t)
	X0 += 0.00000001560*np.cos(0.25292730078 + 1439.5096981492*t)
	X0 += 0.00000001408*np.cos(1.58662566884 + 763.4369296577*t)
	X0 += 0.00000001458*np.cos(5.59143602269 + 1128.534454464*t)
	X0 += 0.00000001478*np.cos(0.06776988437 + 349.3689117539*t)
	X0 += 0.00000001510*np.cos(2.53664213755 + 754.8389099486*t)
	X0 += 0.00000001449*np.cos(3.17300960200 + 1020.025054274*t)
	X0 += 0.00000001356*np.cos(3.98680116862 + 108.50940019*t)
	X0 += 0.00000001249*np.cos(1.30613475993 + 1534.7381658416*t)
	X0 += 0.00000001131*np.cos(3.96272996671 + 5540.0857894588*t)
	X0 += 0.00000001289*np.cos(5.88758679432 + 1403.3342159717*t)
	X0 += 0.00000001191*np.cos(2.88509951530 + 466.7582159433*t)
	X0 += 0.00000001180*np.cos(1.37216464240 + 2012.4896924221*t)
	X0 += 0.00000001433*np.cos(4.14919194066 + 388.7257876691*t)
	X0 += 0.00000001519*np.cos(1.77602034236 + 1151.4290041439*t)
	X0 += 0.00000001096*np.cos(1.26794842991 + 373.0142209592*t)
	X0 += 0.00000001100*np.cos(0.77366362492 + 1724.4089984168*t)
	X0 += 0.00000001237*np.cos(4.45157430570 + 559.6990617753*t)
	X0 += 0.00000001358*np.cos(5.74355886162 + 877.1023233882*t)
	X0 += 0.00000001102*np.cos(4.63066438780 + 531.6967026647*t)
	X0 += 0.00000001302*np.cos(1.44598353889 + 9790.6195085981*t)
	X0 += 0.00000001204*np.cos(1.14665521525 + 1962.087116243*t)
	X0 += 0.00000001099*np.cos(5.99651405584 + 527.6852275245*t)
	X0 += 0.00000001178*np.cos(1.43511695783 + 1392.2885157078*t)
	X0 += 0.00000001255*np.cos(1.98199855048 + 877.5754041402*t)
	X0 += 0.00000001462*np.cos(6.27961731873 + 301.4140161296*t)
	X0 += 0.00000001075*np.cos(3.79098343355 + 645.3139122854*t)
	X0 += 0.00000001072*np.cos(4.01082765782 + 220.5727011332*t)
	X0 += 0.00000001072*np.cos(4.02039116236 + 206.0254897428*t)
	X0 += 0.00000001281*np.cos(4.54544859936 + 9782.7552020719*t)
	X0 += 0.00000001067*np.cos(5.00162271725 + 904.4021070832*t)
	X0 += 0.00000001096*np.cos(4.32947944704 + 1998.2625984205*t)
	X0 += 0.00000001076*np.cos(0.76185840399 + 898.7730327907*t)
	X0 += 0.00000001094*np.cos(0.91660450585 + 3803.81598288*t)
	X0 += 0.00000001428*np.cos(5.37194147298 + 2833.2997329078*t)
	X0 += 0.00000001072*np.cos(1.12267854328 + 206.3456071316*t)
	X0 += 0.00000001072*np.cos(0.62535496972 + 220.2525837444*t)
	X0 += 0.00000001171*np.cos(5.53099866879 + 1475.6851803267*t)
	X0 += 0.00000001054*np.cos(2.72358957995 + 5966.6839803348*t)
	X0 += 0.00000001302*np.cos(3.69508258754 + 1096.2429414398*t)
	X0 += 0.00000001396*np.cos(5.45482103248 + 1461.4410399826*t)
	X0 += 0.00000001385*np.cos(1.20423833249 + 1127.2624300768*t)
	X0 += 0.00000001170*np.cos(2.12698764013 + 704.8570248948*t)
	X0 += 0.00000001155*np.cos(1.13805007709 + 6599.467719648*t)
	X0 += 0.00000001131*np.cos(3.08204815771 + 1222.2784494481*t)
	X0 += 0.00000001116*np.cos(5.98592305871 + 1901.5326116773*t)
	X0 += 0.00000001288*np.cos(0.42379455454 + 1340.5615255148*t)
	X0 += 0.00000001314*np.cos(6.26564385850 + 1560.6187072806*t)
	X0 += 0.00000001286*np.cos(0.79929117404 + 1082.0158474382*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001166*np.cos(5.05890554170 + 2467.3990589494*t)
	X0 += 0.00000001338*np.cos(0.28846575268 + 1244.226837624*t)
	X0 += 0.00000001319*np.cos(4.68406643646 + 5436.9930152402*t)
	X0 += 0.00000001299*np.cos(5.43850078022 + 2509.7943162504*t)
	X0 += 0.00000001253*np.cos(5.04434789546 + 482.2573343321*t)
	X0 += 0.00000001127*np.cos(0.30971437723 + 78477.00852016058*t)
	X0 += 0.00000001362*np.cos(5.11365032735 + 733.428832977*t)
	X0 += 0.00000001045*np.cos(4.69725794848 + 1247.4082313617*t)
	X0 += 0.00000001197*np.cos(0.15642654576 + 3340.6124266998*t)
	X0 += 0.00000001329*np.cos(5.03786795261 + 2740.5018994277*t)
	X0 += 0.00000001088*np.cos(2.67619018542 + 2630.2955782083*t)
	X0 += 0.00000001017*np.cos(2.29943441333 + 1939.2449561898*t)
	X0 += 0.00000001236*np.cos(0.30370190103 + 761.7400086283*t)
	X0 += 0.00000001236*np.cos(4.02922968721 + 2943.5060541272*t)
	X0 += 0.00000001321*np.cos(4.43670480817 + 323.2447842265*t)
	X0 += 0.00000001279*np.cos(3.51604975387 + 223.1209554245*t)
	X0 += 0.00000001279*np.cos(4.51516906631 + 203.4772354515*t)
	X0 += 0.00000001018*np.cos(2.91596221445 + 640.6480458394*t)
	X0 += 0.00000001010*np.cos(2.70311043178 + 3914.0223040994*t)
	X0 += 0.00000001105*np.cos(1.98193872719 + 369.0820676961*t)
	X0 += 0.00000001015*np.cos(3.09583830139 + 411.0990724872*t)
	X0 += 0.00000001113*np.cos(3.02325708016 + 523.5406259403*t)
	X0 += 0.00000001008*np.cos(4.30745009184 + 102.8321417877*t)
	X0 += 0.00000001023*np.cos(1.30830385679 + 608.2446582306*t)
	X0 += 0.00000001014*np.cos(0.02522068638 + 121.8427223143*t)
	X0 += 0.00000001246*np.cos(5.68903950855 + 758.7710632117*t)
	X0 += 0.00000001018*np.cos(4.91714410657 + 6247.5131155228*t)
	X0 += 0.00000001109*np.cos(1.66575096659 + 1397.7051416792*t)
	X0 += 0.00000001195*np.cos(4.77748966530 + 47.061123747*t)
	X0 += 0.00000000987*np.cos(2.64810111086 + 968.1380053866*t)
	X0 += 0.00000001353*np.cos(0.16753327985 + 598.8434893694*t)
	X0 += 0.00000001216*np.cos(6.15221306348 + 9367.2027114598*t)
	X0 += 0.00000001253*np.cos(4.46392704390 + 5867.5233593793*t)
	X0 += 0.00000001069*np.cos(4.67913892913 + 6217.6310719126*t)
	X0 += 0.00000001317*np.cos(3.83858558776 + 260.360219185*t)
	X0 += 0.00000001264*np.cos(0.68934669984 + 1681.1199692385*t)
	X0 += 0.00000001072*np.cos(5.14135047926 + 582.3811631341*t)
	X0 += 0.00000001160*np.cos(6.23718760445 + 152.7445908723*t)
	X0 += 0.00000001105*np.cos(0.38728165518 + 661.0949149645*t)
	X0 += 0.00000001008*np.cos(0.43311135773 + 304.1223291153*t)
	X0 += 0.00000001200*np.cos(3.09836953470 + 528.4671248172*t)
	X0 += 0.00000000973*np.cos(3.93273625700 + 173.1390703707*t)
	X0 += 0.00000000985*np.cos(5.37328572434 + 1012.9115072732*t)
	X0 += 0.00000001105*np.cos(1.14919741381 + 199.1201855462*t)
	X0 += 0.00000001105*np.cos(0.59883609919 + 227.4780053298*t)
	X0 += 0.00000000991*np.cos(1.52113636912 + 331.3697231836*t)
	X0 += 0.00000001226*np.cos(3.94496586095 + 1973.1328165069*t)
	X0 += 0.00000000958*np.cos(1.97392157680 + 1791.3262904579*t)
	X0 += 0.00000001185*np.cos(2.30984449641 + 772.9981572133*t)
	X0 += 0.00000000975*np.cos(5.20361164972 + 2225.7887878601*t)
	X0 += 0.00000001221*np.cos(3.21085670371 + 775.9671026299*t)
	X0 += 0.00000000982*np.cos(6.03742794907 + 1269.4996318895*t)
	X0 += 0.00000001224*np.cos(2.82053624385 + 25344.9130810416*t)
	X0 += 0.00000001026*np.cos(1.03328449858 + 599.6466385215*t)
	X0 += 0.00000001207*np.cos(4.61076899661 + 2597.6223661672*t)
	X0 += 0.00000000992*np.cos(1.52833966963 + 726.3152859762*t)
	X0 += 0.00000000950*np.cos(2.91384578758 + 568.2970814844*t)
	X0 += 0.00000001045*np.cos(1.71934810271 + 447.7958195265*t)
	X0 += 0.00000000958*np.cos(4.13745803808 + 711.4974911436*t)
	X0 += 0.00000001220*np.cos(4.63275786827 + 1458.472094566*t)
	X0 += 0.00000000973*np.cos(0.18291286905 + 1333.2355301929*t)
	X0 += 0.00000001070*np.cos(3.54513482526 + 1471.0022675382*t)
	X0 += 0.00000001155*np.cos(1.80067980448 + 308.5275631304*t)
	X0 += 0.00000000968*np.cos(4.70982562087 + 394.9455627926*t)
	X0 += 0.00000001023*np.cos(2.72566495465 + 522.529233984*t)
	X0 += 0.00000001271*np.cos(4.63428894734 + 25771.5112719176*t)
	X0 += 0.00000001128*np.cos(4.76771165311 + 1459.9565672743*t)
	X0 += 0.00000001214*np.cos(6.08146614200 + 1190.7858800591*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000001056*np.cos(2.41421618519 + 62.038977274*t)
	X0 += 0.00000001211*np.cos(0.07105082597 + 874.3940104025*t)
	X0 += 0.00000001069*np.cos(3.21597034495 + 384.2723695442*t)
	X0 += 0.00000000928*np.cos(1.98032917141 + 689.6185389369*t)
	X0 += 0.00000000927*np.cos(6.25845040638 + 6327.837393132*t)
	X0 += 0.00000001157*np.cos(1.32901172925 + 1374.1292684431*t)
	X0 += 0.00000001221*np.cos(6.07809765786 + 473.068613792*t)
	X0 += 0.00000000945*np.cos(0.09123943360 + 838.218528225*t)
	X0 += 0.00000000936*np.cos(2.17363842403 + 321.808495628*t)
	X0 += 0.00000000989*np.cos(0.87301593506 + 557.0389328994*t)
	X0 += 0.00000000943*np.cos(2.69427894222 + 1875.5090578864*t)
	X0 += 0.00000001172*np.cos(5.88736315639 + 9797.7330555989*t)
	X0 += 0.00000001048*np.cos(3.73168805028 + 4429.4861751924*t)
	X0 += 0.00000001071*np.cos(1.11073151974 + 781.5961769224*t)
	X0 += 0.00000000918*np.cos(2.63844409234 + 385.7568422525*t)
	X0 += 0.00000001082*np.cos(5.24996549702 + 2151.0071892928*t)
	X0 += 0.00000000993*np.cos(6.01306916289 + 1396.2206689709*t)
	X0 += 0.00000001056*np.cos(1.31804101541 + 3707.8367556622*t)
	X0 += 0.00000000971*np.cos(2.88611794550 + 3281.2385647862*t)
	X0 += 0.00000001138*np.cos(5.00068840720 + 5845.4319588515*t)
	X0 += 0.00000000920*np.cos(3.60988608759 + 632.0329797878*t)
	X0 += 0.00000001142*np.cos(0.14819030385 + 1987.2168981566*t)
	X0 += 0.00000000970*np.cos(4.59382496601 + 866.5297038763*t)
	X0 += 0.00000001185*np.cos(5.68033788821 + 10846.0692855242*t)
	X0 += 0.00000001115*np.cos(1.35005478930 + 1079.8287993143*t)
	X0 += 0.00000000909*np.cos(4.51062672335 + 311.7260032106*t)
	X0 += 0.00000001060*np.cos(1.32259506046 + 2520.0892569889*t)
	X0 += 0.00000000931*np.cos(6.04606689039 + 3906.9087570986*t)
	X0 += 0.00000001058*np.cos(3.29946281633 + 613.8737325231*t)
	X0 += 0.00000001142*np.cos(5.20625047920 + 906.849787638*t)
	X0 += 0.00000000952*np.cos(4.74695156387 + 3569.1762464396*t)
	X0 += 0.00000000899*np.cos(0.95311796470 + 605.9570363702*t)
	X0 += 0.00000001259*np.cos(2.56978534873 + 5333.9002410216*t)
	X0 += 0.00000000922*np.cos(4.85082110018 + 401.5378449316*t)
	X0 += 0.00000001212*np.cos(5.83888920317 + 941.3113024436*t)
	X0 += 0.00000001018*np.cos(2.31116440407 + 3700.7232086614*t)
	X0 += 0.00000000896*np.cos(2.50724358689 + 981.4189378842*t)
	X0 += 0.00000000899*np.cos(5.16361191839 + 420.2354034006*t)
	X0 += 0.00000001039*np.cos(5.09352612368 + 68.1893164283*t)
	X0 += 0.00000000960*np.cos(2.47416590676 + 1197.8994270599*t)
	X0 += 0.00000001015*np.cos(1.64026122587 + 714.5358725294*t)
	X0 += 0.00000001108*np.cos(6.09598657011 + 1259.1876448085*t)
	X0 += 0.00000001035*np.cos(1.50974146504 + 6261.7402095244*t)
	X0 += 0.00000000889*np.cos(4.18410664752 + 2306.7901615509*t)
	X0 += 0.00000001195*np.cos(6.15877891933 + 1152.1797636693*t)
	X0 += 0.00000000931*np.cos(4.56496644687 + 529.57909051*t)
	X0 += 0.00000000901*np.cos(4.11178501419 + 1127.0499817557*t)
	X0 += 0.00000000962*np.cos(4.91687121920 + 1759.8337210689*t)
	X0 += 0.00000000905*np.cos(5.08337481428 + 795.6802585721*t)
	X0 += 0.00000001088*np.cos(3.10692546135 + 2332.0629558164*t)
	X0 += 0.00000001148*np.cos(1.83262877540 + 979.1837056505*t)
	X0 += 0.00000001021*np.cos(2.83249057863 + 524.0618908021*t)
	X0 += 0.00000001063*np.cos(1.80742459506 + 921.0768816396*t)
	X0 += 0.00000000962*np.cos(1.78033887272 + 770.3380283374*t)
	X0 += 0.00000000962*np.cos(0.62986061526 + 988.532484885*t)
	X0 += 0.00000000920*np.cos(4.60070286678 + 802.7938055729*t)
	X0 += 0.00000001054*np.cos(0.18348909645 + 1304.9243545416*t)
	X0 += 0.00000001179*np.cos(5.56983461950 + 260.9933586314*t)
	X0 += 0.00000000871*np.cos(1.92755623364 + 102.9327155242*t)
	X0 += 0.00000000902*np.cos(6.00832963626 + 1407.2663692348*t)
	X0 += 0.00000000970*np.cos(0.92586021521 + 51322.60990139639*t)
	X0 += 0.00000000870*np.cos(5.19974857867 + 103.252832913*t)
	X0 += 0.00000000952*np.cos(4.49527687251 + 1527.6246188408*t)
	X0 += 0.00000000977*np.cos(1.89516214334 + 273.8536000037*t)
	X0 += 0.00000000868*np.cos(5.21672394772 + 4539.6924964118*t)
	X0 += 0.00000001016*np.cos(1.81276666100 + 1332.4847706675*t)
	X0 += 0.00000000939*np.cos(4.72160653425 + 12573.2652469836*t)
	X0 += 0.00000000900*np.cos(2.85261484611 + 1022.3126761344*t)
	X0 += 0.00000000867*np.cos(2.01961476477 + 449.4927405559*t)
	X0 += 0.00000001116*np.cos(0.91462209636 + 947.5310775671*t)
	X0 += 0.00000000861*np.cos(2.84568601373 + 1095.6098019934*t)
	X0 += 0.00000001151*np.cos(1.92157822238 + 775.4458377681*t)
	X0 += 0.00000001081*np.cos(1.05451600776 + 316.9131345184*t)
	X0 += 0.00000000889*np.cos(2.78855806552 + 5158.2491417234*t)
	X0 += 0.00000000952*np.cos(1.24922940161 + 52168.69273614759*t)
	X0 += 0.00000000892*np.cos(0.51409333559 + 663.8032279502*t)
	X0 += 0.00000001064*np.cos(0.14095547310 + 9775.6416550711*t)
	X0 += 0.00000000924*np.cos(4.69074368530 + 1072.7152523135*t)
	X0 += 0.00000000996*np.cos(1.13833884977 + 1329.3033769298*t)
	X0 += 0.00000000852*np.cos(6.16458473082 + 4760.1051388506*t)
	X0 += 0.00000000878*np.cos(1.53529061972 + 166.237971691*t)
	X0 += 0.00000000940*np.cos(1.91139473998 + 4216.1870797544*t)
	X0 += 0.00000000880*np.cos(3.09735397949 + 303.8616966844*t)
	X0 += 0.00000000884*np.cos(0.90715778768 + 1336.4169239306*t)
	X0 += 0.00000000960*np.cos(0.24584342277 + 5842.2505651138*t)
	X0 += 0.00000000859*np.cos(2.62627633564 + 1886.5547581503*t)
	X0 += 0.00000001090*np.cos(0.95231319440 + 738.3241940866*t)
	X0 += 0.00000001176*np.cos(0.64353107931 + 4752.9915918498*t)
	X0 += 0.00000000853*np.cos(4.46091624833 + 1241.1884562382*t)
	X0 += 0.00000001107*np.cos(5.37901208764 + 2442.2692770358*t)
	X0 += 0.00000000938*np.cos(0.30415708562 + 600.5404103988*t)
	X0 += 0.00000000858*np.cos(0.41063008749 + 1035.002907801*t)
	X0 += 0.00000000945*np.cos(2.21798974127 + 2107.7181601145*t)
	X0 += 0.00000000928*np.cos(2.03804472509 + 97.4636999261*t)
	X0 += 0.00000000842*np.cos(5.63606603103 + 4642.7852706304*t)
	X0 += 0.00000000845*np.cos(1.52209182104 + 803.5445650983*t)
	X0 += 0.00000001161*np.cos(0.64813941640 + 987.7817253596*t)
	X0 += 0.00000000959*np.cos(2.94700989070 + 249.6870259366*t)
	X0 += 0.00000000959*np.cos(1.94261627589 + 176.9111649394*t)
	X0 += 0.00000000835*np.cos(5.27426036188 + 960.0612505393*t)
	X0 += 0.00000000844*np.cos(4.26705563875 + 3494.5376602242*t)
	X0 += 0.00000000835*np.cos(2.98972997364 + 1699.2792165032*t)
	X0 += 0.00000000843*np.cos(4.69679538916 + 248.4631856592*t)
	X0 += 0.00000000843*np.cos(0.19283077743 + 178.1350052168*t)
	X0 += 0.00000001023*np.cos(3.54777631899 + 1054.7160637432*t)
	X0 += 0.00000000870*np.cos(1.97309067523 + 1467.8208738005*t)
	X0 += 0.00000001010*np.cos(3.19322573273 + 1186.853726796*t)
	X0 += 0.00000000957*np.cos(2.63832021608 + 10529.6774158676*t)
	X0 += 0.00000000900*np.cos(1.80738429411 + 5901.239202256*t)
	X0 += 0.00000000941*np.cos(2.82789997881 + 944.9828232758*t)
	X0 += 0.00000000865*np.cos(2.70960324100 + 1535.488925367*t)
	X0 += 0.00000001067*np.cos(6.03658788356 + 1055.1891444952*t)
	X0 += 0.00000000945*np.cos(1.49743453294 + 829.6205085159*t)
	X0 += 0.00000000912*np.cos(1.39416845682 + 832.5894539325*t)
	X0 += 0.00000001146*np.cos(2.60438294372 + 982.1526510671*t)
	X0 += 0.00000000812*np.cos(5.30598958988 + 20007.0864485468*t)
	X0 += 0.00000000927*np.cos(5.76929068640 + 204.91352405*t)
	X0 += 0.00000000927*np.cos(2.26192813378 + 221.684666826*t)
	X0 += 0.00000001028*np.cos(0.68506380971 + 622.4887985747*t)
	X0 += 0.00000000827*np.cos(3.54375341653 + 3679.382567659*t)
	X0 += 0.00000001020*np.cos(0.81327138026 + 664.0156762713*t)
	X0 += 0.00000001093*np.cos(0.95182537662 + 26404.2950112308*t)
	X0 += 0.00000000920*np.cos(3.29194805293 + 1460.7073267997*t)
	X0 += 0.00000000867*np.cos(0.75858082011 + 155.1922714271*t)
	X0 += 0.00000000821*np.cos(5.37814660681 + 9470.2954856784*t)
	X0 += 0.00000001078*np.cos(5.29413317260 + 902.9176343749*t)
	X0 += 0.00000000857*np.cos(5.49673781780 + 63.847772888*t)
	X0 += 0.00000000798*np.cos(2.46893889261 + 437.9045235708*t)
	X0 += 0.00000000866*np.cos(5.20338687906 + 1784.9635029825*t)
	X0 += 0.00000000788*np.cos(1.83026001861 + 683.0262567979*t)
	X0 += 0.00000000788*np.cos(4.89679068215 + 938.1299087059*t)
	X0 += 0.00000000803*np.cos(2.43017686726 + 19992.85935454519*t)
	X0 += 0.00000000972*np.cos(3.39781775284 + 1858.9943420244*t)
	X0 += 0.00000000870*np.cos(6.20285766706 + 401.3253966105*t)
	X0 += 0.00000000783*np.cos(5.18616462930 + 841.4169683052*t)
	X0 += 0.00000000950*np.cos(4.19698244286 + 507.5995645668*t)
	X0 += 0.00000000972*np.cos(3.15612005468 + 892.5532576672*t)
	X0 += 0.00000000792*np.cos(4.70710210429 + 823.9914342234*t)
	X0 += 0.00000000926*np.cos(4.87407778306 + 1025.4416802454*t)
	X0 += 0.00000000929*np.cos(3.24203444555 + 517.1607921224*t)
	X0 += 0.00000001020*np.cos(3.91362880983 + 103.2046488032*t)
	X0 += 0.00000001094*np.cos(4.65159397422 + 2623.1820312075*t)
	X0 += 0.00000001092*np.cos(0.51760698110 + 938.8806682313*t)
	X0 += 0.00000000872*np.cos(2.51553129794 + 63.6240237188*t)
	X0 += 0.00000001031*np.cos(0.06363683037 + 532.1386456494*t)
	X0 += 0.00000000995*np.cos(4.28573964440 + 1120.148883076*t)
	X0 += 0.00000001013*np.cos(5.43396560078 + 810.6581120991*t)
	X0 += 0.00000000809*np.cos(6.27924207458 + 1371.8416465827*t)
	X0 += 0.00000000792*np.cos(5.83029978253 + 746.1714542703*t)
	X0 += 0.00000001085*np.cos(2.59537042479 + 592.2030231206*t)
	X0 += 0.00000000888*np.cos(3.27135586321 + 26514.5013324502*t)
	X0 += 0.00000001055*np.cos(4.03982380142 + 7232.2514589612*t)
	X0 += 0.00000000781*np.cos(1.96140425782 + 4546.8060434126*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000000799*np.cos(4.48492473652 + 2843.5946736463*t)
	X0 += 0.00000000776*np.cos(2.77204567287 + 494.4786907636*t)
	X0 += 0.00000000936*np.cos(0.36703047310 + 480.251596762*t)
	X0 += 0.00000000893*np.cos(3.82920318115 + 957.0923051227*t)
	X0 += 0.00000000777*np.cos(4.95951789220 + 1031.87390369*t)
	X0 += 0.00000000940*np.cos(0.40461452564 + 2313.9037085517*t)
	X0 += 0.00000000824*np.cos(1.65904903943 + 547.8502123593*t)
	X0 += 0.00000000910*np.cos(4.93700135135 + 2406.7015420318*t)
	X0 += 0.00000001027*np.cos(2.73485817904 + 3657.0042963564*t)
	X0 += 0.00000000768*np.cos(3.19841476084 + 845.3320752258*t)
	X0 += 0.00000000866*np.cos(3.55153634231 + 1293.8786542777*t)
	X0 += 0.00000000998*np.cos(5.44535986140 + 11.7794134468*t)
	X0 += 0.00000000801*np.cos(0.27112028533 + 475.3562356524*t)
	X0 += 0.00000000766*np.cos(6.03832107377 + 2439.0878832981*t)
	X0 += 0.00000001050*np.cos(0.63919198126 + 332.1728723357*t)
	X0 += 0.00000000833*np.cos(4.78190863299 + 1681.8707287639*t)
	X0 += 0.00000000769*np.cos(4.30003410596 + 1052.2201990786*t)
	X0 += 0.00000000776*np.cos(4.35685988911 + 2014.0265547571*t)
	X0 += 0.00000001002*np.cos(4.18369718646 + 52182.9198301492*t)
	X0 += 0.00000000973*np.cos(5.48778736129 + 518.9058972616*t)
	X0 += 0.00000000829*np.cos(1.94484304027 + 595.7144852584*t)
	X0 += 0.00000000839*np.cos(0.93530391094 + 13362.4497067992*t)
	X0 += 0.00000000874*np.cos(1.04026539094 + 493.5154829171*t)
	X0 += 0.00000000866*np.cos(0.25243966445 + 109.9456887885*t)
	X0 += 0.00000001022*np.cos(5.81953700429 + 812.1425848074*t)
	X0 += 0.00000000754*np.cos(4.26857382429 + 735.9246976416*t)
	X0 += 0.00000000788*np.cos(0.86378191468 + 1408.0171287602*t)
	X0 += 0.00000000786*np.cos(4.39939203294 + 1053.2315910349*t)
	X0 += 0.00000000899*np.cos(5.38123051458 + 931.0163617051*t)
	X0 += 0.00000000768*np.cos(1.54323874502 + 6058.7310542895*t)
	X0 += 0.00000000830*np.cos(4.02252856771 + 821.5437536686*t)
	X0 += 0.00000000831*np.cos(0.77280313250 + 436.6324991836*t)
	X0 += 0.00000000934*np.cos(1.59834418987 + 1300.9922012785*t)
	X0 += 0.00000000757*np.cos(4.23078199908 + 5495.9816523824*t)
	X0 += 0.00000000802*np.cos(4.24211624809 + 1386.6594414153*t)
	X0 += 0.00000000949*np.cos(0.86426366309 + 10007.0999977738*t)
	X0 += 0.00000000805*np.cos(1.91700034886 + 580.0935412737*t)
	X0 += 0.00000000940*np.cos(2.94283899053 + 461.7622810972*t)
	X0 += 0.00000000881*np.cos(5.71084129732 + 157.4275036608*t)
	X0 += 0.00000000881*np.cos(5.46197017645 + 269.1706872152*t)
	X0 += 0.00000000789*np.cos(2.80405308992 + 678.0303219518*t)
	X0 += 0.00000000766*np.cos(0.01680401049 + 1235.6117715724*t)
	X0 += 0.00000000767*np.cos(2.96617646777 + 2093.4910661129*t)
	X0 += 0.00000000868*np.cos(0.13582660748 + 1016.8436605363*t)
	X0 += 0.00000000755*np.cos(1.33774449782 + 188.2387494936*t)
	X0 += 0.00000000965*np.cos(2.40006592137 + 1674.0064222377*t)
	X0 += 0.00000000728*np.cos(0.99359722955 + 1052.3165672982*t)
	X0 += 0.00000000840*np.cos(0.88655149235 + 1051.3051753419*t)
	X0 += 0.00000000726*np.cos(2.32238512009 + 545.4719677737*t)
	X0 += 0.00000000725*np.cos(4.18151409048 + 995.6460318858*t)
	X0 += 0.00000000819*np.cos(2.37855017768 + 665.0270682276*t)
	X0 += 0.00000000815*np.cos(4.11376340797 + 699.1797664925*t)
	X0 += 0.00000000748*np.cos(5.94369910761 + 10632.7701900862*t)
	X0 += 0.00000000860*np.cos(3.40471766460 + 473.659314623*t)
	X0 += 0.00000000742*np.cos(4.71775024033 + 740.2817475469*t)
	X0 += 0.00000000917*np.cos(1.78759198509 + 12559.038152982*t)
	X0 += 0.00000000768*np.cos(2.28792148219 + 1310.3933701397*t)
	X0 += 0.00000000989*np.cos(5.46273130551 + 11162.4611551808*t)
	X0 += 0.00000000743*np.cos(5.02549550327 + 1087.6931058405*t)
	X0 += 0.00000000719*np.cos(1.19467319531 + 1736.9915610157*t)
	X0 += 0.00000000775*np.cos(1.68635949381 + 1703.2113697663*t)
	X0 += 0.00000000719*np.cos(6.27712089125 + 103711.71527998279*t)
	X0 += 0.00000000783*np.cos(5.04624349752 + 962.5089310941*t)
	X0 += 0.00000000785*np.cos(5.38854066042 + 1317.5069171405*t)
	X0 += 0.00000000976*np.cos(3.25056793677 + 870.4618571394*t)
	X0 += 0.00000000851*np.cos(4.56667936071 + 3466.083472221*t)
	X0 += 0.00000000935*np.cos(2.03746699681 + 841.8900490572*t)
	X0 += 0.00000001009*np.cos(2.30316838782 + 1126.2992222303*t)
	X0 += 0.00000000729*np.cos(3.08855858649 + 1649.6273998495*t)
	X0 += 0.00000000729*np.cos(6.13104106223 + 951.4632308302*t)
	X0 += 0.00000000714*np.cos(3.87054311946 + 1175.8080265321*t)
	X0 += 0.00000000870*np.cos(4.71802760819 + 749.2098356561*t)
	X0 += 0.00000000884*np.cos(2.18888540145 + 655.4176565622*t)
	X0 += 0.00000000749*np.cos(3.86728999613 + 785.5283301855*t)
	X0 += 0.00000000719*np.cos(1.08144155753 + 467.4395394995*t)
	X0 += 0.00000000708*np.cos(4.72118340243 + 2431.2235767719*t)
	X0 += 0.00000000737*np.cos(2.08501060156 + 521.6142102473*t)
	X0 += 0.00000000824*np.cos(0.35270933491 + 1163.4379122543*t)
	X0 += 0.00000000720*np.cos(1.80911156979 + 255.6249167698*t)
	X0 += 0.00000000800*np.cos(0.28363303165 + 147.1155165798*t)
	X0 += 0.00000000800*np.cos(4.60599313494 + 279.4826742962*t)
	X0 += 0.00000000793*np.cos(0.44341701999 + 951.6232895246*t)
	X0 += 0.00000000974*np.cos(0.50255279262 + 1997.5118388951*t)
	X0 += 0.00000000926*np.cos(3.38675142586 + 9896.8936765544*t)
	X0 += 0.00000000807*np.cos(5.15433117145 + 688.6553310904*t)
	X0 += 0.00000000718*np.cos(2.96669004947 + 9988.9407505091*t)
	X0 += 0.00000000696*np.cos(3.17155112876 + 2254.0999635114*t)
	X0 += 0.00000000891*np.cos(5.13469375619 + 669.6447505638*t)
	X0 += 0.00000000944*np.cos(1.61465906231 + 2748.3662059539*t)
	X0 += 0.00000000783*np.cos(1.34403255618 + 227.0049245778*t)
	X0 += 0.00000000783*np.cos(0.40400095682 + 199.5932662982*t)
	X0 += 0.00000000728*np.cos(2.30992648354 + 839.1817360715*t)
	X0 += 0.00000000698*np.cos(3.25603591732 + 498.1983957056*t)
	X0 += 0.00000000703*np.cos(1.55460321889 + 5654.2242639413*t)
	X0 += 0.00000000717*np.cos(4.55237879181 + 6702.5604938666*t)
	X0 += 0.00000000736*np.cos(1.20028593415 + 403.7036411961*t)
	X0 += 0.00000000701*np.cos(4.58273199053 + 4326.3934009738*t)
	X0 += 0.00000000699*np.cos(5.34077680752 + 725.5815727933*t)
	X0 += 0.00000000684*np.cos(4.81758588915 + 6062.6632075526*t)
	X0 += 0.00000000685*np.cos(5.86089797553 + 455.0523788792*t)
	X0 += 0.00000000792*np.cos(1.62306361946 + 5422.7659212386*t)
	X0 += 0.00000000687*np.cos(5.43360628922 + 103.843533744*t)
	X0 += 0.00000000837*np.cos(5.42290928791 + 570.5323137181*t)
	X0 += 0.00000000681*np.cos(4.97089069344 + 605.275712814*t)
	X0 += 0.00000000752*np.cos(2.13635874110 + 413.1048100573*t)
	X0 += 0.00000000681*np.cos(2.40400472916 + 458.090760265*t)
	X0 += 0.00000000815*np.cos(1.53292306954 + 391.976617376*t)
	X0 += 0.00000000680*np.cos(4.14190883039 + 2143.893642292*t)
	X0 += 0.00000000744*np.cos(0.28747509376 + 457.1969883877*t)
	X0 += 0.00000000687*np.cos(4.40962225159 + 1563.8001010183*t)
	X0 += 0.00000000883*np.cos(0.11492592605 + 378.6432952517*t)
	X0 += 0.00000000740*np.cos(3.78883452039 + 1016.0929010109*t)
	return X0




def Saturn_X1 (t): # 896 terms of order 1

	X1 = 0.
	X1 += 0.07573807889
	X1 += 0.03084144308*np.cos(4.27565898829 + 426.598190876*t)
	X1 += 0.02714141496*np.cos(5.85229546861 + 206.1855484372*t)
	X1 += 0.02642347272*np.cos(5.33291950842 + 220.4126424388*t)
	X1 += 0.00627003445*np.cos(0.32898258729 + 7.1135470008*t)
	X1 += 0.00256488381*np.cos(3.52479443238 + 639.897286314*t)
	X1 += 0.00312269012*np.cos(4.83002443322 + 419.4846438752*t)
	X1 += 0.00189142591*np.cos(4.48642939502 + 433.7117378768*t)
	X1 += 0.00203589147*np.cos(1.10998720016 + 213.299095438*t)
	X1 += 0.00119517217*np.cos(1.14736396934 + 110.2063212194*t)
	X1 += 0.00066742869*np.cos(3.72347003212 + 316.3918696566*t)
	X1 += 0.00066882235*np.cos(5.20257498551 + 227.5261894396*t)
	X1 += 0.00030991837*np.cos(6.06069383491 + 199.0720014364*t)
	X1 += 0.00030413111*np.cos(0.18746990038 + 14.2270940016*t)
	X1 += 0.00022268129*np.cos(6.19542444435 + 103.0927742186*t)
	X1 += 0.00018933918*np.cos(2.77615609434 + 853.196381752*t)
	X1 += 0.00018087850*np.cos(5.09162753222 + 209.3669421749*t)
	X1 += 0.00017772775*np.cos(6.10381591303 + 217.2312487011*t)
	X1 += 0.00016291548*np.cos(4.86945682592 + 216.4804891757*t)
	X1 += 0.00017120603*np.cos(4.59542499292 + 632.7837393132*t)
	X1 += 0.00015889950*np.cos(0.03653526810 + 210.1177017003*t)
	X1 += 0.00016193213*np.cos(5.60825312945 + 323.5054166574*t)
	X1 += 0.00014461916*np.cos(3.67449803828 + 647.0108333148*t)
	X1 += 0.00011058978*np.cos(0.03175095579 + 117.3198682202*t)
	X1 += 0.00009870350*np.cos(5.20065401876 + 202.2533951741*t)
	X1 += 0.00008706840*np.cos(6.03495025016 + 224.3447957019*t)
	X1 += 0.00005497618*np.cos(4.40350640238 + 440.8252848776*t)
	X1 += 0.00005515449*np.cos(2.60541189759 + 11.0457002639*t)
	X1 += 0.00003699033*np.cos(1.36420047437 + 522.5774180938*t)
	X1 += 0.00003570311*np.cos(5.10832701277 + 412.3710968744*t)
	X1 += 0.00002741305*np.cos(4.09776900851 + 149.5631971346*t)
	X1 += 0.00002761279*np.cos(3.96260867581 + 95.9792272178*t)
	X1 += 0.00001876093*np.cos(2.52381113890 + 3.9321532631*t)
	X1 += 0.00001765306*np.cos(0.75684456614 + 277.0349937414*t)
	X1 += 0.00001692588*np.cos(4.74243609118 + 536.8045120954*t)
	X1 += 0.00001688471*np.cos(3.98271487594 + 422.6660376129*t)
	X1 += 0.00001544657*np.cos(5.30307291724 + 330.6189636582*t)
	X1 += 0.00001467039*np.cos(0.00015438412 + 529.6909650946*t)
	X1 += 0.00001366833*np.cos(2.02865467887 + 1066.49547719*t)
	X1 += 0.00001330039*np.cos(5.06312198727 + 234.6397364404*t)
	X1 += 0.00001511486*np.cos(6.23276511633 + 3.1813937377*t)
	X1 += 0.00001270679*np.cos(2.40338510736 + 415.5524906121*t)
	X1 += 0.00001128732*np.cos(5.45795307607 + 423.4167971383*t)
	X1 += 0.00001126065*np.cos(2.88172300482 + 860.3099287528*t)
	X1 += 0.00001100929*np.cos(4.07698729757 + 429.7795846137*t)
	X1 += 0.00001271587*np.cos(0.09494045392 + 742.9900605326*t)
	X1 += 0.00001341894*np.cos(2.98929529398 + 210.8514148832*t)
	X1 += 0.00001330665*np.cos(1.90899526877 + 215.7467759928*t)
	X1 += 0.00000959698*np.cos(0.92647221746 + 838.9692877504*t)
	X1 += 0.00000961220*np.cos(4.48942325366 + 846.0828347512*t)
	X1 += 0.00000882349*np.cos(5.41464815156 + 437.6438911399*t)
	X1 += 0.00000925249*np.cos(1.35858269164 + 625.6701923124*t)
	X1 += 0.00000820262*np.cos(4.74555084219 + 223.5940361765*t)
	X1 += 0.00000811096*np.cos(0.03213863705 + 21.3406410024*t)
	X1 += 0.00000718372*np.cos(6.12728049238 + 430.5303441391*t)
	X1 += 0.00000625679*np.cos(3.88265084193 + 88.865680217*t)
	X1 += 0.00000608949*np.cos(2.50851582822 + 309.2783226558*t)
	X1 += 0.00000544929*np.cos(1.53337149230 + 515.463871093*t)
	X1 += 0.00000595983*np.cos(5.09979150439 + 124.433415221*t)
	X1 += 0.00000472201*np.cos(3.60914985488 + 654.1243803156*t)
	X1 += 0.00000465734*np.cos(0.21394106678 + 203.0041546995*t)
	X1 += 0.00000451746*np.cos(1.11929921156 + 735.8765135318*t)
	X1 += 0.00000405164*np.cos(4.42613862863 + 85.8272988312*t)
	X1 += 0.00000369613*np.cos(3.75025765171 + 76.2660712756*t)
	X1 += 0.00000339017*np.cos(0.74071788415 + 1155.361157407*t)
	X1 += 0.00000340385*np.cos(1.78611648518 + 302.164775655*t)
	X1 += 0.00000323376*np.cos(0.09844912589 + 191.9584544356*t)
	X1 += 0.00000339649*np.cos(2.73823062550 + 217.964961884*t)
	X1 += 0.00000304968*np.cos(0.18416896544 + 231.4583427027*t)
	X1 += 0.00000314732*np.cos(0.28370835646 + 728.762966531*t)
	X1 += 0.00000311511*np.cos(2.36484349864 + 628.8515860501*t)
	X1 += 0.00000311391*np.cos(1.91348898544 + 942.062061969*t)
	X1 += 0.00000298227*np.cos(2.16364374640 + 208.633228992*t)
	X1 += 0.00000270658*np.cos(2.70265519361 + 288.0806940053*t)
	X1 += 0.00000259894*np.cos(0.87228358124 + 18.1592472647*t)
	X1 += 0.00000334303*np.cos(3.07818702918 + 203.7378678824*t)
	X1 += 0.00000259515*np.cos(6.01660018486 + 10.2949407385*t)
	X1 += 0.00000264173*np.cos(3.55307126150 + 362.8622925726*t)
	X1 += 0.00000290607*np.cos(1.81179534417 + 222.8603229936*t)
	X1 += 0.00000214859*np.cos(6.03196961182 + 207.8824694666*t)
	X1 += 0.00000208996*np.cos(5.16442120392 + 218.7157214094*t)
	X1 += 0.00000208264*np.cos(4.40981297916 + 408.4389436113*t)
	X1 += 0.00000209142*np.cos(2.12541918050 + 138.5174968707*t)
	X1 += 0.00000195809*np.cos(0.35649768849 + 52.6901980395*t)
	X1 += 0.00000190687*np.cos(6.22000152508 + 200.7689224658*t)
	X1 += 0.00000188529*np.cos(0.45283523313 + 340.7708920448*t)
	X1 += 0.00000171733*np.cos(1.12897848901 + 831.8557407496*t)
	X1 += 0.00000170838*np.cos(1.17439205178 + 350.3321196004*t)
	X1 += 0.00000167203*np.cos(5.00292045290 + 225.8292684102*t)
	X1 += 0.00000171646*np.cos(2.30457163571 + 127.4717966068*t)
	X1 += 0.00000177509*np.cos(4.94085879824 + 210.3783341312*t)
	X1 += 0.00000177688*np.cos(6.22097530726 + 216.2198567448*t)
	X1 += 0.00000194079*np.cos(5.71429546555 + 1059.3819301892*t)
	X1 += 0.00000161567*np.cos(6.13528887818 + 956.2891559706*t)
	X1 += 0.00000206978*np.cos(5.36438292240 + 949.1756089698*t)
	X1 += 0.00000163339*np.cos(1.48827637108 + 195.1398481733*t)
	X1 += 0.00000149570*np.cos(0.31719520948 + 9.5612275556*t)
	X1 += 0.00000144643*np.cos(4.54007227855 + 543.9180590962*t)
	X1 += 0.00000177257*np.cos(6.27024835072 + 160.6088973985*t)
	X1 += 0.00000170347*np.cos(2.63698505108 + 207.6700211455*t)
	X1 += 0.00000140654*np.cos(0.48104293652 + 1471.7530270636*t)
	X1 += 0.00000150812*np.cos(3.13878111760 + 635.9651330509*t)
	X1 += 0.00000163889*np.cos(2.23920379694 + 218.9281697305*t)
	X1 += 0.00000164968*np.cos(4.62059482677 + 22.0914005278*t)
	X1 += 0.00000145469*np.cos(4.63713942585 + 265.9892934775*t)
	X1 += 0.00000134755*np.cos(3.92461654777 + 750.1036075334*t)
	X1 += 0.00000133754*np.cos(1.25928209722 + 703.6331846174*t)
	X1 += 0.00000152766*np.cos(4.26935902156 + 56.6223513026*t)
	X1 += 0.00000137437*np.cos(1.65792404451 + 1258.4539316256*t)
	X1 += 0.00000125541*np.cos(4.29077908509 + 447.9388318784*t)
	X1 += 0.00000140716*np.cos(4.40833694034 + 142.4496501338*t)
	X1 += 0.00000147398*np.cos(4.19489449356 + 70.8494453042*t)
	X1 += 0.00000134558*np.cos(0.84258328591 + 490.3340891794*t)
	X1 += 0.00000117954*np.cos(2.15227719526 + 618.5566453116*t)
	X1 += 0.00000106790*np.cos(2.74587720126 + 565.1156877467*t)
	X1 += 0.00000105456*np.cos(3.58458171176 + 209.106309744*t)
	X1 += 0.00000123096*np.cos(2.84869686434 + 483.2205421786*t)
	X1 += 0.00000104216*np.cos(1.30367057574 + 217.491881132*t)
	X1 += 0.00000107837*np.cos(6.23672094194 + 1045.1548361876*t)
	X1 += 0.00000103680*np.cos(0.13827521003 + 106.2741679563*t)
	X1 += 0.00000097995*np.cos(1.27230991592 + 1279.794572628*t)
	X1 += 0.00000122664*np.cos(1.73647954150 + 12.5301729722*t)
	X1 += 0.00000107530*np.cos(2.04781654923 + 424.1505103212*t)
	X1 += 0.00000111568*np.cos(3.50500638623 + 269.9214467406*t)
	X1 += 0.00000089898*np.cos(4.39874361756 + 1265.5674786264*t)
	X1 += 0.00000088010*np.cos(2.09813184088 + 1073.6090241908*t)
	X1 += 0.00000085083*np.cos(0.06463976577 + 63.7358983034*t)
	X1 += 0.00000084413*np.cos(6.17211235651 + 113.3877149571*t)
	X1 += 0.00000091967*np.cos(2.31043069927 + 497.4476361802*t)
	X1 += 0.00000081346*np.cos(4.70635118236 + 650.9429865779*t)
	X1 += 0.00000082303*np.cos(3.28548782545 + 643.0786800517*t)
	X1 += 0.00000078375*np.cos(1.28057643864 + 107.0249274817*t)
	X1 += 0.00000095815*np.cos(2.80749230313 + 191.2076949102*t)
	X1 += 0.00000073135*np.cos(0.85149756693 + 1148.2476104062*t)
	X1 += 0.00000070686*np.cos(2.40846378030 + 251.4321310758*t)
	X1 += 0.00000074955*np.cos(1.41374378423 + 284.1485407422*t)
	X1 += 0.00000084109*np.cos(1.77169146527 + 219.4494345923*t)
	X1 += 0.00000065942*np.cos(4.83872793621 + 636.7158925763*t)
	X1 += 0.00000081407*np.cos(0.20581939966 + 1162.4747044078*t)
	X1 += 0.00000063005*np.cos(5.10229133202 + 479.2883889155*t)
	X1 += 0.00000073214*np.cos(4.31149716720 + 344.7030453079*t)
	X1 += 0.00000061071*np.cos(0.21868225550 + 1788.1448967202*t)
	X1 += 0.00000059724*np.cos(6.15667265627 + 99.1606209555*t)
	X1 += 0.00000063039*np.cos(3.97913184944 + 436.8931316145*t)
	X1 += 0.00000064926*np.cos(1.38378985477 + 1574.8458012822*t)
	X1 += 0.00000059701*np.cos(3.30887710221 + 74.7815985673*t)
	X1 += 0.00000057459*np.cos(1.30013550877 + 98.8999885246*t)
	X1 += 0.00000063077*np.cos(3.82649643530 + 358.9301393095*t)
	X1 += 0.00000058706*np.cos(0.74631691499 + 114.1384744825*t)
	X1 += 0.00000065943*np.cos(3.15806871314 + 207.1487562837*t)
	X1 += 0.00000071467*np.cos(5.54585075110 + 1375.7737998458*t)
	X1 += 0.00000060283*np.cos(4.24355163684 + 417.0369633204*t)
	X1 += 0.00000061593*np.cos(0.18111349611 + 404.5067903482*t)
	X1 += 0.00000054192*np.cos(2.42191769133 + 175.1660598002*t)
	X1 += 0.00000063883*np.cos(1.98934528141 + 235.3904959658*t)
	X1 += 0.00000052018*np.cos(2.01145355849 + 220.4608265486*t)
	X1 += 0.00000050350*np.cos(5.61723540234 + 416.3032501375*t)
	X1 += 0.00000048167*np.cos(1.89139655642 + 351.8165923087*t)
	X1 += 0.00000066418*np.cos(4.53131068295 + 337.732510659*t)
	X1 += 0.00000048765*np.cos(3.06797286748 + 151.0476698429*t)
	X1 += 0.00000050400*np.cos(1.52095424250 + 429.0458714308*t)
	X1 += 0.00000046384*np.cos(3.98517523045 + 1581.959348283*t)
	X1 += 0.00000052615*np.cos(4.02063591989 + 4.665866446*t)
	X1 += 0.00000050403*np.cos(1.56736943409 + 121.2520214833*t)
	X1 += 0.00000050842*np.cos(2.66055558906 + 181.0557665236*t)
	X1 += 0.00000055974*np.cos(0.53749535499 + 554.0699874828*t)
	X1 += 0.00000050833*np.cos(2.05330984040 + 934.9485149682*t)
	X1 += 0.00000044915*np.cos(2.30720526284 + 245.5424243524*t)
	X1 += 0.00000044007*np.cos(2.26187654674 + 205.2223405907*t)
	X1 += 0.00000040580*np.cos(2.82302262410 + 867.4234757536*t)
	X1 += 0.00000040794*np.cos(3.77453610582 + 621.7380390493*t)
	X1 += 0.00000039034*np.cos(4.46509633732 + 131.5469622218*t)
	X1 += 0.00000040198*np.cos(4.00305184334 + 81.7521332162*t)
	X1 += 0.00000041101*np.cos(5.97982167014 + 1361.5467058442*t)
	X1 += 0.00000043683*np.cos(2.49416224692 + 198.321241911*t)
	X1 += 0.00000041544*np.cos(5.90298490617 + 643.8294395771*t)
	X1 += 0.00000036501*np.cos(1.88359643454 + 148.0787244263*t)
	X1 += 0.00000036298*np.cos(5.66459628765 + 444.7574381407*t)
	X1 += 0.00000036204*np.cos(2.75001997487 + 214.0498549634*t)
	X1 += 0.00000044554*np.cos(1.95732411408 + 842.1506814881*t)
	X1 += 0.00000034395*np.cos(0.55991266624 + 1464.6394800628*t)
	X1 += 0.00000034251*np.cos(2.87922054674 + 289.5651667136*t)
	X1 += 0.00000036820*np.cos(2.97826336303 + 206.1373643274*t)
	X1 += 0.00000033234*np.cos(5.25972985177 + 177.8743727859*t)
	X1 += 0.00000032812*np.cos(4.42600333541 + 78.7137518304*t)
	X1 += 0.00000032822*np.cos(2.19475458249 + 212.5483359126*t)
	X1 += 0.00000037520*np.cos(2.38353067688 + 228.276948965*t)
	X1 += 0.00000031834*np.cos(1.79566179374 + 275.5505210331*t)
	X1 += 0.00000028965*np.cos(5.92603162323 + 248.7238180901*t)
	X1 += 0.00000031198*np.cos(1.10756989883 + 1891.2376709388*t)
	X1 += 0.00000035352*np.cos(2.37933201235 + 501.3797894433*t)
	X1 += 0.00000027618*np.cos(6.22546756438 + 2104.5367663768*t)
	X1 += 0.00000029957*np.cos(5.40487681857 + 32.2433289144*t)
	X1 += 0.00000033504*np.cos(1.04514414503 + 436.1594184316*t)
	X1 += 0.00000034822*np.cos(6.13406829923 + 1478.8665740644*t)
	X1 += 0.00000031852*np.cos(3.21479408149 + 414.0680179038*t)
	X1 += 0.00000027482*np.cos(3.85997067594 + 114.3991069134*t)
	X1 += 0.00000029366*np.cos(5.70869861143 + 214.7835681463*t)
	X1 += 0.00000025651*np.cos(0.56261005356 + 1052.2683831884*t)
	X1 += 0.00000029442*np.cos(5.76608786139 + 355.7487455718*t)
	X1 += 0.00000024664*np.cos(4.56168548884 + 427.5613987225*t)
	X1 += 0.00000030555*np.cos(5.23325905147 + 1692.1656695024*t)
	X1 += 0.00000027676*np.cos(0.89718596794 + 347.8844390456*t)
	X1 += 0.00000023455*np.cos(2.96060769325 + 278.5194664497*t)
	X1 += 0.00000023061*np.cos(3.72246157747 + 1898.3512179396*t)
	X1 += 0.00000024810*np.cos(0.83325589326 + 425.6349830295*t)
	X1 += 0.00000023968*np.cos(1.93756656786 + 431.264057322*t)
	X1 += 0.00000025563*np.cos(4.02928916042 + 69.1525242748*t)
	X1 += 0.00000022254*np.cos(2.97473191186 + 601.7642506762*t)
	X1 += 0.00000021877*np.cos(3.74094863602 + 299.1263942692*t)
	X1 += 0.00000024055*np.cos(1.75938579140 + 508.3503240922*t)
	X1 += 0.00000021272*np.cos(0.55451958674 + 916.9322800554*t)
	X1 += 0.00000021278*np.cos(3.99747719378 + 319.5732633943*t)
	X1 += 0.00000024242*np.cos(0.23640017361 + 1272.6810256272*t)
	X1 += 0.00000022384*np.cos(2.85389159089 + 576.1613880106*t)
	X1 += 0.00000023974*np.cos(3.13703648780 + 134.5853436076*t)
	X1 += 0.00000024477*np.cos(1.75741242790 + 1251.3403846248*t)
	X1 += 0.00000020791*np.cos(4.86337530922 + 241.7532834412*t)
	X1 += 0.00000025281*np.cos(1.25065914595 + 421.93232443*t)
	X1 += 0.00000021820*np.cos(5.17668449284 + 405.2575498736*t)
	X1 += 0.00000019942*np.cos(1.87120288031 + 295.0512286542*t)
	X1 += 0.00000023121*np.cos(4.47416931306 + 230.7075831773*t)
	X1 += 0.00000020375*np.cos(1.15875306859 + 426.6463749858*t)
	X1 += 0.00000019224*np.cos(2.18427009211 + 333.657345044*t)
	X1 += 0.00000021067*np.cos(4.89381984040 + 421.1815649046*t)
	X1 += 0.00000019761*np.cos(1.44807575199 + 188.9200730498*t)
	X1 += 0.00000021171*np.cos(2.77618836420 + 221.3758502853*t)
	X1 += 0.00000019879*np.cos(4.95105499299 + 312.4597163935*t)
	X1 += 0.00000017765*np.cos(1.15218439574 + 5.4166259714*t)
	X1 += 0.00000018160*np.cos(5.37336510772 + 205.4347889118*t)
	X1 += 0.00000017576*np.cos(4.88872208031 + 313.2104759189*t)
	X1 += 0.00000019556*np.cos(5.57005392669 + 327.4375699205*t)
	X1 += 0.00000017303*np.cos(5.13480198138 + 320.3240229197*t)
	X1 += 0.00000017270*np.cos(4.34613632899 + 120.358249606*t)
	X1 += 0.00000022410*np.cos(4.17014708230 + 39.3568759152*t)
	X1 += 0.00000016690*np.cos(0.29893752523 + 1781.0313497194*t)
	X1 += 0.00000016458*np.cos(4.30803351694 + 439.1283638482*t)
	X1 += 0.00000018207*np.cos(0.48659303659 + 6275.9623029906*t)
	X1 += 0.00000021732*np.cos(5.22005710777 + 211.8146227297*t)
	X1 += 0.00000018507*np.cos(4.70834364633 + 144.1465711632*t)
	X1 += 0.00000016075*np.cos(1.92420405654 + 778.4147831847*t)
	X1 += 0.00000017154*np.cos(3.41932820069 + 237.6781178262*t)
	X1 += 0.00000017797*np.cos(6.17606912280 + 6290.1893969922*t)
	X1 += 0.00000019762*np.cos(2.03523955092 + 696.5196376166*t)
	X1 += 0.00000017090*np.cos(1.90981812501 + 10206.1719992102*t)
	X1 += 0.00000015935*np.cos(5.76041448948 + 1677.9385755008*t)
	X1 += 0.00000020378*np.cos(4.24340498319 + 426.5500067662*t)
	X1 += 0.00000016597*np.cos(0.85397214019 + 2207.6295405954*t)
	X1 += 0.00000016706*np.cos(1.31728263597 + 10220.3990932118*t)
	X1 += 0.00000018071*np.cos(6.21759540157 + 166.828672522*t)
	X1 += 0.00000018385*np.cos(3.75515575211 + 67.6680515665*t)
	X1 += 0.00000015128*np.cos(1.51586170044 + 710.7467316182*t)
	X1 += 0.00000014449*np.cos(6.18261120713 + 525.4981794006*t)
	X1 += 0.00000016166*np.cos(4.69227400215 + 14.977853527*t)
	X1 += 0.00000014583*np.cos(0.68816508751 + 99.9113804809*t)
	X1 += 0.00000014470*np.cos(0.69520749579 + 59.8037450403*t)
	X1 += 0.00000013310*np.cos(5.39284427062 + 1169.5882514086*t)
	X1 += 0.00000017662*np.cos(5.83272145706 + 1795.258443721*t)
	X1 += 0.00000013053*np.cos(4.90886335399 + 196.0336200506*t)
	X1 += 0.00000012965*np.cos(3.45124261363 + 87.3117715395*t)
	X1 += 0.00000013625*np.cos(1.06434195633 + 312.1990839626*t)
	X1 += 0.00000014561*np.cos(4.55001974727 + 381.3516082374*t)
	X1 += 0.00000014849*np.cos(5.26704509981 + 182.279606801*t)
	X1 += 0.00000017110*np.cos(1.29146214271 + 432.2272651685*t)
	X1 += 0.00000012655*np.cos(5.95283827941 + 2420.9286360334*t)
	X1 += 0.00000015239*np.cos(5.32338258618 + 429.5189521828*t)
	X1 += 0.00000012510*np.cos(3.78183987918 + 757.2171545342*t)
	X1 += 0.00000012205*np.cos(3.50752907894 + 661.2379273164*t)
	X1 += 0.00000013493*np.cos(2.43215265163 + 849.2642284889*t)
	X1 += 0.00000014072*np.cos(4.06344928621 + 395.578702239*t)
	X1 += 0.00000013601*np.cos(0.17868852981 + 96.8729990951*t)
	X1 += 0.00000011964*np.cos(6.23368291889 + 230.5645708254*t)
	X1 += 0.00000013246*np.cos(4.65483803385 + 129.9194771616*t)
	X1 += 0.00000014172*np.cos(0.19960468334 + 116.4260963429*t)
	X1 += 0.00000011819*np.cos(0.54037105135 + 430.79097657*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000012156*np.cos(5.83782522442 + 373.9079928365*t)
	X1 += 0.00000011378*np.cos(3.43727161334 + 2214.7430875962*t)
	X1 += 0.00000014807*np.cos(5.01458165145 + 273.1028404783*t)
	X1 += 0.00000013178*np.cos(1.47675722182 + 1567.7322542814*t)
	X1 += 0.00000011322*np.cos(1.65088277124 + 776.9303104764*t)
	X1 += 0.00000012602*np.cos(6.09917656228 + 28.4541880032*t)
	X1 += 0.00000011336*np.cos(4.21862046409 + 131.4039498699*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000010998*np.cos(4.22331215028 + 145.6310438715*t)
	X1 += 0.00000012399*np.cos(4.16744254740 + 329.7251917809*t)
	X1 += 0.00000011422*np.cos(0.13933692639 + 617.8058857862*t)
	X1 += 0.00000010671*np.cos(5.59629136646 + 426.0769260142*t)
	X1 += 0.00000010673*np.cos(5.82038453434 + 221.1634019642*t)
	X1 += 0.00000013921*np.cos(3.33457458779 + 558.0021407459*t)
	X1 += 0.00000010778*np.cos(4.18033815184 + 343.2185725996*t)
	X1 += 0.00000011528*np.cos(4.81930125364 + 432.0148168474*t)
	X1 += 0.00000011552*np.cos(1.84554412069 + 5849.3641121146*t)
	X1 += 0.00000010051*np.cos(0.62803050508 + 767.3690829208*t)
	X1 += 0.00000013339*np.cos(5.02992037744 + 2008.557539159*t)
	X1 += 0.00000010229*np.cos(1.16924486323 + 199.2844497575*t)
	X1 += 0.00000010068*np.cos(1.36356275788 + 206.706813299*t)
	X1 += 0.00000010639*np.cos(0.61839689270 + 84.3428261229*t)
	X1 += 0.00000010876*np.cos(3.34333014843 + 305.3461693927*t)
	X1 += 0.00000010915*np.cos(2.79445499623 + 199.9657733137*t)
	X1 += 0.00000009725*np.cos(3.30023563496 + 181.806526049*t)
	X1 += 0.00000009672*np.cos(6.28029607027 + 238.5718897035*t)
	X1 += 0.00000009859*np.cos(2.88114726106 + 572.2292347475*t)
	X1 += 0.00000012081*np.cos(2.17889127290 + 62.2514255951*t)
	X1 += 0.00000010814*np.cos(3.27218935827 + 9779.5738083342*t)
	X1 += 0.00000009745*np.cos(4.95649952378 + 184.9879197867*t)
	X1 += 0.00000009751*np.cos(1.00495055462 + 192.6921676185*t)
	X1 += 0.00000011495*np.cos(0.37585889114 + 92.0470739547*t)
	X1 += 0.00000009779*np.cos(2.45540897959 + 188.1693135244*t)
	X1 += 0.00000011105*np.cos(5.60272957525 + 46.470422916*t)
	X1 += 0.00000010288*np.cos(1.25217228657 + 5863.5912061162*t)
	X1 += 0.00000012505*np.cos(6.06854885763 + 196.6243208816*t)
	X1 += 0.00000010047*np.cos(0.46188126695 + 20.6069278195*t)
	X1 += 0.00000010712*np.cos(6.08785652303 + 427.1194557378*t)
	X1 += 0.00000009237*np.cos(3.96643507366 + 280.9671470045*t)
	X1 += 0.00000009203*np.cos(4.30153048670 + 214.5711198252*t)
	X1 += 0.00000009203*np.cos(0.58809567989 + 212.0270710508*t)
	X1 += 0.00000010243*np.cos(0.54672366594 + 1589.0728952838*t)
	X1 += 0.00000009371*np.cos(3.72043087349 + 227.3137411185*t)
	X1 += 0.00000010238*np.cos(5.85230859079 + 244.318584075*t)
	X1 += 0.00000010120*np.cos(5.73318727961 + 65.2203710117*t)
	X1 += 0.00000011380*np.cos(1.44237688792 + 156.6767441354*t)
	X1 += 0.00000010536*np.cos(0.03525818188 + 153.4953503977*t)
	X1 += 0.00000010417*np.cos(4.57368017472 + 41.6444977756*t)
	X1 += 0.00000010043*np.cos(2.09517100147 + 226.6324175623*t)
	X1 += 0.00000009557*np.cos(0.89168093041 + 411.620337349*t)
	X1 += 0.00000008873*np.cos(3.26329229257 + 963.4027029714*t)
	X1 += 0.00000011992*np.cos(1.46247236631 + 563.6312150384*t)
	X1 += 0.00000008787*np.cos(1.29695498377 + 51.2057253312*t)
	X1 += 0.00000009612*np.cos(2.67949657630 + 9793.8009023358*t)
	X1 += 0.00000010094*np.cos(4.87681316056 + 259.769518354*t)
	X1 += 0.00000008710*np.cos(2.51870094895 + 238.4288773516*t)
	X1 += 0.00000009008*np.cos(1.18557398919 + 637.4496057592*t)
	X1 += 0.00000008926*np.cos(3.80008358468 + 233.9060232575*t)
	X1 += 0.00000008884*np.cos(2.03591715695 + 159.1244246902*t)
	X1 += 0.00000009253*np.cos(4.47419699520 + 77.962992305*t)
	X1 += 0.00000009590*np.cos(4.94810472412 + 326.6868103951*t)
	X1 += 0.00000011742*np.cos(2.57725200458 + 45.5766510387*t)
	X1 += 0.00000008212*np.cos(0.05357930115 + 2097.423219376*t)
	X1 += 0.00000008676*np.cos(1.36795623721 + 824.7421937488*t)
	X1 += 0.00000009187*np.cos(3.26250261117 + 556.5176680376*t)
	X1 += 0.00000008184*np.cos(6.18341957072 + 241.6102710893*t)
	X1 += 0.00000008040*np.cos(2.68676513528 + 546.956440482*t)
	X1 += 0.00000010057*np.cos(0.45621087059 + 258.8757464767*t)
	X1 += 0.00000008030*np.cos(1.57230173248 + 244.791664827*t)
	X1 += 0.00000010377*np.cos(2.43734552323 + 212.4053235607*t)
	X1 += 0.00000010377*np.cos(2.45228064336 + 214.1928673153*t)
	X1 += 0.00000009061*np.cos(2.72986488306 + 206.233732547*t)
	X1 += 0.00000010519*np.cos(2.17106565253 + 92.940845832*t)
	X1 += 0.00000008685*np.cos(5.30112488875 + 220.364458329*t)
	X1 += 0.00000008358*np.cos(0.57656413895 + 2524.021410252*t)
	X1 += 0.00000008160*np.cos(1.28270278200 + 60.7669528868*t)
	X1 += 0.00000008189*np.cos(0.93497045777 + 195.8906076987*t)
	X1 += 0.00000007936*np.cos(2.57331527300 + 173.9422195228*t)
	X1 += 0.00000007295*np.cos(0.46947569621 + 1493.093668066*t)
	X1 += 0.00000007076*np.cos(1.51163518889 + 464.7312265138*t)
	X1 += 0.00000008902*np.cos(0.92333738769 + 81.8951455681*t)
	X1 += 0.00000007187*np.cos(3.90838603910 + 864.2420820159*t)
	X1 += 0.00000007014*np.cos(3.23031710720 + 627.3671133418*t)
	X1 += 0.00000007389*np.cos(2.49697747476 + 254.9435932136*t)
	X1 += 0.00000006894*np.cos(5.98648101436 + 282.4516197128*t)
	X1 += 0.00000006941*np.cos(1.47629647815 + 561.1835344836*t)
	X1 += 0.00000007826*np.cos(3.52552865669 + 23.5758732361*t)
	X1 += 0.00000006648*np.cos(1.31475016542 + 1286.9081196288*t)
	X1 += 0.00000006665*np.cos(1.25893140425 + 357.4456666012*t)
	X1 += 0.00000007035*np.cos(3.95586092314 + 458.8415197904*t)
	X1 += 0.00000006518*np.cos(6.21803736938 + 638.4128136057*t)
	X1 += 0.00000007597*np.cos(4.56291940149 + 186.472392495*t)
	X1 += 0.00000007106*np.cos(2.68615304998 + 570.7447620392*t)
	X1 += 0.00000006833*np.cos(2.32576577597 + 73.297125859*t)
	X1 += 0.00000006436*np.cos(5.64783432607 + 1994.3304451574*t)
	X1 += 0.00000008770*np.cos(5.50567173542 + 2111.6503133776*t)
	X1 += 0.00000006216*np.cos(2.02339326554 + 171.6545976624*t)
	X1 += 0.00000006188*np.cos(1.48241471659 + 339.2864193365*t)
	X1 += 0.00000007303*np.cos(1.22221564178 + 1884.124123938*t)
	X1 += 0.00000007629*np.cos(3.38251628365 + 295.1942410061*t)
	X1 += 0.00000006035*np.cos(2.93854921292 + 31.019488637*t)
	X1 += 0.00000005998*np.cos(0.44195423177 + 334.5511169213*t)
	X1 += 0.00000006129*np.cos(4.96628964200 + 211.0114735776*t)
	X1 += 0.00000006129*np.cos(6.20652183177 + 215.5867172984*t)
	X1 += 0.00000006230*np.cos(2.93562516232 + 274.0660483248*t)
	X1 += 0.00000007108*np.cos(1.56333289690 + 427.3489504014*t)
	X1 += 0.00000005728*np.cos(5.71498118676 + 2737.32050569*t)
	X1 += 0.00000006470*np.cos(5.25485081311 + 162.0933701068*t)
	X1 += 0.00000005741*np.cos(4.42916296869 + 128.9562693151*t)
	X1 += 0.00000005868*np.cos(5.70598476093 + 264.5048207692*t)
	X1 += 0.00000005589*np.cos(3.90685132543 + 54.1746707478*t)
	X1 += 0.00000006286*np.cos(0.94028611990 + 432.7485300303*t)
	X1 += 0.00000005979*np.cos(0.47283810206 + 240.125798381*t)
	X1 += 0.00000005548*np.cos(3.14875859722 + 2531.1349572528*t)
	X1 += 0.00000005905*np.cos(2.50850442183 + 856.3777754897*t)
	X1 += 0.00000005596*np.cos(2.61159505041 + 193.655375465*t)
	X1 += 0.00000006762*np.cos(2.27424026675 + 420.9691165835*t)
	X1 += 0.00000007277*np.cos(2.47497568796 + 611.4430983108*t)
	X1 += 0.00000005462*np.cos(0.48649532469 + 1905.4647649404*t)
	X1 += 0.00000005579*np.cos(2.41862523941 + 252.6559713532*t)
	X1 += 0.00000005918*np.cos(3.85830083228 + 422.405405182*t)
	X1 += 0.00000005963*np.cos(2.87749733117 + 16.6747745564*t)
	X1 += 0.00000006291*np.cos(4.79715993624 + 423.6774295692*t)
	X1 += 0.00000005288*np.cos(2.86056658179 + 267.4737661858*t)
	X1 += 0.00000005147*np.cos(1.21452560134 + 488.8496164711*t)
	X1 += 0.00000005102*np.cos(1.71142923231 + 472.1748419147*t)
	X1 += 0.00000006136*np.cos(3.08419059916 + 125.9873238985*t)
	X1 += 0.00000004857*np.cos(2.21952453414 + 29.2049475286*t)
	X1 += 0.00000006447*np.cos(4.25155724533 + 107.7586406646*t)
	X1 += 0.00000005252*np.cos(4.32715420518 + 342.2553647531*t)
	X1 += 0.00000004774*np.cos(1.45631356540 + 394.3548619616*t)
	X1 += 0.00000006315*np.cos(4.86204823155 + 2324.9494088156*t)
	X1 += 0.00000004862*np.cos(2.45699450502 + 526.5095713569*t)
	X1 += 0.00000005004*np.cos(3.21047421953 + 650.1922270525*t)
	X1 += 0.00000005322*np.cos(4.76999032492 + 24.3790223882*t)
	X1 += 0.00000004502*np.cos(3.81171539816 + 167.7224443993*t)
	X1 += 0.00000004550*np.cos(0.86759003557 + 291.262087743*t)
	X1 += 0.00000004559*np.cos(1.72604137750 + 418.5214360287*t)
	X1 += 0.00000005441*np.cos(2.06417156626 + 229.9738699944*t)
	X1 += 0.00000005565*np.cos(2.29608792740 + 38.1330356378*t)
	X1 += 0.00000005865*np.cos(3.88586257924 + 551.031606097*t)
	X1 += 0.00000004491*np.cos(4.35642719677 + 850.0149880143*t)
	X1 += 0.00000004589*np.cos(1.09304022282 + 1141.1340634054*t)
	X1 += 0.00000004471*np.cos(0.86761100667 + 361.3778198643*t)
	X1 += 0.00000004779*np.cos(2.28566566949 + 397.3932433474*t)
	X1 += 0.00000004269*np.cos(5.42826152642 + 201.5196819912*t)
	X1 += 0.00000004269*np.cos(2.60295729376 + 225.0785088848*t)
	X1 += 0.00000004391*np.cos(4.27594847745 + 491.8185618877*t)
	X1 += 0.00000004469*np.cos(5.64881997462 + 428.0826635843*t)
	X1 += 0.00000004012*np.cos(5.27339722503 + 425.1137181677*t)
	X1 += 0.00000004407*np.cos(0.30585517060 + 2840.4132799086*t)
	X1 += 0.00000004203*np.cos(2.42086992646 + 364.3467652809*t)
	X1 += 0.00000003858*np.cos(5.61266727903 + 77.7505439839*t)
	X1 += 0.00000004218*np.cos(4.29824706870 + 135.336103133*t)
	X1 += 0.00000003913*np.cos(2.20696118315 + 504.561183181*t)
	X1 += 0.00000003960*np.cos(1.01941294318 + 292.0128472684*t)
	X1 += 0.00000003740*np.cos(4.88716400146 + 658.0565335787*t)
	X1 += 0.00000003805*np.cos(4.25039588116 + 692.5874843535*t)
	X1 += 0.00000003782*np.cos(6.17958645001 + 2413.8150890326*t)
	X1 += 0.00000004999*np.cos(1.43325039057 + 448.6895914038*t)
	X1 += 0.00000003941*np.cos(1.19970132537 + 433.7599219866*t)
	X1 += 0.00000004489*np.cos(2.13031131602 + 409.9234163196*t)
	X1 += 0.00000004724*np.cos(0.88455881434 + 205.6642835754*t)
	X1 += 0.00000004853*np.cos(3.82187028425 + 189.7232222019*t)
	X1 += 0.00000003566*np.cos(1.79794788895 + 211.6021744086*t)
	X1 += 0.00000003566*np.cos(6.23327093123 + 214.9960164674*t)
	X1 += 0.00000004241*np.cos(3.81197673400 + 369.9758395734*t)
	X1 += 0.00000004210*np.cos(0.96298353439 + 2200.5159935946*t)
	X1 += 0.00000003518*np.cos(0.26426270051 + 33.1371007917*t)
	X1 += 0.00000004251*np.cos(5.30335991719 + 525.7588118315*t)
	X1 += 0.00000003682*np.cos(0.80307954180 + 732.6951197941*t)
	X1 += 0.00000004559*np.cos(3.52798487098 + 835.0371344873*t)
	X1 += 0.00000004873*np.cos(1.38708989982 + 721.6494195302*t)
	X1 += 0.00000003781*np.cos(1.03748681100 + 106.0135355254*t)
	X1 += 0.00000004527*np.cos(0.86326298236 + 220.9339073006*t)
	X1 += 0.00000003477*np.cos(0.22806246853 + 2221.856634597*t)
	X1 += 0.00000003735*np.cos(5.87888144153 + 33.9402499438*t)
	X1 += 0.00000004657*np.cos(5.21916539574 + 2428.0421830342*t)
	X1 += 0.00000003967*np.cos(5.18202138976 + 120.5012619579*t)
	X1 += 0.00000003785*np.cos(5.04003954266 + 214.9436268407*t)
	X1 += 0.00000003785*np.cos(6.13277193111 + 211.6545640353*t)
	X1 += 0.00000003610*np.cos(1.83782296246 + 409.1897031367*t)
	X1 += 0.00000003300*np.cos(6.20167657081 + 543.0242872189*t)
	X1 += 0.00000003287*np.cos(4.88392830876 + 184.0941479094*t)
	X1 += 0.00000003713*np.cos(1.92562812532 + 203.2647871304*t)
	X1 += 0.00000003713*np.cos(6.10559069486 + 223.3334037456*t)
	X1 += 0.00000003167*np.cos(0.25257995187 + 201.9927627432*t)
	X1 += 0.00000003167*np.cos(1.49545356113 + 224.6054281328*t)
	X1 += 0.00000003700*np.cos(4.89576644081 + 170.0100662597*t)
	X1 += 0.00000004012*np.cos(2.58912835624 + 494.2662424425*t)
	X1 += 0.00000004001*np.cos(2.01408132063 + 519.3960243561*t)
	X1 += 0.00000003678*np.cos(1.45731309163 + 418.0001711669*t)
	X1 += 0.00000003067*np.cos(2.46882556311 + 441.576044403*t)
	X1 += 0.00000003380*np.cos(0.76892084559 + 236.8749686741*t)
	X1 += 0.00000003101*np.cos(5.70696828046 + 406.954470903*t)
	X1 += 0.00000002898*np.cos(2.07796697547 + 1080.7225711916*t)
	X1 += 0.00000002943*np.cos(4.30276376907 + 255.8373650909*t)
	X1 += 0.00000003571*np.cos(0.56587079675 + 511.5317178299*t)
	X1 += 0.00000003935*np.cos(3.71027206200 + 425.8474313506*t)
	X1 += 0.00000002881*np.cos(4.27828370830 + 92.7978334801*t)
	X1 += 0.00000002993*np.cos(4.47257282424 + 405.9912630565*t)
	X1 += 0.00000003235*np.cos(2.72240470556 + 112.6540017742*t)
	X1 += 0.00000003336*np.cos(0.12942181361 + 128.3655684841*t)
	X1 += 0.00000002826*np.cos(2.70175929398 + 84.9335269539*t)
	X1 += 0.00000002998*np.cos(2.34100102411 + 388.4651552382*t)
	X1 += 0.00000002751*np.cos(3.07786378008 + 518.6452648307*t)
	X1 += 0.00000002850*np.cos(5.39053439064 + 220.5245170234*t)
	X1 += 0.00000002755*np.cos(5.36323095715 + 731.9443602687*t)
	X1 += 0.00000003003*np.cos(3.47647543508 + 450.9772132642*t)
	X1 += 0.00000002703*np.cos(3.67105639526 + 344.8460576598*t)
	X1 += 0.00000002705*np.cos(4.48933959673 + 60.5545045657*t)
	X1 += 0.00000002900*np.cos(1.18282938719 + 532.8723588323*t)
	X1 += 0.00000002669*np.cos(2.23461202741 + 815.0633461142*t)
	X1 += 0.00000003694*np.cos(1.25430082141 + 465.9550667912*t)
	X1 += 0.00000002831*np.cos(2.64047307044 + 2847.5268269094*t)
	X1 += 0.00000002858*np.cos(5.54569423185 + 540.7366653585*t)
	X1 += 0.00000002763*np.cos(2.67302780179 + 5636.0650166766*t)
	X1 += 0.00000002782*np.cos(0.10347092925 + 638.9340784675*t)
	X1 += 0.00000002613*np.cos(0.64725972976 + 739.8086667949*t)
	X1 += 0.00000002865*np.cos(0.07273098423 + 58.1068240109*t)
	X1 += 0.00000003003*np.cos(4.78201826415 + 2641.3412784722*t)
	X1 += 0.00000002843*np.cos(0.39095638889 + 630.3360587584*t)
	X1 += 0.00000003596*np.cos(1.37444203378 + 1055.4497769261*t)
	X1 += 0.00000003169*np.cos(5.31181193539 + 55.1378785943*t)
	X1 += 0.00000002545*np.cos(4.09883259215 + 455.0523788792*t)
	X1 += 0.00000002510*np.cos(3.89386878011 + 640.8604941605*t)
	X1 += 0.00000002993*np.cos(4.38089542258 + 462.0229135281*t)
	X1 += 0.00000002474*np.cos(1.50083275203 + 419.532827985*t)
	X1 += 0.00000002847*np.cos(5.76025163205 + 348.635198571*t)
	X1 += 0.00000002551*np.cos(1.28445104958 + 184.8449074348*t)
	X1 += 0.00000003048*np.cos(0.69309647906 + 6062.6632075526*t)
	X1 += 0.00000002526*np.cos(5.44087477787 + 857.1285350151*t)
	X1 += 0.00000002597*np.cos(0.35423361548 + 426.4863162914*t)
	X1 += 0.00000002441*np.cos(3.20019142038 + 1368.660252845*t)
	X1 += 0.00000002937*np.cos(4.96203625209 + 739.0579072695*t)
	X1 += 0.00000002464*np.cos(5.65030234126 + 3053.7123753466*t)
	X1 += 0.00000002820*np.cos(6.27704326901 + 256.5881246163*t)
	X1 += 0.00000002444*np.cos(3.25740106622 + 420.4478517217*t)
	X1 += 0.00000002412*np.cos(3.12276627293 + 1685.0521225016*t)
	X1 += 0.00000003165*np.cos(5.89068478002 + 200.5564741447*t)
	X1 += 0.00000003165*np.cos(2.14053404016 + 226.0417167313*t)
	X1 += 0.00000002534*np.cos(6.05167254488 + 2730.2069586892*t)
	X1 += 0.00000003229*np.cos(1.28247322439 + 137.0330241624*t)
	X1 += 0.00000002447*np.cos(3.11720914436 + 206.9363079626*t)
	X1 += 0.00000002447*np.cos(4.91400967582 + 219.6618829134*t)
	X1 += 0.00000002710*np.cos(1.36243351725 + 1802.3719907218*t)
	X1 += 0.00000002346*np.cos(2.75550177516 + 533.6231183577*t)
	X1 += 0.00000002344*np.cos(1.03710656159 + 402.2191684878*t)
	X1 += 0.00000002329*np.cos(2.12756268735 + 454.9093665273*t)
	X1 += 0.00000002353*np.cos(2.57967727687 + 398.1440028728*t)
	X1 += 0.00000003270*np.cos(1.82014094673 + 714.6788848813*t)
	X1 += 0.00000002295*np.cos(2.14341201879 + 502.8642621516*t)
	X1 += 0.00000002650*np.cos(1.83522077064 + 172.2452984934*t)
	X1 += 0.00000002906*np.cos(1.49315014147 + 403.0223176399*t)
	X1 += 0.00000002979*np.cos(1.32345981452 + 1485.9801210652*t)
	X1 += 0.00000002217*np.cos(5.60216247483 + 2310.722314814*t)
	X1 += 0.00000002312*np.cos(5.81192933715 + 724.8308132679*t)
	X1 += 0.00000002379*np.cos(0.86162227365 + 1457.525933062*t)
	X1 += 0.00000002636*np.cos(0.30028112725 + 649.4585138696*t)
	X1 += 0.00000002635*np.cos(2.09112624929 + 9992.8729037722*t)
	X1 += 0.00000002459*np.cos(4.21812788054 + 468.2426886516*t)
	X1 += 0.00000002141*np.cos(2.44752114690 + 480.7728616238*t)
	X1 += 0.00000002195*np.cos(0.95099493253 + 593.426863398*t)
	X1 += 0.00000002116*np.cos(3.28858497352 + 1382.8873468466*t)
	X1 += 0.00000002136*np.cos(1.09577252073 + 186.2117600641*t)
	X1 += 0.00000002117*np.cos(4.65919075880 + 71.6002048296*t)
	X1 += 0.00000002275*np.cos(4.10907333096 + 393.4610900843*t)
	X1 += 0.00000002460*np.cos(2.08222252767 + 5650.2921106782*t)
	X1 += 0.00000002690*np.cos(5.21694504184 + 980.6681783588*t)
	X1 += 0.00000002847*np.cos(2.21208357060 + 927.8349679674*t)
	X1 += 0.00000002465*np.cos(2.83150372526 + 306.0969289181*t)
	X1 += 0.00000002153*np.cos(5.44863339657 + 232.942815411*t)
	X1 += 0.00000002597*np.cos(5.04726142112 + 426.7100654606*t)
	X1 += 0.00000002201*np.cos(2.69689845951 + 434.6749457233*t)
	X1 += 0.00000002057*np.cos(0.81369675900 + 298.2326223919*t)
	X1 += 0.00000002404*np.cos(3.51565880925 + 9580.5018068978*t)
	X1 += 0.00000002260*np.cos(4.11126690849 + 42.5382696529*t)
	X1 += 0.00000002242*np.cos(0.02196017056 + 774.4826299216*t)
	X1 += 0.00000001980*np.cos(6.26959509527 + 188.0263011725*t)
	X1 += 0.00000001947*np.cos(4.98845259619 + 141.2258098564*t)
	X1 += 0.00000002519*np.cos(5.65207938247 + 6489.2613984286*t)
	X1 += 0.00000002659*np.cos(4.98749485033 + 2744.4340526908*t)
	X1 += 0.00000002045*np.cos(5.94414624932 + 477.8039162072*t)
	X1 += 0.00000002463*np.cos(0.72737478637 + 629.6023455755*t)
	X1 += 0.00000002042*np.cos(0.22222750144 + 380.12776796*t)
	X1 += 0.00000001912*np.cos(2.15038299463 + 162.8965192589*t)
	X1 += 0.00000001901*np.cos(6.21446767804 + 271.4059194489*t)
	X1 += 0.00000002178*np.cos(3.04872502572 + 254.3528923826*t)
	X1 += 0.00000001872*np.cos(2.25107452526 + 905.8865797915*t)
	X1 += 0.00000001888*np.cos(0.97996534938 + 642.3449668688*t)
	X1 += 0.00000002170*np.cos(1.32347573273 + 1038.0412891868*t)
	X1 += 0.00000001899*np.cos(0.47442297068 + 1049.0869894507*t)
	X1 += 0.00000002182*np.cos(4.42761937882 + 426.8106391971*t)
	X1 += 0.00000001855*np.cos(0.70172463076 + 760.25553592*t)
	X1 += 0.00000001811*np.cos(0.95890385523 + 842.9014410135*t)
	X1 += 0.00000002347*np.cos(0.79433458213 + 10419.4710946482*t)
	X1 += 0.00000001793*np.cos(3.43045021055 + 419.4364597654*t)
	X1 += 0.00000001870*np.cos(4.48530468485 + 49.5088043018*t)
	X1 += 0.00000001788*np.cos(2.03408748606 + 170.7608257851*t)
	X1 += 0.00000001778*np.cos(2.30435271781 + 702.1487119091*t)
	X1 += 0.00000001796*np.cos(3.79385342755 + 240.3864308119*t)
	X1 += 0.00000001974*np.cos(0.40863452127 + 639.9454704238*t)
	X1 += 0.00000001773*np.cos(0.91546662134 + 990.2294059144*t)
	X1 += 0.00000001823*np.cos(6.21733480836 + 2538.2485042536*t)
	X1 += 0.00000001977*np.cos(4.78604848197 + 1048.3362299253*t)
	X1 += 0.00000002481*np.cos(2.96642006057 + 105.5404547734*t)
	X1 += 0.00000002133*np.cos(1.74104444317 + 552.5855147745*t)
	X1 += 0.00000001999*np.cos(1.18716789706 + 6076.8903015542*t)
	X1 += 0.00000002182*np.cos(0.97387565779 + 426.3857425549*t)
	X1 += 0.00000001839*np.cos(5.55208370554 + 486.4019359163*t)
	X1 += 0.00000001980*np.cos(6.08475811682 + 206.2974230218*t)
	X1 += 0.00000001910*np.cos(4.61558595685 + 175.4266922311*t)
	X1 += 0.00000002379*np.cos(3.57535524190 + 594.6507036754*t)
	X1 += 0.00000001783*np.cos(3.93430854425 + 212.3358875915*t)
	X1 += 0.00000001733*np.cos(3.39728756412 + 705.1176573257*t)
	X1 += 0.00000001824*np.cos(0.43158734549 + 420.005908737*t)
	X1 += 0.00000001802*np.cos(4.09102296722 + 9566.2747128962*t)
	X1 += 0.00000001857*np.cos(3.09120325612 + 141.6988906084*t)
	X1 += 0.00000002035*np.cos(3.95594803721 + 481.7360694703*t)
	X1 += 0.00000001706*np.cos(0.75846006307 + 97.6761482472*t)
	X1 += 0.00000001861*np.cos(3.54944197324 + 5165.3626887242*t)
	X1 += 0.00000001713*np.cos(1.30182191650 + 457.617679513*t)
	X1 += 0.00000001826*np.cos(4.99126473800 + 484.7050148869*t)
	X1 += 0.00000001771*np.cos(3.57657405367 + 555.5544601911*t)
	X1 += 0.00000002042*np.cos(0.72463541689 + 6069.7767545534*t)
	X1 += 0.00000001664*np.cos(5.37724239080 + 1127.2624300768*t)
	X1 += 0.00000001863*np.cos(2.61132821127 + 10007.0999977738*t)
	X1 += 0.00000001691*np.cos(2.07854652969 + 789.4604834486*t)
	X1 += 0.00000001806*np.cos(4.28182661820 + 1193.9672737968*t)
	X1 += 0.00000001863*np.cos(3.43301421030 + 699.7010313543*t)
	X1 += 0.00000001651*np.cos(2.95151342978 + 152.5321425512*t)
	X1 += 0.00000001958*np.cos(3.34832715644 + 143.9341228421*t)
	X1 += 0.00000001804*np.cos(0.11880647530 + 353.301065017*t)
	X1 += 0.00000001746*np.cos(0.02529348358 + 3156.8051495652*t)
	X1 += 0.00000001643*np.cos(1.16931668732 + 1112.0721282287*t)
	X1 += 0.00000001572*np.cos(4.52454618070 + 91.7864415238*t)
	X1 += 0.00000001687*np.cos(5.79136509790 + 3046.5988283458*t)
	X1 += 0.00000001664*np.cos(6.06878282437 + 487.3651437628*t)
	X1 += 0.00000001753*np.cos(4.91984933534 + 3333.498879699*t)
	X1 += 0.00000001948*np.cos(4.60933876481 + 268.4369740323*t)
	X1 += 0.00000002018*np.cos(2.20128487926 + 9999.986450773*t)
	X1 += 0.00000001562*np.cos(2.75112579541 + 2001.4439921582*t)
	X1 += 0.00000001654*np.cos(4.67379220133 + 2957.7331481288*t)
	X1 += 0.00000001546*np.cos(2.42254478872 + 258.5456780766*t)
	X1 += 0.00000001712*np.cos(3.12113420418 + 26080.78959457339*t)
	X1 += 0.00000001531*np.cos(4.39131983815 + 5216.5803728014*t)
	X1 += 0.00000001619*np.cos(1.87868074566 + 784.0438574772*t)
	X1 += 0.00000001871*np.cos(0.40711466948 + 206.0736738526*t)
	X1 += 0.00000001732*np.cos(6.00644330186 + 1332.4847706675*t)
	X1 += 0.00000001686*np.cos(4.36569219379 + 3347.7259737006*t)
	X1 += 0.00000001553*np.cos(3.46070648954 + 1101.0264279648*t)
	X1 += 0.00000001674*np.cos(0.20458859876 + 305.0855369618*t)
	X1 += 0.00000001760*np.cos(6.06427820378 + 319.3126309634*t)
	X1 += 0.00000001661*np.cos(2.56966191326 + 26095.016688575*t)
	X1 += 0.00000001583*np.cos(0.21330050712 + 373.0142209592*t)
	X1 += 0.00000001737*np.cos(2.56050871400 + 622.4887985747*t)
	X1 += 0.00000001446*np.cos(0.64453355125 + 221.8971151471*t)
	X1 += 0.00000001446*np.cos(1.10349996175 + 204.7010757289*t)
	X1 += 0.00000001939*np.cos(4.11123627772 + 100.6450936638*t)
	X1 += 0.00000001424*np.cos(4.53013561217 + 140.001969579*t)
	X1 += 0.00000001452*np.cos(6.27129789493 + 1130.2313754934*t)
	X1 += 0.00000001874*np.cos(2.34106959221 + 769.8167634756*t)
	X1 += 0.00000001437*np.cos(3.70114244913 + 1044.4040766622*t)
	X1 += 0.00000001573*np.cos(0.97760246717 + 746.9222137957*t)
	X1 += 0.00000001428*np.cos(5.41858434640 + 1902.2833712027*t)
	X1 += 0.00000001536*np.cos(1.46680556033 + 213.2509113282*t)
	X1 += 0.00000001639*np.cos(5.07308302027 + 426.8588233069*t)
	X1 += 0.00000001565*np.cos(0.60408479572 + 392.6579409322*t)
	X1 += 0.00000001895*np.cos(1.71351370489 + 835.7878940127*t)
	X1 += 0.00000001395*np.cos(5.81475708274 + 9146.790069021*t)
	X1 += 0.00000001378*np.cos(2.63897520396 + 3163.918696566*t)
	X1 += 0.00000001467*np.cos(0.03938415892 + 827.9235874865*t)
	X1 += 0.00000001495*np.cos(3.04726766044 + 263.7016716171*t)
	X1 += 0.00000001506*np.cos(0.27403889742 + 251.1714986449*t)
	X1 += 0.00000001463*np.cos(1.20162324657 + 2118.7638603784*t)
	X1 += 0.00000001528*np.cos(0.65096988363 + 906.849787638*t)
	X1 += 0.00000001562*np.cos(0.64998564498 + 2516.9078632512*t)
	X1 += 0.00000001523*np.cos(0.15241954556 + 921.0768816396*t)
	X1 += 0.00000001335*np.cos(2.34002496567 + 2317.8358618148*t)
	X1 += 0.00000001578*np.cos(5.98549196472 + 190.4045457581*t)
	X1 += 0.00000001578*np.cos(5.18731950905 + 236.1936451179*t)
	X1 += 0.00000001731*np.cos(0.64743919781 + 1126.2992222303*t)
	X1 += 0.00000001526*np.cos(6.26405094967 + 180.1619946463*t)
	X1 += 0.00000001316*np.cos(4.88411707911 + 460.5384408198*t)
	X1 += 0.00000001322*np.cos(1.91541223458 + 2.4476805548*t)
	X1 += 0.00000001420*np.cos(1.14113479810 + 25.2727942655*t)
	X1 += 0.00000001334*np.cos(2.44221187031 + 282.6640680339*t)
	X1 += 0.00000001291*np.cos(4.75415505268 + 694.0719570618*t)
	X1 += 0.00000001279*np.cos(5.09345002137 + 449.232108125*t)
	X1 += 0.00000001287*np.cos(0.26504708130 + 286.596221297*t)
	X1 += 0.00000001401*np.cos(0.36474313629 + 2090.3096723752*t)
	X1 += 0.00000001745*np.cos(0.58733628110 + 2833.2997329078*t)
	X1 += 0.00000001481*np.cos(2.76192290396 + 31.492569389*t)
	X1 += 0.00000001251*np.cos(2.04507143625 + 909.8187330546*t)
	X1 += 0.00000001247*np.cos(4.64664167702 + 187.4356003415*t)
	X1 += 0.00000001247*np.cos(0.24298448957 + 239.1625905345*t)
	X1 += 0.00000001246*np.cos(1.79519085241 + 2487.4160449478*t)
	X1 += 0.00000001231*np.cos(4.07592990685 + 561.934294009*t)
	X1 += 0.00000001270*np.cos(2.19092299809 + 1176.7017984094*t)
	X1 += 0.00000001235*np.cos(3.39862257632 + 11926.2544136688*t)
	X1 += 0.00000001226*np.cos(5.24377580472 + 4127.3213995374*t)
	X1 += 0.00000001216*np.cos(5.52009945657 + 348.8476468921*t)
	X1 += 0.00000001229*np.cos(2.44579020325 + 51535.90899683439*t)
	X1 += 0.00000001477*np.cos(0.42597965987 + 401.3253966105*t)
	X1 += 0.00000001385*np.cos(4.26130043246 + 41.0537969446*t)
	X1 += 0.00000001614*np.cos(4.72661087242 + 3060.8259223474*t)
	X1 += 0.00000001560*np.cos(1.20558662172 + 614.6244920485*t)
	X1 += 0.00000001321*np.cos(0.66259853003 + 1773.9178027186*t)
	X1 += 0.00000001446*np.cos(1.52188920409 + 4628.5581766288*t)
	X1 += 0.00000001175*np.cos(4.77197454256 + 1681.1199692385*t)
	X1 += 0.00000001191*np.cos(3.68577950035 + 9595.2390892234*t)
	X1 += 0.00000001322*np.cos(4.91380958743 + 69.3649725959*t)
	X1 += 0.00000001449*np.cos(2.40222426931 + 1699.2792165032*t)
	X1 += 0.00000001168*np.cos(1.08248414293 + 74.6385862154*t)
	X1 += 0.00000001417*np.cos(6.20540616186 + 3473.1970192218*t)
	X1 += 0.00000001330*np.cos(0.04908988755 + 200.0352092829*t)
	X1 += 0.00000001330*np.cos(1.69894362545 + 226.5629815931*t)
	X1 += 0.00000001175*np.cos(1.75585408438 + 1674.0064222377*t)
	X1 += 0.00000001222*np.cos(0.38365380852 + 335.1418177523*t)
	X1 += 0.00000001406*np.cos(0.93043359633 + 700.6642392008*t)
	X1 += 0.00000001173*np.cos(0.89010724985 + 1159.2933106701*t)
	X1 += 0.00000001387*np.cos(5.73913384732 + 527.2432845398*t)
	X1 += 0.00000001124*np.cos(3.20599582504 + 2107.7181601145*t)
	X1 += 0.00000001536*np.cos(1.65574706063 + 1560.6187072806*t)
	X1 += 0.00000001114*np.cos(0.00659736078 + 25234.70675982219*t)
	X1 += 0.00000001108*np.cos(4.92316604415 + 1364.7280995819*t)
	X1 += 0.00000001408*np.cos(4.31689108869 + 336.8387387817*t)
	X1 += 0.00000001095*np.cos(4.58815212599 + 674.4282370888*t)
	X1 += 0.00000001091*np.cos(4.75459799081 + 1688.2335162393*t)
	X1 += 0.00000001351*np.cos(3.03972655282 + 179.3588454942*t)
	X1 += 0.00000001112*np.cos(5.86445814326 + 1144.3154571431*t)
	X1 += 0.00000001167*np.cos(1.61776931498 + 1784.2127434571*t)
	X1 += 0.00000001166*np.cos(4.32147284453 + 634.4806603426*t)
	X1 += 0.00000001082*np.cos(2.33633445539 + 756.3233826569*t)
	X1 += 0.00000001121*np.cos(3.70392077079 + 366.0436863103*t)
	X1 += 0.00000001501*np.cos(1.96032246780 + 1244.226837624*t)
	X1 += 0.00000001341*np.cos(4.97730299975 + 4312.1663069722*t)
	X1 += 0.00000001217*np.cos(2.01609497062 + 2005.3761454213*t)
	X1 += 0.00000001284*np.cos(1.71254545492 + 313.9441891018*t)
	X1 += 0.00000001288*np.cos(1.85993541573 + 247.2393453818*t)
	X1 += 0.00000001044*np.cos(2.12933199281 + 2634.2277314714*t)
	X1 += 0.00000001294*np.cos(4.62842427087 + 1190.0351205337*t)
	X1 += 0.00000001070*np.cos(1.14804635779 + 3597.6304344428*t)
	X1 += 0.00000001255*np.cos(3.41668691558 + 691.1030116452*t)
	X1 += 0.00000001034*np.cos(2.08536574341 + 1062.5633239269*t)
	X1 += 0.00000001154*np.cos(5.74451178912 + 2921.1277828246*t)
	X1 += 0.00000001040*np.cos(2.45361513153 + 988.532484885*t)
	X1 += 0.00000001090*np.cos(0.54953140818 + 1314.3255234028*t)
	X1 += 0.00000001171*np.cos(3.94743052221 + 672.1406152284*t)
	X1 += 0.00000001084*np.cos(2.22846759206 + 140.9651774255*t)
	X1 += 0.00000001014*np.cos(0.72711076947 + 606.7601855223*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000001069*np.cos(5.34533726393 + 1.2720243872*t)
	X1 += 0.00000001146*np.cos(0.33774172888 + 220.3007678542*t)
	X1 += 0.00000001287*np.cos(5.96335995053 + 72.3339180125*t)
	X1 += 0.00000001195*np.cos(3.17169864377 + 1459.9565672743*t)
	X1 += 0.00000001005*np.cos(4.27372798502 + 1585.1407420207*t)
	X1 += 0.00000001118*np.cos(5.41372662205 + 1534.7381658416*t)
	X1 += 0.00000001008*np.cos(4.07813930825 + 3906.9087570986*t)
	X1 += 0.00000001032*np.cos(2.56286714079 + 241.8709035202*t)
	X1 += 0.00000001032*np.cos(2.32675902580 + 184.7272873558*t)
	X1 += 0.00000001129*np.cos(2.05923392074 + 480.251596762*t)
	X1 += 0.00000001080*np.cos(2.61393080860 + 681.5417840896*t)
	X1 += 0.00000001095*np.cos(4.52873181843 + 745.9108218394*t)
	X1 += 0.00000001111*np.cos(3.94287042483 + 25668.418497699*t)
	X1 += 0.00000001035*np.cos(3.02167382117 + 235.933012687*t)
	X1 += 0.00000001128*np.cos(3.92303838555 + 398.2870152247*t)
	X1 += 0.00000001040*np.cos(1.29012272000 + 6.592282139*t)
	X1 += 0.00000001315*np.cos(2.76743227504 + 1791.3262904579*t)
	X1 += 0.00000001110*np.cos(5.08486528001 + 731.6837278378*t)
	X1 += 0.00000000965*np.cos(5.76694781738 + 17.4084877393*t)
	X1 += 0.00000001130*np.cos(3.37351057745 + 5481.7545583808*t)
	X1 += 0.00000000958*np.cos(4.98632174581 + 1246.6574718363*t)
	X1 += 0.00000001193*np.cos(0.98399514662 + 1468.5716333259*t)
	X1 += 0.00000001277*np.cos(5.88447485498 + 322.6116447801*t)
	X1 += 0.00000001122*np.cos(5.46861037898 + 6467.9257579616*t)
	X1 += 0.00000001202*np.cos(3.77471511835 + 418.7338843498*t)
	X1 += 0.00000001079*np.cos(6.27953776977 + 2906.900688823*t)
	X1 += 0.00000001073*np.cos(1.54239618673 + 494.4786907636*t)
	X1 += 0.00000000942*np.cos(3.50136124997 + 114.8721876654*t)
	X1 += 0.00000001020*np.cos(5.66644343999 + 2627.1141844706*t)
	X1 += 0.00000000941*np.cos(3.67244160492 + 119.767548775*t)
	X1 += 0.00000000996*np.cos(3.06872191440 + 4863.1979130692*t)
	X1 += 0.00000001059*np.cos(4.47743859511 + 25654.19140369739*t)
	X1 += 0.00000000986*np.cos(1.95549483874 + 5842.2505651138*t)
	X1 += 0.00000001051*np.cos(0.87183660869 + 5268.4554629428*t)
	X1 += 0.00000000941*np.cos(5.52302306397 + 97.4155158163*t)
	X1 += 0.00000000945*np.cos(2.54544364353 + 205.9731001161*t)
	X1 += 0.00000000945*np.cos(5.48577517665 + 220.6250907599*t)
	X1 += 0.00000001084*np.cos(0.76684360231 + 2435.155730035*t)
	X1 += 0.00000000912*np.cos(5.29401262474 + 1041.2226829245*t)
	X1 += 0.00000000912*np.cos(3.45128782828 + 952.0963702766*t)
	X1 += 0.00000000906*np.cos(2.01145804191 + 12779.4507954208*t)
	X1 += 0.00000000914*np.cos(0.94055736317 + 306.830642101*t)
	X1 += 0.00000000914*np.cos(6.06812228447 + 285.3723810196*t)
	X1 += 0.00000001034*np.cos(1.11923710876 + 1152.1797636693*t)
	X1 += 0.00000000956*np.cos(4.61179207909 + 1570.9136480191*t)
	X1 += 0.00000000941*np.cos(1.65119763294 + 3583.4033404412*t)
	X1 += 0.00000000925*np.cos(0.19129473176 + 1365.4788591073*t)
	X1 += 0.00000000909*np.cos(2.92059650634 + 1250.5896250994*t)
	X1 += 0.00000000891*np.cos(4.95998693708 + 4443.713269194*t)
	X1 += 0.00000001133*np.cos(0.58698978086 + 318.8395502114*t)
	X1 += 0.00000001094*np.cos(6.25709701419 + 738.7972748386*t)
	X1 += 0.00000001011*np.cos(3.98083146356 + 138.6605092226*t)
	X1 += 0.00000001073*np.cos(4.34308945034 + 875.830299001*t)
	X1 += 0.00000000884*np.cos(5.13674590808 + 2218.6752408593*t)
	X1 += 0.00000001131*np.cos(3.49207338910 + 639.8491022042*t)
	X1 += 0.00000001014*np.cos(3.84499571511 + 246.4361962297*t)
	X1 += 0.00000000921*np.cos(3.37898558991 + 9772.4602613334*t)
	X1 += 0.00000000868*np.cos(4.95859132120 + 1371.8416465827*t)
	X1 += 0.00000000940*np.cos(2.38470781473 + 287.9376816534*t)
	X1 += 0.00000000922*np.cos(2.23583057309 + 1596.1864422846*t)
	X1 += 0.00000000922*np.cos(5.27674146778 + 3686.4961146598*t)
	X1 += 0.00000000997*np.cos(5.10210718986 + 987.7817253596*t)
	X1 += 0.00000001061*np.cos(3.69387971075 + 688.6553310904*t)
	X1 += 0.00000000864*np.cos(5.36977054689 + 3370.1042450032*t)
	X1 += 0.00000001177*np.cos(0.16340430340 + 1328.5526174044*t)
	X1 += 0.00000000860*np.cos(1.23158588637 + 12146.6670561076*t)
	X1 += 0.00000001119*np.cos(4.95005326610 + 6283.0758499914*t)
	X1 += 0.00000000843*np.cos(5.00058816516 + 1239.5439248355*t)
	X1 += 0.00000000846*np.cos(3.17553686252 + 2114.8317071153*t)
	X1 += 0.00000000863*np.cos(6.25214866516 + 3569.1762464396*t)
	X1 += 0.00000000886*np.cos(5.73302742834 + 3803.81598288*t)
	X1 += 0.00000000981*np.cos(1.46133083467 + 1471.0022675382*t)
	X1 += 0.00000000829*np.cos(6.17527627929 + 1372.5924061081*t)
	X1 += 0.00000001164*np.cos(6.03632211065 + 3391.4448860056*t)
	X1 += 0.00000001143*np.cos(0.31721576300 + 3149.6916025644*t)
	X1 += 0.00000000885*np.cos(3.21468341749 + 608.877797677*t)
	X1 += 0.00000000837*np.cos(1.26802412219 + 311.7260032106*t)
	X1 += 0.00000000827*np.cos(4.31418145925 + 1165.6560981455*t)
	X1 += 0.00000000904*np.cos(3.04051970684 + 477.0007670551*t)
	X1 += 0.00000000818*np.cos(4.24078420149 + 5055.1563675048*t)
	X1 += 0.00000000841*np.cos(3.88873056685 + 473.068613792*t)
	X1 += 0.00000000829*np.cos(0.77508627125 + 17.2654753874*t)
	X1 += 0.00000000842*np.cos(4.82411532711 + 831.1049812242*t)
	X1 += 0.00000001023*np.cos(1.90815772351 + 384.0599212231*t)
	X1 += 0.00000000998*np.cos(2.24448938053 + 938.8806682313*t)
	X1 += 0.00000001026*np.cos(3.07657450703 + 5378.6617841622*t)
	X1 += 0.00000000846*np.cos(6.04071273632 + 199.0238173266*t)
	X1 += 0.00000000846*np.cos(1.99050608386 + 227.5743735494*t)
	X1 += 0.00000001105*np.cos(4.93697328282 + 168.0525127994*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000000872*np.cos(5.56428111751 + 3362.9906980024*t)
	X1 += 0.00000001054*np.cos(4.19921163644 + 93.531546663*t)
	X1 += 0.00000000839*np.cos(2.01987352433 + 220.2001941177*t)
	X1 += 0.00000000839*np.cos(6.01134529585 + 206.3979967583*t)
	X1 += 0.00000000826*np.cos(3.67485221518 + 219.891377577*t)
	X1 += 0.00000000853*np.cos(1.21635018066 + 539.9859058331*t)
	X1 += 0.00000000858*np.cos(5.69547658720 + 781.5961769224*t)
	X1 += 0.00000000853*np.cos(3.60553998035 + 1894.4190646765*t)
	X1 += 0.00000000813*np.cos(0.86230265041 + 1578.0271950199*t)
	X1 += 0.00000000967*np.cos(5.86676674618 + 151.260118164*t)
	X1 += 0.00000000858*np.cos(5.62583672873 + 973.554631358*t)
	X1 += 0.00000000831*np.cos(1.84826218261 + 2648.454825473*t)
	X1 += 0.00000000877*np.cos(5.80298687705 + 3789.5888888784*t)
	X1 += 0.00000000976*np.cos(2.02721042666 + 395.105621487*t)
	X1 += 0.00000000851*np.cos(5.76766110685 + 2854.6403739102*t)
	X1 += 0.00000000768*np.cos(4.76896894601 + 4436.5997221932*t)
	X1 += 0.00000000763*np.cos(4.25581933060 + 198.1087935899*t)
	X1 += 0.00000000763*np.cos(3.77539948958 + 228.4893972861*t)
	X1 += 0.00000000767*np.cos(4.72483440810 + 838.218528225*t)
	X1 += 0.00000000949*np.cos(1.98321654363 + 945.9942152321*t)
	X1 += 0.00000000783*np.cos(2.27534905083 + 3494.5376602242*t)
	X1 += 0.00000000817*np.cos(0.82100313331 + 635.231419868*t)
	X1 += 0.00000000836*np.cos(5.87100604717 + 135.5485514541*t)
	X1 += 0.00000000762*np.cos(3.21569513818 + 5158.2491417234*t)
	X1 += 0.00000000861*np.cos(3.85100975973 + 782.3469364478*t)
	X1 += 0.00000000758*np.cos(1.43185126319 + 1997.5118388951*t)
	X1 += 0.00000000778*np.cos(6.03247429542 + 418.9633790134*t)
	X1 += 0.00000000822*np.cos(2.64020332721 + 5436.9930152402*t)
	X1 += 0.00000000752*np.cos(3.50936275717 + 313.4711083498*t)
	X1 += 0.00000000752*np.cos(1.38026340942 + 113.1270825262*t)
	X1 += 0.00000000834*np.cos(5.85070280153 + 763.4369296577*t)
	X1 += 0.00000000871*np.cos(6.01814655144 + 2943.5060541272*t)
	X1 += 0.00000000901*np.cos(3.75914830730 + 444.0066786153*t)
	X1 += 0.00000000903*np.cos(0.23029877348 + 123.5396433437*t)
	X1 += 0.00000001009*np.cos(1.90046156811 + 1987.2168981566*t)
	X1 += 0.00000000750*np.cos(2.15136621786 + 5282.6825569444*t)
	X1 += 0.00000001016*np.cos(2.37444689169 + 1264.816719101*t)
	X1 += 0.00000000874*np.cos(0.93951630481 + 1475.6851803267*t)
	X1 += 0.00000000972*np.cos(2.20085561714 + 1670.82502850*t)
	X1 += 0.00000000738*np.cos(2.52567101420 + 109.3125493421*t)
	X1 += 0.00000000895*np.cos(0.54186785098 + 1119.1856752295*t)
	X1 += 0.00000000798*np.cos(3.47587781714 + 495.9631634719*t)
	X1 += 0.00000000828*np.cos(1.25150197790 + 114.9416236346*t)
	X1 += 0.00000000793*np.cos(0.39999568942 + 4017.115078318*t)
	X1 += 0.00000000882*np.cos(3.55674331780 + 2442.2692770358*t)
	X1 += 0.00000000979*np.cos(0.47406023937 + 2406.7015420318*t)
	X1 += 0.00000000817*np.cos(2.10021317616 + 1257.7031721002*t)
	X1 += 0.00000000717*np.cos(3.99283768764 + 103925.01437542078*t)
	X1 += 0.00000000743*np.cos(3.44205402388 + 5422.7659212386*t)
	X1 += 0.00000000714*np.cos(4.46118510280 + 2115.5824666407*t)
	X1 += 0.00000000719*np.cos(1.08999404688 + 501.2367770914*t)
	X1 += 0.00000000930*np.cos(1.32861036715 + 1877.0105769372*t)
	X1 += 0.00000000815*np.cos(0.61360086763 + 1792.0770499833*t)
	X1 += 0.00000000800*np.cos(4.13459764986 + 9367.2027114598*t)
	X1 += 0.00000000736*np.cos(2.54656520137 + 1460.7073267997*t)
	X1 += 0.00000000722*np.cos(0.84796954175 + 878.3261636656*t)
	X1 += 0.00000000824*np.cos(4.45776575023 + 498.9321088885*t)
	X1 += 0.00000000705*np.cos(6.07014928564 + 275.338072712*t)
	X1 += 0.00000000728*np.cos(1.24535456741 + 51742.09454527159*t)
	X1 += 0.00000000957*np.cos(4.34122317540 + 433.663553767*t)
	X1 += 0.00000000697*np.cos(4.70224891228 + 3274.1250177854*t)
	X1 += 0.00000000711*np.cos(1.89998090537 + 205.9249160063*t)
	X1 += 0.00000000711*np.cos(6.13123791481 + 220.6732748697*t)
	X1 += 0.00000000694*np.cos(1.61522962867 + 664.2763087022*t)
	X1 += 0.00000000829*np.cos(5.32110039039 + 4415.2590811908*t)
	X1 += 0.00000000721*np.cos(4.58275654686 + 952.3570027075*t)
	X1 += 0.00000000692*np.cos(0.62893428225 + 754.0357607965*t)
	X1 += 0.00000000795*np.cos(5.56415917977 + 19786.67380610799*t)
	X1 += 0.00000000689*np.cos(3.82241010942 + 1037.2905296614*t)
	X1 += 0.00000000706*np.cos(1.12328566050 + 644.56315276*t)
	X1 += 0.00000000773*np.cos(5.74997493496 + 620.253566341*t)
	X1 += 0.00000000692*np.cos(5.57318772640 + 25448.00585526019*t)
	X1 += 0.00000000692*np.cos(2.81881748057 + 1165.3954657146*t)
	X1 += 0.00000000808*np.cos(1.55707064891 + 817.628646748*t)
	X1 += 0.00000000681*np.cos(0.26530171784 + 100.3844612329*t)
	X1 += 0.00000000953*np.cos(0.59117119093 + 2826.186185907*t)
	X1 += 0.00000000826*np.cos(1.27188705580 + 284.8993002676*t)
	X1 += 0.00000000695*np.cos(4.58296836233 + 3171.0322435668*t)
	return X1*t




def Saturn_X2 (t): # 481 terms of order 2

	X2 = 0.
	X2 += 0.00560586041*np.cos(1.26401676555 + 206.1855484372*t)
	X2 += 0.00545678885*np.cos(3.62343709789 + 220.4126424388*t)
	X2 -= 0.00443297401
	X2 += 0.00336013651*np.cos(2.42547432210 + 213.299095438*t)
	X2 += 0.00224237163*np.cos(2.49151267683 + 426.598190876*t)
	X2 += 0.00087156936*np.cos(4.89048703815 + 7.1135470008*t)
	X2 += 0.00050013864*np.cos(2.70119455991 + 433.7117378768*t)
	X2 += 0.00045109880*np.cos(0.36735560493 + 419.4846438752*t)
	X2 += 0.00032838505*np.cos(1.59210694211 + 639.897286314*t)
	X2 += 0.00027145848*np.cos(3.49804001342 + 227.5261894396*t)
	X2 += 0.00012672501*np.cos(1.45466696358 + 199.0720014364*t)
	X2 += 0.00010329051*np.cos(4.76949570032 + 14.2270940016*t)
	X2 += 0.00007248688*np.cos(5.70261917802 + 110.2063212194*t)
	X2 += 0.00004651894*np.cos(1.83710425038 + 647.0108333148*t)
	X2 += 0.00004922180*np.cos(3.08463039042 + 216.4804891757*t)
	X2 += 0.00004775993*np.cos(1.81695167893 + 210.1177017003*t)
	X2 += 0.00004165287*np.cos(5.32887778584 + 316.3918696566*t)
	X2 += 0.00003507416*np.cos(0.78248949398 + 853.196381752*t)
	X2 += 0.00002659711*np.cos(3.16731450403 + 209.3669421749*t)
	X2 += 0.00002537339*np.cos(2.65097652412 + 440.8252848776*t)
	X2 += 0.00002567381*np.cos(1.74024227844 + 217.2312487011*t)
	X2 += 0.00002502759*np.cos(4.69464279172 + 117.3198682202*t)
	X2 += 0.00002506135*np.cos(1.74809205533 + 103.0927742186*t)
	X2 += 0.00002128734*np.cos(0.28416516589 + 632.7837393132*t)
	X2 += 0.00001842235*np.cos(3.99299720318 + 323.5054166574*t)
	X2 += 0.00001228190*np.cos(0.42913693726 + 412.3710968744*t)
	X2 += 0.00000804505*np.cos(3.35740687094 + 234.6397364404*t)
	X2 += 0.00000796179*np.cos(1.09484072849 + 202.2533951741*t)
	X2 += 0.00000544923*np.cos(5.78808648308 + 95.9792272178*t)
	X2 += 0.00000732334*np.cos(3.86144567309 + 224.3447957019*t)
	X2 += 0.00000440358*np.cos(3.59840290265 + 330.6189636582*t)
	X2 += 0.00000426791*np.cos(1.00483231522 + 860.3099287528*t)
	X2 += 0.00000392189*np.cos(0.69006702380 + 11.0457002639*t)
	X2 += 0.00000440217*np.cos(4.62429695267 + 21.3406410024*t)
	X2 += 0.00000403719*np.cos(2.95386471404 + 223.5940361765*t)
	X2 += 0.00000399321*np.cos(2.21962287963 + 429.7795846137*t)
	X2 += 0.00000367352*np.cos(3.30624278809 + 522.5774180938*t)
	X2 += 0.00000332827*np.cos(0.00403898284 + 1066.49547719*t)
	X2 += 0.00000306480*np.cos(4.44235835495 + 3.1813937377*t)
	X2 += 0.00000353827*np.cos(2.08574838147 + 422.6660376129*t)
	X2 += 0.00000272466*np.cos(3.00748164082 + 536.8045120954*t)
	X2 += 0.00000382384*np.cos(5.31521149352 + 529.6909650946*t)
	X2 += 0.00000277766*np.cos(3.99263414764 + 3.9321532631*t)
	X2 += 0.00000266087*np.cos(1.10605005957 + 423.4167971383*t)
	X2 += 0.00000244552*np.cos(1.81855172211 + 654.1243803156*t)
	X2 += 0.00000252757*np.cos(5.58633314063 + 88.865680217*t)
	X2 += 0.00000263461*np.cos(3.32945622126 + 124.433415221*t)
	X2 += 0.00000198166*np.cos(1.75391782582 + 191.9584544356*t)
	X2 += 0.00000192788*np.cos(2.35358142259 + 149.5631971346*t)
	X2 += 0.00000223879*np.cos(2.03081321297 + 203.0041546995*t)
	X2 += 0.00000194363*np.cos(2.64555552513 + 625.6701923124*t)
	X2 += 0.00000160387*np.cos(3.30779240923 + 515.463871093*t)
	X2 += 0.00000164989*np.cos(4.45938713920 + 742.9900605326*t)
	X2 += 0.00000132687*np.cos(3.18963228913 + 302.164775655*t)
	X2 += 0.00000171957*np.cos(1.26865256659 + 309.2783226558*t)
	X2 += 0.00000117070*np.cos(2.50733253747 + 277.0349937414*t)
	X2 += 0.00000105122*np.cos(4.21584969999 + 10.2949407385*t)
	X2 += 0.00000123227*np.cos(3.28227189007 + 437.6438911399*t)
	X2 += 0.00000124539*np.cos(2.95233255802 + 735.8765135318*t)
	X2 += 0.00000093822*np.cos(3.96019060061 + 415.5524906121*t)
	X2 += 0.00000094722*np.cos(1.91659373538 + 430.5303441391*t)
	X2 += 0.00000083689*np.cos(2.71914140150 + 838.9692877504*t)
	X2 += 0.00000082638*np.cos(2.55445861205 + 447.9388318784*t)
	X2 += 0.00000080263*np.cos(4.59656702040 + 231.4583427027*t)
	X2 += 0.00000099292*np.cos(0.19488585950 + 846.0828347512*t)
	X2 += 0.00000068111*np.cos(2.06467676396 + 728.762966531*t)
	X2 += 0.00000058325*np.cos(5.16302254216 + 18.1592472647*t)
	X2 += 0.00000049407*np.cos(2.77048375568 + 543.9180590962*t)
	X2 += 0.00000047763*np.cos(2.86136089141 + 831.8557407496*t)
	X2 += 0.00000044407*np.cos(3.49489031748 + 195.1398481733*t)
	X2 += 0.00000046269*np.cos(0.00721267106 + 408.4389436113*t)
	X2 += 0.00000039788*np.cos(0.19276767111 + 1073.6090241908*t)
	X2 += 0.00000044399*np.cos(3.66443935660 + 942.062061969*t)
	X2 += 0.00000040117*np.cos(3.78886773763 + 618.5566453116*t)
	X2 += 0.00000034250*np.cos(1.53749032009 + 362.8622925726*t)
	X2 += 0.00000029256*np.cos(4.45268167111 + 113.3877149571*t)
	X2 += 0.00000039963*np.cos(1.19231439925 + 635.9651330509*t)
	X2 += 0.00000036033*np.cos(0.17719563899 + 222.8603229936*t)
	X2 += 0.00000030069*np.cos(5.33792974143 + 269.9214467406*t)
	X2 += 0.00000030472*np.cos(5.98247335753 + 56.6223513026*t)
	X2 += 0.00000033922*np.cos(2.16638149890 + 436.8931316145*t)
	X2 += 0.00000036126*np.cos(4.68227909720 + 203.7378678824*t)
	X2 += 0.00000037398*np.cos(2.14629677288 + 85.8272988312*t)
	X2 += 0.00000034387*np.cos(1.38650218399 + 643.0786800517*t)
	X2 += 0.00000031940*np.cos(2.72057591859 + 337.732510659*t)
	X2 += 0.00000026971*np.cos(2.72612032459 + 131.5469622218*t)
	X2 += 0.00000027368*np.cos(2.04598732204 + 750.1036075334*t)
	X2 += 0.00000029852*np.cos(5.52245298759 + 1279.794572628*t)
	X2 += 0.00000027428*np.cos(2.69564562615 + 1155.361157407*t)
	X2 += 0.00000024974*np.cos(2.01509072208 + 76.2660712756*t)
	X2 += 0.00000023978*np.cos(5.72658252294 + 81.7521332162*t)
	X2 += 0.00000028869*np.cos(4.16331591891 + 1059.3819301892*t)
	X2 += 0.00000025348*np.cos(4.59248158354 + 483.2205421786*t)
	X2 += 0.00000023209*np.cos(1.00054522408 + 867.4234757536*t)
	X2 += 0.00000024253*np.cos(2.13310973122 + 70.8494453042*t)
	X2 += 0.00000022180*np.cos(1.69005349640 + 1045.1548361876*t)
	X2 += 0.00000021018*np.cos(3.79760928662 + 160.6088973985*t)
	X2 += 0.00000020693*np.cos(0.86918818398 + 288.0806940053*t)
	X2 += 0.00000026561*np.cos(2.65829878676 + 1052.2683831884*t)
	X2 += 0.00000020294*np.cos(2.15135194296 + 22.0914005278*t)
	X2 += 0.00000019907*np.cos(4.59466677736 + 106.2741679563*t)
	X2 += 0.00000020372*np.cos(2.57894069574 + 1148.2476104062*t)
	X2 += 0.00000020650*np.cos(2.97740334682 + 107.0249274817*t)
	X2 += 0.00000019289*np.cos(0.57571935130 + 497.4476361802*t)
	X2 += 0.00000020049*np.cos(4.29941461930 + 956.2891559706*t)
	X2 += 0.00000018131*np.cos(2.87482499239 + 949.1756089698*t)
	X2 += 0.00000020406*np.cos(1.27038102659 + 416.3032501375*t)
	X2 += 0.00000015869*np.cos(0.47111865673 + 628.8515860501*t)
	X2 += 0.00000015417*np.cos(3.16623537199 + 241.7532834412*t)
	X2 += 0.00000019228*np.cos(3.46470845524 + 1258.4539316256*t)
	X2 += 0.00000015274*np.cos(0.98168978226 + 265.9892934775*t)
	X2 += 0.00000016208*np.cos(6.04835517486 + 344.7030453079*t)
	X2 += 0.00000017094*np.cos(1.17789558213 + 63.7358983034*t)
	X2 += 0.00000019673*np.cos(2.08584329643 + 200.7689224658*t)
	X2 += 0.00000014750*np.cos(4.02023803804 + 138.5174968707*t)
	X2 += 0.00000018610*np.cos(6.17356580287 + 142.4496501338*t)
	X2 += 0.00000017400*np.cos(2.80888774149 + 340.7708920448*t)
	X2 += 0.00000018185*np.cos(2.80414739937 + 225.8292684102*t)
	X2 += 0.00000017671*np.cos(3.74153777529 + 934.9485149682*t)
	X2 += 0.00000013724*np.cos(2.11658793699 + 358.9301393095*t)
	X2 += 0.00000013536*np.cos(6.03056178545 + 284.1485407422*t)
	X2 += 0.00000018157*np.cos(2.62423050197 + 52.6901980395*t)
	X2 += 0.00000013432*np.cos(4.50329976780 + 6290.1893969922*t)
	X2 += 0.00000012937*np.cos(0.85990781123 + 181.0557665236*t)
	X2 += 0.00000013012*np.cos(5.38330107399 + 191.2076949102*t)
	X2 += 0.00000014609*np.cos(5.58397686905 + 490.3340891794*t)
	X2 += 0.00000015756*np.cos(2.59168235746 + 650.9429865779*t)
	X2 += 0.00000012424*np.cos(3.40358544133 + 295.0512286542*t)
	X2 += 0.00000013121*np.cos(2.14481625328 + 6275.9623029906*t)
	X2 += 0.00000012303*np.cos(3.76145869505 + 444.7574381407*t)
	X2 += 0.00000012620*np.cos(5.92668313028 + 10220.3990932118*t)
	X2 += 0.00000011807*np.cos(0.06245578074 + 424.1505103212*t)
	X2 += 0.00000013151*np.cos(3.75285664218 + 1375.7737998458*t)
	X2 += 0.00000012327*np.cos(3.56818133002 + 10206.1719992102*t)
	X2 += 0.00000012370*np.cos(0.45725518260 + 405.2575498736*t)
	X2 += 0.00000011299*np.cos(2.87991803497 + 350.3321196004*t)
	X2 += 0.00000010780*np.cos(4.25191295553 + 127.4717966068*t)
	X2 += 0.00000011403*np.cos(2.50450346364 + 1471.7530270636*t)
	X2 += 0.00000010714*np.cos(4.01666936812 + 245.5424243524*t)
	X2 += 0.00000010231*np.cos(5.68395070282 + 703.6331846174*t)
	X2 += 0.00000013693*np.cos(0.82029906057 + 636.7158925763*t)
	X2 += 0.00000009828*np.cos(6.01694251061 + 12.5301729722*t)
	X2 += 0.00000011897*np.cos(3.52839576709 + 508.3503240922*t)
	X2 += 0.00000009302*np.cos(4.78562586259 + 9.5612275556*t)
	X2 += 0.00000009088*np.cos(2.27348136998 + 1464.6394800628*t)
	X2 += 0.00000010108*np.cos(5.58543192996 + 235.3904959658*t)
	X2 += 0.00000010079*np.cos(0.71634516078 + 351.8165923087*t)
	X2 += 0.00000008729*np.cos(1.48166465650 + 1361.5467058442*t)
	X2 += 0.00000008422*np.cos(1.74868225923 + 661.2379273164*t)
	X2 += 0.00000007887*np.cos(0.90663919997 + 565.1156877467*t)
	X2 += 0.00000010680*np.cos(4.78132423423 + 1162.4747044078*t)
	X2 += 0.00000008224*np.cos(3.53925468200 + 5849.3641121146*t)
	X2 += 0.00000007907*np.cos(5.89704027369 + 5863.5912061162*t)
	X2 += 0.00000007278*np.cos(2.70595502930 + 404.5067903482*t)
	X2 += 0.00000007690*np.cos(4.96283444092 + 9779.5738083342*t)
	X2 += 0.00000007394*np.cos(1.03743923255 + 9793.8009023358*t)
	X2 += 0.00000008652*np.cos(3.18495082254 + 1574.8458012822*t)
	X2 += 0.00000008794*np.cos(3.46778208926 + 1251.3403846248*t)
	X2 += 0.00000006698*np.cos(5.81865828240 + 121.2520214833*t)
	X2 += 0.00000006938*np.cos(0.68217212931 + 208.633228992*t)
	X2 += 0.00000006402*np.cos(0.36178333362 + 313.2104759189*t)
	X2 += 0.00000006778*np.cos(1.06356800619 + 217.964961884*t)
	X2 += 0.00000006524*np.cos(5.34330917422 + 429.0458714308*t)
	X2 += 0.00000006830*np.cos(3.24159116011 + 1265.5674786264*t)
	X2 += 0.00000008708*np.cos(2.46136750998 + 1368.660252845*t)
	X2 += 0.00000006147*np.cos(2.24199774873 + 319.5732633943*t)
	X2 += 0.00000008399*np.cos(3.30728600269 + 6283.0758499914*t)
	X2 += 0.00000007759*np.cos(5.80608441219 + 621.7380390493*t)
	X2 += 0.00000005864*np.cos(2.48238256439 + 114.1384744825*t)
	X2 += 0.00000007803*np.cos(4.71886465463 + 10213.285546211*t)
	X2 += 0.00000005393*np.cos(6.27168925772 + 78.7137518304*t)
	X2 += 0.00000005490*np.cos(5.37820332227 + 347.8844390456*t)
	X2 += 0.00000005330*np.cos(0.02876795001 + 842.1506814881*t)
	X2 += 0.00000006053*np.cos(2.87275112758 + 230.7075831773*t)
	X2 += 0.00000005825*np.cos(3.57519970065 + 1692.1656695024*t)
	X2 += 0.00000006109*np.cos(5.18591470990 + 195.8906076987*t)
	X2 += 0.00000006180*np.cos(4.65823145266 + 5856.4776591154*t)
	X2 += 0.00000004574*np.cos(5.23062124474 + 436.1594184316*t)
	X2 += 0.00000004886*np.cos(2.04925295464 + 643.8294395771*t)
	X2 += 0.00000004771*np.cos(2.23510815062 + 99.9113804809*t)
	X2 += 0.00000006196*np.cos(4.51127953775 + 1478.8665740644*t)
	X2 += 0.00000004608*np.cos(1.98433298440 + 757.2171545342*t)
	X2 += 0.00000005775*np.cos(6.08213006176 + 9786.687355335*t)
	X2 += 0.00000004718*np.cos(2.29208330722 + 1788.1448967202*t)
	X2 += 0.00000004271*np.cos(4.02086430435 + 175.1660598002*t)
	X2 += 0.00000004204*np.cos(0.80177985689 + 576.1613880106*t)
	X2 += 0.00000005585*np.cos(1.17248277846 + 479.2883889155*t)
	X2 += 0.00000004241*np.cos(1.02185101303 + 289.5651667136*t)
	X2 += 0.00000004564*np.cos(3.05464344806 + 824.7421937488*t)
	X2 += 0.00000004157*np.cos(3.77906712975 + 398.1440028728*t)
	X2 += 0.00000004220*np.cos(2.07841137450 + 1781.0313497194*t)
	X2 += 0.00000004026*np.cos(0.69077662766 + 251.4321310758*t)
	X2 += 0.00000004026*np.cos(6.02989448816 + 710.7467316182*t)
	X2 += 0.00000003978*np.cos(1.23202456620 + 134.5853436076*t)
	X2 += 0.00000003849*np.cos(3.00000494580 + 98.8999885246*t)
	X2 += 0.00000004233*np.cos(5.52392629908 + 1272.6810256272*t)
	X2 += 0.00000003768*np.cos(0.27912645686 + 501.3797894433*t)
	X2 += 0.00000004060*np.cos(6.14592131253 + 120.358249606*t)
	X2 += 0.00000004811*np.cos(3.22144835793 + 1567.7322542814*t)
	X2 += 0.00000004436*np.cos(5.60117640002 + 9999.986450773*t)
	X2 += 0.00000004369*np.cos(4.18650514859 + 6069.7767545534*t)
	X2 += 0.00000003542*np.cos(0.63053476414 + 320.3240229197*t)
	X2 += 0.00000003320*np.cos(1.30344289880 + 1677.9385755008*t)
	X2 += 0.00000004195*np.cos(4.35216750323 + 333.657345044*t)
	X2 += 0.00000004387*np.cos(2.99277478849 + 1891.2376709388*t)
	X2 += 0.00000003275*np.cos(1.92414476769 + 166.828672522*t)
	X2 += 0.00000003574*np.cos(5.94779813906 + 156.6767441354*t)
	X2 += 0.00000003394*np.cos(3.09924988885 + 196.0336200506*t)
	X2 += 0.00000003533*np.cos(2.14645465127 + 114.3991069134*t)
	X2 += 0.00000004063*np.cos(3.20873890715 + 326.6868103951*t)
	X2 += 0.00000003816*np.cos(4.19418962192 + 611.4430983108*t)
	X2 += 0.00000002979*np.cos(1.23014225252 + 151.0476698429*t)
	X2 += 0.00000003909*np.cos(2.13168218024 + 1685.0521225016*t)
	X2 += 0.00000003741*np.cos(0.62287950834 + 849.2642284889*t)
	X2 += 0.00000003047*np.cos(1.79037600019 + 230.5645708254*t)
	X2 += 0.00000002819*np.cos(6.19576518658 + 431.264057322*t)
	X2 += 0.00000002815*np.cos(5.27911903476 + 414.0680179038*t)
	X2 += 0.00000002928*np.cos(2.32767067793 + 395.578702239*t)
	X2 += 0.00000002894*np.cos(6.25242559802 + 381.3516082374*t)
	X2 += 0.00000003376*np.cos(4.35324654268 + 1795.258443721*t)
	X2 += 0.00000002789*np.cos(4.59954924249 + 526.5095713569*t)
	X2 += 0.00000002805*np.cos(3.11849519950 + 259.769518354*t)
	X2 += 0.00000002798*np.cos(0.07338299890 + 129.9194771616*t)
	X2 += 0.00000003377*np.cos(1.60711929937 + 299.1263942692*t)
	X2 += 0.00000002698*np.cos(5.46428214658 + 1589.0728952838*t)
	X2 += 0.00000002848*np.cos(3.32164076256 + 721.6494195302*t)
	X2 += 0.00000002783*np.cos(5.69239153569 + 1286.9081196288*t)
	X2 += 0.00000002535*np.cos(5.30267830354 + 305.3461693927*t)
	X2 += 0.00000002513*np.cos(5.92254424615 + 343.2185725996*t)
	X2 += 0.00000002465*np.cos(1.10304225755 + 572.2292347475*t)
	X2 += 0.00000003420*np.cos(3.32155470803 + 1581.959348283*t)
	X2 += 0.00000002461*np.cos(3.95494769587 + 409.1897031367*t)
	X2 += 0.00000002580*np.cos(4.98676114859 + 1493.093668066*t)
	X2 += 0.00000002381*np.cos(4.67337216247 + 74.7815985673*t)
	X2 += 0.00000002530*np.cos(3.91187247053 + 696.5196376166*t)
	X2 += 0.00000002623*np.cos(3.23676219968 + 554.0699874828*t)
	X2 += 0.00000002367*np.cos(5.12852371777 + 59.8037450403*t)
	X2 += 0.00000002945*np.cos(2.15064158133 + 551.031606097*t)
	X2 += 0.00000002813*np.cos(5.66780576556 + 421.93232443*t)
	X2 += 0.00000002415*np.cos(4.57966213445 + 45.5766510387*t)
	X2 += 0.00000002353*np.cos(2.72341915306 + 1169.5882514086*t)
	X2 += 0.00000002320*np.cos(4.04967284998 + 519.3960243561*t)
	X2 += 0.00000002211*np.cos(3.66247626749 + 275.5505210331*t)
	X2 += 0.00000002219*np.cos(3.42428116090 + 188.0263011725*t)
	X2 += 0.00000002193*np.cos(4.11153715755 + 205.2223405907*t)
	X2 += 0.00000002193*np.cos(3.91968166263 + 221.3758502853*t)
	X2 += 0.00000002329*np.cos(2.42556084705 + 144.1465711632*t)
	X2 += 0.00000002162*np.cos(4.60032858400 + 238.5718897035*t)
	X2 += 0.00000002149*np.cos(4.99715589626 + 916.9322800554*t)
	X2 += 0.00000002122*np.cos(0.04104438670 + 92.940845832*t)
	X2 += 0.00000002081*np.cos(4.93157740168 + 188.9200730498*t)
	X2 += 0.00000002175*np.cos(5.63002332525 + 432.2272651685*t)
	X2 += 0.00000002595*np.cos(3.40305728866 + 2008.557539159*t)
	X2 += 0.00000002581*np.cos(2.20662036464 + 2097.423219376*t)
	X2 += 0.00000001984*np.cos(4.73063860465 + 5643.1785636774*t)
	X2 += 0.00000002385*np.cos(5.70410580283 + 69.1525242748*t)
	X2 += 0.00000002530*np.cos(2.66181688163 + 2207.6295405954*t)
	X2 += 0.00000002555*np.cos(0.25549086562 + 229.9738699944*t)
	X2 += 0.00000002555*np.cos(1.49254264738 + 196.6243208816*t)
	X2 += 0.00000002066*np.cos(3.32994609833 + 2627.1141844706*t)
	X2 += 0.00000002226*np.cos(2.84564999814 + 1141.1340634054*t)
	X2 += 0.00000002390*np.cos(2.56947989325 + 6062.6632075526*t)
	X2 += 0.00000002000*np.cos(4.63224542281 + 32.2433289144*t)
	X2 += 0.00000001968*np.cos(5.88733808823 + 131.4039498699*t)
	X2 += 0.00000001941*np.cos(3.37602923994 + 373.9079928365*t)
	X2 += 0.00000002353*np.cos(1.38929393306 + 650.1922270525*t)
	X2 += 0.00000001818*np.cos(3.03949571304 + 120.5012619579*t)
	X2 += 0.00000001834*np.cos(6.09045185685 + 561.1835344836*t)
	X2 += 0.00000002193*np.cos(1.56009056549 + 207.1487562837*t)
	X2 += 0.00000002193*np.cos(0.18794294751 + 219.4494345923*t)
	X2 += 0.00000002038*np.cos(1.74690830633 + 2413.8150890326*t)
	X2 += 0.00000001794*np.cos(6.11943078449 + 9573.388259897*t)
	X2 += 0.00000002272*np.cos(6.07078324928 + 135.336103133*t)
	X2 += 0.00000002404*np.cos(3.85253728397 + 927.8349679674*t)
	X2 += 0.00000001787*np.cos(6.24123350695 + 237.6781178262*t)
	X2 += 0.00000002251*np.cos(1.83411449763 + 145.6310438715*t)
	X2 += 0.00000001819*np.cos(0.51111183004 + 220.4608265486*t)
	X2 += 0.00000001819*np.cos(1.23692168296 + 206.1373643274*t)
	X2 += 0.00000001781*np.cos(2.63674790157 + 116.4260963429*t)
	X2 += 0.00000001884*np.cos(4.95154067042 + 556.5176680376*t)
	X2 += 0.00000001855*np.cos(4.36894863492 + 2111.6503133776*t)
	X2 += 0.00000001775*np.cos(6.08377383987 + 3259.8979237838*t)
	X2 += 0.00000002390*np.cos(0.57829722827 + 856.3777754897*t)
	X2 += 0.00000001749*np.cos(6.09665041146 + 417.0369633204*t)
	X2 += 0.00000001826*np.cos(1.86446006635 + 344.8460576598*t)
	X2 += 0.00000001811*np.cos(1.03035050506 + 570.7447620392*t)
	X2 += 0.00000001742*np.cos(5.37462069176 + 425.6349830295*t)
	X2 += 0.00000001971*np.cos(2.58560125016 + 1457.525933062*t)
	X2 += 0.00000002261*np.cos(3.11062462322 + 421.1815649046*t)
	X2 += 0.00000001691*np.cos(2.43995589654 + 455.0523788792*t)
	X2 += 0.00000002031*np.cos(2.29508293823 + 92.0470739547*t)
	X2 += 0.00000001703*np.cos(2.82714873836 + 427.5613987225*t)
	X2 += 0.00000001764*np.cos(2.79871920143 + 186.472392495*t)
	X2 += 0.00000001746*np.cos(3.36116416919 + 898.7730327907*t)
	X2 += 0.00000002282*np.cos(2.04372303495 + 439.1283638482*t)
	X2 += 0.00000001793*np.cos(5.82146283335 + 913.0001267923*t)
	X2 += 0.00000001639*np.cos(3.52013201939 + 2641.3412784722*t)
	X2 += 0.00000001651*np.cos(4.58235804409 + 546.956440482*t)
	X2 += 0.00000001869*np.cos(2.38958346848 + 3597.6304344428*t)
	X2 += 0.00000001597*np.cos(5.72930431899 + 280.9671470045*t)
	X2 += 0.00000001959*np.cos(2.68901201458 + 732.6951197941*t)
	X2 += 0.00000001737*np.cos(1.74570627953 + 167.7224443993*t)
	X2 += 0.00000002134*np.cos(2.95468156383 + 173.9422195228*t)
	X2 += 0.00000001946*np.cos(2.15176891932 + 2420.9286360334*t)
	X2 += 0.00000001581*np.cos(2.31500508773 + 258.8757464767*t)
	X2 += 0.00000001863*np.cos(2.20927715172 + 2104.5367663768*t)
	X2 += 0.00000001819*np.cos(4.43470604008 + 206.233732547*t)
	X2 += 0.00000001819*np.cos(3.59651278010 + 220.364458329*t)
	X2 += 0.00000001527*np.cos(3.04717303366 + 273.1028404783*t)
	X2 += 0.00000001709*np.cos(5.28726064030 + 81.8951455681*t)
	X2 += 0.00000001463*np.cos(0.43556587140 + 298.2326223919*t)
	X2 += 0.00000001894*np.cos(2.99138630157 + 1898.3512179396*t)
	X2 += 0.00000001895*np.cos(5.04730452650 + 291.262087743*t)
	X2 += 0.00000001546*np.cos(2.47057043174 + 739.8086667949*t)
	X2 += 0.00000001887*np.cos(2.94443665997 + 1884.124123938*t)
	X2 += 0.00000001423*np.cos(0.84203295561 + 201.5196819912*t)
	X2 += 0.00000001423*np.cos(0.90600055739 + 225.0785088848*t)
	X2 += 0.00000001491*np.cos(2.09090630362 + 240.125798381*t)
	X2 += 0.00000001913*np.cos(1.64596708222 + 295.1942410061*t)
	X2 += 0.00000001359*np.cos(1.56962491127 + 963.4027029714*t)
	X2 += 0.00000001390*np.cos(3.73504189572 + 731.9443602687*t)
	X2 += 0.00000001553*np.cos(0.23610855161 + 685.4739373527*t)
	X2 += 0.00000001352*np.cos(5.53246920435 + 5429.8794682394*t)
	X2 += 0.00000001323*np.cos(2.98882008525 + 980.6681783588*t)
	X2 += 0.00000001391*np.cos(3.35589924867 + 617.8058857862*t)
	X2 += 0.00000001330*np.cos(6.16179285989 + 3576.2897934404*t)
	X2 += 0.00000001414*np.cos(6.21368674613 + 1371.8416465827*t)
	X2 += 0.00000001700*np.cos(6.21800543945 + 563.6312150384*t)
	X2 += 0.00000001299*np.cos(3.53363256309 + 767.3690829208*t)
	X2 += 0.00000001674*np.cos(2.00015752559 + 2001.4439921582*t)
	X2 += 0.00000001372*np.cos(5.88560479169 + 532.8723588323*t)
	X2 += 0.00000001259*np.cos(0.96011598153 + 850.0149880143*t)
	X2 += 0.00000001305*np.cos(1.37120991188 + 1994.3304451574*t)
	X2 += 0.00000001321*np.cos(4.37658999115 + 28.4541880032*t)
	X2 += 0.00000001379*np.cos(2.12052572095 + 2737.32050569*t)
	X2 += 0.00000001328*np.cos(2.58956206405 + 214.2623032845*t)
	X2 += 0.00000001328*np.cos(5.44165675613 + 212.3358875915*t)
	X2 += 0.00000001579*np.cos(3.34736370728 + 2324.9494088156*t)
	X2 += 0.00000001231*np.cos(4.50009391302 + 3178.1457905676*t)
	X2 += 0.00000001246*np.cos(0.67281854122 + 9360.089164459*t)
	X2 += 0.00000001219*np.cos(1.29311240207 + 945.9942152321*t)
	X2 += 0.00000001269*np.cos(3.22552060147 + 327.4375699205*t)
	X2 += 0.00000001664*np.cos(1.93237560590 + 252.6559713532*t)
	X2 += 0.00000001384*np.cos(2.21441962019 + 2524.021410252*t)
	X2 += 0.00000001544*np.cos(2.44379787028 + 1049.0869894507*t)
	X2 += 0.00000001268*np.cos(3.89702349681 + 472.1748419147*t)
	X2 += 0.00000001191*np.cos(2.11500805970 + 153.4953503977*t)
	X2 += 0.00000001404*np.cos(2.81178679147 + 312.4597163935*t)
	X2 += 0.00000001460*np.cos(1.98205310382 + 699.7010313543*t)
	X2 += 0.00000001222*np.cos(5.71175018863 + 213.3472795478*t)
	X2 += 0.00000001222*np.cos(2.31946863155 + 213.2509113282*t)
	X2 += 0.00000001167*np.cos(4.59358372111 + 193.655375465*t)
	X2 += 0.00000001167*np.cos(3.43763509907 + 232.942815411*t)
	X2 += 0.00000001163*np.cos(0.23385034682 + 148.0787244263*t)
	X2 += 0.00000001407*np.cos(3.99762884497 + 9992.8729037722*t)
	X2 += 0.00000001280*np.cos(0.87484258071 + 4120.2078525366*t)
	X2 += 0.00000001134*np.cos(1.53044808941 + 525.4981794006*t)
	X2 += 0.00000001336*np.cos(4.87465823527 + 1905.4647649404*t)
	X2 += 0.00000001148*np.cos(1.30512021279 + 1596.1864422846*t)
	X2 += 0.00000001155*np.cos(5.90518396544 + 67.6680515665*t)
	X2 += 0.00000001122*np.cos(4.02938519202 + 128.3655684841*t)
	X2 += 0.00000001305*np.cos(3.82342312832 + 96.8729990951*t)
	X2 += 0.00000001321*np.cos(0.98022217092 + 355.7487455718*t)
	X2 += 0.00000001105*np.cos(3.19584194807 + 1038.0412891868*t)
	X2 += 0.00000001431*np.cos(3.57196787982 + 1244.226837624*t)
	X2 += 0.00000001322*np.cos(6.14235561079 + 4216.1870797544*t)
	X2 += 0.00000001068*np.cos(5.90398865331 + 3892.681663097*t)
	X2 += 0.00000001346*np.cos(1.90158806441 + 2406.7015420318*t)
	X2 += 0.00000001154*np.cos(3.56014472151 + 184.8449074348*t)
	X2 += 0.00000001110*np.cos(1.17830763748 + 4017.115078318*t)
	X2 += 0.00000001288*np.cos(2.24776349764 + 629.6023455755*t)
	X2 += 0.00000001023*np.cos(4.46536500836 + 5636.0650166766*t)
	X2 += 0.00000001012*np.cos(3.59569868907 + 211.6021744086*t)
	X2 += 0.00000001012*np.cos(4.43552013111 + 214.9960164674*t)
	X2 += 0.00000001320*np.cos(5.94097955621 + 2964.8466951296*t)
	X2 += 0.00000000997*np.cos(6.16867640374 + 776.9303104764*t)
	X2 += 0.00000001175*np.cos(1.53687242309 + 2730.2069586892*t)
	X2 += 0.00000001377*np.cos(2.53741878844 + 1773.9178027186*t)
	X2 += 0.00000001124*np.cos(2.19052206601 + 3914.0223040994*t)
	X2 += 0.00000001193*np.cos(5.67235253062 + 4113.0943055358*t)
	X2 += 0.00000001237*np.cos(2.82498813081 + 2193.4024465938*t)
	X2 += 0.00000001196*np.cos(1.80112488667 + 2317.8358618148*t)
	X2 += 0.00000000954*np.cos(3.08188516695 + 206.706813299*t)
	X2 += 0.00000000954*np.cos(4.94933365323 + 219.891377577*t)
	X2 += 0.00000000952*np.cos(2.26143146849 + 1912.5783119412*t)
	X2 += 0.00000001022*np.cos(0.15232062073 + 3583.4033404412*t)
	X2 += 0.00000000973*np.cos(1.56107465656 + 181.806526049*t)
	X2 += 0.00000000973*np.cos(3.32855151003 + 244.791664827*t)
	X2 += 0.00000001300*np.cos(3.26495224133 + 835.7878940127*t)
	X2 += 0.00000001249*np.cos(2.51786044665 + 2516.9078632512*t)
	X2 += 0.00000001088*np.cos(3.90357892590 + 2428.0421830342*t)
	X2 += 0.00000000929*np.cos(0.45989104164 + 1475.6851803267*t)
	X2 += 0.00000000956*np.cos(2.56594245315 + 312.1990839626*t)
	X2 += 0.00000000953*np.cos(4.36298872930 + 3494.5376602242*t)
	X2 += 0.00000001186*np.cos(0.16724602956 + 3899.7952100978*t)
	X2 += 0.00000001062*np.cos(5.98827376052 + 4209.0735327536*t)
	X2 += 0.00000000986*np.cos(3.70856598989 + 3487.4241132234*t)
	X2 += 0.00000000917*np.cos(1.25571195126 + 601.7642506762*t)
	X2 += 0.00000001066*np.cos(0.73008144677 + 3686.4961146598*t)
	X2 += 0.00000000909*np.cos(1.10532095217 + 3149.6916025644*t)
	X2 += 0.00000001103*np.cos(1.66926766813 + 1262.3860848887*t)
	X2 += 0.00000000999*np.cos(5.63756377401 + 171.6545976624*t)
	X2 += 0.00000001020*np.cos(3.02702396710 + 2200.5159935946*t)
	X2 += 0.00000001082*np.cos(1.14306307216 + 1382.8873468466*t)
	X2 += 0.00000000948*np.cos(5.39881740490 + 1809.4855377226*t)
	X2 += 0.00000000898*np.cos(5.87496744199 + 9566.2747128962*t)
	X2 += 0.00000001003*np.cos(2.89316477102 + 60.7669528868*t)
	X2 += 0.00000001048*np.cos(1.72895083338 + 3053.7123753466*t)
	X2 += 0.00000000878*np.cos(4.79905755156 + 4422.3726281916*t)
	X2 += 0.00000000883*np.cos(1.95148255924 + 2936.3925071264*t)
	X2 += 0.00000000920*np.cos(3.26816711188 + 458.8415197904*t)
	X2 += 0.00000001034*np.cos(2.00213945097 + 2840.4132799086*t)
	X2 += 0.00000001100*np.cos(5.41378028474 + 3267.0114707846*t)
	X2 += 0.00000000861*np.cos(0.31780761010 + 2943.5060541272*t)
	X2 += 0.00000000869*np.cos(5.85449793979 + 92.7978334801*t)
	X2 += 0.00000000923*np.cos(0.50147958719 + 731.6837278378*t)
	X2 += 0.00000000852*np.cos(6.02200914086 + 835.0371344873*t)
	X2 += 0.00000001019*np.cos(5.16657224921 + 558.0021407459*t)
	X2 += 0.00000000972*np.cos(5.47637157482 + 254.9435932136*t)
	X2 += 0.00000000908*np.cos(2.87474888027 + 745.9108218394*t)
	X2 += 0.00000000851*np.cos(3.39345244102 + 2957.7331481288*t)
	X2 += 0.00000000901*np.cos(1.75381864225 + 823.9914342234*t)
	X2 += 0.00000000885*np.cos(5.04038096483 + 1037.2905296614*t)
	X2 += 0.00000000828*np.cos(6.15073321813 + 60.5545045657*t)
	X2 += 0.00000000906*np.cos(4.89715205670 + 905.8865797915*t)
	X2 += 0.00000000825*np.cos(3.03654698989 + 99.1606209555*t)
	X2 += 0.00000000871*np.cos(2.37191353961 + 137.0330241624*t)
	X2 += 0.00000000944*np.cos(1.27319885318 + 1051.517623663*t)
	X2 += 0.00000000862*np.cos(3.15782546881 + 397.3932433474*t)
	X2 += 0.00000000807*np.cos(5.36535950366 + 3067.9394693482*t)
	X2 += 0.00000001110*np.cos(3.19832395458 + 739.0579072695*t)
	X2 += 0.00000001085*np.cos(0.07341193511 + 1176.7017984094*t)
	X2 += 0.00000001008*np.cos(3.63001056867 + 203.2647871304*t)
	X2 += 0.00000001008*np.cos(4.40120825151 + 223.3334037456*t)
	X2 += 0.00000000791*np.cos(2.01279017523 + 201.9927627432*t)
	X2 += 0.00000000791*np.cos(6.01842864495 + 224.6054281328*t)
	X2 += 0.00000000843*np.cos(4.81860966681 + 411.620337349*t)
	X2 += 0.00000000870*np.cos(5.83539286646 + 2648.454825473*t)
	X2 += 0.00000000948*np.cos(1.68350455637 + 215.7467759928*t)
	X2 += 0.00000001076*np.cos(1.39032879017 + 3789.5888888784*t)
	X2 += 0.00000000764*np.cos(1.39589682354 + 84.9335269539*t)
	X2 += 0.00000000893*np.cos(6.04799393738 + 1802.3719907218*t)
	X2 += 0.00000000934*np.cos(2.01855627131 + 2833.2997329078*t)
	X2 += 0.00000001041*np.cos(3.28284201181 + 1560.6187072806*t)
	X2 += 0.00000000885*np.cos(5.40300478280 + 4326.3934009738*t)
	X2 += 0.00000000832*np.cos(5.94730006536 + 4223.3006267552*t)
	X2 += 0.00000000962*np.cos(5.33472317723 + 214.0498549634*t)
	X2 += 0.00000000962*np.cos(2.69649564295 + 212.5483359126*t)
	X2 += 0.00000001061*np.cos(3.91087935079 + 525.7588118315*t)
	X2 += 0.00000000751*np.cos(6.13617466887 + 3569.1762464396*t)
	X2 += 0.00000000744*np.cos(4.65729515884 + 278.5194664497*t)
	X2 += 0.00000000742*np.cos(4.70968645148 + 1119.1856752295*t)
	X2 += 0.00000000771*np.cos(5.80442543136 + 831.1049812242*t)
	X2 += 0.00000000759*np.cos(0.08689720924 + 778.4147831847*t)
	X2 += 0.00000000771*np.cos(1.93743302083 + 305.0855369618*t)
	X2 += 0.00000000744*np.cos(0.57331346787 + 504.561183181*t)
	X2 += 0.00000000726*np.cos(4.61903728311 + 2861.753920911*t)
	X2 += 0.00000000870*np.cos(2.38183712961 + 1056.2005364515*t)
	X2 += 0.00000000746*np.cos(0.23181387281 + 1080.7225711916*t)
	X2 += 0.00000000829*np.cos(4.76086686294 + 714.5358725294*t)
	X2 += 0.00000000954*np.cos(2.58974255609 + 205.6642835754*t)
	X2 += 0.00000000954*np.cos(5.44147626409 + 220.9339073006*t)
	X2 += 0.00000000907*np.cos(2.91202776680 + 2214.7430875962*t)
	X2 += 0.00000000911*np.cos(1.32688747464 + 3362.9906980024*t)
	X2 += 0.00000000896*np.cos(0.81358229052 + 1699.2792165032*t)
	X2 += 0.00000000823*np.cos(4.36594388653 + 2538.2485042536*t)
	X2 += 0.00000000715*np.cos(1.89070101229 + 760.25553592*t)
	X2 += 0.00000000942*np.cos(2.09563260663 + 953.1077622329*t)
	X2 += 0.00000000699*np.cos(0.89798477775 + 3466.083472221*t)
	X2 += 0.00000000704*np.cos(5.13636089217 + 306.0969289181*t)
	X2 += 0.00000000693*np.cos(5.51319068716 + 637.4496057592*t)
	X2 += 0.00000000732*np.cos(0.46520796438 + 172.2452984934*t)
	X2 += 0.00000000732*np.cos(4.42441820221 + 254.3528923826*t)
	X2 += 0.00000000945*np.cos(1.12211376563 + 388.4651552382*t)
	X2 += 0.00000000865*np.cos(2.55550857107 + 2509.7943162504*t)
	X2 += 0.00000000874*np.cos(2.39287375587 + 2090.3096723752*t)
	X2 += 0.00000000807*np.cos(4.61318661936 + 2221.856634597*t)
	X2 += 0.00000000686*np.cos(4.49678432054 + 2854.6403739102*t)
	X2 += 0.00000000785*np.cos(0.63645876992 + 4436.5997221932*t)
	X2 += 0.00000000716*np.cos(0.31353354367 + 3796.7024358792*t)
	X2 += 0.00000000714*np.cos(4.03037145569 + 3171.0322435668*t)
	return X2*t*t




def Saturn_X3 (t): # 214 terms of order 3

	X3 = 0.
	X3 += 0.00077093916*np.cos(2.97714400003 + 206.1855484372*t)
	X3 += 0.00075318954*np.cos(1.89208004954 + 220.4126424388*t)
	X3 -= 0.00018448888
	X3 += 0.00010524182*np.cos(0.66368351849 + 426.598190876*t)
	X3 += 0.00008992383*np.cos(0.91696888396 + 433.7117378768*t)
	X3 += 0.00007401493*np.cos(1.78627385772 + 227.5261894396*t)
	X3 += 0.00008043886*np.cos(3.12863814419 + 7.1135470008*t)
	X3 += 0.00004503883*np.cos(2.24531651241 + 419.4846438752*t)
	X3 += 0.00003467011*np.cos(3.14591173603 + 199.0720014364*t)
	X3 += 0.00002973756*np.cos(6.00031256382 + 639.897286314*t)
	X3 += 0.00002341707*np.cos(3.06091721419 + 14.2270940016*t)
	X3 += 0.00001230371*np.cos(4.38195871546 + 213.299095438*t)
	X3 += 0.00001023597*np.cos(0.01138890289 + 647.0108333148*t)
	X3 += 0.00000788314*np.cos(0.89850306907 + 440.8252848776*t)
	X3 += 0.00000806115*np.cos(1.28205827389 + 216.4804891757*t)
	X3 += 0.00000768511*np.cos(3.61309275908 + 210.1177017003*t)
	X3 += 0.00000384249*np.cos(3.06233558203 + 117.3198682202*t)
	X3 += 0.00000431624*np.cos(3.77909555661 + 110.2063212194*t)
	X3 += 0.00000456158*np.cos(5.14235391148 + 853.196381752*t)
	X3 += 0.00000323749*np.cos(1.65135986090 + 234.6397364404*t)
	X3 += 0.00000279312*np.cos(2.09194739376 + 412.3710968744*t)
	X3 += 0.00000242325*np.cos(3.37263291828 + 103.0927742186*t)
	X3 += 0.00000194820*np.cos(0.79561075453 + 316.3918696566*t)
	X3 += 0.00000197473*np.cos(2.29502750567 + 632.7837393132*t)
	X3 += 0.00000153539*np.cos(2.32058023635 + 323.5054166574*t)
	X3 += 0.00000153890*np.cos(2.88170193491 + 21.3406410024*t)
	X3 += 0.00000125210*np.cos(1.45557479064 + 209.3669421749*t)
	X3 += 0.00000112760*np.cos(3.40679000015 + 217.2312487011*t)
	X3 += 0.00000111243*np.cos(5.41745722736 + 860.3099287528*t)
	X3 += 0.00000114540*np.cos(1.16490445103 + 223.5940361765*t)
	X3 += 0.00000085309*np.cos(1.89280411727 + 330.6189636582*t)
	X3 += 0.00000085135*np.cos(0.03375816593 + 654.1243803156*t)
	X3 += 0.00000077939*np.cos(1.56010598020 + 124.433415221*t)
	X3 += 0.00000078231*np.cos(3.42914597013 + 191.9584544356*t)
	X3 += 0.00000074130*np.cos(1.42392750477 + 95.9792272178*t)
	X3 += 0.00000068142*np.cos(0.98387434301 + 88.865680217*t)
	X3 += 0.00000087336*np.cos(0.36956268263 + 429.7795846137*t)
	X3 += 0.00000055815*np.cos(3.14406432672 + 202.2533951741*t)
	X3 += 0.00000052827*np.cos(1.73408996046 + 224.3447957019*t)
	X3 += 0.00000057443*np.cos(3.03043444004 + 309.2783226558*t)
	X3 += 0.00000057492*np.cos(3.84782364103 + 203.0041546995*t)
	X3 += 0.00000056170*np.cos(4.32610077535 + 1066.49547719*t)
	X3 += 0.00000036710*np.cos(0.80403065388 + 447.9388318784*t)
	X3 += 0.00000043368*np.cos(0.21492345016 + 422.6660376129*t)
	X3 += 0.00000038392*np.cos(4.61793981610 + 302.164775655*t)
	X3 += 0.00000032639*np.cos(1.27284006674 + 536.8045120954*t)
	X3 += 0.00000026301*np.cos(5.33628294545 + 3.9321532631*t)
	X3 += 0.00000032662*np.cos(5.10912315942 + 515.463871093*t)
	X3 += 0.00000034539*np.cos(4.06711162584 + 625.6701923124*t)
	X3 += 0.00000027097*np.cos(3.52898530668 + 423.4167971383*t)
	X3 += 0.00000032740*np.cos(5.24464525755 + 522.5774180938*t)
	X3 += 0.00000018273*np.cos(5.52009626612 + 11.0457002639*t)
	X3 += 0.00000017384*np.cos(2.60487389200 + 742.9900605326*t)
	X3 += 0.00000016214*np.cos(5.33895191945 + 195.1398481733*t)
	X3 += 0.00000012460*np.cos(1.13917234752 + 437.6438911399*t)
	X3 += 0.00000011566*np.cos(0.99542094843 + 543.9180590962*t)
	X3 += 0.00000010400*np.cos(0.86968337094 + 337.732510659*t)
	X3 += 0.00000009842*np.cos(3.12525312100 + 529.6909650946*t)
	X3 += 0.00000009560*np.cos(3.90950620405 + 728.762966531*t)
	X3 += 0.00000011351*np.cos(4.59214972522 + 1073.6090241908*t)
	X3 += 0.00000009345*np.cos(2.60381362406 + 846.0828347512*t)
	X3 += 0.00000009883*np.cos(0.96970461885 + 131.5469622218*t)
	X3 += 0.00000011913*np.cos(0.32742179509 + 436.8931316145*t)
	X3 += 0.00000008885*np.cos(1.24775346326 + 81.7521332162*t)
	X3 += 0.00000009563*np.cos(5.37444374475 + 618.5566453116*t)
	X3 += 0.00000008801*np.cos(4.62317354759 + 831.8557407496*t)
	X3 += 0.00000008329*np.cos(5.47343196835 + 867.4234757536*t)
	X3 += 0.00000007557*np.cos(0.67492634194 + 149.5631971346*t)
	X3 += 0.00000008632*np.cos(5.79859457484 + 643.0786800517*t)
	X3 += 0.00000007108*np.cos(5.64575177409 + 635.9651330509*t)
	X3 += 0.00000006933*np.cos(2.65057981825 + 231.4583427027*t)
	X3 += 0.00000006264*np.cos(4.41093547560 + 838.9692877504*t)
	X3 += 0.00000006025*np.cos(0.88008570151 + 269.9214467406*t)
	X3 += 0.00000006551*np.cos(2.06592655725 + 408.4389436113*t)
	X3 += 0.00000005426*np.cos(1.51764548237 + 241.7532834412*t)
	X3 += 0.00000006969*np.cos(2.96839894235 + 18.1592472647*t)
	X3 += 0.00000004980*np.cos(3.99676471147 + 277.0349937414*t)
	X3 += 0.00000006072*np.cos(4.85052454022 + 430.5303441391*t)
	X3 += 0.00000006351*np.cos(4.65670685339 + 735.8765135318*t)
	X3 += 0.00000005092*np.cos(5.42295850402 + 415.5524906121*t)
	X3 += 0.00000004853*np.cos(1.41484953432 + 56.6223513026*t)
	X3 += 0.00000004788*np.cos(5.23457916974 + 416.3032501375*t)
	X3 += 0.00000005822*np.cos(3.52591886185 + 1279.794572628*t)
	X3 += 0.00000004502*np.cos(5.18072695308 + 295.0512286542*t)
	X3 += 0.00000004827*np.cos(2.39418231864 + 1059.3819301892*t)
	X3 += 0.00000004162*np.cos(2.57897558009 + 405.2575498736*t)
	X3 += 0.00000004047*np.cos(0.05586072894 + 483.2205421786*t)
	X3 += 0.00000003761*np.cos(0.20298402131 + 184.8449074348*t)
	X3 += 0.00000004267*np.cos(0.15673436136 + 750.1036075334*t)
	X3 += 0.00000003758*np.cos(6.26818424862 + 661.2379273164*t)
	X3 += 0.00000003444*np.cos(0.42308482121 + 70.8494453042*t)
	X3 += 0.00000004356*np.cos(5.28542650706 + 508.3503240922*t)
	X3 += 0.00000003055*np.cos(3.54993071464 + 1045.1548361876*t)
	X3 += 0.00000004020*np.cos(5.39263507810 + 942.062061969*t)
	X3 += 0.00000003963*np.cos(4.65894685562 + 1148.2476104062*t)
	X3 += 0.00000002777*np.cos(5.36220250966 + 398.1440028728*t)
	X3 += 0.00000003496*np.cos(5.46796158814 + 934.9485149682*t)
	X3 += 0.00000002632*np.cos(5.25668667268 + 497.4476361802*t)
	X3 += 0.00000003141*np.cos(2.37254962656 + 113.3877149571*t)
	X3 += 0.00000002985*np.cos(4.24271370111 + 1464.6394800628*t)
	X3 += 0.00000002624*np.cos(5.92774700876 + 362.8622925726*t)
	X3 += 0.00000002819*np.cos(2.37526855634 + 106.2741679563*t)
	X3 += 0.00000002182*np.cos(0.02759628247 + 85.8272988312*t)
	X3 += 0.00000002279*np.cos(5.92066831454 + 611.4430983108*t)
	X3 += 0.00000001975*np.cos(2.38286785833 + 10.2949407385*t)
	X3 += 0.00000002390*np.cos(5.35249244244 + 2111.6503133776*t)
	X3 += 0.00000001947*np.cos(0.29299091741 + 650.9429865779*t)
	X3 += 0.00000002670*np.cos(0.63080955086 + 195.8906076987*t)
	X3 += 0.00000002670*np.cos(1.11722396214 + 230.7075831773*t)
	X3 += 0.00000002109*np.cos(2.18754318252 + 1375.7737998458*t)
	X3 += 0.00000002172*np.cos(4.72482235976 + 824.7421937488*t)
	X3 += 0.00000001881*np.cos(1.51688147809 + 344.7030453079*t)
	X3 += 0.00000001803*np.cos(1.85139236464 + 191.2076949102*t)
	X3 += 0.00000002064*np.cos(3.73413690570 + 636.7158925763*t)
	X3 += 0.00000001731*np.cos(4.25636556249 + 107.0249274817*t)
	X3 += 0.00000002012*np.cos(5.61258183662 + 927.8349679674*t)
	X3 += 0.00000002174*np.cos(3.60856902528 + 2001.4439921582*t)
	X3 += 0.00000001894*np.cos(3.17747534562 + 2634.2277314714*t)
	X3 += 0.00000001623*np.cos(5.85709468849 + 1596.1864422846*t)
	X3 += 0.00000001568*np.cos(3.03962450731 + 235.3904959658*t)
	X3 += 0.00000001620*np.cos(3.59260179724 + 1354.4331588434*t)
	X3 += 0.00000002086*np.cos(1.63830662169 + 444.7574381407*t)
	X3 += 0.00000001666*np.cos(1.70122243075 + 1877.0105769372*t)
	X3 += 0.00000001534*np.cos(2.96438152675 + 2531.1349572528*t)
	X3 += 0.00000001478*np.cos(2.77571041612 + 6290.1893969922*t)
	X3 += 0.00000001478*np.cos(5.26637302788 + 5849.3641121146*t)
	X3 += 0.00000001581*np.cos(3.33927122870 + 1670.82502850*t)
	X3 += 0.00000001463*np.cos(4.17961291276 + 5863.5912061162*t)
	X3 += 0.00000001463*np.cos(3.86247051274 + 6275.9623029906*t)
	X3 += 0.00000001458*np.cos(5.00557873280 + 1471.7530270636*t)
	X3 += 0.00000001800*np.cos(2.33402657895 + 1692.1656695024*t)
	X3 += 0.00000001703*np.cos(5.31204896749 + 1251.3403846248*t)
	X3 += 0.00000001486*np.cos(2.79422230211 + 956.2891559706*t)
	X3 += 0.00000001712*np.cos(3.37615479427 + 2317.8358618148*t)
	X3 += 0.00000001611*np.cos(4.98780035976 + 1155.361157407*t)
	X3 += 0.00000001461*np.cos(4.49945803797 + 284.1485407422*t)
	X3 += 0.00000001422*np.cos(1.45443687756 + 3156.8051495652*t)
	X3 += 0.00000001703*np.cos(4.03248419286 + 1781.0313497194*t)
	X3 += 0.00000001826*np.cos(5.18757361092 + 1258.4539316256*t)
	X3 += 0.00000001710*np.cos(0.91014674347 + 2118.7638603784*t)
	X3 += 0.00000001784*np.cos(4.50423670731 + 2641.3412784722*t)
	X3 += 0.00000001464*np.cos(5.14309710649 + 1567.7322542814*t)
	X3 += 0.00000001401*np.cos(1.88642781204 + 142.4496501338*t)
	X3 += 0.00000001343*np.cos(0.92628967169 + 721.6494195302*t)
	X3 += 0.00000001291*np.cos(3.37888350174 + 2214.7430875962*t)
	X3 += 0.00000001350*np.cos(4.32908573183 + 2104.5367663768*t)
	X3 += 0.00000001418*np.cos(4.89635131851 + 1891.2376709388*t)
	X3 += 0.00000001378*np.cos(5.33317515837 + 1244.226837624*t)
	X3 += 0.00000001169*np.cos(3.51844208566 + 1038.0412891868*t)
	X3 += 0.00000001193*np.cos(2.35328043754 + 208.633228992*t)
	X3 += 0.00000001193*np.cos(5.67793838264 + 217.964961884*t)
	X3 += 0.00000001171*np.cos(1.32912096461 + 67.6680515665*t)
	X3 += 0.00000001448*np.cos(4.76381158065 + 1574.8458012822*t)
	X3 += 0.00000001479*np.cos(2.71782422593 + 2943.5060541272*t)
	X3 += 0.00000001218*np.cos(4.64137100804 + 1802.3719907218*t)
	X3 += 0.00000001258*np.cos(3.13376191836 + 1987.2168981566*t)
	X3 += 0.00000001120*np.cos(2.20237394974 + 2221.856634597*t)
	X3 += 0.00000001489*np.cos(4.90352954971 + 99.9113804809*t)
	X3 += 0.00000001423*np.cos(0.20348614524 + 2751.5475996916*t)
	X3 += 0.00000001287*np.cos(2.87033036762 + 2950.619601128*t)
	X3 += 0.00000001366*np.cos(1.50720012516 + 160.6088973985*t)
	X3 += 0.00000001404*np.cos(4.60280002051 + 1141.1340634054*t)
	X3 += 0.00000001271*np.cos(3.84978015419 + 2516.9078632512*t)
	X3 += 0.00000001043*np.cos(3.94888443244 + 156.6767441354*t)
	X3 += 0.00000001353*np.cos(1.63971328596 + 2332.0629558164*t)
	X3 += 0.00000001107*np.cos(4.52250002071 + 1788.1448967202*t)
	X3 += 0.00000001030*np.cos(3.14179566095 + 1272.6810256272*t)
	X3 += 0.00000001267*np.cos(3.23903356397 + 2730.2069586892*t)
	X3 += 0.00000000983*np.cos(3.57873923658 + 2538.2485042536*t)
	X3 += 0.00000000947*np.cos(1.10602398935 + 2737.32050569*t)
	X3 += 0.00000000943*np.cos(1.43059281636 + 1265.5674786264*t)
	X3 += 0.00000000959*np.cos(2.81080821378 + 3.1813937377*t)
	X3 += 0.00000000934*np.cos(2.85061816635 + 2847.5268269094*t)
	X3 += 0.00000001217*np.cos(0.61048663699 + 2435.155730035*t)
	X3 += 0.00000001065*np.cos(3.11668462648 + 2627.1141844706*t)
	X3 += 0.00000001037*np.cos(5.05773255871 + 1560.6187072806*t)
	X3 += 0.00000000892*np.cos(4.87072941550 + 340.7708920448*t)
	X3 += 0.00000001159*np.cos(4.05810519039 + 1773.9178027186*t)
	X3 += 0.00000000890*np.cos(0.42201287054 + 358.9301393095*t)
	X3 += 0.00000000911*np.cos(4.63172396818 + 52.6901980395*t)
	X3 += 0.00000001141*np.cos(4.36531176294 + 2200.5159935946*t)
	X3 += 0.00000000869*np.cos(1.74356858320 + 621.7380390493*t)
	X3 += 0.00000000874*np.cos(3.20030615211 + 313.2104759189*t)
	X3 += 0.00000001076*np.cos(4.65549790926 + 2310.722314814*t)
	X3 += 0.00000000915*np.cos(3.95150791665 + 2413.8150890326*t)
	X3 += 0.00000000886*np.cos(4.98162541052 + 1884.124123938*t)
	X3 += 0.00000000826*np.cos(0.12226241024 + 2854.6403739102*t)
	X3 += 0.00000000931*np.cos(4.58138300754 + 2207.6295405954*t)
	X3 += 0.00000001022*np.cos(2.73879142256 + 1795.258443721*t)
	X3 += 0.00000000829*np.cos(1.23001925045 + 3473.1970192218*t)
	X3 += 0.00000000780*np.cos(5.40530203824 + 288.0806940053*t)
	X3 += 0.00000000780*np.cos(5.76750943553 + 138.5174968707*t)
	X3 += 0.00000000801*np.cos(4.12442591018 + 2420.9286360334*t)
	X3 += 0.00000001048*np.cos(5.42341780494 + 1699.2792165032*t)
	X3 += 0.00000000980*np.cos(3.38242345124 + 265.9892934775*t)
	X3 += 0.00000000761*np.cos(5.11274182251 + 628.8515860501*t)
	X3 += 0.00000000829*np.cos(4.46319631894 + 1382.8873468466*t)
	X3 += 0.00000000759*np.cos(4.24719590767 + 1589.0728952838*t)
	X3 += 0.00000001036*np.cos(1.92150632612 + 2008.557539159*t)
	X3 += 0.00000001004*np.cos(3.82519737724 + 2097.423219376*t)
	X3 += 0.00000000859*np.cos(6.09743195511 + 1169.5882514086*t)
	X3 += 0.00000001023*np.cos(3.16354165750 + 1162.4747044078*t)
	X3 += 0.00000000749*np.cos(3.65032166516 + 1809.4855377226*t)
	X3 += 0.00000001025*np.cos(1.41031425038 + 2648.454825473*t)
	X3 += 0.00000000970*np.cos(2.42137255057 + 3259.8979237838*t)
	X3 += 0.00000000969*np.cos(4.11891057273 + 2524.021410252*t)
	X3 += 0.00000000760*np.cos(3.53245128537 + 1361.5467058442*t)
	X3 += 0.00000000727*np.cos(2.50277330889 + 245.5424243524*t)
	X3 += 0.00000000727*np.cos(2.38685285770 + 181.0557665236*t)
	X3 += 0.00000000806*np.cos(4.44964273062 + 1912.5783119412*t)
	X3 += 0.00000000699*np.cos(0.41079818318 + 9779.5738083342*t)
	X3 += 0.00000000699*np.cos(4.19500442256 + 10220.3990932118*t)
	X3 += 0.00000000712*np.cos(0.83128225610 + 3149.6916025644*t)
	X3 += 0.00000000943*np.cos(4.37865824380 + 1457.525933062*t)
	return X3*t*t*t




def Saturn_X4 (t): # 87 terms of order 4

	X4 = 0.
	X4 += 0.00007957649*np.cos(4.70523623227 + 206.1855484372*t)
	X4 += 0.00007834416*np.cos(0.13981692944 + 220.4126424388*t)
	X4 += 0.00001510766*np.cos(0.06561562614 + 227.5261894396*t)
	X4 += 0.00001222718*np.cos(5.41618706626 + 433.7117378768*t)
	X4 += 0.00000702578*np.cos(4.84942343584 + 199.0720014364*t)
	X4 += 0.00000861569
	X4 += 0.00000550606*np.cos(1.37376296077 + 7.1135470008*t)
	X4 += 0.00000353954*np.cos(4.14510701125 + 419.4846438752*t)
	X4 += 0.00000386476*np.cos(1.33814676867 + 14.2270940016*t)
	X4 += 0.00000386632*np.cos(5.00698289959 + 426.598190876*t)
	X4 += 0.00000185617*np.cos(5.43394463245 + 440.8252848776*t)
	X4 += 0.00000208917*np.cos(4.14160968677 + 639.897286314*t)
	X4 += 0.00000171842*np.cos(4.47453630580 + 647.0108333148*t)
	X4 += 0.00000107628*np.cos(3.12066785242 + 213.299095438*t)
	X4 += 0.00000085501*np.cos(6.19913432948 + 234.6397364404*t)
	X4 += 0.00000044565*np.cos(1.37919223618 + 117.3198682202*t)
	X4 += 0.00000046688*np.cos(3.24488292928 + 853.196381752*t)
	X4 += 0.00000040674*np.cos(3.84264604432 + 412.3710968744*t)
	X4 += 0.00000031426*np.cos(1.10512966038 + 21.3406410024*t)
	X4 += 0.00000022585*np.cos(4.54572472226 + 654.1243803156*t)
	X4 += 0.00000023455*np.cos(1.82221057710 + 110.2063212194*t)
	X4 += 0.00000022100*np.cos(4.99442974326 + 103.0927742186*t)
	X4 += 0.00000016781*np.cos(5.95845772756 + 124.433415221*t)
	X4 += 0.00000021614*np.cos(3.57669133452 + 860.3099287528*t)
	X4 += 0.00000013266*np.cos(2.62546406286 + 88.865680217*t)
	X4 += 0.00000011159*np.cos(0.51449343376 + 323.5054166574*t)
	X4 += 0.00000012055*np.cos(5.31554479919 + 447.9388318784*t)
	X4 += 0.00000011680*np.cos(0.07071555888 + 330.6189636582*t)
	X4 += 0.00000012768*np.cos(4.29259283212 + 632.7837393132*t)
	X4 += 0.00000009454*np.cos(4.97949666878 + 309.2783226558*t)
	X4 += 0.00000011615*np.cos(5.48666645223 + 191.9584544356*t)
	X4 += 0.00000008176*np.cos(4.69579306758 + 429.7795846137*t)
	X4 += 0.00000008183*np.cos(6.25637069378 + 302.164775655*t)
	X4 += 0.00000007648*np.cos(2.49809540273 + 1066.49547719*t)
	X4 += 0.00000007244*np.cos(2.45154966599 + 316.3918696566*t)
	X4 += 0.00000007122*np.cos(3.48320485477 + 95.9792272178*t)
	X4 += 0.00000006842*np.cos(2.21058521494 + 203.0041546995*t)
	X4 += 0.00000006721*np.cos(5.82034927641 + 223.5940361765*t)
	X4 += 0.00000005567*np.cos(0.74140224137 + 515.463871093*t)
	X4 += 0.00000006054*np.cos(5.76677297417 + 625.6701923124*t)
	X4 += 0.00000003706*np.cos(0.91070583014 + 423.4167971383*t)
	X4 += 0.00000004566*np.cos(2.33336636359 + 210.1177017003*t)
	X4 += 0.00000003547*np.cos(0.88269270613 + 522.5774180938*t)
	X4 += 0.00000003481*np.cos(0.40766895755 + 405.2575498736*t)
	X4 += 0.00000004122*np.cos(5.75056217441 + 216.4804891757*t)
	X4 += 0.00000002952*np.cos(5.70948811764 + 536.8045120954*t)
	X4 += 0.00000002914*np.cos(4.78578940892 + 422.6660376129*t)
	X4 += 0.00000002709*np.cos(0.47869910745 + 831.8557407496*t)
	X4 += 0.00000002717*np.cos(5.35928319999 + 131.5469622218*t)
	X4 += 0.00000002555*np.cos(4.65503946246 + 337.732510659*t)
	X4 += 0.00000001782*np.cos(1.94963952968 + 184.8449074348*t)
	X4 += 0.00000001782*np.cos(6.08157929050 + 241.7532834412*t)
	X4 += 0.00000001647*np.cos(4.69494400206 + 529.6909650946*t)
	X4 += 0.00000001607*np.cos(4.53781851011 + 611.4430983108*t)
	X4 += 0.00000001671*np.cos(5.82347399210 + 728.762966531*t)
	X4 += 0.00000001832*np.cos(1.05748320810 + 618.5566453116*t)
	X4 += 0.00000001378*np.cos(4.60357847531 + 1258.4539316256*t)
	X4 += 0.00000001362*np.cos(0.24349155164 + 295.0512286542*t)
	X4 += 0.00000001424*np.cos(1.29921978517 + 1361.5467058442*t)
	X4 += 0.00000001354*np.cos(0.56585154017 + 1052.2683831884*t)
	X4 += 0.00000001527*np.cos(0.16925157947 + 742.9900605326*t)
	X4 += 0.00000001385*np.cos(1.03348225034 + 934.9485149682*t)
	X4 += 0.00000001276*np.cos(5.27451478451 + 209.3669421749*t)
	X4 += 0.00000001310*np.cos(2.66710126916 + 217.2312487011*t)
	X4 += 0.00000001646*np.cos(0.97572157001 + 195.1398481733*t)
	X4 += 0.00000001646*np.cos(0.77231194299 + 231.4583427027*t)
	X4 += 0.00000001321*np.cos(4.31463392663 + 1891.2376709388*t)
	X4 += 0.00000001220*np.cos(5.77693859261 + 1677.9385755008*t)
	X4 += 0.00000001161*np.cos(6.07080345095 + 81.7521332162*t)
	X4 += 0.00000001326*np.cos(0.08306524701 + 735.8765135318*t)
	X4 += 0.00000001356*np.cos(5.89043928703 + 1464.6394800628*t)
	X4 += 0.00000001109*np.cos(1.13447786805 + 942.062061969*t)
	X4 += 0.00000001079*np.cos(6.04021301968 + 1368.660252845*t)
	X4 += 0.00000001360*np.cos(0.43595823048 + 1251.3403846248*t)
	X4 += 0.00000000970*np.cos(4.35782627482 + 1574.8458012822*t)
	X4 += 0.00000001040*np.cos(6.10739546703 + 1148.2476104062*t)
	X4 += 0.00000001058*np.cos(1.60073627875 + 750.1036075334*t)
	X4 += 0.00000000815*np.cos(3.68677231115 + 1884.124123938*t)
	X4 += 0.00000000963*np.cos(0.31543671592 + 508.3503240922*t)
	X4 += 0.00000000872*np.cos(5.40584490574 + 1994.3304451574*t)
	X4 += 0.00000000859*np.cos(1.14491409094 + 416.3032501375*t)
	X4 += 0.00000000862*np.cos(4.75102573016 + 436.8931316145*t)
	X4 += 0.00000000869*np.cos(4.08394538076 + 2207.6295405954*t)
	X4 += 0.00000000791*np.cos(0.48772914294 + 1375.7737998458*t)
	X4 += 0.00000000699*np.cos(6.11938930504 + 1272.6810256272*t)
	X4 += 0.00000000711*np.cos(3.95347589074 + 838.9692877504*t)
	X4 += 0.00000000684*np.cos(5.09702256485 + 661.2379273164*t)
	return X4*t*t*t*t




def Saturn_X5 (t): # 31 terms of order 5

	X5 = 0.
	X5 += 0.00000589081*np.cos(0.13910544483 + 206.1855484372*t)
	X5 += 0.00000585706*np.cos(4.66559223624 + 220.4126424388*t)
	X5 += 0.00000225585*np.cos(4.60652710308 + 227.5261894396*t)
	X5 += 0.00000130928*np.cos(3.62464025902 + 433.7117378768*t)
	X5 += 0.00000096655*np.cos(0.27211008150 + 199.0720014364*t)
	X5 += 0.00000039234*np.cos(5.89958047262 + 14.2270940016*t)
	X5 += 0.00000034028*np.cos(3.65602602826 + 440.8252848776*t)
	X5 += 0.00000022888*np.cos(2.66308397652 + 647.0108333148*t)
	X5 += 0.00000013217*np.cos(0.45062200345 + 419.4846438752*t)
	X5 += 0.00000011098*np.cos(2.29053445238 + 639.897286314*t)
	X5 += 0.00000010309*np.cos(4.51687321997 + 234.6397364404*t)
	X5 += 0.00000008618*np.cos(3.52496812983 + 191.9584544356*t)
	X5 += 0.00000007232*np.cos(2.35670723669 + 426.598190876*t)
	X5 += 0.00000004570*np.cos(4.45812627425 + 88.865680217*t)
	X5 += 0.00000003952*np.cos(2.26696519317 + 405.2575498736*t)
	X5 += 0.00000004374*np.cos(2.76511551481 + 654.1243803156*t)
	X5 += 0.00000003345*np.cos(0.57732318208 + 302.164775655*t)
	X5 += 0.00000003330*np.cos(1.41526603487 + 853.196381752*t)
	X5 += 0.00000003423*np.cos(0.55242036551 + 213.299095438*t)
	X5 += 0.00000003257*np.cos(2.01504712067 + 7.1135470008*t)
	X5 += 0.00000003259*np.cos(3.89966347218 + 124.433415221*t)
	X5 += 0.00000002600*np.cos(5.88861526835 + 110.2063212194*t)
	X5 += 0.00000002678*np.cos(1.74968775976 + 860.3099287528*t)
	X5 += 0.00000002293*np.cos(3.33163799546 + 515.463871093*t)
	X5 += 0.00000002138*np.cos(3.58678888073 + 447.9388318784*t)
	X5 += 0.00000001434*np.cos(1.52962464590 + 309.2783226558*t)
	X5 += 0.00000001179*np.cos(5.61835587452 + 117.3198682202*t)
	X5 += 0.00000000984*np.cos(3.95579224093 + 203.0041546995*t)
	X5 += 0.00000000984*np.cos(4.07542657925 + 223.5940361765*t)
	X5 += 0.00000000779*np.cos(2.12929707069 + 330.6189636582*t)
	X5 += 0.00000000783*np.cos(3.19520562324 + 522.5774180938*t)
	return X5*t*t*t*t*t




def Saturn_Y0 (t): # 1657 terms of order 0

	Y0 = 0.
	Y0 += 9.52714696877*np.cos(5.58600556072 + 213.299095438*t)
	Y0 -= 0.79354119271
	Y0 += 0.26434197609*np.cos(4.83528742856 + 426.598190876*t)
	Y0 += 0.06914690347*np.cos(2.55279029588 + 206.1855484372*t)
	Y0 += 0.06631679200*np.cos(5.46258849076 + 220.4126424388*t)
	Y0 += 0.02345226948*np.cos(0.44652393276 + 7.1135470008*t)
	Y0 += 0.01183557497*np.cos(1.34637027573 + 419.4846438752*t)
	Y0 += 0.01245523800*np.cos(0.60375781288 + 110.2063212194*t)
	Y0 += 0.01098442011*np.cos(4.08609387384 + 639.897286314*t)
	Y0 += 0.00700636234*np.cos(1.13613024684 + 316.3918696566*t)
	Y0 += 0.00373221824*np.cos(4.71309283502 + 433.7117378768*t)
	Y0 += 0.00335413797*np.cos(0.66392970394 + 103.0927742186*t)
	Y0 += 0.00149675444*np.cos(0.59938943096 + 38.1330356378*t)
	Y0 += 0.00097829309*np.cos(5.72860910220 + 323.5054166574*t)
	Y0 += 0.00080377512*np.cos(1.51715226439 + 529.6909650946*t)
	Y0 += 0.00080576954*np.cos(4.05258308529 + 11.0457002639*t)
	Y0 += 0.00083875875*np.cos(5.33204068233 + 227.5261894396*t)
	Y0 += 0.00070138439*np.cos(5.59777958177 + 209.3669421749*t)
	Y0 += 0.00065919181*np.cos(1.25972156533 + 202.2533951741*t)
	Y0 += 0.00071069917*np.cos(0.88882645933 + 632.7837393132*t)
	Y0 += 0.00068966168*np.cos(2.44460285922 + 217.2312487011*t)
	Y0 += 0.00058391222*np.cos(0.58871774298 + 224.3447957019*t)
	Y0 += 0.00054033488*np.cos(3.33755971377 + 853.196381752*t)
	Y0 += 0.00058932599*np.cos(0.76188426024 + 74.7815985673*t)
	Y0 += 0.00045783362*np.cos(0.30331816441 + 14.2270940016*t)
	Y0 += 0.00041964833*np.cos(2.62589505876 + 199.0720014364*t)
	Y0 += 0.00044692371*np.cos(0.90600229248 + 63.7358983034*t)
	Y0 += 0.00025192380*np.cos(5.08963506546 + 216.4804891757*t)
	Y0 += 0.00024633800*np.cos(2.95445207628 + 210.1177017003*t)
	Y0 += 0.00024828004*np.cos(4.02630021779 + 415.5524906121*t)
	Y0 += 0.00025539506*np.cos(0.06636302741 + 117.3198682202*t)
	Y0 += 0.00029671710*np.cos(6.09960421165 + 735.8765135318*t)
	Y0 += 0.00023390138*np.cos(3.96337860167 + 647.0108333148*t)
	Y0 += 0.00020506212*np.cos(1.05154502619 + 522.5774180938*t)
	Y0 += 0.00020269405*np.cos(2.34321183269 + 309.2783226558*t)
	Y0 += 0.00023261688*np.cos(4.81745174067 + 149.5631971346*t)
	Y0 += 0.00015379504*np.cos(3.10227913670 + 277.0349937414*t)
	Y0 += 0.00012419205*np.cos(2.62558143020 + 490.3340891794*t)
	Y0 += 0.00012044624*np.cos(4.09265940857 + 351.8165923087*t)
	Y0 += 0.00009544823*np.cos(3.48777857215 + 95.9792272178*t)
	Y0 += 0.00007657437*np.cos(1.16709831318 + 742.9900605326*t)
	Y0 += 0.00006918461*np.cos(1.17089073634 + 412.3710968744*t)
	Y0 += 0.00009006036*np.cos(5.87854541021 + 1052.2683831884*t)
	Y0 += 0.00006536938*np.cos(0.84256190288 + 838.9692877504*t)
	Y0 += 0.00006080448*np.cos(4.58758307965 + 440.8252848776*t)
	Y0 += 0.00006221723*np.cos(5.03120156259 + 536.8045120954*t)
	Y0 += 0.00004987241*np.cos(0.92163133661 + 846.0828347512*t)
	Y0 += 0.00005200364*np.cos(2.97482811217 + 210.8514148832*t)
	Y0 += 0.00005155105*np.cos(5.05796992379 + 215.7467759928*t)
	Y0 += 0.00003791258*np.cos(4.41806594234 + 422.6660376129*t)
	Y0 += 0.00003879403*np.cos(3.38065334501 + 3.9321532631*t)
	Y0 += 0.00003767674*np.cos(2.14954245794 + 212.3358875915*t)
	Y0 += 0.00003750939*np.cos(5.88125435107 + 214.2623032845*t)
	Y0 += 0.00003118048*np.cos(5.55799397309 + 213.2509113282*t)
	Y0 += 0.00003117166*np.cos(2.47259779969 + 213.3472795478*t)
	Y0 += 0.00003816713*np.cos(2.44107897815 + 625.6701923124*t)
	Y0 += 0.00003676804*np.cos(4.51090470038 + 76.2660712756*t)
	Y0 += 0.00004041434*np.cos(1.24475045830 + 137.0330241624*t)
	Y0 += 0.00002909579*np.cos(5.84815497128 + 85.8272988312*t)
	Y0 += 0.00002829614*np.cos(5.44452944307 + 330.6189636582*t)
	Y0 += 0.00003366302*np.cos(6.13299715431 + 437.6438911399*t)
	Y0 += 0.00002773819*np.cos(5.61593446938 + 203.7378678824*t)
	Y0 += 0.00002637903*np.cos(3.83678037157 + 288.0806940053*t)
	Y0 += 0.00002531663*np.cos(3.52630260061 + 628.8515860501*t)
	Y0 += 0.00002520223*np.cos(3.89344117733 + 138.5174968707*t)
	Y0 += 0.00002620709*np.cos(0.69738696032 + 127.4717966068*t)
	Y0 += 0.00002913908*np.cos(2.58991935570 + 1066.49547719*t)
	Y0 += 0.00002501957*np.cos(6.19958027393 + 9.5612275556*t)
	Y0 += 0.00002449132*np.cos(0.54252658898 + 1155.361157407*t)
	Y0 += 0.00002428822*np.cos(2.39939798580 + 222.8603229936*t)
	Y0 += 0.00003138264*np.cos(5.63040781132 + 1368.660252845*t)
	Y0 += 0.00002268608*np.cos(2.12403236555 + 430.5303441391*t)
	Y0 += 0.00002077451*np.cos(1.95682583751 + 423.4167971383*t)
	Y0 += 0.00002670260*np.cos(0.18164077956 + 3.1813937377*t)
	Y0 += 0.00002339111*np.cos(4.29619046322 + 388.4651552382*t)
	Y0 += 0.00001636695*np.cos(2.97402097142 + 12.5301729722*t)
	Y0 += 0.00002127828*np.cos(0.42532134789 + 1.4844727083*t)
	Y0 += 0.00001638713*np.cos(0.62823227849 + 212.7778305762*t)
	Y0 += 0.00001633768*np.cos(1.12043073218 + 213.8203602998*t)
	Y0 += 0.00001499907*np.cos(5.16859292196 + 52.6901980395*t)
	Y0 += 0.00001462490*np.cos(4.35286393311 + 429.7795846137*t)
	Y0 += 0.00001640707*np.cos(2.04694637546 + 949.1756089698*t)
	Y0 += 0.00001539780*np.cos(3.21449237414 + 860.3099287528*t)
	Y0 += 0.00001436654*np.cos(3.84293514986 + 350.3321196004*t)
	Y0 += 0.00001276111*np.cos(2.98754780759 + 340.7708920448*t)
	Y0 += 0.00001151687*np.cos(1.78618989351 + 942.062061969*t)
	Y0 += 0.00001112304*np.cos(5.19114179785 + 234.6397364404*t)
	Y0 += 0.00001011157*np.cos(0.27252410682 + 1471.7530270636*t)
	Y0 += 0.00001162485*np.cos(2.35044095493 + 200.7689224658*t)
	Y0 += 0.00001090717*np.cos(4.25638263020 + 362.8622925726*t)
	Y0 += 0.00001090434*np.cos(5.85087641969 + 173.9422195228*t)
	Y0 += 0.00001186448*np.cos(5.38322854424 + 1685.0521225016*t)
	Y0 += 0.00000870118*np.cos(1.66373572799 + 210.3783341312*t)
	Y0 += 0.00001120498*np.cos(1.89478747163 + 703.6331846174*t)
	Y0 += 0.00000868567*np.cos(0.08028652697 + 216.2198567448*t)
	Y0 += 0.00001013844*np.cos(1.37562258871 + 1059.3819301892*t)
	Y0 += 0.00000831751*np.cos(5.29292222262 + 212.5483359126*t)
	Y0 += 0.00000877776*np.cos(4.33786393079 + 1162.4747044078*t)
	Y0 += 0.00000825614*np.cos(2.73629728926 + 214.0498549634*t)
	Y0 += 0.00000880691*np.cos(6.17829958739 + 209.106309744*t)
	Y0 += 0.00000867374*np.cos(1.84353750811 + 217.491881132*t)
	Y0 += 0.00000789522*np.cos(4.95200793900 + 223.5940361765*t)
	Y0 += 0.00000791369*np.cos(1.11551985110 + 515.463871093*t)
	Y0 += 0.00001009165*np.cos(5.79971867848 + 225.8292684102*t)
	Y0 += 0.00000852124*np.cos(3.77491223629 + 88.865680217*t)
	Y0 += 0.00000919472*np.cos(3.29103760893 + 565.1156877467*t)
	Y0 += 0.00000861649*np.cos(2.13214744203 + 252.6559713532*t)
	Y0 += 0.00000708486*np.cos(1.01110734990 + 1265.5674786264*t)
	Y0 += 0.00000935830*np.cos(2.78325753863 + 302.164775655*t)
	Y0 += 0.00000711355*np.cos(1.83909716516 + 417.0369633204*t)
	Y0 += 0.00000918453*np.cos(3.00605070326 + 563.6312150384*t)
	Y0 += 0.00000714225*np.cos(5.61336708759 + 207.6700211455*t)
	Y0 += 0.00000689910*np.cos(0.31593971773 + 956.2891559706*t)
	Y0 += 0.00000795680*np.cos(0.44249478599 + 207.8824694666*t)
	Y0 += 0.00000664618*np.cos(0.18239901113 + 479.2883889155*t)
	Y0 += 0.00000770609*np.cos(1.32128908448 + 218.7157214094*t)
	Y0 += 0.00000693519*np.cos(2.40549687947 + 218.9281697305*t)
	Y0 += 0.00000799557*np.cos(6.06693539047 + 22.0914005278*t)
	Y0 += 0.00000836402*np.cos(1.39153503044 + 160.6088973985*t)
	Y0 += 0.00000740023*np.cos(6.27814822867 + 728.762966531*t)
	Y0 += 0.00000786033*np.cos(1.68340995597 + 36.6485629295*t)
	Y0 += 0.00000593930*np.cos(1.31626642695 + 265.9892934775*t)
	Y0 += 0.00000764611*np.cos(0.14564177629 + 21.3406410024*t)
	Y0 += 0.00000732406*np.cos(2.65496529583 + 39.6175083461*t)
	Y0 += 0.00000581076*np.cos(2.38876104918 + 554.0699874828*t)
	Y0 += 0.00000628971*np.cos(1.22828907220 + 18.1592472647*t)
	Y0 += 0.00000701996*np.cos(1.97471012595 + 62.2514255951*t)
	Y0 += 0.00000698415*np.cos(5.28262978122 + 124.433415221*t)
	Y0 += 0.00000614285*np.cos(2.85212173127 + 217.964961884*t)
	Y0 += 0.00000667726*np.cos(1.25225064585 + 425.1137181677*t)
	Y0 += 0.00000581211*np.cos(0.50782226422 + 231.4583427027*t)
	Y0 += 0.00000520195*np.cos(5.09622319954 + 414.0680179038*t)
	Y0 += 0.00000519835*np.cos(1.70911972460 + 99.1606209555*t)
	Y0 += 0.00000500890*np.cos(1.47883812751 + 1258.4539316256*t)
	Y0 += 0.00000533532*np.cos(0.96174816662 + 214.7835681463*t)
	Y0 += 0.00000483116*np.cos(0.91735857148 + 408.4389436113*t)
	Y0 += 0.00000630240*np.cos(2.95599903199 + 65.2203710117*t)
	Y0 += 0.00000553256*np.cos(5.17631306517 + 208.633228992*t)
	Y0 += 0.00000465386*np.cos(3.05786362626 + 203.0041546995*t)
	Y0 += 0.00000528655*np.cos(0.65909127520 + 211.8146227297*t)
	Y0 += 0.00000465526*np.cos(3.83793669928 + 654.1243803156*t)
	Y0 += 0.00000503180*np.cos(2.80008494039 + 251.4321310758*t)
	Y0 += 0.00000443674*np.cos(0.00736496644 + 1788.1448967202*t)
	Y0 += 0.00000447116*np.cos(4.18006136527 + 1478.8665740644*t)
	Y0 += 0.00000398382*np.cos(0.07909774752 + 213.4109700226*t)
	Y0 += 0.00000398382*np.cos(1.66925524906 + 213.1872208534*t)
	Y0 += 0.00000383114*np.cos(2.20178796576 + 148.0787244263*t)
	Y0 += 0.00000473403*np.cos(5.14050822265 + 2001.4439921582*t)
	Y0 += 0.00000358919*np.cos(4.93878023673 + 2.4476805548*t)
	Y0 += 0.00000379588*np.cos(0.56608330947 + 1581.959348283*t)
	Y0 += 0.00000464877*np.cos(1.45312694666 + 142.4496501338*t)
	Y0 += 0.00000465852*np.cos(5.01110520258 + 73.297125859*t)
	Y0 += 0.00000341585*np.cos(3.45264409045 + 198.321241911*t)
	Y0 += 0.00000433316*np.cos(3.20558404998 + 312.1990839626*t)
	Y0 += 0.00000350436*np.cos(1.14513501672 + 98.8999885246*t)
	Y0 += 0.00000334759*np.cos(2.28889729136 + 213.0866471169*t)
	Y0 += 0.00000334759*np.cos(5.74264101239 + 213.5115437591*t)
	Y0 += 0.00000357143*np.cos(5.33211408348 + 175.1660598002*t)
	Y0 += 0.00000367605*np.cos(4.36445046507 + 750.1036075334*t)
	Y0 += 0.00000319024*np.cos(4.57593199965 + 228.276948965*t)
	Y0 += 0.00000312590*np.cos(0.96110658139 + 831.8557407496*t)
	Y0 += 0.00000367994*np.cos(3.75097201641 + 151.0476698429*t)
	Y0 += 0.00000420699*np.cos(5.61788853488 + 70.8494453042*t)
	Y0 += 0.00000306586*np.cos(4.93996479979 + 195.1398481733*t)
	Y0 += 0.00000384780*np.cos(4.14880260454 + 56.6223513026*t)
	Y0 += 0.00000400030*np.cos(2.71207125945 + 177.8743727859*t)
	Y0 += 0.00000327733*np.cos(2.69309432564 + 191.9584544356*t)
	Y0 += 0.00000273993*np.cos(5.98830026684 + 278.5194664497*t)
	Y0 += 0.00000270202*np.cos(3.57098211820 + 635.9651330509*t)
	Y0 += 0.00000336412*np.cos(3.29741235332 + 114.1384744825*t)
	Y0 += 0.00000269943*np.cos(0.56914501964 + 327.4375699205*t)
	Y0 += 0.00000265070*np.cos(4.06900450863 + 205.2223405907*t)
	Y0 += 0.00000348765*np.cos(5.33112172130 + 248.7238180901*t)
	Y0 += 0.00000296845*np.cos(6.22357485953 + 10.2949407385*t)
	Y0 += 0.00000251697*np.cos(1.64343434992 + 213.0384630071*t)
	Y0 += 0.00000251697*np.cos(0.10491824010 + 213.5597278689*t)
	Y0 += 0.00000253052*np.cos(2.67224328276 + 404.5067903482*t)
	Y0 += 0.00000307227*np.cos(5.83295899287 + 483.2205421786*t)
	Y0 += 0.00000236975*np.cos(1.18670995540 + 1574.8458012822*t)
	Y0 += 0.00000269443*np.cos(6.09247842409 + 1045.1548361876*t)
	Y0 += 0.00000251354*np.cos(5.49027488511 + 191.2076949102*t)
	Y0 += 0.00000241019*np.cos(4.17629516581 + 221.3758502853*t)
	Y0 += 0.00000247351*np.cos(4.14967259359 + 275.5505210331*t)
	Y0 += 0.00000221337*np.cos(4.74937289683 + 543.9180590962*t)
	Y0 += 0.00000292774*np.cos(2.29160155390 + 424.1505103212*t)
	Y0 += 0.00000273849*np.cos(0.48976257091 + 106.2741679563*t)
	Y0 += 0.00000237397*np.cos(3.38925999152 + 235.3904959658*t)
	Y0 += 0.00000206826*np.cos(2.89687953034 + 842.1506814881*t)
	Y0 += 0.00000232878*np.cos(1.32938721664 + 39.3568759152*t)
	Y0 += 0.00000269270*np.cos(1.92392937845 + 121.2520214833*t)
	Y0 += 0.00000202662*np.cos(6.03169886301 + 2104.5367663768*t)
	Y0 += 0.00000230906*np.cos(2.46511266784 + 497.4476361802*t)
	Y0 += 0.00000218872*np.cos(0.86295345782 + 8.0767548473*t)
	Y0 += 0.00000203946*np.cos(1.38528238326 + 284.1485407422*t)
	Y0 += 0.00000216481*np.cos(4.58190569482 + 429.0458714308*t)
	Y0 += 0.00000240544*np.cos(0.08933614222 + 269.9214467406*t)
	Y0 += 0.00000212434*np.cos(5.38637581028 + 650.9429865779*t)
	Y0 += 0.00000236820*np.cos(2.00313603940 + 219.4494345923*t)
	Y0 += 0.00000214707*np.cos(1.40555033199 + 425.6349830295*t)
	Y0 += 0.00000197040*np.cos(0.24444641123 + 1898.3512179396*t)
	Y0 += 0.00000190659*np.cos(2.72280889899 + 355.7487455718*t)
	Y0 += 0.00000173751*np.cos(1.72051113398 + 426.6463749858*t)
	Y0 += 0.00000169750*np.cos(3.20987625429 + 501.3797894433*t)
	Y0 += 0.00000173746*np.cos(4.80590161850 + 426.5500067662*t)
	Y0 += 0.00000168051*np.cos(5.46526862654 + 312.4597163935*t)
	Y0 += 0.00000180566*np.cos(3.84758143637 + 1795.258443721*t)
	Y0 += 0.00000182549*np.cos(5.95923923503 + 210.5907824523*t)
	Y0 += 0.00000181549*np.cos(1.50539014714 + 84.3428261229*t)
	Y0 += 0.00000179528*np.cos(2.07197179284 + 216.0074084237*t)
	Y0 += 0.00000188571*np.cos(2.33544585541 + 618.5566453116*t)
	Y0 += 0.00000186121*np.cos(5.22455005386 + 427.5613987225*t)
	Y0 += 0.00000196312*np.cos(4.90432953947 + 2317.8358618148*t)
	Y0 += 0.00000198340*np.cos(3.69541361584 + 488.8496164711*t)
	Y0 += 0.00000151676*np.cos(2.56675310055 + 213.4591541324*t)
	Y0 += 0.00000151676*np.cos(5.46446571963 + 213.1390367436*t)
	Y0 += 0.00000151429*np.cos(2.33434011196 + 220.4608265486*t)
	Y0 += 0.00000151827*np.cos(1.89597975094 + 1375.7737998458*t)
	Y0 += 0.00000167545*np.cos(1.83420005749 + 1279.794572628*t)
	Y0 += 0.00000190528*np.cos(6.02427347834 + 207.1487562837*t)
	Y0 += 0.00000180421*np.cos(4.76213875112 + 491.8185618877*t)
	Y0 += 0.00000180390*np.cos(1.05469577674 + 344.7030453079*t)
	Y0 += 0.00000146615*np.cos(5.44168799419 + 220.364458329*t)
	Y0 += 0.00000194447*np.cos(2.62404840122 + 188.9200730498*t)
	Y0 += 0.00000136976*np.cos(0.70428757869 + 1148.2476104062*t)
	Y0 += 0.00000185075*np.cos(3.55365539139 + 601.7642506762*t)
	Y0 += 0.00000158868*np.cos(1.84813378152 + 179.3588454942*t)
	Y0 += 0.00000145472*np.cos(1.21853593658 + 636.7158925763*t)
	Y0 += 0.00000155991*np.cos(3.42111288262 + 289.5651667136*t)
	Y0 += 0.00000159449*np.cos(3.96675364143 + 358.9301393095*t)
	Y0 += 0.00000138962*np.cos(1.62828990596 + 436.1594184316*t)
	Y0 += 0.00000174048*np.cos(5.38802135330 + 237.6781178262*t)
	Y0 += 0.00000125284*np.cos(1.76243276586 + 643.8294395771*t)
	Y0 += 0.00000131798*np.cos(0.93003850215 + 212.0270710508*t)
	Y0 += 0.00000147344*np.cos(1.52448539161 + 617.8058857862*t)
	Y0 += 0.00000130710*np.cos(0.81771148871 + 214.5711198252*t)
	Y0 += 0.00000123423*np.cos(0.17360907837 + 621.7380390493*t)
	Y0 += 0.00000132653*np.cos(4.08171658773 + 4.665866446*t)
	Y0 += 0.00000116763*np.cos(0.03834317084 + 113.3877149571*t)
	Y0 += 0.00000117597*np.cos(0.90279986158 + 1891.2376709388*t)
	Y0 += 0.00000115112*np.cos(3.65333095084 + 5.6290742925*t)
	Y0 += 0.00000112534*np.cos(5.68635818339 + 206.1373643274*t)
	Y0 += 0.00000128649*np.cos(6.16927510347 + 247.2393453818*t)
	Y0 += 0.00000112709*np.cos(3.87456537063 + 114.3991069134*t)
	Y0 += 0.00000111075*np.cos(4.41850119615 + 107.0249274817*t)
	Y0 += 0.00000114394*np.cos(5.42454880430 + 32.2433289144*t)
	Y0 += 0.00000106221*np.cos(0.24090572807 + 767.3690829208*t)
	Y0 += 0.00000126251*np.cos(2.79961544501 + 181.0557665236*t)
	Y0 += 0.00000102514*np.cos(5.96313041202 + 0.9632078465*t)
	Y0 += 0.00000107636*np.cos(2.57069606934 + 206.233732547*t)
	Y0 += 0.00000120584*np.cos(0.17406709675 + 342.2553647531*t)
	Y0 += 0.00000134800*np.cos(1.20576280285 + 35.4247226521*t)
	Y0 += 0.00000105828*np.cos(6.16888247845 + 219.891377577*t)
	Y0 += 0.00000095115*np.cos(3.59922461581 + 643.0786800517*t)
	Y0 += 0.00000103878*np.cos(2.46322510423 + 1073.6090241908*t)
	Y0 += 0.00000099528*np.cos(6.13536812132 + 426.0769260142*t)
	Y0 += 0.00000104663*np.cos(5.88419995684 + 1361.5467058442*t)
	Y0 += 0.00000094747*np.cos(5.77564110292 + 2420.9286360334*t)
	Y0 += 0.00000095620*np.cos(4.45357940681 + 447.9388318784*t)
	Y0 += 0.00000130015*np.cos(5.07630034396 + 245.5424243524*t)
	Y0 += 0.00000101365*np.cos(6.23985111882 + 2214.7430875962*t)
	Y0 += 0.00000088342*np.cos(4.76346651574 + 87.3117715395*t)
	Y0 += 0.00000090300*np.cos(2.86774410339 + 525.4981794006*t)
	Y0 += 0.00000090513*np.cos(5.66908341298 + 92.0470739547*t)
	Y0 += 0.00000092409*np.cos(0.90702124100 + 78.7137518304*t)
	Y0 += 0.00000081847*np.cos(1.67799021003 + 20.6069278195*t)
	Y0 += 0.00000091321*np.cos(0.36728160716 + 427.1194557378*t)
	Y0 += 0.00000080705*np.cos(1.93891112794 + 320.3240229197*t)
	Y0 += 0.00000091143*np.cos(2.01894680272 + 206.706813299*t)
	Y0 += 0.00000097745*np.cos(6.23005888799 + 4.192785694*t)
	Y0 += 0.00000079749*np.cos(3.26351898499 + 159.1244246902*t)
	Y0 += 0.00000100221*np.cos(1.98574874715 + 140.001969579*t)
	Y0 += 0.00000077990*np.cos(1.66809322351 + 14.0146456805*t)
	Y0 += 0.00000076329*np.cos(5.90195594455 + 543.0242872189*t)
	Y0 += 0.00000074957*np.cos(4.60768341839 + 420.9691165835*t)
	Y0 += 0.00000077269*np.cos(2.80019747431 + 67.6680515665*t)
	Y0 += 0.00000080180*np.cos(1.76473699777 + 125.9873238985*t)
	Y0 += 0.00000071100*np.cos(0.89129238653 + 630.3360587584*t)
	Y0 += 0.00000076008*np.cos(4.57174101646 + 134.5853436076*t)
	Y0 += 0.00000076857*np.cos(4.88095052633 + 692.5874843535*t)
	Y0 += 0.00000069326*np.cos(4.40670817988 + 212.0752551606*t)
	Y0 += 0.00000069326*np.cos(3.62451064029 + 214.5229357154*t)
	Y0 += 0.00000076210*np.cos(1.91960721245 + 934.9485149682*t)
	Y0 += 0.00000071701*np.cos(3.46497359389 + 2111.6503133776*t)
	Y0 += 0.00000085047*np.cos(3.18774989859 + 54.1746707478*t)
	Y0 += 0.00000081906*np.cos(0.02823325050 + 353.301065017*t)
	Y0 += 0.00000091385*np.cos(2.24806332628 + 776.9303104764*t)
	Y0 += 0.00000083341*np.cos(4.67038022346 + 2634.2277314714*t)
	Y0 += 0.00000086493*np.cos(1.15488292363 + 916.9322800554*t)
	Y0 += 0.00000076520*np.cos(5.70422944555 + 144.1465711632*t)
	Y0 += 0.00000083998*np.cos(1.30453941538 + 69.1525242748*t)
	Y0 += 0.00000066684*np.cos(0.76966880509 + 423.6774295692*t)
	Y0 += 0.00000064747*np.cos(4.57928856242 + 128.9562693151*t)
	Y0 += 0.00000070850*np.cos(4.61521587231 + 211.6021744086*t)
	Y0 += 0.00000065595*np.cos(3.23651495782 + 6.1503391543*t)
	Y0 += 0.00000064137*np.cos(0.44216461549 + 1464.6394800628*t)
	Y0 += 0.00000075789*np.cos(2.72257817752 + 153.4953503977*t)
	Y0 += 0.00000063366*np.cos(4.99065911889 + 184.9879197867*t)
	Y0 += 0.00000073570*np.cos(6.14451890498 + 286.596221297*t)
	Y0 += 0.00000064126*np.cos(1.30105389213 + 2.9207613068*t)
	Y0 += 0.00000073235*np.cos(0.30668196860 + 1272.6810256272*t)
	Y0 += 0.00000061422*np.cos(4.93336864703 + 267.4737661858*t)
	Y0 += 0.00000078591*np.cos(5.90644184590 + 46.470422916*t)
	Y0 += 0.00000070325*np.cos(4.73999009945 + 337.732510659*t)
	Y0 += 0.00000067029*np.cos(2.10509391932 + 33.9402499438*t)
	Y0 += 0.00000059139*np.cos(6.25938993884 + 51.2057253312*t)
	Y0 += 0.00000059935*np.cos(0.62832430985 + 2207.6295405954*t)
	Y0 += 0.00000063494*np.cos(0.80826123304 + 391.1734682239*t)
	Y0 += 0.00000059971*np.cos(5.45076407738 + 182.279606801*t)
	Y0 += 0.00000076232*np.cos(4.60147129724 + 299.1263942692*t)
	Y0 += 0.00000066001*np.cos(2.50975335235 + 778.4147831847*t)
	Y0 += 0.00000066705*np.cos(0.99016626571 + 220.9339073006*t)
	Y0 += 0.00000065833*np.cos(1.74010602145 + 416.3032501375*t)
	Y0 += 0.00000055245*np.cos(4.21009430774 + 436.8931316145*t)
	Y0 += 0.00000061866*np.cos(0.96601636837 + 14.977853527*t)
	Y0 += 0.00000066195*np.cos(4.88980737223 + 696.5196376166*t)
	Y0 += 0.00000068948*np.cos(6.02250542420 + 305.3461693927*t)
	Y0 += 0.00000054609*np.cos(0.00793727320 + 387.2413149608*t)
	Y0 += 0.00000059022*np.cos(3.40769037534 + 214.9960164674*t)
	Y0 += 0.00000054036*np.cos(4.61708325976 + 627.3671133418*t)
	Y0 += 0.00000070977*np.cos(4.86234954710 + 487.3651437628*t)
	Y0 += 0.00000063311*np.cos(3.50812337721 + 576.1613880106*t)
	Y0 += 0.00000066791*np.cos(4.95921724777 + 116.4260963429*t)
	Y0 += 0.00000052982*np.cos(2.94521665287 + 241.6102710893*t)
	Y0 += 0.00000054244*np.cos(1.77761196480 + 329.7251917809*t)
	Y0 += 0.00000064685*np.cos(4.11817037305 + 421.93232443*t)
	Y0 += 0.00000066198*np.cos(6.25266954481 + 1169.5882514086*t)
	Y0 += 0.00000053229*np.cos(4.09328383786 + 292.0128472684*t)
	Y0 += 0.00000056864*np.cos(6.02030048296 + 444.7574381407*t)
	Y0 += 0.00000050139*np.cos(0.33981792989 + 7.065362891*t)
	Y0 += 0.00000050427*np.cos(3.58218487728 + 211.8628068395*t)
	Y0 += 0.00000050427*np.cos(4.44903394289 + 214.7353840365*t)
	Y0 += 0.00000052408*np.cos(2.49871082273 + 282.4516197128*t)
	Y0 += 0.00000052915*np.cos(3.66309570535 + 199.2844497575*t)
	Y0 += 0.00000055592*np.cos(3.43165296192 + 221.1634019642*t)
	Y0 += 0.00000047715*np.cos(5.10534935586 + 219.6618829134*t)
	Y0 += 0.00000056847*np.cos(0.97741250258 + 418.5214360287*t)
	Y0 += 0.00000059393*np.cos(5.04777216540 + 439.1283638482*t)
	Y0 += 0.00000049622*np.cos(1.07397902514 + 430.79097657*t)
	Y0 += 0.00000048678*np.cos(1.59398431827 + 96.8729990951*t)
	Y0 += 0.00000048710*np.cos(5.60640836585 + 429.5189521828*t)
	Y0 += 0.00000046209*np.cos(4.54083648481 + 425.8474313506*t)
	Y0 += 0.00000051493*np.cos(5.97425873524 + 2531.1349572528*t)
	Y0 += 0.00000051412*np.cos(5.76661298592 + 518.6452648307*t)
	Y0 += 0.00000047005*np.cos(2.61649558438 + 31.019488637*t)
	Y0 += 0.00000045618*np.cos(5.66704236554 + 273.1028404783*t)
	Y0 += 0.00000044467*np.cos(5.53037319900 + 2737.32050569*t)
	Y0 += 0.00000055947*np.cos(0.51535719965 + 638.4128136057*t)
	Y0 += 0.00000042519*np.cos(2.70084502599 + 5.4166259714*t)
	Y0 += 0.00000042505*np.cos(5.31459145594 + 421.1815649046*t)
	Y0 += 0.00000048382*np.cos(3.51641445336 + 7.1617311106*t)
	Y0 += 0.00000042004*np.cos(0.91254981055 + 280.9671470045*t)
	Y0 += 0.00000041851*np.cos(2.36099631927 + 244.318584075*t)
	Y0 += 0.00000052538*np.cos(4.47099895134 + 205.4347889118*t)
	Y0 += 0.00000041378*np.cos(3.38701415728 + 59.8037450403*t)
	Y0 += 0.00000041254*np.cos(4.01431999731 + 120.358249606*t)
	Y0 += 0.00000046802*np.cos(0.01622711468 + 558.0021407459*t)
	Y0 += 0.00000052883*np.cos(2.83931668083 + 166.828672522*t)
	Y0 += 0.00000041956*np.cos(5.69540610025 + 1677.9385755008*t)
	Y0 += 0.00000050113*np.cos(1.81016163546 + 6.592282139*t)
	Y0 += 0.00000045107*np.cos(4.49380088938 + 227.3137411185*t)
	Y0 += 0.00000045964*np.cos(0.75454904800 + 205.6642835754*t)
	Y0 += 0.00000046355*np.cos(1.53774731019 + 432.2272651685*t)
	Y0 += 0.00000037172*np.cos(2.93645417223 + 206.9363079626*t)
	Y0 += 0.00000044659*np.cos(5.38536280774 + 2.9689454166*t)
	Y0 += 0.00000036628*np.cos(2.09707542805 + 427.3489504014*t)
	Y0 += 0.00000045029*np.cos(0.46131983164 + 428.0826635843*t)
	Y0 += 0.00000038453*np.cos(4.42450266346 + 209.1544938538*t)
	Y0 += 0.00000040433*np.cos(5.16219115737 + 233.9060232575*t)
	Y0 += 0.00000037471*np.cos(3.60681221764 + 217.4436970222*t)
	Y0 += 0.00000046113*np.cos(5.55096889463 + 212.4053235607*t)
	Y0 += 0.00000046113*np.cos(2.48024992554 + 214.1928673153*t)
	Y0 += 0.00000036077*np.cos(3.08476346783 + 867.4234757536*t)
	Y0 += 0.00000037160*np.cos(3.14289320760 + 41.6444977756*t)
	Y0 += 0.00000037350*np.cos(1.63735841154 + 1251.3403846248*t)
	Y0 += 0.00000035072*np.cos(6.23912039279 + 181.806526049*t)
	Y0 += 0.00000039215*np.cos(4.12162482146 + 28.3111756513*t)
	Y0 += 0.00000036956*np.cos(5.98933325919 + 77.7505439839*t)
	Y0 += 0.00000039775*np.cos(4.04549743419 + 339.2864193365*t)
	Y0 += 0.00000037635*np.cos(1.44659682623 + 347.8844390456*t)
	Y0 += 0.00000045853*np.cos(3.13205357665 + 192.6921676185*t)
	Y0 += 0.00000039323*np.cos(3.20138954128 + 756.3233826569*t)
	Y0 += 0.00000039910*np.cos(2.04686718372 + 1692.1656695024*t)
	Y0 += 0.00000044137*np.cos(5.48321215590 + 135.5485514541*t)
	Y0 += 0.00000034157*np.cos(3.94135052425 + 81.7521332162*t)
	Y0 += 0.00000032207*np.cos(1.93681169587 + 313.2104759189*t)
	Y0 += 0.00000036698*np.cos(2.11524812183 + 431.264057322*t)
	Y0 += 0.00000031105*np.cos(0.18786474496 + 1781.0313497194*t)
	Y0 += 0.00000031230*np.cos(0.23280228607 + 405.9912630565*t)
	Y0 += 0.00000037384*np.cos(4.45699108315 + 319.5732633943*t)
	Y0 += 0.00000039779*np.cos(4.74985208556 + 738.7972748386*t)
	Y0 += 0.00000035892*np.cos(4.44540281948 + 2950.619601128*t)
	Y0 += 0.00000039342*np.cos(0.62472997033 + 373.9079928365*t)
	Y0 += 0.00000029650*np.cos(3.37204650277 + 274.0660483248*t)
	Y0 += 0.00000031782*np.cos(4.13370262314 + 24.3790223882*t)
	Y0 += 0.00000030193*np.cos(0.35423807736 + 2524.021410252*t)
	Y0 += 0.00000031118*np.cos(1.69116341490 + 465.9550667912*t)
	Y0 += 0.00000029441*np.cos(3.03544092290 + 2428.0421830342*t)
	Y0 += 0.00000029292*np.cos(4.61105433395 + 131.5469622218*t)
	Y0 += 0.00000038807*np.cos(4.79007536474 + 145.6310438715*t)
	Y0 += 0.00000028756*np.cos(4.87076509051 + 192.8522263129*t)
	Y0 += 0.00000031497*np.cos(4.15219792180 + 468.2426886516*t)
	Y0 += 0.00000034699*np.cos(1.27595242408 + 381.3516082374*t)
	Y0 += 0.00000027274*np.cos(2.45030050983 + 60.7669528868*t)
	Y0 += 0.00000027836*np.cos(5.88920583793 + 216.2680408546*t)
	Y0 += 0.00000034964*np.cos(4.96686863310 + 23.5758732361*t)
	Y0 += 0.00000027991*np.cos(4.95642453415 + 525.7588118315*t)
	Y0 += 0.00000028750*np.cos(6.23126382059 + 333.657345044*t)
	Y0 += 0.00000027255*np.cos(1.69447975245 + 244.791664827*t)
	Y0 += 0.00000029305*np.cos(1.98340428594 + 464.7312265138*t)
	Y0 += 0.00000031737*np.cos(2.99242362906 + 0.7507595254*t)
	Y0 += 0.00000027051*np.cos(1.35484538064 + 361.3778198643*t)
	Y0 += 0.00000034058*np.cos(1.75751565147 + 405.2575498736*t)
	Y0 += 0.00000033607*np.cos(4.20725171012 + 395.578702239*t)
	Y0 += 0.00000026325*np.cos(2.16951933975 + 0.5212648618*t)
	Y0 += 0.00000032004*np.cos(3.05644356241 + 35.1640902212*t)
	Y0 += 0.00000027057*np.cos(2.08658456308 + 210.3301500214*t)
	Y0 += 0.00000026627*np.cos(1.22485059499 + 681.5417840896*t)
	Y0 += 0.00000029985*np.cos(1.75140772777 + 710.7467316182*t)
	Y0 += 0.00000029611*np.cos(3.03563269574 + 295.0512286542*t)
	Y0 += 0.00000025305*np.cos(3.16045424330 + 233.7459645631*t)
	Y0 += 0.00000026679*np.cos(5.17299701811 + 494.2662424425*t)
	Y0 += 0.00000025384*np.cos(3.22791759769 + 16.6747745564*t)
	Y0 += 0.00000025196*np.cos(0.12107682753 + 412.5835451955*t)
	Y0 += 0.00000034215*np.cos(5.10822596181 + 259.769518354*t)
	Y0 += 0.00000033250*np.cos(0.30954521223 + 162.0933701068*t)
	Y0 += 0.00000025742*np.cos(1.25888857316 + 477.8039162072*t)
	Y0 += 0.00000029765*np.cos(4.52626132577 + 129.9194771616*t)
	Y0 += 0.00000025034*np.cos(4.88552569459 + 420.4478517217*t)
	Y0 += 0.00000026200*np.cos(2.20762141616 + 45.5766510387*t)
	Y0 += 0.00000023913*np.cos(3.85751439026 + 162.8965192589*t)
	Y0 += 0.00000023970*np.cos(2.34887571453 + 264.5048207692*t)
	Y0 += 0.00000033556*np.cos(3.87396335885 + 27.0873353739*t)
	Y0 += 0.00000027190*np.cos(3.46933216009 + 214.9436268407*t)
	Y0 += 0.00000027190*np.cos(4.56188666009 + 211.6545640353*t)
	Y0 += 0.00000025644*np.cos(2.29213712683 + 229.9738699944*t)
	Y0 += 0.00000029006*np.cos(5.94908879891 + 454.9093665273*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000023511*np.cos(5.11817349516 + 212.4959462859*t)
	Y0 += 0.00000023511*np.cos(2.91304532501 + 214.1022445901*t)
	Y0 += 0.00000023833*np.cos(6.14424686939 + 422.405405182*t)
	Y0 += 0.00000025612*np.cos(1.72388920925 + 411.620337349*t)
	Y0 += 0.00000025496*np.cos(5.69074258555 + 2847.5268269094*t)
	Y0 += 0.00000022472*np.cos(2.15633918584 + 7.6348118626*t)
	Y0 += 0.00000026222*np.cos(2.80143128349 + 31.492569389*t)
	Y0 += 0.00000022198*np.cos(0.91804268520 + 426.4863162914*t)
	Y0 += 0.00000023046*np.cos(3.99493191448 + 184.7272873558*t)
	Y0 += 0.00000023226*np.cos(6.03563080998 + 207.0793203145*t)
	Y0 += 0.00000021720*np.cos(1.02524191391 + 432.0148168474*t)
	Y0 += 0.00000021569*np.cos(1.63592154899 + 224.6054281328*t)
	Y0 += 0.00000022198*np.cos(5.61107049084 + 426.7100654606*t)
	Y0 += 0.00000022961*np.cos(2.58109891107 + 92.940845832*t)
	Y0 += 0.00000022695*np.cos(6.24214736431 + 223.3334037456*t)
	Y0 += 0.00000020843*np.cos(3.43174352438 + 472.1748419147*t)
	Y0 += 0.00000022283*np.cos(1.99778424604 + 219.5188705615*t)
	Y0 += 0.00000020519*np.cos(5.28715778940 + 3053.7123753466*t)
	Y0 += 0.00000024105*np.cos(0.97906190272 + 334.5511169213*t)
	Y0 += 0.00000020030*np.cos(2.81675406065 + 849.2642284889*t)
	Y0 += 0.00000019784*np.cos(0.44865479660 + 1485.9801210652*t)
	Y0 += 0.00000019519*np.cos(1.31453508293 + 357.4456666012*t)
	Y0 += 0.00000021045*np.cos(4.00724213785 + 241.8709035202*t)
	Y0 += 0.00000021410*np.cos(0.86161640271 + 343.2185725996*t)
	Y0 += 0.00000024839*np.cos(2.65438981650 + 46.2097904851*t)
	Y0 += 0.00000022024*np.cos(1.95120216269 + 186.2117600641*t)
	Y0 += 0.00000018921*np.cos(3.45842911419 + 171.6545976624*t)
	Y0 += 0.00000018653*np.cos(4.99142844854 + 426.8106391971*t)
	Y0 += 0.00000023815*np.cos(6.02632859549 + 112.6540017742*t)
	Y0 += 0.00000018653*np.cos(1.53768472751 + 426.3857425549*t)
	Y0 += 0.00000018843*np.cos(6.17211329882 + 555.5544601911*t)
	Y0 += 0.00000019727*np.cos(6.15337850264 + 100.6450936638*t)
	Y0 += 0.00000022972*np.cos(4.85207087547 + 450.9772132642*t)
	Y0 += 0.00000023844*np.cos(4.55885748022 + 593.426863398*t)
	Y0 += 0.00000020032*np.cos(1.35662572450 + 1567.7322542814*t)
	Y0 += 0.00000019430*np.cos(0.49889379660 + 392.6579409322*t)
	Y0 += 0.00000018276*np.cos(1.17948262732 + 508.3503240922*t)
	Y0 += 0.00000023767*np.cos(4.50296212000 + 462.0229135281*t)
	Y0 += 0.00000019372*np.cos(0.24140775392 + 831.1049812242*t)
	Y0 += 0.00000021013*np.cos(2.13939539715 + 402.2191684878*t)
	Y0 += 0.00000018535*np.cos(5.57136714221 + 546.956440482*t)
	Y0 += 0.00000019726*np.cos(3.64855444024 + 963.4027029714*t)
	Y0 += 0.00000022398*np.cos(6.21091779253 + 556.5176680376*t)
	Y0 += 0.00000017812*np.cos(4.67876860218 + 460.5384408198*t)
	Y0 += 0.00000020404*np.cos(1.44835454438 + 458.8415197904*t)
	Y0 += 0.00000017127*np.cos(1.42593326651 + 419.532827985*t)
	Y0 += 0.00000023833*np.cos(2.58926520909 + 141.2258098564*t)
	Y0 += 0.00000018879*np.cos(3.13780715639 + 572.2292347475*t)
	Y0 += 0.00000018098*np.cos(4.67997866940 + 230.7075831773*t)
	Y0 += 0.00000020564*np.cos(1.73670066361 + 156.6767441354*t)
	Y0 += 0.00000016722*np.cos(2.18699356364 + 1055.4497769261*t)
	Y0 += 0.00000018221*np.cos(1.66360953902 + 561.1835344836*t)
	Y0 += 0.00000017235*np.cos(5.69642460408 + 254.9435932136*t)
	Y0 += 0.00000017269*np.cos(4.52531012357 + 199.9657733137*t)
	Y0 += 0.00000017264*np.cos(3.70601205694 + 295.1942410061*t)
	Y0 += 0.00000020777*np.cos(1.66799856647 + 175.4266922311*t)
	Y0 += 0.00000016444*np.cos(4.28983295170 + 263.7016716171*t)
	Y0 += 0.00000018781*np.cos(6.05523756391 + 240.3864308119*t)
	Y0 += 0.00000018297*np.cos(0.74893263028 + 533.6231183577*t)
	Y0 += 0.00000022334*np.cos(2.49164712100 + 423.6292454594*t)
	Y0 += 0.00000019518*np.cos(0.10849262421 + 71.8126531507*t)
	Y0 += 0.00000016374*np.cos(4.05318035950 + 757.2171545342*t)
	Y0 += 0.00000018861*np.cos(1.53135934768 + 66.70484372*t)
	Y0 += 0.00000022359*np.cos(5.94675603401 + 486.4019359163*t)
	Y0 += 0.00000015958*np.cos(6.18474282955 + 2097.423219376*t)
	Y0 += 0.00000021495*np.cos(1.80009954963 + 206.3979967583*t)
	Y0 += 0.00000016498*np.cos(5.52997951230 + 1994.3304451574*t)
	Y0 += 0.00000017370*np.cos(3.48286795322 + 552.5855147745*t)
	Y0 += 0.00000018321*np.cos(0.71302333930 + 50.4025761791*t)
	Y0 += 0.00000018291*np.cos(0.84252688005 + 100.3844612329*t)
	Y0 += 0.00000017455*np.cos(1.71250488224 + 905.8865797915*t)
	Y0 += 0.00000015961*np.cos(0.08620485585 + 2840.4132799086*t)
	Y0 += 0.00000018199*np.cos(2.63471966869 + 152.5321425512*t)
	Y0 += 0.00000015567*np.cos(1.54318325188 + 220.3007678542*t)
	Y0 += 0.00000016067*np.cos(3.49794734385 + 226.6324175623*t)
	Y0 += 0.00000015648*np.cos(1.56688636016 + 211.2933578679*t)
	Y0 += 0.00000015648*np.cos(0.18114715284 + 215.3048330081*t)
	Y0 += 0.00000018382*np.cos(0.18848462965 + 220.2001941177*t)
	Y0 += 0.00000018947*np.cos(1.50194389720 + 637.4496057592*t)
	Y0 += 0.00000020602*np.cos(5.47900525864 + 285.3723810196*t)
	Y0 += 0.00000016290*np.cos(4.40037017827 + 41.0537969446*t)
	Y0 += 0.00000016595*np.cos(3.19935275989 + 364.3467652809*t)
	Y0 += 0.00000017326*np.cos(1.34597087283 + 199.8057146193*t)
	Y0 += 0.00000016253*np.cos(3.43269290331 + 109.2431133729*t)
	Y0 += 0.00000016383*np.cos(1.10309267801 + 203.8979265768*t)
	Y0 += 0.00000014710*np.cos(0.56450048893 + 110.1581371096*t)
	Y0 += 0.00000015065*np.cos(4.48008314400 + 258.8757464767*t)
	Y0 += 0.00000016371*np.cos(1.11833300339 + 81.8951455681*t)
	Y0 += 0.00000016641*np.cos(4.52681352135 + 419.4364597654*t)
	Y0 += 0.00000015483*np.cos(5.00138655264 + 409.9234163196*t)
	Y0 += 0.00000014822*np.cos(0.12437161534 + 195.7729876197*t)
	Y0 += 0.00000014820*np.cos(5.69441218507 + 835.0371344873*t)
	Y0 += 0.00000018061*np.cos(2.78810034757 + 82.8583534146*t)
	Y0 += 0.00000015930*np.cos(0.61706914429 + 172.4577468145*t)
	Y0 += 0.00000015790*np.cos(1.37001454466 + 348.8476468921*t)
	Y0 += 0.00000019923*np.cos(4.18939127616 + 107.7586406646*t)
	Y0 += 0.00000015462*np.cos(0.64414979340 + 222.7002642992*t)
	Y0 += 0.00000015877*np.cos(4.20691449361 + 17.2654753874*t)
	Y0 += 0.00000014016*np.cos(5.63689121224 + 426.8588233069*t)
	Y0 += 0.00000015062*np.cos(4.17432597418 + 441.576044403*t)
	Y0 += 0.00000014016*np.cos(0.89222201489 + 426.3375584451*t)
	Y0 += 0.00000014705*np.cos(3.76205802021 + 110.2545053292*t)
	Y0 += 0.00000015302*np.cos(5.65006523821 + 980.6681783588*t)
	Y0 += 0.00000015926*np.cos(0.40206286298 + 226.7924762567*t)
	Y0 += 0.00000019008*np.cos(1.39536466934 + 72.0732855816*t)
	Y0 += 0.00000014043*np.cos(5.08109977245 + 77.962992305*t)
	Y0 += 0.00000013632*np.cos(2.31331276774 + 13.3333221243*t)
	Y0 += 0.00000015012*np.cos(6.23427543593 + 220.5245170234*t)
	Y0 += 0.00000015647*np.cos(4.22924053362 + 3267.0114707846*t)
	Y0 += 0.00000013901*np.cos(3.25076552397 + 146.594251718*t)
	Y0 += 0.00000014376*np.cos(2.59472611987 + 448.6895914038*t)
	Y0 += 0.00000018185*np.cos(3.04689762052 + 702.1487119091*t)
	Y0 += 0.00000015578*np.cos(2.79287881306 + 570.7447620392*t)
	Y0 += 0.00000016412*np.cos(1.18291299381 + 221.8971151471*t)
	Y0 += 0.00000013830*np.cos(3.43135660708 + 434.6749457233*t)
	Y0 += 0.00000018337*np.cos(4.67709417616 + 170.0100662597*t)
	Y0 += 0.00000017128*np.cos(2.65513969995 + 28.5718080822*t)
	Y0 += 0.00000016503*np.cos(0.86644103914 + 111.1695290659*t)
	Y0 += 0.00000013281*np.cos(1.62081717611 + 230.8252032563*t)
	Y0 += 0.00000012978*np.cos(5.00967719419 + 241.7532834412*t)
	Y0 += 0.00000013849*np.cos(0.56971120253 + 850.0149880143*t)
	Y0 += 0.00000015892*np.cos(2.38247604286 + 230.5645708254*t)
	Y0 += 0.00000014101*np.cos(1.45466687402 + 99.9113804809*t)
	Y0 += 0.00000013407*np.cos(0.01099066757 + 540.7366653585*t)
	Y0 += 0.00000013199*np.cos(4.38388584990 + 457.617679513*t)
	Y0 += 0.00000012620*np.cos(0.92344635694 + 131.4039498699*t)
	Y0 += 0.00000015831*np.cos(0.08492919982 + 251.1714986449*t)
	Y0 += 0.00000013957*np.cos(4.60482139712 + 864.2420820159*t)
	Y0 += 0.00000016676*np.cos(4.00720673932 + 705.1176573257*t)
	Y0 += 0.00000017279*np.cos(4.83208309701 + 569.0478410098*t)
	Y0 += 0.00000012993*np.cos(5.71458760363 + 193.655375465*t)
	Y0 += 0.00000015393*np.cos(0.15806990290 + 420.005908737*t)
	Y0 += 0.00000012381*np.cos(2.78554352136 + 380.12776796*t)
	Y0 += 0.00000012127*np.cos(2.57414102933 + 2744.4340526908*t)
	Y0 += 0.00000012577*np.cos(0.31187279533 + 238.5718897035*t)
	Y0 += 0.00000012359*np.cos(5.19894120419 + 326.6868103951*t)
	Y0 += 0.00000013217*np.cos(2.66592366261 + 188.1693135244*t)
	Y0 += 0.00000014162*np.cos(4.87830248734 + 894.8408795276*t)
	Y0 += 0.00000011557*np.cos(5.03813004128 + 280.003939158*t)
	Y0 += 0.00000014282*np.cos(4.27263941293 + 42.5382696529*t)
	Y0 += 0.00000012957*np.cos(5.40884833034 + 3163.918696566*t)
	Y0 += 0.00000011989*np.cos(4.02199963625 + 642.3449668688*t)
	Y0 += 0.00000011206*np.cos(2.55059167193 + 714.6788848813*t)
	Y0 += 0.00000011094*np.cos(3.77494369838 + 119.767548775*t)
	Y0 += 0.00000011265*np.cos(3.74313513949 + 403.0223176399*t)
	Y0 += 0.00000014433*np.cos(2.20590955504 + 386.9806825299*t)
	Y0 += 0.00000012049*np.cos(1.79618188447 + 203.2647871304*t)
	Y0 += 0.00000011058*np.cos(0.35405181917 + 17.5261078183*t)
	Y0 += 0.00000012095*np.cos(1.14547306649 + 254.1404440615*t)
	Y0 += 0.00000010842*np.cos(0.97259949349 + 639.9454704238*t)
	Y0 += 0.00000013350*np.cos(0.65575474438 + 638.9340784675*t)
	Y0 += 0.00000014697*np.cos(1.26523877234 + 432.7485300303*t)
	Y0 += 0.00000010935*np.cos(2.99474883979 + 19.1224551112*t)
	Y0 += 0.00000013741*np.cos(2.81160245841 + 815.0633461142*t)
	Y0 += 0.00000012848*np.cos(5.62672323243 + 196.0336200506*t)
	Y0 += 0.00000010879*np.cos(2.84976926802 + 820.0592809603*t)
	Y0 += 0.00000010518*np.cos(2.64349450169 + 97.6761482472*t)
	Y0 += 0.00000010570*np.cos(5.55557605599 + 606.7601855223*t)
	Y0 += 0.00000010505*np.cos(0.20513029140 + 206.2974230218*t)
	Y0 += 0.00000010385*np.cos(4.75266542249 + 196.8367692027*t)
	Y0 += 0.00000010842*np.cos(4.05799649461 + 639.8491022042*t)
	Y0 += 0.00000010315*np.cos(5.04748152372 + 3370.1042450032*t)
	Y0 += 0.00000010254*np.cos(0.18412125850 + 201.9927627432*t)
	Y0 += 0.00000010419*np.cos(2.88584157548 + 1589.0728952838*t)
	Y0 += 0.00000010891*np.cos(1.07425081751 + 1884.124123938*t)
	Y0 += 0.00000010249*np.cos(1.25494504145 + 107.2855599126*t)
	Y0 += 0.00000009860*np.cos(1.06822199204 + 526.5095713569*t)
	Y0 += 0.00000009862*np.cos(1.78722934048 + 33.1371007917*t)
	Y0 += 0.00000013735*np.cos(1.94688549102 + 2008.557539159*t)
	Y0 += 0.00000013237*np.cos(4.82102210965 + 480.7728616238*t)
	Y0 += 0.00000010908*np.cos(4.50392808100 + 186.472392495*t)
	Y0 += 0.00000009594*np.cos(1.63466155819 + 433.7599219866*t)
	Y0 += 0.00000009944*np.cos(1.10909756879 + 47.6942631934*t)
	Y0 += 0.00000010478*np.cos(0.37560099716 + 189.7232222019*t)
	Y0 += 0.00000011233*np.cos(4.51872140986 + 640.8604941605*t)
	Y0 += 0.00000009492*np.cos(3.11486993450 + 106.0135355254*t)
	Y0 += 0.00000012985*np.cos(3.33325603152 + 256.5881246163*t)
	Y0 += 0.00000009546*np.cos(0.75076951952 + 219.1406180516*t)
	Y0 += 0.00000012721*np.cos(4.26318149453 + 170.7608257851*t)
	Y0 += 0.00000009370*np.cos(3.27855373671 + 229.7614216733*t)
	Y0 += 0.00000009245*np.cos(2.21550080989 + 406.954470903*t)
	Y0 += 0.00000011067*np.cos(3.43799154852 + 240.125798381*t)
	Y0 += 0.00000009735*np.cos(4.72972824448 + 433.663553767*t)
	Y0 += 0.00000010066*np.cos(5.20819082705 + 423.8898778903*t)
	Y0 += 0.00000011401*np.cos(4.60187128385 + 172.2452984934*t)
	Y0 += 0.00000012271*np.cos(0.45950418131 + 662.531203563*t)
	Y0 += 0.00000009355*np.cos(1.53347383876 + 194.1766403268*t)
	Y0 += 0.00000010379*np.cos(5.25618033429 + 238.4288773516*t)
	Y0 += 0.00000011289*np.cos(3.24732062670 + 389.9496279465*t)
	Y0 += 0.00000008924*np.cos(6.03883665364 + 19.643719973*t)
	Y0 += 0.00000008841*np.cos(0.50392103518 + 1802.3719907218*t)
	Y0 += 0.00000010267*np.cos(4.23756855504 + 746.9222137957*t)
	Y0 += 0.00000008733*np.cos(4.67037924875 + 157.6399519819*t)
	Y0 += 0.00000010066*np.cos(1.32092240008 + 429.3065038617*t)
	Y0 += 0.00000009374*np.cos(1.79762056777 + 206.0736738526*t)
	Y0 += 0.00000009533*np.cos(2.29107827195 + 236.8749686741*t)
	Y0 += 0.00000008433*np.cos(1.81570030403 + 426.7582495704*t)
	Y0 += 0.00000010715*np.cos(4.37027632759 + 495.7507151508*t)
	Y0 += 0.00000008433*np.cos(4.71341292310 + 426.4381321816*t)
	Y0 += 0.00000009526*np.cos(3.31288975087 + 384.0599212231*t)
	Y0 += 0.00000008366*np.cos(2.89420654474 + 89.7594520943*t)
	Y0 += 0.00000008491*np.cos(6.09666431453 + 3156.8051495652*t)
	Y0 += 0.00000009436*np.cos(1.12567006222 + 1493.093668066*t)
	Y0 += 0.00000009863*np.cos(1.00498501412 + 376.1956146969*t)
	Y0 += 0.00000008903*np.cos(0.86621106611 + 649.4585138696*t)
	Y0 += 0.00000008389*np.cos(0.30076958467 + 232.4215505492*t)
	Y0 += 0.00000008246*np.cos(0.71370891617 + 194.3890886479*t)
	Y0 += 0.00000008317*np.cos(3.70830433977 + 661.2379273164*t)
	Y0 += 0.00000011199*np.cos(5.06635124052 + 395.105621487*t)
	Y0 += 0.00000011220*np.cos(5.60781396892 + 453.6855262499*t)
	Y0 += 0.00000008086*np.cos(3.34184345438 + 385.5443939314*t)
	Y0 += 0.00000008096*np.cos(1.13101164600 + 824.7421937488*t)
	Y0 += 0.00000008959*np.cos(5.65941324166 + 187.4356003415*t)
	Y0 += 0.00000008026*np.cos(2.62564001618 + 313.6835566709*t)
	Y0 += 0.00000011002*np.cos(0.34533540558 + 354.5249052944*t)
	Y0 += 0.00000008380*np.cos(1.30664256598 + 857.1285350151*t)
	Y0 += 0.00000009920*np.cos(0.28888805593 + 204.7010757289*t)
	Y0 += 0.00000008727*np.cos(2.65844044975 + 196.6243208816*t)
	Y0 += 0.00000007978*np.cos(1.68245693691 + 394.3548619616*t)
	Y0 += 0.00000007712*np.cos(5.98060890594 + 2413.8150890326*t)
	Y0 += 0.00000009112*np.cos(4.34972455215 + 167.7224443993*t)
	Y0 += 0.00000009228*np.cos(0.22253166769 + 594.6507036754*t)
	Y0 += 0.00000009889*np.cos(2.79591836728 + 29.2049475286*t)
	Y0 += 0.00000007695*np.cos(1.00995675874 + 207.4575728244*t)
	Y0 += 0.00000007998*np.cos(4.19812784482 + 255.8373650909*t)
	Y0 += 0.00000008421*np.cos(2.65464574606 + 502.8642621516*t)
	Y0 += 0.00000009658*np.cos(5.37523639564 + 380.3884003909*t)
	Y0 += 0.00000007450*np.cos(6.00758654848 + 366.7944458357*t)
	Y0 += 0.00000009590*np.cos(5.19097739834 + 343.7398374614*t)
	Y0 += 0.00000007327*np.cos(1.03432503215 + 232.2091022281*t)
	Y0 += 0.00000007358*np.cos(4.89176431480 + 449.232108125*t)
	Y0 += 0.00000007649*np.cos(5.24109368050 + 1382.8873468466*t)
	Y0 += 0.00000007564*np.cos(2.72444649380 + 325.9530972122*t)
	Y0 += 0.00000009416*np.cos(4.48854222432 + 418.0001711669*t)
	Y0 += 0.00000007037*np.cos(5.89918763754 + 418.9633790134*t)
	Y0 += 0.00000009150*np.cos(0.91468054201 + 562.1467423301*t)
	Y0 += 0.00000007298*np.cos(0.17912713996 + 425.3261664888*t)
	Y0 += 0.00000007767*np.cos(3.44132053994 + 195.8906076987*t)
	Y0 += 0.00000007169*np.cos(0.78094936112 + 291.262087743*t)
	Y0 += 0.00000008066*np.cos(2.33980427517 + 84.9335269539*t)
	Y0 += 0.00000009654*np.cos(4.51737909313 + 112.9146342051*t)
	Y0 += 0.00000006841*np.cos(6.05461927306 + 397.3932433474*t)
	Y0 += 0.00000006688*np.cos(2.70758296796 + 313.9441891018*t)
	Y0 += 0.00000007544*np.cos(2.39660132843 + 239.1625905345*t)
	Y0 += 0.00000007298*np.cos(0.06680077999 + 427.8702152632*t)
	Y0 += 0.00000007038*np.cos(2.36428897508 + 110.7275860812*t)
	Y0 += 0.00000007821*np.cos(5.18741695859 + 176.6505325085*t)
	Y0 += 0.00000006649*np.cos(5.44986911188 + 2310.722314814*t)
	Y0 += 0.00000007539*np.cos(5.29427535852 + 25.6028626656*t)
	Y0 += 0.00000007418*np.cos(4.53992673926 + 700.6642392008*t)
	Y0 += 0.00000007095*np.cos(4.07590920492 + 3583.4033404412*t)
	Y0 += 0.00000006935*np.cos(1.68866622749 + 1286.9081196288*t)
	Y0 += 0.00000006624*np.cos(3.38478404710 + 268.9582388941*t)
	Y0 += 0.00000006922*np.cos(5.86148555985 + 511.5317178299*t)
	Y0 += 0.00000008876*np.cos(1.45124442917 + 190.4045457581*t)
	Y0 += 0.00000008632*np.cos(5.94716297224 + 739.8086667949*t)
	Y0 += 0.00000006376*np.cos(3.04969045967 + 117.9105690512*t)
	Y0 += 0.00000007976*np.cos(6.27614086118 + 28.4541880032*t)
	Y0 += 0.00000008635*np.cos(3.06913386835 + 1905.4647649404*t)
	Y0 += 0.00000008583*np.cos(1.38183299971 + 298.2326223919*t)
	Y0 += 0.00000006427*np.cos(5.78516785645 + 328.9220426288*t)
	Y0 += 0.00000006901*np.cos(2.93953956658 + 249.9476583675*t)
	Y0 += 0.00000006169*np.cos(0.02881162455 + 104.5772469269*t)
	Y0 += 0.00000007512*np.cos(5.57403695070 + 25.1297819136*t)
	Y0 += 0.00000007268*np.cos(0.55017036505 + 128.3655684841*t)
	Y0 += 0.00000007663*np.cos(4.59575677319 + 724.8308132679*t)
	Y0 += 0.00000007570*np.cos(1.45797407216 + 990.2294059144*t)
	Y0 += 0.00000006057*np.cos(2.85826530733 + 856.3777754897*t)
	Y0 += 0.00000007044*np.cos(0.74967263787 + 141.4864422873*t)
	Y0 += 0.00000007326*np.cos(4.22422661121 + 909.8187330546*t)
	Y0 += 0.00000006147*np.cos(5.38817990453 + 639.3760214522*t)
	Y0 += 0.00000005874*np.cos(1.44969396662 + 393.4610900843*t)
	Y0 += 0.00000005838*np.cos(4.69945144897 + 505.3119427064*t)
	Y0 += 0.00000005932*np.cos(4.48350348373 + 120.9913890524*t)
	Y0 += 0.00000005818*np.cos(3.32808006343 + 43.2890291783*t)
	Y0 += 0.00000007778*np.cos(1.43620402576 + 25.2727942655*t)
	Y0 += 0.00000006661*np.cos(3.45258138447 + 95.3885263868*t)
	Y0 += 0.00000005748*np.cos(0.04298421235 + 843.6351541964*t)
	Y0 += 0.00000005766*np.cos(4.84601849388 + 88.1149206916*t)
	Y0 += 0.00000007756*np.cos(1.93405266531 + 55.6591434561*t)
	Y0 += 0.00000006334*np.cos(1.84951949945 + 109.6850563576*t)
	Y0 += 0.00000005819*np.cos(4.80388713776 + 215.9592243139*t)
	Y0 += 0.00000005819*np.cos(3.22733168242 + 210.6389665621*t)
	Y0 += 0.00000006720*np.cos(1.66015821490 + 135.336103133*t)
	Y0 += 0.00000006628*np.cos(2.31043141001 + 611.4430983108*t)
	Y0 += 0.00000005550*np.cos(2.16803692359 + 3060.8259223474*t)
	Y0 += 0.00000007445*np.cos(0.29603600769 + 236.1936451179*t)
	Y0 += 0.00000006305*np.cos(5.07644380408 + 3480.3105662226*t)
	Y0 += 0.00000005773*np.cos(5.34909870712 + 97.4155158163*t)
	Y0 += 0.00000005959*np.cos(0.81674403093 + 2200.5159935946*t)
	Y0 += 0.00000005771*np.cos(4.76574145067 + 164.5410506616*t)
	Y0 += 0.00000005702*np.cos(4.85038864412 + 610.6923387854*t)
	Y0 += 0.00000006085*np.cos(5.30179771397 + 433.190473015*t)
	Y0 += 0.00000007072*np.cos(1.42498322135 + 72.3339180125*t)
	Y0 += 0.00000005516*np.cos(0.00146158188 + 631.8205314667*t)
	Y0 += 0.00000006414*np.cos(1.18221848920 + 624.919432787*t)
	Y0 += 0.00000006082*np.cos(5.90524903819 + 640.4185511758*t)
	Y0 += 0.00000006689*np.cos(5.67587790589 + 140.9651774255*t)
	Y0 += 0.00000005832*np.cos(3.23574880242 + 635.231419868*t)
	Y0 += 0.00000005677*np.cos(0.22462654591 + 218.4069048687*t)
	Y0 += 0.00000005677*np.cos(1.52340696709 + 208.1912860073*t)
	Y0 += 0.00000005154*np.cos(4.72385268655 + 806.725958836*t)
	Y0 += 0.00000006235*np.cos(2.64890299983 + 616.3214130779*t)
	Y0 += 0.00000006572*np.cos(0.46207708293 + 1130.2313754934*t)
	Y0 += 0.00000006928*np.cos(0.39261887909 + 143.9341228421*t)
	Y0 += 0.00000006462*np.cos(4.11395311508 + 369.9758395734*t)
	Y0 += 0.00000006897*np.cos(1.11750070334 + 310.7146112543*t)
	Y0 += 0.00000005032*np.cos(4.78394356647 + 3686.4961146598*t)
	Y0 += 0.00000006508*np.cos(5.51529639159 + 566.600160455*t)
	Y0 += 0.00000005905*np.cos(2.11203050847 + 969.6224780949*t)
	Y0 += 0.00000006416*np.cos(0.42307449455 + 69.3649725959*t)
	Y0 += 0.00000005751*np.cos(0.14238078678 + 305.0855369618*t)
	Y0 += 0.00000005479*np.cos(4.10400660456 + 551.031606097*t)
	Y0 += 0.00000004865*np.cos(3.10986841616 + 124.5028511902*t)
	Y0 += 0.00000006101*np.cos(5.27130569482 + 55.1378785943*t)
	Y0 += 0.00000004873*np.cos(3.86714341213 + 760.25553592*t)
	Y0 += 0.00000004886*np.cos(3.16798230764 + 306.0969289181*t)
	Y0 += 0.00000004978*np.cos(3.21017890061 + 178.086821107*t)
	Y0 += 0.00000005637*np.cos(5.42364517987 + 499.895316735*t)
	Y0 += 0.00000005105*np.cos(3.43791199676 + 88.7962442478*t)
	Y0 += 0.00000005419*np.cos(6.03456044528 + 320.5846553506*t)
	Y0 += 0.00000005591*np.cos(0.97716211165 + 285.1117485887*t)
	Y0 += 0.00000005035*np.cos(5.27515551134 + 658.0565335787*t)
	Y0 += 0.00000004931*np.cos(5.41266558398 + 771.3012361839*t)
	Y0 += 0.00000005385*np.cos(0.30815887732 + 1033.3583763983*t)
	Y0 += 0.00000004606*np.cos(3.90101372950 + 634.2682120215*t)
	Y0 += 0.00000005516*np.cos(4.29920828193 + 455.1699989582*t)
	Y0 += 0.00000005289*np.cos(1.72715966366 + 484.7050148869*t)
	Y0 += 0.00000004901*np.cos(1.94192487952 + 319.3126309634*t)
	Y0 += 0.00000004509*np.cos(2.94241810571 + 271.4059194489*t)
	Y0 += 0.00000005054*np.cos(1.30081494754 + 43.1289704839*t)
	Y0 += 0.00000004550*np.cos(4.64059617411 + 958.576777831*t)
	Y0 += 0.00000005328*np.cos(6.23500759865 + 58.1068240109*t)
	Y0 += 0.00000004628*np.cos(1.03763056101 + 745.277682393*t)
	Y0 += 0.00000004492*np.cos(0.36984177539 + 732.6951197941*t)
	Y0 += 0.00000005514*np.cos(2.98116751203 + 2221.856634597*t)
	Y0 += 0.00000004464*np.cos(0.00963533764 + 636.9765250072*t)
	Y0 += 0.00000005558*np.cos(3.37188064285 + 493.303034596*t)
	Y0 += 0.00000004957*np.cos(2.49575219954 + 526.9826521089*t)
	Y0 += 0.00000004485*np.cos(3.80247388459 + 623.2225117576*t)
	Y0 += 0.00000004770*np.cos(1.62322752296 + 991.7138786227*t)
	Y0 += 0.00000004783*np.cos(2.31677561430 + 504.561183181*t)
	Y0 += 0.00000004633*np.cos(4.41902834379 + 26.826702943*t)
	Y0 += 0.00000004812*np.cos(3.04861600576 + 327.6982023514*t)
	Y0 += 0.00000004454*np.cos(6.20355474499 + 198.4813006054*t)
	Y0 += 0.00000004511*np.cos(3.87445380751 + 707.5653378805*t)
	Y0 += 0.00000004451*np.cos(1.27013594738 + 113.1270825262*t)
	Y0 += 0.00000004350*np.cos(4.07716874275 + 840.6662087798*t)
	Y0 += 0.00000004327*np.cos(5.70195843787 + 2730.2069586892*t)
	Y0 += 0.00000005808*np.cos(3.24854160326 + 254.3528923826*t)
	Y0 += 0.00000004664*np.cos(4.20536088537 + 318.8395502114*t)
	Y0 += 0.00000004378*np.cos(5.82692125515 + 3473.1970192218*t)
	Y0 += 0.00000004313*np.cos(3.88436316438 + 439.9315130003*t)
	Y0 += 0.00000005010*np.cos(1.87919232767 + 2324.9494088156*t)
	Y0 += 0.00000004613*np.cos(0.10623373342 + 774.4826299216*t)
	Y0 += 0.00000004450*np.cos(2.82885666591 + 629.6023455755*t)
	Y0 += 0.00000005233*np.cos(4.00529540892 + 952.0963702766*t)
	Y0 += 0.00000005260*np.cos(2.15622840750 + 115.6229471908*t)
	Y0 += 0.00000004321*np.cos(2.28638024486 + 201.5196819912*t)
	Y0 += 0.00000005321*np.cos(1.23695932593 + 597.3590166611*t)
	Y0 += 0.00000004111*np.cos(3.99363576385 + 561.934294009*t)
	Y0 += 0.00000004845*np.cos(2.27697782163 + 226.0417167313*t)
	Y0 += 0.00000004049*np.cos(2.54842532095 + 372.4235201282*t)
	Y0 += 0.00000004077*np.cos(3.46715688833 + 650.1922270525*t)
	Y0 += 0.00000004372*np.cos(2.72226535320 + 225.0785088848*t)
	Y0 += 0.00000004108*np.cos(0.27128923799 + 2118.7638603784*t)
	Y0 += 0.00000004173*np.cos(0.28763595583 + 211.0114735776*t)
	Y0 += 0.00000004173*np.cos(1.46039755717 + 215.5867172984*t)
	Y0 += 0.00000004019*np.cos(0.87322430941 + 1141.1340634054*t)
	Y0 += 0.00000005075*np.cos(3.41425583730 + 317.8763423649*t)
	Y0 += 0.00000004060*np.cos(1.82766433682 + 228.1168902706*t)
	Y0 += 0.00000003992*np.cos(6.06359298496 + 668.2084619653*t)
	Y0 += 0.00000004165*np.cos(3.75880493478 + 6275.9623029906*t)
	Y0 += 0.00000004041*np.cos(5.36982470528 + 331.2096644892*t)
	Y0 += 0.00000005062*np.cos(2.71562815851 + 200.5564741447*t)
	Y0 += 0.00000005029*np.cos(4.81157332925 + 197.257460328*t)
	Y0 += 0.00000005457*np.cos(0.62936317016 + 481.7360694703*t)
	Y0 += 0.00000005129*np.cos(3.87485901115 + 207.6218370357*t)
	Y0 += 0.00000005129*np.cos(4.15635980903 + 218.9763538403*t)
	Y0 += 0.00000003855*np.cos(3.65565538336 + 425.3743505986*t)
	Y0 += 0.00000004705*np.cos(3.72248568793 + 424.9012698466*t)
	Y0 += 0.00000003880*np.cos(0.75632369741 + 541.5398145106*t)
	Y0 += 0.00000003860*np.cos(3.28596473379 + 512.4254897072*t)
	Y0 += 0.00000003855*np.cos(2.87345784377 + 427.8220311534*t)
	Y0 += 0.00000003992*np.cos(4.82104146147 + 248.511369769*t)
	Y0 += 0.00000004040*np.cos(1.33827734907 + 49.7212526229*t)
	Y0 += 0.00000003973*np.cos(5.17941188721 + 10206.1719992102*t)
	Y0 += 0.00000004561*np.cos(6.09725389673 + 491.5579294568*t)
	Y0 += 0.00000003903*np.cos(0.64285376704 + 378.9039276826*t)
	Y0 += 0.00000004917*np.cos(5.33496755731 + 769.8167634756*t)
	Y0 += 0.00000003770*np.cos(3.22875931246 + 214.6716935617*t)
	Y0 += 0.00000003770*np.cos(4.80245950772 + 211.9264973143*t)
	Y0 += 0.00000003732*np.cos(1.87406384413 + 48.7580447764*t)
	Y0 += 0.00000005021*np.cos(4.77663253414 + 108.7218485111*t)
	Y0 += 0.00000003851*np.cos(3.44837014022 + 305.6068018236*t)
	Y0 += 0.00000003728*np.cos(5.06145217265 + 407.4757357648*t)
	Y0 += 0.00000004008*np.cos(3.44168738224 + 1044.4040766622*t)
	Y0 += 0.00000003788*np.cos(2.56555519144 + 258.5456780766*t)
	Y0 += 0.00000003639*np.cos(4.65501398335 + 634.4806603426*t)
	Y0 += 0.00000004845*np.cos(6.02448861393 + 604.4725636619*t)
	Y0 += 0.00000004292*np.cos(4.23108349990 + 180.1619946463*t)
	Y0 += 0.00000003969*np.cos(3.99964137261 + 398.2870152247*t)
	Y0 += 0.00000004729*np.cos(2.75258800170 + 184.0941479094*t)
	Y0 += 0.00000004535*np.cos(3.22219467599 + 229.340730548*t)
	Y0 += 0.00000003649*np.cos(1.96746396187 + 444.1242986943*t)
	Y0 += 0.00000003517*np.cos(4.03852795064 + 3899.7952100978*t)
	Y0 += 0.00000003538*np.cos(1.31552944944 + 316.4400537664*t)
	Y0 += 0.00000004339*np.cos(3.48361091763 + 608.877797677*t)
	Y0 += 0.00000003506*np.cos(4.40454614352 + 316.3436855468*t)
	Y0 += 0.00000003647*np.cos(1.50873517823 + 519.3960243561*t)
	Y0 += 0.00000004193*np.cos(2.69898321973 + 775.233389447*t)
	Y0 += 0.00000004286*np.cos(3.18185934871 + 77.2292791221*t)
	Y0 += 0.00000004034*np.cos(3.45748098127 + 262.0571402144*t)
	Y0 += 0.00000003347*np.cos(0.14036401631 + 109.455561694*t)
	Y0 += 0.00000004116*np.cos(5.24881005284 + 120.5012619579*t)
	Y0 += 0.00000003377*np.cos(1.41049429770 + 765.8846102125*t)
	Y0 += 0.00000003617*np.cos(1.09655203793 + 315.4286618101*t)
	Y0 += 0.00000003642*np.cos(3.59693059890 + 348.635198571*t)
	Y0 += 0.00000003282*np.cos(6.05512739363 + 211.762233103*t)
	Y0 += 0.00000003282*np.cos(1.97609142655 + 214.835957773*t)
	Y0 += 0.00000003358*np.cos(5.03561049516 + 165.6048322446*t)
	Y0 += 0.00000003178*np.cos(4.04653368104 + 110.9570807448*t)
	Y0 += 0.00000003804*np.cos(5.94126091615 + 80.1982245387*t)
	Y0 += 0.00000004062*np.cos(2.18177184785 + 92.3077063856*t)
	Y0 += 0.00000003301*np.cos(2.46298796727 + 282.6640680339*t)
	Y0 += 0.00000003787*np.cos(4.28600120342 + 652.4274592862*t)
	Y0 += 0.00000003212*np.cos(4.02232029742 + 306.830642101*t)
	Y0 += 0.00000003880*np.cos(4.82754222667 + 317.3550775031*t)
	Y0 += 0.00000003691*np.cos(5.19957011681 + 194.2885149114*t)
	Y0 += 0.00000003467*np.cos(2.75272147827 + 428.2951119054*t)
	Y0 += 0.00000004132*np.cos(0.15196778100 + 434.2330027386*t)
	Y0 += 0.00000004289*np.cos(0.56065340003 + 187.6962327724*t)
	Y0 += 0.00000003828*np.cos(6.10468598936 + 114.9416236346*t)
	Y0 += 0.00000003067*np.cos(1.19985423472 + 71.6002048296*t)
	Y0 += 0.00000003142*np.cos(3.74647337221 + 130.4407420234*t)
	Y0 += 0.00000003054*np.cos(4.31541167047 + 699.7010313543*t)
	Y0 += 0.00000003219*np.cos(4.40669258863 + 657.1627617014*t)
	Y0 += 0.00000003527*np.cos(3.59075624103 + 495.9631634719*t)
	Y0 += 0.00000003310*np.cos(0.53771489354 + 2516.9078632512*t)
	Y0 += 0.00000003471*np.cos(0.95985137600 + 1119.1856752295*t)
	Y0 += 0.00000004106*np.cos(2.03430708190 + 685.4739373527*t)
	Y0 += 0.00000003032*np.cos(3.52225726785 + 93.531546663*t)
	Y0 += 0.00000003788*np.cos(0.41613967902 + 672.1406152284*t)
	Y0 += 0.00000003317*np.cos(1.05508535425 + 721.6494195302*t)
	Y0 += 0.00000003312*np.cos(6.04970700966 + 691.1030116452*t)
	Y0 += 0.00000002970*np.cos(4.62780237780 + 4002.8879843164*t)
	Y0 += 0.00000003020*np.cos(5.03890376384 + 151.260118164*t)
	Y0 += 0.00000003500*np.cos(2.81349072076 + 789.4604834486*t)
	Y0 += 0.00000003174*np.cos(6.10109078944 + 453.424893819*t)
	Y0 += 0.00000002994*np.cos(4.38745012498 + 91.7864415238*t)
	Y0 += 0.00000003894*np.cos(1.24532219442 + 268.4369740323*t)
	Y0 += 0.00000003953*np.cos(6.16022797347 + 101.8689339412*t)
	Y0 += 0.00000003539*np.cos(5.71127070378 + 232.942815411*t)
	Y0 += 0.00000003866*np.cos(5.44364081086 + 37.8724032069*t)
	Y0 += 0.00000002998*np.cos(2.95919686933 + 328.2407190726*t)
	Y0 += 0.00000003033*np.cos(1.45458632603 + 188.0263011725*t)
	Y0 += 0.00000003405*np.cos(3.08243677773 + 167.0893049529*t)
	Y0 += 0.00000002917*np.cos(1.86331950934 + 357.2332182801*t)
	Y0 += 0.00000002890*np.cos(4.23477281091 + 92.7978334801*t)
	Y0 += 0.00000003086*np.cos(5.84396093041 + 443.8636662634*t)
	Y0 += 0.00000003008*np.cos(2.53117554530 + 434.4624974022*t)
	Y0 += 0.00000003572*np.cos(6.08350760138 + 851.7119090437*t)
	Y0 += 0.00000002900*np.cos(1.19512524260 + 842.9014410135*t)
	Y0 += 0.00000002804*np.cos(2.83113208076 + 425.1619022775*t)
	Y0 += 0.00000003277*np.cos(2.83164917192 + 232.3096759646*t)
	Y0 += 0.00000002758*np.cos(3.67825788850 + 103.0445901088*t)
	Y0 += 0.00000003541*np.cos(0.53353274088 + 239.3226492289*t)
	Y0 += 0.00000002882*np.cos(3.07881226842 + 123.5396433437*t)
	Y0 += 0.00000002804*np.cos(3.69798114637 + 428.0344794745*t)
	Y0 += 0.00000002728*np.cos(1.13605812584 + 354.2642728635*t)
	Y0 += 0.00000002986*np.cos(0.01727868701 + 42.3258213318*t)
	Y0 += 0.00000003750*np.cos(3.91661897655 + 145.4185955504*t)
	Y0 += 0.00000002715*np.cos(1.40747373075 + 620.253566341*t)
	Y0 += 0.00000003737*np.cos(0.26727034607 + 25.8634950965*t)
	Y0 += 0.00000002707*np.cos(0.11590621754 + 310.9752436852*t)
	Y0 += 0.00000003259*np.cos(4.73993803463 + 3796.7024358792*t)
	Y0 += 0.00000002699*np.cos(4.09770361223 + 141.6988906084*t)
	Y0 += 0.00000002846*np.cos(0.59348034929 + 103.1409583284*t)
	Y0 += 0.00000002693*np.cos(4.35806644152 + 432.9609783514*t)
	Y0 += 0.00000003752*np.cos(1.31275213009 + 187.2755416471*t)
	Y0 += 0.00000003408*np.cos(4.57767638767 + 498.9321088885*t)
	Y0 += 0.00000003270*np.cos(1.13501059030 + 924.0458270562*t)
	Y0 += 0.00000002922*np.cos(3.43339315332 + 335.1418177523*t)
	Y0 += 0.00000003462*np.cos(4.87665384758 + 182.5402392319*t)
	Y0 += 0.00000003056*np.cos(3.84258397222 + 179.5712938153*t)
	Y0 += 0.00000003566*np.cos(1.22446128806 + 238.9019581036*t)
	Y0 += 0.00000003321*np.cos(0.62461208452 + 122.7364941916*t)
	Y0 += 0.00000002751*np.cos(2.00343492050 + 322.0209439491*t)
	Y0 += 0.00000002606*np.cos(0.14368418549 + 1049.0869894507*t)
	Y0 += 0.00000002722*np.cos(0.33833300117 + 644.090072008*t)
	Y0 += 0.00000002655*np.cos(2.71424424324 + 125.1841747464*t)
	Y0 += 0.00000002840*np.cos(5.63787661296 + 336.8387387817*t)
	Y0 += 0.00000002833*np.cos(4.49076222674 + 782.3469364478*t)
	Y0 += 0.00000003360*np.cos(4.08549912142 + 1063.3140834523*t)
	Y0 += 0.00000002712*np.cos(3.26766861519 + 631.2992666049*t)
	Y0 += 0.00000002667*np.cos(2.34899182217 + 1080.7225711916*t)
	Y0 += 0.00000003565*np.cos(5.73250034919 + 1056.2005364515*t)
	Y0 += 0.00000002603*np.cos(3.14892751264 + 508.4933364441*t)
	Y0 += 0.00000002559*np.cos(3.79368088293 + 639.1465267886*t)
	Y0 += 0.00000003194*np.cos(0.26003120905 + 913.9633346388*t)
	Y0 += 0.00000002555*np.cos(5.91141702766 + 625.8826406335*t)
	Y0 += 0.00000002581*np.cos(1.05939099951 + 158.9643659958*t)
	Y0 += 0.00000003373*np.cos(6.22510987996 + 102.1295663721*t)
	Y0 += 0.00000002548*np.cos(1.66256671387 + 95.2284676924*t)
	Y0 += 0.00000003193*np.cos(2.66788003455 + 2538.2485042536*t)
	Y0 += 0.00000002686*np.cos(4.87164344891 + 642.8180476208*t)
	Y0 += 0.00000002536*np.cos(3.93316993605 + 64.9597385808*t)
	Y0 += 0.00000002480*np.cos(4.89581480605 + 111.4301614968*t)
	Y0 += 0.00000002660*np.cos(1.58245860025 + 443.2729654324*t)
	Y0 += 0.00000002495*np.cos(5.48966738548 + 2627.1141844706*t)
	Y0 += 0.00000002429*np.cos(2.83521812027 + 235.933012687*t)
	Y0 += 0.00000002396*np.cos(3.78771740781 + 173.6815870919*t)
	Y0 += 0.00000002649*np.cos(3.41312329124 + 244.0579516441*t)
	Y0 += 0.00000002387*np.cos(4.23055061931 + 619.2903584945*t)
	Y0 += 0.00000002373*np.cos(5.47710357456 + 3046.5988283458*t)
	Y0 += 0.00000002556*np.cos(1.66067410548 + 3377.217792004*t)
	Y0 += 0.00000002655*np.cos(3.73582825216 + 440.6128365565*t)
	Y0 += 0.00000002369*np.cos(5.55705197269 + 205.9731001161*t)
	Y0 += 0.00000002369*np.cos(5.61575950108 + 220.6250907599*t)
	Y0 += 0.00000002774*np.cos(2.02597665846 + 168.0525127994*t)
	Y0 += 0.00000003235*np.cos(2.58049219033 + 338.4832701844*t)
	Y0 += 0.00000002329*np.cos(4.11799083739 + 398.1440028728*t)
	Y0 += 0.00000002701*np.cos(3.73947164540 + 300.6108669775*t)
	Y0 += 0.00000003125*np.cos(3.79844466951 + 531.978586955*t)
	Y0 += 0.00000002323*np.cos(3.05034654081 + 535.9107402181*t)
	Y0 += 0.00000002895*np.cos(5.50164208553 + 945.2434557067*t)
	Y0 += 0.00000002373*np.cos(5.46855507643 + 337.8019466282*t)
	Y0 += 0.00000002726*np.cos(1.94958732685 + 953.1077622329*t)
	Y0 += 0.00000002952*np.cos(0.74298822983 + 645.5263606065*t)
	Y0 += 0.00000003101*np.cos(4.07921701551 + 104.0559820651*t)
	Y0 += 0.00000002253*np.cos(0.65614704540 + 310.1720945331*t)
	Y0 += 0.00000002325*np.cos(5.58522441833 + 3789.5888888784*t)
	Y0 += 0.00000002533*np.cos(0.42337625047 + 90.5626012464*t)
	Y0 += 0.00000002313*np.cos(4.74432612488 + 469.8872200543*t)
	Y0 += 0.00000002261*np.cos(0.49414568193 + 297.6419215609*t)
	Y0 += 0.00000002906*np.cos(5.36614631776 + 550.1378342197*t)
	Y0 += 0.00000002203*np.cos(4.74111725788 + 281.1795953256*t)
	Y0 += 0.00000002305*np.cos(1.27906331822 + 768.8535556291*t)
	Y0 += 0.00000002215*np.cos(1.98003879892 + 2641.3412784722*t)
	Y0 += 0.00000002811*np.cos(6.10219051624 + 641.3817590223*t)
	Y0 += 0.00000002247*np.cos(1.30388296472 + 315.1680293792*t)
	Y0 += 0.00000002184*np.cos(0.64755103697 + 1457.525933062*t)
	Y0 += 0.00000002591*np.cos(5.35033213699 + 170.1701249541*t)
	Y0 += 0.00000002177*np.cos(4.17779611513 + 67.8804998876*t)
	Y0 += 0.00000002159*np.cos(2.78579770414 + 347.4113582936*t)
	Y0 += 0.00000002304*np.cos(4.39421156840 + 49.5088043018*t)
	Y0 += 0.00000002466*np.cos(4.19474542518 + 247.0268970607*t)
	Y0 += 0.00000002386*np.cos(2.80178234746 + 430.7427924602*t)
	Y0 += 0.00000002610*np.cos(4.77257985354 + 1193.9672737968*t)
	Y0 += 0.00000002641*np.cos(3.35196821148 + 739.0579072695*t)
	Y0 += 0.00000002700*np.cos(2.12282494441 + 927.8349679674*t)
	Y0 += 0.00000002379*np.cos(0.49192182148 + 176.3899000776*t)
	Y0 += 0.00000002808*np.cos(2.30330319489 + 837.6972633632*t)
	Y0 += 0.00000002250*np.cos(3.80713989523 + 366.0436863103*t)
	Y0 += 0.00000002115*np.cos(2.49144340867 + 476.3194434989*t)
	Y0 += 0.00000002334*np.cos(3.56275093608 + 60.5545045657*t)
	Y0 += 0.00000002069*np.cos(3.42638286804 + 256.4280659219*t)
	Y0 += 0.00000002094*np.cos(2.69778083768 + 883.7951792637*t)
	Y0 += 0.00000002634*np.cos(4.98366789173 + 103.3534066495*t)
	Y0 += 0.00000002113*np.cos(3.71735542360 + 90.8232336773*t)
	Y0 += 0.00000002259*np.cos(5.23005869914 + 183.2428146475*t)
	Y0 += 0.00000002403*np.cos(0.69911286193 + 452.2010535416*t)
	Y0 += 0.00000002564*np.cos(1.72919712902 + 427.4919627533*t)
	Y0 += 0.00000002111*np.cos(3.67340327220 + 422.4535892918*t)
	Y0 += 0.00000002309*np.cos(1.52889857656 + 154.979823106*t)
	Y0 += 0.00000002101*np.cos(3.17100143341 + 418.7338843498*t)
	Y0 += 0.00000002339*np.cos(3.19581014018 + 475.3562356524*t)
	Y0 += 0.00000002810*np.cos(4.44919998552 + 1041.2226829245*t)
	Y0 += 0.00000001991*np.cos(0.07570870145 + 1097.0942747017*t)
	Y0 += 0.00000002346*np.cos(4.39881551809 + 447.2051186955*t)
	Y0 += 0.00000002489*np.cos(1.26387069472 + 2487.4160449478*t)
	Y0 += 0.00000002265*np.cos(5.41116346117 + 827.9235874865*t)
	Y0 += 0.00000002041*np.cos(5.11578854043 + 409.1897031367*t)
	Y0 += 0.00000002467*np.cos(5.87379769512 + 429.5671362926*t)
	Y0 += 0.00000001995*np.cos(4.07142764766 + 409.3327154886*t)
	Y0 += 0.00000002007*np.cos(0.06206259537 + 614.6244920485*t)
	Y0 += 0.00000002459*np.cos(2.83207805977 + 485.8806710545*t)
	Y0 += 0.00000001949*np.cos(2.29014828042 + 1171.875873269*t)
	Y0 += 0.00000002073*np.cos(4.35393775952 + 532.1386456494*t)
	Y0 += 0.00000001873*np.cos(3.82628269559 + 344.8460576598*t)
	Y0 += 0.00000002386*np.cos(5.73054918768 + 25234.70675982219*t)
	Y0 += 0.00000001913*np.cos(1.11318492193 + 835.7878940127*t)
	Y0 += 0.00000002201*np.cos(2.10310925537 + 784.0438574772*t)
	Y0 += 0.00000002205*np.cos(2.54976398910 + 527.2432845398*t)
	Y0 += 0.00000002159*np.cos(5.22897893375 + 666.723989257*t)
	Y0 += 0.00000002042*np.cos(4.90569999816 + 102.5715093568*t)
	Y0 += 0.00000001859*np.cos(2.43455134316 + 469.7271613599*t)
	Y0 += 0.00000002564*np.cos(4.79991609811 + 425.7044189987*t)
	Y0 += 0.00000001848*np.cos(1.89340310979 + 528.9402055692*t)
	Y0 += 0.00000001965*np.cos(4.29620967516 + 40.1600250673*t)
	Y0 += 0.00000001953*np.cos(2.77684772272 + 115.8353955119*t)
	Y0 += 0.00000002542*np.cos(4.99291303185 + 354.7855377253*t)
	Y0 += 0.00000002293*np.cos(3.74833102224 + 180.8433182025*t)
	Y0 += 0.00000001833*np.cos(0.68864623997 + 267.6338248802*t)
	Y0 += 0.00000002098*np.cos(4.80007899391 + 252.9166037841*t)
	Y0 += 0.00000002063*np.cos(4.42290544540 + 177.1236132605*t)
	Y0 += 0.00000002289*np.cos(3.53527647248 + 482.2573343321*t)
	Y0 += 0.00000002360*np.cos(3.90231570903 + 1108.1399749656*t)
	Y0 += 0.00000001811*np.cos(5.59255697169 + 530.44172462*t)
	Y0 += 0.00000001804*np.cos(5.24742259566 + 3362.9906980024*t)
	Y0 += 0.00000001844*np.cos(0.00789242156 + 2435.155730035*t)
	Y0 += 0.00000001982*np.cos(5.35608124487 + 103.6140390804*t)
	Y0 += 0.00000001908*np.cos(5.22238265370 + 466.7582159433*t)
	Y0 += 0.00000002016*np.cos(2.76555324862 + 243.3553762285*t)
	Y0 += 0.00000001848*np.cos(4.20159262156 + 633.7469471597*t)
	Y0 += 0.00000001781*np.cos(4.91158923453 + 205.9249160063*t)
	Y0 += 0.00000001781*np.cos(6.26122223924 + 220.6732748697*t)
	Y0 += 0.00000001887*np.cos(6.15706255153 + 1083.7609525774*t)
	Y0 += 0.00000002271*np.cos(3.52462508383 + 192.8040422031*t)
	Y0 += 0.00000002271*np.cos(4.50659373635 + 233.7941486729*t)
	Y0 += 0.00000002089*np.cos(2.74677830240 + 105.5404547734*t)
	Y0 += 0.00000002115*np.cos(3.37920796693 + 670.916774951*t)
	Y0 += 0.00000002035*np.cos(4.41826161524 + 1357.6145525811*t)
	Y0 += 0.00000002371*np.cos(0.74039668492 + 799.6124118352*t)
	Y0 += 0.00000001774*np.cos(3.33747140433 + 206.4461808681*t)
	Y0 += 0.00000001774*np.cos(1.55215476226 + 220.1520100079*t)
	Y0 += 0.00000001959*np.cos(5.96363240537 + 1246.6574718363*t)
	Y0 += 0.00000002018*np.cos(1.23143921903 + 250.2082907984*t)
	Y0 += 0.00000002294*np.cos(4.61597338213 + 912.4788619305*t)
	Y0 += 0.00000001775*np.cos(0.81870406810 + 198.1087935899*t)
	Y0 += 0.00000001775*np.cos(4.07092209849 + 228.4893972861*t)
	Y0 += 0.00000002098*np.cos(4.32225540550 + 754.8389099486*t)
	Y0 += 0.00000001762*np.cos(4.83065781118 + 551.1010420662*t)
	Y0 += 0.00000002337*np.cos(6.02524868807 + 635.70450062*t)
	Y0 += 0.00000002222*np.cos(5.48379459480 + 1699.2792165032*t)
	Y0 += 0.00000001706*np.cos(0.55353279572 + 749.2098356561*t)
	Y0 += 0.00000001694*np.cos(6.24017209111 + 518.3846323998*t)
	Y0 += 0.00000001784*np.cos(3.41130277039 + 346.1875180162*t)
	Y0 += 0.00000001912*np.cos(5.83154317920 + 133.1008708993*t)
	Y0 += 0.00000001839*np.cos(6.01872357391 + 589.4947101349*t)
	Y0 += 0.00000001703*np.cos(2.29299187318 + 146.3818033969*t)
	Y0 += 0.00000001687*np.cos(0.96512635264 + 10.0343083076*t)
	Y0 += 0.00000002084*np.cos(3.81612644973 + 5216.5803728014*t)
	Y0 += 0.00000001707*np.cos(5.43507761109 + 1144.3154571431*t)
	Y0 += 0.00000001855*np.cos(5.99205151484 + 301.4140161296*t)
	Y0 += 0.00000002070*np.cos(0.48705338683 + 45.2465826386*t)
	Y0 += 0.00000001709*np.cos(2.43242085921 + 1062.5633239269*t)
	Y0 += 0.00000001655*np.cos(1.00249438802 + 104.789695248*t)
	Y0 += 0.00000001838*np.cos(1.94927537660 + 2854.6403739102*t)
	Y0 += 0.00000001836*np.cos(1.35614614488 + 644.56315276*t)
	Y0 += 0.00000002080*np.cos(6.16951060410 + 587.2070882745*t)
	Y0 += 0.00000001689*np.cos(3.06052557709 + 275.338072712*t)
	Y0 += 0.00000002104*np.cos(5.53965159347 + 1372.5924061081*t)
	Y0 += 0.00000001649*np.cos(3.76361921057 + 4216.1870797544*t)
	Y0 += 0.00000001822*np.cos(1.36816817971 + 118.0706277456*t)
	Y0 += 0.00000001720*np.cos(6.04159111363 + 6290.1893969922*t)
	Y0 += 0.00000002084*np.cos(1.19654093349 + 414.8187774292*t)
	Y0 += 0.00000001658*np.cos(0.45133729472 + 624.3981679252*t)
	Y0 += 0.00000001707*np.cos(0.48133465395 + 98.3574718034*t)
	Y0 += 0.00000001742*np.cos(5.09299481446 + 349.3689117539*t)
	Y0 += 0.00000001749*np.cos(2.17421151845 + 25455.119402261*t)
	Y0 += 0.00000001782*np.cos(3.25289876760 + 9772.4602613334*t)
	Y0 += 0.00000001774*np.cos(4.76865612658 + 533.8837507886*t)
	Y0 += 0.00000001684*np.cos(1.20229401820 + 10220.3990932118*t)
	Y0 += 0.00000001942*np.cos(5.33749253343 + 246.4361962297*t)
	Y0 += 0.00000001839*np.cos(0.63974984193 + 524.0137066923*t)
	Y0 += 0.00000001666*np.cos(2.21549340552 + 700.4517908797*t)
	Y0 += 0.00000001943*np.cos(5.24690810849 + 9146.790069021*t)
	Y0 += 0.00000001802*np.cos(3.88396641267 + 2707.8286873866*t)
	Y0 += 0.00000001696*np.cos(3.74962508253 + 134.1122628556*t)
	Y0 += 0.00000001560*np.cos(1.35555739940 + 413.8555695827*t)
	Y0 += 0.00000001800*np.cos(1.13754295844 + 1389.1071219701*t)
	Y0 += 0.00000001866*np.cos(5.16894152281 + 58.319272332*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000001569*np.cos(2.96590949044 + 122.4758617607*t)
	Y0 += 0.00000001878*np.cos(0.56034818540 + 134.0640787458*t)
	Y0 += 0.00000001573*np.cos(6.00727125972 + 2751.5475996916*t)
	Y0 += 0.00000001715*np.cos(3.48124521150 + 709.0498105888*t)
	Y0 += 0.00000001549*np.cos(3.00079525151 + 735.828329422*t)
	Y0 += 0.00000001584*np.cos(3.71413202518 + 3767.2106175758*t)
	Y0 += 0.00000001617*np.cos(0.82146396585 + 83.3796182764*t)
	Y0 += 0.00000001522*np.cos(3.95543295975 + 406.1513217509*t)
	Y0 += 0.00000001774*np.cos(2.05577451783 + 988.532484885*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001668*np.cos(0.15464960467 + 318.679491517*t)
	Y0 += 0.00000001505*np.cos(2.43278632462 + 447.0450600011*t)
	Y0 += 0.00000001851*np.cos(1.32257916724 + 586.3133163972*t)
	Y0 += 0.00000001699*np.cos(1.83589151289 + 5849.3641121146*t)
	Y0 += 0.00000001513*np.cos(1.58063538394 + 694.0719570618*t)
	Y0 += 0.00000001652*np.cos(2.29417006197 + 1364.7280995819*t)
	Y0 += 0.00000001681*np.cos(3.27233741787 + 9779.5738083342*t)
	Y0 += 0.00000001761*np.cos(4.54815343835 + 59.2824801785*t)
	Y0 += 0.00000001512*np.cos(5.62855091662 + 1748.0372612796*t)
	Y0 += 0.00000001830*np.cos(5.34715739631 + 259.5088859231*t)
	Y0 += 0.00000001955*np.cos(1.14034312132 + 913.7508863177*t)
	Y0 += 0.00000001700*np.cos(2.52690589264 + 1091.6252591036*t)
	Y0 += 0.00000001492*np.cos(3.87041262067 + 878.3261636656*t)
	Y0 += 0.00000001813*np.cos(4.74934995230 + 284.8993002676*t)
	Y0 += 0.00000001477*np.cos(2.97738624058 + 105.380396079*t)
	Y0 += 0.00000001498*np.cos(0.41523796774 + 174.6929790482*t)
	Y0 += 0.00000001557*np.cos(4.72868742196 + 5753.3848848968*t)
	Y0 += 0.00000001661*np.cos(0.36710516357 + 1012.9115072732*t)
	Y0 += 0.00000001458*np.cos(0.77581736648 + 632.831923423*t)
	Y0 += 0.00000001835*np.cos(4.28335523752 + 245.7548726735*t)
	Y0 += 0.00000001579*np.cos(2.18056769700 + 680.0573113813*t)
	Y0 += 0.00000001563*np.cos(3.16063918535 + 736.8397213783*t)
	Y0 += 0.00000001450*np.cos(6.03894003020 + 735.9246976416*t)
	Y0 += 0.00000001763*np.cos(3.79907071140 + 383.3091616977*t)
	Y0 += 0.00000001651*np.cos(1.38404939118 + 1038.0412891868*t)
	Y0 += 0.00000001644*np.cos(3.60831498439 + 249.4745776155*t)
	Y0 += 0.00000001496*np.cos(4.79857033083 + 77623.81213840858*t)
	Y0 += 0.00000001555*np.cos(1.75214206831 + 679.2541622292*t)
	Y0 += 0.00000001432*np.cos(4.37859929602 + 4319.279853973*t)
	Y0 += 0.00000001890*np.cos(2.07781526909 + 764.4001375042*t)
	Y0 += 0.00000001529*np.cos(3.49230150581 + 1379.7059531089*t)
	Y0 += 0.00000001537*np.cos(2.30815561940 + 321.0577361026*t)
	Y0 += 0.00000001683*np.cos(2.44398546913 + 6503.4884924302*t)
	Y0 += 0.00000001413*np.cos(5.19282461963 + 322.6116447801*t)
	Y0 += 0.00000001473*np.cos(5.41554956833 + 1452.8430202735*t)
	Y0 += 0.00000001848*np.cos(0.98286127487 + 419.6970921963*t)
	Y0 += 0.00000001615*np.cos(3.28706588176 + 763.4369296577*t)
	Y0 += 0.00000001495*np.cos(0.29095019343 + 155.7829722581*t)
	Y0 += 0.00000001394*np.cos(3.59008434668 + 632.0329797878*t)
	Y0 += 0.00000001588*np.cos(3.92824002664 + 148.3393568572*t)
	Y0 += 0.00000001416*np.cos(1.27557908922 + 840.4537604587*t)
	Y0 += 0.00000001377*np.cos(1.49343226956 + 1354.4331588434*t)
	Y0 += 0.00000001512*np.cos(1.46479222367 + 5746.271337896*t)
	Y0 += 0.00000001512*np.cos(2.71827936357 + 428.2427222787*t)
	Y0 += 0.00000001373*np.cos(5.14213868043 + 118.8737768977*t)
	Y0 += 0.00000001432*np.cos(0.34980510915 + 1166.4068576709*t)
	Y0 += 0.00000001361*np.cos(0.09412736777 + 331.3697231836*t)
	Y0 += 0.00000001891*np.cos(3.43728723911 + 1165.3954657146*t)
	Y0 += 0.00000001501*np.cos(2.87450546367 + 9676.4810341156*t)
	Y0 += 0.00000001759*np.cos(3.01502964755 + 200.0352092829*t)
	Y0 += 0.00000001759*np.cos(1.87459651904 + 226.5629815931*t)
	Y0 += 0.00000001599*np.cos(3.86769166408 + 10433.6981886498*t)
	Y0 += 0.00000001401*np.cos(4.97239262675 + 1950.2906564537*t)
	Y0 += 0.00000001637*np.cos(1.37711471652 + 451.7279727896*t)
	Y0 += 0.00000001339*np.cos(0.57976012942 + 1159.2933106701*t)
	Y0 += 0.00000001375*np.cos(1.60430927308 + 1670.82502850*t)
	Y0 += 0.00000001377*np.cos(2.45454466359 + 183.5516311882*t)
	Y0 += 0.00000001377*np.cos(5.57667415659 + 243.0465596878*t)
	Y0 += 0.00000001464*np.cos(3.85374204577 + 263.0203480609*t)
	Y0 += 0.00000001337*np.cos(6.03006105607 + 6.3627874754*t)
	Y0 += 0.00000001647*np.cos(2.07108808598 + 109.3125493421*t)
	Y0 += 0.00000001455*np.cos(0.74361321398 + 25661.3049506982*t)
	Y0 += 0.00000001312*np.cos(4.56459920331 + 311.7260032106*t)
	Y0 += 0.00000001500*np.cos(1.53242411242 + 2313.9037085517*t)
	Y0 += 0.00000001715*np.cos(4.51218397068 + 79.1868325824*t)
	Y0 += 0.00000001381*np.cos(5.24179656775 + 718.6110381444*t)
	Y0 += 0.00000001758*np.cos(1.96055689832 + 452.4616859725*t)
	Y0 += 0.00000001687*np.cos(3.24710382106 + 1151.4290041439*t)
	Y0 += 0.00000001765*np.cos(5.03429736111 + 757.8078553652*t)
	Y0 += 0.00000001660*np.cos(2.14686249511 + 661.0949149645*t)
	Y0 += 0.00000001464*np.cos(2.84230067135 + 359.893347156*t)
	Y0 += 0.00000001374*np.cos(5.32410055956 + 535.3200393871*t)
	Y0 += 0.00000001342*np.cos(1.84663745229 + 384.2723695442*t)
	Y0 += 0.00000001663*np.cos(0.24097601233 + 102.980899634*t)
	Y0 += 0.00000001297*np.cos(3.46029204668 + 4532.578949411*t)
	Y0 += 0.00000001451*np.cos(5.66628703851 + 316.6525020875*t)
	Y0 += 0.00000001270*np.cos(2.95469445132 + 373.0142209592*t)
	Y0 += 0.00000001460*np.cos(1.42235125301 + 1020.025054274*t)
	Y0 += 0.00000001406*np.cos(0.84231326933 + 560.7104537316*t)
	Y0 += 0.00000001459*np.cos(4.62047341220 + 9352.9756174582*t)
	Y0 += 0.00000001414*np.cos(3.87043606216 + 632.7355552034*t)
	Y0 += 0.00000001665*np.cos(5.34226157718 + 163.5778428151*t)
	Y0 += 0.00000001394*np.cos(3.70666435538 + 1008.9793540101*t)
	Y0 += 0.00000001372*np.cos(5.09085657141 + 1182.9215735329*t)
	Y0 += 0.00000001379*np.cos(5.79481326272 + 315.8706047948*t)
	Y0 += 0.00000001321*np.cos(0.36554718986 + 271.61836777*t)
	Y0 += 0.00000001564*np.cos(6.16373253849 + 3391.4448860056*t)
	Y0 += 0.00000001475*np.cos(5.61366600619 + 5643.1785636774*t)
	Y0 += 0.00000001471*np.cos(0.61030032816 + 2693.601593385*t)
	Y0 += 0.00000001580*np.cos(3.30444982133 + 1477.5945496772*t)
	Y0 += 0.00000001597*np.cos(1.08229581813 + 303.8616966844*t)
	Y0 += 0.00000001295*np.cos(2.80308750215 + 5179.5897827258*t)
	Y0 += 0.00000001282*np.cos(2.45390821025 + 1048.3362299253*t)
	Y0 += 0.00000001623*np.cos(2.82702522323 + 2914.0142358238*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001267*np.cos(3.75487767558 + 114.8721876654*t)
	Y0 += 0.00000001279*np.cos(5.34028961972 + 208.8938614229*t)
	Y0 += 0.00000001279*np.cos(5.83252185405 + 217.7043294531*t)
	Y0 += 0.00000001208*np.cos(6.03949546814 + 115.8835796217*t)
	Y0 += 0.00000001406*np.cos(3.94363693881 + 959.2099172774*t)
	Y0 += 0.00000001426*np.cos(3.54668411045 + 823.9914342234*t)
	Y0 += 0.00000001187*np.cos(5.29569678283 + 2648.454825473*t)
	Y0 += 0.00000001376*np.cos(2.38955780400 + 973.554631358*t)
	Y0 += 0.00000001435*np.cos(5.24207563071 + 1147.4968508808*t)
	Y0 += 0.00000001183*np.cos(4.17236140424 + 415.2918581812*t)
	Y0 += 0.00000001307*np.cos(5.09096433091 + 962.5089310941*t)
	Y0 += 0.00000001460*np.cos(1.81062368165 + 1244.226837624*t)
	Y0 += 0.00000001332*np.cos(0.68009283969 + 896.3253522359*t)
	Y0 += 0.00000001408*np.cos(1.48916422175 + 1560.6187072806*t)
	Y0 += 0.00000001354*np.cos(2.19008098418 + 529.8028396792*t)
	Y0 += 0.00000001236*np.cos(5.87828881803 + 539.0921339558*t)
	Y0 += 0.00000001187*np.cos(4.77583628852 + 1261.6353253633*t)
	Y0 += 0.00000001569*np.cos(4.96637455080 + 1178.9894202698*t)
	Y0 += 0.00000001168*np.cos(1.96403978263 + 832.5894539325*t)
	Y0 += 0.00000001351*np.cos(5.90695241311 + 795.6802585721*t)
	Y0 += 0.00000001188*np.cos(5.75060601791 + 1394.7361962626*t)
	Y0 += 0.00000001182*np.cos(6.04710142267 + 3149.6916025644*t)
	Y0 += 0.00000001278*np.cos(3.39065490978 + 851.4994607226*t)
	Y0 += 0.00000001176*np.cos(1.33279737043 + 251.9052118278*t)
	Y0 += 0.00000001150*np.cos(5.05374956343 + 4105.980758535*t)
	Y0 += 0.00000001245*np.cos(3.08432272519 + 293.4973199767*t)
	Y0 += 0.00000001274*np.cos(2.13259616483 + 165.3441998137*t)
	Y0 += 0.00000001391*np.cos(1.59445777142 + 5860.4098123785*t)
	Y0 += 0.00000001383*np.cos(2.91115338480 + 880.023084695*t)
	Y0 += 0.00000001364*np.cos(3.65670468364 + 673.8375362578*t)
	Y0 += 0.00000001211*np.cos(0.72754477376 + 270.8152186179*t)
	Y0 += 0.00000001220*np.cos(5.76615286425 + 6599.467719648*t)
	Y0 += 0.00000001260*np.cos(4.21792862426 + 95.0160193713*t)
	Y0 += 0.00000001435*np.cos(4.73699005047 + 745.9108218394*t)
	Y0 += 0.00000001175*np.cos(0.45124710680 + 1773.9178027186*t)
	Y0 += 0.00000001373*np.cos(4.69446038699 + 5852.5455058523*t)
	Y0 += 0.00000001156*np.cos(2.09958021403 + 2957.7331481288*t)
	Y0 += 0.00000001148*np.cos(3.66152510897 + 2047.9144150742*t)
	Y0 += 0.00000001139*np.cos(2.68435803005 + 199.0238173266*t)
	Y0 += 0.00000001139*np.cos(2.20526813654 + 227.5743735494*t)
	Y0 += 0.00000001350*np.cos(5.09745513208 + 25440.89230825939*t)
	Y0 += 0.00000001311*np.cos(2.47777507424 + 332.1728723357*t)
	Y0 += 0.00000001176*np.cos(0.25747287404 + 303.0585475323*t)
	Y0 += 0.00000001161*np.cos(0.08009629228 + 2833.2997329078*t)
	Y0 += 0.00000001276*np.cos(4.92819616998 + 613.8737325231*t)
	Y0 += 0.00000001179*np.cos(0.96347481460 + 272.5815756165*t)
	Y0 += 0.00000001122*np.cos(0.92184815863 + 432.8179659995*t)
	Y0 += 0.00000001228*np.cos(4.57812464858 + 91.4563731237*t)
	Y0 += 0.00000001187*np.cos(4.30030791094 + 5863.5912061162*t)
	Y0 += 0.00000001432*np.cos(1.96156899893 + 1467.0701142751*t)
	Y0 += 0.00000001565*np.cos(5.50866075952 + 670.4960838257*t)
	Y0 += 0.00000001460*np.cos(4.02014508155 + 1128.534454464*t)
	Y0 += 0.00000001127*np.cos(0.75894620303 + 1248.1419445446*t)
	Y0 += 0.00000001142*np.cos(3.13725365534 + 1378.0614217062*t)
	Y0 += 0.00000001292*np.cos(4.94892179549 + 101.6083015103*t)
	Y0 += 0.00000001182*np.cos(5.41503430757 + 5540.0857894588*t)
	Y0 += 0.00000001261*np.cos(3.01344786948 + 520.129737539*t)
	Y0 += 0.00000001189*np.cos(1.44697668431 + 934.1977554428*t)
	Y0 += 0.00000001290*np.cos(4.31664662387 + 1403.3342159717*t)
	Y0 += 0.00000001238*np.cos(0.92078746343 + 1383.6904959987*t)
	Y0 += 0.00000001287*np.cos(2.71685606596 + 11.3063326948*t)
	Y0 += 0.00000001429*np.cos(2.57870016615 + 388.7257876691*t)
	Y0 += 0.00000001241*np.cos(1.16374635040 + 938.1299087059*t)
	Y0 += 0.00000001429*np.cos(1.35590972606 + 9367.2027114598*t)
	Y0 += 0.00000001238*np.cos(2.88082011488 + 559.6990617753*t)
	Y0 += 0.00000001464*np.cos(2.19517746458 + 1268.7488723641*t)
	Y0 += 0.00000001475*np.cos(4.07024767243 + 2810.9214616052*t)
	Y0 += 0.00000001114*np.cos(4.80667138601 + 674.4282370888*t)
	Y0 += 0.00000001103*np.cos(3.05975735898 + 531.6967026647*t)
	Y0 += 0.00000001075*np.cos(5.77191306487 + 17.4084877393*t)
	Y0 += 0.00000001301*np.cos(3.01791185503 + 9790.6195085981*t)
	Y0 += 0.00000001100*np.cos(4.42560702702 + 527.6852275245*t)
	Y0 += 0.00000001266*np.cos(5.92426661157 + 5867.5233593793*t)
	Y0 += 0.00000001257*np.cos(0.41197726402 + 877.5754041402*t)
	Y0 += 0.00000001442*np.cos(4.23877549265 + 4113.0943055358*t)
	Y0 += 0.00000001094*np.cos(4.00646645065 + 9896.8936765544*t)
	Y0 += 0.00000001072*np.cos(2.44003133103 + 220.5727011332*t)
	Y0 += 0.00000001072*np.cos(2.44959483556 + 206.0254897428*t)
	Y0 += 0.00000001283*np.cos(6.11791413409 + 9782.7552020719*t)
	Y0 += 0.00000001066*np.cos(0.35413270142 + 313.4711083498*t)
	Y0 += 0.00000001496*np.cos(6.13864478613 + 5436.9930152402*t)
	Y0 += 0.00000001150*np.cos(2.75164397729 + 622.4887985747*t)
	Y0 += 0.00000001081*np.cos(5.43327205124 + 1512.6467653138*t)
	Y0 += 0.00000001101*np.cos(4.55889118971 + 526.7702037878*t)
	Y0 += 0.00000001081*np.cos(5.08897949602 + 304.1223291153*t)
	Y0 += 0.00000001122*np.cos(2.67408029502 + 525.0250986486*t)
	Y0 += 0.00000001099*np.cos(2.14793939788 + 582.3811631341*t)
	Y0 += 0.00000001113*np.cos(2.78895749341 + 184.8449074348*t)
	Y0 += 0.00000001124*np.cos(1.95050273016 + 40.8413486235*t)
	Y0 += 0.00000001156*np.cos(4.91320818501 + 885.4397106664*t)
	Y0 += 0.00000001072*np.cos(5.83506752367 + 206.3456071316*t)
	Y0 += 0.00000001072*np.cos(5.33774395010 + 220.2525837444*t)
	Y0 += 0.00000001303*np.cos(2.12418606135 + 1096.2429414398*t)
	Y0 += 0.00000001170*np.cos(0.54627504485 + 704.8570248948*t)
	Y0 += 0.00000001397*np.cos(3.88391400366 + 1461.4410399826*t)
	Y0 += 0.00000001408*np.cos(3.76229402125 + 1112.0721282287*t)
	Y0 += 0.00000001047*np.cos(6.13974886268 + 2090.3096723752*t)
	Y0 += 0.00000001301*np.cos(6.22683407267 + 875.830299001*t)
	Y0 += 0.00000001288*np.cos(5.13607461897 + 1340.5615255148*t)
	Y0 += 0.00000001299*np.cos(0.71540574041 + 2509.7943162504*t)
	Y0 += 0.00000001230*np.cos(0.13956830728 + 25867.49049913539*t)
	Y0 += 0.00000001139*np.cos(0.41496903697 + 253.4591205053*t)
	Y0 += 0.00000001166*np.cos(3.48880285321 + 2467.3990589494*t)
	Y0 += 0.00000001294*np.cos(5.50067006265 + 1082.0158474382*t)
	Y0 += 0.00000001128*np.cos(1.50250031231 + 1222.2784494481*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001335*np.cos(1.08179722040 + 730.4598875604*t)
	Y0 += 0.00000001131*np.cos(0.03214465517 + 689.6185389369*t)
	Y0 += 0.00000001038*np.cos(0.51297577197 + 1152.1797636693*t)
	Y0 += 0.00000001033*np.cos(1.52450189207 + 4010.0015313172*t)
	Y0 += 0.00000001303*np.cos(1.99200329985 + 945.9942152321*t)
	Y0 += 0.00000001127*np.cos(5.02755449215 + 78477.00852016058*t)
	Y0 += 0.00000001088*np.cos(1.87536175530 + 976.7360250957*t)
	Y0 += 0.00000001199*np.cos(2.54525785509 + 308.3151148093*t)
	Y0 += 0.00000001314*np.cos(2.07607830812 + 701.936263588*t)
	Y0 += 0.00000001105*np.cos(3.15207498933 + 971.1069508032*t)
	Y0 += 0.00000001029*np.cos(6.18632577425 + 1365.4788591073*t)
	Y0 += 0.00000001026*np.cos(0.76317034722 + 521.6142102473*t)
	Y0 += 0.00000001035*np.cos(1.58079454896 + 121.8427223143*t)
	Y0 += 0.00000001330*np.cos(3.46718588783 + 2740.5018994277*t)
	Y0 += 0.00000001129*np.cos(5.61460981892 + 1054.7160637432*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001026*np.cos(3.09324791083 + 2442.2692770358*t)
	Y0 += 0.00000001244*np.cos(5.00296233329 + 761.7400086283*t)
	Y0 += 0.00000001252*np.cos(0.34989378235 + 1116.0042814918*t)
	Y0 += 0.00000001321*np.cos(2.86590848137 + 323.2447842265*t)
	Y0 += 0.00000001279*np.cos(1.94525342708 + 223.1209554245*t)
	Y0 += 0.00000001279*np.cos(2.94437273951 + 203.4772354515*t)
	Y0 += 0.00000001018*np.cos(1.34516588766 + 640.6480458394*t)
	Y0 += 0.00000001055*np.cos(5.07319058758 + 1460.7073267997*t)
	Y0 += 0.00000001015*np.cos(4.28796379199 + 1022.3126761344*t)
	Y0 += 0.00000001258*np.cos(0.69213323852 + 9573.388259897*t)
	Y0 += 0.00000001184*np.cos(1.06455252744 + 9797.7330555989*t)
	Y0 += 0.00000001007*np.cos(5.87812275210 + 102.8321417877*t)
	Y0 += 0.00000001104*np.cos(4.69963929431 + 1276.6131788903*t)
	Y0 += 0.00000001037*np.cos(2.37689196096 + 645.3139122854*t)
	Y0 += 0.00000001241*np.cos(0.02017171913 + 748.406686504*t)
	Y0 += 0.00000001019*np.cos(0.20483353540 + 6247.5131155228*t)
	Y0 += 0.00000001320*np.cos(5.92048945020 + 1127.2624300768*t)
	Y0 += 0.00000001110*np.cos(0.09479876796 + 1397.7051416792*t)
	Y0 += 0.00000001254*np.cos(4.10528340828 + 758.7710632117*t)
	Y0 += 0.00000001119*np.cos(1.80586847421 + 4966.2906872878*t)
	Y0 += 0.00000001393*np.cos(2.24060310557 + 25558.2121764796*t)
	Y0 += 0.00000001197*np.cos(0.06674040925 + 47.061123747*t)
	Y0 += 0.00000000993*np.cos(3.81339502228 + 1759.8337210689*t)
	Y0 += 0.00000001344*np.cos(5.35674518674 + 108.50940019*t)
	Y0 += 0.00000001031*np.cos(3.42249730866 + 714.5358725294*t)
	Y0 += 0.00000001008*np.cos(5.42544405998 + 557.0389328994*t)
	Y0 += 0.00000001003*np.cos(5.72439128757 + 3067.9394693482*t)
	Y0 += 0.00000001170*np.cos(3.04619310978 + 1176.7017984094*t)
	Y0 += 0.00000001030*np.cos(1.19140347405 + 5385.775331163*t)
	Y0 += 0.00000001160*np.cos(4.66675692714 + 152.7445908723*t)
	Y0 += 0.00000001132*np.cos(3.30323864793 + 1467.8208738005*t)
	Y0 += 0.00000001056*np.cos(2.35368791284 + 683.1863154923*t)
	Y0 += 0.00000001201*np.cos(1.52741197289 + 528.4671248172*t)
	Y0 += 0.00000001019*np.cos(2.53037345351 + 599.6466385215*t)
	Y0 += 0.00000001009*np.cos(0.40854433922 + 1939.2449561898*t)
	Y0 += 0.00000001228*np.cos(4.84889327900 + 1439.5096981492*t)
	Y0 += 0.00000001269*np.cos(0.83510696953 + 1239.5439248355*t)
	Y0 += 0.00000000973*np.cos(2.36193993021 + 173.1390703707*t)
	Y0 += 0.00000001082*np.cos(6.08511886961 + 442.639825986*t)
	Y0 += 0.00000001282*np.cos(5.51004335308 + 314.9073969483*t)
	Y0 += 0.00000001108*np.cos(4.52501543913 + 523.5406259403*t)
	Y0 += 0.00000001105*np.cos(5.86158639420 + 199.1201855462*t)
	Y0 += 0.00000001105*np.cos(5.31122507957 + 227.4780053298*t)
	Y0 += 0.00000000965*np.cos(1.83712872363 + 5599.074426601*t)
	Y0 += 0.00000001072*np.cos(3.41208137140 + 572.9799942729*t)
	Y0 += 0.00000001227*np.cos(2.37509830492 + 1973.1328165069*t)
	Y0 += 0.00000000986*np.cos(5.10430433948 + 3679.382567659*t)
	Y0 += 0.00000001186*np.cos(0.73895067297 + 772.9981572133*t)
	Y0 += 0.00000001222*np.cos(1.63996260052 + 775.9671026299*t)
	Y0 += 0.00000001089*np.cos(4.89269944083 + 416.5638825684*t)
	Y0 += 0.00000001180*np.cos(2.37180620952 + 1226.2106027112*t)
	Y0 += 0.00000000953*np.cos(1.64633028007 + 951.4632308302*t)
	Y0 += 0.00000001226*np.cos(4.39692936186 + 25344.9130810416*t)
	Y0 += 0.00000001022*np.cos(3.85581532580 + 968.1380053866*t)
	Y0 += 0.00000001161*np.cos(5.33337222331 + 6327.837393132*t)
	Y0 += 0.00000000959*np.cos(3.23065315419 + 104138.31347085879*t)
	Y0 += 0.00000000950*np.cos(1.34328833506 + 568.2970814844*t)
	Y0 += 0.00000001210*np.cos(6.18765615746 + 2597.6223661672*t)
	Y0 += 0.00000001221*np.cos(3.06185083945 + 1458.472094566*t)
	Y0 += 0.00000000989*np.cos(6.21888180767 + 394.9455627926*t)
	Y0 += 0.00000001092*np.cos(2.10149693935 + 1681.1199692385*t)
	Y0 += 0.00000001155*np.cos(0.22997009337 + 308.5275631304*t)
	Y0 += 0.00000000945*np.cos(2.34748592116 + 731.6837278378*t)
	Y0 += 0.00000000961*np.cos(1.78007954840 + 1333.2355301929*t)
	Y0 += 0.00000001100*np.cos(3.22997983392 + 608.2446582306*t)
	Y0 += 0.00000000937*np.cos(3.34749725600 + 544.5087599272*t)
	Y0 += 0.00000001297*np.cos(2.80101502823 + 1784.2127434571*t)
	Y0 += 0.00000001122*np.cos(0.69750945684 + 877.1023233882*t)
	Y0 += 0.00000000933*np.cos(0.51299958961 + 848.530515306*t)
	Y0 += 0.00000001045*np.cos(1.54081682323 + 1987.2168981566*t)
	Y0 += 0.00000001056*np.cos(0.84339591320 + 62.038977274*t)
	Y0 += 0.00000000999*np.cos(0.90076451228 + 3569.1762464396*t)
	Y0 += 0.00000001005*np.cos(0.28351221664 + 9793.8009023358*t)
	Y0 += 0.00000000930*np.cos(4.21016384068 + 818.574808252*t)
	Y0 += 0.00000001066*np.cos(0.47942092975 + 2306.7901615509*t)
	Y0 += 0.00000000963*np.cos(0.11398671683 + 316.9131345184*t)
	Y0 += 0.00000001221*np.cos(4.50707535867 + 473.068613792*t)
	Y0 += 0.00000001116*np.cos(1.68960080489 + 517.1607921224*t)
	Y0 += 0.00000001044*np.cos(2.16537763505 + 836.5216071956*t)
	Y0 += 0.00000001147*np.cos(5.47459127263 + 633.305004175*t)
	Y0 += 0.00000001052*np.cos(3.11316362179 + 6261.7402095244*t)
	Y0 += 0.00000001072*np.cos(5.82302843412 + 781.5961769224*t)
	Y0 += 0.00000001082*np.cos(3.68063207053 + 2151.0071892928*t)
	Y0 += 0.00000000931*np.cos(0.21521830264 + 354.9979860464*t)
	Y0 += 0.00000000948*np.cos(3.43998144012 + 97.4636999261*t)
	Y0 += 0.00000001057*np.cos(6.03030458165 + 3707.8367556622*t)
	Y0 += 0.00000000960*np.cos(6.20933873501 + 2015.6710861598*t)
	Y0 += 0.00000001049*np.cos(5.33285992294 + 1018.3281332446*t)
	Y0 += 0.00000001139*np.cos(0.28846267487 + 5845.4319588515*t)
	Y0 += 0.00000000914*np.cos(6.19113704199 + 838.218528225*t)
	Y0 += 0.00000000914*np.cos(1.06552716224 + 385.7568422525*t)
	Y0 += 0.00000001042*np.cos(1.84028027185 + 1304.9243545416*t)
	Y0 += 0.00000001203*np.cos(1.07996928802 + 5333.9002410216*t)
	Y0 += 0.00000001048*np.cos(1.94898160418 + 1471.0022675382*t)
	Y0 += 0.00000000931*np.cos(3.02433582418 + 5966.6839803348*t)
	Y0 += 0.00000001121*np.cos(6.06132137788 + 1079.8287993143*t)
	Y0 += 0.00000000973*np.cos(4.25729641570 + 522.529233984*t)
	Y0 += 0.00000001041*np.cos(1.71140114347 + 1186.853726796*t)
	Y0 += 0.00000001248*np.cos(5.81880585315 + 1392.2885157078*t)
	Y0 += 0.00000001071*np.cos(2.37134940495 + 947.5310775671*t)
	Y0 += 0.00000000983*np.cos(6.14597134557 + 1432.3961511484*t)
	Y0 += 0.00000000939*np.cos(4.76698210393 + 632.2624744514*t)
	Y0 += 0.00000000947*np.cos(1.70406168716 + 1791.3262904579*t)
	Y0 += 0.00000000933*np.cos(0.10105086253 + 401.5378449316*t)
	Y0 += 0.00000000899*np.cos(5.66539137251 + 605.9570363702*t)
	Y0 += 0.00000000895*np.cos(4.34232828985 + 774.0095491696*t)
	Y0 += 0.00000001120*np.cos(5.72518062452 + 507.5995645668*t)
	Y0 += 0.00000001109*np.cos(4.52510690641 + 1259.1876448085*t)
	Y0 += 0.00000001167*np.cos(3.02717194449 + 25771.5112719176*t)
	Y0 += 0.00000001011*np.cos(4.96279902162 + 600.5404103988*t)
	Y0 += 0.00000000896*np.cos(1.24835724643 + 6386.16862421*t)
	Y0 += 0.00000000931*np.cos(2.99706770941 + 529.57909051*t)
	Y0 += 0.00000000952*np.cos(0.90233317636 + 1197.8994270599*t)
	Y0 += 0.00000000963*np.cos(0.20943184390 + 770.3380283374*t)
	Y0 += 0.00000000923*np.cos(1.51298250216 + 3171.0322435668*t)
	Y0 += 0.00000000907*np.cos(2.14028131544 + 663.8032279502*t)
	Y0 += 0.00000000906*np.cos(5.11765190175 + 2961.6653013919*t)
	Y0 += 0.00000001214*np.cos(4.42120077268 + 2946.6874478649*t)
	Y0 += 0.00000000967*np.cos(0.98988062069 + 10529.6774158676*t)
	Y0 += 0.00000001179*np.cos(3.99906681922 + 260.9933586314*t)
	Y0 += 0.00000000950*np.cos(0.59456934149 + 944.9828232758*t)
	Y0 += 0.00000000872*np.cos(3.49844276549 + 102.9327155242*t)
	Y0 += 0.00000000956*np.cos(2.92027266913 + 1527.6246188408*t)
	Y0 += 0.00000000902*np.cos(4.43760131078 + 1407.2663692348*t)
	Y0 += 0.00000000970*np.cos(2.49664105561 + 51322.60990139639*t)
	Y0 += 0.00000000871*np.cos(0.48742243908 + 103.252832913*t)
	Y0 += 0.00000000873*np.cos(0.09381959854 + 532.8723588323*t)
	Y0 += 0.00000000943*np.cos(0.71258336966 + 6018.5590704762*t)
	Y0 += 0.00000001016*np.cos(4.70921884112 + 981.4189378842*t)
	Y0 += 0.00000000881*np.cos(4.58021114149 + 2843.5946736463*t)
	Y0 += 0.00000001085*np.cos(0.37811767801 + 1546.5346256309*t)
	Y0 += 0.00000000939*np.cos(3.15073621706 + 12573.2652469836*t)
	Y0 += 0.00000000868*np.cos(0.44886276523 + 449.4927405559*t)
	Y0 += 0.00000001172*np.cos(0.20951776841 + 979.1837056505*t)
	Y0 += 0.00000001152*np.cos(0.35051240732 + 775.4458377681*t)
	Y0 += 0.00000001101*np.cos(5.07266587861 + 494.4786907636*t)
	Y0 += 0.00000001065*np.cos(1.71191506456 + 9775.6416550711*t)
	Y0 += 0.00000000853*np.cos(4.59373677875 + 4760.1051388506*t)
	Y0 += 0.00000000918*np.cos(6.03829321587 + 52168.69273614759*t)
	Y0 += 0.00000000878*np.cos(6.24767898008 + 166.237971691*t)
	Y0 += 0.00000001010*np.cos(1.98220117589 + 480.251596762*t)
	Y0 += 0.00000001152*np.cos(1.04093902543 + 3693.6096616606*t)
	Y0 += 0.00000000960*np.cos(1.81660864656 + 5842.2505651138*t)
	Y0 += 0.00000000859*np.cos(1.05530609054 + 1886.5547581503*t)
	Y0 += 0.00000000877*np.cos(5.41246001857 + 4642.7852706304*t)
	Y0 += 0.00000000845*np.cos(2.85280736082 + 726.3152859762*t)
	Y0 += 0.00000000858*np.cos(5.12251529685 + 1035.002907801*t)
	Y0 += 0.00000000935*np.cos(1.83502346499 + 61.2882177486*t)
	Y0 += 0.00000000840*np.cos(2.81067577434 + 9808.5381846614*t)
	Y0 += 0.00000000959*np.cos(1.37621356390 + 249.6870259366*t)
	Y0 += 0.00000000959*np.cos(0.37181994910 + 176.9111649394*t)
	Y0 += 0.00000000855*np.cos(3.98853878940 + 1310.3933701397*t)
	Y0 += 0.00000000843*np.cos(3.12599906236 + 248.4631856592*t)
	Y0 += 0.00000000843*np.cos(4.90521975782 + 178.1350052168*t)
	Y0 += 0.00000000996*np.cos(0.20876442702 + 1332.4847706675*t)
	Y0 += 0.00000000953*np.cos(0.51927892471 + 1230.1427559743*t)
	Y0 += 0.00000000829*np.cos(4.13735314255 + 1303.2798231389*t)
	Y0 += 0.00000000915*np.cos(0.15291133436 + 1329.3033769298*t)
	Y0 += 0.00000000866*np.cos(4.28206544053 + 1535.488925367*t)
	Y0 += 0.00000000882*np.cos(6.14842643790 + 9683.5945811164*t)
	Y0 += 0.00000000852*np.cos(0.51301141846 + 6004.3319764746*t)
	Y0 += 0.00000000825*np.cos(0.62630510792 + 20007.0864485468*t)
	Y0 += 0.00000000918*np.cos(3.42990447828 + 803.5445650983*t)
	Y0 += 0.00000000853*np.cos(1.59971801488 + 1235.6117715724*t)
	Y0 += 0.00000000951*np.cos(5.46704322360 + 170.9732741062*t)
	Y0 += 0.00000001144*np.cos(1.01612696205 + 982.1526510671*t)
	Y0 += 0.00000000875*np.cos(0.47626060283 + 711.4974911436*t)
	Y0 += 0.00000000905*np.cos(2.71960412461 + 1257.7031721002*t)
	Y0 += 0.00000001152*np.cos(5.33984775483 + 987.7817253596*t)
	Y0 += 0.00000000998*np.cos(1.04631660524 + 6069.7767545534*t)
	Y0 += 0.00000000854*np.cos(0.23340791396 + 6179.9830757728*t)
	Y0 += 0.00000000840*np.cos(5.60050623367 + 1336.4169239306*t)
	Y0 += 0.00000000991*np.cos(3.14797549363 + 720.8986600048*t)
	Y0 += 0.00000000819*np.cos(2.67378067049 + 10316.3783204296*t)
	Y0 += 0.00000000919*np.cos(3.47325211191 + 1026.2448293975*t)
	Y0 += 0.00000000994*np.cos(1.60950672580 + 829.6205085159*t)
	Y0 += 0.00000000943*np.cos(4.17403338141 + 1109.6244476739*t)
	Y0 += 0.00000000927*np.cos(4.19849435960 + 204.91352405*t)
	Y0 += 0.00000000927*np.cos(0.69113180699 + 221.684666826*t)
	Y0 += 0.00000000871*np.cos(0.52354702088 + 9470.2954856784*t)
	Y0 += 0.00000000933*np.cos(4.15364437718 + 1674.0064222377*t)
	Y0 += 0.00000000877*np.cos(4.52268592431 + 653.2306084383*t)
	Y0 += 0.00000000927*np.cos(2.66429940836 + 1962.087116243*t)
	Y0 += 0.00000000880*np.cos(0.13023886547 + 547.8502123593*t)
	Y0 += 0.00000001082*np.cos(5.65042296748 + 26404.2950112308*t)
	Y0 += 0.00000000919*np.cos(4.83467452443 + 1055.1891444952*t)
	Y0 += 0.00000000846*np.cos(6.02295130304 + 931.0163617051*t)
	Y0 += 0.00000001037*np.cos(5.02887266884 + 5805.2599750382*t)
	Y0 += 0.00000000800*np.cos(4.13177049709 + 4635.6717236296*t)
	Y0 += 0.00000000867*np.cos(5.47092894803 + 155.1922714271*t)
	Y0 += 0.00000001053*np.cos(4.90390047531 + 1901.5326116773*t)
	Y0 += 0.00000001079*np.cos(3.72322614378 + 902.9176343749*t)
	Y0 += 0.00000000896*np.cos(0.27836778819 + 580.0935412737*t)
	Y0 += 0.00000001031*np.cos(0.60335376470 + 688.6553310904*t)
	Y0 += 0.00000000798*np.cos(0.89814256581 + 437.9045235708*t)
	Y0 += 0.00000001053*np.cos(1.91920415131 + 859.4161568755*t)
	Y0 += 0.00000000831*np.cos(0.54907671784 + 2748.3662059539*t)
	Y0 += 0.00000000795*np.cos(2.54691720565 + 866.5297038763*t)
	Y0 += 0.00000000840*np.cos(1.48233531283 + 1385.174968707*t)
	Y0 += 0.00000000803*np.cos(4.00105166343 + 19992.85935454519*t)
	Y0 += 0.00000000854*np.cos(0.46873622406 + 1784.9635029825*t)
	Y0 += 0.00000000831*np.cos(5.64600755399 + 898.7730327907*t)
	Y0 += 0.00000000937*np.cos(0.42725418233 + 68.1893164283*t)
	Y0 += 0.00000000972*np.cos(1.58618574208 + 892.5532576672*t)
	Y0 += 0.00000000927*np.cos(3.30290599729 + 1025.4416802454*t)
	Y0 += 0.00000000805*np.cos(1.96267237780 + 913.0001267923*t)
	Y0 += 0.00000001019*np.cos(5.48579524125 + 103.2046488032*t)
	Y0 += 0.00000000847*np.cos(2.97610300430 + 1052.3165672982*t)
	Y0 += 0.00000000873*np.cos(4.08656619449 + 63.6240237188*t)
	Y0 += 0.00000000893*np.cos(0.91586743264 + 63.847772888*t)
	Y0 += 0.00000000793*np.cos(4.26073072769 + 746.1714542703*t)
	Y0 += 0.00000001086*np.cos(1.02446339597 + 592.2030231206*t)
	Y0 += 0.00000000771*np.cos(2.27022333294 + 887.7273325268*t)
	Y0 += 0.00000000779*np.cos(2.54078758579 + 689.4060906158*t)
	Y0 += 0.00000000806*np.cos(1.66859223326 + 10110.1927719924*t)
	Y0 += 0.00000000887*np.cos(1.70334556979 + 26514.5013324502*t)
	Y0 += 0.00000000929*np.cos(2.62709773685 + 1120.148883076*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000789*np.cos(3.20945790021 + 1030.927742186*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000767*np.cos(4.66307945149 + 498.1983957056*t)
	Y0 += 0.00000001021*np.cos(1.40139494002 + 1.6969210294*t)
	Y0 += 0.00000000959*np.cos(1.04789269733 + 6076.8903015542*t)
	Y0 += 0.00000000784*np.cos(5.99841824258 + 5158.2491417234*t)
	Y0 += 0.00000000936*np.cos(0.72034877666 + 841.8900490572*t)
	Y0 += 0.00000000766*np.cos(6.24799605844 + 1101.0264279648*t)
	Y0 += 0.00000000839*np.cos(4.71654625446 + 1231.6272286826*t)
	Y0 += 0.00000001015*np.cos(0.10530028205 + 100.1720129118*t)
	Y0 += 0.00000000778*np.cos(4.04810843349 + 2321.7680150779*t)
	Y0 += 0.00000000866*np.cos(5.12432196817 + 1293.8786542777*t)
	Y0 += 0.00000001032*np.cos(1.17517343066 + 3657.0042963564*t)
	Y0 += 0.00000000947*np.cos(3.08746343216 + 447.7958195265*t)
	Y0 += 0.00000000768*np.cos(1.62756580326 + 845.3320752258*t)
	Y0 += 0.00000000799*np.cos(5.14688268900 + 734.9133056853*t)
	Y0 += 0.00000000908*np.cos(0.26950699609 + 733.428832977*t)
	Y0 += 0.00000000767*np.cos(4.46762890624 + 2439.0878832981*t)
	Y0 += 0.00000000814*np.cos(0.37021427089 + 545.4719677737*t)
	Y0 += 0.00000000758*np.cos(0.34567197825 + 2520.0892569889*t)
	Y0 += 0.00000000769*np.cos(5.87092758190 + 1052.2201990786*t)
	Y0 += 0.00000000777*np.cos(2.78595286028 + 2014.0265547571*t)
	Y0 += 0.00000000882*np.cos(1.95143255195 + 870.4618571394*t)
	Y0 += 0.00000001020*np.cos(5.90465000788 + 1475.6851803267*t)
	Y0 += 0.00000001002*np.cos(2.61282923035 + 52182.9198301492*t)
	Y0 += 0.00000000968*np.cos(0.11565571052 + 273.8536000037*t)
	Y0 += 0.00000001032*np.cos(4.67952456423 + 901.9544265284*t)
	Y0 += 0.00000000798*np.cos(2.99561263866 + 188.2387494936*t)
	Y0 += 0.00000000783*np.cos(4.50695826573 + 664.2763087022*t)
	Y0 += 0.00000000974*np.cos(3.91688033246 + 518.9058972616*t)
	Y0 += 0.00000000839*np.cos(5.64758218929 + 13362.4497067992*t)
	Y0 += 0.00000000787*np.cos(5.13104524009 + 487.1526954417*t)
	Y0 += 0.00000000916*np.cos(3.77881993784 + 655.4176565622*t)
	Y0 += 0.00000000771*np.cos(3.10909230338 + 6058.7310542895*t)
	Y0 += 0.00000000881*np.cos(4.53520937731 + 522.6256022036*t)
	Y0 += 0.00000000849*np.cos(2.69053963232 + 142.6620984549*t)
	Y0 += 0.00000000831*np.cos(5.48519211288 + 436.6324991836*t)
	Y0 += 0.00000000777*np.cos(4.48728323493 + 1459.9565672743*t)
	Y0 += 0.00000000768*np.cos(4.55911217014 + 2093.4910661129*t)
	Y0 += 0.00000000757*np.cos(2.65987497026 + 5495.9816523824*t)
	Y0 += 0.00000000742*np.cos(5.52726117983 + 2332.0629558164*t)
	Y0 += 0.00000000940*np.cos(1.37204266374 + 461.7622810972*t)
	Y0 += 0.00000000881*np.cos(4.14004497053 + 157.4275036608*t)
	Y0 += 0.00000000881*np.cos(3.89117384965 + 269.1706872152*t)
	Y0 += 0.00000000789*np.cos(1.23325676313 + 678.0303219518*t)
	Y0 += 0.00000001033*np.cos(0.17480901728 + 6283.0758499914*t)
	Y0 += 0.00000000984*np.cos(3.96155401430 + 3281.2385647862*t)
	Y0 += 0.00000000831*np.cos(3.47299098336 + 595.7144852584*t)
	Y0 += 0.00000000999*np.cos(1.13314642156 + 920.8644333185*t)
	Y0 += 0.00000000742*np.cos(5.70935160714 + 731.9443602687*t)
	Y0 += 0.00000000731*np.cos(2.60139474945 + 995.6460318858*t)
	Y0 += 0.00000000830*np.cos(1.77407654847 + 1016.8436605363*t)
	Y0 += 0.00000000838*np.cos(2.96887278071 + 1809.4855377226*t)
	Y0 += 0.00000000841*np.cos(2.45745541864 + 1051.3051753419*t)
	Y0 += 0.00000000854*np.cos(0.98057544228 + 260.360219185*t)
	Y0 += 0.00000000744*np.cos(0.83167351532 + 1262.3860848887*t)
	Y0 += 0.00000000741*np.cos(5.23085224752 + 2630.2955782083*t)
	Y0 += 0.00000000993*np.cos(0.70716715579 + 1126.2992222303*t)
	Y0 += 0.00000000720*np.cos(1.56500655520 + 103711.71527998279*t)
	Y0 += 0.00000000776*np.cos(0.11552710493 + 1703.2113697663*t)
	Y0 += 0.00000000781*np.cos(2.19194495830 + 1255.2725378879*t)
	Y0 += 0.00000000984*np.cos(2.53004116896 + 7232.2514589612*t)
	Y0 += 0.00000000729*np.cos(4.65946561531 + 1649.6273998495*t)
	Y0 += 0.00000000795*np.cos(3.18515228074 + 1578.0271950199*t)
	Y0 += 0.00000000785*np.cos(4.60689165591 + 3892.681663097*t)
	Y0 += 0.00000000749*np.cos(2.29649366933 + 785.5283301855*t)
	Y0 += 0.00000000810*np.cos(4.93913245615 + 109.9456887885*t)
	Y0 += 0.00000000719*np.cos(5.79339190715 + 467.4395394995*t)
	Y0 += 0.00000000857*np.cos(3.17633759904 + 1158.5425511447*t)
	Y0 += 0.00000000709*np.cos(3.15027123836 + 2431.2235767719*t)
	Y0 += 0.00000000825*np.cos(5.06498115275 + 1163.4379122543*t)
	Y0 += 0.00000000846*np.cos(0.32817929651 + 669.6447505638*t)
	Y0 += 0.00000000711*np.cos(0.51488865945 + 257.3912737684*t)
	Y0 += 0.00000000720*np.cos(0.23831524300 + 255.6249167698*t)
	Y0 += 0.00000000850*np.cos(6.00519987822 + 893.3564068193*t)
	Y0 += 0.00000000786*np.cos(1.09310702278 + 1877.0105769372*t)
	Y0 += 0.00000000800*np.cos(4.99602201203 + 147.1155165798*t)
	Y0 += 0.00000000800*np.cos(3.03519680815 + 279.4826742962*t)
	Y0 += 0.00000000726*np.cos(1.74105086917 + 119.3950417595*t)
	Y0 += 0.00000000720*np.cos(4.53254360784 + 9988.9407505091*t)
	Y0 += 0.00000000974*np.cos(2.42570914230 + 738.3241940866*t)
	Y0 += 0.00000000825*np.cos(4.40565729511 + 1012.8633231634*t)
	Y0 += 0.00000000928*np.cos(4.77788887117 + 5856.4776591154*t)
	Y0 += 0.00000000729*np.cos(1.61950166057 + 938.8806682313*t)
	Y0 += 0.00000000783*np.cos(6.05642153657 + 227.0049245778*t)
	Y0 += 0.00000000783*np.cos(5.11638993720 + 199.5932662982*t)
	Y0 += 0.00000000711*np.cos(0.78076574241 + 461.1291416508*t)
	Y0 += 0.00000000706*np.cos(3.11783170970 + 740.2817475469*t)
	Y0 += 0.00000000707*np.cos(3.12817541549 + 5654.2242639413*t)
	Y0 += 0.00000000917*np.cos(5.15440738995 + 665.0270682276*t)
	Y0 += 0.00000000707*np.cos(3.00720307782 + 111.6907939277*t)
	Y0 += 0.00000000811*np.cos(4.27025807476 + 1799.1905969841*t)
	Y0 += 0.00000000703*np.cos(0.34276578700 + 809.0135806964*t)
	Y0 += 0.00000000736*np.cos(5.91316802743 + 403.7036411961*t)
	Y0 += 0.00000000782*np.cos(5.65617344255 + 309.230138546*t)
	Y0 += 0.00000000737*np.cos(2.65037863056 + 285.6330134505*t)
	Y0 += 0.00000000817*np.cos(2.85530610777 + 4863.1979130692*t)
	Y0 += 0.00000000684*np.cos(5.85076034411 + 1585.1407420207*t)
	Y0 += 0.00000000685*np.cos(4.29010164874 + 455.0523788792*t)
	Y0 += 0.00000000793*np.cos(3.19405005242 + 5422.7659212386*t)
	Y0 += 0.00000000803*np.cos(5.39520301385 + 1688.9842757647*t)
	Y0 += 0.00000000818*np.cos(3.10302225792 + 391.976617376*t)
	Y0 += 0.00000000705*np.cos(5.82260938168 + 3466.083472221*t)
	Y0 += 0.00000000836*np.cos(3.85309730075 + 570.5323137181*t)
	Y0 += 0.00000000752*np.cos(0.56556241430 + 413.1048100573*t)
	Y0 += 0.00000000681*np.cos(0.83326775082 + 458.090760265*t)
	Y0 += 0.00000000681*np.cos(5.71281585921 + 2143.893642292*t)
	Y0 += 0.00000000743*np.cos(2.21707684604 + 1016.0929010109*t)
	Y0 += 0.00000000702*np.cos(1.24544695479 + 598.8434893694*t)
	Y0 += 0.00000000810*np.cos(3.81368284008 + 614.8369403696*t)
	Y0 += 0.00000000681*np.cos(1.84015126699 + 2954.5517543911*t)
	return Y0




def Saturn_Y1 (t): # 921 terms of order 1

	Y1 = 0.
	Y1 += 0.05373895252
	Y1 += 0.03089676414*np.cos(2.70347020059 + 426.598190876*t)
	Y1 += 0.02740812928*np.cos(4.26667506460 + 206.1855484372*t)
	Y1 += 0.02646734779*np.cos(3.76132299914 + 220.4126424388*t)
	Y1 += 0.00631417689*np.cos(5.03245728319 + 7.1135470008*t)
	Y1 += 0.00256727017*np.cos(1.95352327208 + 639.897286314*t)
	Y1 += 0.00312184641*np.cos(3.25850939353 + 419.4846438752*t)
	Y1 += 0.00189379568*np.cos(2.91502328680 + 433.7117378768*t)
	Y1 += 0.00164086267*np.cos(5.29239224879 + 213.299095438*t)
	Y1 += 0.00116775818*np.cos(5.89150757121 + 110.2063212194*t)
	Y1 += 0.00067189505*np.cos(2.17042977500 + 316.3918696566*t)
	Y1 += 0.00066984273*np.cos(3.63101074215 + 227.5261894396*t)
	Y1 += 0.00032993193*np.cos(4.35526131741 + 199.0720014364*t)
	Y1 += 0.00030623941*np.cos(4.88862019450 + 14.2270940016*t)
	Y1 += 0.00022227517*np.cos(4.62224969869 + 103.0927742186*t)
	Y1 += 0.00018939541*np.cos(1.20409782475 + 853.196381752*t)
	Y1 += 0.00018074789*np.cos(3.51566121826 + 209.3669421749*t)
	Y1 += 0.00017786462*np.cos(4.53214139341 + 217.2312487011*t)
	Y1 += 0.00016316041*np.cos(3.29784030574 + 216.4804891757*t)
	Y1 += 0.00015939705*np.cos(4.74503240139 + 210.1177017003*t)
	Y1 += 0.00016718004*np.cos(3.00200323762 + 632.7837393132*t)
	Y1 += 0.00016150533*np.cos(4.04213724873 + 323.5054166574*t)
	Y1 += 0.00014477333*np.cos(2.10298721499 + 647.0108333148*t)
	Y1 += 0.00011081470*np.cos(4.74085903299 + 117.3198682202*t)
	Y1 += 0.00009902653*np.cos(3.60258639503 + 202.2533951741*t)
	Y1 += 0.00008725278*np.cos(4.46324685676 + 224.3447957019*t)
	Y1 += 0.00006584549*np.cos(4.07328504513 + 309.2783226558*t)
	Y1 += 0.00005504485*np.cos(2.83207431701 + 440.8252848776*t)
	Y1 += 0.00005427246*np.cos(1.03183073701 + 11.0457002639*t)
	Y1 += 0.00004177277*np.cos(3.01038599928 + 412.3710968744*t)
	Y1 += 0.00004047069*np.cos(5.17479134124 + 95.9792272178*t)
	Y1 += 0.00002745113*np.cos(2.52862121261 + 149.5631971346*t)
	Y1 += 0.00002423372*np.cos(2.64373010772 + 522.5774180938*t)
	Y1 += 0.00001744754*np.cos(5.50576132273 + 277.0349937414*t)
	Y1 += 0.00001672526*np.cos(3.18810844159 + 536.8045120954*t)
	Y1 += 0.00001692304*np.cos(2.39926742035 + 422.6660376129*t)
	Y1 += 0.00001545875*np.cos(3.73180287915 + 330.6189636582*t)
	Y1 += 0.00001360664*np.cos(0.45530625979 + 1066.49547719*t)
	Y1 += 0.00001332178*np.cos(3.49199811942 + 234.6397364404*t)
	Y1 += 0.00001300561*np.cos(0.83727576430 + 415.5524906121*t)
	Y1 += 0.00001393361*np.cos(4.62211146668 + 3.1813937377*t)
	Y1 += 0.00001173958*np.cos(2.72608805865 + 846.0828347512*t)
	Y1 += 0.00001314212*np.cos(4.38807267093 + 625.6701923124*t)
	Y1 += 0.00001127628*np.cos(3.87310113490 + 423.4167971383*t)
	Y1 += 0.00001127311*np.cos(1.31087998856 + 860.3099287528*t)
	Y1 += 0.00001519756*np.cos(6.12909098030 + 3.9321532631*t)
	Y1 += 0.00001102045*np.cos(2.50535926173 + 429.7795846137*t)
	Y1 += 0.00001344507*np.cos(1.41793614164 + 210.8514148832*t)
	Y1 += 0.00001331406*np.cos(0.33834520814 + 215.7467759928*t)
	Y1 += 0.00000984782*np.cos(4.06175514589 + 529.6909650946*t)
	Y1 += 0.00000882803*np.cos(3.84618864037 + 437.6438911399*t)
	Y1 += 0.00000845402*np.cos(2.61067150867 + 838.9692877504*t)
	Y1 += 0.00000820885*np.cos(3.17476992262 + 223.5940361765*t)
	Y1 += 0.00000661753*np.cos(5.44592350630 + 742.9900605326*t)
	Y1 += 0.00000689847*np.cos(5.48656147822 + 88.865680217*t)
	Y1 += 0.00000816193*np.cos(4.73301735835 + 21.3406410024*t)
	Y1 += 0.00000711322*np.cos(4.54955881405 + 430.5303441391*t)
	Y1 += 0.00000698870*np.cos(4.56691908682 + 302.164775655*t)
	Y1 += 0.00000597396*np.cos(3.52691223403 + 124.433415221*t)
	Y1 += 0.00000471839*np.cos(2.03826977441 + 654.1243803156*t)
	Y1 += 0.00000479853*np.cos(4.85897867518 + 203.0041546995*t)
	Y1 += 0.00000512378*np.cos(5.88153151176 + 735.8765135318*t)
	Y1 += 0.00000405932*np.cos(2.85402341284 + 85.8272988312*t)
	Y1 += 0.00000405563*np.cos(2.74169565316 + 515.463871093*t)
	Y1 += 0.00000380146*np.cos(4.42849645888 + 191.9584544356*t)
	Y1 += 0.00000369673*np.cos(2.17850899524 + 76.2660712756*t)
	Y1 += 0.00000329674*np.cos(2.25304515644 + 1155.361157407*t)
	Y1 += 0.00000339777*np.cos(1.16732337173 + 217.964961884*t)
	Y1 += 0.00000304932*np.cos(4.89664555631 + 231.4583427027*t)
	Y1 += 0.00000313279*np.cos(0.79690491776 + 628.8515860501*t)
	Y1 += 0.00000312226*np.cos(3.52631355331 + 942.062061969*t)
	Y1 += 0.00000299967*np.cos(0.58486918119 + 208.633228992*t)
	Y1 += 0.00000271553*np.cos(1.13380715292 + 288.0806940053*t)
	Y1 += 0.00000261665*np.cos(5.58043800182 + 18.1592472647*t)
	Y1 += 0.00000336751*np.cos(1.51006955238 + 203.7378678824*t)
	Y1 += 0.00000259741*np.cos(4.42049959331 + 10.2949407385*t)
	Y1 += 0.00000263792*np.cos(1.98500737829 + 362.8622925726*t)
	Y1 += 0.00000289108*np.cos(1.62539765309 + 728.762966531*t)
	Y1 += 0.00000292480*np.cos(0.24003627114 + 222.8603229936*t)
	Y1 += 0.00000213893*np.cos(4.46025867511 + 207.8824694666*t)
	Y1 += 0.00000228306*np.cos(5.83832283113 + 949.1756089698*t)
	Y1 += 0.00000208106*np.cos(3.59333007773 + 218.7157214094*t)
	Y1 += 0.00000208355*np.cos(2.79392574025 + 408.4389436113*t)
	Y1 += 0.00000210228*np.cos(0.51312557889 + 138.5174968707*t)
	Y1 += 0.00000195753*np.cos(1.92286511963 + 52.6901980395*t)
	Y1 += 0.00000194622*np.cos(5.15592319826 + 340.7708920448*t)
	Y1 += 0.00000194009*np.cos(4.64002206209 + 200.7689224658*t)
	Y1 += 0.00000169514*np.cos(5.90010865240 + 350.3321196004*t)
	Y1 += 0.00000167903*np.cos(3.43165870674 + 225.8292684102*t)
	Y1 += 0.00000165942*np.cos(2.65915928084 + 831.8557407496*t)
	Y1 += 0.00000177511*np.cos(3.37006150668 + 210.3783341312*t)
	Y1 += 0.00000177822*np.cos(4.64970159848 + 216.2198567448*t)
	Y1 += 0.00000160353*np.cos(0.38234469263 + 195.1398481733*t)
	Y1 += 0.00000162449*np.cos(4.34655014824 + 956.2891559706*t)
	Y1 += 0.00000145028*np.cos(2.97035649604 + 543.9180590962*t)
	Y1 += 0.00000145034*np.cos(5.01521877128 + 9.5612275556*t)
	Y1 += 0.00000178224*np.cos(4.70070237084 + 160.6088973985*t)
	Y1 += 0.00000170270*np.cos(1.06169886425 + 207.6700211455*t)
	Y1 += 0.00000151139*np.cos(1.56897925752 + 635.9651330509*t)
	Y1 += 0.00000163974*np.cos(0.66806989122 + 218.9281697305*t)
	Y1 += 0.00000136838*np.cos(1.98352486919 + 1471.7530270636*t)
	Y1 += 0.00000164874*np.cos(3.04584528801 + 22.0914005278*t)
	Y1 += 0.00000134654*np.cos(5.96927335823 + 703.6331846174*t)
	Y1 += 0.00000151556*np.cos(3.67396623947 + 127.4717966068*t)
	Y1 += 0.00000153277*np.cos(5.85394341815 + 56.6223513026*t)
	Y1 += 0.00000131057*np.cos(2.45918482900 + 750.1036075334*t)
	Y1 += 0.00000135815*np.cos(3.20272541900 + 1258.4539316256*t)
	Y1 += 0.00000124428*np.cos(2.71560761485 + 447.9388318784*t)
	Y1 += 0.00000135909*np.cos(2.82497232885 + 142.4496501338*t)
	Y1 += 0.00000137107*np.cos(5.58034331705 + 490.3340891794*t)
	Y1 += 0.00000122780*np.cos(0.78945958156 + 1059.3819301892*t)
	Y1 += 0.00000108222*np.cos(1.17614128037 + 565.1156877467*t)
	Y1 += 0.00000122931*np.cos(1.28638505576 + 483.2205421786*t)
	Y1 += 0.00000105358*np.cos(2.01086087701 + 209.106309744*t)
	Y1 += 0.00000105077*np.cos(6.01394978397 + 217.491881132*t)
	Y1 += 0.00000123632*np.cos(0.14236071000 + 12.5301729722*t)
	Y1 += 0.00000098664*np.cos(5.98315192678 + 1279.794572628*t)
	Y1 += 0.00000099427*np.cos(6.13367597022 + 1265.5674786264*t)
	Y1 += 0.00000117145*np.cos(1.93408241498 + 269.9214467406*t)
	Y1 += 0.00000107531*np.cos(0.47701573313 + 424.1505103212*t)
	Y1 += 0.00000105139*np.cos(1.47641840902 + 1045.1548361876*t)
	Y1 += 0.00000128853*np.cos(4.09081439424 + 618.5566453116*t)
	Y1 += 0.00000091193*np.cos(4.71687415100 + 70.8494453042*t)
	Y1 += 0.00000088029*np.cos(0.52735226168 + 1073.6090241908*t)
	Y1 += 0.00000109631*np.cos(3.58034902833 + 265.9892934775*t)
	Y1 += 0.00000084025*np.cos(4.60150990218 + 113.3877149571*t)
	Y1 += 0.00000091314*np.cos(0.73720537017 + 497.4476361802*t)
	Y1 += 0.00000080531*np.cos(3.13922825011 + 650.9429865779*t)
	Y1 += 0.00000082305*np.cos(1.71469351335 + 643.0786800517*t)
	Y1 += 0.00000072994*np.cos(2.40916079132 + 1148.2476104062*t)
	Y1 += 0.00000079808*np.cos(4.98284118355 + 106.2741679563*t)
	Y1 += 0.00000070939*np.cos(0.83631473279 + 251.4321310758*t)
	Y1 += 0.00000076736*np.cos(6.18128713604 + 284.1485407422*t)
	Y1 += 0.00000084108*np.cos(0.20089720996 + 219.4494345923*t)
	Y1 += 0.00000067694*np.cos(3.29161643533 + 636.7158925763*t)
	Y1 += 0.00000068746*np.cos(1.72448117794 + 191.2076949102*t)
	Y1 += 0.00000067011*np.cos(6.07534735470 + 107.0249274817*t)
	Y1 += 0.00000073484*np.cos(2.75710156454 + 344.7030453079*t)
	Y1 += 0.00000063624*np.cos(1.26038981874 + 74.7815985673*t)
	Y1 += 0.00000060209*np.cos(3.59292747590 + 479.2883889155*t)
	Y1 += 0.00000059886*np.cos(1.72462101125 + 1788.1448967202*t)
	Y1 += 0.00000063039*np.cos(2.40834438410 + 436.8931316145*t)
	Y1 += 0.00000063642*np.cos(2.90623173294 + 1574.8458012822*t)
	Y1 += 0.00000061645*np.cos(0.47415613574 + 1375.7737998458*t)
	Y1 += 0.00000063067*np.cos(2.25783021871 + 358.9301393095*t)
	Y1 += 0.00000056656*np.cos(2.85346867563 + 98.8999885246*t)
	Y1 += 0.00000065944*np.cos(1.58727020558 + 207.1487562837*t)
	Y1 += 0.00000058621*np.cos(2.69431743641 + 417.0369633204*t)
	Y1 += 0.00000054845*np.cos(3.63305913358 + 416.3032501375*t)
	Y1 += 0.00000063898*np.cos(0.41807886669 + 235.3904959658*t)
	Y1 += 0.00000051983*np.cos(0.98560774735 + 175.1660598002*t)
	Y1 += 0.00000052017*np.cos(0.44065942413 + 220.4608265486*t)
	Y1 += 0.00000050246*np.cos(5.95122725127 + 1581.959348283*t)
	Y1 += 0.00000066519*np.cos(2.96087412556 + 337.732510659*t)
	Y1 += 0.00000052203*np.cos(6.26845412867 + 121.2520214833*t)
	Y1 += 0.00000048816*np.cos(1.49585273959 + 151.0476698429*t)
	Y1 += 0.00000047109*np.cos(0.39163135029 + 351.8165923087*t)
	Y1 += 0.00000050400*np.cos(6.23334046215 + 429.0458714308*t)
	Y1 += 0.00000048966*np.cos(5.37445400062 + 114.1384744825*t)
	Y1 += 0.00000049995*np.cos(1.08980573833 + 181.0557665236*t)
	Y1 += 0.00000052992*np.cos(2.37357973686 + 4.665866446*t)
	Y1 += 0.00000051283*np.cos(5.32818158756 + 554.0699874828*t)
	Y1 += 0.00000051115*np.cos(3.63154677592 + 934.9485149682*t)
	Y1 += 0.00000048930*np.cos(0.61944877126 + 245.5424243524*t)
	Y1 += 0.00000052265*np.cos(1.76447498585 + 1162.4747044078*t)
	Y1 += 0.00000041901*np.cos(5.63603975380 + 81.7521332162*t)
	Y1 += 0.00000044083*np.cos(0.68386602503 + 205.2223405907*t)
	Y1 += 0.00000040580*np.cos(1.25223435843 + 867.4234757536*t)
	Y1 += 0.00000040978*np.cos(2.17727067387 + 621.7380390493*t)
	Y1 += 0.00000052199*np.cos(5.22313624591 + 404.5067903482*t)
	Y1 += 0.00000038938*np.cos(2.88746633845 + 131.5469622218*t)
	Y1 += 0.00000041367*np.cos(1.28036571274 + 1361.5467058442*t)
	Y1 += 0.00000036349*np.cos(0.31120539101 + 148.0787244263*t)
	Y1 += 0.00000036297*np.cos(4.09378541509 + 444.7574381407*t)
	Y1 += 0.00000036204*np.cos(1.17922364807 + 214.0498549634*t)
	Y1 += 0.00000040865*np.cos(4.28623605561 + 643.8294395771*t)
	Y1 += 0.00000045475*np.cos(0.40542517807 + 842.1506814881*t)
	Y1 += 0.00000036962*np.cos(5.43865166017 + 1052.2683831884*t)
	Y1 += 0.00000034507*np.cos(2.15105522201 + 1464.6394800628*t)
	Y1 += 0.00000034261*np.cos(1.30832375393 + 289.5651667136*t)
	Y1 += 0.00000036821*np.cos(1.40746404714 + 206.1373643274*t)
	Y1 += 0.00000035277*np.cos(4.79548581950 + 295.0512286542*t)
	Y1 += 0.00000038754*np.cos(0.95034448968 + 198.321241911*t)
	Y1 += 0.00000033004*np.cos(3.66317254626 + 177.8743727859*t)
	Y1 += 0.00000032822*np.cos(0.62395825570 + 212.5483359126*t)
	Y1 += 0.00000037519*np.cos(0.81273995929 + 228.276948965*t)
	Y1 += 0.00000032161*np.cos(0.23596694801 + 275.5505210331*t)
	Y1 += 0.00000030977*np.cos(2.76363299639 + 78.7137518304*t)
	Y1 += 0.00000029162*np.cos(4.35941497066 + 248.7238180901*t)
	Y1 += 0.00000031052*np.cos(2.62522341734 + 1891.2376709388*t)
	Y1 += 0.00000033254*np.cos(3.46044658988 + 405.2575498736*t)
	Y1 += 0.00000035352*np.cos(0.80858694073 + 501.3797894433*t)
	Y1 += 0.00000032207*np.cos(1.65110353191 + 414.0680179038*t)
	Y1 += 0.00000026802*np.cos(1.48913028184 + 2104.5367663768*t)
	Y1 += 0.00000033504*np.cos(5.75755276401 + 436.1594184316*t)
	Y1 += 0.00000027476*np.cos(2.28916318049 + 114.3991069134*t)
	Y1 += 0.00000029375*np.cos(4.14201483171 + 214.7835681463*t)
	Y1 += 0.00000027350*np.cos(4.28960125311 + 355.7487455718*t)
	Y1 += 0.00000032491*np.cos(1.41984273462 + 1478.8665740644*t)
	Y1 += 0.00000024664*np.cos(2.99088916204 + 427.5613987225*t)
	Y1 += 0.00000027439*np.cos(0.32819955804 + 1692.1656695024*t)
	Y1 += 0.00000031458*np.cos(0.97131994074 + 32.2433289144*t)
	Y1 += 0.00000024545*np.cos(5.69075638662 + 1898.3512179396*t)
	Y1 += 0.00000023644*np.cos(1.44198198532 + 278.5194664497*t)
	Y1 += 0.00000024790*np.cos(4.17753953454 + 99.1606209555*t)
	Y1 += 0.00000024810*np.cos(5.54564487364 + 425.6349830295*t)
	Y1 += 0.00000023968*np.cos(0.36677339015 + 431.264057322*t)
	Y1 += 0.00000025471*np.cos(2.45870689530 + 69.1525242748*t)
	Y1 += 0.00000022253*np.cos(1.40400187528 + 601.7642506762*t)
	Y1 += 0.00000021879*np.cos(5.82469648186 + 5.4166259714*t)
	Y1 += 0.00000021821*np.cos(2.16944144639 + 299.1263942692*t)
	Y1 += 0.00000022180*np.cos(3.69514971843 + 313.2104759189*t)
	Y1 += 0.00000021267*np.cos(5.26614913504 + 916.9322800554*t)
	Y1 += 0.00000022381*np.cos(1.28311915565 + 576.1613880106*t)
	Y1 += 0.00000020789*np.cos(3.29258683166 + 241.7532834412*t)
	Y1 += 0.00000024965*np.cos(3.35942036955 + 1251.3403846248*t)
	Y1 += 0.00000020940*np.cos(2.47050974766 + 319.5732633943*t)
	Y1 += 0.00000021153*np.cos(4.25482812903 + 1169.5882514086*t)
	Y1 += 0.00000024097*np.cos(1.29392903774 + 39.3568759152*t)
	Y1 += 0.00000021598*np.cos(3.88492023488 + 320.3240229197*t)
	Y1 += 0.00000025319*np.cos(5.93722822520 + 421.93232443*t)
	Y1 += 0.00000023120*np.cos(2.90337843385 + 230.7075831773*t)
	Y1 += 0.00000021611*np.cos(3.34376918112 + 312.4597163935*t)
	Y1 += 0.00000021367*np.cos(3.99569581578 + 327.4375699205*t)
	Y1 += 0.00000020375*np.cos(5.87114204897 + 426.6463749858*t)
	Y1 += 0.00000021067*np.cos(3.32303268835 + 421.1815649046*t)
	Y1 += 0.00000021170*np.cos(1.20539648133 + 221.3758502853*t)
	Y1 += 0.00000019320*np.cos(6.19416200591 + 188.9200730498*t)
	Y1 += 0.00000017858*np.cos(0.13265725774 + 63.7358983034*t)
	Y1 += 0.00000018160*np.cos(3.80256648237 + 205.4347889118*t)
	Y1 += 0.00000017830*np.cos(5.89469972322 + 120.358249606*t)
	Y1 += 0.00000016895*np.cos(1.87814122042 + 1781.0313497194*t)
	Y1 += 0.00000016578*np.cos(2.79198392554 + 508.3503240922*t)
	Y1 += 0.00000016563*np.cos(4.08679914102 + 134.5853436076*t)
	Y1 += 0.00000016458*np.cos(2.73725981634 + 439.1283638482*t)
	Y1 += 0.00000018272*np.cos(5.18806803729 + 6275.9623029906*t)
	Y1 += 0.00000016078*np.cos(0.35327615385 + 778.4147831847*t)
	Y1 += 0.00000016691*np.cos(1.09332093320 + 1677.9385755008*t)
	Y1 += 0.00000017811*np.cos(4.60507339479 + 6290.1893969922*t)
	Y1 += 0.00000018693*np.cos(3.79915612503 + 211.8146227297*t)
	Y1 += 0.00000015558*np.cos(1.80190957772 + 333.657345044*t)
	Y1 += 0.00000017965*np.cos(3.08971573736 + 14.977853527*t)
	Y1 += 0.00000017164*np.cos(0.32859484938 + 10206.1719992102*t)
	Y1 += 0.00000016429*np.cos(2.35675032601 + 2207.6295405954*t)
	Y1 += 0.00000019617*np.cos(0.46012011083 + 696.5196376166*t)
	Y1 += 0.00000020378*np.cos(2.67260865639 + 426.5500067662*t)
	Y1 += 0.00000016720*np.cos(6.02943216083 + 10220.3990932118*t)
	Y1 += 0.00000018307*np.cos(4.61706941936 + 166.828672522*t)
	Y1 += 0.00000015744*np.cos(1.88003442344 + 237.6781178262*t)
	Y1 += 0.00000014844*np.cos(1.57837518408 + 92.0470739547*t)
	Y1 += 0.00000015127*np.cos(6.22734841918 + 710.7467316182*t)
	Y1 += 0.00000013896*np.cos(4.68914749586 + 525.4981794006*t)
	Y1 += 0.00000018459*np.cos(1.12369510709 + 1795.258443721*t)
	Y1 += 0.00000015871*np.cos(3.68232724320 + 182.279606801*t)
	Y1 += 0.00000014181*np.cos(5.76892575123 + 312.1990839626*t)
	Y1 += 0.00000013039*np.cos(1.86499285810 + 87.3117715395*t)
	Y1 += 0.00000013054*np.cos(3.33806013415 + 196.0336200506*t)
	Y1 += 0.00000014553*np.cos(2.98023672350 + 381.3516082374*t)
	Y1 += 0.00000017110*np.cos(6.00385352506 + 432.2272651685*t)
	Y1 += 0.00000012749*np.cos(1.26043486960 + 2420.9286360334*t)
	Y1 += 0.00000013372*np.cos(2.17443872737 + 59.8037450403*t)
	Y1 += 0.00000015239*np.cos(3.75258625939 + 429.5189521828*t)
	Y1 += 0.00000012464*np.cos(2.22284574501 + 757.2171545342*t)
	Y1 += 0.00000012205*np.cos(1.93673309903 + 661.2379273164*t)
	Y1 += 0.00000014070*np.cos(2.49267619933 + 395.578702239*t)
	Y1 += 0.00000013577*np.cos(4.88645694646 + 96.8729990951*t)
	Y1 += 0.00000012848*np.cos(1.86448207878 + 305.3461693927*t)
	Y1 += 0.00000016592*np.cos(3.63905709488 + 1272.6810256272*t)
	Y1 += 0.00000013100*np.cos(0.85481187046 + 849.2642284889*t)
	Y1 += 0.00000013949*np.cos(1.75148537427 + 116.4260963429*t)
	Y1 += 0.00000011819*np.cos(5.25276003174 + 430.79097657*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000013084*np.cos(6.21897330504 + 129.9194771616*t)
	Y1 += 0.00000012158*np.cos(4.26700103392 + 373.9079928365*t)
	Y1 += 0.00000011809*np.cos(5.43652749359 + 2214.7430875962*t)
	Y1 += 0.00000013442*np.cos(3.06902780273 + 1567.7322542814*t)
	Y1 += 0.00000011229*np.cos(4.64413388000 + 230.5645708254*t)
	Y1 += 0.00000013500*np.cos(4.36062336832 + 196.6243208816*t)
	Y1 += 0.00000011166*np.cos(0.07959909309 + 776.9303104764*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000010671*np.cos(4.02549503966 + 426.0769260142*t)
	Y1 += 0.00000013925*np.cos(1.76313918148 + 558.0021407459*t)
	Y1 += 0.00000010673*np.cos(4.24959203585 + 221.1634019642*t)
	Y1 += 0.00000011528*np.cos(3.24851110875 + 432.0148168474*t)
	Y1 += 0.00000011815*np.cos(0.09299240001 + 2008.557539159*t)
	Y1 += 0.00000011593*np.cos(3.42150881999 + 5849.3641121146*t)
	Y1 += 0.00000010706*np.cos(5.32683313201 + 84.3428261229*t)
	Y1 += 0.00000010726*np.cos(5.88519609344 + 192.6921676185*t)
	Y1 += 0.00000010230*np.cos(5.88162921381 + 199.2844497575*t)
	Y1 += 0.00000010068*np.cos(6.07595102211 + 206.706813299*t)
	Y1 += 0.00000010345*np.cos(5.08478659317 + 20.6069278195*t)
	Y1 += 0.00000009919*np.cos(2.32998042308 + 280.9671470045*t)
	Y1 += 0.00000010417*np.cos(2.54605028348 + 343.2185725996*t)
	Y1 += 0.00000011215*np.cos(4.78008790757 + 153.4953503977*t)
	Y1 += 0.00000010484*np.cos(2.87917497547 + 145.6310438715*t)
	Y1 += 0.00000010915*np.cos(1.22365424726 + 199.9657733137*t)
	Y1 += 0.00000009672*np.cos(4.70950839637 + 238.5718897035*t)
	Y1 += 0.00000011766*np.cos(4.65102517362 + 28.4541880032*t)
	Y1 += 0.00000009860*np.cos(1.31027229484 + 572.2292347475*t)
	Y1 += 0.00000010848*np.cos(4.84797546300 + 9779.5738083342*t)
	Y1 += 0.00000009609*np.cos(1.77311660543 + 181.806526049*t)
	Y1 += 0.00000009746*np.cos(3.38579212893 + 184.9879197867*t)
	Y1 += 0.00000009655*np.cos(5.39671219074 + 767.3690829208*t)
	Y1 += 0.00000011807*np.cos(3.76535437114 + 62.2514255951*t)
	Y1 += 0.00000009779*np.cos(0.88460460264 + 188.1693135244*t)
	Y1 += 0.00000010712*np.cos(4.51706019623 + 427.1194557378*t)
	Y1 += 0.00000011504*np.cos(4.56344934969 + 144.1465711632*t)
	Y1 += 0.00000009586*np.cos(0.45566717751 + 159.1244246902*t)
	Y1 += 0.00000009203*np.cos(2.73073415990 + 214.5711198252*t)
	Y1 += 0.00000009203*np.cos(5.30048466028 + 212.0270710508*t)
	Y1 += 0.00000010497*np.cos(6.17177980486 + 41.6444977756*t)
	Y1 += 0.00000009370*np.cos(2.14963964190 + 227.3137411185*t)
	Y1 += 0.00000012234*np.cos(6.18809205263 + 563.6312150384*t)
	Y1 += 0.00000010237*np.cos(4.28152767419 + 244.318584075*t)
	Y1 += 0.00000011381*np.cos(6.15512821138 + 156.6767441354*t)
	Y1 += 0.00000010107*np.cos(2.87828198451 + 5863.5912061162*t)
	Y1 += 0.00000010043*np.cos(0.52437948083 + 226.6324175623*t)
	Y1 += 0.00000009156*np.cos(5.02396736289 + 617.8058857862*t)
	Y1 += 0.00000008851*np.cos(2.89832546376 + 51.2057253312*t)
	Y1 += 0.00000010085*np.cos(3.30668269779 + 259.769518354*t)
	Y1 += 0.00000008596*np.cos(1.23210897186 + 546.956440482*t)
	Y1 += 0.00000009008*np.cos(5.89790029935 + 637.4496057592*t)
	Y1 += 0.00000008925*np.cos(2.22929558479 + 233.9060232575*t)
	Y1 += 0.00000009667*np.cos(3.38327802047 + 326.6868103951*t)
	Y1 += 0.00000011698*np.cos(4.17938557250 + 45.5766510387*t)
	Y1 += 0.00000008767*np.cos(5.40542030217 + 472.1748419147*t)
	Y1 += 0.00000008663*np.cos(1.30416402722 + 267.4737661858*t)
	Y1 += 0.00000009447*np.cos(4.30430679634 + 9793.8009023358*t)
	Y1 += 0.00000010188*np.cos(5.69390908773 + 347.8844390456*t)
	Y1 += 0.00000008373*np.cos(4.61083828197 + 241.6102710893*t)
	Y1 += 0.00000008254*np.cos(1.61618489394 + 963.4027029714*t)
	Y1 += 0.00000008240*np.cos(1.57545403896 + 2097.423219376*t)
	Y1 += 0.00000008267*np.cos(0.93707963365 + 73.297125859*t)
	Y1 += 0.00000009192*np.cos(1.67959848745 + 556.5176680376*t)
	Y1 += 0.00000010532*np.cos(1.25439567343 + 65.2203710117*t)
	Y1 += 0.00000008029*np.cos(0.00151886179 + 244.791664827*t)
	Y1 += 0.00000010377*np.cos(0.86654919644 + 212.4053235607*t)
	Y1 += 0.00000010377*np.cos(0.88148431656 + 214.1928673153*t)
	Y1 += 0.00000009461*np.cos(4.03836049759 + 46.470422916*t)
	Y1 += 0.00000009061*np.cos(1.15906814795 + 206.233732547*t)
	Y1 += 0.00000010521*np.cos(0.59635443681 + 92.940845832*t)
	Y1 += 0.00000008413*np.cos(2.05836489461 + 2524.021410252*t)
	Y1 += 0.00000010716*np.cos(0.83453298030 + 2111.6503133776*t)
	Y1 += 0.00000008001*np.cos(2.82221595266 + 824.7421937488*t)
	Y1 += 0.00000008685*np.cos(3.73032890348 + 220.364458329*t)
	Y1 += 0.00000008026*np.cos(0.76761905754 + 238.4288773516*t)
	Y1 += 0.00000008554*np.cos(0.97000952694 + 137.0330241624*t)
	Y1 += 0.00000008060*np.cos(2.81448650265 + 60.7669528868*t)
	Y1 += 0.00000008882*np.cos(4.25154684026 + 486.4019359163*t)
	Y1 += 0.00000007091*np.cos(2.89138411937 + 692.5874843535*t)
	Y1 += 0.00000007076*np.cos(6.22401435166 + 464.7312265138*t)
	Y1 += 0.00000007187*np.cos(2.33756820807 + 864.2420820159*t)
	Y1 += 0.00000007117*np.cos(4.20299838678 + 282.4516197128*t)
	Y1 += 0.00000007014*np.cos(1.65943646852 + 627.3671133418*t)
	Y1 += 0.00000006953*np.cos(6.15878720133 + 339.2864193365*t)
	Y1 += 0.00000007646*np.cos(1.01232502313 + 173.9422195228*t)
	Y1 += 0.00000006921*np.cos(6.10093552816 + 357.4456666012*t)
	Y1 += 0.00000007299*np.cos(2.37883439450 + 458.8415197904*t)
	Y1 += 0.00000006752*np.cos(3.48073494728 + 77.962992305*t)
	Y1 += 0.00000008038*np.cos(0.12694546060 + 258.8757464767*t)
	Y1 += 0.00000008011*np.cos(1.91772033476 + 23.5758732361*t)
	Y1 += 0.00000006648*np.cos(6.02715969637 + 1286.9081196288*t)
	Y1 += 0.00000006661*np.cos(6.15191523027 + 561.1835344836*t)
	Y1 += 0.00000008707*np.cos(3.94168949686 + 67.6680515665*t)
	Y1 += 0.00000006819*np.cos(2.74418471990 + 131.4039498699*t)
	Y1 += 0.00000006518*np.cos(4.64724104258 + 638.4128136057*t)
	Y1 += 0.00000007597*np.cos(2.99211484721 + 186.472392495*t)
	Y1 += 0.00000006426*np.cos(1.27546614194 + 193.655375465*t)
	Y1 += 0.00000006413*np.cos(5.28516632111 + 1493.093668066*t)
	Y1 += 0.00000007070*np.cos(1.11516171811 + 570.7447620392*t)
	Y1 += 0.00000006371*np.cos(1.52403837626 + 518.6452648307*t)
	Y1 += 0.00000006300*np.cos(5.98089525933 + 411.620337349*t)
	Y1 += 0.00000006668*np.cos(2.23289861343 + 1589.0728952838*t)
	Y1 += 0.00000007215*np.cos(2.75216423983 + 1884.124123938*t)
	Y1 += 0.00000006216*np.cos(0.45259148972 + 171.6545976624*t)
	Y1 += 0.00000006289*np.cos(0.94099317701 + 1994.3304451574*t)
	Y1 += 0.00000006124*np.cos(0.98855335752 + 2737.32050569*t)
	Y1 += 0.00000007637*np.cos(1.81450375930 + 295.1942410061*t)
	Y1 += 0.00000006170*np.cos(6.02456387142 + 128.9562693151*t)
	Y1 += 0.00000006208*np.cos(2.49457325625 + 526.5095713569*t)
	Y1 += 0.00000006540*np.cos(4.88945975145 + 1485.9801210652*t)
	Y1 += 0.00000005995*np.cos(5.17469821167 + 334.5511169213*t)
	Y1 += 0.00000006129*np.cos(3.39549331521 + 211.0114735776*t)
	Y1 += 0.00000006129*np.cos(4.63572550497 + 215.5867172984*t)
	Y1 += 0.00000007666*np.cos(5.59618234503 + 81.8951455681*t)
	Y1 += 0.00000007108*np.cos(6.27572187728 + 427.3489504014*t)
	Y1 += 0.00000005857*np.cos(2.99507812756 + 543.0242872189*t)
	Y1 += 0.00000008076*np.cos(5.35159389958 + 195.8906076987*t)
	Y1 += 0.00000005703*np.cos(4.89941145086 + 274.0660483248*t)
	Y1 += 0.00000005904*np.cos(5.14907268147 + 2531.1349572528*t)
	Y1 += 0.00000006470*np.cos(3.68404764620 + 162.0933701068*t)
	Y1 += 0.00000005632*np.cos(5.49833678714 + 54.1746707478*t)
	Y1 += 0.00000007029*np.cos(4.25905954762 + 329.7251917809*t)
	Y1 += 0.00000006286*np.cos(5.65267510028 + 432.7485300303*t)
	Y1 += 0.00000007824*np.cos(3.36686887016 + 99.9113804809*t)
	Y1 += 0.00000007307*np.cos(4.01074770863 + 611.4430983108*t)
	Y1 += 0.00000005905*np.cos(0.93769875191 + 856.3777754897*t)
	Y1 += 0.00000005596*np.cos(4.20350967343 + 31.019488637*t)
	Y1 += 0.00000006762*np.cos(0.70345352932 + 420.9691165835*t)
	Y1 += 0.00000005918*np.cos(2.28750450549 + 422.405405182*t)
	Y1 += 0.00000006723*np.cos(4.90771973158 + 240.125798381*t)
	Y1 += 0.00000005461*np.cos(2.66176789006 + 342.2553647531*t)
	Y1 += 0.00000006291*np.cos(3.22636360944 + 423.6774295692*t)
	Y1 += 0.00000005758*np.cos(1.74985736492 + 835.0371344873*t)
	Y1 += 0.00000005148*np.cos(5.92672676710 + 488.8496164711*t)
	Y1 += 0.00000005052*np.cos(0.43140093037 + 24.3790223882*t)
	Y1 += 0.00000006211*np.cos(2.76152708645 + 107.7586406646*t)
	Y1 += 0.00000004859*np.cos(0.64868543868 + 29.2049475286*t)
	Y1 += 0.00000004775*np.cos(6.16871863280 + 394.3548619616*t)
	Y1 += 0.00000006172*np.cos(4.62085119316 + 125.9873238985*t)
	Y1 += 0.00000006061*np.cos(0.50690771703 + 252.6559713532*t)
	Y1 += 0.00000004858*np.cos(1.81663890928 + 33.9402499438*t)
	Y1 += 0.00000005700*np.cos(6.27984769112 + 1055.4497769261*t)
	Y1 += 0.00000005004*np.cos(1.63967789274 + 650.1922270525*t)
	Y1 += 0.00000004646*np.cos(5.54769102219 + 291.262087743*t)
	Y1 += 0.00000004947*np.cos(2.70299305311 + 525.7588118315*t)
	Y1 += 0.00000004502*np.cos(2.24091054158 + 167.7224443993*t)
	Y1 += 0.00000005224*np.cos(1.12122143120 + 468.2426886516*t)
	Y1 += 0.00000004559*np.cos(0.15524505071 + 418.5214360287*t)
	Y1 += 0.00000004529*np.cos(4.09375839029 + 273.1028404783*t)
	Y1 += 0.00000005440*np.cos(0.49338802541 + 229.9738699944*t)
	Y1 += 0.00000005826*np.cos(2.31670821643 + 551.031606097*t)
	Y1 += 0.00000006012*np.cos(0.53998869706 + 2428.0421830342*t)
	Y1 += 0.00000004308*np.cos(4.78508097302 + 629.6023455755*t)
	Y1 += 0.00000004780*np.cos(6.05035048896 + 2324.9494088156*t)
	Y1 += 0.00000004415*np.cos(3.50744529852 + 298.2326223919*t)
	Y1 += 0.00000004472*np.cos(5.57992516251 + 361.3778198643*t)
	Y1 += 0.00000004243*np.cos(4.90305834790 + 306.0969289181*t)
	Y1 += 0.00000004295*np.cos(4.84382185270 + 1802.3719907218*t)
	Y1 += 0.00000004246*np.cos(2.54779769462 + 1141.1340634054*t)
	Y1 += 0.00000004281*np.cos(2.96546921101 + 405.9912630565*t)
	Y1 += 0.00000004269*np.cos(3.85746519963 + 201.5196819912*t)
	Y1 += 0.00000004269*np.cos(1.03216096696 + 225.0785088848*t)
	Y1 += 0.00000004121*np.cos(3.44763524659 + 1382.8873468466*t)
	Y1 += 0.00000004115*np.cos(1.38226473702 + 2413.8150890326*t)
	Y1 += 0.00000004332*np.cos(1.78553286268 + 2840.4132799086*t)
	Y1 += 0.00000004392*np.cos(2.70520415735 + 491.8185618877*t)
	Y1 += 0.00000004469*np.cos(4.07802364782 + 428.0826635843*t)
	Y1 += 0.00000004813*np.cos(1.71682749378 + 1905.4647649404*t)
	Y1 += 0.00000004052*np.cos(3.88176872544 + 425.1137181677*t)
	Y1 += 0.00000004203*np.cos(0.84999684256 + 364.3467652809*t)
	Y1 += 0.00000003914*np.cos(5.22293191768 + 28.3111756513*t)
	Y1 += 0.00000003858*np.cos(4.04205370508 + 77.7505439839*t)
	Y1 += 0.00000003915*np.cos(0.63612829951 + 504.561183181*t)
	Y1 += 0.00000003740*np.cos(3.31636767466 + 658.0565335787*t)
	Y1 += 0.00000004998*np.cos(6.14567011515 + 448.6895914038*t)
	Y1 += 0.00000003941*np.cos(5.91209030576 + 433.7599219866*t)
	Y1 += 0.00000004487*np.cos(0.56012010972 + 409.9234163196*t)
	Y1 += 0.00000003616*np.cos(5.35134628835 + 292.0128472684*t)
	Y1 += 0.00000004140*np.cos(1.72820223176 + 397.3932433474*t)
	Y1 += 0.00000004724*np.cos(5.59694115939 + 205.6642835754*t)
	Y1 += 0.00000003566*np.cos(0.22715156216 + 211.6021744086*t)
	Y1 += 0.00000003566*np.cos(4.66247460443 + 214.9960164674*t)
	Y1 += 0.00000004241*np.cos(2.24122643057 + 369.9758395734*t)
	Y1 += 0.00000003519*np.cos(4.97646449150 + 33.1371007917*t)
	Y1 += 0.00000003509*np.cos(2.98078877538 + 189.7232222019*t)
	Y1 += 0.00000003460*np.cos(2.58166716757 + 850.0149880143*t)
	Y1 += 0.00000003452*np.cos(2.08246425974 + 732.6951197941*t)
	Y1 += 0.00000004527*np.cos(5.57565356286 + 220.9339073006*t)
	Y1 += 0.00000003733*np.cos(5.60649943194 + 465.9550667912*t)
	Y1 += 0.00000003963*np.cos(2.49682953173 + 2200.5159935946*t)
	Y1 += 0.00000004640*np.cos(4.65653142987 + 264.5048207692*t)
	Y1 += 0.00000004193*np.cos(6.01638489773 + 170.7608257851*t)
	Y1 += 0.00000003968*np.cos(3.61107686825 + 120.5012619579*t)
	Y1 += 0.00000003785*np.cos(4.56197560432 + 211.6545640353*t)
	Y1 += 0.00000003785*np.cos(3.46924321586 + 214.9436268407*t)
	Y1 += 0.00000004427*np.cos(2.01805201614 + 254.9435932136*t)
	Y1 += 0.00000003319*np.cos(1.07445155196 + 731.9443602687*t)
	Y1 += 0.00000003713*np.cos(0.35483179852 + 203.2647871304*t)
	Y1 += 0.00000003713*np.cos(4.53479436807 + 223.3334037456*t)
	Y1 += 0.00000003167*np.cos(4.96496893225 + 201.9927627432*t)
	Y1 += 0.00000003167*np.cos(6.20784254152 + 224.6054281328*t)
	Y1 += 0.00000003700*np.cos(3.32495693901 + 170.0100662597*t)
	Y1 += 0.00000003091*np.cos(1.60504310764 + 6062.6632075526*t)
	Y1 += 0.00000003678*np.cos(6.16970207201 + 418.0001711669*t)
	Y1 += 0.00000003067*np.cos(0.89802750598 + 441.576044403*t)
	Y1 += 0.00000003169*np.cos(6.06706915544 + 92.7978334801*t)
	Y1 += 0.00000003999*np.cos(0.96003854854 + 494.2662424425*t)
	Y1 += 0.00000003169*np.cos(4.99328407843 + 2847.5268269094*t)
	Y1 += 0.00000003379*np.cos(5.48132058561 + 236.8749686741*t)
	Y1 += 0.00000003100*np.cos(4.13702546039 + 406.954470903*t)
	Y1 += 0.00000002898*np.cos(0.50716531857 + 1080.7225711916*t)
	Y1 += 0.00000002898*np.cos(3.02536240457 + 9992.8729037722*t)
	Y1 += 0.00000002943*np.cos(2.73198845165 + 255.8373650909*t)
	Y1 += 0.00000003459*np.cos(5.70450484288 + 532.8723588323*t)
	Y1 += 0.00000003935*np.cos(2.13947573521 + 425.8474313506*t)
	Y1 += 0.00000002974*np.cos(4.75387274036 + 184.0941479094*t)
	Y1 += 0.00000003866*np.cos(1.18231350391 + 388.4651552382*t)
	Y1 += 0.00000003337*np.cos(4.84172710789 + 128.3655684841*t)
	Y1 += 0.00000003217*np.cos(3.24642675636 + 519.3960243561*t)
	Y1 += 0.00000003232*np.cos(0.69234918409 + 55.1378785943*t)
	Y1 += 0.00000002974*np.cos(5.15832495594 + 630.3360587584*t)
	Y1 += 0.00000002801*np.cos(4.26499278042 + 84.9335269539*t)
	Y1 += 0.00000002747*np.cos(0.59959266926 + 409.1897031367*t)
	Y1 += 0.00000002850*np.cos(3.81973806384 + 220.5245170234*t)
	Y1 += 0.00000002747*np.cos(0.59415209174 + 3053.7123753466*t)
	Y1 += 0.00000002721*np.cos(4.07189880807 + 857.1285350151*t)
	Y1 += 0.00000003018*np.cos(1.90405526939 + 450.9772132642*t)
	Y1 += 0.00000002703*np.cos(2.10024434265 + 344.8460576598*t)
	Y1 += 0.00000002862*np.cos(1.66172273544 + 2221.856634597*t)
	Y1 += 0.00000002669*np.cos(0.66381570062 + 815.0633461142*t)
	Y1 += 0.00000003615*np.cos(3.07446523021 + 135.336103133*t)
	Y1 += 0.00000002874*np.cos(1.65791837564 + 58.1068240109*t)
	Y1 += 0.00000002765*np.cos(4.24403667902 + 5636.0650166766*t)
	Y1 += 0.00000002782*np.cos(4.81585990964 + 638.9340784675*t)
	Y1 += 0.00000002611*np.cos(1.05384317164 + 739.0579072695*t)
	Y1 += 0.00000003024*np.cos(6.08706149799 + 403.0223176399*t)
	Y1 += 0.00000002987*np.cos(1.95584965297 + 1685.0521225016*t)
	Y1 += 0.00000002545*np.cos(2.52803626535 + 455.0523788792*t)
	Y1 += 0.00000002747*np.cos(5.24344205402 + 6076.8903015542*t)
	Y1 += 0.00000002523*np.cos(1.46582251094 + 511.5317178299*t)
	Y1 += 0.00000002510*np.cos(2.32307245332 + 640.8604941605*t)
	Y1 += 0.00000002992*np.cos(2.81022130646 + 462.0229135281*t)
	Y1 += 0.00000002474*np.cos(6.21322173241 + 419.532827985*t)
	Y1 += 0.00000002639*np.cos(4.52480635495 + 487.3651437628*t)
	Y1 += 0.00000002597*np.cos(5.06662259586 + 426.4863162914*t)
	Y1 += 0.00000002429*np.cos(4.60328054292 + 477.8039162072*t)
	Y1 += 0.00000002650*np.cos(5.99488065652 + 398.1440028728*t)
	Y1 += 0.00000002819*np.cos(4.70626423287 + 256.5881246163*t)
	Y1 += 0.00000002444*np.cos(1.68660473943 + 420.4478517217*t)
	Y1 += 0.00000003165*np.cos(4.31988845323 + 200.5564741447*t)
	Y1 += 0.00000003165*np.cos(0.56973771336 + 226.0417167313*t)
	Y1 += 0.00000002712*np.cos(5.93555277060 + 50.4025761791*t)
	Y1 += 0.00000002563*np.cos(0.38164149001 + 10007.0999977738*t)
	Y1 += 0.00000002447*np.cos(3.34321334903 + 219.6618829134*t)
	Y1 += 0.00000002447*np.cos(1.54641281756 + 206.9363079626*t)
	Y1 += 0.00000002560*np.cos(2.60777675851 + 106.0135355254*t)
	Y1 += 0.00000002481*np.cos(4.40404596279 + 2118.7638603784*t)
	Y1 += 0.00000002342*np.cos(5.74881935689 + 402.2191684878*t)
	Y1 += 0.00000002438*np.cos(1.28023647756 + 2730.2069586892*t)
	Y1 += 0.00000003270*np.cos(0.24934461993 + 714.6788848813*t)
	Y1 += 0.00000002615*np.cos(0.89208215786 + 38.1330356378*t)
	Y1 += 0.00000002295*np.cos(0.57260746210 + 502.8642621516*t)
	Y1 += 0.00000002279*np.cos(0.66039697096 + 454.9093665273*t)
	Y1 += 0.00000002946*np.cos(1.37128403088 + 739.8086667949*t)
	Y1 += 0.00000003102*np.cos(3.82184422445 + 927.8349679674*t)
	Y1 += 0.00000002228*np.cos(5.50268808814 + 593.426863398*t)
	Y1 += 0.00000002593*np.cos(0.24109780915 + 172.2452984934*t)
	Y1 += 0.00000002636*np.cos(5.01267010764 + 649.4585138696*t)
	Y1 += 0.00000002219*np.cos(5.68743660683 + 25.2727942655*t)
	Y1 += 0.00000002526*np.cos(3.82490201245 + 540.7366653585*t)
	Y1 += 0.00000002240*np.cos(2.35846114302 + 1457.525933062*t)
	Y1 += 0.00000002132*np.cos(3.02423868473 + 71.6002048296*t)
	Y1 += 0.00000002136*np.cos(5.80815269639 + 186.2117600641*t)
	Y1 += 0.00000002460*np.cos(3.65186422754 + 5650.2921106782*t)
	Y1 += 0.00000002060*np.cos(0.83760116573 + 2310.722314814*t)
	Y1 += 0.00000002152*np.cos(3.87784651070 + 232.942815411*t)
	Y1 += 0.00000002117*np.cos(1.42894515335 + 3156.8051495652*t)
	Y1 += 0.00000002115*np.cos(1.90666946498 + 905.8865797915*t)
	Y1 += 0.00000002597*np.cos(3.47646509433 + 426.7100654606*t)
	Y1 += 0.00000002201*np.cos(1.12610213271 + 434.6749457233*t)
	Y1 += 0.00000002404*np.cos(5.08535872369 + 9580.5018068978*t)
	Y1 += 0.00000002261*np.cos(2.54049627534 + 42.5382696529*t)
	Y1 += 0.00000002519*np.cos(3.61992656089 + 980.6681783588*t)
	Y1 += 0.00000001958*np.cos(0.51006487073 + 610.6923387854*t)
	Y1 += 0.00000002062*np.cos(2.54499257042 + 699.7010313543*t)
	Y1 += 0.00000001937*np.cos(3.50920262578 + 141.2258098564*t)
	Y1 += 0.00000002495*np.cos(4.07951736289 + 6489.2613984286*t)
	Y1 += 0.00000002634*np.cos(0.26482595016 + 2744.4340526908*t)
	Y1 += 0.00000001903*np.cos(1.86707361207 + 1049.0869894507*t)
	Y1 += 0.00000001940*np.cos(4.49422553046 + 622.4887985747*t)
	Y1 += 0.00000001900*np.cos(4.64507172866 + 271.4059194489*t)
	Y1 += 0.00000001918*np.cos(6.14933299248 + 49.5088043018*t)
	Y1 += 0.00000002178*np.cos(1.47792419376 + 254.3528923826*t)
	Y1 += 0.00000002055*np.cos(5.77388045921 + 2641.3412784722*t)
	Y1 += 0.00000001888*np.cos(5.69235432976 + 642.3449668688*t)
	Y1 += 0.00000002182*np.cos(2.85682305202 + 426.8106391971*t)
	Y1 += 0.00000001793*np.cos(1.85965388376 + 419.4364597654*t)
	Y1 += 0.00000001820*np.cos(1.05742317980 + 480.7728616238*t)
	Y1 += 0.00000002325*np.cos(5.50497285155 + 10419.4710946482*t)
	Y1 += 0.00000001779*np.cos(0.73316360703 + 702.1487119091*t)
	Y1 += 0.00000001796*np.cos(2.22306757146 + 240.3864308119*t)
	Y1 += 0.00000001974*np.cos(5.12102350165 + 639.9454704238*t)
	Y1 += 0.00000001773*np.cos(5.62739708151 + 990.2294059144*t)
	Y1 += 0.00000001891*np.cos(1.59279038223 + 533.6231183577*t)
	Y1 += 0.00000002017*np.cos(1.16455816298 + 112.6540017742*t)
	Y1 += 0.00000002182*np.cos(5.68626463817 + 426.3857425549*t)
	Y1 += 0.00000001732*np.cos(0.79114238967 + 724.8308132679*t)
	Y1 += 0.00000001724*np.cos(4.80247738218 + 184.8449074348*t)
	Y1 += 0.00000001980*np.cos(4.51396179003 + 206.2974230218*t)
	Y1 += 0.00000001910*np.cos(3.04477792936 + 175.4266922311*t)
	Y1 += 0.00000002379*np.cos(2.00455891511 + 594.6507036754*t)
	Y1 += 0.00000001734*np.cos(1.82611959703 + 705.1176573257*t)
	Y1 += 0.00000001805*np.cos(5.66213272167 + 9566.2747128962*t)
	Y1 += 0.00000001824*np.cos(5.14397632587 + 420.005908737*t)
	Y1 += 0.00000002040*np.cos(2.38214203493 + 481.7360694703*t)
	Y1 += 0.00000002013*np.cos(3.83948575721 + 685.4739373527*t)
	Y1 += 0.00000002198*np.cos(1.83487758422 + 2001.4439921582*t)
	Y1 += 0.00000001675*np.cos(1.77654694925 + 2.4476805548*t)
	Y1 += 0.00000001830*np.cos(3.41713034070 + 484.7050148869*t)
	Y1 += 0.00000001713*np.cos(6.01421212418 + 457.617679513*t)
	Y1 += 0.00000001701*np.cos(4.27525315421 + 2435.155730035*t)
	Y1 += 0.00000001969*np.cos(2.11243080520 + 5165.3626887242*t)
	Y1 += 0.00000001666*np.cos(3.80593626843 + 1127.2624300768*t)
	Y1 += 0.00000001992*np.cos(1.21200285220 + 16.6747745564*t)
	Y1 += 0.00000001637*np.cos(0.37607532277 + 909.8187330546*t)
	Y1 += 0.00000001728*np.cos(1.03967609565 + 3046.5988283458*t)
	Y1 += 0.00000001691*np.cos(0.50775020289 + 789.4604834486*t)
	Y1 += 0.00000001633*np.cos(4.08902762771 + 168.0525127994*t)
	Y1 += 0.00000001759*np.cos(2.56455172887 + 721.6494195302*t)
	Y1 += 0.00000001786*np.cos(2.70265885565 + 1193.9672737968*t)
	Y1 += 0.00000001652*np.cos(1.38065256963 + 152.5321425512*t)
	Y1 += 0.00000001961*np.cos(1.77700160103 + 143.9341228421*t)
	Y1 += 0.00000001804*np.cos(4.83122115379 + 353.301065017*t)
	Y1 += 0.00000001646*np.cos(5.87987374745 + 1112.0721282287*t)
	Y1 += 0.00000001795*np.cos(1.77560607719 + 305.0855369618*t)
	Y1 += 0.00000001837*np.cos(0.16712025895 + 162.8965192589*t)
	Y1 += 0.00000001572*np.cos(6.09546987334 + 91.7864415238*t)
	Y1 += 0.00000001884*np.cos(1.44716590675 + 2317.8358618148*t)
	Y1 += 0.00000001947*np.cos(3.03979941704 + 268.4369740323*t)
	Y1 += 0.00000001779*np.cos(3.32090155293 + 3333.498879699*t)
	Y1 += 0.00000001734*np.cos(0.96745963616 + 746.9222137957*t)
	Y1 += 0.00000001791*np.cos(5.80059576545 + 624.919432787*t)
	Y1 += 0.00000001937*np.cos(3.12447835337 + 842.9014410135*t)
	Y1 += 0.00000001587*np.cos(1.53900553933 + 2538.2485042536*t)
	Y1 += 0.00000001726*np.cos(2.92947725798 + 835.7878940127*t)
	Y1 += 0.00000001546*np.cos(0.85174846193 + 258.5456780766*t)
	Y1 += 0.00000001736*np.cos(1.52298525836 + 26080.78959457339*t)
	Y1 += 0.00000001620*np.cos(0.30763317476 + 784.0438574772*t)
	Y1 += 0.00000001531*np.cos(5.96261991396 + 5216.5803728014*t)
	Y1 += 0.00000001871*np.cos(5.11950364986 + 206.0736738526*t)
	Y1 += 0.00000001733*np.cos(4.43541173951 + 1332.4847706675*t)
	Y1 += 0.00000001730*np.cos(1.14746042144 + 6069.7767545534*t)
	Y1 += 0.00000001506*np.cos(1.67495816083 + 1101.0264279648*t)
	Y1 += 0.00000001688*np.cos(2.79465260174 + 3347.7259737006*t)
	Y1 += 0.00000001605*np.cos(2.05454244503 + 487.1526954417*t)
	Y1 += 0.00000001633*np.cos(4.83727240810 + 384.0599212231*t)
	Y1 += 0.00000001640*np.cos(4.79487962143 + 774.4826299216*t)
	Y1 += 0.00000001591*np.cos(1.78350637644 + 373.0142209592*t)
	Y1 += 0.00000001662*np.cos(0.99863125096 + 26095.016688575*t)
	Y1 += 0.00000001446*np.cos(5.35692253163 + 221.8971151471*t)
	Y1 += 0.00000001446*np.cos(5.81588894214 + 204.7010757289*t)
	Y1 += 0.00000001554*np.cos(5.58405408827 + 760.25553592*t)
	Y1 += 0.00000001670*np.cos(5.24614942818 + 348.635198571*t)
	Y1 += 0.00000001452*np.cos(4.70023348372 + 1130.2313754934*t)
	Y1 += 0.00000001427*np.cos(5.56166562526 + 97.6761482472*t)
	Y1 += 0.00000001875*np.cos(0.77039124872 + 769.8167634756*t)
	Y1 += 0.00000001443*np.cos(3.07158890839 + 694.0719570618*t)
	Y1 += 0.00000001639*np.cos(3.50228669347 + 426.8588233069*t)
	Y1 += 0.00000001566*np.cos(5.31659707606 + 392.6579409322*t)
	Y1 += 0.00000001601*np.cos(1.14874732984 + 31.492569389*t)
	Y1 += 0.00000001904*np.cos(5.38085542514 + 380.12776796*t)
	Y1 += 0.00000001421*np.cos(4.90813463368 + 287.9376816534*t)
	Y1 += 0.00000001396*np.cos(1.10287761125 + 9146.790069021*t)
	Y1 += 0.00000001431*np.cos(1.66082448408 + 2833.2997329078*t)
	Y1 += 0.00000001885*np.cos(1.15755737985 + 5275.5690099436*t)
	Y1 += 0.00000001602*np.cos(2.55207628612 + 9999.986450773*t)
	Y1 += 0.00000001408*np.cos(3.82839552801 + 348.8476468921*t)
	Y1 += 0.00000001379*np.cos(1.75134819042 + 555.5544601911*t)
	Y1 += 0.00000001368*np.cos(2.25768027500 + 606.7601855223*t)
	Y1 += 0.00000001369*np.cos(4.62332067160 + 681.5417840896*t)
	Y1 += 0.00000001566*np.cos(4.85371280569 + 3163.918696566*t)
	Y1 += 0.00000001489*np.cos(1.47256565119 + 263.7016716171*t)
	Y1 += 0.00000001345*np.cos(0.40544096187 + 449.232108125*t)
	Y1 += 0.00000001347*np.cos(0.95659867183 + 1176.7017984094*t)
	Y1 += 0.00000001506*np.cos(4.98644271497 + 251.1714986449*t)
	Y1 += 0.00000001463*np.cos(0.13381728103 + 69.3649725959*t)
	Y1 += 0.00000001533*np.cos(5.35897682405 + 906.849787638*t)
	Y1 += 0.00000001537*np.cos(4.00254787001 + 393.4610900843*t)
	Y1 += 0.00000001524*np.cos(4.86466679268 + 921.0768816396*t)
	Y1 += 0.00000001330*np.cos(3.29563299950 + 460.5384408198*t)
	Y1 += 0.00000001732*np.cos(5.35967006820 + 1126.2992222303*t)
	Y1 += 0.00000001578*np.cos(4.41469563792 + 190.4045457581*t)
	Y1 += 0.00000001578*np.cos(3.61652318226 + 236.1936451179*t)
	Y1 += 0.00000001333*np.cos(1.44452251314 + 518.3846323998*t)
	Y1 += 0.00000001517*np.cos(4.56505866021 + 3480.3105662226*t)
	Y1 += 0.00000001348*np.cos(3.97556216331 + 17.4084877393*t)
	Y1 += 0.00000001541*np.cos(3.08280299118 + 151.260118164*t)
	Y1 += 0.00000001333*np.cos(0.87141945338 + 282.6640680339*t)
	Y1 += 0.00000001290*np.cos(2.78166040458 + 141.6988906084*t)
	Y1 += 0.00000001548*np.cos(1.15089562508 + 1048.3362299253*t)
	Y1 += 0.00000001703*np.cos(5.79509953170 + 100.6450936638*t)
	Y1 += 0.00000001313*np.cos(1.00529348900 + 319.3126309634*t)
	Y1 += 0.00000001287*np.cos(4.97743606169 + 286.596221297*t)
	Y1 += 0.00000001287*np.cos(3.05378275849 + 140.001969579*t)
	Y1 += 0.00000001284*np.cos(1.25389505833 + 7.1617311106*t)
	Y1 += 0.00000001269*np.cos(0.60500062367 + 180.1619946463*t)
	Y1 += 0.00000001551*np.cos(0.90565423938 + 6.1503391543*t)
	Y1 += 0.00000001321*np.cos(5.40533932982 + 401.3253966105*t)
	Y1 += 0.00000001247*np.cos(3.07584535023 + 187.4356003415*t)
	Y1 += 0.00000001247*np.cos(4.95537346995 + 239.1625905345*t)
	Y1 += 0.00000001670*np.cos(3.20068218026 + 1560.6187072806*t)
	Y1 += 0.00000001246*np.cos(3.36638903654 + 2487.4160449478*t)
	Y1 += 0.00000001227*np.cos(3.22759415891 + 1354.4331588434*t)
	Y1 += 0.00000001237*np.cos(4.96982095855 + 11926.2544136688*t)
	Y1 += 0.00000001244*np.cos(0.04476099962 + 674.4282370888*t)
	Y1 += 0.00000001259*np.cos(4.77947362013 + 823.9914342234*t)
	Y1 += 0.00000001227*np.cos(3.67293743287 + 4127.3213995374*t)
	Y1 += 0.00000001343*np.cos(1.02487927152 + 72.3339180125*t)
	Y1 += 0.00000001396*np.cos(1.29558481851 + 1063.3140834523*t)
	Y1 += 0.00000001231*np.cos(4.01733211314 + 51535.90899683439*t)
	Y1 += 0.00000001385*np.cos(2.69047350261 + 41.0537969446*t)
	Y1 += 0.00000001208*np.cos(0.55094685421 + 3370.1042450032*t)
	Y1 += 0.00000001361*np.cos(0.60826072973 + 313.9441891018*t)
	Y1 += 0.00000001353*np.cos(1.29562446082 + 1056.2005364515*t)
	Y1 += 0.00000001501*np.cos(1.76820220332 + 3914.0223040994*t)
	Y1 += 0.00000001672*np.cos(3.53405579707 + 1244.226837624*t)
	Y1 += 0.00000001294*np.cos(0.43494678616 + 3259.8979237838*t)
	Y1 += 0.00000001192*np.cos(5.25668652917 + 9595.2390892234*t)
	Y1 += 0.00000001186*np.cos(4.29620869798 + 938.8806682313*t)
	Y1 += 0.00000001168*np.cos(2.65330892914 + 74.6385862154*t)
	Y1 += 0.00000001330*np.cos(4.76147886793 + 200.0352092829*t)
	Y1 += 0.00000001330*np.cos(0.12814729866 + 226.5629815931*t)
	Y1 += 0.00000001232*np.cos(3.67245960431 + 188.0263011725*t)
	Y1 += 0.00000001154*np.cos(1.67729267315 + 782.3469364478*t)
	Y1 += 0.00000001209*np.cos(0.44068563547 + 552.5855147745*t)
	Y1 += 0.00000001386*np.cos(4.16778562437 + 527.2432845398*t)
	Y1 += 0.00000001397*np.cos(2.30137095313 + 2516.9078632512*t)
	Y1 += 0.00000001547*np.cos(3.43482102043 + 213.2509113282*t)
	Y1 += 0.00000001114*np.cos(1.57780803639 + 25234.70675982219*t)
	Y1 += 0.00000001387*np.cos(5.86439679069 + 336.8387387817*t)
	Y1 += 0.00000001528*np.cos(6.24034456555 + 3060.8259223474*t)
	Y1 += 0.00000001322*np.cos(3.81888755667 + 501.2367770914*t)
	Y1 += 0.00000001155*np.cos(1.81278387825 + 2090.3096723752*t)
	Y1 += 0.00000001141*np.cos(1.23640832422 + 1144.3154571431*t)
	Y1 += 0.00000001278*np.cos(2.91635929568 + 1038.0412891868*t)
	Y1 += 0.00000001351*np.cos(1.46889117918 + 179.3588454942*t)
	Y1 += 0.00000001167*np.cos(2.75098896132 + 634.4806603426*t)
	Y1 += 0.00000001131*np.cos(2.08666023513 + 1773.9178027186*t)
	Y1 += 0.00000001148*np.cos(3.75033984958 + 1357.6145525811*t)
	Y1 += 0.00000001409*np.cos(0.80723610507 + 1372.5924061081*t)
	Y1 += 0.00000001121*np.cos(2.13314347848 + 366.0436863103*t)
	Y1 += 0.00000001070*np.cos(1.30514111321 + 827.9235874865*t)
	Y1 += 0.00000001137*np.cos(0.05422233304 + 4333.5069479746*t)
	Y1 += 0.00000001097*np.cos(2.32605918661 + 988.532484885*t)
	Y1 += 0.00000001056*np.cos(4.78995933839 + 212.7778305762*t)
	Y1 += 0.00000001288*np.cos(0.28913908894 + 247.2393453818*t)
	Y1 += 0.00000001035*np.cos(0.51476774227 + 1062.5633239269*t)
	Y1 += 0.00000001130*np.cos(2.11237960176 + 1368.660252845*t)
	Y1 += 0.00000001180*np.cos(1.07459117463 + 2921.1277828246*t)
	Y1 += 0.00000001092*np.cos(5.25938351806 + 1314.3255234028*t)
	Y1 += 0.00000001020*np.cos(5.73588714350 + 1596.1864422846*t)
	Y1 += 0.00000001230*np.cos(3.95893223706 + 831.1049812242*t)
	Y1 += 0.00000001086*np.cos(0.65554097744 + 140.9651774255*t)
	Y1 += 0.00000001178*np.cos(0.17068538925 + 7.6348118626*t)
	Y1 += 0.00000001050*np.cos(3.33777919837 + 1791.3262904579*t)
	Y1 += 0.00000001294*np.cos(1.78071318384 + 691.1030116452*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001146*np.cos(5.05013070926 + 220.3007678542*t)
	Y1 += 0.00000001196*np.cos(1.60064335169 + 1459.9565672743*t)
	Y1 += 0.00000001298*np.cos(1.26343370681 + 2634.2277314714*t)
	Y1 += 0.00000001024*np.cos(2.20885054302 + 1026.2448293975*t)
	Y1 += 0.00000001142*np.cos(3.62094396061 + 480.251596762*t)
	Y1 += 0.00000001119*np.cos(3.84255993144 + 1534.7381658416*t)
	Y1 += 0.00000001032*np.cos(0.99207081399 + 241.8709035202*t)
	Y1 += 0.00000001032*np.cos(0.75596269901 + 184.7272873558*t)
	Y1 += 0.00000001000*np.cos(3.70447169258 + 1166.4068576709*t)
	Y1 += 0.00000001095*np.cos(0.46976742311 + 541.5398145106*t)
	Y1 += 0.00000001135*np.cos(5.55554743280 + 25668.418497699*t)
	Y1 += 0.00000001018*np.cos(0.19827209218 + 969.6224780949*t)
	Y1 += 0.00000001035*np.cos(2.08039216504 + 2107.7181601145*t)
	Y1 += 0.00000001021*np.cos(0.97936116353 + 586.3133163972*t)
	Y1 += 0.00000001128*np.cos(2.35318641429 + 398.2870152247*t)
	Y1 += 0.00000001034*np.cos(4.59248984743 + 235.933012687*t)
	Y1 += 0.00000001255*np.cos(2.58348469138 + 945.2434557067*t)
	Y1 += 0.00000001131*np.cos(1.80260354863 + 5481.7545583808*t)
	Y1 += 0.00000000985*np.cos(3.11692018349 + 2004.6253858959*t)
	Y1 += 0.00000000973*np.cos(4.58689241437 + 1696.0978227655*t)
	Y1 += 0.00000001281*np.cos(1.17354221088 + 322.6116447801*t)
	Y1 += 0.00000001311*np.cos(1.69829246657 + 1040.4719233991*t)
	Y1 += 0.00000001133*np.cos(3.28608815192 + 1044.4040766622*t)
	Y1 += 0.00000001023*np.cos(6.17359852630 + 306.830642101*t)
	Y1 += 0.00000001080*np.cos(1.56769032500 + 2906.900688823*t)
	Y1 += 0.00000000947*np.cos(2.80425771264 + 3569.1762464396*t)
	Y1 += 0.00000001048*np.cos(2.96360462842 + 745.9108218394*t)
	Y1 += 0.00000000958*np.cos(1.01512625795 + 5378.6617841622*t)
	Y1 += 0.00000000942*np.cos(1.93042438563 + 114.8721876654*t)
	Y1 += 0.00000000981*np.cos(0.61206352827 + 700.6642392008*t)
	Y1 += 0.00000000943*np.cos(3.77054123407 + 443.8636662634*t)
	Y1 += 0.00000001169*np.cos(2.55431542134 + 1468.5716333259*t)
	Y1 += 0.00000000941*np.cos(2.10164527812 + 119.767548775*t)
	Y1 += 0.00000000997*np.cos(1.49781488558 + 4863.1979130692*t)
	Y1 += 0.00000001058*np.cos(3.10506351339 + 494.4786907636*t)
	Y1 += 0.00000001060*np.cos(6.04870941841 + 25654.19140369739*t)
	Y1 += 0.00000001150*np.cos(2.81140082194 + 1152.1797636693*t)
	Y1 += 0.00000000986*np.cos(3.52646141704 + 5842.2505651138*t)
	Y1 += 0.00000001082*np.cos(3.48267233754 + 731.6837278378*t)
	Y1 += 0.00000001061*np.cos(2.53267332217 + 7.8643065262*t)
	Y1 += 0.00000001246*np.cos(4.88854535253 + 738.7972748386*t)
	Y1 += 0.00000000940*np.cos(0.81063715213 + 97.4155158163*t)
	Y1 += 0.00000000972*np.cos(0.55466768669 + 3473.1970192218*t)
	Y1 += 0.00000001035*np.cos(0.84548736211 + 672.1406152284*t)
	Y1 += 0.00000000932*np.cos(4.76193011807 + 838.218528225*t)
	Y1 += 0.00000000945*np.cos(0.97464731674 + 205.9731001161*t)
	Y1 += 0.00000000945*np.cos(3.91497884985 + 220.6250907599*t)
	Y1 += 0.00000000914*np.cos(0.07220332386 + 1681.1199692385*t)
	Y1 += 0.00000000930*np.cos(0.85222232622 + 1310.3933701397*t)
	Y1 += 0.00000000905*np.cos(0.44194841216 + 12779.4507954208*t)
	Y1 += 0.00000000951*np.cos(2.55095800722 + 418.7338843498*t)
	Y1 += 0.00000000957*np.cos(3.87155467351 + 2751.5475996916*t)
	Y1 += 0.00000001065*np.cos(2.47549936867 + 614.6244920485*t)
	Y1 += 0.00000000913*np.cos(4.49732893500 + 285.3723810196*t)
	Y1 += 0.00000001130*np.cos(4.33302778122 + 1902.2833712027*t)
	Y1 += 0.00000001012*np.cos(0.44789996996 + 1379.7059531089*t)
	Y1 += 0.00000000911*np.cos(1.34750279511 + 1250.5896250994*t)
	Y1 += 0.00000000892*np.cos(3.38913025388 + 4443.713269194*t)
	Y1 += 0.00000000894*np.cos(5.20515813371 + 3803.81598288*t)
	Y1 += 0.00000001011*np.cos(2.41001422307 + 138.6605092226*t)
	Y1 += 0.00000001039*np.cos(3.05654473231 + 2332.0629558164*t)
	Y1 += 0.00000001091*np.cos(1.83710876302 + 123.5396433437*t)
	Y1 += 0.00000000939*np.cos(3.50343473164 + 20213.271996984*t)
	Y1 += 0.00000001131*np.cos(1.92127706230 + 639.8491022042*t)
	Y1 += 0.00000000993*np.cos(5.41814026418 + 635.231419868*t)
	Y1 += 0.00000001014*np.cos(2.27419938832 + 246.4361962297*t)
	Y1 += 0.00000000922*np.cos(4.94995215129 + 9772.4602613334*t)
	Y1 += 0.00000000867*np.cos(1.40600454066 + 2442.2692770358*t)
	Y1 += 0.00000001086*np.cos(4.72298778334 + 1998.2625984205*t)
	Y1 += 0.00000001114*np.cos(5.51408175984 + 318.8395502114*t)
	Y1 += 0.00000000867*np.cos(1.87500015152 + 952.0963702766*t)
	Y1 += 0.00000000866*np.cos(0.93216349587 + 51962.5071877104*t)
	Y1 += 0.00000000872*np.cos(0.35835124427 + 1097.0942747017*t)
	Y1 += 0.00000000876*np.cos(3.23898762254 + 1699.2792165032*t)
	Y1 += 0.00000000861*np.cos(5.35015485056 + 1474.9344208013*t)
	Y1 += 0.00000001041*np.cos(3.52118365739 + 1670.82502850*t)
	Y1 += 0.00000000893*np.cos(1.40847703679 + 3149.6916025644*t)
	Y1 += 0.00000001037*np.cos(1.61883909205 + 756.3233826569*t)
	Y1 += 0.00000000859*np.cos(4.64155099558 + 1347.3196118426*t)
	Y1 += 0.00000001008*np.cos(4.34062461071 + 7.065362891*t)
	Y1 += 0.00000000868*np.cos(2.81754009176 + 12146.6670561076*t)
	Y1 += 0.00000001178*np.cos(4.87566234372 + 1328.5526174044*t)
	Y1 += 0.00000000841*np.cos(4.45584468813 + 535.9107402181*t)
	Y1 += 0.00000000974*np.cos(3.51497366146 + 987.7817253596*t)
	Y1 += 0.00000000845*np.cos(3.42724095402 + 1239.5439248355*t)
	Y1 += 0.00000000845*np.cos(2.85404367064 + 1570.9136480191*t)
	Y1 += 0.00000000936*np.cos(3.41425549096 + 550.1378342197*t)
	Y1 += 0.00000000846*np.cos(1.60464490839 + 2114.8317071153*t)
	Y1 += 0.00000000982*np.cos(6.17335642566 + 1471.0022675382*t)
	Y1 += 0.00000001164*np.cos(4.46540287915 + 3391.4448860056*t)
	Y1 += 0.00000001137*np.cos(0.50785963490 + 6467.9257579616*t)
	Y1 += 0.00000000885*np.cos(1.64388709070 + 608.877797677*t)
	Y1 += 0.00000000832*np.cos(6.23911864828 + 616.3214130779*t)
	Y1 += 0.00000000887*np.cos(0.81421674914 + 3362.9906980024*t)
	Y1 += 0.00000000898*np.cos(4.20351235707 + 5436.9930152402*t)
	Y1 += 0.00000000833*np.cos(5.79841023985 + 883.7951792637*t)
	Y1 += 0.00000000848*np.cos(2.79833225924 + 5158.2491417234*t)
	Y1 += 0.00000000841*np.cos(2.31765589143 + 473.068613792*t)
	Y1 += 0.00000000902*np.cos(1.46957685393 + 477.0007670551*t)
	Y1 += 0.00000000875*np.cos(4.50068448495 + 3494.5376602242*t)
	Y1 += 0.00000000837*np.cos(1.18787622858 + 2854.6403739102*t)
	Y1 += 0.00000000846*np.cos(4.46991640952 + 199.0238173266*t)
	Y1 += 0.00000000846*np.cos(0.41970975707 + 227.5743735494*t)
	Y1 += 0.00000000821*np.cos(2.13215936793 + 4223.3006267552*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000000839*np.cos(0.44907719753 + 220.2001941177*t)
	Y1 += 0.00000000839*np.cos(4.44054896906 + 206.3979967583*t)
	Y1 += 0.00000000801*np.cos(4.03195225550 + 1255.2725378879*t)
	Y1 += 0.00000000827*np.cos(2.10399735762 + 219.891377577*t)
	Y1 += 0.00000000852*np.cos(0.69770700155 + 2950.619601128*t)
	Y1 += 0.00000000854*np.cos(5.92834155433 + 539.9859058331*t)
	Y1 += 0.00000000871*np.cos(5.97413520662 + 10213.285546211*t)
	Y1 += 0.00000000858*np.cos(4.12455323678 + 781.5961769224*t)
	Y1 += 0.00000001068*np.cos(5.79442483670 + 2957.7331481288*t)
	Y1 += 0.00000000849*np.cos(4.58387124471 + 832.5894539325*t)
	Y1 += 0.00000000865*np.cos(0.51942079568 + 2125.8774073792*t)
	Y1 += 0.00000000788*np.cos(2.02294007206 + 749.2098356561*t)
	Y1 += 0.00000001023*np.cos(2.62667117726 + 93.531546663*t)
	Y1 += 0.00000001078*np.cos(2.97011727945 + 1877.0105769372*t)
	Y1 += 0.00000001056*np.cos(2.96418062084 + 214.2623032845*t)
	Y1 += 0.00000000875*np.cos(3.41429492396 + 945.9942152321*t)
	Y1 += 0.00000000763*np.cos(2.68502300380 + 198.1087935899*t)
	Y1 += 0.00000000763*np.cos(2.20460316279 + 228.4893972861*t)
	Y1 += 0.00000000783*np.cos(2.39253729880 + 98.4269077726*t)
	Y1 += 0.00000000808*np.cos(2.01329663652 + 5856.4776591154*t)
	Y1 += 0.00000000831*np.cos(5.62799756997 + 9367.2027114598*t)
	Y1 += 0.00000000852*np.cos(4.01306880569 + 973.554631358*t)
	Y1 += 0.00000000758*np.cos(4.17954417886 + 109.3125493421*t)
	Y1 += 0.00000001032*np.cos(2.50124672205 + 775.233389447*t)
	Y1 += 0.00000000778*np.cos(4.46167796863 + 418.9633790134*t)
	Y1 += 0.00000000763*np.cos(5.67125967655 + 1912.5783119412*t)
	Y1 += 0.00000000949*np.cos(2.87351778014 + 1159.2933106701*t)
	Y1 += 0.00000000752*np.cos(1.93856643038 + 313.4711083498*t)
	Y1 += 0.00000000752*np.cos(6.09265238980 + 113.1270825262*t)
	Y1 += 0.00000000901*np.cos(2.18835198050 + 444.0066786153*t)
	Y1 += 0.00000001017*np.cos(0.80348484502 + 1264.816719101*t)
	Y1 += 0.00000000781*np.cos(1.09088467810 + 4752.9915918498*t)
	Y1 += 0.00000000829*np.cos(3.76042707908 + 3906.9087570986*t)
	Y1 += 0.00000000740*np.cos(0.33707021115 + 1364.7280995819*t)
	Y1 += 0.00000000787*np.cos(4.14285154465 + 953.1077622329*t)
	Y1 += 0.00000000786*np.cos(3.03025765906 + 1385.174968707*t)
	Y1 += 0.00000000743*np.cos(4.94465691744 + 1784.2127434571*t)
	Y1 += 0.00000000730*np.cos(1.54029484212 + 1365.4788591073*t)
	Y1 += 0.00000000745*np.cos(1.32328297416 + 4017.115078318*t)
	Y1 += 0.00000000884*np.cos(2.91900213011 + 114.9416236346*t)
	Y1 += 0.00000000799*np.cos(1.90491555917 + 495.9631634719*t)
	Y1 += 0.00000000720*np.cos(2.14719013122 + 878.3261636656*t)
	Y1 += 0.00000000910*np.cos(5.59941883957 + 213.8203602998*t)
	Y1 += 0.00000001001*np.cos(1.63769179212 + 4230.414173756*t)
	Y1 += 0.00000000717*np.cos(5.56374471646 + 103925.01437542078*t)
	Y1 += 0.00000000744*np.cos(5.01299895798 + 5422.7659212386*t)
	Y1 += 0.00000000896*np.cos(4.09061813923 + 25661.3049506982*t)
	Y1 += 0.00000000714*np.cos(2.89023492932 + 2115.5824666407*t)
	Y1 += 0.00000000723*np.cos(6.18405509738 + 662.531203563*t)
	Y1 += 0.00000000713*np.cos(4.36612152570 + 1663.7114814992*t)
	Y1 += 0.00000000745*np.cos(5.54206315448 + 1578.0271950199*t)
	Y1 += 0.00000000706*np.cos(0.01886419763 + 664.2763087022*t)
	Y1 += 0.00000000736*np.cos(4.11752977909 + 1460.7073267997*t)
	Y1 += 0.00000000977*np.cos(1.87199705293 + 1987.2168981566*t)
	Y1 += 0.00000000825*np.cos(2.88680810425 + 498.9321088885*t)
	Y1 += 0.00000000729*np.cos(2.81635363996 + 51742.09454527159*t)
	Y1 += 0.00000000705*np.cos(4.49937953677 + 275.338072712*t)
	Y1 += 0.00000000957*np.cos(2.77042684861 + 433.663553767*t)
	Y1 += 0.00000000825*np.cos(3.13361237855 + 817.628646748*t)
	Y1 += 0.00000000711*np.cos(0.32918457858 + 205.9249160063*t)
	Y1 += 0.00000000711*np.cos(4.56044158801 + 220.6732748697*t)
	Y1 += 0.00000000792*np.cos(5.07640935202 + 561.934294009*t)
	Y1 += 0.00000000815*np.cos(4.55283923414 + 3355.8771510016*t)
	Y1 += 0.00000000796*np.cos(0.85220984274 + 19786.67380610799*t)
	Y1 += 0.00000000706*np.cos(5.83567464088 + 644.56315276*t)
	Y1 += 0.00000000693*np.cos(0.86742075683 + 25448.00585526019*t)
	Y1 += 0.00000000775*np.cos(4.17411042862 + 620.253566341*t)
	Y1 += 0.00000000785*np.cos(3.26469936926 + 1585.1407420207*t)
	Y1 += 0.00000000692*np.cos(1.24760556574 + 1165.3954657146*t)
	Y1 += 0.00000000960*np.cos(2.16058060627 + 2826.186185907*t)
	Y1 += 0.00000000681*np.cos(1.83626169258 + 100.3844612329*t)
	Y1 += 0.00000000694*np.cos(3.92108200272 + 107.2855599126*t)
	Y1 += 0.00000000780*np.cos(4.34812306979 + 2321.7680150779*t)
	Y1 += 0.00000000692*np.cos(4.70527378160 + 3590.516887442*t)
	Y1 += 0.00000000681*np.cos(2.46730626644 + 3885.5681160962*t)
	Y1 += 0.00000000687*np.cos(1.26279091079 + 1261.6353253633*t)
	Y1 += 0.00000000695*np.cos(1.75702964176 + 812.9457339595*t)
	Y1 += 0.00000000826*np.cos(5.98430782385 + 284.8993002676*t)
	return Y1*t




def Saturn_Y2 (t): # 464 terms of order 2

	Y2 = 0.
	Y2 += 0.00563545688*np.cos(5.97115835983 + 206.1855484372*t)
	Y2 += 0.00546856143*np.cos(2.05154974712 + 220.4126424388*t)
	Y2 += 0.00458462799
	Y2 += 0.00362190876*np.cos(0.89540102818 + 213.299095438*t)
	Y2 += 0.00225456249*np.cos(0.91699830789 + 426.598190876*t)
	Y2 += 0.00088376134*np.cos(3.30289743790 + 7.1135470008*t)
	Y2 += 0.00050087062*np.cos(1.12976577868 + 433.7117378768*t)
	Y2 += 0.00045503682*np.cos(5.07669915666 + 419.4846438752*t)
	Y2 += 0.00032887404*np.cos(0.02089587128 + 639.897286314*t)
	Y2 += 0.00027192023*np.cos(1.92638417379 + 227.5261894396*t)
	Y2 += 0.00013247777*np.cos(6.07692233033 + 199.0720014364*t)
	Y2 += 0.00010424268*np.cos(3.18247070949 + 14.2270940016*t)
	Y2 += 0.00006672789*np.cos(4.24754247893 + 110.2063212194*t)
	Y2 += 0.00004657269*np.cos(0.26558212048 + 647.0108333148*t)
	Y2 += 0.00004932685*np.cos(1.51301176465 + 216.4804891757*t)
	Y2 += 0.00004788186*np.cos(0.24337888601 + 210.1177017003*t)
	Y2 += 0.00004165917*np.cos(3.73203571740 + 316.3918696566*t)
	Y2 += 0.00003508567*np.cos(5.49278691726 + 853.196381752*t)
	Y2 += 0.00002742669*np.cos(6.21942410610 + 103.0927742186*t)
	Y2 += 0.00002660411*np.cos(1.58795353685 + 209.3669421749*t)
	Y2 += 0.00002540502*np.cos(1.07964699287 + 440.8252848776*t)
	Y2 += 0.00002567284*np.cos(0.16811215438 + 217.2312487011*t)
	Y2 += 0.00002507213*np.cos(3.11896693485 + 117.3198682202*t)
	Y2 += 0.00002158545*np.cos(4.99876489338 + 632.7837393132*t)
	Y2 += 0.00001828667*np.cos(2.43398377331 + 323.5054166574*t)
	Y2 += 0.00001351292*np.cos(4.81674779715 + 412.3710968744*t)
	Y2 += 0.00001177094*np.cos(5.84487292439 + 309.2783226558*t)
	Y2 += 0.00000804686*np.cos(1.78663039116 + 234.6397364404*t)
	Y2 += 0.00000890962*np.cos(0.57870923865 + 95.9792272178*t)
	Y2 += 0.00000806323*np.cos(5.80160469505 + 202.2533951741*t)
	Y2 += 0.00000737326*np.cos(2.29003982090 + 224.3447957019*t)
	Y2 += 0.00000439328*np.cos(2.02776827506 + 330.6189636582*t)
	Y2 += 0.00000427442*np.cos(5.71757576099 + 860.3099287528*t)
	Y2 += 0.00000377335*np.cos(5.39640588055 + 11.0457002639*t)
	Y2 += 0.00000438738*np.cos(3.04003133763 + 21.3406410024*t)
	Y2 += 0.00000404595*np.cos(1.38253517416 + 223.5940361765*t)
	Y2 += 0.00000400049*np.cos(0.64827543918 + 429.7795846137*t)
	Y2 += 0.00000330461*np.cos(4.70864137961 + 1066.49547719*t)
	Y2 += 0.00000313557*np.cos(2.87420547669 + 3.1813937377*t)
	Y2 += 0.00000356011*np.cos(0.49515346590 + 422.6660376129*t)
	Y2 += 0.00000283801*np.cos(0.92471217472 + 88.865680217*t)
	Y2 += 0.00000276595*np.cos(0.06669144413 + 625.6701923124*t)
	Y2 += 0.00000264830*np.cos(1.47289826706 + 536.8045120954*t)
	Y2 += 0.00000274267*np.cos(0.07990244299 + 302.164775655*t)
	Y2 += 0.00000265498*np.cos(5.80586423553 + 423.4167971383*t)
	Y2 += 0.00000243984*np.cos(0.24814637625 + 654.1243803156*t)
	Y2 += 0.00000263236*np.cos(1.75838078242 + 124.433415221*t)
	Y2 += 0.00000234804*np.cos(1.98441386459 + 3.9321532631*t)
	Y2 += 0.00000222884*np.cos(6.17115980346 + 191.9584544356*t)
	Y2 += 0.00000229042*np.cos(0.40578151728 + 203.0041546995*t)
	Y2 += 0.00000193642*np.cos(0.77773603724 + 149.5631971346*t)
	Y2 += 0.00000249913*np.cos(3.74336024074 + 529.6909650946*t)
	Y2 += 0.00000115588*np.cos(0.89164509195 + 277.0349937414*t)
	Y2 += 0.00000109123*np.cos(2.57234111431 + 10.2949407385*t)
	Y2 += 0.00000104394*np.cos(4.34072678547 + 515.463871093*t)
	Y2 += 0.00000111821*np.cos(3.97880150457 + 522.5774180938*t)
	Y2 += 0.00000123782*np.cos(1.71078775140 + 437.6438911399*t)
	Y2 += 0.00000102074*np.cos(5.33636424684 + 846.0828347512*t)
	Y2 += 0.00000089666*np.cos(2.38634979171 + 415.5524906121*t)
	Y2 += 0.00000094080*np.cos(0.34838778915 + 430.5303441391*t)
	Y2 += 0.00000082635*np.cos(0.98367627117 + 447.9388318784*t)
	Y2 += 0.00000080158*np.cos(3.02403811252 + 231.4583427027*t)
	Y2 += 0.00000056165*np.cos(3.57976541726 + 18.1592472647*t)
	Y2 += 0.00000059355*np.cos(3.25639427388 + 728.762966531*t)
	Y2 += 0.00000055421*np.cos(4.71536076772 + 838.9692877504*t)
	Y2 += 0.00000049553*np.cos(1.20225257432 + 543.9180590962*t)
	Y2 += 0.00000045494*np.cos(4.35717735333 + 831.8557407496*t)
	Y2 += 0.00000046592*np.cos(2.16397372306 + 195.1398481733*t)
	Y2 += 0.00000045784*np.cos(4.72127813952 + 408.4389436113*t)
	Y2 += 0.00000045096*np.cos(5.87984776956 + 618.5566453116*t)
	Y2 += 0.00000039015*np.cos(4.89730697683 + 1073.6090241908*t)
	Y2 += 0.00000037698*np.cos(5.37392517178 + 1059.3819301892*t)
	Y2 += 0.00000044163*np.cos(5.32028640042 + 942.062061969*t)
	Y2 += 0.00000034252*np.cos(6.24954297345 + 362.8622925726*t)
	Y2 += 0.00000043261*np.cos(4.50272466853 + 742.9900605326*t)
	Y2 += 0.00000042263*np.cos(5.91441597118 + 635.9651330509*t)
	Y2 += 0.00000036033*np.cos(4.88958618693 + 222.8603229936*t)
	Y2 += 0.00000028666*np.cos(2.89210881124 + 113.3877149571*t)
	Y2 += 0.00000030304*np.cos(1.28676234140 + 56.6223513026*t)
	Y2 += 0.00000033922*np.cos(0.59559534499 + 436.8931316145*t)
	Y2 += 0.00000037552*np.cos(0.57341890891 + 85.8272988312*t)
	Y2 += 0.00000036126*np.cos(3.11147910034 + 203.7378678824*t)
	Y2 += 0.00000029536*np.cos(3.76331314778 + 269.9214467406*t)
	Y2 += 0.00000034388*np.cos(6.09889554857 + 643.0786800517*t)
	Y2 += 0.00000031901*np.cos(1.14481756518 + 337.732510659*t)
	Y2 += 0.00000026875*np.cos(1.14516402265 + 131.5469622218*t)
	Y2 += 0.00000025259*np.cos(0.69371609826 + 750.1036075334*t)
	Y2 += 0.00000028840*np.cos(3.94162037781 + 1279.794572628*t)
	Y2 += 0.00000024873*np.cos(0.44942144561 + 76.2660712756*t)
	Y2 += 0.00000024820*np.cos(1.10294034290 + 81.7521332162*t)
	Y2 += 0.00000024784*np.cos(4.17997238824 + 1155.361157407*t)
	Y2 += 0.00000025349*np.cos(3.01894544341 + 483.2205421786*t)
	Y2 += 0.00000023209*np.cos(5.71293795197 + 867.4234757536*t)
	Y2 += 0.00000021337*np.cos(0.28233505485 + 295.0512286542*t)
	Y2 += 0.00000021014*np.cos(2.22286425893 + 160.6088973985*t)
	Y2 += 0.00000020843*np.cos(5.58798240327 + 288.0806940053*t)
	Y2 += 0.00000021918*np.cos(3.17518895554 + 1045.1548361876*t)
	Y2 += 0.00000020760*np.cos(5.62171781320 + 416.3032501375*t)
	Y2 += 0.00000020311*np.cos(0.53682587226 + 22.0914005278*t)
	Y2 += 0.00000019660*np.cos(4.12343704195 + 1148.2476104062*t)
	Y2 += 0.00000020049*np.cos(3.60192475616 + 70.8494453042*t)
	Y2 += 0.00000019267*np.cos(5.28623997942 + 497.4476361802*t)
	Y2 += 0.00000023162*np.cos(2.25252644106 + 956.2891559706*t)
	Y2 += 0.00000016596*np.cos(5.19612423608 + 628.8515860501*t)
	Y2 += 0.00000019471*np.cos(2.29694410644 + 63.7358983034*t)
	Y2 += 0.00000019338*np.cos(4.99775249418 + 1258.4539316256*t)
	Y2 += 0.00000017318*np.cos(1.50339429745 + 107.0249274817*t)
	Y2 += 0.00000015416*np.cos(1.59544914625 + 241.7532834412*t)
	Y2 += 0.00000015048*np.cos(2.45248308283 + 138.5174968707*t)
	Y2 += 0.00000015098*np.cos(5.93836982612 + 265.9892934775*t)
	Y2 += 0.00000016202*np.cos(4.47797857238 + 344.7030453079*t)
	Y2 += 0.00000019674*np.cos(0.51504291324 + 200.7689224658*t)
	Y2 += 0.00000016443*np.cos(5.11024344770 + 405.2575498736*t)
	Y2 += 0.00000018325*np.cos(4.26463276211 + 52.6901980395*t)
	Y2 += 0.00000018701*np.cos(4.60015871543 + 142.4496501338*t)
	Y2 += 0.00000018184*np.cos(1.23335576012 + 225.8292684102*t)
	Y2 += 0.00000018137*np.cos(5.36395571858 + 934.9485149682*t)
	Y2 += 0.00000017086*np.cos(4.39727548001 + 1052.2683831884*t)
	Y2 += 0.00000013721*np.cos(0.54585194233 + 358.9301393095*t)
	Y2 += 0.00000017699*np.cos(1.09183113450 + 340.7708920448*t)
	Y2 += 0.00000015349*np.cos(4.02900442305 + 490.3340891794*t)
	Y2 += 0.00000013441*np.cos(2.93226064342 + 6290.1893969922*t)
	Y2 += 0.00000012938*np.cos(5.57228673197 + 181.0557665236*t)
	Y2 += 0.00000013344*np.cos(3.33822391651 + 106.2741679563*t)
	Y2 += 0.00000015757*np.cos(1.02090474834 + 650.9429865779*t)
	Y2 += 0.00000013152*np.cos(0.57129323430 + 6275.9623029906*t)
	Y2 += 0.00000013637*np.cos(4.63945882031 + 284.1485407422*t)
	Y2 += 0.00000012435*np.cos(0.92453447284 + 735.8765135318*t)
	Y2 += 0.00000012303*np.cos(2.19066097291 + 444.7574381407*t)
	Y2 += 0.00000012692*np.cos(5.22300147317 + 1375.7737998458*t)
	Y2 += 0.00000012628*np.cos(4.35563394629 + 10220.3990932118*t)
	Y2 += 0.00000011807*np.cos(4.77484476112 + 424.1505103212*t)
	Y2 += 0.00000012355*np.cos(1.99468333352 + 10206.1719992102*t)
	Y2 += 0.00000011234*np.cos(1.25840483834 + 350.3321196004*t)
	Y2 += 0.00000013925*np.cos(5.46758177566 + 636.7158925763*t)
	Y2 += 0.00000012431*np.cos(5.70697352257 + 949.1756089698*t)
	Y2 += 0.00000010816*np.cos(5.57657783615 + 127.4717966068*t)
	Y2 += 0.00000010468*np.cos(2.47282916923 + 245.5424243524*t)
	Y2 += 0.00000010243*np.cos(4.11036997935 + 703.6331846174*t)
	Y2 += 0.00000009824*np.cos(4.14183224295 + 12.5301729722*t)
	Y2 += 0.00000010114*np.cos(3.97585916137 + 1471.7530270636*t)
	Y2 += 0.00000011347*np.cos(5.52210735319 + 351.8165923087*t)
	Y2 += 0.00000009198*np.cos(3.91003631710 + 1464.6394800628*t)
	Y2 += 0.00000010107*np.cos(4.01464967571 + 235.3904959658*t)
	Y2 += 0.00000008422*np.cos(0.17788593244 + 661.2379273164*t)
	Y2 += 0.00000011523*np.cos(4.28038150916 + 191.2076949102*t)
	Y2 += 0.00000008050*np.cos(4.42633572783 + 508.3503240922*t)
	Y2 += 0.00000007885*np.cos(5.61931104320 + 565.1156877467*t)
	Y2 += 0.00000008233*np.cos(5.11045948330 + 5849.3641121146*t)
	Y2 += 0.00000007982*np.cos(2.94467951015 + 1361.5467058442*t)
	Y2 += 0.00000007644*np.cos(1.29316810715 + 404.5067903482*t)
	Y2 += 0.00000007938*np.cos(1.18915691335 + 5863.5912061162*t)
	Y2 += 0.00000009121*np.cos(4.72270138876 + 1574.8458012822*t)
	Y2 += 0.00000007699*np.cos(0.25085366401 + 9779.5738083342*t)
	Y2 += 0.00000009489*np.cos(4.07433472727 + 1368.660252845*t)
	Y2 += 0.00000007423*np.cos(2.61273997897 + 9793.8009023358*t)
	Y2 += 0.00000008980*np.cos(5.08550396886 + 1251.3403846248*t)
	Y2 += 0.00000007350*np.cos(5.49243057571 + 313.2104759189*t)
	Y2 += 0.00000006938*np.cos(5.39456818142 + 208.633228992*t)
	Y2 += 0.00000006778*np.cos(5.77595384598 + 217.964961884*t)
	Y2 += 0.00000006524*np.cos(3.77251284742 + 429.0458714308*t)
	Y2 += 0.00000006362*np.cos(0.52150509836 + 319.5732633943*t)
	Y2 += 0.00000008402*np.cos(1.72645111914 + 6283.0758499914*t)
	Y2 += 0.00000007897*np.cos(0.14444386144 + 1162.4747044078*t)
	Y2 += 0.00000007764*np.cos(4.22781318512 + 621.7380390493*t)
	Y2 += 0.00000005960*np.cos(0.85552901967 + 114.1384744825*t)
	Y2 += 0.00000007979*np.cos(3.16170623406 + 10213.285546211*t)
	Y2 += 0.00000005502*np.cos(4.69989095999 + 78.7137518304*t)
	Y2 += 0.00000005532*np.cos(4.74020289938 + 1265.5674786264*t)
	Y2 += 0.00000006204*np.cos(3.56272058362 + 195.8906076987*t)
	Y2 += 0.00000005083*np.cos(4.30495322830 + 842.1506814881*t)
	Y2 += 0.00000006053*np.cos(1.30195578009 + 230.7075831773*t)
	Y2 += 0.00000005326*np.cos(4.98440493121 + 1692.1656695024*t)
	Y2 += 0.00000004909*np.cos(3.71093580405 + 1788.1448967202*t)
	Y2 += 0.00000004574*np.cos(3.65982491794 + 436.1594184316*t)
	Y2 += 0.00000004886*np.cos(0.47844921825 + 643.8294395771*t)
	Y2 += 0.00000004500*np.cos(6.03958077194 + 99.1606209555*t)
	Y2 += 0.00000004485*np.cos(4.27145091277 + 121.2520214833*t)
	Y2 += 0.00000004496*np.cos(0.45535353234 + 757.2171545342*t)
	Y2 += 0.00000004384*np.cos(3.69838113413 + 333.657345044*t)
	Y2 += 0.00000004240*np.cos(2.80668494715 + 175.1660598002*t)
	Y2 += 0.00000004203*np.cos(5.51409326781 + 576.1613880106*t)
	Y2 += 0.00000004364*np.cos(4.50874666063 + 824.7421937488*t)
	Y2 += 0.00000004242*np.cos(5.73406669115 + 289.5651667136*t)
	Y2 += 0.00000004026*np.cos(5.40316560805 + 251.4321310758*t)
	Y2 += 0.00000004027*np.cos(4.45902875729 + 710.7467316182*t)
	Y2 += 0.00000003992*np.cos(2.51147020916 + 1169.5882514086*t)
	Y2 += 0.00000003876*np.cos(2.82381242930 + 134.5853436076*t)
	Y2 += 0.00000004906*np.cos(6.03440415257 + 479.2883889155*t)
	Y2 += 0.00000003796*np.cos(4.54598861176 + 98.8999885246*t)
	Y2 += 0.00000003768*np.cos(4.99152883867 + 501.3797894433*t)
	Y2 += 0.00000004513*np.cos(1.80716596854 + 398.1440028728*t)
	Y2 += 0.00000003877*np.cos(3.70998482895 + 1781.0313497194*t)
	Y2 += 0.00000004177*np.cos(3.64910690649 + 74.7815985673*t)
	Y2 += 0.00000004428*np.cos(6.21808891979 + 1478.8665740644*t)
	Y2 += 0.00000004026*np.cos(1.47953978871 + 120.358249606*t)
	Y2 += 0.00000004198*np.cos(4.37815056603 + 1891.2376709388*t)
	Y2 += 0.00000004587*np.cos(3.67578748136 + 1685.0521225016*t)
	Y2 += 0.00000004530*np.cos(4.80061804389 + 1567.7322542814*t)
	Y2 += 0.00000004348*np.cos(0.05774649263 + 5856.4776591154*t)
	Y2 += 0.00000003573*np.cos(4.37750447178 + 156.6767441354*t)
	Y2 += 0.00000003394*np.cos(1.52844790239 + 196.0336200506*t)
	Y2 += 0.00000003533*np.cos(0.57565855894 + 114.3991069134*t)
	Y2 += 0.00000003641*np.cos(0.04003274809 + 166.828672522*t)
	Y2 += 0.00000003936*np.cos(1.67508528335 + 326.6868103951*t)
	Y2 += 0.00000003247*np.cos(2.67423610661 + 1677.9385755008*t)
	Y2 += 0.00000004069*np.cos(1.48284023947 + 9786.687355335*t)
	Y2 += 0.00000002980*np.cos(5.94251782395 + 151.0476698429*t)
	Y2 += 0.00000003098*np.cos(4.45079673488 + 1581.959348283*t)
	Y2 += 0.00000003742*np.cos(5.33557512257 + 849.2642284889*t)
	Y2 += 0.00000003047*np.cos(0.21958597767 + 230.5645708254*t)
	Y2 += 0.00000003648*np.cos(5.75342713476 + 611.4430983108*t)
	Y2 += 0.00000003098*np.cos(3.89851404128 + 526.5095713569*t)
	Y2 += 0.00000002819*np.cos(4.62496885979 + 431.264057322*t)
	Y2 += 0.00000002815*np.cos(3.70833186151 + 414.0680179038*t)
	Y2 += 0.00000002927*np.cos(0.75690409846 + 395.578702239*t)
	Y2 += 0.00000002893*np.cos(4.68195629987 + 381.3516082374*t)
	Y2 += 0.00000002669*np.cos(0.23163089942 + 306.0969289181*t)
	Y2 += 0.00000002803*np.cos(1.54793175537 + 259.769518354*t)
	Y2 += 0.00000002799*np.cos(1.64435927281 + 129.9194771616*t)
	Y2 += 0.00000003378*np.cos(0.03637154602 + 299.1263942692*t)
	Y2 += 0.00000002783*np.cos(4.12158984765 + 1286.9081196288*t)
	Y2 += 0.00000002557*np.cos(0.41569961768 + 59.8037450403*t)
	Y2 += 0.00000003374*np.cos(4.24961349276 + 69.1525242748*t)
	Y2 += 0.00000002649*np.cos(0.08633239547 + 84.9335269539*t)
	Y2 += 0.00000002771*np.cos(5.51441923038 + 320.3240229197*t)
	Y2 += 0.00000002909*np.cos(2.59078817253 + 137.0330241624*t)
	Y2 += 0.00000002465*np.cos(5.81534068526 + 572.2292347475*t)
	Y2 += 0.00000002461*np.cos(2.38415136907 + 409.1897031367*t)
	Y2 += 0.00000002443*np.cos(1.29249188449 + 1272.6810256272*t)
	Y2 += 0.00000002579*np.cos(3.41613819491 + 1493.093668066*t)
	Y2 += 0.00000002442*np.cos(2.95735834989 + 546.956440482*t)
	Y2 += 0.00000002536*np.cos(2.34085009776 + 696.5196376166*t)
	Y2 += 0.00000002428*np.cos(6.23679777999 + 45.5766510387*t)
	Y2 += 0.00000002318*np.cos(4.42637917857 + 343.2185725996*t)
	Y2 += 0.00000002813*np.cos(4.09700943877 + 421.93232443*t)
	Y2 += 0.00000002298*np.cos(1.85531273629 + 188.0263011725*t)
	Y2 += 0.00000002880*np.cos(0.56316732699 + 551.031606097*t)
	Y2 += 0.00000002256*np.cos(1.11650889937 + 554.0699874828*t)
	Y2 += 0.00000002211*np.cos(2.09170078196 + 275.5505210331*t)
	Y2 += 0.00000002512*np.cos(1.24402266178 + 312.1990839626*t)
	Y2 += 0.00000002193*np.cos(2.54074083075 + 205.2223405907*t)
	Y2 += 0.00000002193*np.cos(2.34888533584 + 221.3758502853*t)
	Y2 += 0.00000002332*np.cos(3.99762087333 + 144.1465711632*t)
	Y2 += 0.00000002849*np.cos(3.77789682092 + 92.0470739547*t)
	Y2 += 0.00000002162*np.cos(3.02953584766 + 238.5718897035*t)
	Y2 += 0.00000002604*np.cos(5.54796500632 + 927.8349679674*t)
	Y2 += 0.00000003001*np.cos(0.87555285269 + 6069.7767545534*t)
	Y2 += 0.00000002148*np.cos(3.42586788929 + 916.9322800554*t)
	Y2 += 0.00000002122*np.cos(4.75341405041 + 92.940845832*t)
	Y2 += 0.00000002767*np.cos(2.23440285883 + 9999.986450773*t)
	Y2 += 0.00000002081*np.cos(3.36077324824 + 188.9200730498*t)
	Y2 += 0.00000002080*np.cos(0.82558359811 + 1589.0728952838*t)
	Y2 += 0.00000002175*np.cos(4.05922699845 + 432.2272651685*t)
	Y2 += 0.00000002268*np.cos(3.61370278398 + 2104.5367663768*t)
	Y2 += 0.00000002007*np.cos(0.02600377472 + 5643.1785636774*t)
	Y2 += 0.00000002555*np.cos(4.96787984600 + 229.9738699944*t)
	Y2 += 0.00000002555*np.cos(6.20493162777 + 196.6243208816*t)
	Y2 += 0.00000001894*np.cos(1.69980050572 + 1382.8873468466*t)
	Y2 += 0.00000001988*np.cos(4.20307991244 + 1141.1340634054*t)
	Y2 += 0.00000001954*np.cos(3.41365114640 + 2097.423219376*t)
	Y2 += 0.00000001941*np.cos(1.80523291315 + 373.9079928365*t)
	Y2 += 0.00000002353*np.cos(6.10168291345 + 650.1922270525*t)
	Y2 += 0.00000001955*np.cos(3.17983281108 + 2413.8150890326*t)
	Y2 += 0.00000001819*np.cos(1.46861515290 + 120.5012619579*t)
	Y2 += 0.00000001815*np.cos(1.41544549589 + 9573.388259897*t)
	Y2 += 0.00000002193*np.cos(6.27247954588 + 207.1487562837*t)
	Y2 += 0.00000002193*np.cos(4.90033192789 + 219.4494345923*t)
	Y2 += 0.00000002273*np.cos(4.49996826493 + 135.336103133*t)
	Y2 += 0.00000001791*np.cos(5.66600971254 + 99.9113804809*t)
	Y2 += 0.00000001786*np.cos(4.67044629573 + 237.6781178262*t)
	Y2 += 0.00000001819*np.cos(5.22350081042 + 220.4608265486*t)
	Y2 += 0.00000001819*np.cos(5.94931066335 + 206.1373643274*t)
	Y2 += 0.00000001775*np.cos(4.28100694137 + 116.4260963429*t)
	Y2 += 0.00000001891*np.cos(3.37577508092 + 556.5176680376*t)
	Y2 += 0.00000002022*np.cos(4.82062172922 + 2008.557539159*t)
	Y2 += 0.00000002390*np.cos(5.29068620866 + 856.3777754897*t)
	Y2 += 0.00000001931*np.cos(2.21979858592 + 258.8757464767*t)
	Y2 += 0.00000001749*np.cos(4.52585501392 + 417.0369633204*t)
	Y2 += 0.00000001825*np.cos(0.29368090914 + 344.8460576598*t)
	Y2 += 0.00000002044*np.cos(5.98201068402 + 1795.258443721*t)
	Y2 += 0.00000001812*np.cos(5.74287970366 + 570.7447620392*t)
	Y2 += 0.00000001742*np.cos(3.80382436497 + 425.6349830295*t)
	Y2 += 0.00000001689*np.cos(1.94087093302 + 327.4375699205*t)
	Y2 += 0.00000002261*np.cos(1.53982829642 + 421.1815649046*t)
	Y2 += 0.00000001820*np.cos(3.09123068436 + 347.8844390456*t)
	Y2 += 0.00000001691*np.cos(0.86915956975 + 455.0523788792*t)
	Y2 += 0.00000001703*np.cos(1.25635241157 + 427.5613987225*t)
	Y2 += 0.00000001764*np.cos(1.22791432289 + 186.472392495*t)
	Y2 += 0.00000001749*np.cos(1.78920007271 + 898.7730327907*t)
	Y2 += 0.00000001663*np.cos(0.70583379773 + 145.6310438715*t)
	Y2 += 0.00000002282*np.cos(0.47292670815 + 439.1283638482*t)
	Y2 += 0.00000001687*np.cos(4.58551918588 + 519.3960243561*t)
	Y2 += 0.00000001795*np.cos(4.25046313837 + 913.0001267923*t)
	Y2 += 0.00000002103*np.cos(3.56257377771 + 2001.4439921582*t)
	Y2 += 0.00000001928*np.cos(1.64847154951 + 312.4597163935*t)
	Y2 += 0.00000001597*np.cos(4.15770465382 + 280.9671470045*t)
	Y2 += 0.00000001737*np.cos(0.17489616820 + 167.7224443993*t)
	Y2 += 0.00000002134*np.cos(1.38387224617 + 173.9422195228*t)
	Y2 += 0.00000001657*np.cos(3.99819302774 + 1457.525933062*t)
	Y2 += 0.00000002107*np.cos(2.96121116298 + 1485.9801210652*t)
	Y2 += 0.00000001726*np.cos(2.56063559984 + 486.4019359163*t)
	Y2 += 0.00000001608*np.cos(1.16665145047 + 3252.784376783*t)
	Y2 += 0.00000001819*np.cos(2.86390971329 + 206.233732547*t)
	Y2 += 0.00000001819*np.cos(2.02571645330 + 220.364458329*t)
	Y2 += 0.00000001690*np.cos(4.06888271137 + 2207.6295405954*t)
	Y2 += 0.00000001590*np.cos(4.82328890581 + 685.4739373527*t)
	Y2 += 0.00000001579*np.cos(5.01190493526 + 210.8514148832*t)
	Y2 += 0.00000001556*np.cos(1.08924884995 + 1905.4647649404*t)
	Y2 += 0.00000001708*np.cos(3.71571156744 + 81.8951455681*t)
	Y2 += 0.00000001441*np.cos(3.51719846434 + 732.6951197941*t)
	Y2 += 0.00000001895*np.cos(3.47646526553 + 291.262087743*t)
	Y2 += 0.00000001966*np.cos(4.80989076120 + 131.4039498699*t)
	Y2 += 0.00000001423*np.cos(5.55442193599 + 201.5196819912*t)
	Y2 += 0.00000001423*np.cos(5.61838953778 + 225.0785088848*t)
	Y2 += 0.00000001579*np.cos(4.23583577080 + 532.8723588323*t)
	Y2 += 0.00000001491*np.cos(0.52012009126 + 240.125798381*t)
	Y2 += 0.00000001913*np.cos(0.07514513304 + 295.1942410061*t)
	Y2 += 0.00000001586*np.cos(1.17791014057 + 3803.81598288*t)
	Y2 += 0.00000001495*np.cos(0.63703973970 + 1056.2005364515*t)
	Y2 += 0.00000001439*np.cos(0.12364835405 + 699.7010313543*t)
	Y2 += 0.00000001438*np.cos(3.07483474005 + 1802.3719907218*t)
	Y2 += 0.00000001326*np.cos(1.41662015141 + 980.6681783588*t)
	Y2 += 0.00000001805*np.cos(4.74583119029 + 4216.1870797544*t)
	Y2 += 0.00000001351*np.cos(0.82163520410 + 5429.8794682394*t)
	Y2 += 0.00000001414*np.cos(1.50148705867 + 1371.8416465827*t)
	Y2 += 0.00000001581*np.cos(5.27304223476 + 1244.226837624*t)
	Y2 += 0.00000001580*np.cos(4.99649873582 + 561.1835344836*t)
	Y2 += 0.00000001464*np.cos(0.92036676895 + 472.1748419147*t)
	Y2 += 0.00000001343*np.cos(4.95515927820 + 1055.4497769261*t)
	Y2 += 0.00000001260*np.cos(5.67257957480 + 850.0149880143*t)
	Y2 += 0.00000001287*np.cos(2.73723314006 + 28.4541880032*t)
	Y2 += 0.00000001457*np.cos(0.82523140286 + 3597.6304344428*t)
	Y2 += 0.00000001328*np.cos(1.01876573725 + 214.2623032845*t)
	Y2 += 0.00000001328*np.cos(3.87086042934 + 212.3358875915*t)
	Y2 += 0.00000001245*np.cos(2.24518120845 + 9360.089164459*t)
	Y2 += 0.00000001382*np.cos(0.47552392329 + 525.7588118315*t)
	Y2 += 0.00000001311*np.cos(4.68618251681 + 4113.0943055358*t)
	Y2 += 0.00000001664*np.cos(0.36159363492 + 252.6559713532*t)
	Y2 += 0.00000001205*np.cos(3.28772939852 + 1049.0869894507*t)
	Y2 += 0.00000001646*np.cos(4.59140776956 + 563.6312150384*t)
	Y2 += 0.00000001191*np.cos(0.54419432213 + 153.4953503977*t)
	Y2 += 0.00000001188*np.cos(6.25671522816 + 525.4981794006*t)
	Y2 += 0.00000001184*np.cos(2.77078103022 + 1994.3304451574*t)
	Y2 += 0.00000001223*np.cos(3.45895305129 + 905.8865797915*t)
	Y2 += 0.00000001222*np.cos(4.14095386183 + 213.3472795478*t)
	Y2 += 0.00000001222*np.cos(0.74867230476 + 213.2509113282*t)
	Y2 += 0.00000001257*np.cos(5.93589486535 + 629.6023455755*t)
	Y2 += 0.00000001167*np.cos(3.02278739432 + 193.655375465*t)
	Y2 += 0.00000001167*np.cos(1.86683877227 + 232.942815411*t)
	Y2 += 0.00000001164*np.cos(4.94621977070 + 148.0787244263*t)
	Y2 += 0.00000001596*np.cos(4.59579152366 + 1884.124123938*t)
	Y2 += 0.00000001536*np.cos(1.03704208468 + 3693.6096616606*t)
	Y2 += 0.00000001339*np.cos(4.42212893352 + 1898.3512179396*t)
	Y2 += 0.00000001137*np.cos(3.59027879357 + 2641.3412784722*t)
	Y2 += 0.00000001370*np.cos(4.97502462959 + 835.7878940127*t)
	Y2 += 0.00000001107*np.cos(2.54015999967 + 2310.722314814*t)
	Y2 += 0.00000001160*np.cos(4.32688430133 + 67.6680515665*t)
	Y2 += 0.00000001276*np.cos(4.57782455431 + 1176.7017984094*t)
	Y2 += 0.00000001122*np.cos(2.45856567122 + 128.3655684841*t)
	Y2 += 0.00000001305*np.cos(2.25261819091 + 96.8729990951*t)
	Y2 += 0.00000001197*np.cos(5.01667820627 + 4209.0735327536*t)
	Y2 += 0.00000001321*np.cos(5.69067622276 + 355.7487455718*t)
	Y2 += 0.00000001313*np.cos(5.46638052649 + 38.1330356378*t)
	Y2 += 0.00000001103*np.cos(5.24996982319 + 739.0579072695*t)
	Y2 += 0.00000001024*np.cos(6.03645869910 + 5636.0650166766*t)
	Y2 += 0.00000001012*np.cos(2.02490236228 + 211.6021744086*t)
	Y2 += 0.00000001012*np.cos(2.86472380431 + 214.9960164674*t)
	Y2 += 0.00000001000*np.cos(4.59565320814 + 776.9303104764*t)
	Y2 += 0.00000001241*np.cos(4.41224004220 + 2193.4024465938*t)
	Y2 += 0.00000001125*np.cos(0.61961503719 + 3914.0223040994*t)
	Y2 += 0.00000001212*np.cos(2.74105995095 + 2627.1141844706*t)
	Y2 += 0.00000001014*np.cos(3.56962332387 + 2516.9078632512*t)
	Y2 += 0.00000000954*np.cos(1.51108884016 + 206.706813299*t)
	Y2 += 0.00000000954*np.cos(3.37853732643 + 219.891377577*t)
	Y2 += 0.00000001134*np.cos(1.97815267667 + 92.7978334801*t)
	Y2 += 0.00000001041*np.cos(3.23233571279 + 3178.1457905676*t)
	Y2 += 0.00000001094*np.cos(3.06630520047 + 2730.2069586892*t)
	Y2 += 0.00000000999*np.cos(3.11265581262 + 2406.7015420318*t)
	Y2 += 0.00000000973*np.cos(6.27346363694 + 181.806526049*t)
	Y2 += 0.00000000973*np.cos(1.75775518324 + 244.791664827*t)
	Y2 += 0.00000000941*np.cos(3.53095210851 + 739.8086667949*t)
	Y2 += 0.00000001054*np.cos(3.24298004303 + 2634.2277314714*t)
	Y2 += 0.00000001156*np.cos(4.96571827287 + 1560.6187072806*t)
	Y2 += 0.00000001008*np.cos(4.00176629932 + 254.9435932136*t)
	Y2 += 0.00000000990*np.cos(0.01303950026 + 4120.2078525366*t)
	Y2 += 0.00000001113*np.cos(3.86892203772 + 2524.021410252*t)
	Y2 += 0.00000000917*np.cos(5.96810093164 + 601.7642506762*t)
	Y2 += 0.00000000939*np.cos(5.19502728821 + 2936.3925071264*t)
	Y2 += 0.00000001116*np.cos(4.64049818808 + 2324.9494088156*t)
	Y2 += 0.00000000918*np.cos(0.71003260736 + 714.5358725294*t)
	Y2 += 0.00000000999*np.cos(4.06676744721 + 171.6545976624*t)
	Y2 += 0.00000001134*np.cos(5.94161973674 + 3782.4753418776*t)
	Y2 += 0.00000000984*np.cos(0.88646918920 + 2221.856634597*t)
	Y2 += 0.00000000950*np.cos(3.82757616527 + 1809.4855377226*t)
	Y2 += 0.00000001158*np.cos(5.47288930030 + 3995.7744373156*t)
	Y2 += 0.00000000899*np.cos(1.16276249362 + 9566.2747128962*t)
	Y2 += 0.00000001002*np.cos(4.46394843643 + 60.7669528868*t)
	Y2 += 0.00000000897*np.cos(2.73761578991 + 3494.5376602242*t)
	Y2 += 0.00000000956*np.cos(3.59264934611 + 2317.8358618148*t)
	Y2 += 0.00000000882*np.cos(3.45281377344 + 1773.9178027186*t)
	Y2 += 0.00000001101*np.cos(3.13667172657 + 2332.0629558164*t)
	Y2 += 0.00000000883*np.cos(0.14085296374 + 622.4887985747*t)
	Y2 += 0.00000000903*np.cos(1.70433886791 + 838.218528225*t)
	Y2 += 0.00000000920*np.cos(1.69749373479 + 458.8415197904*t)
	Y2 += 0.00000000891*np.cos(0.82111399765 + 1262.3860848887*t)
	Y2 += 0.00000001168*np.cos(0.25468840622 + 3906.9087570986*t)
	Y2 += 0.00000001103*np.cos(5.29906832904 + 4002.8879843164*t)
	Y2 += 0.00000000925*np.cos(5.21215658970 + 731.6837278378*t)
	Y2 += 0.00000000909*np.cos(1.30371158475 + 745.9108218394*t)
	Y2 += 0.00000001018*np.cos(3.59536645659 + 558.0021407459*t)
	Y2 += 0.00000000903*np.cos(0.18176721951 + 823.9914342234*t)
	Y2 += 0.00000000840*np.cos(1.97666011108 + 610.6923387854*t)
	Y2 += 0.00000000887*np.cos(3.46857320111 + 1037.2905296614*t)
	Y2 += 0.00000001156*np.cos(1.16648756429 + 2964.8466951296*t)
	Y2 += 0.00000000847*np.cos(4.97551009586 + 3377.217792004*t)
	Y2 += 0.00000000945*np.cos(5.98539579259 + 1051.517623663*t)
	Y2 += 0.00000000875*np.cos(5.17703782078 + 731.9443602687*t)
	Y2 += 0.00000000871*np.cos(4.70133426692 + 397.3932433474*t)
	Y2 += 0.00000000810*np.cos(4.41261482309 + 835.0371344873*t)
	Y2 += 0.00000000926*np.cos(3.77259745562 + 6076.8903015542*t)
	Y2 += 0.00000000818*np.cos(4.77834353092 + 3700.7232086614*t)
	Y2 += 0.00000000801*np.cos(3.28824778134 + 3686.4961146598*t)
	Y2 += 0.00000000846*np.cos(1.14796661681 + 3067.9394693482*t)
	Y2 += 0.00000000853*np.cos(1.95779608562 + 1912.5783119412*t)
	Y2 += 0.00000001042*np.cos(4.51072806644 + 4532.578949411*t)
	Y2 += 0.00000000836*np.cos(3.30367731513 + 2833.2997329078*t)
	Y2 += 0.00000000964*np.cos(5.79852972922 + 329.7251917809*t)
	Y2 += 0.00000001008*np.cos(2.05921424187 + 203.2647871304*t)
	Y2 += 0.00000001008*np.cos(2.83041192472 + 223.3334037456*t)
	Y2 += 0.00000000791*np.cos(0.44199384843 + 201.9927627432*t)
	Y2 += 0.00000000791*np.cos(4.44763231816 + 224.6054281328*t)
	Y2 += 0.00000000776*np.cos(3.11238011428 + 6062.6632075526*t)
	Y2 += 0.00000000868*np.cos(4.18895614941 + 624.919432787*t)
	Y2 += 0.00000000803*np.cos(0.12271627005 + 4.665866446*t)
	Y2 += 0.00000000948*np.cos(0.11270822957 + 215.7467759928*t)
	Y2 += 0.00000000818*np.cos(3.42867198731 + 305.3461693927*t)
	Y2 += 0.00000000826*np.cos(3.99063604806 + 2214.7430875962*t)
	Y2 += 0.00000000864*np.cos(5.19762795666 + 10007.0999977738*t)
	Y2 += 0.00000000962*np.cos(3.76392685043 + 214.0498549634*t)
	Y2 += 0.00000000962*np.cos(1.12569931616 + 212.5483359126*t)
	Y2 += 0.00000000804*np.cos(0.07795599025 + 411.620337349*t)
	Y2 += 0.00000000750*np.cos(4.63483469672 + 4422.3726281916*t)
	Y2 += 0.00000000744*np.cos(3.08653093986 + 278.5194664497*t)
	Y2 += 0.00000000743*np.cos(3.13775662089 + 1119.1856752295*t)
	Y2 += 0.00000000879*np.cos(5.06060879535 + 3487.4241132234*t)
	Y2 += 0.00000000759*np.cos(4.79928618962 + 778.4147831847*t)
	Y2 += 0.00000000744*np.cos(5.28551554864 + 504.561183181*t)
	Y2 += 0.00000000745*np.cos(2.26212763756 + 842.9014410135*t)
	Y2 += 0.00000000756*np.cos(4.75493097410 + 1038.0412891868*t)
	Y2 += 0.00000001004*np.cos(2.14151892609 + 945.9942152321*t)
	Y2 += 0.00000000726*np.cos(4.54313688481 + 9992.8729037722*t)
	Y2 += 0.00000000746*np.cos(4.94420073742 + 1080.7225711916*t)
	Y2 += 0.00000000761*np.cos(4.44729002083 + 4429.4861751924*t)
	Y2 += 0.00000000954*np.cos(1.01894622930 + 205.6642835754*t)
	Y2 += 0.00000000954*np.cos(3.87067993729 + 220.9339073006*t)
	Y2 += 0.00000000943*np.cos(0.52469754606 + 953.1077622329*t)
	Y2 += 0.00000000753*np.cos(3.47512241950 + 305.0855369618*t)
	Y2 += 0.00000000873*np.cos(4.14443296922 + 2509.7943162504*t)
	Y2 += 0.00000000693*np.cos(3.94239436037 + 637.4496057592*t)
	Y2 += 0.00000000732*np.cos(5.17759694477 + 172.2452984934*t)
	Y2 += 0.00000000732*np.cos(2.85362187541 + 254.3528923826*t)
	Y2 += 0.00000000945*np.cos(5.83450274601 + 388.4651552382*t)
	Y2 += 0.00000000813*np.cos(3.83625059019 + 2420.9286360334*t)
	return Y2*t*t




def Saturn_Y3 (t): # 200 terms of order 3

	Y3 = 0.
	Y3 += 0.00077354527*np.cos(1.40391035241 + 206.1855484372*t)
	Y3 += 0.00075542804*np.cos(0.31962897945 + 220.4126424388*t)
	Y3 -= 0.00022841198
	Y3 += 0.00010669170*np.cos(5.36495612200 + 426.598190876*t)
	Y3 += 0.00009007608*np.cos(5.62865492125 + 433.7117378768*t)
	Y3 += 0.00007415913*np.cos(0.21442311819 + 227.5261894396*t)
	Y3 += 0.00008297360*np.cos(1.52263020988 + 7.1135470008*t)
	Y3 += 0.00004505795*np.cos(0.67249306339 + 419.4846438752*t)
	Y3 += 0.00003580670*np.cos(1.51466198240 + 199.0720014364*t)
	Y3 += 0.00002981120*np.cos(4.42869532103 + 639.897286314*t)
	Y3 += 0.00002375829*np.cos(1.46232991989 + 14.2270940016*t)
	Y3 += 0.00001023972*np.cos(4.72338150445 + 647.0108333148*t)
	Y3 += 0.00000788612*np.cos(5.61078118652 + 440.8252848776*t)
	Y3 += 0.00000807685*np.cos(5.99385575552 + 216.4804891757*t)
	Y3 += 0.00000770611*np.cos(2.04234808917 + 210.1177017003*t)
	Y3 += 0.00000384210*np.cos(1.48542445090 + 117.3198682202*t)
	Y3 += 0.00000456443*np.cos(3.56523371093 + 853.196381752*t)
	Y3 += 0.00000324148*np.cos(0.08074667476 + 234.6397364404*t)
	Y3 += 0.00000338016*np.cos(2.47226721573 + 110.2063212194*t)
	Y3 += 0.00000355769*np.cos(5.40701066557 + 213.299095438*t)
	Y3 += 0.00000296603*np.cos(0.32077836251 + 412.3710968744*t)
	Y3 += 0.00000241378*np.cos(1.79772375424 + 103.0927742186*t)
	Y3 += 0.00000198202*np.cos(5.51857978716 + 316.3918696566*t)
	Y3 += 0.00000195234*np.cos(0.72153771655 + 632.7837393132*t)
	Y3 += 0.00000150777*np.cos(0.77624311648 + 323.5054166574*t)
	Y3 += 0.00000154028*np.cos(1.31543626425 + 21.3406410024*t)
	Y3 += 0.00000151698*np.cos(1.38281351365 + 309.2783226558*t)
	Y3 += 0.00000131653*np.cos(2.26722574599 + 95.9792272178*t)
	Y3 += 0.00000125170*np.cos(6.14972338278 + 209.3669421749*t)
	Y3 += 0.00000113221*np.cos(1.84141052645 + 217.2312487011*t)
	Y3 += 0.00000111239*np.cos(3.84668749918 + 860.3099287528*t)
	Y3 += 0.00000087163*np.cos(1.60174328814 + 191.9584544356*t)
	Y3 += 0.00000114537*np.cos(5.87729837758 + 223.5940361765*t)
	Y3 += 0.00000085241*np.cos(0.33009287077 + 330.6189636582*t)
	Y3 += 0.00000085136*np.cos(4.74614465215 + 654.1243803156*t)
	Y3 += 0.00000079372*np.cos(2.67260966241 + 88.865680217*t)
	Y3 += 0.00000078274*np.cos(6.27419421323 + 124.433415221*t)
	Y3 += 0.00000074114*np.cos(1.88903477580 + 302.164775655*t)
	Y3 += 0.00000087336*np.cos(5.08195542296 + 429.7795846137*t)
	Y3 += 0.00000055318*np.cos(1.56951361659 + 202.2533951741*t)
	Y3 += 0.00000054081*np.cos(0.16896886000 + 224.3447957019*t)
	Y3 += 0.00000045789*np.cos(2.00674179989 + 625.6701923124*t)
	Y3 += 0.00000057974*np.cos(2.26359334860 + 203.0041546995*t)
	Y3 += 0.00000055659*np.cos(2.74083199091 + 1066.49547719*t)
	Y3 += 0.00000036709*np.cos(5.51643477597 + 447.9388318784*t)
	Y3 += 0.00000043284*np.cos(4.94816449709 + 422.6660376129*t)
	Y3 += 0.00000030209*np.cos(6.07309625712 + 536.8045120954*t)
	Y3 += 0.00000025777*np.cos(3.78412773568 + 3.9321532631*t)
	Y3 += 0.00000027097*np.cos(1.95819765953 + 423.4167971383*t)
	Y3 += 0.00000018435*np.cos(5.84806629186 + 515.463871093*t)
	Y3 += 0.00000017669*np.cos(3.86152764852 + 195.1398481733*t)
	Y3 += 0.00000015244*np.cos(3.68776396232 + 11.0457002639*t)
	Y3 += 0.00000012459*np.cos(5.85161085641 + 437.6438911399*t)
	Y3 += 0.00000011569*np.cos(1.45834921416 + 618.5566453116*t)
	Y3 += 0.00000010183*np.cos(5.57013967818 + 337.732510659*t)
	Y3 += 0.00000010780*np.cos(5.70769981805 + 543.9180590962*t)
	Y3 += 0.00000009663*np.cos(2.89192389329 + 81.7521332162*t)
	Y3 += 0.00000011351*np.cos(3.02135945276 + 1073.6090241908*t)
	Y3 += 0.00000009885*np.cos(5.68206370029 + 131.5469622218*t)
	Y3 += 0.00000011913*np.cos(5.03981077547 + 436.8931316145*t)
	Y3 += 0.00000008812*np.cos(6.08120926609 + 831.8557407496*t)
	Y3 += 0.00000009053*np.cos(4.07366714695 + 522.5774180938*t)
	Y3 += 0.00000008222*np.cos(2.09131673945 + 295.0512286542*t)
	Y3 += 0.00000008329*np.cos(3.90263564155 + 867.4234757536*t)
	Y3 += 0.00000008291*np.cos(4.91363846303 + 728.762966531*t)
	Y3 += 0.00000007561*np.cos(5.38689397533 + 149.5631971346*t)
	Y3 += 0.00000008632*np.cos(4.22779824805 + 643.0786800517*t)
	Y3 += 0.00000007340*np.cos(0.62446686551 + 846.0828347512*t)
	Y3 += 0.00000007109*np.cos(4.07508151963 + 635.9651330509*t)
	Y3 += 0.00000006932*np.cos(1.07981679851 + 231.4583427027*t)
	Y3 += 0.00000005842*np.cos(5.59806189386 + 269.9214467406*t)
	Y3 += 0.00000006550*np.cos(0.49524007864 + 408.4389436113*t)
	Y3 += 0.00000005275*np.cos(3.88157561156 + 742.9900605326*t)
	Y3 += 0.00000007034*np.cos(1.52021874624 + 18.1592472647*t)
	Y3 += 0.00000005426*np.cos(6.23004509808 + 241.7532834412*t)
	Y3 += 0.00000006265*np.cos(3.21841918334 + 735.8765135318*t)
	Y3 += 0.00000005328*np.cos(3.56494620223 + 416.3032501375*t)
	Y3 += 0.00000005005*np.cos(2.34522240082 + 277.0349937414*t)
	Y3 += 0.00000006072*np.cos(3.27968409813 + 430.5303441391*t)
	Y3 += 0.00000005093*np.cos(3.85217305978 + 415.5524906121*t)
	Y3 += 0.00000005737*np.cos(1.92668332911 + 1279.794572628*t)
	Y3 += 0.00000004670*np.cos(6.21938669397 + 529.6909650946*t)
	Y3 += 0.00000004587*np.cos(3.05441582756 + 56.6223513026*t)
	Y3 += 0.00000004247*np.cos(3.86366292793 + 1059.3819301892*t)
	Y3 += 0.00000004078*np.cos(1.22387025939 + 838.9692877504*t)
	Y3 += 0.00000004517*np.cos(1.01678299139 + 942.062061969*t)
	Y3 += 0.00000004049*np.cos(4.76798056225 + 483.2205421786*t)
	Y3 += 0.00000003683*np.cos(1.92667696990 + 70.8494453042*t)
	Y3 += 0.00000003558*np.cos(6.14015198465 + 508.3503240922*t)
	Y3 += 0.00000003702*np.cos(4.99766931310 + 184.8449074348*t)
	Y3 += 0.00000003758*np.cos(4.69738792182 + 661.2379273164*t)
	Y3 += 0.00000003531*np.cos(0.19316056256 + 956.2891559706*t)
	Y3 += 0.00000003544*np.cos(5.19943850042 + 750.1036075334*t)
	Y3 += 0.00000003856*np.cos(1.00534599914 + 934.9485149682*t)
	Y3 += 0.00000003331*np.cos(5.77295446897 + 1148.2476104062*t)
	Y3 += 0.00000003016*np.cos(0.85072422054 + 405.2575498736*t)
	Y3 += 0.00000002913*np.cos(4.85389224022 + 1045.1548361876*t)
	Y3 += 0.00000002988*np.cos(3.65899809970 + 398.1440028728*t)
	Y3 += 0.00000002634*np.cos(3.68558280810 + 497.4476361802*t)
	Y3 += 0.00000003134*np.cos(0.10698641533 + 99.9113804809*t)
	Y3 += 0.00000002625*np.cos(4.35671067549 + 362.8622925726*t)
	Y3 += 0.00000002488*np.cos(5.59994597708 + 1464.6394800628*t)
	Y3 += 0.00000002597*np.cos(0.47099450841 + 3.1813937377*t)
	Y3 += 0.00000002356*np.cos(0.69069106204 + 10.2949407385*t)
	Y3 += 0.00000002640*np.cos(0.85341396103 + 113.3877149571*t)
	Y3 += 0.00000002163*np.cos(4.65276596776 + 85.8272988312*t)
	Y3 += 0.00000002285*np.cos(1.19717455829 + 611.4430983108*t)
	Y3 += 0.00000002126*np.cos(5.70068892104 + 2641.3412784722*t)
	Y3 += 0.00000002139*np.cos(0.83753177595 + 1258.4539316256*t)
	Y3 += 0.00000002341*np.cos(0.59778909735 + 2111.6503133776*t)
	Y3 += 0.00000001947*np.cos(5.00537989779 + 650.9429865779*t)
	Y3 += 0.00000002670*np.cos(5.34319853125 + 195.8906076987*t)
	Y3 += 0.00000002670*np.cos(5.82961294252 + 230.7075831773*t)
	Y3 += 0.00000001977*np.cos(3.54209313030 + 1375.7737998458*t)
	Y3 += 0.00000001985*np.cos(1.48344430796 + 2538.2485042536*t)
	Y3 += 0.00000002132*np.cos(6.24195050544 + 824.7421937488*t)
	Y3 += 0.00000001881*np.cos(6.22942122495 + 344.7030453079*t)
	Y3 += 0.00000002058*np.cos(0.97339401280 + 927.8349679674*t)
	Y3 += 0.00000001803*np.cos(0.28058928924 + 191.2076949102*t)
	Y3 += 0.00000002065*np.cos(2.16335972331 + 636.7158925763*t)
	Y3 += 0.00000001622*np.cos(4.38588433956 + 1596.1864422846*t)
	Y3 += 0.00000001912*np.cos(1.55609472462 + 2634.2277314714*t)
	Y3 += 0.00000001568*np.cos(1.46883712025 + 235.3904959658*t)
	Y3 += 0.00000001617*np.cos(3.46868055477 + 1354.4331588434*t)
	Y3 += 0.00000001596*np.cos(3.07896109863 + 2015.6710861598*t)
	Y3 += 0.00000001541*np.cos(3.48264306776 + 721.6494195302*t)
	Y3 += 0.00000002091*np.cos(3.75685134157 + 106.2741679563*t)
	Y3 += 0.00000002086*np.cos(0.06751029490 + 444.7574381407*t)
	Y3 += 0.00000001666*np.cos(3.27206561790 + 1877.0105769372*t)
	Y3 += 0.00000001480*np.cos(1.20429336070 + 6290.1893969922*t)
	Y3 += 0.00000001480*np.cos(0.55460477853 + 5849.3641121146*t)
	Y3 += 0.00000001465*np.cos(5.75128324979 + 5863.5912061162*t)
	Y3 += 0.00000001465*np.cos(2.29080017866 + 6275.9623029906*t)
	Y3 += 0.00000001651*np.cos(0.67163171570 + 1251.3403846248*t)
	Y3 += 0.00000001632*np.cos(1.34059417592 + 2943.5060541272*t)
	Y3 += 0.00000001549*np.cos(1.85314072632 + 2840.4132799086*t)
	Y3 += 0.00000001495*np.cos(2.98148025490 + 284.1485407422*t)
	Y3 += 0.00000001939*np.cos(2.07057795187 + 2420.9286360334*t)
	Y3 += 0.00000001609*np.cos(1.54974241176 + 2627.1141844706*t)
	Y3 += 0.00000001707*np.cos(1.76728968158 + 2317.8358618148*t)
	Y3 += 0.00000001608*np.cos(0.36802699660 + 1574.8458012822*t)
	Y3 += 0.00000001399*np.cos(3.25289482572 + 1670.82502850*t)
	Y3 += 0.00000001389*np.cos(6.02263502114 + 2516.9078632512*t)
	Y3 += 0.00000001310*np.cos(4.96087795521 + 1361.5467058442*t)
	Y3 += 0.00000001401*np.cos(0.31555359079 + 142.4496501338*t)
	Y3 += 0.00000001293*np.cos(4.48180993899 + 2751.5475996916*t)
	Y3 += 0.00000001405*np.cos(0.68391140599 + 1244.226837624*t)
	Y3 += 0.00000001311*np.cos(3.36443749410 + 1692.1656695024*t)
	Y3 += 0.00000001383*np.cos(3.58356448743 + 949.1756089698*t)
	Y3 += 0.00000001417*np.cos(4.03665624936 + 1038.0412891868*t)
	Y3 += 0.00000001300*np.cos(5.39614568744 + 1781.0313497194*t)
	Y3 += 0.00000001193*np.cos(0.78248411075 + 208.633228992*t)
	Y3 += 0.00000001193*np.cos(4.10714205584 + 217.964961884*t)
	Y3 += 0.00000001171*np.cos(6.04131034114 + 67.6680515665*t)
	Y3 += 0.00000001131*np.cos(2.79794597235 + 1987.2168981566*t)
	Y3 += 0.00000001184*np.cos(0.80111846132 + 2214.7430875962*t)
	Y3 += 0.00000001141*np.cos(5.72568661760 + 1141.1340634054*t)
	Y3 += 0.00000001301*np.cos(5.09290499928 + 1677.9385755008*t)
	Y3 += 0.00000001288*np.cos(1.29942333880 + 2950.619601128*t)
	Y3 += 0.00000001457*np.cos(0.99248805007 + 2531.1349572528*t)
	Y3 += 0.00000001450*np.cos(0.55337290194 + 1272.6810256272*t)
	Y3 += 0.00000001366*np.cos(6.21957347335 + 160.6088973985*t)
	Y3 += 0.00000001072*np.cos(4.60413355250 + 2435.155730035*t)
	Y3 += 0.00000001043*np.cos(2.37828937153 + 156.6767441354*t)
	Y3 += 0.00000001114*np.cos(1.51992635023 + 1802.3719907218*t)
	Y3 += 0.00000001138*np.cos(1.07669045985 + 3259.8979237838*t)
	Y3 += 0.00000000940*np.cos(0.33745097450 + 52.6901980395*t)
	Y3 += 0.00000001052*np.cos(0.39800410793 + 1560.6187072806*t)
	Y3 += 0.00000001229*np.cos(0.08723623518 + 1567.7322542814*t)
	Y3 += 0.00000001026*np.cos(0.61823553841 + 3156.8051495652*t)
	Y3 += 0.00000000892*np.cos(3.29998766977 + 340.7708920448*t)
	Y3 += 0.00000000889*np.cos(5.13462662304 + 358.9301393095*t)
	Y3 += 0.00000000945*np.cos(5.33287321961 + 1773.9178027186*t)
	Y3 += 0.00000000889*np.cos(2.33106713811 + 107.0249274817*t)
	Y3 += 0.00000000870*np.cos(0.17225649920 + 621.7380390493*t)
	Y3 += 0.00000001004*np.cos(1.79393659890 + 1169.5882514086*t)
	Y3 += 0.00000000841*np.cos(5.76737390177 + 2833.2997329078*t)
	Y3 += 0.00000000845*np.cos(4.49649956754 + 2730.2069586892*t)
	Y3 += 0.00000000773*np.cos(3.99924716391 + 1162.4747044078*t)
	Y3 += 0.00000000986*np.cos(5.98655793699 + 2200.5159935946*t)
	Y3 += 0.00000000772*np.cos(5.37044694274 + 319.5732633943*t)
	Y3 += 0.00000000780*np.cos(3.83450571144 + 288.0806940053*t)
	Y3 += 0.00000000780*np.cos(4.19671310874 + 138.5174968707*t)
	Y3 += 0.00000000964*np.cos(4.07945276922 + 1795.258443721*t)
	Y3 += 0.00000001023*np.cos(0.89342926110 + 1382.8873468466*t)
	Y3 += 0.00000000980*np.cos(1.81164890909 + 265.9892934775*t)
	Y3 += 0.00000000761*np.cos(3.54194549571 + 628.8515860501*t)
	Y3 += 0.00000000810*np.cos(6.05054198296 + 2524.021410252*t)
	Y3 += 0.00000000749*np.cos(2.07949757307 + 1809.4855377226*t)
	Y3 += 0.00000000883*np.cos(5.97568793053 + 1891.2376709388*t)
	Y3 += 0.00000000856*np.cos(3.30227852657 + 2008.557539159*t)
	Y3 += 0.00000000727*np.cos(0.93197698209 + 245.5424243524*t)
	Y3 += 0.00000000727*np.cos(0.81605653091 + 181.0557665236*t)
	Y3 += 0.00000000747*np.cos(5.49849719458 + 1994.3304451574*t)
	Y3 += 0.00000000856*np.cos(0.85986163419 + 2847.5268269094*t)
	Y3 += 0.00000000807*np.cos(2.87880371744 + 1912.5783119412*t)
	Y3 += 0.00000000787*np.cos(0.41063399377 + 2332.0629558164*t)
	Y3 += 0.00000000701*np.cos(1.98280933247 + 9779.5738083342*t)
	Y3 += 0.00000000701*np.cos(2.62299327327 + 10220.3990932118*t)
	Y3 += 0.00000000709*np.cos(5.45403624686 + 1457.525933062*t)
	return Y3*t*t*t




def Saturn_Y4 (t): # 89 terms of order 4

	Y4 = 0.
	Y4 += 0.00007976609*np.cos(3.13229267905 + 206.1855484372*t)
	Y4 += 0.00007866134*np.cos(4.84940259473 + 220.4126424388*t)
	Y4 += 0.00001514404*np.cos(4.77675736118 + 227.5261894396*t)
	Y4 += 0.00001225220*np.cos(3.84500353256 + 433.7117378768*t)
	Y4 += 0.00000720369*np.cos(3.23772774429 + 199.0720014364*t)
	Y4 += 0.00000609979*np.cos(5.96461769948 + 7.1135470008*t)
	Y4 += 0.00000353860*np.cos(2.57548318224 + 419.4846438752*t)
	Y4 += 0.00000382994*np.cos(6.00399581554 + 14.2270940016*t)
	Y4 -= 0.00000469340
	Y4 += 0.00000403662*np.cos(3.41614173802 + 426.598190876*t)
	Y4 += 0.00000185465*np.cos(3.86274212431 + 440.8252848776*t)
	Y4 += 0.00000208259*np.cos(2.57791157635 + 639.897286314*t)
	Y4 += 0.00000172118*np.cos(2.90478987674 + 647.0108333148*t)
	Y4 += 0.00000097307*np.cos(3.40223422689 + 213.299095438*t)
	Y4 += 0.00000084185*np.cos(4.62368663332 + 234.6397364404*t)
	Y4 += 0.00000043451*np.cos(6.08812379890 + 117.3198682202*t)
	Y4 += 0.00000046432*np.cos(1.67433282568 + 853.196381752*t)
	Y4 += 0.00000042226*np.cos(2.13000934788 + 412.3710968744*t)
	Y4 += 0.00000029947*np.cos(5.90543316589 + 21.3406410024*t)
	Y4 += 0.00000022585*np.cos(2.97492806608 + 654.1243803156*t)
	Y4 += 0.00000018023*np.cos(3.32864810894 + 309.2783226558*t)
	Y4 += 0.00000020733*np.cos(3.40067848410 + 103.0927742186*t)
	Y4 += 0.00000016785*np.cos(4.38743014498 + 124.433415221*t)
	Y4 += 0.00000021614*np.cos(2.00589132562 + 860.3099287528*t)
	Y4 += 0.00000016096*np.cos(4.54858886737 + 88.865680217*t)
	Y4 += 0.00000015292*np.cos(3.76962773546 + 302.164775655*t)
	Y4 += 0.00000015000*np.cos(4.10018537649 + 95.9792272178*t)
	Y4 += 0.00000012174*np.cos(3.42898602458 + 191.9584544356*t)
	Y4 += 0.00000011676*np.cos(5.27063573454 + 323.5054166574*t)
	Y4 += 0.00000012054*np.cos(3.74475270374 + 447.9388318784*t)
	Y4 += 0.00000013392*np.cos(2.72202073311 + 632.7837393132*t)
	Y4 += 0.00000011585*np.cos(4.76605780772 + 330.6189636582*t)
	Y4 += 0.00000011837*np.cos(0.66874515167 + 110.2063212194*t)
	Y4 += 0.00000008176*np.cos(3.12499674078 + 429.7795846137*t)
	Y4 += 0.00000009418*np.cos(1.37154453834 + 316.3918696566*t)
	Y4 += 0.00000007773*np.cos(3.77140700642 + 625.6701923124*t)
	Y4 += 0.00000007925*np.cos(0.99159987248 + 1066.49547719*t)
	Y4 += 0.00000006842*np.cos(0.63976654749 + 203.0041546995*t)
	Y4 += 0.00000006721*np.cos(4.24955582048 + 223.5940361765*t)
	Y4 += 0.00000005021*np.cos(4.08379815445 + 216.4804891757*t)
	Y4 += 0.00000003706*np.cos(5.62309481052 + 423.4167971383*t)
	Y4 += 0.00000004566*np.cos(0.76257003680 + 210.1177017003*t)
	Y4 += 0.00000003749*np.cos(5.12362808483 + 405.2575498736*t)
	Y4 += 0.00000002906*np.cos(1.12121500287 + 515.463871093*t)
	Y4 += 0.00000002914*np.cos(3.21499308213 + 422.6660376129*t)
	Y4 += 0.00000002416*np.cos(3.88958492559 + 295.0512286542*t)
	Y4 += 0.00000002718*np.cos(3.78846437142 + 131.5469622218*t)
	Y4 += 0.00000002556*np.cos(3.08391464161 + 337.732510659*t)
	Y4 += 0.00000001928*np.cos(2.94939792463 + 618.5566453116*t)
	Y4 += 0.00000001704*np.cos(1.10834750380 + 831.8557407496*t)
	Y4 += 0.00000001692*np.cos(0.59694424259 + 728.762966531*t)
	Y4 += 0.00000002295*np.cos(3.06773250770 + 742.9900605326*t)
	Y4 += 0.00000001711*np.cos(5.34031096354 + 1052.2683831884*t)
	Y4 += 0.00000001782*np.cos(0.37884320289 + 184.8449074348*t)
	Y4 += 0.00000001782*np.cos(4.51078296370 + 241.7532834412*t)
	Y4 += 0.00000001636*np.cos(4.60365551069 + 536.8045120954*t)
	Y4 += 0.00000001603*np.cos(2.55469774635 + 1251.3403846248*t)
	Y4 += 0.00000001700*np.cos(5.64431210768 + 522.5774180938*t)
	Y4 += 0.00000001607*np.cos(6.10865142042 + 611.4430983108*t)
	Y4 += 0.00000001971*np.cos(4.10286738399 + 1361.5467058442*t)
	Y4 += 0.00000001392*np.cos(1.49756293227 + 508.3503240922*t)
	Y4 += 0.00000001360*np.cos(1.76766357198 + 956.2891559706*t)
	Y4 += 0.00000001505*np.cos(3.96794786519 + 1677.9385755008*t)
	Y4 += 0.00000001276*np.cos(3.70365044251 + 209.3669421749*t)
	Y4 += 0.00000001310*np.cos(1.09617628890 + 217.2312487011*t)
	Y4 += 0.00000001646*np.cos(5.68811055040 + 195.1398481733*t)
	Y4 += 0.00000001646*np.cos(5.48470092337 + 231.4583427027*t)
	Y4 += 0.00000001479*np.cos(0.48785149790 + 529.6909650946*t)
	Y4 += 0.00000001159*np.cos(1.35912570285 + 81.7521332162*t)
	Y4 += 0.00000001227*np.cos(2.54162930000 + 934.9485149682*t)
	Y4 += 0.00000001038*np.cos(2.36830129087 + 1567.7322542814*t)
	Y4 += 0.00000001079*np.cos(4.46930599086 + 1368.660252845*t)
	Y4 += 0.00000001214*np.cos(1.13732432251 + 1464.6394800628*t)
	Y4 += 0.00000001112*np.cos(3.73702856394 + 1994.3304451574*t)
	Y4 += 0.00000001274*np.cos(4.63347476589 + 735.8765135318*t)
	Y4 += 0.00000000993*np.cos(2.67257314348 + 942.062061969*t)
	Y4 += 0.00000001037*np.cos(1.31415314586 + 1148.2476104062*t)
	Y4 += 0.00000000888*np.cos(4.99973811384 + 1788.1448967202*t)
	Y4 += 0.00000000843*np.cos(0.88917875831 + 750.1036075334*t)
	Y4 += 0.00000000818*np.cos(0.60404781383 + 1045.1548361876*t)
	Y4 += 0.00000000859*np.cos(5.85730307132 + 416.3032501375*t)
	Y4 += 0.00000000862*np.cos(3.18022940336 + 436.8931316145*t)
	Y4 += 0.00000000804*np.cos(5.27286205751 + 1155.361157407*t)
	Y4 += 0.00000000995*np.cos(3.12700036302 + 1891.2376709388*t)
	Y4 += 0.00000000803*np.cos(2.03547611416 + 1375.7737998458*t)
	Y4 += 0.00000000760*np.cos(4.30005555725 + 1258.4539316256*t)
	Y4 += 0.00000000738*np.cos(4.25590020164 + 10.2949407385*t)
	Y4 += 0.00000000728*np.cos(3.57279637901 + 1802.3719907218*t)
	Y4 += 0.00000000684*np.cos(3.52622623805 + 661.2379273164*t)
	return Y4*t*t*t*t




def Saturn_Y5 (t): # 32 terms of order 5

	Y5 = 0.
	Y5 += 0.00000588911*np.cos(4.84910386986 + 206.1855484372*t)
	Y5 += 0.00000589946*np.cos(3.08953743297 + 220.4126424388*t)
	Y5 += 0.00000226448*np.cos(3.03832080293 + 227.5261894396*t)
	Y5 += 0.00000131513*np.cos(2.04967560816 + 433.7117378768*t)
	Y5 += 0.00000094102*np.cos(5.02382407527 + 199.0720014364*t)
	Y5 += 0.00000039693*np.cos(4.32346998407 + 14.2270940016*t)
	Y5 += 0.00000034027*np.cos(2.08525646945 + 440.8252848776*t)
	Y5 += 0.00000022889*np.cos(1.09229217690 + 647.0108333148*t)
	Y5 += 0.00000013218*np.cos(5.16299629187 + 419.4846438752*t)
	Y5 += 0.00000011166*np.cos(0.74664450300 + 639.897286314*t)
	Y5 += 0.00000010308*np.cos(2.94611135407 + 234.6397364404*t)
	Y5 += 0.00000008700*np.cos(1.93382574540 + 191.9584544356*t)
	Y5 += 0.00000007283*np.cos(0.85862173949 + 426.598190876*t)
	Y5 += 0.00000004868*np.cos(6.24105305063 + 88.865680217*t)
	Y5 += 0.00000004778*np.cos(3.47027519446 + 7.1135470008*t)
	Y5 += 0.00000003843*np.cos(0.76786462039 + 405.2575498736*t)
	Y5 += 0.00000004110*np.cos(2.21053405134 + 213.299095438*t)
	Y5 += 0.00000004374*np.cos(1.19431918801 + 654.1243803156*t)
	Y5 += 0.00000003330*np.cos(6.12745878547 + 853.196381752*t)
	Y5 += 0.00000003260*np.cos(2.32884812687 + 124.433415221*t)
	Y5 += 0.00000002704*np.cos(1.44355016718 + 515.463871093*t)
	Y5 += 0.00000002565*np.cos(1.20250305213 + 110.2063212194*t)
	Y5 += 0.00000002678*np.cos(0.17889143297 + 860.3099287528*t)
	Y5 += 0.00000002138*np.cos(2.01599255393 + 447.9388318784*t)
	Y5 += 0.00000001636*np.cos(0.39362704173 + 302.164775655*t)
	Y5 += 0.00000001889*np.cos(0.49025110230 + 95.9792272178*t)
	Y5 += 0.00000001454*np.cos(0.14310762168 + 309.2783226558*t)
	Y5 += 0.00000000972*np.cos(4.13503049863 + 117.3198682202*t)
	Y5 += 0.00000000984*np.cos(2.38499591413 + 203.0041546995*t)
	Y5 += 0.00000000984*np.cos(2.50463025246 + 223.5940361765*t)
	Y5 += 0.00000000780*np.cos(0.55796214439 + 330.6189636582*t)
	Y5 += 0.00000000786*np.cos(1.61541856004 + 522.5774180938*t)
	return Y5*t*t*t*t*t




def Saturn_Z0 (t): # 424 terms of order 0

	Z0 = 0.
	Z0 += 0.41345140292*np.cos(3.60234141893 + 213.299095438*t)
	Z0 += 0.01147953788*np.cos(2.85128771957 + 426.598190876*t)
	Z0 += 0.01213097211
	Z0 += 0.00329186544*np.cos(0.57121482436 + 206.1855484372*t)
	Z0 += 0.00286852189*np.cos(3.48073528206 + 220.4126424388*t)
	Z0 += 0.00099054808*np.cos(4.73370561217 + 7.1135470008*t)
	Z0 += 0.00057347600*np.cos(4.92616271331 + 110.2063212194*t)
	Z0 += 0.00047724545*np.cos(2.10039838370 + 639.897286314*t)
	Z0 += 0.00043448305*np.cos(5.84904880596 + 419.4846438752*t)
	Z0 += 0.00034555171*np.cos(5.42614764541 + 316.3918696566*t)
	Z0 += 0.00016180782*np.cos(2.72987541776 + 433.7117378768*t)
	Z0 += 0.00009004046*np.cos(1.38192071602 + 103.0927742186*t)
	Z0 += 0.00005397142*np.cos(5.13204682732 + 202.2533951741*t)
	Z0 += 0.00004577011*np.cos(4.56990158929 + 38.1330356378*t)
	Z0 += 0.00003901809*np.cos(3.71512735501 + 323.5054166574*t)
	Z0 += 0.00003711659*np.cos(5.05573795500 + 632.7837393132*t)
	Z0 += 0.00003613072*np.cos(3.35210458559 + 227.5261894396*t)
	Z0 += 0.00003379535*np.cos(2.13867177875 + 11.0457002639*t)
	Z0 += 0.00003088992*np.cos(3.62572857085 + 209.3669421749*t)
	Z0 += 0.00002683108*np.cos(4.87673933693 + 224.3447957019*t)
	Z0 += 0.00002962647*np.cos(0.46490184985 + 217.2312487011*t)
	Z0 += 0.00002342675*np.cos(1.34556621598 + 853.196381752*t)
	Z0 += 0.00002424180*np.cos(2.92931088398 + 63.7358983034*t)
	Z0 += 0.00001701916*np.cos(1.89892525654 + 735.8765135318*t)
	Z0 += 0.00001940777*np.cos(4.59422357831 + 14.2270940016*t)
	Z0 += 0.00001989569*np.cos(0.73166484127 + 199.0720014364*t)
	Z0 += 0.00001800493*np.cos(5.12194244143 + 529.6909650946*t)
	Z0 += 0.00001423982*np.cos(3.11558318997 + 522.5774180938*t)
	Z0 += 0.00001148029*np.cos(4.41145011466 + 117.3198682202*t)
	Z0 += 0.00001092497*np.cos(3.10679381209 + 216.4804891757*t)
	Z0 += 0.00001014889*np.cos(1.97897277665 + 647.0108333148*t)
	Z0 += 0.00001097941*np.cos(0.96097709156 + 210.1177017003*t)
	Z0 += 0.00000992793*np.cos(2.99636857682 + 846.0828347512*t)
	Z0 += 0.00001028445*np.cos(2.11933097909 + 415.5524906121*t)
	Z0 += 0.00000907521*np.cos(4.68574636784 + 309.2783226558*t)
	Z0 += 0.00000832820*np.cos(2.88893409053 + 149.5631971346*t)
	Z0 += 0.00000612306*np.cos(0.10918824809 + 74.7815985673*t)
	Z0 += 0.00000631089*np.cos(1.30558812837 + 277.0349937414*t)
	Z0 += 0.00000574105*np.cos(0.63353442802 + 490.3340891794*t)
	Z0 += 0.00000470993*np.cos(1.61845232899 + 1052.2683831884*t)
	Z0 += 0.00000416101*np.cos(5.88183041216 + 95.9792272178*t)
	Z0 += 0.00000410222*np.cos(2.56080817002 + 1162.4747044078*t)
	Z0 += 0.00000381934*np.cos(2.83850532211 + 838.9692877504*t)
	Z0 += 0.00000370902*np.cos(2.22356953874 + 351.8165923087*t)
	Z0 += 0.00000337338*np.cos(4.12487690436 + 3.9321532631*t)
	Z0 += 0.00000263173*np.cos(2.60594324261 + 440.8252848776*t)
	Z0 += 0.00000242649*np.cos(3.05671546262 + 536.8045120954*t)
	Z0 += 0.00000231186*np.cos(2.79137518143 + 127.4717966068*t)
	Z0 += 0.00000226218*np.cos(0.98981012262 + 210.8514148832*t)
	Z0 += 0.00000252287*np.cos(3.04205345262 + 137.0330241624*t)
	Z0 += 0.00000223924*np.cos(3.07498346391 + 215.7467759928*t)
	Z0 += 0.00000189542*np.cos(5.75473717633 + 742.9900605326*t)
	Z0 += 0.00000162873*np.cos(3.89762690585 + 214.2623032845*t)
	Z0 += 0.00000164510*np.cos(2.45697452905 + 422.6660376129*t)
	Z0 += 0.00000158129*np.cos(2.31312619246 + 1478.8665740644*t)
	Z0 += 0.00000203884*np.cos(3.85881179734 + 949.1756089698*t)
	Z0 += 0.00000156454*np.cos(1.35680198123 + 1368.660252845*t)
	Z0 += 0.00000150079*np.cos(4.14045329244 + 437.6438911399*t)
	Z0 += 0.00000142705*np.cos(2.58383947868 + 1155.361157407*t)
	Z0 += 0.00000140820*np.cos(2.28833335144 + 76.2660712756*t)
	Z0 += 0.00000163551*np.cos(0.16578976592 + 212.3358875915*t)
	Z0 += 0.00000135335*np.cos(0.48883402314 + 213.3472795478*t)
	Z0 += 0.00000126614*np.cos(0.59356477117 + 1066.49547719*t)
	Z0 += 0.00000140534*np.cos(3.97289861748 + 625.6701923124*t)
	Z0 += 0.00000121564*np.cos(4.51381049808 + 3.1813937377*t)
	Z0 += 0.00000119190*np.cos(1.61391416177 + 628.8515860501*t)
	Z0 += 0.00000115147*np.cos(3.43459040245 + 330.6189636582*t)
	Z0 += 0.00000135375*np.cos(3.57424025701 + 213.2509113282*t)
	Z0 += 0.00000103727*np.cos(6.17639441368 + 200.7689224658*t)
	Z0 += 0.00000107221*np.cos(3.52515054076 + 138.5174968707*t)
	Z0 += 0.00000107873*np.cos(3.99795753041 + 85.8272988312*t)
	Z0 += 0.00000113808*np.cos(0.43922136441 + 222.8603229936*t)
	Z0 += 0.00000094920*np.cos(2.26222536028 + 388.4651552382*t)
	Z0 += 0.00000109894*np.cos(3.51094365836 + 1265.5674786264*t)
	Z0 += 0.00000101425*np.cos(0.14126238472 + 430.5303441391*t)
	Z0 += 0.00000101928*np.cos(0.21047731069 + 412.3710968744*t)
	Z0 += 0.00000104973*np.cos(4.19518394917 + 9.5612275556*t)
	Z0 += 0.00000082819*np.cos(4.86658856977 + 1.4844727083*t)
	Z0 += 0.00000071104*np.cos(4.92741306047 + 212.7778305762*t)
	Z0 += 0.00000070089*np.cos(1.05108025259 + 12.5301729722*t)
	Z0 += 0.00000066662*np.cos(1.22617152895 + 860.3099287528*t)
	Z0 += 0.00000077048*np.cos(0.80511279723 + 52.6901980395*t)
	Z0 += 0.00000090986*np.cos(6.28198480720 + 423.4167971383*t)
	Z0 += 0.00000062746*np.cos(2.06105893244 + 1795.258443721*t)
	Z0 += 0.00000063467*np.cos(2.36959372262 + 429.7795846137*t)
	Z0 += 0.00000058999*np.cos(2.31882650737 + 1471.7530270636*t)
	Z0 += 0.00000076181*np.cos(2.67435759741 + 191.2076949102*t)
	Z0 += 0.00000063389*np.cos(1.81556177589 + 350.3321196004*t)
	Z0 += 0.00000056601*np.cos(1.11303957705 + 1685.0521225016*t)
	Z0 += 0.00000057345*np.cos(3.28686490919 + 515.463871093*t)
	Z0 += 0.00000070959*np.cos(5.41979944279 + 213.8203602998*t)
	Z0 += 0.00000070150*np.cos(3.82574373735 + 942.062061969*t)
	Z0 += 0.00000051149*np.cos(3.86030131690 + 173.9422195228*t)
	Z0 += 0.00000051666*np.cos(3.49111344070 + 203.7378678824*t)
	Z0 += 0.00000050128*np.cos(1.98273693937 + 195.1398481733*t)
	Z0 += 0.00000048091*np.cos(3.20971334548 + 234.6397364404*t)
	Z0 += 0.00000049761*np.cos(6.18808156638 + 703.6331846174*t)
	Z0 += 0.00000046488*np.cos(3.80768518798 + 225.8292684102*t)
	Z0 += 0.00000054127*np.cos(3.18092923296 + 1581.959348283*t)
	Z0 += 0.00000047483*np.cos(1.53655093485 + 265.9892934775*t)
	Z0 += 0.00000039354*np.cos(2.10537295968 + 728.762966531*t)
	Z0 += 0.00000039602*np.cos(2.27507746067 + 288.0806940053*t)
	Z0 += 0.00000041716*np.cos(1.05111221485 + 563.6312150384*t)
	Z0 += 0.00000037614*np.cos(6.14179074602 + 217.491881132*t)
	Z0 += 0.00000042785*np.cos(0.11273484212 + 252.6559713532*t)
	Z0 += 0.00000037718*np.cos(5.96333653993 + 210.3783341312*t)
	Z0 += 0.00000036792*np.cos(1.35292393469 + 565.1156877467*t)
	Z0 += 0.00000037862*np.cos(4.00773869969 + 62.2514255951*t)
	Z0 += 0.00000036057*np.cos(3.30899953753 + 212.5483359126*t)
	Z0 += 0.00000035460*np.cos(5.01105830246 + 65.2203710117*t)
	Z0 += 0.00000034852*np.cos(4.75445504646 + 207.8824694666*t)
	Z0 += 0.00000040506*np.cos(2.20073759144 + 362.8622925726*t)
	Z0 += 0.00000032560*np.cos(6.14806301843 + 417.0369633204*t)
	Z0 += 0.00000037967*np.cos(4.57075294928 + 302.164775655*t)
	Z0 += 0.00000032818*np.cos(5.79538785685 + 99.1606209555*t)
	Z0 += 0.00000030744*np.cos(3.64317302294 + 207.6700211455*t)
	Z0 += 0.00000032548*np.cos(2.95740474962 + 70.8494453042*t)
	Z0 += 0.00000035830*np.cos(0.75230512173 + 214.0498549634*t)
	Z0 += 0.00000034253*np.cos(2.96835157474 + 223.5940361765*t)
	Z0 += 0.00000032939*np.cos(4.45144712576 + 21.3406410024*t)
	Z0 += 0.00000037689*np.cos(4.37977418287 + 216.2198567448*t)
	Z0 += 0.00000032421*np.cos(5.78559756829 + 160.6088973985*t)
	Z0 += 0.00000028902*np.cos(5.81529149124 + 88.865680217*t)
	Z0 += 0.00000033335*np.cos(5.62401622695 + 218.7157214094*t)
	Z0 += 0.00000038185*np.cos(4.19997816879 + 209.106309744*t)
	Z0 += 0.00000027693*np.cos(5.55618950213 + 18.1592472647*t)
	Z0 += 0.00000028922*np.cos(5.58858980738 + 425.1137181677*t)
	Z0 += 0.00000032330*np.cos(4.22794944092 + 22.0914005278*t)
	Z0 += 0.00000029913*np.cos(3.31182307103 + 124.433415221*t)
	Z0 += 0.00000029634*np.cos(5.83020812669 + 956.2891559706*t)
	Z0 += 0.00000026648*np.cos(0.86666603224 + 217.964961884*t)
	Z0 += 0.00000025659*np.cos(5.10869894674 + 479.2883889155*t)
	Z0 += 0.00000025652*np.cos(4.80215156054 + 231.4583427027*t)
	Z0 += 0.00000026011*np.cos(2.05589181933 + 1788.1448967202*t)
	Z0 += 0.00000025663*np.cos(1.81564756635 + 2111.6503133776*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000029049*np.cos(1.03106421110 + 1059.3819301892*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000022977*np.cos(5.44037839738 + 142.4496501338*t)
	Z0 += 0.00000031283*np.cos(3.54881062563 + 1258.4539316256*t)
	Z0 += 0.00000030192*np.cos(0.42929684303 + 218.9281697305*t)
	Z0 += 0.00000026495*np.cos(2.86288115466 + 1898.3512179396*t)
	Z0 += 0.00000029523*np.cos(0.37961341545 + 554.0699874828*t)
	Z0 += 0.00000022228*np.cos(5.48142509504 + 408.4389436113*t)
	Z0 += 0.00000021237*np.cos(0.87139429027 + 2001.4439921582*t)
	Z0 += 0.00000020174*np.cos(1.85380647370 + 654.1243803156*t)
	Z0 += 0.00000020521*np.cos(6.16117414568 + 56.6223513026*t)
	Z0 += 0.00000023744*np.cos(3.20046265011 + 208.633228992*t)
	Z0 += 0.00000021685*np.cos(3.17871482760 + 414.0680179038*t)
	Z0 += 0.00000019856*np.cos(3.13857572740 + 175.1660598002*t)
	Z0 += 0.00000017347*np.cos(5.96946168051 + 213.1872208534*t)
	Z0 += 0.00000017925*np.cos(1.14556340660 + 203.0041546995*t)
	Z0 += 0.00000018247*np.cos(3.00127995342 + 831.8557407496*t)
	Z0 += 0.00000017378*np.cos(0.74127655202 + 177.8743727859*t)
	Z0 += 0.00000016401*np.cos(1.36402971878 + 211.8146227297*t)
	Z0 += 0.00000016228*np.cos(3.17582194781 + 98.8999885246*t)
	Z0 += 0.00000016107*np.cos(0.54971362869 + 251.4321310758*t)
	Z0 += 0.00000015546*np.cos(2.29108586908 + 750.1036075334*t)
	Z0 += 0.00000015320*np.cos(3.80296373340 + 483.2205421786*t)
	Z0 += 0.00000014467*np.cos(1.32549449124 + 114.1384744825*t)
	Z0 += 0.00000014017*np.cos(0.22639450394 + 148.0787244263*t)
	Z0 += 0.00000014146*np.cos(4.85276668809 + 327.4375699205*t)
	Z0 += 0.00000015436*np.cos(1.48161033604 + 198.321241911*t)
	Z0 += 0.00000014576*np.cos(3.75966213667 + 213.5115437591*t)
	Z0 += 0.00000014820*np.cos(3.34957428396 + 248.7238180901*t)
	Z0 += 0.00000013743*np.cos(4.77276011938 + 106.2741679563*t)
	Z0 += 0.00000017347*np.cos(4.37930417897 + 213.4109700226*t)
	Z0 += 0.00000014576*np.cos(0.30591841563 + 213.0866471169*t)
	Z0 += 0.00000013755*np.cos(2.59733474149 + 228.276948965*t)
	Z0 += 0.00000012945*np.cos(1.84552645547 + 1045.1548361876*t)
	Z0 += 0.00000012834*np.cos(4.24597463890 + 10.2949407385*t)
	Z0 += 0.00000012885*np.cos(4.86095700310 + 39.3568759152*t)
	Z0 += 0.00000016969*np.cos(1.27721722241 + 214.7835681463*t)
	Z0 += 0.00000012706*np.cos(0.31024660308 + 424.1505103212*t)
	Z0 += 0.00000012558*np.cos(0.03128357867 + 1272.6810256272*t)
	Z0 += 0.00000014310*np.cos(2.34661407283 + 1375.7737998458*t)
	Z0 += 0.00000011808*np.cos(1.79617614059 + 2104.5367663768*t)
	Z0 += 0.00000013258*np.cos(2.56724178887 + 2214.7430875962*t)
	Z0 += 0.00000011158*np.cos(0.45949551763 + 497.4476361802*t)
	Z0 += 0.00000014798*np.cos(1.03056978581 + 2.4476805548*t)
	Z0 += 0.00000014861*np.cos(3.26343762010 + 1574.8458012822*t)
	Z0 += 0.00000011978*np.cos(6.22486801109 + 121.2520214833*t)
	Z0 += 0.00000010959*np.cos(1.31570222417 + 235.3904959658*t)
	Z0 += 0.00000011901*np.cos(1.58846496072 + 635.9651330509*t)
	Z0 += 0.00000011080*np.cos(5.37041305935 + 1169.5882514086*t)
	Z0 += 0.00000010475*np.cos(2.19368288733 + 221.3758502853*t)
	Z0 += 0.00000012129*np.cos(4.63783219973 + 269.9214467406*t)
	Z0 += 0.00000013259*np.cos(1.84711455587 + 151.0476698429*t)
	Z0 += 0.00000010959*np.cos(4.40512358221 + 213.5597278689*t)
	Z0 += 0.00000010673*np.cos(1.60141035946 + 2428.0421830342*t)
	Z0 += 0.00000011521*np.cos(2.11579255167 + 205.2223405907*t)
	Z0 += 0.00000010228*np.cos(2.41342516828 + 275.5505210331*t)
	Z0 += 0.00000010229*np.cos(0.96548776504 + 842.1506814881*t)
	Z0 += 0.00000010959*np.cos(5.94363969204 + 213.0384630071*t)
	Z0 += 0.00000009406*np.cos(3.39740548756 + 650.9429865779*t)
	Z0 += 0.00000010284*np.cos(0.01930234298 + 219.4494345923*t)
	Z0 += 0.00000009424*np.cos(1.68112701238 + 488.8496164711*t)
	Z0 += 0.00000008939*np.cos(5.28697277625 + 340.7708920448*t)
	Z0 += 0.00000008867*np.cos(2.69602875485 + 1692.1656695024*t)
	Z0 += 0.00000009979*np.cos(3.97256303244 + 278.5194664497*t)
	Z0 += 0.00000008356*np.cos(0.65143790392 + 2317.8358618148*t)
	Z0 += 0.00000008169*np.cos(3.23957036879 + 427.5613987225*t)
	Z0 += 0.00000009044*np.cos(0.23054654773 + 312.1990839626*t)
	Z0 += 0.00000007927*np.cos(3.97539997718 + 210.5907824523*t)
	Z0 += 0.00000010063*np.cos(4.21498692120 + 618.5566453116*t)
	Z0 += 0.00000009335*np.cos(5.70779396792 + 425.6349830295*t)
	Z0 += 0.00000008385*np.cos(0.64196694648 + 188.9200730498*t)
	Z0 += 0.00000008670*np.cos(2.75601079050 + 491.8185618877*t)
	Z0 += 0.00000008100*np.cos(4.06039030284 + 207.1487562837*t)
	Z0 += 0.00000007835*np.cos(2.72270422259 + 543.9180590962*t)
	Z0 += 0.00000009452*np.cos(2.59277908129 + 429.0458714308*t)
	Z0 += 0.00000007738*np.cos(1.55361395079 + 601.7642506762*t)
	Z0 += 0.00000007577*np.cos(6.02114380426 + 426.6463749858*t)
	Z0 += 0.00000009275*np.cos(5.16642875471 + 8.0767548473*t)
	Z0 += 0.00000007663*np.cos(2.73399784358 + 1148.2476104062*t)
	Z0 += 0.00000007158*np.cos(5.84039229615 + 84.3428261229*t)
	Z0 += 0.00000008033*np.cos(4.20065885029 + 767.3690829208*t)
	Z0 += 0.00000006822*np.cos(6.12047591103 + 1279.794572628*t)
	Z0 += 0.00000006961*np.cos(3.34826318442 + 237.6781178262*t)
	Z0 += 0.00000006580*np.cos(5.81874339759 + 284.1485407422*t)
	Z0 += 0.00000006629*np.cos(1.53732206945 + 289.5651667136*t)
	Z0 += 0.00000006283*np.cos(3.84796221759 + 125.9873238985*t)
	Z0 += 0.00000007796*np.cos(0.08813581424 + 216.0074084237*t)
	Z0 += 0.00000008282*np.cos(1.90022750359 + 134.5853436076*t)
	Z0 += 0.00000006576*np.cos(0.35050721605 + 220.4608265486*t)
	Z0 += 0.00000006587*np.cos(0.58291546593 + 213.4591541324*t)
	Z0 += 0.00000006626*np.cos(3.37506241952 + 312.4597163935*t)
	Z0 += 0.00000006587*np.cos(3.48062808501 + 213.1390367436*t)
	Z0 += 0.00000007576*np.cos(2.82334902636 + 426.5500067662*t)
	Z0 += 0.00000005988*np.cos(5.47551169354 + 35.4247226521*t)
	Z0 += 0.00000005723*np.cos(5.22938546212 + 212.0270710508*t)
	Z0 += 0.00000006565*np.cos(5.18423527980 + 67.6680515665*t)
	Z0 += 0.00000005704*np.cos(5.31164037710 + 1485.9801210652*t)
	Z0 += 0.00000006842*np.cos(6.15429926594 + 179.3588454942*t)
	Z0 += 0.00000007349*np.cos(0.73079523905 + 355.7487455718*t)
	Z0 += 0.00000005590*np.cos(4.19082216094 + 247.2393453818*t)
	Z0 += 0.00000006488*np.cos(2.29038019982 + 2531.1349572528*t)
	Z0 += 0.00000007413*np.cos(2.98595847215 + 1891.2376709388*t)
	Z0 += 0.00000005491*np.cos(2.70527999156 + 2008.557539159*t)
	Z0 += 0.00000005820*np.cos(2.98199777797 + 5.4166259714*t)
	Z0 += 0.00000005622*np.cos(1.45901882320 + 501.3797894433*t)
	Z0 += 0.00000005473*np.cos(0.81641753389 + 181.0557665236*t)
	Z0 += 0.00000005454*np.cos(6.12211624341 + 643.8294395771*t)
	Z0 += 0.00000005407*np.cos(1.53066536154 + 2420.9286360334*t)
	Z0 += 0.00000005621*np.cos(4.67878120796 + 73.297125859*t)
	Z0 += 0.00000005442*np.cos(0.02368001914 + 404.5067903482*t)
	Z0 += 0.00000005436*np.cos(4.67977840196 + 621.7380390493*t)
	Z0 += 0.00000006267*np.cos(5.43877709236 + 636.7158925763*t)
	Z0 += 0.00000005068*np.cos(4.33978904750 + 113.3877149571*t)
	Z0 += 0.00000004865*np.cos(5.10809843245 + 69.1525242748*t)
	Z0 += 0.00000005833*np.cos(0.02767070726 + 1589.0728952838*t)
	Z0 += 0.00000005070*np.cos(3.27536823314 + 144.1465711632*t)
	Z0 += 0.00000004738*np.cos(0.53669462342 + 1073.6090241908*t)
	Z0 += 0.00000005183*np.cos(2.18841260581 + 107.0249274817*t)
	Z0 += 0.00000005310*np.cos(0.66732715963 + 116.4260963429*t)
	Z0 += 0.00000005141*np.cos(2.42998599018 + 692.5874843535*t)
	Z0 += 0.00000006231*np.cos(5.93759865879 + 436.1594184316*t)
	Z0 += 0.00000006367*np.cos(3.45785496152 + 220.364458329*t)
	Z0 += 0.00000004541*np.cos(0.61777794179 + 206.233732547*t)
	Z0 += 0.00000004528*np.cos(1.65756596310 + 1361.5467058442*t)
	Z0 += 0.00000005172*np.cos(4.96799695932 + 342.2553647531*t)
	Z0 += 0.00000005805*np.cos(2.10740836405 + 4.665866446*t)
	Z0 += 0.00000004639*np.cos(1.63821364676 + 5.6290742925*t)
	Z0 += 0.00000004731*np.cos(1.44641985940 + 2744.4340526908*t)
	Z0 += 0.00000004756*np.cos(3.73287086188 + 206.1373643274*t)
	Z0 += 0.00000004322*np.cos(4.15153138812 + 426.0769260142*t)
	Z0 += 0.00000004167*np.cos(1.65241802351 + 191.9584544356*t)
	Z0 += 0.00000004164*np.cos(2.47912208303 + 447.9388318784*t)
	Z0 += 0.00000005676*np.cos(5.11706007934 + 214.5711198252*t)
	Z0 += 0.00000003966*np.cos(0.05086647098 + 206.706813299*t)
	Z0 += 0.00000004603*np.cos(5.52562693778 + 78.7137518304*t)
	Z0 += 0.00000003802*np.cos(0.43628874694 + 617.8058857862*t)
	Z0 += 0.00000004800*np.cos(5.54041183899 + 344.7030453079*t)
	Z0 += 0.00000004743*np.cos(0.53760335914 + 128.9562693151*t)
	Z0 += 0.00000004130*np.cos(1.61538042826 + 643.0786800517*t)
	Z0 += 0.00000004686*np.cos(3.97383030786 + 934.9485149682*t)
	Z0 += 0.00000004043*np.cos(2.18819710124 + 358.9301393095*t)
	Z0 += 0.00000003906*np.cos(5.19970623343 + 630.3360587584*t)
	Z0 += 0.00000003883*np.cos(5.39147665291 + 320.3240229197*t)
	Z0 += 0.00000004913*np.cos(1.03288629446 + 32.2433289144*t)
	Z0 += 0.00000003689*np.cos(5.45822055399 + 916.9322800554*t)
	Z0 += 0.00000004228*np.cos(4.28360558940 + 4.192785694*t)
	Z0 += 0.00000004020*np.cos(4.88073386744 + 54.1746707478*t)
	Z0 += 0.00000004185*np.cos(3.32405342181 + 245.5424243524*t)
	Z0 += 0.00000004673*np.cos(1.82605230090 + 114.3991069134*t)
	Z0 += 0.00000004596*np.cos(4.18504944347 + 219.891377577*t)
	Z0 += 0.00000003552*np.cos(5.98005739127 + 20.6069278195*t)
	Z0 += 0.00000003975*np.cos(5.80157206371 + 14.977853527*t)
	Z0 += 0.00000003475*np.cos(2.47178960968 + 1464.6394800628*t)
	Z0 += 0.00000004395*np.cos(0.85418906454 + 525.4981794006*t)
	Z0 += 0.00000003187*np.cos(2.61148353061 + 2324.9494088156*t)
	Z0 += 0.00000003966*np.cos(4.66662911986 + 427.1194557378*t)
	Z0 += 0.00000003124*np.cos(0.10655817305 + 14.0146456805*t)
	Z0 += 0.00000003104*np.cos(0.38849805992 + 2634.2277314714*t)
	Z0 += 0.00000003508*np.cos(2.85265213502 + 87.3117715395*t)
	Z0 += 0.00000002979*np.cos(3.04084830124 + 420.9691165835*t)
	Z0 += 0.00000003143*np.cos(1.71420147928 + 0.9632078465*t)
	Z0 += 0.00000003169*np.cos(1.34499488466 + 159.1244246902*t)
	Z0 += 0.00000003871*np.cos(2.71348462732 + 2207.6295405954*t)
	Z0 += 0.00000002814*np.cos(0.52649713800 + 778.4147831847*t)
	Z0 += 0.00000002890*np.cos(1.29415320006 + 2737.32050569*t)
	Z0 += 0.00000002831*np.cos(4.45595764630 + 518.6452648307*t)
	Z0 += 0.00000002757*np.cos(2.05371431350 + 214.5229357154*t)
	Z0 += 0.00000002757*np.cos(2.83591185309 + 212.0752551606*t)
	Z0 += 0.00000003187*np.cos(2.00772012188 + 2847.5268269094*t)
	Z0 += 0.00000002712*np.cos(5.27492060596 + 305.3461693927*t)
	Z0 += 0.00000002771*np.cos(2.54360038772 + 319.5732633943*t)
	Z0 += 0.00000002630*np.cos(5.50124179878 + 423.6774295692*t)
	Z0 += 0.00000002626*np.cos(0.49212317679 + 153.4953503977*t)
	Z0 += 0.00000002828*np.cos(3.04457317761 + 211.6021744086*t)
	Z0 += 0.00000002650*np.cos(2.71849987794 + 145.6310438715*t)
	Z0 += 0.00000002589*np.cos(5.18248239650 + 1802.3719907218*t)
	Z0 += 0.00000002579*np.cos(1.68789924795 + 6.1503391543*t)
	Z0 += 0.00000003452*np.cos(0.69033243447 + 776.9303104764*t)
	Z0 += 0.00000002527*np.cos(3.47384786002 + 184.9879197867*t)
	Z0 += 0.00000002496*np.cos(5.96218386110 + 2.9207613068*t)
	Z0 += 0.00000003222*np.cos(3.60809233593 + 1251.3403846248*t)
	Z0 += 0.00000002684*np.cos(5.48972047825 + 391.1734682239*t)
	Z0 += 0.00000002370*np.cos(1.54660575926 + 51.2057253312*t)
	Z0 += 0.00000002310*np.cos(0.63846192912 + 416.3032501375*t)
	Z0 += 0.00000002444*np.cos(3.87972666346 + 182.279606801*t)
	Z0 += 0.00000002435*np.cos(2.71829697900 + 627.3671133418*t)
	Z0 += 0.00000002236*np.cos(1.31003501645 + 241.6102710893*t)
	Z0 += 0.00000002653*np.cos(5.70255270090 + 220.9339073006*t)
	Z0 += 0.00000002646*np.cos(3.30185009916 + 696.5196376166*t)
	Z0 += 0.00000002211*np.cos(4.72699183302 + 387.2413149608*t)
	Z0 += 0.00000002313*np.cos(2.81517281649 + 738.7972748386*t)
	Z0 += 0.00000002197*np.cos(2.63929129920 + 436.8931316145*t)
	Z0 += 0.00000002348*np.cos(1.83689902078 + 214.9960164674*t)
	Z0 += 0.00000002842*np.cos(2.88171478117 + 337.732510659*t)
	Z0 += 0.00000002195*np.cos(1.58125142363 + 1677.9385755008*t)
	Z0 += 0.00000002609*np.cos(1.41922918177 + 329.7251917809*t)
	Z0 += 0.00000002207*np.cos(5.67197607780 + 905.8865797915*t)
	Z0 += 0.00000002182*np.cos(3.15263816837 + 439.1283638482*t)
	Z0 += 0.00000002060*np.cos(5.78919528834 + 120.358249606*t)
	Z0 += 0.00000002079*np.cos(5.08007114480 + 7.065362891*t)
	Z0 += 0.00000002351*np.cos(0.26849523535 + 140.001969579*t)
	Z0 += 0.00000002770*np.cos(4.57559729641 + 24.3790223882*t)
	Z0 += 0.00000002705*np.cos(4.32491993913 + 46.470422916*t)
	Z0 += 0.00000002052*np.cos(1.22649156182 + 92.0470739547*t)
	Z0 += 0.00000002046*np.cos(5.19173373776 + 347.8844390456*t)
	Z0 += 0.00000002036*np.cos(2.88971262431 + 980.6681783588*t)
	Z0 += 0.00000002481*np.cos(1.55318712059 + 576.1613880106*t)
	Z0 += 0.00000002024*np.cos(4.32935289944 + 31.019488637*t)
	Z0 += 0.00000002006*np.cos(2.01138855049 + 211.8628068395*t)
	Z0 += 0.00000002006*np.cos(2.87823761610 + 214.7353840365*t)
	Z0 += 0.00000002026*np.cos(2.42235724251 + 2641.3412784722*t)
	Z0 += 0.00000001938*np.cos(2.48016602910 + 487.3651437628*t)
	Z0 += 0.00000002065*np.cos(1.16081214330 + 192.6921676185*t)
	Z0 += 0.00000002254*np.cos(5.99623174740 + 1905.4647649404*t)
	Z0 += 0.00000001922*np.cos(5.98223148262 + 96.8729990951*t)
	Z0 += 0.00000002534*np.cos(2.62272549680 + 421.93232443*t)
	Z0 += 0.00000002106*np.cos(1.84883841490 + 299.1263942692*t)
	Z0 += 0.00000002211*np.cos(1.86083014117 + 221.1634019642*t)
	Z0 += 0.00000002083*np.cos(6.14443432076 + 59.8037450403*t)
	Z0 += 0.00000001909*np.cos(1.13231253998 + 282.4516197128*t)
	Z0 += 0.00000001898*np.cos(3.53454927143 + 219.6618829134*t)
	Z0 += 0.00000002007*np.cos(4.35167828920 + 444.7574381407*t)
	Z0 += 0.00000001974*np.cos(5.78637079670 + 430.79097657*t)
	Z0 += 0.00000001937*np.cos(4.03561100629 + 429.5189521828*t)
	Z0 += 0.00000001838*np.cos(2.97004270413 + 425.8474313506*t)
	Z0 += 0.00000001927*np.cos(4.45403563257 + 2.9689454166*t)
	Z0 += 0.00000001858*np.cos(5.83605607376 + 280.9671470045*t)
	Z0 += 0.00000002128*np.cos(3.95375781114 + 831.1049812242*t)
	Z0 += 0.00000002111*np.cos(5.51034879271 + 428.0826635843*t)
	Z0 += 0.00000002084*np.cos(4.99656154667 + 254.9435932136*t)
	Z0 += 0.00000002189*np.cos(5.75843317256 + 418.5214360287*t)
	Z0 += 0.00000002225*np.cos(5.22774546552 + 638.4128136057*t)
	Z0 += 0.00000002362*np.cos(0.10821349524 + 131.4039498699*t)
	Z0 += 0.00000001938*np.cos(3.62212314488 + 267.4737661858*t)
	Z0 += 0.00000002349*np.cos(2.45602769901 + 2524.021410252*t)
	Z0 += 0.00000001752*np.cos(0.17721513623 + 969.6224780949*t)
	Z0 += 0.00000002216*np.cos(4.46378373321 + 353.301065017*t)
	Z0 += 0.00000001697*np.cos(3.74680430424 + 421.1815649046*t)
	Z0 += 0.00000001692*np.cos(1.29673821700 + 2840.4132799086*t)
	Z0 += 0.00000001698*np.cos(2.09387250037 + 292.0128472684*t)
	Z0 += 0.00000002118*np.cos(2.90133577623 + 205.4347889118*t)
	Z0 += 0.00000002049*np.cos(1.88559014939 + 199.2844497575*t)
	Z0 += 0.00000001712*np.cos(2.97477489664 + 273.1028404783*t)
	Z0 += 0.00000001828*np.cos(2.23147050409 + 1781.0313497194*t)
	Z0 += 0.00000001737*np.cos(2.59432238776 + 264.5048207692*t)
	Z0 += 0.00000001676*np.cos(2.73737546375 + 3480.3105662226*t)
	Z0 += 0.00000001935*np.cos(2.01080991907 + 7.1617311106*t)
	Z0 += 0.00000001602*np.cos(4.81017819939 + 1382.8873468466*t)
	Z0 += 0.00000001894*np.cos(4.74702697079 + 558.0021407459*t)
	Z0 += 0.00000001589*np.cos(0.85622467383 + 1044.4040766622*t)
	Z0 += 0.00000001565*np.cos(5.03064453644 + 458.8415197904*t)
	Z0 += 0.00000001648*np.cos(5.00766073214 + 2648.454825473*t)
	Z0 += 0.00000001562*np.cos(4.62304098893 + 543.0242872189*t)
	Z0 += 0.00000001794*np.cos(2.92299868481 + 227.3137411185*t)
	Z0 += 0.00000001844*np.cos(6.25012647811 + 432.2272651685*t)
	Z0 += 0.00000001821*np.cos(5.47892889469 + 205.6642835754*t)
	Z0 += 0.00000001699*np.cos(3.29572190816 + 533.6231183577*t)
	Z0 += 0.00000001605*np.cos(2.57251520836 + 3127.3133312618*t)
	Z0 += 0.00000001477*np.cos(1.36669731999 + 206.9363079626*t)
	Z0 += 0.00000001468*np.cos(4.67912895132 + 339.2864193365*t)
	Z0 += 0.00000001481*np.cos(0.92457754588 + 1994.3304451574*t)
	Z0 += 0.00000001547*np.cos(0.13419340100 + 465.9550667912*t)
	Z0 += 0.00000001457*np.cos(0.52628058703 + 427.3489504014*t)
	Z0 += 0.00000001902*np.cos(1.24600006636 + 166.828672522*t)
	Z0 += 0.00000001529*np.cos(2.85370771355 + 209.1544938538*t)
	Z0 += 0.00000001494*np.cos(3.66845408834 + 1182.9215735329*t)
	Z0 += 0.00000001588*np.cos(1.63988438811 + 3163.918696566*t)
	Z0 += 0.00000001502*np.cos(4.96348459770 + 373.9079928365*t)
	Z0 += 0.00000001608*np.cos(3.59138122093 + 233.9060232575*t)
	Z0 += 0.00000001460*np.cos(1.17818401345 + 92.940845832*t)
	Z0 += 0.00000001462*np.cos(5.05747764334 + 33.9402499438*t)
	Z0 += 0.00000001490*np.cos(2.03601440129 + 217.4436970222*t)
	Z0 += 0.00000001688*np.cos(1.50928274793 + 815.0633461142*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001778*np.cos(0.24563726151 + 6.592282139*t)
	Z0 += 0.00000001834*np.cos(3.98017256784 + 212.4053235607*t)
	Z0 += 0.00000001834*np.cos(0.90945359875 + 214.1928673153*t)
	Z0 += 0.00000001451*np.cos(3.59438611623 + 494.2662424425*t)
	Z0 += 0.00000001474*np.cos(4.97772142978 + 1699.2792165032*t)
	Z0 += 0.00000001388*np.cos(4.77847833406 + 2854.6403739102*t)
	Z0 += 0.00000001589*np.cos(5.43527416407 + 2538.2485042536*t)
	Z0 += 0.00000001390*np.cos(4.08155384651 + 894.8408795276*t)
	Z0 += 0.00000001435*np.cos(1.51395699369 + 867.4234757536*t)
	Z0 += 0.00000001404*np.cos(4.02343833901 + 300.6108669775*t)
	Z0 += 0.00000001359*np.cos(4.93938730479 + 2118.7638603784*t)
	Z0 += 0.00000001540*np.cos(2.97773040595 + 10213.285546211*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000000764*np.cos(5.13454347326 + 26087.9031415742*t)
	return Z0




def Saturn_Z1 (t): # 218 terms of order 1

	Z1 = 0.
	Z1 += 0.01905958940*np.cos(4.94544746619 + 213.299095438*t)
	Z1 -= 0.00528167867
	Z1 += 0.00130224990*np.cos(2.26141028606 + 206.1855484372*t)
	Z1 += 0.00101437388*np.cos(1.79095832223 + 220.4126424388*t)
	Z1 += 0.00085922590*np.cos(0.51612794233 + 426.598190876*t)
	Z1 += 0.00022253070*np.cos(3.07685453172 + 7.1135470008*t)
	Z1 += 0.00016174973*np.cos(1.19988846625 + 419.4846438752*t)
	Z1 += 0.00009114816*np.cos(6.17205939393 + 639.897286314*t)
	Z1 += 0.00007468572*np.cos(0.93135975352 + 433.7117378768*t)
	Z1 += 0.00004965110*np.cos(0.19046416304 + 316.3918696566*t)
	Z1 += 0.00003816033*np.cos(4.38281692683 + 110.2063212194*t)
	Z1 += 0.00002723345*np.cos(1.65580153042 + 227.5261894396*t)
	Z1 += 0.00001734454*np.cos(3.51648726804 + 103.0927742186*t)
	Z1 += 0.00001541549*np.cos(2.42323929864 + 199.0720014364*t)
	Z1 += 0.00001209044*np.cos(2.91141318291 + 14.2270940016*t)
	Z1 += 0.00000866749*np.cos(0.73823432275 + 632.7837393132*t)
	Z1 += 0.00000878790*np.cos(2.44338509079 + 217.2312487011*t)
	Z1 += 0.00000734163*np.cos(2.73478985417 + 210.1177017003*t)
	Z1 += 0.00000722571*np.cos(5.44723955466 + 853.196381752*t)
	Z1 += 0.00000651177*np.cos(1.48968855554 + 209.3669421749*t)
	Z1 += 0.00000582295*np.cos(0.11224949820 + 647.0108333148*t)
	Z1 += 0.00000657757*np.cos(1.31442181621 + 216.4804891757*t)
	Z1 += 0.00000510058*np.cos(1.75579271708 + 202.2533951741*t)
	Z1 += 0.00000467815*np.cos(2.04997674225 + 323.5054166574*t)
	Z1 += 0.00000449108*np.cos(2.82333930488 + 117.3198682202*t)
	Z1 += 0.00000309971*np.cos(2.20380300055 + 224.3447957019*t)
	Z1 += 0.00000226192*np.cos(0.85233380252 + 440.8252848776*t)
	Z1 += 0.00000213319*np.cos(4.88626822372 + 529.6909650946*t)
	Z1 += 0.00000177430*np.cos(0.67755587853 + 309.2783226558*t)
	Z1 += 0.00000214346*np.cos(4.69288132929 + 11.0457002639*t)
	Z1 += 0.00000142289*np.cos(1.34444047746 + 95.9792272178*t)
	Z1 += 0.00000121733*np.cos(1.54733882587 + 63.7358983034*t)
	Z1 += 0.00000117181*np.cos(0.50453513602 + 735.8765135318*t)
	Z1 += 0.00000115399*np.cos(4.72389777991 + 522.5774180938*t)
	Z1 += 0.00000126962*np.cos(1.40560397506 + 412.3710968744*t)
	Z1 += 0.00000118129*np.cos(4.62838752214 + 846.0828347512*t)
	Z1 += 0.00000068514*np.cos(0.39007157007 + 149.5631971346*t)
	Z1 += 0.00000067952*np.cos(4.60474899910 + 215.7467759928*t)
	Z1 += 0.00000078293*np.cos(3.26031102191 + 277.0349937414*t)
	Z1 += 0.00000058447*np.cos(2.70674418979 + 3.1813937377*t)
	Z1 += 0.00000057495*np.cos(4.15246081510 + 415.5524906121*t)
	Z1 += 0.00000056149*np.cos(4.11058404699 + 1162.4747044078*t)
	Z1 += 0.00000055408*np.cos(1.51354163855 + 234.6397364404*t)
	Z1 += 0.00000057884*np.cos(1.72832352555 + 330.6189636582*t)
	Z1 += 0.00000054118*np.cos(1.17844695765 + 536.8045120954*t)
	Z1 += 0.00000052089*np.cos(3.14726027446 + 74.7815985673*t)
	Z1 += 0.00000051032*np.cos(5.09783807355 + 3.9321532631*t)
	Z1 += 0.00000065605*np.cos(0.40831715964 + 422.6660376129*t)
	Z1 += 0.00000053852*np.cos(4.71773720484 + 1066.49547719*t)
	Z1 += 0.00000052398*np.cos(1.85751217072 + 423.4167971383*t)
	Z1 += 0.00000048311*np.cos(5.76774562578 + 210.8514148832*t)
	Z1 += 0.00000045825*np.cos(5.60012609774 + 860.3099287528*t)
	Z1 += 0.00000042528*np.cos(0.26574124089 + 1052.2683831884*t)
	Z1 += 0.00000051422*np.cos(3.03212480799 + 742.9900605326*t)
	Z1 += 0.00000044935*np.cos(0.51847195684 + 429.7795846137*t)
	Z1 += 0.00000033430*np.cos(2.45707742085 + 430.5303441391*t)
	Z1 += 0.00000033541*np.cos(2.76204651966 + 21.3406410024*t)
	Z1 += 0.00000030208*np.cos(4.43680762317 + 838.9692877504*t)
	Z1 += 0.00000037762*np.cos(5.50817907664 + 949.1756089698*t)
	Z1 += 0.00000033424*np.cos(1.74752373535 + 437.6438911399*t)
	Z1 += 0.00000034043*np.cos(1.19174438930 + 223.5940361765*t)
	Z1 += 0.00000027260*np.cos(2.19815364804 + 490.3340891794*t)
	Z1 += 0.00000029031*np.cos(4.98485313743 + 515.463871093*t)
	Z1 += 0.00000023381*np.cos(1.20660558774 + 88.865680217*t)
	Z1 += 0.00000024187*np.cos(1.56373114114 + 124.433415221*t)
	Z1 += 0.00000021789*np.cos(3.85669545186 + 1478.8665740644*t)
	Z1 += 0.00000020026*np.cos(2.90747764480 + 203.0041546995*t)
	Z1 += 0.00000019633*np.cos(0.06158742119 + 654.1243803156*t)
	Z1 += 0.00000018954*np.cos(5.59002140439 + 203.7378678824*t)
	Z1 += 0.00000017709*np.cos(1.87617250329 + 137.0330241624*t)
	Z1 += 0.00000017769*np.cos(0.01632384963 + 302.164775655*t)
	Z1 += 0.00000016148*np.cos(6.24824370719 + 1368.660252845*t)
	Z1 += 0.00000013816*np.cos(5.06584035631 + 625.6701923124*t)
	Z1 += 0.00000013533*np.cos(5.47658747033 + 217.964961884*t)
	Z1 += 0.00000013265*np.cos(3.80591212548 + 728.762966531*t)
	Z1 += 0.00000013270*np.cos(3.43877857351 + 351.8165923087*t)
	Z1 += 0.00000016625*np.cos(5.31689217526 + 1265.5674786264*t)
	Z1 += 0.00000016759*np.cos(0.35928972666 + 127.4717966068*t)
	Z1 += 0.00000016432*np.cos(5.56181596719 + 942.062061969*t)
	Z1 += 0.00000017168*np.cos(1.73825643839 + 138.5174968707*t)
	Z1 += 0.00000013738*np.cos(4.31097928238 + 1155.361157407*t)
	Z1 += 0.00000012548*np.cos(2.88960022005 + 231.4583427027*t)
	Z1 += 0.00000014146*np.cos(3.98643812146 + 195.1398481733*t)
	Z1 += 0.00000013973*np.cos(4.86218215819 + 208.633228992*t)
	Z1 += 0.00000010571*np.cos(2.45820467886 + 10.2949407385*t)
	Z1 += 0.00000011510*np.cos(4.63923085971 + 628.8515860501*t)
	Z1 += 0.00000013727*np.cos(0.66439765546 + 85.8272988312*t)
	Z1 += 0.00000010173*np.cos(3.58197312694 + 18.1592472647*t)
	Z1 += 0.00000009694*np.cos(0.86976616980 + 408.4389436113*t)
	Z1 += 0.00000010070*np.cos(0.02992656018 + 76.2660712756*t)
	Z1 += 0.00000009354*np.cos(1.32092608711 + 210.3783341312*t)
	Z1 += 0.00000010071*np.cos(1.48889940912 + 218.7157214094*t)
	Z1 += 0.00000011184*np.cos(6.02461705687 + 191.2076949102*t)
	Z1 += 0.00000008726*np.cos(5.30389752427 + 207.6700211455*t)
	Z1 += 0.00000009584*np.cos(2.47120940305 + 200.7689224658*t)
	Z1 += 0.00000009611*np.cos(2.41761563717 + 340.7708920448*t)
	Z1 += 0.00000008286*np.cos(4.32556970704 + 222.8603229936*t)
	Z1 += 0.00000008287*np.cos(3.58071495915 + 1795.258443721*t)
	Z1 += 0.00000009236*np.cos(3.03146091034 + 1059.3819301892*t)
	Z1 += 0.00000008038*np.cos(2.85526575273 + 191.9584544356*t)
	Z1 += 0.00000007775*np.cos(6.20277851494 + 362.8622925726*t)
	Z1 += 0.00000008724*np.cos(4.70273397649 + 831.8557407496*t)
	Z1 += 0.00000007487*np.cos(5.24393231687 + 214.2623032845*t)
	Z1 += 0.00000009808*np.cos(3.71994359218 + 350.3321196004*t)
	Z1 += 0.00000007520*np.cos(1.51238938306 + 212.3358875915*t)
	Z1 += 0.00000008313*np.cos(3.88563330807 + 38.1330356378*t)
	Z1 += 0.00000006967*np.cos(6.14764780396 + 265.9892934775*t)
	Z1 += 0.00000007930*np.cos(2.38845142534 + 207.8824694666*t)
	Z1 += 0.00000006526*np.cos(5.97355876891 + 1685.0521225016*t)
	Z1 += 0.00000006383*np.cos(0.76399546198 + 142.4496501338*t)
	Z1 += 0.00000008591*np.cos(4.23329326783 + 52.6901980395*t)
	Z1 += 0.00000007895*np.cos(5.28983476924 + 1258.4539316256*t)
	Z1 += 0.00000006270*np.cos(1.55039102252 + 56.6223513026*t)
	Z1 += 0.00000006596*np.cos(6.06955286464 + 618.5566453116*t)
	Z1 += 0.00000007305*np.cos(5.10230083831 + 1581.959348283*t)
	Z1 += 0.00000006510*np.cos(2.58766047235 + 160.6088973985*t)
	Z1 += 0.00000006396*np.cos(4.05175128194 + 1471.7530270636*t)
	Z1 += 0.00000006222*np.cos(1.83534241087 + 213.3472795478*t)
	Z1 += 0.00000005967*np.cos(6.10561287765 + 209.106309744*t)
	Z1 += 0.00000005430*np.cos(0.73930957950 + 447.9388318784*t)
	Z1 += 0.00000005422*np.cos(0.89394666012 + 22.0914005278*t)
	Z1 += 0.00000006010*np.cos(5.59380340709 + 483.2205421786*t)
	Z1 += 0.00000005756*np.cos(1.17220111999 + 70.8494453042*t)
	Z1 += 0.00000005508*np.cos(0.23756513534 + 750.1036075334*t)
	Z1 += 0.00000005736*np.cos(4.98124695327 + 218.9281697305*t)
	Z1 += 0.00000006223*np.cos(4.92073192158 + 213.2509113282*t)
	Z1 += 0.00000006028*np.cos(5.84835751560 + 635.9651330509*t)
	Z1 += 0.00000004583*np.cos(3.14247250829 + 1375.7737998458*t)
	Z1 += 0.00000005682*np.cos(1.25271749641 + 225.8292684102*t)
	Z1 += 0.00000004307*np.cos(4.70978533037 + 424.1505103212*t)
	Z1 += 0.00000005034*np.cos(0.89554065489 + 543.9180590962*t)
	Z1 += 0.00000005989*np.cos(2.68952514002 + 216.2198567448*t)
	Z1 += 0.00000005256*np.cos(0.01969964251 + 269.9214467406*t)
	Z1 += 0.00000004270*np.cos(3.35479531672 + 1045.1548361876*t)
	Z1 += 0.00000004124*np.cos(4.55060879049 + 235.3904959658*t)
	Z1 += 0.00000004323*np.cos(4.14790272459 + 1279.794572628*t)
	Z1 += 0.00000004166*np.cos(6.09766763608 + 1.4844727083*t)
	Z1 += 0.00000004069*np.cos(2.60100005478 + 554.0699874828*t)
	Z1 += 0.00000004878*np.cos(5.04922604658 + 1574.8458012822*t)
	Z1 += 0.00000003915*np.cos(2.97379506367 + 106.2741679563*t)
	Z1 += 0.00000003843*np.cos(4.98162442107 + 497.4476361802*t)
	Z1 += 0.00000003824*np.cos(3.45246107016 + 388.4651552382*t)
	Z1 += 0.00000004575*np.cos(6.20805088569 + 288.0806940053*t)
	Z1 += 0.00000004025*np.cos(3.79300651947 + 12.5301729722*t)
	Z1 += 0.00000003723*np.cos(4.85309927868 + 1073.6090241908*t)
	Z1 += 0.00000003610*np.cos(5.94058751363 + 934.9485149682*t)
	Z1 += 0.00000003663*np.cos(2.61919749562 + 113.3877149571*t)
	Z1 += 0.00000003915*np.cos(4.45024378168 + 1148.2476104062*t)
	Z1 += 0.00000003357*np.cos(4.43225060692 + 219.4494345923*t)
	Z1 += 0.00000003882*np.cos(3.74682686736 + 703.6331846174*t)
	Z1 += 0.00000003314*np.cos(3.41625676576 + 2111.6503133776*t)
	Z1 += 0.00000003270*np.cos(6.27410700801 + 212.7778305762*t)
	Z1 += 0.00000003141*np.cos(1.45568133680 + 650.9429865779*t)
	Z1 += 0.00000003103*np.cos(5.65046683605 + 2001.4439921582*t)
	Z1 += 0.00000003028*np.cos(3.42518715666 + 956.2891559706*t)
	Z1 += 0.00000003012*np.cos(4.45827269601 + 107.0249274817*t)
	Z1 += 0.00000003261*np.cos(0.48253112370 + 213.8203602998*t)
	Z1 += 0.00000003058*np.cos(4.77954182227 + 212.5483359126*t)
	Z1 += 0.00000003018*np.cos(4.95707802560 + 1898.3512179396*t)
	Z1 += 0.00000002951*np.cos(1.31088973653 + 344.7030453079*t)
	Z1 += 0.00000002877*np.cos(3.78456494258 + 1788.1448967202*t)
	Z1 += 0.00000003574*np.cos(6.01403213335 + 643.0786800517*t)
	Z1 += 0.00000002649*np.cos(4.08901068887 + 284.1485407422*t)
	Z1 += 0.00000003174*np.cos(1.19063213567 + 337.732510659*t)
	Z1 += 0.00000002623*np.cos(1.69713528262 + 636.7158925763*t)
	Z1 += 0.00000003581*np.cos(4.12344575096 + 9.5612275556*t)
	Z1 += 0.00000002743*np.cos(5.32978008284 + 565.1156877467*t)
	Z1 += 0.00000002507*np.cos(0.83753919585 + 436.8931316145*t)
	Z1 += 0.00000002398*np.cos(2.60430644776 + 404.5067903482*t)
	Z1 += 0.00000002917*np.cos(0.89207515266 + 417.0369633204*t)
	Z1 += 0.00000002972*np.cos(4.71447928798 + 1891.2376709388*t)
	Z1 += 0.00000002623*np.cos(0.01647605955 + 207.1487562837*t)
	Z1 += 0.00000002187*np.cos(0.95383665392 + 114.3991069134*t)
	Z1 += 0.00000002936*np.cos(3.84290338749 + 217.491881132*t)
	Z1 += 0.00000002409*np.cos(3.56267761888 + 1169.5882514086*t)
	Z1 += 0.00000002157*np.cos(3.02442510484 + 1692.1656695024*t)
	Z1 += 0.00000002262*np.cos(4.25820830689 + 98.8999885246*t)
	Z1 += 0.00000002141*np.cos(1.82853778649 + 479.2883889155*t)
	Z1 += 0.00000002564*np.cos(0.84277674835 + 358.9301393095*t)
	Z1 += 0.00000002209*np.cos(4.80292631309 + 2214.7430875962*t)
	Z1 += 0.00000002136*np.cos(2.96715839944 + 1361.5467058442*t)
	Z1 += 0.00000002069*np.cos(5.15304621208 + 220.4608265486*t)
	Z1 += 0.00000002140*np.cos(5.38666672806 + 175.1660598002*t)
	Z1 += 0.00000002003*np.cos(2.47564274875 + 416.3032501375*t)
	Z1 += 0.00000002085*np.cos(4.09277149039 + 1272.6810256272*t)
	Z1 += 0.00000002088*np.cos(5.05465836254 + 251.4321310758*t)
	Z1 += 0.00000002082*np.cos(4.63603111699 + 121.2520214833*t)
	Z1 += 0.00000001861*np.cos(4.45402970588 + 508.3503240922*t)
	Z1 += 0.00000002005*np.cos(4.66254689609 + 429.0458714308*t)
	Z1 += 0.00000002045*np.cos(3.73820015775 + 114.1384744825*t)
	Z1 += 0.00000002093*np.cos(0.87904326630 + 4.665866446*t)
	Z1 += 0.00000002056*np.cos(2.39618093351 + 2435.155730035*t)
	Z1 += 0.00000002022*np.cos(5.80214824265 + 181.0557665236*t)
	Z1 += 0.00000001881*np.cos(1.13062277248 + 757.2171545342*t)
	Z1 += 0.00000001707*np.cos(1.57935987501 + 6069.7767545534*t)
	Z1 += 0.00000001746*np.cos(3.06455575770 + 2008.557539159*t)
	Z1 += 0.00000001795*np.cos(2.95316519456 + 1781.0313497194*t)
	Z1 += 0.00000001786*np.cos(5.44879791643 + 245.5424243524*t)
	Z1 += 0.00000001642*np.cos(1.87652377033 + 177.8743727859*t)
	Z1 += 0.00000001614*np.cos(5.96461527769 + 867.4234757536*t)
	Z1 += 0.00000001623*np.cos(0.63294345223 + 621.7380390493*t)
	Z1 += 0.00000001553*np.cos(1.32350368373 + 131.5469622218*t)
	Z1 += 0.00000001599*np.cos(0.86145918975 + 81.7521332162*t)
	Z1 += 0.00000001513*np.cos(3.01415732754 + 2428.0421830342*t)
	Z1 += 0.00000001939*np.cos(2.25124681713 + 1677.9385755008*t)
	Z1 += 0.00000001827*np.cos(5.04434694439 + 842.1506814881*t)
	Z1 += 0.00000001748*np.cos(5.85086226218 + 173.9422195228*t)
	Z1 += 0.00000001652*np.cos(2.76139225258 + 643.8294395771*t)
	Z1 += 0.00000001511*np.cos(3.22650702148 + 99.1606209555*t)
	Z1 += 0.00000001714*np.cos(4.99601182685 + 2317.8358618148*t)
	Z1 += 0.00000001990*np.cos(2.08785550062 + 2420.9286360334*t)
	Z1 += 0.00000001664*np.cos(0.14097949424 + 151.0476698429*t)
	Z1 += 0.00000001480*np.cos(2.89230197932 + 355.7487455718*t)
	Z1 += 0.00000001425*np.cos(3.02679993106 + 248.7238180901*t)
	Z1 += 0.00000001384*np.cos(2.33959628851 + 444.7574381407*t)
	Z1 += 0.00000001458*np.cos(5.37055128984 + 148.0787244263*t)
	Z1 += 0.00000001464*np.cos(6.11985601662 + 206.1373643274*t)
	Z1 += 0.00000001173*np.cos(0.00063234885 + 1589.0728952838*t)
	return Z1*t




def Saturn_Z2 (t): # 87 terms of order 2

	Z2 = 0.
	Z2 += 0.00131237677*np.cos(0.08868998014 + 213.299095438*t)
	Z2 += 0.00030139033*np.cos(3.91396211806 + 206.1855484372*t)
	Z2 += 0.00019316662*np.cos(0.09228751610 + 220.4126424388*t)
	Z2 += 0.00006866944*np.cos(5.48420260868 + 426.598190876*t)
	Z2 += 0.00002825589*np.cos(1.36584703698 + 7.1135470008*t)
	Z2 += 0.00002645589*np.cos(2.94607374034 + 419.4846438752*t)
	Z2 += 0.00003136555
	Z2 += 0.00001844271*np.cos(5.43612384912 + 433.7117378768*t)
	Z2 += 0.00001055082*np.cos(6.23890821882 + 227.5261894396*t)
	Z2 += 0.00001036141*np.cos(4.33916742809 + 639.897286314*t)
	Z2 += 0.00000634427*np.cos(4.10414101922 + 199.0720014364*t)
	Z2 += 0.00000492977*np.cos(1.74516307253 + 316.3918696566*t)
	Z2 += 0.00000384993*np.cos(1.22066829531 + 14.2270940016*t)
	Z2 += 0.00000239476*np.cos(4.47935921474 + 210.1177017003*t)
	Z2 += 0.00000205194*np.cos(1.76728126877 + 110.2063212194*t)
	Z2 += 0.00000176308*np.cos(4.56317761920 + 647.0108333148*t)
	Z2 += 0.00000150033*np.cos(4.33649711181 + 103.0927742186*t)
	Z2 += 0.00000148023*np.cos(4.28188112046 + 217.2312487011*t)
	Z2 += 0.00000184735*np.cos(5.81729679119 + 216.4804891757*t)
	Z2 += 0.00000128877*np.cos(2.62827363828 + 632.7837393132*t)
	Z2 += 0.00000100020*np.cos(5.38535854003 + 440.8252848776*t)
	Z2 += 0.00000092666*np.cos(1.20622589441 + 117.3198682202*t)
	Z2 += 0.00000121332*np.cos(3.47780478719 + 853.196381752*t)
	Z2 += 0.00000086968*np.cos(5.92619695759 + 209.3669421749*t)
	Z2 += 0.00000056696*np.cos(0.46733705639 + 323.5054166574*t)
	Z2 += 0.00000051546*np.cos(3.14926659859 + 202.2533951741*t)
	Z2 += 0.00000054658*np.cos(3.01021120875 + 412.3710968744*t)
	Z2 += 0.00000032218*np.cos(6.09457934158 + 234.6397364404*t)
	Z2 += 0.00000032681*np.cos(3.01893080236 + 309.2783226558*t)
	Z2 += 0.00000027740*np.cos(3.18735286796 + 95.9792272178*t)
	Z2 += 0.00000024497*np.cos(1.49246807159 + 529.6909650946*t)
	Z2 += 0.00000019282*np.cos(0.27555296168 + 224.3447957019*t)
	Z2 += 0.00000017381*np.cos(1.07924221725 + 21.3406410024*t)
	Z2 += 0.00000016304*np.cos(3.71897508099 + 860.3099287528*t)
	Z2 += 0.00000013436*np.cos(3.73879936403 + 423.4167971383*t)
	Z2 += 0.00000015102*np.cos(0.02346987379 + 330.6189636582*t)
	Z2 += 0.00000013774*np.cos(0.25334550410 + 3.9321532631*t)
	Z2 += 0.00000015896*np.cos(5.68181987799 + 223.5940361765*t)
	Z2 += 0.00000015147*np.cos(4.93843585740 + 429.7795846137*t)
	Z2 += 0.00000012461*np.cos(0.13116820715 + 522.5774180938*t)
	Z2 += 0.00000012327*np.cos(4.80179468989 + 422.6660376129*t)
	Z2 += 0.00000010457*np.cos(0.89680214250 + 3.1813937377*t)
	Z2 += 0.00000010434*np.cos(4.69863675329 + 203.0041546995*t)
	Z2 += 0.00000010092*np.cos(6.08646339762 + 124.433415221*t)
	Z2 += 0.00000012269*np.cos(2.71630374130 + 1066.49547719*t)
	Z2 += 0.00000009316*np.cos(2.92660214659 + 88.865680217*t)
	Z2 += 0.00000011165*np.cos(4.47469129108 + 11.0457002639*t)
	Z2 += 0.00000009675*np.cos(4.54865123798 + 654.1243803156*t)
	Z2 += 0.00000008155*np.cos(6.19382665540 + 415.5524906121*t)
	Z2 += 0.00000009179*np.cos(1.56314990824 + 742.9900605326*t)
	Z2 += 0.00000007320*np.cos(5.80446120079 + 536.8045120954*t)
	Z2 += 0.00000009366*np.cos(4.88722886988 + 277.0349937414*t)
	Z2 += 0.00000006493*np.cos(4.43377180184 + 191.9584544356*t)
	Z2 += 0.00000005970*np.cos(6.13227111688 + 63.7358983034*t)
	Z2 += 0.00000005743*np.cos(5.48648092848 + 149.5631971346*t)
	Z2 += 0.00000006020*np.cos(5.88359837552 + 735.8765135318*t)
	Z2 += 0.00000006285*np.cos(0.34693933458 + 515.463871093*t)
	Z2 += 0.00000006935*np.cos(0.77796862892 + 949.1756089698*t)
	Z2 += 0.00000005259*np.cos(4.46395984779 + 430.5303441391*t)
	Z2 += 0.00000004112*np.cos(5.13362859612 + 625.6701923124*t)
	Z2 += 0.00000003945*np.cos(4.84154619020 + 74.7815985673*t)
	Z2 += 0.00000003942*np.cos(0.63354697459 + 10.2949407385*t)
	Z2 += 0.00000003875*np.cos(5.91484244505 + 437.6438911399*t)
	Z2 += 0.00000003734*np.cos(6.15283978599 + 838.9692877504*t)
	Z2 += 0.00000003458*np.cos(5.48363967638 + 728.762966531*t)
	Z2 += 0.00000003345*np.cos(5.97838746664 + 215.7467759928*t)
	Z2 += 0.00000003588*np.cos(1.04087840499 + 942.062061969*t)
	Z2 += 0.00000003589*np.cos(5.28302198799 + 447.9388318784*t)
	Z2 += 0.00000003269*np.cos(1.73432278238 + 1059.3819301892*t)
	Z2 += 0.00000002981*np.cos(1.38021533477 + 231.4583427027*t)
	Z2 += 0.00000002856*np.cos(1.86665866713 + 302.164775655*t)
	Z2 += 0.00000002269*np.cos(2.10089264689 + 18.1592472647*t)
	Z2 += 0.00000002766*np.cos(0.40134293559 + 846.0828347512*t)
	Z2 += 0.00000002088*np.cos(1.82541193746 + 1471.7530270636*t)
	Z2 += 0.00000001990*np.cos(0.79685389889 + 210.8514148832*t)
	Z2 += 0.00000002040*np.cos(5.80760536835 + 1162.4747044078*t)
	Z2 += 0.00000001934*np.cos(0.04319189448 + 195.1398481733*t)
	Z2 += 0.00000001949*np.cos(0.83703762066 + 1265.5674786264*t)
	Z2 += 0.00000002107*np.cos(0.59861697225 + 1258.4539316256*t)
	Z2 += 0.00000001868*np.cos(0.23989474559 + 1898.3512179396*t)
	Z2 += 0.00000001840*np.cos(3.14880532464 + 408.4389436113*t)
	Z2 += 0.00000001589*np.cos(3.33563676583 + 1073.6090241908*t)
	Z2 += 0.00000001824*np.cos(0.08294127784 + 831.8557407496*t)
	Z2 += 0.00000001751*np.cos(1.22063055823 + 203.7378678824*t)
	Z2 += 0.00000001874*np.cos(0.84722174143 + 1375.7737998458*t)
	Z2 += 0.00000001596*np.cos(0.64727508404 + 618.5566453116*t)
	Z2 += 0.00000001504*np.cos(2.13190551837 + 1368.660252845*t)
	return Z2*t*t




def Saturn_Z3 (t): # 45 terms of order 3

	Z3 = 0.
	Z3 += 0.00004558118*np.cos(1.70646871501 + 213.299095438*t)
	Z3 += 0.00004777710*np.cos(5.57723756330 + 206.1855484372*t)
	Z3 += 0.00003964164
	Z3 += 0.00002507526*np.cos(4.64959056313 + 220.4126424388*t)
	Z3 += 0.00000314334*np.cos(3.65978364894 + 433.7117378768*t)
	Z3 += 0.00000276132*np.cos(4.53051550901 + 227.5261894396*t)
	Z3 += 0.00000322702*np.cos(4.70757024216 + 419.4846438752*t)
	Z3 += 0.00000327628*np.cos(3.31597275465 + 426.598190876*t)
	Z3 += 0.00000243745*np.cos(5.87706678179 + 7.1135470008*t)
	Z3 += 0.00000174957*np.cos(5.78592635050 + 199.0720014364*t)
	Z3 += 0.00000083895*np.cos(5.79905591107 + 14.2270940016*t)
	Z3 += 0.00000093820*np.cos(2.49637955720 + 639.897286314*t)
	Z3 += 0.00000044020*np.cos(6.21480013484 + 210.1177017003*t)
	Z3 += 0.00000036917*np.cos(3.20726820162 + 316.3918696566*t)
	Z3 += 0.00000037045*np.cos(2.74532673184 + 647.0108333148*t)
	Z3 += 0.00000029901*np.cos(3.63700944423 + 440.8252848776*t)
	Z3 += 0.00000027316*np.cos(4.02192055477 + 216.4804891757*t)
	Z3 += 0.00000021812*np.cos(0.29602454753 + 103.0927742186*t)
	Z3 += 0.00000015029*np.cos(1.61287308719 + 853.196381752*t)
	Z3 += 0.00000013278*np.cos(5.83332386279 + 117.3198682202*t)
	Z3 += 0.00000014206*np.cos(4.66959349596 + 412.3710968744*t)
	Z3 += 0.00000012017*np.cos(5.87019158782 + 217.2312487011*t)
	Z3 += 0.00000012913*np.cos(4.42190026971 + 632.7837393132*t)
	Z3 += 0.00000012456*np.cos(4.39130353720 + 234.6397364404*t)
	Z3 += 0.00000012442*np.cos(0.62890480503 + 110.2063212194*t)
	Z3 += 0.00000005815*np.cos(5.62033243896 + 21.3406410024*t)
	Z3 += 0.00000005017*np.cos(5.53227381289 + 309.2783226558*t)
	Z3 += 0.00000004570*np.cos(4.93624436902 + 323.5054166574*t)
	Z3 += 0.00000004550*np.cos(5.34216832770 + 202.2533951741*t)
	Z3 += 0.00000004167*np.cos(3.89464734960 + 223.5940361765*t)
	Z3 += 0.00000003453*np.cos(6.08609637145 + 191.9584544356*t)
	Z3 += 0.00000004233*np.cos(5.05443804202 + 95.9792272178*t)
	Z3 += 0.00000003981*np.cos(1.84663176062 + 860.3099287528*t)
	Z3 += 0.00000002864*np.cos(4.29206444885 + 124.433415221*t)
	Z3 += 0.00000002996*np.cos(3.08351604262 + 429.7795846137*t)
	Z3 += 0.00000002719*np.cos(4.65594179175 + 209.3669421749*t)
	Z3 += 0.00000003210*np.cos(2.76409200956 + 654.1243803156*t)
	Z3 += 0.00000002781*np.cos(4.63436661235 + 330.6189636582*t)
	Z3 += 0.00000002337*np.cos(4.61669572366 + 88.865680217*t)
	Z3 += 0.00000002134*np.cos(1.37581224457 + 1066.49547719*t)
	Z3 += 0.00000002287*np.cos(0.70623098744 + 203.0041546995*t)
	Z3 += 0.00000001693*np.cos(4.70902661652 + 224.3447957019*t)
	Z3 += 0.00000001460*np.cos(5.32768614058 + 302.164775655*t)
	Z3 += 0.00000001460*np.cos(3.94562330747 + 447.9388318784*t)
	Z3 += 0.00000000920*np.cos(1.65069146673 + 529.6909650946*t)
	return Z3*t*t*t




def Saturn_Z4 (t): # 19 terms of order 4

	Z4 = 0.
	Z4 += 0.00000574306*np.cos(0.96387396086 + 206.1855484372*t)
	Z4 += 0.00000252516*np.cos(2.90188946355 + 220.4126424388*t)
	Z4 += 0.00000244875*np.cos(2.96492296609 + 213.299095438*t)
	Z4 += 0.00000054532*np.cos(2.81565014397 + 227.5261894396*t)
	Z4 += 0.00000038219*np.cos(1.18981630114 + 199.0720014364*t)
	Z4 += 0.00000040987*np.cos(1.88329932395 + 433.7117378768*t)
	Z4 -= 0.00000036668
	Z4 += 0.00000029532*np.cos(0.21869783244 + 419.4846438752*t)
	Z4 += 0.00000015829*np.cos(4.08518202922 + 7.1135470008*t)
	Z4 += 0.00000013086*np.cos(4.09506233764 + 14.2270940016*t)
	Z4 += 0.00000016648*np.cos(1.68086126796 + 426.598190876*t)
	Z4 += 0.00000006459*np.cos(0.62293627131 + 639.897286314*t)
	Z4 += 0.00000006486*np.cos(1.89121948225 + 440.8252848776*t)
	Z4 += 0.00000006027*np.cos(0.93640230433 + 647.0108333148*t)
	Z4 += 0.00000003053*np.cos(2.66311279154 + 234.6397364404*t)
	Z4 += 0.00000001780*np.cos(4.77855998924 + 117.3198682202*t)
	Z4 += 0.00000002105*np.cos(0.46469400267 + 853.196381752*t)
	Z4 += 0.00000001586*np.cos(5.79955908864 + 110.2063212194*t)
	Z4 += 0.00000001592*np.cos(0.49445731602 + 412.3710968744*t)
	return Z4*t*t*t*t




def Saturn_Z5 (t): # 6 terms of order 5

	Z5 = 0.
	Z5 += 0.00000053400*np.cos(2.61403861391 + 206.1855484372*t)
	Z5 += 0.00000018015*np.cos(1.15819542312 + 220.4126424388*t)
	Z5 -= 0.00000010802
	Z5 += 0.00000007783*np.cos(1.07953666846 + 227.5261894396*t)
	Z5 += 0.00000006016*np.cos(2.88267666200 + 199.0720014364*t)
	Z5 += 0.00000004424*np.cos(0.11691197681 + 433.7117378768*t)
	return Z5*t*t*t*t*t





def Uranus_X0 (t): # 1432 terms of order 0

	X0 = 0.
	X0 += 19.17286937362*np.cos(5.48133416758 + 74.7815985673*t)
	X0 += 1.32301898121
	X0 += 0.44400556159*np.cos(1.65967535182 + 149.5631971346*t)
	X0 += 0.14667584671*np.cos(3.42395875589 + 73.297125859*t)
	X0 += 0.14129215712*np.cos(4.39576776954 + 76.2660712756*t)
	X0 += 0.06200970387*np.cos(5.14043568284 + 1.4844727083*t)
	X0 += 0.01542890129*np.cos(4.12122840701 + 224.3447957019*t)
	X0 += 0.01444153470*np.cos(2.65117108186 + 148.0787244263*t)
	X0 += 0.00944969862*np.cos(1.65871112189 + 11.0457002639*t)
	X0 += 0.00657496073*np.cos(0.57595186181 + 151.0476698429*t)
	X0 += 0.00621603101*np.cos(3.05881560775 + 77.7505439839*t)
	X0 += 0.00585159800*np.cos(4.79934731599 + 71.8126531507*t)
	X0 += 0.00633971831*np.cos(4.09554584740 + 63.7358983034*t)
	X0 += 0.00547675794*np.cos(3.63127816021 + 85.8272988312*t)
	X0 += 0.00458242260*np.cos(3.90788427382 + 2.9689454166*t)
	X0 += 0.00383608186*np.cos(6.18762167352 + 138.5174968707*t)
	X0 += 0.00145499145*np.cos(2.31759819136 + 70.8494453042*t)
	X0 += 0.00135334157*np.cos(5.51062460646 + 78.7137518304*t)
	X0 += 0.00120354886*np.cos(4.10218670070 + 39.6175083461*t)
	X0 += 0.00125099578*np.cos(2.51455157066 + 111.4301614968*t)
	X0 += 0.00111255099*np.cos(5.12253353573 + 222.8603229936*t)
	X0 += 0.00104615229*np.cos(3.90538915195 + 146.594251718*t)
	X0 += 0.00110162872*np.cos(4.45478121996 + 35.1640902212*t)
	X0 += 0.00063581767*np.cos(0.29966264689 + 299.1263942692*t)
	X0 += 0.00053904041*np.cos(3.92590422507 + 3.9321532631*t)
	X0 += 0.00065063923*np.cos(3.73008432701 + 109.9456887885*t)
	X0 += 0.00059935440*np.cos(5.30012287089 + 38.1330356378*t)
	X0 += 0.00039183521*np.cos(2.68841323459 + 4.4534181249*t)
	X0 += 0.00034340286*np.cos(3.03782445102 + 225.8292684102*t)
	X0 += 0.00033133106*np.cos(2.54202102521 + 65.2203710117*t)
	X0 += 0.00034554296*np.cos(1.84698778371 + 79.2350166922*t)
	X0 += 0.00033865960*np.cos(5.98418361600 + 70.3281804424*t)
	X0 += 0.00028371102*np.cos(2.58026061716 + 127.4717966068*t)
	X0 += 0.00035938423*np.cos(4.08805817528 + 202.2533951741*t)
	X0 += 0.00025208291*np.cos(5.30270440656 + 9.5612275556*t)
	X0 += 0.00023466780*np.cos(4.09729826283 + 145.6310438715*t)
	X0 += 0.00022962960*np.cos(5.51475242270 + 84.3428261229*t)
	X0 += 0.00031822530*np.cos(5.53948530245 + 152.5321425512*t)
	X0 += 0.00025767220*np.cos(2.64279937947 + 213.299095438*t)
	X0 += 0.00028383708*np.cos(6.01785438397 + 184.7272873558*t)
	X0 += 0.00026656250*np.cos(6.11027934265 + 160.6088973985*t)
	X0 += 0.00019675903*np.cos(5.53431398332 + 74.6697239827*t)
	X0 += 0.00019653015*np.cos(2.28660913421 + 74.8934731519*t)
	X0 += 0.00019953738*np.cos(0.57452653801 + 12.5301729722*t)
	X0 += 0.00018565067*np.cos(0.62225019017 + 52.6901980395*t)
	X0 += 0.00020084107*np.cos(4.47297514058 + 22.0914005278*t)
	X0 += 0.00019925827*np.cos(1.39875506889 + 112.9146342051*t)
	X0 += 0.00018577959*np.cos(5.70218580551 + 33.6796175129*t)
	X0 += 0.00016587870*np.cos(4.86920309163 + 108.4612160802*t)
	X0 += 0.00015199755*np.cos(2.88408510221 + 41.1019810544*t)
	X0 += 0.00011245310*np.cos(6.11597014635 + 71.6002048296*t)
	X0 += 0.00013947849*np.cos(6.27545944070 + 221.3758502853*t)
	X0 += 0.00010797879*np.cos(1.70031895074 + 77.962992305*t)
	X0 += 0.00013593381*np.cos(2.55407931798 + 87.3117715395*t)
	X0 += 0.00012884351*np.cos(5.08737999470 + 145.1097790097*t)
	X0 += 0.00012394786*np.cos(6.21892878850 + 72.3339180125*t)
	X0 += 0.00011538642*np.cos(1.77241794539 + 77.2292791221*t)
	X0 += 0.00011442510*np.cos(0.20030247485 + 36.6485629295*t)
	X0 += 0.00008738409*np.cos(4.96956808452 + 186.2117600641*t)
	X0 += 0.00007095608*np.cos(1.30384750044 + 297.6419215609*t)
	X0 += 0.00006262602*np.cos(1.71385983783 + 153.4953503977*t)
	X0 += 0.00007798974*np.cos(5.82410372587 + 340.7708920448*t)
	X0 += 0.00006669249*np.cos(5.08626589612 + 62.2514255951*t)
	X0 += 0.00005505358*np.cos(3.31282108025 + 140.001969579*t)
	X0 += 0.00005372927*np.cos(4.12498282863 + 75.3028634291*t)
	X0 += 0.00005354242*np.cos(3.69263973447 + 74.2603337055*t)
	X0 += 0.00004478123*np.cos(1.11838191479 + 66.70484372*t)
	X0 += 0.00004233075*np.cos(3.94913608184 + 265.9892934775*t)
	X0 += 0.00005038353*np.cos(4.68664376918 + 18.1592472647*t)
	X0 += 0.00004570470*np.cos(0.97536665751 + 183.2428146475*t)
	X0 += 0.00004751325*np.cos(4.95762395337 + 73.8183907208*t)
	X0 += 0.00004447622*np.cos(0.29332757659 + 114.3991069134*t)
	X0 += 0.00003312340*np.cos(0.52418923788 + 82.8583534146*t)
	X0 += 0.00004515952*np.cos(2.88576303120 + 75.7448064138*t)
	X0 += 0.00003383674*np.cos(5.12516331582 + 7.1135470008*t)
	X0 += 0.00003559276*np.cos(1.47627607503 + 5.9378908332*t)
	X0 += 0.00003577938*np.cos(1.11558436434 + 137.0330241624*t)
	X0 += 0.00002882392*np.cos(2.76136583899 + 373.9079928365*t)
	X0 += 0.00002576509*np.cos(3.84663423210 + 277.0349937414*t)
	X0 += 0.00002597765*np.cos(0.22409539936 + 96.8729990951*t)
	X0 += 0.00002560744*np.cos(4.44236223450 + 80.1982245387*t)
	X0 += 0.00002722745*np.cos(6.09456175016 + 106.9767433719*t)
	X0 += 0.00002528025*np.cos(0.89508396542 + 68.8437077341*t)
	X0 += 0.00002631138*np.cos(0.04831552531 + 305.3461693927*t)
	X0 += 0.00002541716*np.cos(0.64495056482 + 32.1951448046*t)
	X0 += 0.00002241129*np.cos(5.22377697501 + 3.1813937377*t)
	X0 += 0.00001965145*np.cos(0.09207526632 + 20.6069278195*t)
	X0 += 0.00002232022*np.cos(0.63571664756 + 80.7194894005*t)
	X0 += 0.00001933814*np.cos(5.75490033864 + 74.7334144575*t)
	X0 += 0.00001933817*np.cos(2.06557585395 + 74.8297826771*t)
	X0 += 0.00002138391*np.cos(4.20897429922 + 74.5209661364*t)
	X0 += 0.00002126427*np.cos(3.61171465436 + 75.0422309982*t)
	X0 += 0.00002215516*np.cos(2.18613112875 + 259.5088859231*t)
	X0 += 0.00001891213*np.cos(5.49941424248 + 300.6108669775*t)
	X0 += 0.00001927679*np.cos(1.29228021932 + 159.1244246902*t)
	X0 += 0.00001796558*np.cos(5.73271543335 + 74.6215398729*t)
	X0 += 0.00001792522*np.cos(2.08789166984 + 74.9416572617*t)
	X0 += 0.00002182901*np.cos(1.23755478345 + 479.2883889155*t)
	X0 += 0.00001862003*np.cos(1.67534522569 + 42.5864537627*t)
	X0 += 0.00002075591*np.cos(3.15586933464 + 131.4039498699*t)
	X0 += 0.00001912582*np.cos(5.83091918696 + 14.977853527*t)
	X0 += 0.00001529180*np.cos(2.05204104820 + 191.2076949102*t)
	X0 += 0.00001495017*np.cos(0.22268077239 + 220.4126424388*t)
	X0 += 0.00002064173*np.cos(3.60208606410 + 835.0371344873*t)
	X0 += 0.00001768763*np.cos(1.19254481620 + 219.891377577*t)
	X0 += 0.00001892359*np.cos(4.32128621847 + 154.0166152595*t)
	X0 += 0.00001797047*np.cos(1.73417465594 + 227.3137411185*t)
	X0 += 0.00001558489*np.cos(6.16891070489 + 59.8037450403*t)
	X0 += 0.00001672893*np.cos(0.01232646186 + 143.6253063014*t)
	X0 += 0.00001467268*np.cos(2.10975578758 + 2.4476805548*t)
	X0 += 0.00001677659*np.cos(0.42525121334 + 8.0767548473*t)
	X0 += 0.00001346494*np.cos(5.46766563529 + 288.0806940053*t)
	X0 += 0.00001744555*np.cos(0.82022450313 + 56.6223513026*t)
	X0 += 0.00001427180*np.cos(0.38786175669 + 92.940845832*t)
	X0 += 0.00001263032*np.cos(5.63689596853 + 404.5067903482*t)
	X0 += 0.00001221506*np.cos(5.20012455894 + 54.1746707478*t)
	X0 += 0.00001574905*np.cos(5.72297800263 + 39.3568759152*t)
	X0 += 0.00001269686*np.cos(2.66330104031 + 142.4496501338*t)
	X0 += 0.00001418300*np.cos(2.29718712012 + 235.3904959658*t)
	X0 += 0.00001040948*np.cos(2.74644165501 + 5.4166259714*t)
	X0 += 0.00001256867*np.cos(5.61684736425 + 67.6680515665*t)
	X0 += 0.00001164218*np.cos(2.08302637541 + 81.8951455681*t)
	X0 += 0.00001009252*np.cos(2.02320517037 + 74.0308390419*t)
	X0 += 0.00001077810*np.cos(1.05685900920 + 128.9562693151*t)
	X0 += 0.00000995392*np.cos(5.79703441041 + 75.5323580927*t)
	X0 += 0.00001212025*np.cos(3.41577832660 + 211.8146227297*t)
	X0 += 0.00001223648*np.cos(3.84373514640 + 187.6962327724*t)
	X0 += 0.00001335202*np.cos(2.17623376867 + 380.12776796*t)
	X0 += 0.00001144565*np.cos(2.42148845239 + 296.1574488526*t)
	X0 += 0.00001241589*np.cos(1.81282962357 + 134.5853436076*t)
	X0 += 0.00001192274*np.cos(5.58661990233 + 50.4025761791*t)
	X0 += 0.00001093678*np.cos(3.94451812233 + 230.5645708254*t)
	X0 += 0.00000866728*np.cos(3.65638980673 + 125.9873238985*t)
	X0 += 0.00000858603*np.cos(6.06095240605 + 68.1893164283*t)
	X0 += 0.00000913477*np.cos(1.69392733805 + 149.45132255*t)
	X0 += 0.00001077916*np.cos(5.01417740021 + 181.7583419392*t)
	X0 += 0.00000858335*np.cos(1.50454807667 + 89.7594520943*t)
	X0 += 0.00001056848*np.cos(5.53440854164 + 14.0146456805*t)
	X0 += 0.00000964091*np.cos(2.66151436132 + 35.4247226521*t)
	X0 += 0.00000909790*np.cos(4.72919543782 + 149.6750717192*t)
	X0 += 0.00000987528*np.cos(6.20191485915 + 203.7378678824*t)
	X0 += 0.00000704557*np.cos(1.78667248384 + 81.3738807063*t)
	X0 += 0.00000727979*np.cos(1.68450966248 + 51.2057253312*t)
	X0 += 0.00000895034*np.cos(3.38678219821 + 23.5758732361*t)
	X0 += 0.00000898270*np.cos(2.10244301916 + 110.2063212194*t)
	X0 += 0.00000862050*np.cos(5.03077008764 + 162.0933701068*t)
	X0 += 0.00000870204*np.cos(5.37263296164 + 81.0013736908*t)
	X0 += 0.00000811437*np.cos(5.17638099206 + 200.7689224658*t)
	X0 += 0.00000598538*np.cos(5.04735819055 + 24.3790223882*t)
	X0 += 0.00000766812*np.cos(2.46431370490 + 68.5618234438*t)
	X0 += 0.00000620509*np.cos(3.32340073105 + 69.3649725959*t)
	X0 += 0.00000743561*np.cos(1.22664998599 + 760.25553592*t)
	X0 += 0.00000643798*np.cos(1.27173146057 + 88.7962442478*t)
	X0 += 0.00000696351*np.cos(0.45928521046 + 116.4260963429*t)
	X0 += 0.00000528197*np.cos(2.28043920518 + 146.3818033969*t)
	X0 += 0.00000699542*np.cos(2.93566905569 + 617.8058857862*t)
	X0 += 0.00000674539*np.cos(3.06005508910 + 6.2197751235*t)
	X0 += 0.00000587451*np.cos(3.90803174254 + 152.0108776894*t)
	X0 += 0.00000578643*np.cos(2.55597699269 + 28.5718080822*t)
	X0 += 0.00000504865*np.cos(2.53585718344 + 157.6399519819*t)
	X0 += 0.00000551887*np.cos(1.14420383033 + 260.9933586314*t)
	X0 += 0.00000476019*np.cos(4.06685999780 + 415.5524906121*t)
	X0 += 0.00000580796*np.cos(6.18692743051 + 258.0244132148*t)
	X0 += 0.00000597694*np.cos(5.21701637296 + 218.4069048687*t)
	X0 += 0.00000527668*np.cos(2.29752010941 + 351.8165923087*t)
	X0 += 0.00000445140*np.cos(5.84184650462 + 120.358249606*t)
	X0 += 0.00000442835*np.cos(3.75400855881 + 329.7251917809*t)
	X0 += 0.00000449040*np.cos(1.03508146650 + 543.0242872189*t)
	X0 += 0.00000484827*np.cos(0.33092998607 + 73.4090004436*t)
	X0 += 0.00000444042*np.cos(4.74854436122 + 41.6444977756*t)
	X0 += 0.00000542001*np.cos(1.04883718038 + 195.1398481733*t)
	X0 += 0.00000435208*np.cos(3.76518154062 + 372.4235201282*t)
	X0 += 0.00000419163*np.cos(1.97405677459 + 95.3885263868*t)
	X0 += 0.00000514155*np.cos(5.40820017990 + 115.8835796217*t)
	X0 += 0.00000387375*np.cos(5.96869839758 + 152.7445908723*t)
	X0 += 0.00000408499*np.cos(3.42756156092 + 0.9632078465*t)
	X0 += 0.00000453506*np.cos(4.10881151991 + 209.3669421749*t)
	X0 += 0.00000374730*np.cos(5.67831880744 + 144.1465711632*t)
	X0 += 0.00000384413*np.cos(5.21546597177 + 114.1384744825*t)
	X0 += 0.00000427408*np.cos(2.47035624732 + 141.4864422873*t)
	X0 += 0.00000371413*np.cos(3.47157274946 + 73.1852512744*t)
	X0 += 0.00000371243*np.cos(1.03748816404 + 105.4922706636*t)
	X0 += 0.00000318357*np.cos(0.22505788913 + 33.1371007917*t)
	X0 += 0.00000326002*np.cos(4.18918332052 + 228.276948965*t)
	X0 += 0.00000327618*np.cos(0.75068049756 + 46.2097904851*t)
	X0 += 0.00000412500*np.cos(4.17567324159 + 490.3340891794*t)
	X0 += 0.00000351601*np.cos(6.23854037301 + 214.7835681463*t)
	X0 += 0.00000414924*np.cos(0.59122427620 + 529.6909650946*t)
	X0 += 0.00000404322*np.cos(2.13001764328 + 99.1606209555*t)
	X0 += 0.00000326652*np.cos(0.26933343606 + 7.4223635415*t)
	X0 += 0.00000314386*np.cos(3.82461196975 + 45.5766510387*t)
	X0 += 0.00000323118*np.cos(1.86185830328 + 30.7106720963*t)
	X0 += 0.00000300220*np.cos(2.12651918134 + 6.592282139*t)
	X0 += 0.00000311772*np.cos(2.38235128420 + 147.1155165798*t)
	X0 += 0.00000368105*np.cos(5.45799824106 + 255.0554677982*t)
	X0 += 0.00000346148*np.cos(4.51747810137 + 454.9093665273*t)
	X0 += 0.00000321808*np.cos(0.08789094066 + 180.2738692309*t)
	X0 += 0.00000337319*np.cos(5.17833136955 + 150.5264049811*t)
	X0 += 0.00000251931*np.cos(1.50053452494 + 19.1224551112*t)
	X0 += 0.00000252403*np.cos(0.29915395892 + 150.0844619964*t)
	X0 += 0.00000278704*np.cos(1.17271973925 + 29.2049475286*t)
	X0 += 0.00000266863*np.cos(5.73005045142 + 28.3111756513*t)
	X0 += 0.00000238805*np.cos(5.52577063741 + 554.0699874828*t)
	X0 += 0.00000299852*np.cos(1.99796836133 + 984.6003316219*t)
	X0 += 0.00000226271*np.cos(5.35719329331 + 120.9913890524*t)
	X0 += 0.00000215050*np.cos(2.10000017027 + 67.3592350258*t)
	X0 += 0.00000198057*np.cos(4.76361127500 + 69.6737891366*t)
	X0 += 0.00000220399*np.cos(0.46944876871 + 44.070926471*t)
	X0 += 0.00000219523*np.cos(5.01086928137 + 47.6942631934*t)
	X0 += 0.00000213140*np.cos(4.90437681706 + 0.5212648618*t)
	X0 += 0.00000258423*np.cos(5.01692232937 + 1289.9465010146*t)
	X0 += 0.00000185610*np.cos(4.14658641505 + 55.6591434561*t)
	X0 += 0.00000241311*np.cos(4.64092150995 + 756.3233826569*t)
	X0 += 0.00000222625*np.cos(1.63499247598 + 155.7829722581*t)
	X0 += 0.00000204428*np.cos(1.23043556439 + 142.1408335931*t)
	X0 += 0.00000231243*np.cos(4.34962187207 + 46.470422916*t)
	X0 += 0.00000231117*np.cos(0.59598761086 + 339.2864193365*t)
	X0 += 0.00000214402*np.cos(2.75106858640 + 189.1807054807*t)
	X0 += 0.00000240160*np.cos(1.57472247802 + 342.2553647531*t)
	X0 += 0.00000173507*np.cos(3.07143937754 + 79.889407998*t)
	X0 += 0.00000175735*np.cos(3.10617729573 + 57.255490749*t)
	X0 += 0.00000166885*np.cos(0.92704904427 + 30.0562807905*t)
	X0 += 0.00000173052*np.cos(2.71901382868 + 681.5417840896*t)
	X0 += 0.00000167166*np.cos(6.18216223717 + 206.1855484372*t)
	X0 += 0.00000212210*np.cos(2.48249922098 + 135.5485514541*t)
	X0 += 0.00000164032*np.cos(5.42438913166 + 468.2426886516*t)
	X0 += 0.00000203487*np.cos(1.11695843604 + 148.5999892881*t)
	X0 += 0.00000156930*np.cos(4.49200656712 + 92.3077063856*t)
	X0 += 0.00000165255*np.cos(0.65702015844 + 154.979823106*t)
	X0 += 0.00000185802*np.cos(5.56639953504 + 73.88782669*t)
	X0 += 0.00000185802*np.cos(2.25459555455 + 75.6753704446*t)
	X0 += 0.00000174776*np.cos(0.64896858671 + 103.3534066495*t)
	X0 += 0.00000187624*np.cos(6.19491337250 + 149.0419322728*t)
	X0 += 0.00000193532*np.cos(6.21234933839 + 60.7669528868*t)
	X0 += 0.00000160061*np.cos(5.01823584858 + 264.5048207692*t)
	X0 += 0.00000185820*np.cos(1.04769695695 + 76.154196691*t)
	X0 += 0.00000197311*np.cos(1.21765365835 + 256.5399405065*t)
	X0 += 0.00000175478*np.cos(2.83270040396 + 333.657345044*t)
	X0 += 0.00000157905*np.cos(5.70734466920 + 82.2039621088*t)
	X0 += 0.00000182625*np.cos(0.27259358854 + 216.9224321604*t)
	X0 += 0.00000147918*np.cos(1.82282570469 + 17.5261078183*t)
	X0 += 0.00000177450*np.cos(5.10372503690 + 685.4739373527*t)
	X0 += 0.00000139515*np.cos(2.37850065779 + 426.598190876*t)
	X0 += 0.00000137789*np.cos(5.22295277421 + 448.6895914038*t)
	X0 += 0.00000189430*np.cos(5.63043055528 + 291.7040307277*t)
	X0 += 0.00000152602*np.cos(3.60417761486 + 233.9060232575*t)
	X0 += 0.00000141512*np.cos(6.28314137970 + 130.4407420234*t)
	X0 += 0.00000134010*np.cos(3.97075396565 + 156.1554792736*t)
	X0 += 0.00000136823*np.cos(2.06403429379 + 16.6747745564*t)
	X0 += 0.00000129045*np.cos(6.13432221167 + 76.4785195967*t)
	X0 += 0.00000146031*np.cos(6.21320130613 + 294.6729761443*t)
	X0 += 0.00000146362*np.cos(4.63496106478 + 334.2904844904*t)
	X0 += 0.00000153385*np.cos(5.73024384991 + 347.8844390456*t)
	X0 += 0.00000127869*np.cos(1.20450690573 + 61.448276443*t)
	X0 += 0.00000150311*np.cos(6.16854891408 + 173.9422195228*t)
	X0 += 0.00000138900*np.cos(6.09258539376 + 286.596221297*t)
	X0 += 0.00000141169*np.cos(3.15247546979 + 24.1183899573*t)
	X0 += 0.00000115436*np.cos(3.64215841031 + 13.3333221243*t)
	X0 += 0.00000143741*np.cos(3.47182034598 + 103.0927742186*t)
	X0 += 0.00000111293*np.cos(0.10667309735 + 88.1149206916*t)
	X0 += 0.00000121087*np.cos(0.17422963984 + 79.4474650133*t)
	X0 += 0.00000108657*np.cos(0.23419995878 + 66.9172920411*t)
	X0 += 0.00000109513*np.cos(1.37565056754 + 44.7253177768*t)
	X0 += 0.00000128511*np.cos(1.87873176315 + 254.9435932136*t)
	X0 += 0.00000115349*np.cos(0.88899033684 + 692.5874843535*t)
	X0 += 0.00000135117*np.cos(2.72548252468 + 171.6545976624*t)
	X0 += 0.00000125714*np.cos(5.43040501453 + 98.3574718034*t)
	X0 += 0.00000104433*np.cos(1.66540127359 + 54.3347294422*t)
	X0 += 0.00000128791*np.cos(3.10899630296 + 155.5010879678*t)
	X0 += 0.00000105829*np.cos(1.67999980378 + 375.3924655448*t)
	X0 += 0.00000109272*np.cos(3.18774824824 + 273.1028404783*t)
	X0 += 0.00000100410*np.cos(1.92606761482 + 362.8622925726*t)
	X0 += 0.00000102158*np.cos(1.42491352478 + 0.1118745846*t)
	X0 += 0.00000095969*np.cos(0.95437290534 + 258.8757464767*t)
	X0 += 0.00000126502*np.cos(5.84097730521 + 628.8515860501*t)
	X0 += 0.00000106157*np.cos(4.21108144267 + 302.0953396858*t)
	X0 += 0.00000115494*np.cos(2.79386838622 + 604.4725636619*t)
	X0 += 0.00000097686*np.cos(3.08538131581 + 76.7873361374*t)
	X0 += 0.00000092952*np.cos(3.37459370406 + 93.9040536785*t)
	X0 += 0.00000093122*np.cos(3.05386776621 + 43.2890291783*t)
	X0 += 0.00000099120*np.cos(0.38719985960 + 149.3025647037*t)
	X0 += 0.00000089934*np.cos(4.52722147760 + 149.6113812444*t)
	X0 += 0.00000094924*np.cos(1.22382250585 + 267.4737661858*t)
	X0 += 0.00000109946*np.cos(1.23547347355 + 100.3844612329*t)
	X0 += 0.00000111791*np.cos(3.59906622192 + 19.643719973*t)
	X0 += 0.00000088765*np.cos(4.68268569184 + 27.0873353739*t)
	X0 += 0.00000089563*np.cos(2.61565675484 + 295.1942410061*t)
	X0 += 0.00000089934*np.cos(1.93336144673 + 149.5150130248*t)
	X0 += 0.00000108044*np.cos(0.47218816752 + 253.5709950899*t)
	X0 += 0.00000087921*np.cos(5.89750281232 + 74.1484591209*t)
	X0 += 0.00000087921*np.cos(1.92349227727 + 75.4147380137*t)
	X0 += 0.00000086241*np.cos(6.10142938790 + 76.42612997*t)
	X0 += 0.00000115664*np.cos(2.63306868216 + 1215.1649024473*t)
	X0 += 0.00000112324*np.cos(0.51418380423 + 228.7982138268*t)
	X0 += 0.00000106858*np.cos(3.13973175313 + 81.682697247*t)
	X0 += 0.00000083195*np.cos(3.64480716244 + 5.1078094307*t)
	X0 += 0.00000082020*np.cos(1.12030294482 + 82.6459050935*t)
	X0 += 0.00000083480*np.cos(4.54952756372 + 149.723255829*t)
	X0 += 0.00000096333*np.cos(2.43138031905 + 98.8999885246*t)
	X0 += 0.00000080076*np.cos(2.03790828937 + 73.1370671646*t)
	X0 += 0.00000099120*np.cos(6.07338306473 + 149.8238295655*t)
	X0 += 0.00000088716*np.cos(4.77601772186 + 275.5505210331*t)
	X0 += 0.00000076677*np.cos(1.12697999111 + 73.5577582899*t)
	X0 += 0.00000076021*np.cos(1.38978865049 + 218.9281697305*t)
	X0 += 0.00000083480*np.cos(1.91105536061 + 149.4031384402*t)
	X0 += 0.00000083936*np.cos(4.85628717843 + 370.9390474199*t)
	X0 += 0.00000078478*np.cos(1.13478868865 + 6.9010986797*t)
	X0 += 0.00000100821*np.cos(4.69066192585 + 210.3301500214*t)
	X0 += 0.00000075413*np.cos(4.86601833800 + 217.2312487011*t)
	X0 += 0.00000077269*np.cos(1.59133790131 + 26.0235537909*t)
	X0 += 0.00000072762*np.cos(6.17791614729 + 95.2284676924*t)
	X0 += 0.00000099273*np.cos(5.79876917993 + 328.3525936572*t)
	X0 += 0.00000083725*np.cos(3.19473451570 + 175.1660598002*t)
	X0 += 0.00000090852*np.cos(6.17909689432 + 17.2654753874*t)
	X0 += 0.00000069179*np.cos(3.11951980820 + 189.7232222019*t)
	X0 += 0.00000087997*np.cos(0.07064517287 + 894.8408795276*t)
	X0 += 0.00000091016*np.cos(4.20728010672 + 82.4858463991*t)
	X0 += 0.00000070434*np.cos(5.00824373874 + 117.9105690512*t)
	X0 += 0.00000078847*np.cos(0.01322041001 + 262.4778313397*t)
	X0 += 0.00000070212*np.cos(4.41304710948 + 820.0592809603*t)
	X0 += 0.00000067841*np.cos(0.82180485113 + 606.7601855223*t)
	X0 += 0.00000077380*np.cos(4.76492032598 + 310.1720945331*t)
	X0 += 0.00000067827*np.cos(3.41010408816 + 16.04163511*t)
	X0 += 0.00000065829*np.cos(1.93018071058 + 73.9784494152*t)
	X0 += 0.00000065829*np.cos(5.89081437901 + 75.5847477194*t)
	X0 += 0.00000072397*np.cos(4.31806917473 + 61.2882177486*t)
	X0 += 0.00000078311*np.cos(5.41215578557 + 50.66320861*t)
	X0 += 0.00000080708*np.cos(4.69137061335 + 16.4623262353*t)
	X0 += 0.00000066793*np.cos(4.81099593544 + 106.2741679563*t)
	X0 += 0.00000077424*np.cos(1.46638584169 + 70.0462961521*t)
	X0 += 0.00000063890*np.cos(0.78467782617 + 119.5069163441*t)
	X0 += 0.00000088791*np.cos(1.36813139013 + 293.188503436*t)
	X0 += 0.00000086043*np.cos(4.58346857263 + 173.6815870919*t)
	X0 += 0.00000079594*np.cos(6.19357054917 + 192.6921676185*t)
	X0 += 0.00000078342*np.cos(5.90294859657 + 58.1068240109*t)
	X0 += 0.00000060317*np.cos(5.85931117087 + 123.5396433437*t)
	X0 += 0.00000070498*np.cos(4.37183238608 + 76.3779458602*t)
	X0 += 0.00000078119*np.cos(2.28098562045 + 477.8039162072*t)
	X0 += 0.00000080964*np.cos(0.34694152649 + 331.3215390738*t)
	X0 += 0.00000081902*np.cos(3.23474305820 + 480.7728616238*t)
	X0 += 0.00000079911*np.cos(2.41727074003 + 332.8060117821*t)
	X0 += 0.00000075512*np.cos(3.63824702540 + 67.0773507355*t)
	X0 += 0.00000068354*np.cos(0.08038703786 + 79.5169009825*t)
	X0 += 0.00000076488*np.cos(0.73635514691 + 237.6781178262*t)
	X0 += 0.00000070060*np.cos(2.85493198706 + 167.7224443993*t)
	X0 += 0.00000077986*np.cos(3.27368512650 + 70.1157321213*t)
	X0 += 0.00000077640*np.cos(3.06328765206 + 71.1582618449*t)
	X0 += 0.00000066500*np.cos(1.53365564126 + 125.1841747464*t)
	X0 += 0.00000075093*np.cos(4.73904922026 + 78.4049352897*t)
	X0 += 0.00000064912*np.cos(4.53988533411 + 472.1748419147*t)
	X0 += 0.00000058628*np.cos(0.40805425491 + 403.0223176399*t)
	X0 += 0.00000054636*np.cos(1.47333499230 + 71.8608372605*t)
	X0 += 0.00000053838*np.cos(0.93176659976 + 269.9214467406*t)
	X0 += 0.00000072381*np.cos(4.25223277801 + 15.4991183888*t)
	X0 += 0.00000052189*np.cos(3.65429708039 + 48.7580447764*t)
	X0 += 0.00000053865*np.cos(5.83782773067 + 90.8232336773*t)
	X0 += 0.00000072807*np.cos(5.95313969312 + 7.8643065262*t)
	X0 += 0.00000053991*np.cos(4.58226336725 + 148.8124376092*t)
	X0 += 0.00000051866*np.cos(0.06447470425 + 77.7023598741*t)
	X0 += 0.00000056128*np.cos(4.11138805649 + 65.3804297061*t)
	X0 += 0.00000049942*np.cos(4.89879835209 + 124.5028511902*t)
	X0 += 0.00000054088*np.cos(2.02562065658 + 13.4933808187*t)
	X0 += 0.00000053830*np.cos(2.54062357724 + 831.1049812242*t)
	X0 += 0.00000057136*np.cos(2.07135660474 + 31.6526280834*t)
	X0 += 0.00000048357*np.cos(5.44952727770 + 162.8965192589*t)
	X0 += 0.00000055249*np.cos(0.27729925019 + 74.4090915518*t)
	X0 += 0.00000055249*np.cos(1.26051053222 + 75.1541055828*t)
	X0 += 0.00000049301*np.cos(0.68505345474 + 76.0054388447*t)
	X0 += 0.00000057521*np.cos(1.59317631675 + 142.9709149956*t)
	X0 += 0.00000055685*np.cos(2.94302170889 + 43.1289704839*t)
	X0 += 0.00000059455*np.cos(0.63514957816 + 290.2195580194*t)
	X0 += 0.00000063900*np.cos(2.18112319933 + 92.0470739547*t)
	X0 += 0.00000055444*np.cos(1.36286779313 + 178.7893965226*t)
	X0 += 0.00000051624*np.cos(4.72218953206 + 184.9879197867*t)
	X0 += 0.00000048683*np.cos(2.61213928649 + 48.9181034708*t)
	X0 += 0.00000052985*np.cos(2.22171821346 + 104.0077979553*t)
	X0 += 0.00000059399*np.cos(1.13646884872 + 486.4019359163*t)
	X0 += 0.00000050137*np.cos(1.48506070888 + 25.6028626656*t)
	X0 += 0.00000047590*np.cos(4.15725769893 + 224.2329211173*t)
	X0 += 0.00000052475*np.cos(4.48165606967 + 14.2270940016*t)
	X0 += 0.00000047899*np.cos(2.26914506777 + 91.4563731237*t)
	X0 += 0.00000057214*np.cos(1.13849444877 + 303.8616966844*t)
	X0 += 0.00000048855*np.cos(2.68360202842 + 101.8689339412*t)
	X0 += 0.00000054468*np.cos(1.20360366787 + 236.8749686741*t)
	X0 += 0.00000054466*np.cos(3.74899735584 + 74.1272072615*t)
	X0 += 0.00000054466*np.cos(4.07199773375 + 75.4359898731*t)
	X0 += 0.00000050910*np.cos(0.91148399106 + 58.319272332*t)
	X0 += 0.00000044633*np.cos(5.10559995376 + 57.5161231799*t)
	X0 += 0.00000047699*np.cos(0.83638374581 + 177.8743727859*t)
	X0 += 0.00000048819*np.cos(0.49665135549 + 122.4758617607*t)
	X0 += 0.00000045108*np.cos(1.90469222942 + 31.492569389*t)
	X0 += 0.00000047736*np.cos(3.70992038267 + 84.1827674285*t)
	X0 += 0.00000052405*np.cos(1.63380029621 + 58.7399634573*t)
	X0 += 0.00000059366*np.cos(4.21455208670 + 117.36805233*t)
	X0 += 0.00000042464*np.cos(1.91841049036 + 150.31395666*t)
	X0 += 0.00000056885*np.cos(2.10911106828 + 25.0603459444*t)
	X0 += 0.00000046007*np.cos(2.96485484521 + 49.7212526229*t)
	X0 += 0.00000056472*np.cos(1.96585169960 + 7.7042478318*t)
	X0 += 0.00000044203*np.cos(6.07483181407 + 70.5888128733*t)
	X0 += 0.00000047746*np.cos(1.96668828064 + 55.7710180407*t)
	X0 += 0.00000039643*np.cos(5.20792456163 + 69.1525242748*t)
	X0 += 0.00000044855*np.cos(1.92750497570 + 278.5194664497*t)
	X0 += 0.00000039626*np.cos(3.19265632224 + 72.4939767069*t)
	X0 += 0.00000039721*np.cos(3.77197555779 + 88.274979386*t)
	X0 += 0.00000042243*np.cos(4.84138065267 + 232.4215505492*t)
	X0 += 0.00000041872*np.cos(2.23021803037 + 306.830642101*t)
	X0 += 0.00000043297*np.cos(3.08650429793 + 284.1485407422*t)
	X0 += 0.00000047398*np.cos(0.90624036754 + 75.6329318292*t)
	X0 += 0.00000047398*np.cos(0.63156941487 + 73.9302653054*t)
	X0 += 0.00000052967*np.cos(5.96991904375 + 365.0011565867*t)
	X0 += 0.00000041020*np.cos(1.74616309945 + 78.9743842613*t)
	X0 += 0.00000037774*np.cos(2.65860578213 + 397.3932433474*t)
	X0 += 0.00000045419*np.cos(3.54780469477 + 393.4610900843*t)
	X0 += 0.00000042747*np.cos(4.43768599991 + 22.633917249*t)
	X0 += 0.00000050051*np.cos(1.56642196700 + 329.8370663655*t)
	X0 += 0.00000037780*np.cos(4.54908192680 + 77.0692204277*t)
	X0 += 0.00000047477*np.cos(0.90974768312 + 224.4566702865*t)
	X0 += 0.00000040362*np.cos(3.07087573985 + 29.226199388*t)
	X0 += 0.00000047665*np.cos(5.63221017988 + 73.0846775379*t)
	X0 += 0.00000040108*np.cos(4.02631792351 + 164.5410506616*t)
	X0 += 0.00000037773*np.cos(0.38995132314 + 91.2439248026*t)
	X0 += 0.00000049928*np.cos(4.53119467931 + 51.8870488874*t)
	X0 += 0.00000043014*np.cos(0.99655679002 + 198.321241911*t)
	X0 += 0.00000041910*np.cos(1.65589142441 + 141.6988906084*t)
	X0 += 0.00000041401*np.cos(1.59219235396 + 25.8634950965*t)
	X0 += 0.00000046580*np.cos(5.66779233323 + 836.5216071956*t)
	X0 += 0.00000037167*np.cos(6.06382385676 + 226.7924762567*t)
	X0 += 0.00000041073*np.cos(5.01411798286 + 411.620337349*t)
	X0 += 0.00000041143*np.cos(4.02823090738 + 1364.7280995819*t)
	X0 += 0.00000034855*np.cos(5.31109602436 + 184.0941479094*t)
	X0 += 0.00000039925*np.cos(4.80143653382 + 205.2223405907*t)
	X0 += 0.00000037356*np.cos(3.07320573780 + 0.8031491521*t)
	X0 += 0.00000043663*np.cos(4.70679058518 + 833.552661779*t)
	X0 += 0.00000043619*np.cos(0.18982086815 + 199.2844497575*t)
	X0 += 0.00000033000*np.cos(1.08181996374 + 248.7238180901*t)
	X0 += 0.00000034130*np.cos(0.02490696585 + 35.685355083*t)
	X0 += 0.00000037505*np.cos(5.59177300768 + 94.4253185403*t)
	X0 += 0.00000041560*np.cos(3.77042855528 + 163.5778428151*t)
	X0 += 0.00000034189*np.cos(3.60118447896 + 335.7749571987*t)
	X0 += 0.00000033848*np.cos(0.13377240364 + 132.8884225782*t)
	X0 += 0.00000031365*np.cos(0.09634401362 + 32.2433289144*t)
	X0 += 0.00000033282*np.cos(3.17341780978 + 0.7507595254*t)
	X0 += 0.00000030713*np.cos(2.52388675397 + 745.277682393*t)
	X0 += 0.00000030162*np.cos(5.92221199518 + 31.5407534988*t)
	X0 += 0.00000034238*np.cos(4.41376588408 + 20.4468691251*t)
	X0 += 0.00000030462*np.cos(5.36718556691 + 154.6710065653*t)
	X0 += 0.00000029782*np.cos(2.66340469665 + 43.2408450685*t)
	X0 += 0.00000031103*np.cos(1.65433821047 + 5.6290742925*t)
	X0 += 0.00000035171*np.cos(3.56835481210 + 97.4155158163*t)
	X0 += 0.00000029774*np.cos(3.47143447278 + 167.0893049529*t)
	X0 += 0.00000034498*np.cos(6.22826740240 + 180.1619946463*t)
	X0 += 0.00000036881*np.cos(4.37161776762 + 75.3722993983*t)
	X0 += 0.00000036881*np.cos(3.44937732197 + 74.1908977363*t)
	X0 += 0.00000030008*np.cos(0.58535104450 + 530.6541729411*t)
	X0 += 0.00000039561*np.cos(1.15355175157 + 58.6280888727*t)
	X0 += 0.00000032428*np.cos(2.26557707921 + 80.4106728598*t)
	X0 += 0.00000040057*np.cos(0.14187991318 + 1744.8558675419*t)
	X0 += 0.00000034894*np.cos(4.92668814244 + 143.3434220111*t)
	X0 += 0.00000029628*np.cos(6.11127530723 + 958.576777831*t)
	X0 += 0.00000029382*np.cos(0.16680358431 + 136.0698163159*t)
	X0 += 0.00000038451*np.cos(2.94085167994 + 133.1008708993*t)
	X0 += 0.00000032922*np.cos(1.54640324936 + 215.4379594521*t)
	X0 += 0.00000030833*np.cos(5.34525997176 + 8.9068362498*t)
	X0 += 0.00000028947*np.cos(3.75166596544 + 528.7277572481*t)
	X0 += 0.00000032377*np.cos(2.27298665245 + 8.5980197091*t)
	X0 += 0.00000031149*np.cos(2.40599502782 + 140.6563608848*t)
	X0 += 0.00000038175*np.cos(1.51759937027 + 114.9416236346*t)
	X0 += 0.00000029983*np.cos(0.03280380782 + 90.2807169561*t)
	X0 += 0.00000035108*np.cos(1.21482551913 + 767.3690829208*t)
	X0 += 0.00000034210*np.cos(0.77552752107 + 326.8681209489*t)
	X0 += 0.00000032854*np.cos(1.80185340982 + 1033.3583763983*t)
	X0 += 0.00000031995*np.cos(5.07221890976 + 216.2680408546*t)
	X0 += 0.00000027036*np.cos(3.03122786083 + 27.7204748203*t)
	X0 += 0.00000027412*np.cos(4.74407471114 + 221.1634019642*t)
	X0 += 0.00000032772*np.cos(5.85879342901 + 42.5382696529*t)
	X0 += 0.00000028766*np.cos(5.99039327077 + 93.7921790939*t)
	X0 += 0.00000033552*np.cos(5.03954377007 + 229.0800981171*t)
	X0 += 0.00000034037*np.cos(0.77937092280 + 142.6620984549*t)
	X0 += 0.00000034980*np.cos(4.19796683573 + 4.7353024152*t)
	X0 += 0.00000026441*np.cos(4.88885611145 + 151.260118164*t)
	X0 += 0.00000026014*np.cos(6.23229383455 + 447.2051186955*t)
	X0 += 0.00000025836*np.cos(5.11135193547 + 68.3011910129*t)
	X0 += 0.00000033053*np.cos(0.27134750984 + 1140.38330388*t)
	X0 += 0.00000026778*np.cos(1.28950862567 + 2.2876218604*t)
	X0 += 0.00000034236*np.cos(0.18746853265 + 54.2865453324*t)
	X0 += 0.00000026054*np.cos(4.42308630147 + 11.1575748485*t)
	X0 += 0.00000030776*np.cos(3.56610123946 + 66.1835788582*t)
	X0 += 0.00000024027*np.cos(4.78275838142 + 328.2407190726*t)
	X0 += 0.00000025791*np.cos(3.30165903006 + 65.8747623175*t)
	X0 += 0.00000026209*np.cos(5.82811768517 + 40.1600250673*t)
	X0 += 0.00000025701*np.cos(2.19731633217 + 75.8935642601*t)
	X0 += 0.00000025701*np.cos(5.62367875742 + 73.6696328745*t)
	X0 += 0.00000025237*np.cos(2.58308165954 + 81.2620061217*t)
	X0 += 0.00000025534*np.cos(5.23319959774 + 3.6233367224*t)
	X0 += 0.00000032460*np.cos(3.40226553572 + 1439.5096981492*t)
	X0 += 0.00000031017*np.cos(2.47019866675 + 227.5261894396*t)
	X0 += 0.00000022917*np.cos(1.69064646797 + 118.0224436358*t)
	X0 += 0.00000030625*np.cos(0.38543308891 + 90.9351082619*t)
	X0 += 0.00000024336*np.cos(4.23223779782 + 969.6224780949*t)
	X0 += 0.00000024514*np.cos(5.83282809414 + 414.0680179038*t)
	X0 += 0.00000022571*np.cos(3.73767113299 + 70.6369969831*t)
	X0 += 0.00000026189*np.cos(1.37714071031 + 10.9338256793*t)
	X0 += 0.00000026863*np.cos(4.46513557360 + 25.2727942655*t)
	X0 += 0.00000024777*np.cos(3.82558545550 + 134.0640787458*t)
	X0 += 0.00000022242*np.cos(0.31041708817 + 85.9391734158*t)
	X0 += 0.00000027006*np.cos(5.66339011829 + 104.8378793578*t)
	X0 += 0.00000030312*np.cos(4.91657918154 + 619.2903584945*t)
	X0 += 0.00000029499*np.cos(1.89955716827 + 565.1156877467*t)
	X0 += 0.00000021818*np.cos(5.43668115613 + 34.62157350*t)
	X0 += 0.00000029506*np.cos(0.51511362512 + 367.9701020033*t)
	X0 += 0.00000023404*np.cos(2.08578309566 + 541.5398145106*t)
	X0 += 0.00000023718*np.cos(5.53660822153 + 45.5553991793*t)
	X0 += 0.00000021550*np.cos(0.38029070385 + 140.9651774255*t)
	X0 += 0.00000024081*np.cos(4.27910869955 + 170.1701249541*t)
	X0 += 0.00000023248*np.cos(1.69953849620 + 166.828672522*t)
	X0 += 0.00000028495*np.cos(3.98299051940 + 616.3214130779*t)
	X0 += 0.00000029686*np.cos(6.13498719207 + 401.6497195162*t)
	X0 += 0.00000022285*np.cos(2.36595950759 + 107.918699359*t)
	X0 += 0.00000022853*np.cos(3.29726108048 + 103.9865460959*t)
	X0 += 0.00000024493*np.cos(0.22829425196 + 49.1787359017*t)
	X0 += 0.00000021208*np.cos(1.65163762659 + 188.9200730498*t)
	X0 += 0.00000026911*np.cos(2.55176488247 + 405.9912630565*t)
	X0 += 0.00000024843*np.cos(5.68013157679 + 57.1436161644*t)
	X0 += 0.00000020957*np.cos(4.08352831368 + 78.9262001515*t)
	X0 += 0.00000025450*np.cos(5.85899081364 + 100.6450936638*t)
	X0 += 0.00000025078*np.cos(2.20068349108 + 92.4195809702*t)
	X0 += 0.00000027346*np.cos(1.72847573029 + 366.485629295*t)
	X0 += 0.00000020414*np.cos(5.00632227650 + 221.8971151471*t)
	X0 += 0.00000019766*np.cos(0.95451045485 + 9.4011688612*t)
	X0 += 0.00000022784*np.cos(0.28900298014 + 64.4866578288*t)
	X0 += 0.00000020289*np.cos(1.41637307438 + 143.9341228421*t)
	X0 += 0.00000022092*np.cos(5.52239110854 + 107.4980082337*t)
	X0 += 0.00000027052*np.cos(2.23986874740 + 67.9286839974*t)
	X0 += 0.00000020822*np.cos(5.23087049171 + 77.489911553*t)
	X0 += 0.00000020822*np.cos(2.59012459788 + 72.0732855816*t)
	X0 += 0.00000021660*np.cos(1.70573151068 + 55.1378785943*t)
	X0 += 0.00000023236*np.cos(4.27186225116 + 52.1476813183*t)
	X0 += 0.00000024236*np.cos(2.27410241019 + 758.7710632117*t)
	X0 += 0.00000019238*np.cos(3.43567324357 + 144.8973306886*t)
	X0 += 0.00000026390*np.cos(2.53868436083 + 369.4545747116*t)
	X0 += 0.00000019012*np.cos(6.23987372040 + 165.6048322446*t)
	X0 += 0.00000018856*np.cos(2.80925108504 + 289.5651667136*t)
	X0 += 0.00000018734*np.cos(2.24124585820 + 312.4597163935*t)
	X0 += 0.00000026008*np.cos(4.64004097317 + 40.8413486235*t)
	X0 += 0.00000018884*np.cos(6.27294547517 + 22.8945496799*t)
	X0 += 0.00000021610*np.cos(1.24753853837 + 31.2319369581*t)
	X0 += 0.00000021305*np.cos(3.56429538359 + 37.8724032069*t)
	X0 += 0.00000018454*np.cos(5.32515403804 + 381.0909758065*t)
	X0 += 0.00000024738*np.cos(5.59448379294 + 81.6345131372*t)
	X0 += 0.00000018468*np.cos(2.20982131564 + 379.1645601135*t)
	X0 += 0.00000021107*np.cos(1.69240112719 + 252.0865223816*t)
	X0 += 0.00000020493*np.cos(2.67164929770 + 147.9668498417*t)
	X0 += 0.00000020131*np.cos(4.43054318113 + 156.6767441354*t)
	X0 += 0.00000021567*np.cos(1.12409329716 + 225.3080035484*t)
	X0 += 0.00000017391*np.cos(4.43132202586 + 72.7758609972*t)
	X0 += 0.00000017559*np.cos(0.35908279202 + 303.0585475323*t)
	X0 += 0.00000017692*np.cos(1.96141224662 + 47.061123747*t)
	X0 += 0.00000022852*np.cos(2.89096727559 + 624.919432787*t)
	X0 += 0.00000016980*np.cos(5.08939294950 + 75.2391729543*t)
	X0 += 0.00000016980*np.cos(2.73160214009 + 74.3240241803*t)
	X0 += 0.00000021062*np.cos(1.57933011690 + 331.2096644892*t)
	X0 += 0.00000022471*np.cos(0.58316987607 + 248.4631856592*t)
	X0 += 0.00000019612*np.cos(5.21011193916 + 531.978586955*t)
	X0 += 0.00000018741*np.cos(1.24596689149 + 85.0765393058*t)
	X0 += 0.00000018599*np.cos(5.83146457459 + 148.1905990109*t)
	X0 += 0.00000016059*np.cos(2.12824166984 + 610.6923387854*t)
	X0 += 0.00000019657*np.cos(0.45310853850 + 408.4389436113*t)
	X0 += 0.00000020916*np.cos(0.97601965892 + 10.0824924174*t)
	X0 += 0.00000015997*np.cos(0.65650708975 + 118.8737768977*t)
	X0 += 0.00000016134*np.cos(1.42599191372 + 117.3198682202*t)
	X0 += 0.00000018297*np.cos(3.57190587419 + 19.0105805266*t)
	X0 += 0.00000021297*np.cos(1.30859463816 + 95.2766518022*t)
	X0 += 0.00000018354*np.cos(4.92321966101 + 14.5571624017*t)
	X0 += 0.00000021477*np.cos(4.05503641492 + 1670.0742689746*t)
	X0 += 0.00000018715*np.cos(2.00072701140 + 107.0249274817*t)
	X0 += 0.00000018450*np.cos(3.24530527857 + 135.336103133*t)
	X0 += 0.00000018685*np.cos(4.76756860051 + 64.6991061499*t)
	X0 += 0.00000019467*np.cos(0.47075581635 + 550.1378342197*t)
	X0 += 0.00000017882*np.cos(1.66188161698 + 190.665178189*t)
	X0 += 0.00000016009*np.cos(2.30252486366 + 75.6116799698*t)
	X0 += 0.00000016009*np.cos(5.51847022593 + 73.9515171648*t)
	X0 += 0.00000019328*np.cos(0.95373832886 + 363.5166838784*t)
	X0 += 0.00000016801*np.cos(3.30389996644 + 196.6243208816*t)
	X0 += 0.00000017995*np.cos(3.15857292717 + 378.6432952517*t)
	X0 += 0.00000014946*np.cos(0.01933631594 + 73.3453099688*t)
	X0 += 0.00000014946*np.cos(4.66006612006 + 76.2178871658*t)
	X0 += 0.00000014777*np.cos(4.06474308403 + 79.7775334134*t)
	X0 += 0.00000019634*np.cos(2.43284555545 + 376.1956146969*t)
	X0 += 0.00000015651*np.cos(1.14451886246 + 552.5855147745*t)
	X0 += 0.00000014573*np.cos(0.98064774203 + 76.3142553854*t)
	X0 += 0.00000014573*np.cos(3.69875469397 + 73.2489417492*t)
	X0 += 0.00000015358*np.cos(0.75466203125 + 63.847772888*t)
	X0 += 0.00000018123*np.cos(0.22904578695 + 118.0706277456*t)
	X0 += 0.00000019109*np.cos(5.46363197829 + 60.5545045657*t)
	X0 += 0.00000014137*np.cos(0.58479900612 + 17.6379824029*t)
	X0 += 0.00000014481*np.cos(1.45090213380 + 1097.0942747017*t)
	X0 += 0.00000014249*np.cos(3.86670568389 + 909.8187330546*t)
	X0 += 0.00000014623*np.cos(3.60649391630 + 280.9671470045*t)
	X0 += 0.00000016592*np.cos(0.96055193273 + 285.1117485887*t)
	X0 += 0.00000013647*np.cos(6.10917059910 + 842.1506814881*t)
	X0 += 0.00000013776*np.cos(1.24049151018 + 63.6240237188*t)
	X0 += 0.00000014396*np.cos(4.20664636136 + 121.8427223143*t)
	X0 += 0.00000013418*np.cos(3.63644963778 + 69.7856637212*t)
	X0 += 0.00000016062*np.cos(2.15259310684 + 73.0364934281*t)
	X0 += 0.00000016062*np.cos(2.52680932916 + 76.5267037065*t)
	X0 += 0.00000018191*np.cos(4.17431360807 + 381.6122406683*t)
	X0 += 0.00000013441*np.cos(4.64743942354 + 535.9107402181*t)
	X0 += 0.00000013362*np.cos(4.22579107073 + 883.7951792637*t)
	X0 += 0.00000013242*np.cos(4.64847854184 + 105.380396079*t)
	X0 += 0.00000013053*np.cos(4.16130064427 + 12.0089081104*t)
	X0 += 0.00000013153*np.cos(2.76878972668 + 224.8660605637*t)
	X0 += 0.00000016919*np.cos(3.45612873180 + 703.6331846174*t)
	X0 += 0.00000015264*np.cos(3.70218217589 + 109.3125493421*t)
	X0 += 0.00000014158*np.cos(0.89623255371 + 147.5574595645*t)
	X0 += 0.00000016005*np.cos(0.81396049172 + 176.6505325085*t)
	X0 += 0.00000012475*np.cos(3.47993027626 + 195.7729876197*t)
	X0 += 0.00000013527*np.cos(0.03173550378 + 73.4571845534*t)
	X0 += 0.00000013527*np.cos(4.64766693222 + 76.1060125812*t)
	X0 += 0.00000012777*np.cos(1.95759097830 + 749.2098356561*t)
	X0 += 0.00000015707*np.cos(0.55008100514 + 106.0135355254*t)
	X0 += 0.00000013959*np.cos(6.05672603790 + 60.112561581*t)
	X0 += 0.00000012459*np.cos(0.64812677658 + 322.6116447801*t)
	X0 += 0.00000016441*np.cos(4.32023721096 + 83.3796182764*t)
	X0 += 0.00000012986*np.cos(2.70817696012 + 194.2885149114*t)
	X0 += 0.00000016646*np.cos(2.86315414412 + 336.8387387817*t)
	X0 += 0.00000014831*np.cos(2.47765698308 + 115.3623147599*t)
	X0 += 0.00000015925*np.cos(4.38695774322 + 1059.3819301892*t)
	X0 += 0.00000016221*np.cos(4.38221842826 + 129.9194771616*t)
	X0 += 0.00000013549*np.cos(5.95860980996 + 172.1971143836*t)
	X0 += 0.00000014395*np.cos(2.82450237931 + 232.0490435337*t)
	X0 += 0.00000011794*np.cos(1.77599774058 + 34.5309507748*t)
	X0 += 0.00000014677*np.cos(5.99138198153 + 208.8456773131*t)
	X0 += 0.00000012330*np.cos(4.49348353960 + 83.6884348171*t)
	X0 += 0.00000011579*np.cos(2.24791104882 + 65.3322455963*t)
	X0 += 0.00000012045*np.cos(4.83431406522 + 44.0921783304*t)
	X0 += 0.00000012793*np.cos(2.24093998376 + 62.7726904569*t)
	X0 += 0.00000013012*np.cos(2.69693854531 + 905.8865797915*t)
	X0 += 0.00000014381*np.cos(5.21992705202 + 207.8824694666*t)
	X0 += 0.00000011100*np.cos(6.25287419269 + 417.0369633204*t)
	X0 += 0.00000012912*np.cos(1.88014975039 + 288.7350853111*t)
	X0 += 0.00000011090*np.cos(3.73543127320 + 55.8715917772*t)
	X0 += 0.00000011922*np.cos(4.45761281158 + 501.3797894433*t)
	X0 += 0.00000015032*np.cos(1.87104290296 + 403.1341922245*t)
	X0 += 0.00000012512*np.cos(3.54733200878 + 1171.875873269*t)
	X0 += 0.00000010863*np.cos(3.14224264687 + 229.7614216733*t)
	X0 += 0.00000010576*np.cos(5.06922756941 + 11.848849416*t)
	X0 += 0.00000011670*np.cos(5.99338710443 + 308.6876218248*t)
	X0 += 0.00000014227*np.cos(3.18331697186 + 84.8640909847*t)
	X0 += 0.00000014378*np.cos(2.15578224139 + 193.655375465*t)
	X0 += 0.00000010353*np.cos(0.14713330527 + 466.7582159433*t)
	X0 += 0.00000010969*np.cos(3.80039920878 + 680.0573113813*t)
	X0 += 0.00000012242*np.cos(3.77918880252 + 827.9235874865*t)
	X0 += 0.00000011480*np.cos(1.70581546221 + 318.679491517*t)
	X0 += 0.00000013223*np.cos(3.20469849858 + 97.6761482472*t)
	X0 += 0.00000013031*np.cos(0.40010415472 + 757.8078553652*t)
	X0 += 0.00000011539*np.cos(0.97518052335 + 75.3510475389*t)
	X0 += 0.00000011539*np.cos(0.56262925906 + 74.2121495957*t)
	X0 += 0.00000011683*np.cos(5.01402128604 + 679.2541622292*t)
	X0 += 0.00000013475*np.cos(6.25032260448 + 438.2982824457*t)
	X0 += 0.00000012599*np.cos(2.05716339618 + 113.8778420516*t)
	X0 += 0.00000011550*np.cos(5.90402341878 + 256.4280659219*t)
	X0 += 0.00000010715*np.cos(5.95633473988 + 1108.1399749656*t)
	X0 += 0.00000010811*np.cos(2.03451109527 + 89.0086925689*t)
	X0 += 0.00000010894*np.cos(2.60919922031 + 177.3049238143*t)
	X0 += 0.00000010858*np.cos(3.65797726694 + 63.9965307343*t)
	X0 += 0.00000011727*np.cos(5.98538516260 + 210.8514148832*t)
	X0 += 0.00000009781*np.cos(5.57308312756 + 84.2309515383*t)
	X0 += 0.00000011509*np.cos(4.35301138657 + 353.301065017*t)
	X0 += 0.00000010655*np.cos(5.22089129487 + 263.962304048*t)
	X0 += 0.00000010262*np.cos(2.37561039493 + 361.3778198643*t)
	X0 += 0.00000012663*np.cos(2.78008051966 + 406.1031376411*t)
	X0 += 0.00000011319*np.cos(1.06015629901 + 43.5496616092*t)
	X0 += 0.00000010733*np.cos(1.76426685552 + 89.4506355536*t)
	X0 += 0.00000010593*np.cos(4.05752516876 + 71.7007785661*t)
	X0 += 0.00000011184*np.cos(4.54016329366 + 150.3663462867*t)
	X0 += 0.00000009592*np.cos(4.01468282292 + 422.6660376129*t)
	X0 += 0.00000009502*np.cos(1.55679754929 + 350.3321196004*t)
	X0 += 0.00000009202*np.cos(1.64799177482 + 555.5544601911*t)
	X0 += 0.00000011426*np.cos(3.32782449621 + 124.2904028691*t)
	X0 += 0.00000009406*np.cos(1.01182317286 + 69.3125829692*t)
	X0 += 0.00000009406*np.cos(0.52598660955 + 80.2506141654*t)
	X0 += 0.00000012276*np.cos(1.87738186166 + 337.8019466282*t)
	X0 += 0.00000009056*np.cos(0.11525943257 + 230.9370778409*t)
	X0 += 0.00000010681*np.cos(5.41426794763 + 1819.6374661092*t)
	X0 += 0.00000009273*np.cos(6.23870082502 + 263.0203480609*t)
	X0 += 0.00000010129*np.cos(1.27631196928 + 443.8636662634*t)
	X0 += 0.00000009954*np.cos(0.40697067708 + 79.6075237077*t)
	X0 += 0.00000009338*np.cos(2.76311888794 + 217.4436970222*t)
	X0 += 0.00000008643*np.cos(1.19803400302 + 86.6304479833*t)
	X0 += 0.00000010377*np.cos(2.71674179936 + 30.5987975117*t)
	X0 += 0.00000009828*np.cos(1.09342495140 + 69.9556734269*t)
	X0 += 0.00000011715*np.cos(4.15216104346 + 544.5087599272*t)
	X0 += 0.00000010279*np.cos(2.14278644635 + 546.956440482*t)
	X0 += 0.00000011622*np.cos(4.25766350370 + 39.0962434843*t)
	X0 += 0.00000010704*np.cos(1.12167677007 + 400.1652468079*t)
	X0 += 0.00000010253*np.cos(0.01695148000 + 30.6894202369*t)
	X0 += 0.00000011241*np.cos(5.75986380235 + 754.8389099486*t)
	X0 += 0.00000009226*np.cos(0.54709114702 + 73.8665748306*t)
	X0 += 0.00000009226*np.cos(0.99071863539 + 75.696622304*t)
	X0 += 0.00000008473*np.cos(3.94361694677 + 212.3358875915*t)
	X0 += 0.00000008052*np.cos(6.17336789892 + 674.4282370888*t)
	X0 += 0.00000009330*np.cos(1.56227394083 + 52.8020726241*t)
	X0 += 0.00000009982*np.cos(3.21457462706 + 175.4266922311*t)
	X0 += 0.00000009204*np.cos(3.60245144803 + 223.3815878554*t)
	X0 += 0.00000009571*np.cos(0.10725282156 + 292.0128472684*t)
	X0 += 0.00000008044*np.cos(2.40245968826 + 77.1174045375*t)
	X0 += 0.00000008044*np.cos(5.41853540133 + 72.4457925971*t)
	X0 += 0.00000007954*np.cos(5.69169782621 + 1022.3126761344*t)
	X0 += 0.00000008823*np.cos(4.42446680823 + 437.6438911399*t)
	X0 += 0.00000008193*np.cos(5.37748789450 + 59.2824801785*t)
	X0 += 0.00000011131*np.cos(4.60858554715 + 763.4369296577*t)
	X0 += 0.00000010522*np.cos(2.55229928724 + 154.2984995498*t)
	X0 += 0.00000009032*np.cos(0.95177465042 + 89.338760969*t)
	X0 += 0.00000007893*np.cos(4.08556010372 + 93.6916053574*t)
	X0 += 0.00000009501*np.cos(5.55196701361 + 156.4642958143*t)
	X0 += 0.00000009420*np.cos(3.18504090065 + 112.6540017742*t)
	X0 += 0.00000009347*np.cos(1.91675074687 + 156.9855606761*t)
	X0 += 0.00000008617*np.cos(4.16810264439 + 85.5666664003*t)
	X0 += 0.00000009410*np.cos(0.01602955020 + 298.2326223919*t)
	X0 += 0.00000007942*np.cos(3.63978160188 + 108.982480942*t)
	X0 += 0.00000008607*np.cos(6.26788808564 + 62.9327491513*t)
	X0 += 0.00000009481*np.cos(4.67209385843 + 36.9091953604*t)
	X0 += 0.00000009891*np.cos(0.62867977206 + 404.6186649328*t)
	X0 += 0.00000007952*np.cos(1.86804354686 + 34.2008823747*t)
	X0 += 0.00000007543*np.cos(4.71193192925 + 77.016830801*t)
	X0 += 0.00000007543*np.cos(6.25065581393 + 72.5463663336*t)
	X0 += 0.00000008486*np.cos(4.73310682076 + 77.8624185685*t)
	X0 += 0.00000009006*np.cos(0.59784568320 + 670.4960838257*t)
	X0 += 0.00000007488*np.cos(3.66691685281 + 89.9719004154*t)
	X0 += 0.00000007543*np.cos(3.74071360489 + 74.0478853844*t)
	X0 += 0.00000007543*np.cos(0.93868883111 + 75.5153117502*t)
	X0 += 0.00000008714*np.cos(6.11380091266 + 683.9894646444*t)
	X0 += 0.00000007753*np.cos(3.89251894809 + 192.8040422031*t)
	X0 += 0.00000008055*np.cos(4.51541804140 + 59.5912967192*t)
	X0 += 0.00000008473*np.cos(4.68984634698 + 71.0095039986*t)
	X0 += 0.00000008473*np.cos(3.13114874261 + 78.553693136*t)
	X0 += 0.00000008189*np.cos(2.89161988893 + 253.4591205053*t)
	X0 += 0.00000008070*np.cos(5.10239813363 + 37.1698277913*t)
	X0 += 0.00000008122*np.cos(5.93117685976 + 274.0660483248*t)
	X0 += 0.00000009184*np.cos(3.56690567030 + 100.8051523582*t)
	X0 += 0.00000008782*np.cos(5.21522198514 + 488.8496164711*t)
	X0 += 0.00000008447*np.cos(4.00626139640 + 216.4804891757*t)
	X0 += 0.00000008166*np.cos(2.05529799644 + 325.3836482406*t)
	X0 += 0.00000008125*np.cos(4.10724946912 + 115.6229471908*t)
	X0 += 0.00000008905*np.cos(3.41134329058 + 59.9638037347*t)
	X0 += 0.00000007594*np.cos(2.80403622692 + 213.9534867438*t)
	X0 += 0.00000006996*np.cos(0.89646725407 + 144.4553877039*t)
	X0 += 0.00000009581*np.cos(5.19830082333 + 241.8709035202*t)
	X0 += 0.00000006890*np.cos(1.28122854187 + 164.1203595363*t)
	X0 += 0.00000007953*np.cos(5.63301442789 + 86.7905066777*t)
	X0 += 0.00000006970*np.cos(3.53189631991 + 130.552616608*t)
	X0 += 0.00000007608*np.cos(0.76491107529 + 409.0720830577*t)
	X0 += 0.00000008498*np.cos(5.43986459432 + 20.4950532349*t)
	X0 += 0.00000008495*np.cos(5.62996070710 + 249.9476583675*t)
	X0 += 0.00000007031*np.cos(4.11339759505 + 41.7563723602*t)
	X0 += 0.00000007286*np.cos(5.61565476776 + 241.6102710893*t)
	X0 += 0.00000008429*np.cos(0.69056403771 + 153.186533857*t)
	X0 += 0.00000006801*np.cos(1.01412347718 + 301.4140161296*t)
	X0 += 0.00000007107*np.cos(4.41250045520 + 33.0252262071*t)
	X0 += 0.00000006539*np.cos(3.95099517204 + 129.1163280095*t)
	X0 += 0.00000006645*np.cos(2.66725386831 + 691.1030116452*t)
	X0 += 0.00000007084*np.cos(3.44059419900 + 102.523325247*t)
	X0 += 0.00000008617*np.cos(4.71598219531 + 150.4569690119*t)
	X0 += 0.00000007721*np.cos(2.81365717816 + 180.7951340927*t)
	X0 += 0.00000006468*np.cos(1.37143971940 + 44.6134431922*t)
	X0 += 0.00000007676*np.cos(0.12205330938 + 60.2244361656*t)
	X0 += 0.00000007616*np.cos(0.19823929024 + 343.7398374614*t)
	X0 += 0.00000008883*np.cos(1.60499381544 + 749.5823426716*t)
	X0 += 0.00000007176*np.cos(0.91191120786 + 445.7206459872*t)
	X0 += 0.00000007576*np.cos(1.63976998398 + 148.6694252573*t)
	X0 += 0.00000007153*np.cos(0.97472079949 + 44.9859502077*t)
	X0 += 0.00000007107*np.cos(5.68687193631 + 6456.8800576977*t)
	X0 += 0.00000006257*np.cos(3.43472193500 + 119.3950417595*t)
	X0 += 0.00000007314*np.cos(6.02029115164 + 188.6594406189*t)
	X0 += 0.00000006219*np.cos(5.05640701071 + 95.931043108*t)
	X0 += 0.00000007640*np.cos(1.15145978039 + 21.9795259432*t)
	X0 += 0.00000006226*np.cos(1.42012111738 + 14.8177948326*t)
	X0 += 0.00000006518*np.cos(1.02341157168 + 214.2623032845*t)
	X0 += 0.00000006334*np.cos(0.41446504672 + 491.8185618877*t)
	X0 += 0.00000006172*np.cos(1.64082544093 + 358.4088744477*t)
	X0 += 0.00000007113*np.cos(1.81225163838 + 731.9443602687*t)
	X0 += 0.00000006404*np.cos(5.37183717126 + 1310.3933701397*t)
	X0 += 0.00000006542*np.cos(5.62829080881 + 21.1494445407*t)
	X0 += 0.00000007490*np.cos(0.83410715646 + 1291.4309737229*t)
	X0 += 0.00000007443*np.cos(1.82999961281 + 396.5419100855*t)
	X0 += 0.00000005799*np.cos(3.38417427072 + 694.0719570618*t)
	X0 += 0.00000006501*np.cos(0.47551640281 + 386.0656587932*t)
	X0 += 0.00000008032*np.cos(2.40925890235 + 223.8235308401*t)
	X0 += 0.00000005745*np.cos(3.19567125444 + 20202.22629672009*t)
	X0 += 0.00000006979*np.cos(1.46529506093 + 197.7999770492*t)
	X0 += 0.00000007333*np.cos(4.15029279297 + 497.4476361802*t)
	X0 += 0.00000005643*np.cos(2.97445175627 + 116.5379709275*t)
	X0 += 0.00000007207*np.cos(3.86366874667 + 267.2131337549*t)
	X0 += 0.00000006659*np.cos(0.62431567185 + 49.5088043018*t)
	X0 += 0.00000007612*np.cos(0.68976665906 + 139.4807047172*t)
	X0 += 0.00000007515*np.cos(3.99352933456 + 514.7131115676*t)
	X0 += 0.00000005915*np.cos(5.38925556106 + 87.0511391086*t)
	X0 += 0.00000005915*np.cos(2.43173952854 + 62.512058026*t)
	X0 += 0.00000005591*np.cos(3.33946751463 + 1235.6117715724*t)
	X0 += 0.00000006326*np.cos(4.56486319559 + 178.1350052168*t)
	X0 += 0.00000005697*np.cos(1.92398898451 + 809.0135806964*t)
	X0 += 0.00000006663*np.cos(1.30321671145 + 893.3564068193*t)
	X0 += 0.00000006712*np.cos(2.34121862543 + 304.1223291153*t)
	X0 += 0.00000006670*np.cos(1.35551468688 + 436.8138097374*t)
	X0 += 0.00000005623*np.cos(2.57084176932 + 42.0651889009*t)
	X0 += 0.00000005492*np.cos(3.62415542738 + 293.7097682978*t)
	X0 += 0.00000005496*np.cos(2.40094729126 + 158.9643659958*t)
	X0 += 0.00000005598*np.cos(4.42020772430 + 188.2387494936*t)
	X0 += 0.00000006865*np.cos(4.85354232653 + 407.5876103494*t)
	X0 += 0.00000005577*np.cos(5.67561254291 + 168.6856522458*t)
	X0 += 0.00000007667*np.cos(2.26561874174 + 688.6553310904*t)
	X0 += 0.00000006288*np.cos(3.75451099606 + 314.9073969483*t)
	X0 += 0.00000006275*np.cos(6.25871609198 + 96.7611245105*t)
	X0 += 0.00000005396*np.cos(1.55557394648 + 817.7716590999*t)
	X0 += 0.00000006354*np.cos(5.36308075526 + 369.9758395734*t)
	X0 += 0.00000006932*np.cos(1.14877684957 + 483.2205421786*t)
	X0 += 0.00000005489*np.cos(3.66616236592 + 136.2298750103*t)
	X0 += 0.00000005980*np.cos(2.26259334707 + 362.0322111701*t)
	X0 += 0.00000006735*np.cos(1.57580167444 + 5994.9951559861*t)
	X0 += 0.00000007154*np.cos(0.38367300877 + 259.769518354*t)
	X0 += 0.00000006012*np.cos(3.76327673441 + 476.3194434989*t)
	X0 += 0.00000006717*np.cos(0.10184664713 + 474.9468453752*t)
	X0 += 0.00000006569*np.cos(1.45283712289 + 349.3689117539*t)
	X0 += 0.00000005212*np.cos(5.81704085223 + 561.1835344836*t)
	X0 += 0.00000005251*np.cos(0.77102401214 + 305.6068018236*t)
	X0 += 0.00000006333*np.cos(3.04339045762 + 151.850818995*t)
	X0 += 0.00000005922*np.cos(2.22626179675 + 896.3253522359*t)
	X0 += 0.00000006369*np.cos(3.21678234700 + 457.1969883877*t)
	X0 += 0.00000007006*np.cos(5.48369013299 + 237.4174853953*t)
	X0 += 0.00000006494*np.cos(3.00088317220 + 9925.2048522057*t)
	X0 += 0.00000005421*np.cos(0.58125835319 + 229.340730548*t)
	X0 += 0.00000005440*np.cos(1.54861465044 + 401.5378449316*t)
	X0 += 0.00000006012*np.cos(6.01637588426 + 695.0351649083*t)
	X0 += 0.00000006713*np.cos(2.53300554864 + 358.9301393095*t)
	X0 += 0.00000004937*np.cos(3.50473085964 + 778.4147831847*t)
	X0 += 0.00000006282*np.cos(2.70326102686 + 711.4493070338*t)
	X0 += 0.00000004956*np.cos(4.14479114010 + 450.1740641121*t)
	X0 += 0.00000005873*np.cos(1.54540557953 + 347.9326231554*t)
	X0 += 0.00000006652*np.cos(1.87662994202 + 236.1936451179*t)
	X0 += 0.00000006111*np.cos(0.57632522173 + 346.3999663373*t)
	X0 += 0.00000005219*np.cos(4.29113850675 + 27.7417266797*t)
	X0 += 0.00000005752*np.cos(4.25326612876 + 838.0060799039*t)
	X0 += 0.00000005911*np.cos(4.36010712190 + 561.8861098992*t)
	X0 += 0.00000005407*np.cos(3.68956638902 + 147.9186657319*t)
	X0 += 0.00000006307*np.cos(3.36363443595 + 300.8927512678*t)
	X0 += 0.00000004830*np.cos(5.68923513122 + 818.574808252*t)
	X0 += 0.00000005465*np.cos(5.75477672933 + 49.6518166537*t)
	X0 += 0.00000004962*np.cos(3.25178378949 + 40.2506477925*t)
	X0 += 0.00000004862*np.cos(3.98443206848 + 156.043604689*t)
	X0 += 0.00000004763*np.cos(2.45119683765 + 101.6083015103*t)
	X0 += 0.00000004831*np.cos(3.31832104988 + 621.7380390493*t)
	X0 += 0.00000004773*np.cos(5.87209787138 + 123.0183784819*t)
	X0 += 0.00000006080*np.cos(5.38005534998 + 369.0820676961*t)
	X0 += 0.00000004712*np.cos(0.72241704208 + 240.3864308119*t)
	X0 += 0.00000004866*np.cos(4.15001957737 + 271.61836777*t)
	X0 += 0.00000005165*np.cos(5.20820337200 + 419.4846438752*t)
	X0 += 0.00000005247*np.cos(3.99273309023 + 89.5993933999*t)
	X0 += 0.00000004798*np.cos(1.99760114613 + 257.3912737684*t)
	X0 += 0.00000005871*np.cos(4.92536650443 + 524.2743391232*t)
	X0 += 0.00000006355*np.cos(2.91875544444 + 425.1137181677*t)
	X0 += 0.00000006233*np.cos(1.68063570142 + 1595.2926704073*t)
	X0 += 0.00000005518*np.cos(1.72808265472 + 85.7154242466*t)
	X0 += 0.00000006174*np.cos(6.20195291439 + 1288.4620283063*t)
	X0 += 0.00000005266*np.cos(3.16745397591 + 323.5054166574*t)
	X0 += 0.00000005474*np.cos(2.88264855465 + 118.8525250383*t)
	X0 += 0.00000005268*np.cos(3.23575329194 + 164.3809919672*t)
	X0 += 0.00000004598*np.cos(3.62412165981 + 155.1922714271*t)
	X0 += 0.00000004562*np.cos(4.84497063338 + 355.7487455718*t)
	X0 += 0.00000006030*np.cos(4.60083877410 + 3191.0492295652*t)
	X0 += 0.00000004619*np.cos(4.56283368598 + 194.1766403268*t)
	X0 += 0.00000004787*np.cos(2.45717311995 + 461.1291416508*t)
	X0 += 0.00000005963*np.cos(3.78210055675 + 37.611770776*t)
	X0 += 0.00000005537*np.cos(4.69446621919 + 475.3562356524*t)
	X0 += 0.00000004705*np.cos(3.18358647312 + 239.1625905345*t)
	X0 += 0.00000005254*np.cos(4.89804499710 + 335.1418177523*t)
	X0 += 0.00000004508*np.cos(3.96143616095 + 106.4342266507*t)
	X0 += 0.00000004992*np.cos(1.91379124627 + 53.653405886*t)
	X0 += 0.00000005229*np.cos(2.37453148939 + 1514.2912967165*t)
	X0 += 0.00000004545*np.cos(3.99007594196 + 138.4056222861*t)
	X0 += 0.00000005801*np.cos(5.60942548145 + 453.424893819*t)
	X0 += 0.00000004598*np.cos(2.84824896257 + 224.084163271*t)
	X0 += 0.00000004442*np.cos(2.55719441632 + 1578.0271950199*t)
	X0 += 0.00000004529*np.cos(0.42105215119 + 529.851023789*t)
	X0 += 0.00000005086*np.cos(3.02781327890 + 1031.87390369*t)
	X0 += 0.00000004518*np.cos(3.91961032516 + 529.5309064002*t)
	X0 += 0.00000004527*np.cos(0.18440066668 + 100.0543928328*t)
	X0 += 0.00000005251*np.cos(3.17128548460 + 469.7271613599*t)
	X0 += 0.00000005605*np.cos(2.76934913754 + 25938.3399444396*t)
	X0 += 0.00000004316*np.cos(5.46795424616 + 132.5796060375*t)
	X0 += 0.00000005868*np.cos(4.23210669739 + 1065.6017053127*t)
	X0 += 0.00000005247*np.cos(1.70237501787 + 2199.7652340692*t)
	X0 += 0.00000005793*np.cos(4.75395160520 + 1894.4190646765*t)
	X0 += 0.00000004350*np.cos(0.58138936558 + 21.1976286505*t)
	X0 += 0.00000004501*np.cos(1.13668862821 + 523.4711899711*t)
	X0 += 0.00000005387*np.cos(0.36739665703 + 193.9160078959*t)
	X0 += 0.00000004637*np.cos(1.23008862142 + 178.677521938*t)
	X0 += 0.00000005789*np.cos(6.28230577403 + 131.9252147317*t)
	X0 += 0.00000004725*np.cos(5.50921508396 + 1222.2784494481*t)
	X0 += 0.00000005643*np.cos(2.44509347920 + 315.1680293792*t)
	X0 += 0.00000004301*np.cos(3.66662949536 + 137.5542890242*t)
	X0 += 0.00000005743*np.cos(5.13195739925 + 246.4361962297*t)
	X0 += 0.00000004316*np.cos(3.62023586731 + 310.9752436852*t)
	X0 += 0.00000004346*np.cos(2.53786810357 + 319.5732633943*t)
	X0 += 0.00000004279*np.cos(1.39897629930 + 383.3091616977*t)
	X0 += 0.00000005449*np.cos(2.52988969603 + 29.7474642498*t)
	X0 += 0.00000005197*np.cos(3.92618185605 + 223.4510238246*t)
	X0 += 0.00000004770*np.cos(5.04550182969 + 823.9914342234*t)
	X0 += 0.00000004166*np.cos(0.08492730501 + 627.3671133418*t)
	X0 += 0.00000004371*np.cos(1.61761667675 + 1072.7152523135*t)
	X0 += 0.00000004183*np.cos(5.74021676862 + 997.9336537462*t)
	X0 += 0.00000004817*np.cos(2.88466542669 + 3041.4860324306*t)
	X0 += 0.00000004598*np.cos(5.14313919761 + 158.7519176747*t)
	X0 += 0.00000005388*np.cos(3.47215286830 + 636.6677084665*t)
	X0 += 0.00000004119*np.cos(3.70589946554 + 2120.2483330867*t)
	X0 += 0.00000004676*np.cos(4.61937154628 + 527.2432845398*t)
	X0 += 0.00000004756*np.cos(1.48001282657 + 1360.7959463188*t)
	X0 += 0.00000005241*np.cos(4.99807675817 + 444.2361732789*t)
	X0 += 0.00000004624*np.cos(3.36725532914 + 887.7273325268*t)
	X0 += 0.00000004742*np.cos(1.08531509632 + 25788.776747305*t)
	X0 += 0.00000004150*np.cos(4.29707458546 + 181.6464673546*t)
	X0 += 0.00000005700*np.cos(4.42021373130 + 772.5887669361*t)
	X0 += 0.00000004604*np.cos(3.23730533014 + 52177.29075585669*t)
	X0 += 0.00000004518*np.cos(0.12021315429 + 227.5956254088*t)
	X0 += 0.00000004801*np.cos(1.91657173650 + 763.2244813366*t)
	X0 += 0.00000004302*np.cos(4.07488146098 + 99.8419445117*t)
	X0 += 0.00000004832*np.cos(1.83839787801 + 439.782755154*t)
	X0 += 0.00000004731*np.cos(4.58220741156 + 598.5346728287*t)
	X0 += 0.00000005139*np.cos(0.05224584019 + 170.0100662597*t)
	X0 += 0.00000005340*np.cos(3.74844424776 + 332.1728723357*t)
	X0 += 0.00000003942*np.cos(0.90741814441 + 1020.025054274*t)
	X0 += 0.00000004265*np.cos(3.62938010955 + 139.1718881765*t)
	X0 += 0.00000005538*np.cos(0.97968779982 + 296.7481496836*t)
	X0 += 0.00000004471*np.cos(3.67508159105 + 33.9402499438*t)
	X0 += 0.00000003959*np.cos(5.50934383834 + 150.9357952583*t)
	X0 += 0.00000004888*np.cos(0.42127851602 + 522.5774180938*t)
	X0 += 0.00000004752*np.cos(5.13310717346 + 230.8252032563*t)
	X0 += 0.00000004546*np.cos(2.33235152672 + 44.1828010556*t)
	X0 += 0.00000004199*np.cos(6.00132942631 + 305.4580439773*t)
	X0 += 0.00000004748*np.cos(4.72352640183 + 551.2129166508*t)
	X0 += 0.00000004410*np.cos(3.94433837247 + 1034.8428491066*t)
	X0 += 0.00000003907*np.cos(3.18697718640 + 36.1754821775*t)
	X0 += 0.00000003892*np.cos(1.69273861503 + 1246.6574718363*t)
	X0 += 0.00000004621*np.cos(1.60315185681 + 104.5290628171*t)
	X0 += 0.00000004010*np.cos(0.96832089300 + 957.0923051227*t)
	X0 += 0.00000003999*np.cos(0.67919742508 + 55.8192021505*t)
	X0 += 0.00000003999*np.cos(0.85861235733 + 93.7439949841*t)
	X0 += 0.00000005220*np.cos(2.73849324439 + 66.3960271793*t)
	X0 += 0.00000004058*np.cos(4.17182793283 + 1044.4040766622*t)
	X0 += 0.00000004292*np.cos(4.26391012839 + 908.3342603463*t)
	X0 += 0.00000005151*np.cos(0.05080208802 + 901.9544265284*t)
	X0 += 0.00000004067*np.cos(1.30593331214 + 528.2064923863*t)
	X0 += 0.00000004398*np.cos(3.05010000369 + 1019.7644218431*t)
	X0 += 0.00000004054*np.cos(3.93008682239 + 1147.4968508808*t)
	X0 += 0.00000004089*np.cos(4.88671627275 + 770.3380283374*t)
	X0 += 0.00000004979*np.cos(5.72556882350 + 683.0262567979*t)
	X0 += 0.00000004410*np.cos(5.46838417109 + 460.5384408198*t)
	X0 += 0.00000004536*np.cos(5.18012223444 + 387.2413149608*t)
	X0 += 0.00000004307*np.cos(3.93578836401 + 302.637856407*t)
	X0 += 0.00000004828*np.cos(0.61933574564 + 262.0571402144*t)
	X0 += 0.00000003807*np.cos(5.26788824520 + 170.7608257851*t)
	X0 += 0.00000004776*np.cos(5.01230725530 + 379.0158022672*t)
	X0 += 0.00000003768*np.cos(5.36076741746 + 1755.9015678058*t)
	X0 += 0.00000004703*np.cos(0.18391535840 + 473.659314623*t)
	X0 += 0.00000003914*np.cos(5.05534607924 + 525.4981794006*t)
	X0 += 0.00000004727*np.cos(4.19123757571 + 686.958410061*t)
	X0 += 0.00000004710*np.cos(2.26465786650 + 484.917463208*t)
	X0 += 0.00000004340*np.cos(0.03358099560 + 215.7467759928*t)
	X0 += 0.00000004815*np.cos(3.65417851763 + 673.316271396*t)
	X0 += 0.00000004601*np.cos(0.56848721506 + 204.7010757289*t)
	X0 += 0.00000003833*np.cos(4.50882706137 + 464.4705940829*t)
	X0 += 0.00000003921*np.cos(2.31238727110 + 367.8582274187*t)
	X0 += 0.00000004584*np.cos(3.59482425537 + 30.1681553751*t)
	X0 += 0.00000004458*np.cos(0.31703385792 + 127.5836711914*t)
	X0 += 0.00000004432*np.cos(4.29795903962 + 781.5961769224*t)
	X0 += 0.00000004364*np.cos(2.10393899022 + 196.8367692027*t)
	X0 += 0.00000003790*np.cos(0.89714826480 + 138.6293714553*t)
	X0 += 0.00000003668*np.cos(4.04509712972 + 829.6205085159*t)
	X0 += 0.00000003739*np.cos(2.49930590383 + 909.9306076392*t)
	X0 += 0.00000003762*np.cos(2.60655174903 + 294.3004691288*t)
	X0 += 0.00000005077*np.cos(1.77462786076 + 786.2309056011*t)
	X0 += 0.00000003969*np.cos(2.97347811680 + 250.6020496733*t)
	X0 += 0.00000003631*np.cos(0.71340218954 + 1336.4169239306*t)
	X0 += 0.00000004628*np.cos(0.34854671150 + 324.7292569348*t)
	X0 += 0.00000003876*np.cos(5.90510178691 + 990.2294059144*t)
	X0 += 0.00000003603*np.cos(1.59469951538 + 386.720050099*t)
	X0 += 0.00000003764*np.cos(5.50610875494 + 68.631259413*t)
	X0 += 0.00000003764*np.cos(5.45647898824 + 80.9319377216*t)
	X0 += 0.00000003603*np.cos(3.55211452968 + 586.377006872*t)
	X0 += 0.00000003741*np.cos(0.33398234764 + 813.8395058368*t)
	X0 += 0.00000004245*np.cos(0.02485941311 + 291.1190753911*t)
	X0 += 0.00000004700*np.cos(2.63332393497 + 292.8159964205*t)
	X0 += 0.00000003576*np.cos(4.10345975514 + 168.5737776612*t)
	X0 += 0.00000004645*np.cos(0.80030005818 + 441.2672278623*t)
	X0 += 0.00000004649*np.cos(6.16884000839 + 700.7761137854*t)
	X0 += 0.00000004954*np.cos(4.52779163462 + 16.6110840816*t)
	X0 += 0.00000004002*np.cos(1.60087230027 + 395.0574373772*t)
	X0 += 0.00000004185*np.cos(2.96597437308 + 305.2342948081*t)
	X0 += 0.00000004462*np.cos(0.93157251490 + 161.4120465506*t)
	X0 += 0.00000004102*np.cos(4.59093836137 + 1169.3276189777*t)
	X0 += 0.00000003588*np.cos(0.27873050602 + 1340.3490771937*t)
	X0 += 0.00000004185*np.cos(6.23485375931 + 1574.8458012822*t)
	X0 += 0.00000003578*np.cos(5.08118538256 + 154.5591319807*t)
	X0 += 0.00000003760*np.cos(2.77230298800 + 532.8723588323*t)
	X0 += 0.00000003758*np.cos(0.14294735321 + 1041.2226829245*t)
	X0 += 0.00000003568*np.cos(0.85509496232 + 1016.0929010109*t)
	X0 += 0.00000004172*np.cos(2.93211623273 + 581.1573228567*t)
	X0 += 0.00000003780*np.cos(3.65614433020 + 90.5626012464*t)
	X0 += 0.00000004564*np.cos(2.97361651836 + 112.3933693433*t)
	X0 += 0.00000003717*np.cos(5.61326911538 + 1471.7530270636*t)
	X0 += 0.00000003535*np.cos(0.10988485689 + 872.9095376942*t)
	X0 += 0.00000004336*np.cos(1.59644351231 + 548.6533615114*t)
	X0 += 0.00000003439*np.cos(1.46598704716 + 812.9457339595*t)
	X0 += 0.00000004841*np.cos(1.95552773911 + 822.8794685306*t)
	X0 += 0.00000004454*np.cos(3.42579762098 + 374.7111419886*t)
	X0 += 0.00000004434*np.cos(0.71080738069 + 1685.0521225016*t)
	X0 += 0.00000003664*np.cos(6.12918648460 + 320.1639642253*t)
	X0 += 0.00000003860*np.cos(4.17371507398 + 48.2367799146*t)
	X0 += 0.00000004508*np.cos(3.07386548950 + 983.1158589136*t)
	X0 += 0.00000004102*np.cos(2.99945701352 + 808.2104315443*t)
	X0 += 0.00000003995*np.cos(2.74810269783 + 632.0329797878*t)
	X0 += 0.00000003917*np.cos(3.69870848484 + 608.2446582306*t)
	X0 += 0.00000003412*np.cos(4.77079031354 + 832.5894539325*t)
	X0 += 0.00000003961*np.cos(3.33250778247 + 185.5786206177*t)
	X0 += 0.00000003623*np.cos(4.64985456293 + 454.7974919427*t)
	X0 += 0.00000004124*np.cos(3.37976754896 + 252.6559713532*t)
	X0 += 0.00000003919*np.cos(0.26952670688 + 6137.4448061199*t)
	X0 += 0.00000003372*np.cos(0.45014900270 + 406.954470903*t)
	X0 += 0.00000003314*np.cos(2.84122766862 + 280.2163874791*t)
	X0 += 0.00000004206*np.cos(2.08946908078 + 435.1962105851*t)
	X0 += 0.00000004058*np.cos(1.50736855443 + 432.2272651685*t)
	X0 += 0.00000004630*np.cos(3.53027863494 + 6170.1612157863*t)
	X0 += 0.00000003904*np.cos(0.24163677359 + 458.090760265*t)
	X0 += 0.00000003335*np.cos(3.30445833614 + 771.3012361839*t)
	X0 += 0.00000003318*np.cos(5.45360392276 + 1450.5553984131*t)
	X0 += 0.00000003471*np.cos(1.25113554742 + 199.0720014364*t)
	X0 += 0.00000003544*np.cos(1.33379125488 + 188.0263011725*t)
	X0 += 0.00000003557*np.cos(4.95484715865 + 1254.5217783625*t)
	X0 += 0.00000003312*np.cos(0.89488112289 + 517.1607921224*t)
	X0 += 0.00000004587*np.cos(4.60594057122 + 25483.43057791229*t)
	X0 += 0.00000004069*np.cos(1.27659765222 + 274.6354972964*t)
	X0 += 0.00000003826*np.cos(3.29750710982 + 6129.5804995937*t)
	X0 += 0.00000003422*np.cos(1.53733627594 + 886.2428598185*t)
	X0 += 0.00000003652*np.cos(2.44969882307 + 398.6807740996*t)
	X0 += 0.00000004578*np.cos(0.12293169591 + 2736.1398630379*t)
	X0 += 0.00000003702*np.cos(5.13339128979 + 1321.4390704036*t)
	X0 += 0.00000003351*np.cos(3.76280400362 + 743.7932096847*t)
	X0 += 0.00000004132*np.cos(0.01289789881 + 761.7400086283*t)
	X0 += 0.00000004478*np.cos(2.53095817704 + 446.3113468182*t)
	X0 += 0.00000003398*np.cos(0.23047450502 + 182.6096752011*t)
	X0 += 0.00000003973*np.cos(2.04945985964 + 433.190473015*t)
	X0 += 0.00000003778*np.cos(1.07863762669 + 86.939264524*t)
	X0 += 0.00000004082*np.cos(0.25118427960 + 511.5954083047*t)
	X0 += 0.00000003857*np.cos(3.16268032037 + 254.0922599517*t)
	X0 += 0.00000003896*np.cos(0.46366115563 + 798.3885715578*t)
	X0 += 0.00000003268*np.cos(4.00080141209 + 59.0005958882*t)
	X0 += 0.00000003725*np.cos(1.88982085589 + 498.4108440267*t)
	X0 += 0.00000003641*np.cos(1.92575340799 + 29.7956483596*t)
	X0 += 0.00000004018*np.cos(3.66861564496 + 757.2865905034*t)
	X0 += 0.00000004350*np.cos(2.92081750057 + 442.7517005706*t)
	X0 += 0.00000003957*np.cos(5.88730379340 + 407.4757357648*t)
	X0 += 0.00000003536*np.cos(3.36275654524 + 78039.36462902068*t)
	X0 += 0.00000003769*np.cos(0.60875044771 + 650.0492147006*t)
	X0 += 0.00000003231*np.cos(4.95941213173 + 274.5873131866*t)
	X0 += 0.00000003616*np.cos(1.40200347339 + 455.0212411119*t)
	X0 += 0.00000003845*np.cos(5.35098476288 + 614.8369403696*t)
	X0 += 0.00000004406*np.cos(5.47551901323 + 847.5673074595*t)
	X0 += 0.00000003479*np.cos(0.21471955910 + 271.6665518798*t)
	X0 += 0.00000003179*np.cos(5.76357883511 + 1886.5547581503*t)
	X0 += 0.00000004221*np.cos(4.85565822083 + 102.5020733876*t)
	X0 += 0.00000004257*np.cos(4.65953203398 + 269.0701134787*t)
	X0 += 0.00000003699*np.cos(1.69223585010 + 10067.6545023395*t)
	X0 += 0.00000003211*np.cos(5.53866872898 + 151.5689347047*t)
	X0 += 0.00000004374*np.cos(5.39609986794 + 356.9244017394*t)
	X0 += 0.00000003516*np.cos(0.78503214935 + 470.4934272503*t)
	X0 += 0.00000003380*np.cos(0.70280224085 + 2.0057375701*t)
	X0 += 0.00000003221*np.cos(3.21423971704 + 1442.4786435658*t)
	X0 += 0.00000004337*np.cos(0.71530474065 + 325.9530972122*t)
	X0 += 0.00000004363*np.cos(4.95297283334 + 10100.3709120059*t)
	X0 += 0.00000003105*np.cos(0.42212828385 + 551.1010420662*t)
	X0 += 0.00000003392*np.cos(2.25899685018 + 5909.1678571549*t)
	X0 += 0.00000003932*np.cos(3.92524338589 + 243.3553762285*t)
	X0 += 0.00000004325*np.cos(4.50980035788 + 502.8642621516*t)
	X0 += 0.00000003079*np.cos(4.48934263963 + 828.8173593638*t)
	X0 += 0.00000004000*np.cos(4.23137559040 + 238.9019581036*t)
	X0 += 0.00000003547*np.cos(1.18954889005 + 38.6061163898*t)
	X0 += 0.00000003069*np.cos(3.57500923483 + 53.3233374859*t)
	X0 += 0.00000003619*np.cos(0.53814238131 + 121.2520214833*t)
	X0 += 0.00000003646*np.cos(1.55483894873 + 473.4623726669*t)
	X0 += 0.00000003219*np.cos(2.64143743565 + 1274.9686474876*t)
	X0 += 0.00000003339*np.cos(2.95148684971 + 839.4905526122*t)
	X0 += 0.00000003604*np.cos(4.72016797397 + 10059.7901958133*t)
	X0 += 0.00000003316*np.cos(2.53257077581 + 302.3772239761*t)
	X0 += 0.00000003235*np.cos(1.79025814071 + 377.1588225434*t)
	X0 += 0.00000003558*np.cos(0.14957844924 + 366.1131222795*t)
	X0 += 0.00000003077*np.cos(4.11145647240 + 367.5975949878*t)
	X0 += 0.00000003047*np.cos(3.71010425526 + 74.5691502462*t)
	X0 += 0.00000003047*np.cos(0.96929818074 + 74.9940468884*t)
	X0 += 0.00000003633*np.cos(1.90925113302 + 2175.386211681*t)
	X0 += 0.00000003399*np.cos(3.06470005459 + 418.5214360287*t)
	X0 += 0.00000003398*np.cos(4.85438710621 + 991.7138786227*t)
	X0 += 0.00000003226*np.cos(1.45240599904 + 394.9455627926*t)
	X0 += 0.00000003217*np.cos(4.87069954758 + 1061.6695520496*t)
	X0 += 0.00000003096*np.cos(6.05361002082 + 846.0828347512*t)
	X0 += 0.00000003230*np.cos(5.92927393828 + 219.5188705615*t)
	X0 += 0.00000003756*np.cos(1.80033274284 + 669.0116111174*t)
	X0 += 0.00000003453*np.cos(1.61122511232 + 1205.9761819072*t)
	X0 += 0.00000003146*np.cos(3.91978798680 + 6533.1461289733*t)
	X0 += 0.00000003774*np.cos(1.39886028887 + 251.1714986449*t)
	X0 += 0.00000003935*np.cos(3.17535121697 + 487.8864086246*t)
	X0 += 0.00000003189*np.cos(2.85027634129 + 439.9315130003*t)
	X0 += 0.00000002987*np.cos(1.05473954283 + 182.279606801*t)
	X0 += 0.00000003273*np.cos(5.76363220748 + 2424.1100297711*t)
	X0 += 0.00000003667*np.cos(3.07143289100 + 1.6969210294*t)
	X0 += 0.00000004138*np.cos(2.73202390759 + 436.1594184316*t)
	X0 += 0.00000003328*np.cos(4.55158693252 + 391.976617376*t)
	X0 += 0.00000002978*np.cos(5.94580624646 + 373.535485821*t)
	X0 += 0.00000004154*np.cos(5.62690393825 + 195.4004806042*t)
	X0 += 0.00000003637*np.cos(4.87903340292 + 587.8614795803*t)
	X0 += 0.00000003553*np.cos(0.07777162237 + 261.9565664779*t)
	X0 += 0.00000003149*np.cos(1.45984421265 + 395.105621487*t)
	X0 += 0.00000002962*np.cos(2.60920797777 + 1158.5425511447*t)
	X0 += 0.00000003589*np.cos(2.03353815770 + 487.1045113319*t)
	X0 += 0.00000003349*np.cos(5.45643647292 + 523.7530742614*t)
	X0 += 0.00000003063*np.cos(1.06632237280 + 699.7010313543*t)
	X0 += 0.00000003247*np.cos(4.79603063160 + 313.42292424*t)
	X0 += 0.00000003841*np.cos(2.50542705831 + 674.8007441043*t)
	X0 += 0.00000002973*np.cos(1.67622654649 + 605.275712814*t)
	X0 += 0.00000003760*np.cos(3.72986643389 + 751.0668153799*t)
	X0 += 0.00000003193*np.cos(3.98720961022 + 302.8984888379*t)
	X0 += 0.00000003640*np.cos(6.18169873722 + 410.1358646407*t)
	X0 += 0.00000003533*np.cos(5.51851339600 + 271.4059194489*t)
	X0 += 0.00000003112*np.cos(1.63679903914 + 482.2573343321*t)
	X0 += 0.00000003029*np.cos(4.03332340352 + 245.5424243524*t)
	X0 += 0.00000002950*np.cos(4.59717760832 + 47.2735720681*t)
	X0 += 0.00000002936*np.cos(5.68363571769 + 380.8785274854*t)
	X0 += 0.00000004122*np.cos(4.80389472595 + 2885.7030601725*t)
	X0 += 0.00000002922*np.cos(0.61496402948 + 94.7553869404*t)
	X0 += 0.00000002922*np.cos(0.92284575293 + 54.8078101942*t)
	X0 += 0.00000003691*np.cos(2.87961032764 + 748.0978699633*t)
	X0 += 0.00000003250*np.cos(3.50840756791 + 949.4362414007*t)
	X0 += 0.00000003191*np.cos(3.68151144937 + 9839.3775533745*t)
	X0 += 0.00000003950*np.cos(5.25973340926 + 697.8071683688*t)
	X0 += 0.00000002909*np.cos(1.86561947750 + 379.3770084346*t)
	X0 += 0.00000003750*np.cos(3.72694170125 + 5985.4339284305*t)
	X0 += 0.00000003840*np.cos(4.95586519535 + 6061.6999997061*t)
	X0 += 0.00000003498*np.cos(0.14578444966 + 3114.7831582896*t)
	X0 += 0.00000003912*np.cos(4.31481409741 + 669.6929346736*t)
	X0 += 0.00000003233*np.cos(3.42786641063 + 423.4167971383*t)
	X0 += 0.00000002948*np.cos(3.53413358490 + 78338.49102328988*t)
	X0 += 0.00000003225*np.cos(1.40637905526 + 576.1613880106*t)
	X0 += 0.00000002937*np.cos(0.29646296117 + 590.2454696603*t)
	X0 += 0.00000004025*np.cos(2.99661933871 + 25632.99377504689*t)
	X0 += 0.00000003822*np.cos(3.99843493630 + 827.1728279611*t)
	X0 += 0.00000003870*np.cos(5.51356586663 + 2124.9836355019*t)
	X0 += 0.00000003324*np.cos(4.80337367540 + 6209.7787241324*t)
	X0 += 0.00000003638*np.cos(3.50918818351 + 1008.9793540101*t)
	X0 += 0.00000002874*np.cos(5.12119295555 + 187.2755416471*t)
	X0 += 0.00000003359*np.cos(4.46803343205 + 359.893347156*t)
	X0 += 0.00000003854*np.cos(2.68175502948 + 224.9354965329*t)
	X0 += 0.00000003809*np.cos(4.38400618597 + 3117.7521037062*t)
	X0 += 0.00000003942*np.cos(4.28275251770 + 927.9779803193*t)
	X0 += 0.00000002978*np.cos(1.97136538075 + 400.7346957795*t)
	X0 += 0.00000002912*np.cos(1.78010174024 + 753.1419889192*t)
	X0 += 0.00000003186*np.cos(3.01587158229 + 53.6321540266*t)
	X0 += 0.00000003735*np.cos(5.74696647535 + 909.70685847*t)
	X0 += 0.00000003185*np.cos(5.79943875516 + 5982.4649830139*t)
	X0 += 0.00000003341*np.cos(5.20072763739 + 511.5317178299*t)
	X0 += 0.00000002997*np.cos(0.04223641582 + 354.9979860464*t)
	X0 += 0.00000002902*np.cos(1.79129681788 + 47.2211824414*t)
	X0 += 0.00000002902*np.cos(6.02969827171 + 102.3420146932*t)
	X0 += 0.00000003255*np.cos(1.03591834871 + 482.3692089167*t)
	X0 += 0.00000003946*np.cos(0.04138275847 + 6096.8640899273*t)
	X0 += 0.00000003872*np.cos(5.45119868236 + 470.6903692064*t)
	X0 += 0.00000003005*np.cos(3.53992132641 + 162.635886828*t)
	X0 += 0.00000003924*np.cos(4.40439164938 + 526.9826521089*t)
	X0 += 0.00000002825*np.cos(3.80497099809 + 1606.3383706712*t)
	X0 += 0.00000003232*np.cos(3.91334446659 + 444.8268741099*t)
	X0 += 0.00000003561*np.cos(5.09342203154 + 1668.5897962663*t)
	X0 += 0.00000002803*np.cos(2.09081885651 + 451.7279727896*t)
	X0 += 0.00000002835*np.cos(5.26040401145 + 294.5611015597*t)
	X0 += 0.00000002802*np.cos(1.97945485167 + 1592.0418407004*t)
	X0 += 0.00000003388*np.cos(4.62841923047 + 25862.073873164*t)
	X0 += 0.00000003050*np.cos(2.94686489799 + 6530.1771835567*t)
	X0 += 0.00000003115*np.cos(2.76472416518 + 436.7501192626*t)
	X0 += 0.00000003266*np.cos(4.88735094654 + 265.7286610466*t)
	X0 += 0.00000003668*np.cos(5.22572399717 + 415.6643651967*t)
	X0 += 0.00000003868*np.cos(2.64909249866 + 113.4571509263*t)
	X0 += 0.00000002850*np.cos(0.93628396613 + 1448.9108670104*t)
	X0 += 0.00000003327*np.cos(0.82829766822 + 412.5835451955*t)
	X0 += 0.00000002863*np.cos(4.00036548571 + 323.2447842265*t)
	X0 += 0.00000002774*np.cos(4.33267175059 + 551.7823656224*t)
	X0 += 0.00000003704*np.cos(2.58308448101 + 25865.04281858059*t)
	X0 += 0.00000002806*np.cos(5.17543386153 + 2088.8081533244*t)
	X0 += 0.00000002766*np.cos(2.53845010068 + 1600.1185955477*t)
	X0 += 0.00000003634*np.cos(3.00439582111 + 77.6386693993*t)
	X0 += 0.00000003634*np.cos(1.67500661490 + 71.9245277353*t)
	X0 += 0.00000002909*np.cos(3.25311064209 + 112.4939430798*t)
	X0 += 0.00000002957*np.cos(3.89190030394 + 53.5839699168*t)
	X0 += 0.00000002793*np.cos(1.50011760025 + 465.273743235*t)
	X0 += 0.00000003101*np.cos(1.82377616022 + 529.9515975255*t)
	X0 += 0.00000003179*np.cos(2.47362164483 + 529.4303326637*t)
	X0 += 0.00000003091*np.cos(3.36846576185 + 912.7876784712*t)
	X0 += 0.00000002841*np.cos(4.99710506357 + 1349.7502460549*t)
	X0 += 0.00000002975*np.cos(4.20884044975 + 224.1847370075*t)
	X0 += 0.00000003614*np.cos(0.09529926684 + 9991.9096959257*t)
	X0 += 0.00000002886*np.cos(5.75239983007 + 428.0826635843*t)
	X0 += 0.00000003022*np.cos(3.67976254648 + 829.4080601948*t)
	X0 += 0.00000002937*np.cos(0.99310447017 + 282.6640680339*t)
	X0 += 0.00000002920*np.cos(4.81655636505 + 1190.7858800591*t)
	X0 += 0.00000002859*np.cos(3.59162912719 + 395.9087706391*t)
	X0 += 0.00000003672*np.cos(0.39454281112 + 376.9463742223*t)
	X0 += 0.00000003502*np.cos(5.14876183773 + 9915.6436246501*t)
	X0 += 0.00000003139*np.cos(6.22398139851 + 10139.988420352*t)
	X0 += 0.00000003266*np.cos(0.65217674021 + 201.2901873276*t)
	X0 += 0.00000002771*np.cos(5.00950677412 + 1821.1219388175*t)
	X0 += 0.00000002891*np.cos(0.16321611264 + 245.4942402426*t)
	X0 += 0.00000002716*np.cos(5.94390688693 + 1533.2536931333*t)
	X0 += 0.00000003340*np.cos(4.48479148149 + 1366.2125722902*t)
	X0 += 0.00000002941*np.cos(1.40585778661 + 147.8662761052*t)
	X0 += 0.00000003427*np.cos(1.74554946194 + 914.4845995006*t)
	X0 += 0.00000003494*np.cos(1.50642632860 + 191.3195694948*t)
	X0 += 0.00000003318*np.cos(3.73912779069 + 260.360219185*t)
	X0 += 0.00000003079*np.cos(1.13242149517 + 1062.5633239269*t)
	X0 += 0.00000002969*np.cos(4.51605546992 + 1541.8517128424*t)
	X0 += 0.00000003726*np.cos(2.67277746243 + 26542.81250810149*t)
	X0 += 0.00000003051*np.cos(2.78368746438 + 421.1815649046*t)
	X0 += 0.00000003639*np.cos(2.40271831395 + 513.079881013*t)
	X0 += 0.00000002651*np.cos(2.04478708937 + 960.0612505393*t)
	X0 += 0.00000003509*np.cos(3.30273492208 + 6354.8885031421*t)
	X0 += 0.00000002660*np.cos(4.35820637617 + 96.2398596487*t)
	X0 += 0.00000002984*np.cos(0.93929798505 + 9912.6746792335*t)
	X0 += 0.00000002642*np.cos(4.81017870174 + 487.1526954417*t)
	X0 += 0.00000003349*np.cos(1.77006672178 + 67.8804998876*t)
	X0 += 0.00000003715*np.cos(1.46398359301 + 10027.0737861469*t)
	X0 += 0.00000002698*np.cos(2.25129487280 + 569.0478410098*t)
	X0 += 0.00000002779*np.cos(2.95332852844 + 392.6579409322*t)
	X0 += 0.00000003062*np.cos(3.91142815674 + 789.4604834486*t)
	X0 += 0.00000002631*np.cos(2.37052193061 + 1474.9344208013*t)
	X0 += 0.00000003011*np.cos(2.22470704566 + 1605.5876111458*t)
	X0 += 0.00000002879*np.cos(4.54178981532 + 857.1285350151*t)
	X0 += 0.00000003258*np.cos(0.70846024546 + 104.5772469269*t)
	X0 += 0.00000003049*np.cos(2.06524904960 + 1303.2798231389*t)
	X0 += 0.00000002961*np.cos(2.78419866266 + 12564.6672272745*t)
	X0 += 0.00000002727*np.cos(0.43906543709 + 1063.8353483141*t)
	X0 += 0.00000003091*np.cos(5.61530760960 + 554.1818620674*t)
	X0 += 0.00000002903*np.cos(3.07181627040 + 1541.1179996595*t)
	X0 += 0.00000002689*np.cos(3.91719627755 + 517.4214245533*t)
	X0 += 0.00000002846*np.cos(3.20097069993 + 540.0553418023*t)
	X0 += 0.00000003440*np.cos(2.45078516584 + 236.5024616586*t)
	X0 += 0.00000002719*np.cos(0.45068700830 + 52325.36948028299*t)
	X0 += 0.00000003093*np.cos(0.78760201101 + 93.531546663*t)
	X0 += 0.00000003043*np.cos(5.84553288250 + 752.5512880882*t)
	X0 += 0.00000002585*np.cos(2.67373555383 + 2117.2793876701*t)
	X0 += 0.00000003559*np.cos(4.29992888175 + 900.4699538201*t)
	X0 += 0.00000003598*np.cos(0.24186259790 + 132.0370893163*t)
	X0 += 0.00000002947*np.cos(1.10177902088 + 446.83261168*t)
	X0 += 0.00000003551*np.cos(1.27437867131 + 316.3918696566*t)
	X0 += 0.00000002584*np.cos(3.54943039679 + 268.4369740323*t)
	X0 += 0.00000003167*np.cos(3.77971849522 + 12567.6361726911*t)
	X0 += 0.00000003345*np.cos(1.93508620092 + 583.4080614554*t)
	X0 += 0.00000002651*np.cos(2.97228932638 + 643.8294395771*t)
	X0 += 0.00000002573*np.cos(0.04096075848 + 584.8925341637*t)
	X0 += 0.00000002562*np.cos(5.04631980333 + 1374.1292684431*t)
	X0 += 0.00000003377*np.cos(4.72559531257 + 10285.0981993617*t)
	X0 += 0.00000002831*np.cos(4.29539738341 + 539.773457512*t)
	X0 += 0.00000003190*np.cos(3.69756383156 + 769.6198215195*t)
	X0 += 0.00000003242*np.cos(1.83260797987 + 805.2414861277*t)
	X0 += 0.00000003373*np.cos(0.25136652920 + 764.921402366*t)
	X0 += 0.00000003299*np.cos(2.15481336956 + 440.8947208468*t)
	X0 += 0.00000002810*np.cos(1.23890197328 + 311.2840602259*t)
	X0 += 0.00000002856*np.cos(0.44622736949 + 2281.6603796373*t)
	X0 += 0.00000002578*np.cos(1.28353508968 + 1160.8301730051*t)
	X0 += 0.00000002783*np.cos(1.02755087868 + 1268.7488723641*t)
	X0 += 0.00000003006*np.cos(4.04391286855 + 1544.0869450761*t)
	X0 += 0.00000003130*np.cos(6.25757675247 + 2727.9717264555*t)
	X0 += 0.00000002551*np.cos(2.40340258218 + 1159.3457002968*t)
	X0 += 0.00000003287*np.cos(0.26000896186 + 463.2467538055*t)
	X0 += 0.00000002596*np.cos(5.25166061607 + 826.4391147782*t)
	X0 += 0.00000002734*np.cos(1.91308659798 + 799.8730442661*t)
	X0 += 0.00000003317*np.cos(2.51269837372 + 807.7528571573*t)
	X0 += 0.00000003375*np.cos(1.74643993256 + 605.9570363702*t)
	X0 += 0.00000003011*np.cos(2.37110515848 + 373.0142209592*t)
	X0 += 0.00000002984*np.cos(0.24635683106 + 936.6454359976*t)
	X0 += 0.00000002866*np.cos(4.91213635727 + 2192.6516870684*t)
	X0 += 0.00000003269*np.cos(0.04981734572 + 737.4246767149*t)
	X0 += 0.00000003098*np.cos(4.07812927937 + 657.4233941323*t)
	X0 += 0.00000002711*np.cos(3.98895103447 + 678.3603903519*t)
	X0 += 0.00000002507*np.cos(1.43443806433 + 20278.49236799569*t)
	X0 += 0.00000002824*np.cos(2.94497633242 + 508.6264628881*t)
	X0 += 0.00000003132*np.cos(5.12767484173 + 1553.6481726317*t)
	X0 += 0.00000002806*np.cos(5.71814807428 + 351.7047177241*t)
	X0 += 0.00000002705*np.cos(2.12994126939 + 172.4577468145*t)
	X0 += 0.00000003334*np.cos(0.15340910675 + 1361.7591541653*t)
	X0 += 0.00000002782*np.cos(3.15719024944 + 519.6084726772*t)
	X0 += 0.00000003073*np.cos(2.66711354956 + 106.8648687873*t)
	X0 += 0.00000003061*np.cos(2.24403344534 + 52174.32181044009*t)
	X0 += 0.00000002505*np.cos(0.80744053241 + 672.9437643805*t)
	X0 += 0.00000003073*np.cos(0.35436617007 + 10065.2068217847*t)
	X0 += 0.00000003459*np.cos(4.58079150140 + 809.2373298656*t)
	X0 += 0.00000003386*np.cos(0.97499612837 + 1056.2005364515*t)
	X0 += 0.00000002648*np.cos(3.45216167121 + 659.674132731*t)
	X0 += 0.00000002685*np.cos(4.85368581683 + 257.9125386302*t)
	X0 += 0.00000002572*np.cos(2.13972748651 + 584.8288436889*t)
	X0 += 0.00000003106*np.cos(2.61817632505 + 1375.7737998458*t)
	X0 += 0.00000002506*np.cos(6.23212920846 + 382.1335055301*t)
	X0 += 0.00000002717*np.cos(2.48381545310 + 351.9284668933*t)
	X0 += 0.00000003347*np.cos(5.14134665087 + 247.8300462128*t)
	X0 += 0.00000002483*np.cos(0.84499721587 + 213.2509113282*t)
	X0 += 0.00000002480*np.cos(4.04140005960 + 213.3472795478*t)
	X0 += 0.00000002428*np.cos(0.46154118993 + 20275.52342257909*t)
	X0 += 0.00000002799*np.cos(4.86813388259 + 1005.047200747*t)
	X0 += 0.00000002657*np.cos(3.11477828769 + 587.7977891055*t)
	X0 += 0.00000003021*np.cos(1.21277274474 + 280.003939158*t)
	X0 += 0.00000002618*np.cos(5.27831691087 + 877.5754041402*t)
	X0 += 0.00000002592*np.cos(3.82396293779 + 175.820451106*t)
	X0 += 0.00000003345*np.cos(5.33418227770 + 810.6581120991*t)
	X0 += 0.00000002427*np.cos(6.00834528881 + 243.8978929497*t)
	X0 += 0.00000002413*np.cos(3.69693635912 + 623.0255698015*t)
	X0 += 0.00000002744*np.cos(3.90942586821 + 442.639825986*t)
	X0 += 0.00000002509*np.cos(3.57281224902 + 1789.6817590552*t)
	X0 += 0.00000003097*np.cos(0.89535439878 + 911.515654084*t)
	X0 += 0.00000003208*np.cos(3.79865497427 + 386.9806825299*t)
	X0 += 0.00000003146*np.cos(2.76661285663 + 1242.7253185732*t)
	X0 += 0.00000002431*np.cos(0.85207197895 + 836.7340555167*t)
	X0 += 0.00000002622*np.cos(1.08347941593 + 369.342700127*t)
	X0 += 0.00000002655*np.cos(2.90453219642 + 625.6701923124*t)
	X0 += 0.00000002769*np.cos(4.12625133544 + 207.3612046048*t)
	X0 += 0.00000002906*np.cos(0.80826038658 + 481.7360694703*t)
	X0 += 0.00000002598*np.cos(3.45095863503 + 2267.4332856357*t)
	X0 += 0.00000003109*np.cos(6.09716177778 + 45.0341343175*t)
	X0 += 0.00000002804*np.cos(4.20913964758 + 978.9712573294*t)
	X0 += 0.00000002802*np.cos(3.34017271353 + 764.4001375042*t)
	X0 += 0.00000002592*np.cos(3.49895787987 + 360.5477384618*t)
	X0 += 0.00000002999*np.cos(5.22361260271 + 6134.9971255651*t)
	X0 += 0.00000002428*np.cos(2.99468117542 + 229.4526051326*t)
	X0 += 0.00000002533*np.cos(5.95316695932 + 432.8179659995*t)
	X0 += 0.00000002382*np.cos(0.68810083757 + 325.7930385178*t)
	X0 += 0.00000002930*np.cos(1.53042890055 + 173.1390703707*t)
	X0 += 0.00000002420*np.cos(0.89948530881 + 1720.4768451537*t)
	X0 += 0.00000002377*np.cos(2.36761685006 + 1928.1992559259*t)
	X0 += 0.00000002782*np.cos(2.17593412190 + 889.2118052351*t)
	X0 += 0.00000002573*np.cos(0.26649824790 + 1536.2226385499*t)
	X0 += 0.00000002508*np.cos(2.11454020497 + 341.7340998913*t)
	X0 += 0.00000002448*np.cos(1.98619678461 + 1327.8189042215*t)
	X0 += 0.00000003336*np.cos(3.10162597185 + 725.0914456988*t)
	X0 += 0.00000002392*np.cos(0.21242741759 + 614.6244920485*t)
	X0 += 0.00000002507*np.cos(1.80828402176 + 394.3548619616*t)
	X0 += 0.00000002823*np.cos(0.19015234079 + 122.0551706354*t)
	X0 += 0.00000002530*np.cos(2.95773515771 + 1330.7878496381*t)
	X0 += 0.00000002532*np.cos(4.46226588980 + 1511.3223512999*t)
	X0 += 0.00000003040*np.cos(5.16745492791 + 480.8847362084*t)
	X0 += 0.00000002606*np.cos(2.59310129142 + 661.0949149645*t)
	X0 += 0.00000002474*np.cos(2.81621738023 + 1407.2663692348*t)
	X0 += 0.00000002595*np.cos(3.72982344914 + 1586.1039498672*t)
	X0 += 0.00000002451*np.cos(1.74083806788 + 838.218528225*t)
	X0 += 0.00000002448*np.cos(5.35097946752 + 320.3240229197*t)
	X0 += 0.00000002409*np.cos(4.99514413314 + 2118.7638603784*t)
	X0 += 0.00000002622*np.cos(5.73550541407 + 1048.3362299253*t)
	X0 += 0.00000002851*np.cos(2.37230529824 + 747.7253629478*t)
	X0 += 0.00000003251*np.cos(1.90510984540 + 83.1671699553*t)
	X0 += 0.00000002387*np.cos(2.83037383593 + 714.6788848813*t)
	X0 += 0.00000002780*np.cos(1.77987961860 + 141.1776257466*t)
	X0 += 0.00000003048*np.cos(1.66294992528 + 430.5303441391*t)
	X0 += 0.00000002460*np.cos(2.27287175347 + 1292.9154464312*t)
	X0 += 0.00000002783*np.cos(1.02550599707 + 1080.5795588397*t)
	X0 += 0.00000003097*np.cos(4.72047182702 + 10063.7223490764*t)
	X0 += 0.00000002910*np.cos(0.78044221568 + 650.9429865779*t)
	X0 += 0.00000002359*np.cos(1.30445584096 + 378.1220303899*t)
	X0 += 0.00000002497*np.cos(4.18707812445 + 599.6466385215*t)
	X0 += 0.00000003102*np.cos(2.15094298964 + 476.4313180835*t)
	X0 += 0.00000002875*np.cos(5.63713008045 + 6812.766815086*t)
	X0 += 0.00000002522*np.cos(2.55619336731 + 441.1553532777*t)
	X0 += 0.00000002570*np.cos(3.49764756320 + 1699.2792165032*t)
	X0 += 0.00000002325*np.cos(0.80296980818 + 290.3683158657*t)
	X0 += 0.00000002635*np.cos(1.08428876142 + 6132.0281801485*t)
	X0 += 0.00000002743*np.cos(4.20664830562 + 1969.2006632438*t)
	X0 += 0.00000002417*np.cos(3.03355272640 + 283.6272758804*t)
	X0 += 0.00000002315*np.cos(4.85594677157 + 424.1505103212*t)
	X0 += 0.00000002411*np.cos(4.77687475493 + 343.2185725996*t)
	X0 += 0.00000002923*np.cos(4.03560484889 + 1599.9585368533*t)
	X0 += 0.00000003120*np.cos(5.44366360558 + 769.8167634756*t)
	X0 += 0.00000002459*np.cos(0.51644781610 + 494.2662424425*t)
	X0 += 0.00000002279*np.cos(5.84210879958 + 594.9113361063*t)
	X0 += 0.00000002380*np.cos(0.93599236213 + 1258.4539316256*t)
	X0 += 0.00000002675*np.cos(1.18409531003 + 519.0177718462*t)
	X0 += 0.00000002764*np.cos(3.89164591027 + 291.0496394219*t)
	X0 += 0.00000002585*np.cos(1.04410652057 + 754.0357607965*t)
	X0 += 0.00000002276*np.cos(2.99670185563 + 1404.0849754971*t)
	X0 += 0.00000002768*np.cos(0.90030726299 + 2274.5468326365*t)
	X0 += 0.00000002803*np.cos(3.69303331087 + 95.9792272178*t)
	X0 += 0.00000002274*np.cos(1.85168217548 + 104276.83096772949*t)
	X0 += 0.00000002268*np.cos(0.20518949756 + 537.3952129264*t)
	X0 += 0.00000002286*np.cos(5.33958308193 + 557.0389328994*t)
	X0 += 0.00000002319*np.cos(3.39859717806 + 173.0484476455*t)
	X0 += 0.00000002773*np.cos(4.21974240408 + 431.3334932912*t)
	X0 += 0.00000002914*np.cos(3.02958692463 + 784.7464328928*t)
	X0 += 0.00000002993*np.cos(0.49951880041 + 459.0539681115*t)
	X0 += 0.00000003129*np.cos(4.47843032507 + 939.6143814142*t)
	X0 += 0.00000003165*np.cos(4.75058891561 + 26161.20026743319*t)
	X0 += 0.00000002283*np.cos(5.65964892836 + 811.4612612512*t)
	X0 += 0.00000002261*np.cos(4.33110508196 + 1736.9915610157*t)
	X0 += 0.00000002566*np.cos(4.39554125385 + 63.4752658725*t)
	X0 += 0.00000002681*np.cos(6.00923286619 + 412.3229127646*t)
	X0 += 0.00000002437*np.cos(0.38702218640 + 376.8769382531*t)
	X0 += 0.00000002452*np.cos(3.15408990558 + 287.2506126028*t)
	X0 += 0.00000002384*np.cos(1.73850316210 + 1970.6851359521*t)
	X0 += 0.00000002249*np.cos(3.06698924618 + 1372.6447957348*t)
	X0 += 0.00000002259*np.cos(4.68065566116 + 113.3877149571*t)
	X0 += 0.00000002278*np.cos(5.35632851845 + 1026.2448293975*t)
	X0 += 0.00000002834*np.cos(1.49045047339 + 485.8806710545*t)
	X0 += 0.00000003153*np.cos(4.46150066246 + 3795.5217932271*t)
	X0 += 0.00000002368*np.cos(5.98954180707 + 226.6324175623*t)
	X0 += 0.00000002795*np.cos(0.77259066809 + 10742.9765113056*t)
	X0 += 0.00000002231*np.cos(6.02735193252 + 386.3475430835*t)
	X0 += 0.00000002256*np.cos(1.85300200201 + 1811.773159583*t)
	X0 += 0.00000002945*np.cos(3.51719262167 + 714.4182524504*t)
	X0 += 0.00000003088*np.cos(5.58047807216 + 230.2826865351*t)
	X0 += 0.00000002228*np.cos(3.92663836521 + 844.5983620429*t)
	X0 += 0.00000002685*np.cos(2.97936141724 + 303.5798123941*t)
	X0 += 0.00000002260*np.cos(4.95342040684 + 123.960334469*t)
	X0 += 0.00000002403*np.cos(2.94703926890 + 1151.4290041439*t)
	X0 += 0.00000002879*np.cos(5.91440314810 + 924.0458270562*t)
	X0 += 0.00000002854*np.cos(0.88172955033 + 646.1170614375*t)
	X0 += 0.00000003091*np.cos(0.26846308854 + 3413.9095525588*t)
	X0 += 0.00000002202*np.cos(4.93836731176 + 1436.5407527326*t)
	X0 += 0.00000002308*np.cos(4.93454100712 + 1170.3914005607*t)
	X0 += 0.00000002331*np.cos(5.55597569672 + 820.8100404857*t)
	X0 += 0.00000002447*np.cos(5.30192531544 + 299.7170951002*t)
	X0 += 0.00000002713*np.cos(1.33801079136 + 770.5504766585*t)
	X0 += 0.00000002261*np.cos(0.44102163363 + 817.0903355437*t)
	X0 += 0.00000002950*np.cos(5.76859185743 + 653.2306084383*t)
	X0 += 0.00000002185*np.cos(2.44586598369 + 246.9787129509*t)
	return X0




def Uranus_X1 (t): # 628 terms of order 1

	X1 = 0.
	X1 += 0.00739697937*np.cos(6.01067921255 + 149.5631971346*t)
	X1 -= 0.00528174379
	X1 += 0.00239830578*np.cos(5.33657752107 + 73.297125859*t)
	X1 += 0.00229661096*np.cos(2.48203377424 + 76.2660712756*t)
	X1 += 0.00111041831*np.cos(5.57157483973 + 11.0457002639*t)
	X1 += 0.00096348588*np.cos(0.35070396367 + 63.7358983034*t)
	X1 += 0.00081508425*np.cos(1.21058628422 + 85.8272988312*t)
	X1 += 0.00045685509*np.cos(2.29216605538 + 138.5174968707*t)
	X1 += 0.00051382144*np.cos(2.18938250169 + 224.3447957019*t)
	X1 += 0.00038842663*np.cos(0.30724636172 + 70.8494453042*t)
	X1 += 0.00036156923*np.cos(1.23634800002 + 78.7137518304*t)
	X1 += 0.00032331648*np.cos(5.06666434496 + 74.7815985673*t)
	X1 += 0.00021684713*np.cos(4.93711029212 + 151.0476698429*t)
	X1 += 0.00019441253*np.cos(1.30617221059 + 77.7505439839*t)
	X1 += 0.00017375530*np.cos(0.24607209329 + 71.8126531507*t)
	X1 += 0.00015211071*np.cos(5.53141633140 + 3.9321532631*t)
	X1 += 0.00007735984*np.cos(1.61349552789 + 71.6002048296*t)
	X1 += 0.00007425078*np.cos(6.20357977116 + 77.962992305*t)
	X1 += 0.00006995857*np.cos(2.40633283814 + 145.6310438715*t)
	X1 += 0.00007291691*np.cos(2.23597571444 + 2.9689454166*t)
	X1 += 0.00007585264*np.cos(2.76074218330 + 148.0787244263*t)
	X1 += 0.00004378335*np.cos(3.74296322240 + 160.6088973985*t)
	X1 += 0.00004127713*np.cos(1.48475181305 + 22.0914005278*t)
	X1 += 0.00003933541*np.cos(4.73864204208 + 65.2203710117*t)
	X1 += 0.00002910312*np.cos(5.91941333050 + 127.4717966068*t)
	X1 += 0.00002834328*np.cos(4.88889623484 + 213.299095438*t)
	X1 += 0.00002802392*np.cos(3.76505436434 + 52.6901980395*t)
	X1 += 0.00002545264*np.cos(3.36768337628 + 9.5612275556*t)
	X1 += 0.00002647073*np.cos(4.53813176345 + 12.5301729722*t)
	X1 += 0.00003177614*np.cos(4.65226634926 + 299.1263942692*t)
	X1 += 0.00002228396*np.cos(0.18087986338 + 87.3117715395*t)
	X1 += 0.00002824668*np.cos(3.40143685673 + 84.3428261229*t)
	X1 += 0.00002525203*np.cos(2.83821144961 + 18.1592472647*t)
	X1 += 0.00002216987*np.cos(4.78338909951 + 72.3339180125*t)
	X1 += 0.00001624493*np.cos(3.75817281127 + 153.4953503977*t)
	X1 += 0.00001941329*np.cos(2.39889176495 + 39.6175083461*t)
	X1 += 0.00001555444*np.cos(4.13741667297 + 73.8183907208*t)
	X1 += 0.00001600865*np.cos(0.08376247543 + 79.2350166922*t)
	X1 += 0.00001476317*np.cos(3.67283851029 + 75.7448064138*t)
	X1 += 0.00001427088*np.cos(1.45690759014 + 70.3281804424*t)
	X1 += 0.00001533469*np.cos(3.71776498048 + 152.5321425512*t)
	X1 += 0.00001747266*np.cos(3.24870046809 + 77.2292791221*t)
	X1 += 0.00001716831*np.cos(3.39415662657 + 222.8603229936*t)
	X1 += 0.00001707504*np.cos(1.11296012106 + 225.8292684102*t)
	X1 += 0.00001734228*np.cos(5.39619902298 + 146.594251718*t)
	X1 += 0.00001476617*np.cos(3.53047075439 + 3.1813937377*t)
	X1 += 0.00001239315*np.cos(0.98221206501 + 4.4534181249*t)
	X1 += 0.00001099691*np.cos(1.35138854505 + 62.2514255951*t)
	X1 += 0.00000977123*np.cos(1.01847642495 + 74.6697239827*t)
	X1 += 0.00000975571*np.cos(0.51903242150 + 74.8934731519*t)
	X1 += 0.00001061312*np.cos(5.00125105380 + 131.4039498699*t)
	X1 += 0.00001029261*np.cos(5.42434597865 + 109.9456887885*t)
	X1 += 0.00000868857*np.cos(2.79792544805 + 56.6223513026*t)
	X1 += 0.00000928372*np.cos(3.34272600968 + 7.1135470008*t)
	X1 += 0.00000747420*np.cos(4.78455200239 + 92.940845832*t)
	X1 += 0.00000647136*np.cos(0.20307260484 + 80.1982245387*t)
	X1 += 0.00000720965*np.cos(0.28353896718 + 1.4844727083*t)
	X1 += 0.00000666117*np.cos(3.49754791028 + 96.8729990951*t)
	X1 += 0.00000497791*np.cos(3.50054849965 + 137.0330241624*t)
	X1 += 0.00000463277*np.cos(4.82158205361 + 220.4126424388*t)
	X1 += 0.00000478135*np.cos(1.15784370177 + 41.1019810544*t)
	X1 += 0.00000452889*np.cos(1.09710482126 + 67.6680515665*t)
	X1 += 0.00000412572*np.cos(3.78953003468 + 66.70484372*t)
	X1 += 0.00000408503*np.cos(0.33951833274 + 81.8951455681*t)
	X1 += 0.00000366735*np.cos(4.72836346262 + 202.2533951741*t)
	X1 += 0.00000395742*np.cos(1.58893964955 + 14.977853527*t)
	X1 += 0.00000377813*np.cos(3.73353761428 + 2.4476805548*t)
	X1 += 0.00000347012*np.cos(6.15993155091 + 134.5853436076*t)
	X1 += 0.00000347209*np.cos(4.09740378576 + 146.3818033969*t)
	X1 += 0.00000346276*np.cos(3.88647750381 + 59.8037450403*t)
	X1 += 0.00000343714*np.cos(4.42446342755 + 142.4496501338*t)
	X1 += 0.00000294160*np.cos(4.42096282169 + 5.4166259714*t)
	X1 += 0.00000329148*np.cos(5.84103283969 + 112.9146342051*t)
	X1 += 0.00000327786*np.cos(1.84209237036 + 36.6485629295*t)
	X1 += 0.00000306476*np.cos(1.06590600726 + 33.6796175129*t)
	X1 += 0.00000275437*np.cos(4.10479793303 + 82.8583534146*t)
	X1 += 0.00000293125*np.cos(0.49846117327 + 145.1097790097*t)
	X1 += 0.00000254628*np.cos(6.25473678549 + 235.3904959658*t)
	X1 += 0.00000246505*np.cos(5.32024438086 + 159.1244246902*t)
	X1 += 0.00000249949*np.cos(0.67221714016 + 265.9892934775*t)
	X1 += 0.00000235773*np.cos(3.62653751252 + 20.6069278195*t)
	X1 += 0.00000217183*np.cos(4.25583219062 + 152.7445908723*t)
	X1 += 0.00000210343*np.cos(4.63336622628 + 140.001969579*t)
	X1 += 0.00000231137*np.cos(0.38954829748 + 108.4612160802*t)
	X1 += 0.00000183920*np.cos(5.05228486550 + 191.2076949102*t)
	X1 += 0.00000221484*np.cos(2.71939746995 + 195.1398481733*t)
	X1 += 0.00000192825*np.cos(0.45904824372 + 23.5758732361*t)
	X1 += 0.00000228031*np.cos(5.73832504591 + 297.6419215609*t)
	X1 += 0.00000181760*np.cos(1.50820819426 + 120.358249606*t)
	X1 += 0.00000182509*np.cos(2.37138086919 + 209.3669421749*t)
	X1 += 0.00000160927*np.cos(4.77614458093 + 8.0767548473*t)
	X1 += 0.00000154383*np.cos(0.90699803576 + 288.0806940053*t)
	X1 += 0.00000164982*np.cos(6.03209867187 + 5.9378908332*t)
	X1 += 0.00000153438*np.cos(2.70088223137 + 162.0933701068*t)
	X1 += 0.00000191778*np.cos(0.83177362607 + 373.9079928365*t)
	X1 += 0.00000154090*np.cos(3.25708486897 + 14.0146456805*t)
	X1 += 0.00000150916*np.cos(1.30817182471 + 69.3649725959*t)
	X1 += 0.00000143519*np.cos(5.80839382745 + 211.8146227297*t)
	X1 += 0.00000140612*np.cos(5.35931699754 + 29.2049475286*t)
	X1 += 0.00000141703*np.cos(2.64874298288 + 68.8437077341*t)
	X1 += 0.00000134614*np.cos(0.41866243813 + 39.3568759152*t)
	X1 += 0.00000140275*np.cos(5.15925110927 + 80.7194894005*t)
	X1 += 0.00000148005*np.cos(3.01901836595 + 186.2117600641*t)
	X1 += 0.00000138435*np.cos(0.38546052988 + 81.0013736908*t)
	X1 += 0.00000156471*np.cos(3.62049946715 + 116.4260963429*t)
	X1 += 0.00000142032*np.cos(4.72599483352 + 114.3991069134*t)
	X1 += 0.00000132979*np.cos(1.16919556561 + 68.5618234438*t)
	X1 += 0.00000132271*np.cos(3.93102400599 + 89.7594520943*t)
	X1 += 0.00000117156*np.cos(1.04699930678 + 277.0349937414*t)
	X1 += 0.00000115855*np.cos(3.50608314585 + 33.1371007917*t)
	X1 += 0.00000116656*np.cos(4.77768622576 + 99.1606209555*t)
	X1 += 0.00000118667*np.cos(0.97921601472 + 305.3461693927*t)
	X1 += 0.00000141195*np.cos(5.83532011809 + 45.5766510387*t)
	X1 += 0.00000124069*np.cos(1.48589888078 + 41.6444977756*t)
	X1 += 0.00000110901*np.cos(4.69277387714 + 51.2057253312*t)
	X1 += 0.00000119992*np.cos(2.88407866671 + 50.4025761791*t)
	X1 += 0.00000121041*np.cos(2.51714592201 + 154.0166152595*t)
	X1 += 0.00000109540*np.cos(5.23116357278 + 88.7962442478*t)
	X1 += 0.00000103214*np.cos(3.71629269070 + 144.1465711632*t)
	X1 += 0.00000103776*np.cos(2.10287854036 + 54.1746707478*t)
	X1 += 0.00000116279*np.cos(6.16263578313 + 227.3137411185*t)
	X1 += 0.00000122915*np.cos(3.57188972236 + 300.6108669775*t)
	X1 += 0.00000102736*np.cos(5.34763165471 + 152.0108776894*t)
	X1 += 0.00000090202*np.cos(0.56709477474 + 125.9873238985*t)
	X1 += 0.00000081723*np.cos(6.27079297819 + 228.276948965*t)
	X1 += 0.00000079097*np.cos(1.62215576410 + 206.1855484372*t)
	X1 += 0.00000084840*np.cos(6.21066793803 + 42.5864537627*t)
	X1 += 0.00000077211*np.cos(1.11725893023 + 110.2063212194*t)
	X1 += 0.00000074095*np.cos(0.25759427545 + 148.5999892881*t)
	X1 += 0.00000074141*np.cos(6.12651413564 + 150.5264049811*t)
	X1 += 0.00000074651*np.cos(4.40519875592 + 128.9562693151*t)
	X1 += 0.00000081515*np.cos(2.33379448960 + 32.1951448046*t)
	X1 += 0.00000073276*np.cos(5.35840675742 + 95.3885263868*t)
	X1 += 0.00000072236*np.cos(1.94385727161 + 24.3790223882*t)
	X1 += 0.00000080037*np.cos(4.41743269825 + 6.2197751235*t)
	X1 += 0.00000067741*np.cos(0.23367851706 + 16.6747745564*t)
	X1 += 0.00000068101*np.cos(4.86711498571 + 28.5718080822*t)
	X1 += 0.00000071855*np.cos(2.40256356403 + 404.5067903482*t)
	X1 += 0.00000071445*np.cos(1.52414424740 + 106.9767433719*t)
	X1 += 0.00000069920*np.cos(5.06695266595 + 230.5645708254*t)
	X1 += 0.00000069373*np.cos(4.50365511857 + 333.657345044*t)
	X1 += 0.00000068989*np.cos(2.68367160082 + 183.2428146475*t)
	X1 += 0.00000060705*np.cos(5.84738219849 + 70.1157321213*t)
	X1 += 0.00000060413*np.cos(2.93879448663 + 149.6750717192*t)
	X1 += 0.00000055718*np.cos(5.10108753250 + 79.4474650133*t)
	X1 += 0.00000056673*np.cos(0.54290172829 + 73.0846775379*t)
	X1 += 0.00000053588*np.cos(0.54527702807 + 329.7251917809*t)
	X1 += 0.00000055709*np.cos(0.10599541457 + 157.6399519819*t)
	X1 += 0.00000060943*np.cos(4.04427039342 + 347.8844390456*t)
	X1 += 0.00000052263*np.cos(1.22770416736 + 147.1155165798*t)
	X1 += 0.00000054800*np.cos(4.12258527812 + 76.4785195967*t)
	X1 += 0.00000048631*np.cos(3.08750329574 + 68.1893164283*t)
	X1 += 0.00000052758*np.cos(1.71379465510 + 143.6253063014*t)
	X1 += 0.00000046174*np.cos(1.83537384705 + 7.8643065262*t)
	X1 += 0.00000056770*np.cos(1.76001621326 + 19.643719973*t)
	X1 += 0.00000043941*np.cos(4.22289924597 + 75.5323580927*t)
	X1 += 0.00000042882*np.cos(3.60953274952 + 74.0308390419*t)
	X1 += 0.00000043779*np.cos(1.34862437117 + 415.5524906121*t)
	X1 += 0.00000040257*np.cos(2.70866946307 + 154.979823106*t)
	X1 += 0.00000039553*np.cos(2.78953556992 + 258.8757464767*t)
	X1 += 0.00000041251*np.cos(1.57144664659 + 273.1028404783*t)
	X1 += 0.00000052956*np.cos(4.24304077012 + 66.9172920411*t)
	X1 += 0.00000038326*np.cos(2.63476750820 + 14.2270940016*t)
	X1 += 0.00000037480*np.cos(4.69690532605 + 81.3738807063*t)
	X1 += 0.00000036051*np.cos(4.81417494173 + 135.5485514541*t)
	X1 += 0.00000037066*np.cos(2.17708105206 + 46.470422916*t)
	X1 += 0.00000035447*np.cos(0.98545964791 + 167.7224443993*t)
	X1 += 0.00000033444*np.cos(3.72411302136 + 149.45132255*t)
	X1 += 0.00000040029*np.cos(1.96239968243 + 187.6962327724*t)
	X1 += 0.00000040824*np.cos(5.97303225818 + 340.7708920448*t)
	X1 += 0.00000037372*np.cos(0.21122306999 + 259.5088859231*t)
	X1 += 0.00000041612*np.cos(1.41361112597 + 58.1068240109*t)
	X1 += 0.00000029956*np.cos(2.57082015227 + 60.7669528868*t)
	X1 += 0.00000037429*np.cos(0.79282523594 + 73.88782669*t)
	X1 += 0.00000037429*np.cos(0.74498454647 + 75.6753704446*t)
	X1 += 0.00000031065*np.cos(1.71827695871 + 38.1330356378*t)
	X1 += 0.00000029298*np.cos(5.94882239894 + 141.6988906084*t)
	X1 += 0.00000030708*np.cos(0.24881030437 + 72.4939767069*t)
	X1 += 0.00000030708*np.cos(1.28899947804 + 77.0692204277*t)
	X1 += 0.00000028875*np.cos(0.54752160834 + 28.3111756513*t)
	X1 += 0.00000035363*np.cos(3.42227627978 + 82.6459050935*t)
	X1 += 0.00000028113*np.cos(0.90670133000 + 295.1942410061*t)
	X1 += 0.00000029459*np.cos(3.07426083488 + 120.9913890524*t)
	X1 += 0.00000026709*np.cos(4.75598916376 + 43.2890291783*t)
	X1 += 0.00000030738*np.cos(5.90774706345 + 111.4301614968*t)
	X1 += 0.00000027631*np.cos(5.95830254498 + 6.592282139*t)
	X1 += 0.00000026884*np.cos(3.04057230046 + 219.891377577*t)
	X1 += 0.00000033927*np.cos(6.02713258404 + 171.6545976624*t)
	X1 += 0.00000031094*np.cos(2.39334686272 + 98.3574718034*t)
	X1 += 0.00000023975*np.cos(5.91677137117 + 218.9281697305*t)
	X1 += 0.00000031513*np.cos(3.08220495699 + 221.3758502853*t)
	X1 += 0.00000026064*np.cos(6.25963849838 + 472.1748419147*t)
	X1 += 0.00000023869*np.cos(0.00423630284 + 57.255490749*t)
	X1 += 0.00000023509*np.cos(2.61626799404 + 47.6942631934*t)
	X1 += 0.00000026035*np.cos(0.51844176177 + 91.4563731237*t)
	X1 += 0.00000024834*np.cos(2.68780869865 + 25.2727942655*t)
	X1 += 0.00000029098*np.cos(2.94097567270 + 184.7272873558*t)
	X1 += 0.00000023343*np.cos(4.42888199279 + 61.448276443*t)
	X1 += 0.00000022926*np.cos(1.30160852920 + 233.9060232575*t)
	X1 += 0.00000023216*np.cos(4.09428674912 + 543.0242872189*t)
	X1 += 0.00000022142*np.cos(5.64414938832 + 103.0927742186*t)
	X1 += 0.00000021446*np.cos(3.17224618831 + 106.2741679563*t)
	X1 += 0.00000021268*np.cos(2.97922212711 + 554.0699874828*t)
	X1 += 0.00000024907*np.cos(5.76718730053 + 486.4019359163*t)
	X1 += 0.00000021433*np.cos(4.64123618296 + 19.1224551112*t)
	X1 += 0.00000020924*np.cos(2.76614931958 + 269.9214467406*t)
	X1 += 0.00000020909*np.cos(3.85974203870 + 67.3592350258*t)
	X1 += 0.00000022980*np.cos(4.90937541667 + 254.9435932136*t)
	X1 += 0.00000020201*np.cos(2.12417844647 + 468.2426886516*t)
	X1 += 0.00000020847*np.cos(4.81409904565 + 7.4223635415*t)
	X1 += 0.00000019458*np.cos(4.76792603924 + 98.8999885246*t)
	X1 += 0.00000022487*np.cos(0.48938180181 + 217.2312487011*t)
	X1 += 0.00000019604*np.cos(2.45797310689 + 17.2654753874*t)
	X1 += 0.00000018374*np.cos(3.12972828948 + 88.1149206916*t)
	X1 += 0.00000018710*np.cos(2.07002102692 + 69.6737891366*t)
	X1 += 0.00000024970*np.cos(6.04865694767 + 35.1640902212*t)
	X1 += 0.00000018185*np.cos(1.53549222688 + 92.3077063856*t)
	X1 += 0.00000020526*np.cos(3.55883475114 + 115.8835796217*t)
	X1 += 0.00000017318*np.cos(3.58183814043 + 100.3844612329*t)
	X1 += 0.00000019680*np.cos(0.37692395289 + 296.1574488526*t)
	X1 += 0.00000016772*np.cos(0.69703195542 + 210.3301500214*t)
	X1 += 0.00000017082*np.cos(5.75097380140 + 79.889407998*t)
	X1 += 0.00000016920*np.cos(5.76277101216 + 67.8804998876*t)
	X1 += 0.00000016712*np.cos(1.22647704720 + 55.6591434561*t)
	X1 += 0.00000017764*np.cos(2.75549341652 + 105.4922706636*t)
	X1 += 0.00000017983*np.cos(3.23076091926 + 151.260118164*t)
	X1 += 0.00000018460*np.cos(3.11251197292 + 35.4247226521*t)
	X1 += 0.00000017967*np.cos(3.88222144853 + 181.7583419392*t)
	X1 += 0.00000016331*np.cos(3.65716262733 + 94.4253185403*t)
	X1 += 0.00000016285*np.cos(5.57732210648 + 24.1183899573*t)
	X1 += 0.00000016506*np.cos(3.12748016927 + 76.42612997*t)
	X1 += 0.00000016506*np.cos(4.69351492032 + 73.1370671646*t)
	X1 += 0.00000015826*np.cos(3.12499527551 + 13.4933808187*t)
	X1 += 0.00000017227*np.cos(0.29402089847 + 13.3333221243*t)
	X1 += 0.00000017819*np.cos(0.27595854333 + 221.1634019642*t)
	X1 += 0.00000021162*np.cos(1.87088890253 + 372.4235201282*t)
	X1 += 0.00000016749*np.cos(1.45888449067 + 284.1485407422*t)
	X1 += 0.00000019283*np.cos(1.10096678754 + 479.2883889155*t)
	X1 += 0.00000018795*np.cos(0.86065812508 + 60.5545045657*t)
	X1 += 0.00000015261*np.cos(4.52180709793 + 397.3932433474*t)
	X1 += 0.00000019020*np.cos(0.80787178507 + 227.5261894396*t)
	X1 += 0.00000016556*np.cos(5.58514879053 + 198.321241911*t)
	X1 += 0.00000014970*np.cos(3.72163026622 + 30.0562807905*t)
	X1 += 0.00000015636*np.cos(3.32592798239 + 173.9422195228*t)
	X1 += 0.00000014561*np.cos(3.11384969661 + 50.66320861*t)
	X1 += 0.00000015544*np.cos(4.96423459329 + 58.319272332*t)
	X1 += 0.00000014998*np.cos(0.09396760027 + 200.7689224658*t)
	X1 += 0.00000014725*np.cos(5.12312966582 + 135.336103133*t)
	X1 += 0.00000017061*np.cos(0.93145915427 + 184.0941479094*t)
	X1 += 0.00000014873*np.cos(3.56846085608 + 30.7106720963*t)
	X1 += 0.00000015380*np.cos(0.45042165283 + 16.4623262353*t)
	X1 += 0.00000014306*np.cos(2.43060361636 + 310.1720945331*t)
	X1 += 0.00000017345*np.cos(5.49233484735 + 260.9933586314*t)
	X1 += 0.00000013683*np.cos(3.92221116342 + 82.2039621088*t)
	X1 += 0.00000015207*np.cos(3.34962343405 + 411.620337349*t)
	X1 += 0.00000013968*np.cos(2.61772955404 + 61.2882177486*t)
	X1 += 0.00000013099*np.cos(2.01417422899 + 286.596221297*t)
	X1 += 0.00000013681*np.cos(4.97929425746 + 44.070926471*t)
	X1 += 0.00000013283*np.cos(2.82191824384 + 6.9010986797*t)
	X1 += 0.00000012983*np.cos(0.75249502704 + 173.6815870919*t)
	X1 += 0.00000016262*np.cos(1.99912523467 + 64.4866578288*t)
	X1 += 0.00000012734*np.cos(1.70208913039 + 74.2603337055*t)
	X1 += 0.00000012734*np.cos(2.97731330561 + 75.3028634291*t)
	X1 += 0.00000012701*np.cos(1.71027963895 + 57.5161231799*t)
	X1 += 0.00000017442*np.cos(2.80800083816 + 760.25553592*t)
	X1 += 0.00000015036*np.cos(1.86765123574 + 132.8884225782*t)
	X1 += 0.00000012678*np.cos(5.21255769594 + 81.682697247*t)
	X1 += 0.00000012959*np.cos(0.93518082353 + 133.1008708993*t)
	X1 += 0.00000012526*np.cos(3.61958368638 + 351.8165923087*t)
	X1 += 0.00000012872*np.cos(3.95804014267 + 46.2097904851*t)
	X1 += 0.00000011855*np.cos(2.97019730282 + 267.4737661858*t)
	X1 += 0.00000014155*np.cos(2.86543106920 + 155.7829722581*t)
	X1 += 0.00000011443*np.cos(1.78051620224 + 32.2433289144*t)
	X1 += 0.00000012080*np.cos(5.16415823774 + 74.1272072615*t)
	X1 += 0.00000012080*np.cos(2.65683685185 + 75.4359898731*t)
	X1 += 0.00000011303*np.cos(0.93310421002 + 31.492569389*t)
	X1 += 0.00000013533*np.cos(5.82192605708 + 85.0765393058*t)
	X1 += 0.00000010738*np.cos(0.24602380813 + 93.9040536785*t)
	X1 += 0.00000010787*np.cos(6.01142464319 + 189.7232222019*t)
	X1 += 0.00000013828*np.cos(5.36493508915 + 31.6526280834*t)
	X1 += 0.00000013824*np.cos(4.23707962346 + 26.0235537909*t)
	X1 += 0.00000010459*np.cos(5.12191321154 + 144.8973306886*t)
	X1 += 0.00000010910*np.cos(2.91004182482 + 142.1408335931*t)
	X1 += 0.00000010123*np.cos(5.18571320702 + 236.8749686741*t)
	X1 += 0.00000011542*np.cos(4.18988776185 + 42.5382696529*t)
	X1 += 0.00000010460*np.cos(4.81590103862 + 692.5874843535*t)
	X1 += 0.00000013204*np.cos(3.50824637161 + 123.5396433437*t)
	X1 += 0.00000009836*np.cos(5.95244492576 + 681.5417840896*t)
	X1 += 0.00000009778*np.cos(5.72836796284 + 43.1289704839*t)
	X1 += 0.00000010652*np.cos(5.07486942549 + 124.2904028691*t)
	X1 += 0.00000010953*np.cos(0.56341673987 + 89.0086925689*t)
	X1 += 0.00000009978*np.cos(3.97784657700 + 214.7835681463*t)
	X1 += 0.00000009832*np.cos(2.83131988231 + 54.3347294422*t)
	X1 += 0.00000009739*np.cos(5.28158188664 + 73.1852512744*t)
	X1 += 0.00000009739*np.cos(5.68100585654 + 76.3779458602*t)
	X1 += 0.00000009297*np.cos(3.79217857949 + 203.7378678824*t)
	X1 += 0.00000011679*np.cos(1.33060128320 + 48.7580447764*t)
	X1 += 0.00000009552*np.cos(1.19132306969 + 156.1554792736*t)
	X1 += 0.00000008972*np.cos(0.10072096939 + 27.0873353739*t)
	X1 += 0.00000011401*np.cos(1.59445531296 + 264.5048207692*t)
	X1 += 0.00000009556*np.cos(4.94813324338 + 196.6243208816*t)
	X1 += 0.00000008931*np.cos(1.75464198962 + 117.9105690512*t)
	X1 += 0.00000009144*np.cos(4.96253120483 + 44.7253177768*t)
	X1 += 0.00000010751*np.cos(1.19819066544 + 624.919432787*t)
	X1 += 0.00000010035*np.cos(3.29686320022 + 448.6895914038*t)
	X1 += 0.00000008947*np.cos(0.49097448474 + 141.4864422873*t)
	X1 += 0.00000008492*np.cos(1.04669089016 + 103.9865460959*t)
	X1 += 0.00000008396*np.cos(1.85274078285 + 610.6923387854*t)
	X1 += 0.00000008844*np.cos(5.13691622390 + 88.274979386*t)
	X1 += 0.00000008524*np.cos(4.93963929817 + 17.5261078183*t)
	X1 += 0.00000008157*np.cos(1.41280346613 + 163.5778428151*t)
	X1 += 0.00000009170*np.cos(0.18882338324 + 685.4739373527*t)
	X1 += 0.00000009000*np.cos(4.32410050104 + 210.8514148832*t)
	X1 += 0.00000008372*np.cos(4.15532894311 + 218.4069048687*t)
	X1 += 0.00000008521*np.cos(1.30623024759 + 155.5010879678*t)
	X1 += 0.00000009137*np.cos(2.66521611116 + 617.8058857862*t)
	X1 += 0.00000007785*np.cos(1.91600387357 + 177.8743727859*t)
	X1 += 0.00000009949*np.cos(6.00066057789 + 129.9194771616*t)
	X1 += 0.00000007808*np.cos(3.50087426378 + 47.061123747*t)
	X1 += 0.00000007420*np.cos(3.41076837074 + 130.4407420234*t)
	X1 += 0.00000007378*np.cos(5.84270209088 + 109.3125493421*t)
	X1 += 0.00000007443*np.cos(5.63786026620 + 175.1660598002*t)
	X1 += 0.00000008741*np.cos(4.78640084032 + 58.7399634573*t)
	X1 += 0.00000008402*np.cos(1.60812206860 + 79.5169009825*t)
	X1 += 0.00000008402*np.cos(6.21287302099 + 70.0462961521*t)
	X1 += 0.00000008695*np.cos(3.86773796124 + 193.655375465*t)
	X1 += 0.00000007159*np.cos(3.97508715690 + 606.7601855223*t)
	X1 += 0.00000006973*np.cos(2.38105652541 + 162.8965192589*t)
	X1 += 0.00000008045*np.cos(2.56499806459 + 40.1600250673*t)
	X1 += 0.00000006997*np.cos(4.11367019220 + 119.5069163441*t)
	X1 += 0.00000006780*np.cos(0.88290624842 + 71.1582618449*t)
	X1 += 0.00000006780*np.cos(0.65490353399 + 78.4049352897*t)
	X1 += 0.00000006651*np.cos(3.56933431950 + 107.4980082337*t)
	X1 += 0.00000008439*np.cos(2.97298949766 + 180.1619946463*t)
	X1 += 0.00000007040*np.cos(0.16766290094 + 393.4610900843*t)
	X1 += 0.00000008809*np.cos(4.60479111456 + 114.9416236346*t)
	X1 += 0.00000007093*np.cos(2.52722254009 + 118.8737768977*t)
	X1 += 0.00000006803*np.cos(4.98967084497 + 95.2284676924*t)
	X1 += 0.00000008202*np.cos(1.70137039976 + 192.6921676185*t)
	X1 += 0.00000006537*np.cos(2.99785157074 + 362.8622925726*t)
	X1 += 0.00000006391*np.cos(5.70439630334 + 49.7212526229*t)
	X1 += 0.00000006895*np.cos(1.17290291521 + 532.8723588323*t)
	X1 += 0.00000006512*np.cos(5.96135741097 + 97.4155158163*t)
	X1 += 0.00000006577*np.cos(0.62857724014 + 426.598190876*t)
	X1 += 0.00000006196*np.cos(3.54421587297 + 381.0909758065*t)
	X1 += 0.00000006196*np.cos(5.54176074629 + 528.7277572481*t)
	X1 += 0.00000007620*np.cos(3.73538335649 + 55.1378785943*t)
	X1 += 0.00000006877*np.cos(3.44957142724 + 207.8824694666*t)
	X1 += 0.00000006080*np.cos(5.07669365981 + 530.6541729411*t)
	X1 += 0.00000006080*np.cos(4.00928242865 + 379.1645601135*t)
	X1 += 0.00000006022*np.cos(1.31297053546 + 105.380396079*t)
	X1 += 0.00000006631*np.cos(3.99124846968 + 34.5309507748*t)
	X1 += 0.00000006319*np.cos(3.57711620849 + 143.3434220111*t)
	X1 += 0.00000006650*np.cos(4.28063379650 + 454.9093665273*t)
	X1 += 0.00000006837*np.cos(6.06157563262 + 375.3924655448*t)
	X1 += 0.00000005881*np.cos(4.60273440786 + 405.9912630565*t)
	X1 += 0.00000005969*np.cos(0.03112902827 + 535.9107402181*t)
	X1 += 0.00000005863*np.cos(5.60462702771 + 107.918699359*t)
	X1 += 0.00000006744*np.cos(1.08073706710 + 27.7204748203*t)
	X1 += 0.00000006308*np.cos(0.34505692022 + 831.1049812242*t)
	X1 += 0.00000005516*np.cos(2.08339680294 + 232.4215505492*t)
	X1 += 0.00000005840*np.cos(4.74275994750 + 29.226199388*t)
	X1 += 0.00000005532*np.cos(0.31891843882 + 164.5410506616*t)
	X1 += 0.00000006345*np.cos(2.71755172801 + 91.2439248026*t)
	X1 += 0.00000005822*np.cos(4.31260736618 + 301.4140161296*t)
	X1 += 0.00000005587*np.cos(5.40846346381 + 125.1841747464*t)
	X1 += 0.00000006604*np.cos(3.03527526051 + 90.8232336773*t)
	X1 += 0.00000005425*np.cos(0.16380669642 + 76.154196691*t)
	X1 += 0.00000005425*np.cos(4.51559573958 + 73.4090004436*t)
	X1 += 0.00000005757*np.cos(2.28671638418 + 408.4389436113*t)
	X1 += 0.00000005414*np.cos(0.23481115779 + 16.04163511*t)
	X1 += 0.00000005498*np.cos(5.01400832025 + 142.6620984549*t)
	X1 += 0.00000006300*np.cos(5.07868286422 + 550.1378342197*t)
	X1 += 0.00000005252*np.cos(4.37461363945 + 49.1787359017*t)
	X1 += 0.00000005259*np.cos(5.53089870357 + 31.2319369581*t)
	X1 += 0.00000005177*np.cos(2.42408915707 + 34.62157350*t)
	X1 += 0.00000005117*np.cos(4.27503491473 + 114.1384744825*t)
	X1 += 0.00000004984*np.cos(0.86380095341 + 312.4597163935*t)
	X1 += 0.00000006222*np.cos(1.16391286215 + 336.8387387817*t)
	X1 += 0.00000005039*np.cos(0.49473492002 + 22.633917249*t)
	X1 += 0.00000005371*np.cos(2.46932051435 + 293.7097682978*t)
	X1 += 0.00000005874*np.cos(0.96815943251 + 406.1031376411*t)
	X1 += 0.00000005033*np.cos(2.55869165354 + 234.4967240885*t)
	X1 += 0.00000005168*np.cos(2.97658265378 + 147.8662761052*t)
	X1 += 0.00000006514*np.cos(2.35520859919 + 302.0953396858*t)
	X1 += 0.00000004810*np.cos(0.69226746482 + 59.2824801785*t)
	X1 += 0.00000004541*np.cos(4.53731690208 + 92.0470739547*t)
	X1 += 0.00000004506*np.cos(4.68118426392 + 100.0543928328*t)
	X1 += 0.00000004623*np.cos(6.18668496930 + 344.7030453079*t)
	X1 += 0.00000005577*np.cos(5.54543388365 + 237.6781178262*t)
	X1 += 0.00000005453*np.cos(4.06894870256 + 232.0490435337*t)
	X1 += 0.00000004872*np.cos(4.69587056338 + 35.685355083*t)
	X1 += 0.00000004545*np.cos(1.88214672059 + 52.1476813183*t)
	X1 += 0.00000005548*np.cos(3.25810309156 + 403.0223176399*t)
	X1 += 0.00000004290*np.cos(3.91220944048 + 257.3912737684*t)
	X1 += 0.00000004254*np.cos(1.62798817507 + 328.2407190726*t)
	X1 += 0.00000004307*np.cos(4.56309542115 + 122.4758617607*t)
	X1 += 0.00000004254*np.cos(3.62114251757 + 749.2098356561*t)
	X1 += 0.00000004870*np.cos(2.38371018423 + 216.4804891757*t)
	X1 += 0.00000004193*np.cos(3.82664074676 + 756.3233826569*t)
	X1 += 0.00000004196*np.cos(3.75281529760 + 221.8971151471*t)
	X1 += 0.00000004188*np.cos(5.43602058182 + 450.9772132642*t)
	X1 += 0.00000004590*np.cos(2.50743217001 + 767.3690829208*t)
	X1 += 0.00000004383*np.cos(3.97195747597 + 103.3534066495*t)
	X1 += 0.00000005092*np.cos(1.83697233633 + 376.9463742223*t)
	X1 += 0.00000004132*np.cos(1.46552725443 + 518.6452648307*t)
	X1 += 0.00000004221*np.cos(5.71365076183 + 40.5807161926*t)
	X1 += 0.00000004161*np.cos(3.08173290170 + 43.5496616092*t)
	X1 += 0.00000004217*np.cos(1.51515332931 + 124.5028511902*t)
	X1 += 0.00000004570*np.cos(0.27475223192 + 335.1418177523*t)
	X1 += 0.00000004424*np.cos(5.04632900852 + 101.8689339412*t)
	X1 += 0.00000004462*np.cos(4.10707023296 + 166.828672522*t)
	X1 += 0.00000005595*np.cos(2.82323309803 + 322.6116447801*t)
	X1 += 0.00000004318*np.cos(2.35206886311 + 422.6660376129*t)
	X1 += 0.00000004209*np.cos(2.59829196504 + 271.61836777*t)
	X1 += 0.00000004223*np.cos(5.84608335181 + 332.1728723357*t)
	X1 += 0.00000004130*np.cos(5.90033316568 + 380.12776796*t)
	X1 += 0.00000005655*np.cos(0.58180438062 + 44.0921783304*t)
	X1 += 0.00000004345*np.cos(4.06258042881 + 49.6518166537*t)
	X1 += 0.00000004767*np.cos(4.96873316993 + 280.9671470045*t)
	X1 += 0.00000005029*np.cos(0.85996015450 + 189.1807054807*t)
	X1 += 0.00000005167*np.cos(3.49590720572 + 107.0249274817*t)
	X1 += 0.00000004072*np.cos(0.90732377696 + 319.5732633943*t)
	X1 += 0.00000004979*np.cos(1.20868922303 + 913.7508863177*t)
	X1 += 0.00000004154*np.cos(1.32035665964 + 170.1701249541*t)
	X1 += 0.00000004195*np.cos(5.10670456809 + 383.3091616977*t)
	X1 += 0.00000004651*np.cos(5.36764353188 + 827.9235874865*t)
	X1 += 0.00000004391*np.cos(5.26620078093 + 449.2802922348*t)
	X1 += 0.00000004251*np.cos(0.17351063134 + 248.7238180901*t)
	X1 += 0.00000004303*np.cos(2.59827089280 + 339.2864193365*t)
	X1 += 0.00000005421*np.cos(2.42482990878 + 49.5088043018*t)
	X1 += 0.00000004372*np.cos(5.90210524291 + 595.8745439528*t)
	X1 += 0.00000004319*np.cos(5.38446577684 + 610.1016379544*t)
	X1 += 0.00000003871*np.cos(1.71107021316 + 195.7729876197*t)
	X1 += 0.00000004570*np.cos(5.48308136143 + 25.0603459444*t)
	X1 += 0.00000004417*np.cos(3.95107732707 + 302.3772239761*t)
	X1 += 0.00000004053*np.cos(5.74857415364 + 121.8427223143*t)
	X1 += 0.00000004480*np.cos(5.83144216082 + 30.5987975117*t)
	X1 += 0.00000004503*np.cos(5.54195257014 + 223.4510238246*t)
	X1 += 0.00000003991*np.cos(1.28311117198 + 226.7924762567*t)
	X1 += 0.00000003925*np.cos(4.97969700029 + 136.0698163159*t)
	X1 += 0.00000004783*np.cos(2.94910756347 + 763.4369296577*t)
	X1 += 0.00000004002*np.cos(3.56106680884 + 1887.3055176757*t)
	X1 += 0.00000003686*np.cos(5.81711299556 + 117.3198682202*t)
	X1 += 0.00000003692*np.cos(1.41758603082 + 219.5188705615*t)
	X1 += 0.00000003641*np.cos(1.43628154308 + 820.0592809603*t)
	X1 += 0.00000003829*np.cos(2.80943361629 + 331.2096644892*t)
	X1 += 0.00000004228*np.cos(6.06023136808 + 349.3689117539*t)
	X1 += 0.00000004291*np.cos(4.80060249860 + 463.5073862364*t)
	X1 += 0.00000004508*np.cos(1.23637888737 + 275.5505210331*t)
	X1 += 0.00000003813*np.cos(0.29413995146 + 457.8783119439*t)
	X1 += 0.00000004520*np.cos(2.66865635036 + 21.1976286505*t)
	X1 += 0.00000004808*np.cos(5.17813277461 + 842.1506814881*t)
	X1 += 0.00000003594*np.cos(2.39944522659 + 757.8078553652*t)
	X1 += 0.00000004076*np.cos(1.44622169070 + 487.8864086246*t)
	X1 += 0.00000003617*np.cos(2.10676407474 + 310.9752436852*t)
	X1 += 0.00000003497*np.cos(0.21989673558 + 39.0962434843*t)
	X1 += 0.00000004073*np.cos(2.34392479937 + 303.8616966844*t)
	X1 += 0.00000003713*np.cos(4.67119374021 + 906.849787638*t)
	X1 += 0.00000004431*np.cos(1.66761109039 + 180.2738692309*t)
	X1 += 0.00000003556*np.cos(3.06018698393 + 501.3797894433*t)
	X1 += 0.00000003866*np.cos(0.39317068403 + 511.5317178299*t)
	X1 += 0.00000003594*np.cos(0.32134026487 + 705.1176573257*t)
	X1 += 0.00000003846*np.cos(6.01710266339 + 253.4591205053*t)
	X1 += 0.00000003788*np.cos(0.87966092565 + 909.8187330546*t)
	X1 += 0.00000003919*np.cos(2.25929240862 + 204.7010757289*t)
	X1 += 0.00000004009*np.cos(2.40455671219 + 1512.8068240082*t)
	X1 += 0.00000003398*np.cos(2.96372505035 + 547.8502123593*t)
	X1 += 0.00000003348*np.cos(1.29908274068 + 672.1406152284*t)
	X1 += 0.00000003556*np.cos(3.61703502565 + 1368.660252845*t)
	X1 += 0.00000003799*np.cos(4.51126065072 + 328.3525936572*t)
	X1 += 0.00000004017*np.cos(1.13962547504 + 442.7517005706*t)
	X1 += 0.00000003347*np.cos(5.43291318939 + 10021.8372800994*t)
	X1 += 0.00000003338*np.cos(2.31470330186 + 89.9719004154*t)
	X1 += 0.00000003390*np.cos(2.85111866429 + 1050.7839104801*t)
	X1 += 0.00000003929*np.cos(0.50815651093 + 1317.5069171405*t)
	X1 += 0.00000003279*np.cos(6.13069875648 + 260.360219185*t)
	X1 += 0.00000003275*np.cos(3.69539670729 + 184.9879197867*t)
	X1 += 0.00000003635*np.cos(5.93838955300 + 342.2553647531*t)
	X1 += 0.00000003470*np.cos(4.38416040172 + 1067.9799498983*t)
	X1 += 0.00000003246*np.cos(4.22018785464 + 30.6894202369*t)
	X1 += 0.00000004053*np.cos(0.36617667414 + 229.0800981171*t)
	X1 += 0.00000004276*np.cos(3.60421025224 + 526.5095713569*t)
	X1 += 0.00000003189*np.cos(1.16801935319 + 374.7111419886*t)
	X1 += 0.00000003414*np.cos(3.86440731923 + 25.6028626656*t)
	X1 += 0.00000003217*np.cos(0.12820891378 + 34.2008823747*t)
	X1 += 0.00000003560*np.cos(2.60404464111 + 781.5961769224*t)
	X1 += 0.00000003415*np.cos(2.81637195671 + 630.3360587584*t)
	X1 += 0.00000003360*np.cos(0.15525313851 + 370.0452755426*t)
	X1 += 0.00000003190*np.cos(4.54846044482 + 555.5544601911*t)
	X1 += 0.00000003942*np.cos(1.29262318233 + 728.762966531*t)
	X1 += 0.00000003249*np.cos(2.10483095182 + 683.9894646444*t)
	X1 += 0.00000003292*np.cos(1.11690233393 + 2424.1100297711*t)
	X1 += 0.00000004018*np.cos(4.06464228328 + 758.7710632117*t)
	X1 += 0.00000003393*np.cos(1.72164643720 + 291.1190753911*t)
	X1 += 0.00000003177*np.cos(0.19535441493 + 194.2885149114*t)
	X1 += 0.00000003163*np.cos(0.64155462640 + 348.8476468921*t)
	X1 += 0.00000003506*np.cos(1.64839531939 + 51.8870488874*t)
	X1 += 0.00000003400*np.cos(4.67887517916 + 995.6460318858*t)
	X1 += 0.00000003647*np.cos(5.40830199356 + 290.2195580194*t)
	X1 += 0.00000003048*np.cos(1.14769098014 + 1303.2798231389*t)
	X1 += 0.00000004227*np.cos(1.64069494312 + 480.7728616238*t)
	X1 += 0.00000003533*np.cos(0.57957961089 + 332.8060117821*t)
	X1 += 0.00000003015*np.cos(3.89417585654 + 1053.7528558967*t)
	X1 += 0.00000004080*np.cos(0.80320966998 + 470.6903692064*t)
	X1 += 0.00000003255*np.cos(3.12460739752 + 113.8778420516*t)
	X1 += 0.00000003737*np.cos(0.36607689746 + 5983.9494557222*t)
	X1 += 0.00000004072*np.cos(3.51391687030 + 402.2191684878*t)
	X1 += 0.00000003302*np.cos(1.28184038619 + 532.1386456494*t)
	X1 += 0.00000004089*np.cos(5.55409021925 + 1264.816719101*t)
	X1 += 0.00000002960*np.cos(1.72708071261 + 15.4991183888*t)
	X1 += 0.00000002903*np.cos(4.79566936964 + 525.7588118315*t)
	X1 += 0.00000003638*np.cos(0.63261201547 + 601.5036182453*t)
	X1 += 0.00000002872*np.cos(4.41744820869 + 384.0599212231*t)
	X1 += 0.00000002873*np.cos(4.16082568297 + 192.8040422031*t)
	X1 += 0.00000003359*np.cos(4.95035468643 + 228.7982138268*t)
	X1 += 0.00000003034*np.cos(3.89748087769 + 696.5196376166*t)
	X1 += 0.00000002831*np.cos(4.73243294784 + 106.0135355254*t)
	X1 += 0.00000002904*np.cos(4.01411287559 + 90.2807169561*t)
	X1 += 0.00000002802*np.cos(1.37429211436 + 674.4282370888*t)
	X1 += 0.00000003004*np.cos(2.54822841274 + 522.5774180938*t)
	X1 += 0.00000002786*np.cos(2.73392004399 + 594.9113361063*t)
	X1 += 0.00000002784*np.cos(1.57292650857 + 531.978586955*t)
	X1 += 0.00000003407*np.cos(5.90631625650 + 293.188503436*t)
	X1 += 0.00000003627*np.cos(3.21932712073 + 156.6767441354*t)
	X1 += 0.00000003773*np.cos(4.08447014502 + 358.0363674322*t)
	X1 += 0.00000003186*np.cos(4.09159297487 + 1440.9941708575*t)
	X1 += 0.00000002758*np.cos(1.23813964293 + 280.2163874791*t)
	X1 += 0.00000003504*np.cos(1.78948704996 + 9914.1591519418*t)
	X1 += 0.00000003472*np.cos(2.67146862670 + 296.7481496836*t)
	X1 += 0.00000003442*np.cos(3.60665744056 + 689.4060906158*t)
	X1 += 0.00000002947*np.cos(5.46192054865 + 818.574808252*t)
	X1 += 0.00000003345*np.cos(2.10061200490 + 1598.474064145*t)
	X1 += 0.00000002830*np.cos(1.34921944342 + 121.2520214833*t)
	X1 += 0.00000002757*np.cos(3.23219311957 + 417.0369633204*t)
	X1 += 0.00000003390*np.cos(4.67266294758 + 1471.0022675382*t)
	X1 += 0.00000002855*np.cos(5.71772374100 + 48.9181034708*t)
	X1 += 0.00000002740*np.cos(5.58500315091 + 395.9087706391*t)
	X1 += 0.00000002998*np.cos(5.17106934197 + 432.8179659995*t)
	X1 += 0.00000002900*np.cos(1.82862476718 + 298.2326223919*t)
	X1 += 0.00000003474*np.cos(5.73771635165 + 1065.6017053127*t)
	X1 += 0.00000003348*np.cos(2.15893228485 + 969.6224780949*t)
	X1 += 0.00000002777*np.cos(3.99928366015 + 32.7164096664*t)
	X1 += 0.00000002898*np.cos(6.21680044789 + 100.8051523582*t)
	X1 += 0.00000003716*np.cos(2.25787808273 + 668.2084619653*t)
	X1 += 0.00000003001*np.cos(3.17957379483 + 215.4379594521*t)
	X1 += 0.00000002786*np.cos(5.73888329772 + 350.3321196004*t)
	X1 += 0.00000002748*np.cos(3.42529326270 + 1065.0110044817*t)
	X1 += 0.00000002951*np.cos(4.98034050783 + 255.8373650909*t)
	X1 += 0.00000002808*np.cos(3.92417119747 + 104.0077979553*t)
	X1 += 0.00000003108*np.cos(6.28115439587 + 626.4039054953*t)
	X1 += 0.00000002648*np.cos(5.64217999071 + 745.277682393*t)
	X1 += 0.00000002693*np.cos(0.64719337286 + 12491.3701014155*t)
	X1 += 0.00000003649*np.cos(4.93104386608 + 469.7271613599*t)
	X1 += 0.00000002881*np.cos(3.68590589176 + 369.9758395734*t)
	X1 += 0.00000002719*np.cos(2.97795482524 + 188.0263011725*t)
	X1 += 0.00000002837*np.cos(0.47528515487 + 484.917463208*t)
	X1 += 0.00000003591*np.cos(0.47810594324 + 1062.3508756058*t)
	X1 += 0.00000002768*np.cos(6.23503099225 + 384.5811860849*t)
	X1 += 0.00000003124*np.cos(5.91112116900 + 384.2723695442*t)
	X1 += 0.00000002896*np.cos(1.09307446307 + 632.0329797878*t)
	X1 += 0.00000002876*np.cos(2.89367499074 + 6058.7310542895*t)
	X1 += 0.00000002580*np.cos(3.84884795844 + 461.1291416508*t)
	X1 += 0.00000002805*np.cos(2.02060190838 + 2111.6503133776*t)
	X1 += 0.00000002562*np.cos(6.21096468054 + 657.1627617014*t)
	X1 += 0.00000002741*np.cos(5.92551190768 + 548.4409131903*t)
	X1 += 0.00000002864*np.cos(2.93732003045 + 637.4496057592*t)
	X1 += 0.00000002511*np.cos(2.72212219874 + 1258.4539316256*t)
	X1 += 0.00000002606*np.cos(4.16927672027 + 390.2102603774*t)
	X1 += 0.00000002522*np.cos(4.54786028172 + 115.3623147599*t)
	X1 += 0.00000002644*np.cos(6.03426038864 + 525.2375469697*t)
	X1 += 0.00000003075*np.cos(2.01414173991 + 980.6681783588*t)
	X1 += 0.00000002907*np.cos(2.53866072765 + 620.253566341*t)
	X1 += 0.00000002493*np.cos(1.94336313048 + 916.9322800554*t)
	X1 += 0.00000002474*np.cos(4.49620359206 + 699.7010313543*t)
	X1 += 0.00000002890*np.cos(3.31566105811 + 361.3778198643*t)
	X1 += 0.00000002663*np.cos(1.46195985219 + 591.9423906897*t)
	X1 += 0.00000002497*np.cos(1.78580918376 + 628.8515860501*t)
	X1 += 0.00000003001*np.cos(3.83591213005 + 1812.5239191084*t)
	X1 += 0.00000003222*np.cos(0.65043581113 + 420.9691165835*t)
	X1 += 0.00000002497*np.cos(2.08712349497 + 108.982480942*t)
	X1 += 0.00000002811*np.cos(1.62447795577 + 604.4725636619*t)
	X1 += 0.00000003182*np.cos(2.56721794097 + 256.4280659219*t)
	X1 += 0.00000002714*np.cos(0.34980714047 + 833.552661779*t)
	X1 += 0.00000002442*np.cos(0.23526085974 + 765.8846102125*t)
	X1 += 0.00000003142*np.cos(4.57297454509 + 436.7501192626*t)
	X1 += 0.00000002680*np.cos(4.31504164134 + 9988.9407505091*t)
	X1 += 0.00000002529*np.cos(2.60083470938 + 2498.8916283384*t)
	X1 += 0.00000002610*np.cos(0.08192500265 + 159.7151255212*t)
	X1 += 0.00000002590*np.cos(3.99630297144 + 391.1734682239*t)
	X1 += 0.00000002409*np.cos(5.18535928834 + 1228.4982245716*t)
	X1 += 0.00000002438*np.cos(5.72336756326 + 894.8408795276*t)
	X1 += 0.00000002850*np.cos(0.83031157343 + 947.5310775671*t)
	X1 += 0.00000002657*np.cos(3.45458545922 + 623.2225117576*t)
	X1 += 0.00000002353*np.cos(5.45605657739 + 74.5691502462*t)
	X1 += 0.00000002353*np.cos(5.50653116579 + 74.9940468884*t)
	X1 += 0.00000002792*np.cos(4.78307547656 + 1288.4620283063*t)
	X1 += 0.00000003121*np.cos(2.37991695182 + 609.2078660771*t)
	X1 += 0.00000002677*np.cos(2.36907350580 + 241.6102710893*t)
	X1 += 0.00000002390*np.cos(1.94030205457 + 843.6351541964*t)
	X1 += 0.00000002596*np.cos(1.91979793854 + 595.7144852584*t)
	X1 += 0.00000002308*np.cos(0.01956189175 + 369.0820676961*t)
	X1 += 0.00000002976*np.cos(4.98106512922 + 80.4106728598*t)
	X1 += 0.00000002378*np.cos(2.81529995511 + 223.3815878554*t)
	X1 += 0.00000002292*np.cos(4.26962421467 + 546.956440482*t)
	X1 += 0.00000003185*np.cos(1.62941934430 + 582.3811631341*t)
	X1 += 0.00000002664*np.cos(5.08255284594 + 761.7400086283*t)
	X1 += 0.00000002676*np.cos(2.05300313239 + 409.9234163196*t)
	X1 += 0.00000002562*np.cos(0.42035638498 + 450.4559484024*t)
	X1 += 0.00000002320*np.cos(1.17670422596 + 246.9787129509*t)
	X1 += 0.00000002416*np.cos(3.72195483988 + 612.1768114937*t)
	X1 += 0.00000002997*np.cos(1.26526670860 + 370.5665404044*t)
	X1 += 0.00000002330*np.cos(6.08434326856 + 846.0828347512*t)
	X1 += 0.00000002420*np.cos(3.12157994295 + 252.6559713532*t)
	X1 += 0.00000002679*np.cos(1.61397900182 + 1336.4169239306*t)
	X1 += 0.00000002893*np.cos(0.56010064090 + 439.782755154*t)
	X1 += 0.00000002718*np.cos(1.31145316870 + 479.4002635001*t)
	X1 += 0.00000002612*np.cos(0.99380221309 + 3116.2676309979*t)
	X1 += 0.00000002223*np.cos(1.90165447185 + 53.5839699168*t)
	X1 += 0.00000002352*np.cos(1.36626479610 + 1239.5439248355*t)
	X1 += 0.00000002224*np.cos(3.45165547622 + 531.1754378029*t)
	X1 += 0.00000002318*np.cos(1.71497343084 + 536.8045120954*t)
	X1 += 0.00000002418*np.cos(5.06040722485 + 346.3999663373*t)
	X1 += 0.00000002255*np.cos(5.81999066695 + 451.9404211107*t)
	X1 += 0.00000002241*np.cos(2.22997211668 + 6144.5583531207*t)
	X1 += 0.00000002330*np.cos(3.20850507386 + 821.5437536686*t)
	X1 += 0.00000002648*np.cos(3.95978520157 + 460.5384408198*t)
	X1 += 0.00000002459*np.cos(2.05612285306 + 634.4806603426*t)
	return X1*t




def Uranus_X2 (t): # 234 terms of order 2

	X2 = 0.
	X2 += 0.00016015031*np.cos(3.83700030134 + 74.7815985673*t)
	X2 += 0.00010915299*np.cos(3.02987776270 + 149.5631971346*t)
	X2 += 0.00007497619*np.cos(3.83429136661 + 11.0457002639*t)
	X2 += 0.00008053623*np.cos(2.54646146122 + 63.7358983034*t)
	X2 += 0.00005408033*np.cos(4.78033642303 + 70.8494453042*t)
	X2 += 0.00005021971*np.cos(3.04632772928 + 78.7137518304*t)
	X2 += 0.00006717313*np.cos(5.31264214501 + 85.8272988312*t)
	X2 += 0.00005284684*np.cos(2.11901942097 + 73.297125859*t)
	X2 += 0.00004874936*np.cos(5.68616132176 + 76.2660712756*t)
	X2 += 0.00003002124*np.cos(4.07944398452 + 138.5174968707*t)
	X2 += 0.00002521797*np.cos(3.36028253173 + 71.6002048296*t)
	X2 += 0.00002413832*np.cos(4.45865225690 + 77.962992305*t)
	X2 += 0.00002221373*np.cos(0.87427485235 + 3.9321532631*t)
	X2 += 0.00002336552
	X2 += 0.00001040250*np.cos(0.73133408837 + 145.6310438715*t)
	X2 += 0.00001046100*np.cos(5.85311910228 + 224.3447957019*t)
	X2 += 0.00000661586*np.cos(1.01544505345 + 18.1592472647*t)
	X2 += 0.00000497229*np.cos(5.27733214183 + 22.0914005278*t)
	X2 += 0.00000502471*np.cos(2.22514214710 + 151.0476698429*t)
	X2 += 0.00000478348*np.cos(3.19107941219 + 72.3339180125*t)
	X2 += 0.00000382454*np.cos(5.20159531773 + 77.7505439839*t)
	X2 += 0.00000469767*np.cos(1.82481202242 + 3.1813937377*t)
	X2 += 0.00000403174*np.cos(1.56215178272 + 160.6088973985*t)
	X2 += 0.00000329455*np.cos(2.55333634094 + 71.8126531507*t)
	X2 += 0.00000384741*np.cos(4.73239324750 + 77.2292791221*t)
	X2 += 0.00000335931*np.cos(0.05377868960 + 65.2203710117*t)
	X2 += 0.00000281380*np.cos(0.54117101233 + 131.4039498699*t)
	X2 += 0.00000266860*np.cos(0.01657445784 + 52.6901980395*t)
	X2 += 0.00000234876*np.cos(4.75379495234 + 56.6223513026*t)
	X2 += 0.00000247761*np.cos(2.17938049654 + 127.4717966068*t)
	X2 += 0.00000301025*np.cos(1.77677607945 + 84.3428261229*t)
	X2 += 0.00000284485*np.cos(5.80269050272 + 148.0787244263*t)
	X2 += 0.00000205875*np.cos(2.90044450656 + 92.940845832*t)
	X2 += 0.00000211227*np.cos(5.58201664740 + 153.4953503977*t)
	X2 += 0.00000198069*np.cos(2.71231997005 + 12.5301729722*t)
	X2 += 0.00000204743*np.cos(4.25027722017 + 87.3117715395*t)
	X2 += 0.00000153445*np.cos(0.37502726199 + 213.299095438*t)
	X2 += 0.00000139847*np.cos(1.67730385016 + 9.5612275556*t)
	X2 += 0.00000135067*np.cos(1.54885838397 + 7.1135470008*t)
	X2 += 0.00000098993*np.cos(2.02428809026 + 80.1982245387*t)
	X2 += 0.00000097004*np.cos(0.86929640949 + 96.8729990951*t)
	X2 += 0.00000106322*np.cos(5.89383486521 + 146.3818033969*t)
	X2 += 0.00000086287*np.cos(2.23015105953 + 299.1263942692*t)
	X2 += 0.00000090522*np.cos(2.74395447453 + 67.6680515665*t)
	X2 += 0.00000103834*np.cos(3.59301778375 + 62.2514255951*t)
	X2 += 0.00000077436*np.cos(4.98636443135 + 81.8951455681*t)
	X2 += 0.00000070849*np.cos(5.07088456819 + 2.4476805548*t)
	X2 += 0.00000069701*np.cos(3.12415134304 + 220.4126424388*t)
	X2 += 0.00000065862*np.cos(3.55424953000 + 14.977853527*t)
	X2 += 0.00000085668*np.cos(5.65370424236 + 2.9689454166*t)
	X2 += 0.00000061522*np.cos(2.56662485733 + 152.7445908723*t)
	X2 += 0.00000058821*np.cos(4.32245164895 + 134.5853436076*t)
	X2 += 0.00000051315*np.cos(0.00373759576 + 202.2533951741*t)
	X2 += 0.00000049992*np.cos(1.98018927812 + 59.8037450403*t)
	X2 += 0.00000050856*np.cos(4.15026804629 + 79.2350166922*t)
	X2 += 0.00000049175*np.cos(4.90786846273 + 225.8292684102*t)
	X2 += 0.00000051450*np.cos(4.40765627804 + 195.1398481733*t)
	X2 += 0.00000044332*np.cos(3.66737843207 + 70.3281804424*t)
	X2 += 0.00000041618*np.cos(1.43117441969 + 152.5321425512*t)
	X2 += 0.00000037700*np.cos(1.70254629773 + 45.5766510387*t)
	X2 += 0.00000036505*np.cos(5.84418341803 + 69.3649725959*t)
	X2 += 0.00000039803*np.cos(3.21738514579 + 29.2049475286*t)
	X2 += 0.00000048281*np.cos(6.18868466775 + 142.4496501338*t)
	X2 += 0.00000036470*np.cos(5.45483351078 + 137.0330241624*t)
	X2 += 0.00000038301*np.cos(0.69629677985 + 209.3669421749*t)
	X2 += 0.00000039412*np.cos(3.54558409287 + 120.358249606*t)
	X2 += 0.00000032468*np.cos(6.09766987253 + 5.4166259714*t)
	X2 += 0.00000025083*np.cos(4.16747912718 + 23.5758732361*t)
	X2 += 0.00000025905*np.cos(0.80510379907 + 222.8603229936*t)
	X2 += 0.00000024866*np.cos(1.45023442479 + 20.6069278195*t)
	X2 += 0.00000027600*np.cos(0.65039122587 + 152.0108776894*t)
	X2 += 0.00000025328*np.cos(4.07713496029 + 235.3904959658*t)
	X2 += 0.00000021826*np.cos(1.14630128930 + 14.2270940016*t)
	X2 += 0.00000021959*np.cos(0.78915450301 + 33.1371007917*t)
	X2 += 0.00000026156*np.cos(0.49779058359 + 1.4844727083*t)
	X2 += 0.00000019149*np.cos(3.29078598900 + 206.1855484372*t)
	X2 += 0.00000020189*np.cos(1.31242215188 + 70.1157321213*t)
	X2 += 0.00000019159*np.cos(1.72257291786 + 146.594251718*t)
	X2 += 0.00000018559*np.cos(5.83653047667 + 89.7594520943*t)
	X2 += 0.00000018566*np.cos(3.51201554536 + 159.1244246902*t)
	X2 += 0.00000018948*np.cos(4.93737832347 + 4.4534181249*t)
	X2 += 0.00000019964*np.cos(0.05022016188 + 116.4260963429*t)
	X2 += 0.00000018655*np.cos(3.35843280718 + 79.4474650133*t)
	X2 += 0.00000022886*np.cos(5.80349455674 + 39.6175083461*t)
	X2 += 0.00000016179*np.cos(4.91038066160 + 16.6747745564*t)
	X2 += 0.00000017966*np.cos(2.30154520649 + 73.0846775379*t)
	X2 += 0.00000015341*np.cos(2.59132541436 + 265.9892934775*t)
	X2 += 0.00000017437*np.cos(2.36850714129 + 76.4785195967*t)
	X2 += 0.00000019179*np.cos(4.23225185740 + 41.6444977756*t)
	X2 += 0.00000014327*np.cos(6.07708539930 + 19.643719973*t)
	X2 += 0.00000014407*np.cos(6.22205029028 + 333.657345044*t)
	X2 += 0.00000016134*np.cos(0.95473971871 + 191.2076949102*t)
	X2 += 0.00000014945*np.cos(0.55877569736 + 162.0933701068*t)
	X2 += 0.00000015321*np.cos(5.50789142281 + 147.1155165798*t)
	X2 += 0.00000013527*np.cos(2.36755086379 + 347.8844390456*t)
	X2 += 0.00000011934*np.cos(1.13597368221 + 51.2057253312*t)
	X2 += 0.00000010994*np.cos(3.10745184212 + 60.5545045657*t)
	X2 += 0.00000011585*np.cos(1.72485861981 + 144.1465711632*t)
	X2 += 0.00000011019*np.cos(0.89138177474 + 25.2727942655*t)
	X2 += 0.00000010122*np.cos(1.26610747406 + 211.8146227297*t)
	X2 += 0.00000010330*np.cos(0.06803425383 + 140.001969579*t)
	X2 += 0.00000012693*np.cos(2.00537829250 + 109.9456887885*t)
	X2 += 0.00000009260*np.cos(5.39381298602 + 167.7224443993*t)
	X2 += 0.00000011487*np.cos(2.92874910876 + 88.7962442478*t)
	X2 += 0.00000008958*np.cos(5.52983885924 + 66.70484372*t)
	X2 += 0.00000009049*np.cos(4.52900392951 + 258.8757464767*t)
	X2 += 0.00000008611*np.cos(2.37390114378 + 277.0349937414*t)
	X2 += 0.00000009262*np.cos(1.82460574891 + 228.276948965*t)
	X2 += 0.00000008671*np.cos(4.30176725357 + 54.1746707478*t)
	X2 += 0.00000009388*np.cos(1.27494742725 + 340.7708920448*t)
	X2 += 0.00000007532*np.cos(4.84171458960 + 89.0086925689*t)
	X2 += 0.00000007790*np.cos(5.06093412042 + 41.1019810544*t)
	X2 += 0.00000007705*np.cos(3.36980508173 + 58.1068240109*t)
	X2 += 0.00000007448*np.cos(0.18702725085 + 128.9562693151*t)
	X2 += 0.00000008960*np.cos(3.03666968180 + 125.9873238985*t)
	X2 += 0.00000006887*np.cos(6.14238760125 + 273.1028404783*t)
	X2 += 0.00000007217*np.cos(2.86382215417 + 95.3885263868*t)
	X2 += 0.00000006283*np.cos(2.26635295310 + 305.3461693927*t)
	X2 += 0.00000006265*np.cos(2.79881908106 + 145.1097790097*t)
	X2 += 0.00000008596*np.cos(3.22141799373 + 288.0806940053*t)
	X2 += 0.00000006356*np.cos(4.52111917010 + 154.979823106*t)
	X2 += 0.00000006107*np.cos(0.90480185525 + 24.3790223882*t)
	X2 += 0.00000006766*np.cos(1.53737992411 + 151.260118164*t)
	X2 += 0.00000005981*np.cos(0.41637475396 + 135.336103133*t)
	X2 += 0.00000005829*np.cos(2.11807735162 + 39.3568759152*t)
	X2 += 0.00000005824*np.cos(0.69450297478 + 46.470422916*t)
	X2 += 0.00000005423*np.cos(4.52805116374 + 91.4563731237*t)
	X2 += 0.00000005485*np.cos(3.82938065661 + 141.6988906084*t)
	X2 += 0.00000005191*np.cos(1.66188854192 + 472.1748419147*t)
	X2 += 0.00000005364*np.cos(2.53241953776 + 75.7448064138*t)
	X2 += 0.00000005364*np.cos(2.14698289824 + 73.8183907208*t)
	X2 += 0.00000005409*np.cos(4.09924811021 + 486.4019359163*t)
	X2 += 0.00000005249*np.cos(5.11243104270 + 60.7669528868*t)
	X2 += 0.00000004778*np.cos(5.86181739720 + 55.1378785943*t)
	X2 += 0.00000006015*np.cos(4.77184571162 + 36.6485629295*t)
	X2 += 0.00000006190*np.cos(4.96470959339 + 269.9214467406*t)
	X2 += 0.00000004736*np.cos(0.99217847094 + 103.0927742186*t)
	X2 += 0.00000004604*np.cos(5.88010176802 + 415.5524906121*t)
	X2 += 0.00000004821*np.cos(4.95662631406 + 373.9079928365*t)
	X2 += 0.00000004572*np.cos(0.75390834385 + 124.2904028691*t)
	X2 += 0.00000004403*np.cos(3.47909854702 + 171.6545976624*t)
	X2 += 0.00000005162*np.cos(4.18164651430 + 383.3091616977*t)
	X2 += 0.00000005249*np.cos(6.10907433407 + 901.9544265284*t)
	X2 += 0.00000004614*np.cos(1.05531353110 + 230.5645708254*t)
	X2 += 0.00000004747*np.cos(5.94193042028 + 98.3574718034*t)
	X2 += 0.00000004287*np.cos(2.76994883489 + 108.4612160802*t)
	X2 += 0.00000005441*np.cos(5.68787484247 + 227.5261894396*t)
	X2 += 0.00000004233*np.cos(2.44612471178 + 329.7251917809*t)
	X2 += 0.00000003941*np.cos(3.69499703473 + 504.561183181*t)
	X2 += 0.00000004079*np.cos(1.27681238416 + 1969.2006632438*t)
	X2 += 0.00000003855*np.cos(4.05367916366 + 155.7829722581*t)
	X2 += 0.00000004566*np.cos(0.81568008468 + 223.4510238246*t)
	X2 += 0.00000003744*np.cos(0.15880085295 + 43.2890291783*t)
	X2 += 0.00000003719*np.cos(4.36823511490 + 404.5067903482*t)
	X2 += 0.00000003929*np.cos(5.65850658735 + 905.8865797915*t)
	X2 += 0.00000003709*np.cos(1.73135859909 + 94.4253185403*t)
	X2 += 0.00000003673*np.cos(5.13529281141 + 69.1525242748*t)
	X2 += 0.00000003673*np.cos(2.68570227818 + 80.4106728598*t)
	X2 += 0.00000003600*np.cos(1.76146735387 + 61.448276443*t)
	X2 += 0.00000003659*np.cos(4.79213652114 + 849.2642284889*t)
	X2 += 0.00000003681*np.cos(2.15475075702 + 460.5384408198*t)
	X2 += 0.00000003651*np.cos(6.08455104271 + 446.3113468182*t)
	X2 += 0.00000003881*np.cos(2.98444968516 + 184.0941479094*t)
	X2 += 0.00000003428*np.cos(5.14400730282 + 440.6822725257*t)
	X2 += 0.00000003543*np.cos(5.66454579944 + 110.2063212194*t)
	X2 += 0.00000003443*np.cos(2.21022759178 + 354.9979860464*t)
	X2 += 0.00000003421*np.cos(0.74103984530 + 309.2783226558*t)
	X2 += 0.00000003280*np.cos(5.46703748793 + 295.1942410061*t)
	X2 += 0.00000003244*np.cos(4.46870563032 + 428.0826635843*t)
	X2 += 0.00000004130*np.cos(1.43798019531 + 323.5054166574*t)
	X2 += 0.00000003530*np.cos(2.35217076937 + 204.7010757289*t)
	X2 += 0.00000003225*np.cos(0.68793280970 + 1044.4040766622*t)
	X2 += 0.00000003211*np.cos(6.27801219506 + 1057.8974574809*t)
	X2 += 0.00000003210*np.cos(2.99486184675 + 237.6781178262*t)
	X2 += 0.00000003295*np.cos(1.57881542596 + 32.2433289144*t)
	X2 += 0.00000003632*np.cos(5.42848370959 + 57.5161231799*t)
	X2 += 0.00000003617*np.cos(4.97055767543 + 103.9865460959*t)
	X2 += 0.00000003795*np.cos(6.10018451515 + 294.3004691288*t)
	X2 += 0.00000003164*np.cos(6.16088044931 + 1819.6374661092*t)
	X2 += 0.00000004062*np.cos(3.00655088214 + 112.9146342051*t)
	X2 += 0.00000003605*np.cos(0.72583106929 + 344.7030453079*t)
	X2 += 0.00000003019*np.cos(2.15678911314 + 924.0458270562*t)
	X2 += 0.00000003542*np.cos(3.69190213033 + 956.2891559706*t)
	X2 += 0.00000003851*np.cos(2.80656744089 + 82.8583534146*t)
	X2 += 0.00000003332*np.cos(5.67293465746 + 336.8387387817*t)
	X2 += 0.00000003805*np.cos(2.89413818631 + 479.2883889155*t)
	X2 += 0.00000003052*np.cos(0.51209008409 + 531.1754378029*t)
	X2 += 0.00000003128*np.cos(5.41255399827 + 1282.8329540138*t)
	X2 += 0.00000002957*np.cos(3.38660409843 + 207.6700211455*t)
	X2 += 0.00000003148*np.cos(6.00503879370 + 1169.5882514086*t)
	X2 += 0.00000003007*np.cos(3.41327104523 + 291.1190753911*t)
	X2 += 0.00000003096*np.cos(1.57250329749 + 109.3125493421*t)
	X2 += 0.00000003336*np.cos(5.87472092438 + 50.4025761791*t)
	X2 += 0.00000002836*np.cos(6.05952590725 + 88.1149206916*t)
	X2 += 0.00000003603*np.cos(0.32186436243 + 397.3932433474*t)
	X2 += 0.00000002839*np.cos(1.72546221305 + 942.062061969*t)
	X2 += 0.00000003033*np.cos(2.68660553420 + 976.7360250957*t)
	X2 += 0.00000003534*np.cos(3.92461589097 + 33.6796175129*t)
	X2 += 0.00000002928*np.cos(2.44090835126 + 465.9550667912*t)
	X2 += 0.00000002936*np.cos(2.23930177092 + 306.830642101*t)
	X2 += 0.00000002797*np.cos(5.27776461068 + 381.6122406683*t)
	X2 += 0.00000003685*np.cos(3.67062213532 + 132.8884225782*t)
	X2 += 0.00000002705*np.cos(0.91231544669 + 469.1364605289*t)
	X2 += 0.00000002859*np.cos(0.21700779836 + 241.6102710893*t)
	X2 += 0.00000002585*np.cos(2.76360547907 + 99.1606209555*t)
	X2 += 0.00000002931*np.cos(5.74557876585 + 180.1619946463*t)
	X2 += 0.00000002538*np.cos(4.29751680883 + 218.9281697305*t)
	X2 += 0.00000002655*np.cos(4.61991142764 + 476.1069951778*t)
	X2 += 0.00000002655*np.cos(3.08090677601 + 297.6419215609*t)
	X2 += 0.00000002495*np.cos(3.85258617208 + 450.9772132642*t)
	X2 += 0.00000002574*np.cos(1.56646107957 + 411.620337349*t)
	X2 += 0.00000002619*np.cos(0.30873583037 + 221.3758502853*t)
	X2 += 0.00000002614*np.cos(3.56422655479 + 1155.361157407*t)
	X2 += 0.00000002869*np.cos(5.95990878227 + 606.7601855223*t)
	X2 += 0.00000002427*np.cos(0.92530262269 + 714.6788848813*t)
	X2 += 0.00000002527*np.cos(0.69443718848 + 778.4147831847*t)
	X2 += 0.00000002542*np.cos(0.17187583717 + 461.1291416508*t)
	X2 += 0.00000002602*np.cos(0.56141580457 + 144.8973306886*t)
	X2 += 0.00000002602*np.cos(0.97639397784 + 4.665866446*t)
	X2 += 0.00000002377*np.cos(3.23840164112 + 358.9301393095*t)
	X2 += 0.00000002338*np.cos(1.95316065171 + 916.9322800554*t)
	X2 += 0.00000002554*np.cos(2.51124659785 + 200.7689224658*t)
	X2 += 0.00000003266*np.cos(2.87192522292 + 610.6923387854*t)
	X2 += 0.00000002576*np.cos(0.29704294543 + 987.7817253596*t)
	X2 += 0.00000002332*np.cos(1.28782128032 + 429.7795846137*t)
	X2 += 0.00000002386*np.cos(5.04212582936 + 346.1875180162*t)
	X2 += 0.00000002352*np.cos(3.74305038474 + 198.321241911*t)
	X2 += 0.00000003010*np.cos(4.42947128023 + 275.5505210331*t)
	X2 += 0.00000002825*np.cos(2.88092253402 + 735.8765135318*t)
	X2 += 0.00000002279*np.cos(3.39714919937 + 129.9194771616*t)
	X2 += 0.00000002589*np.cos(3.32716471243 + 376.9463742223*t)
	X2 += 0.00000002330*np.cos(3.64055170939 + 227.3137411185*t)
	X2 += 0.00000002749*np.cos(2.28150388150 + 92.0470739547*t)
	X2 += 0.00000002576*np.cos(3.89651804361 + 343.2185725996*t)
	return X2*t*t




def Uranus_X3 (t): # 79 terms of order 3

	X3 = 0.
	X3 += 0.00001309056
	X3 += 0.00000679651*np.cos(2.93375081556 + 70.8494453042*t)
	X3 += 0.00000631782*np.cos(4.88998230611 + 78.7137518304*t)
	X3 += 0.00000578540*np.cos(0.78827411585 + 149.5631971346*t)
	X3 += 0.00000555324*np.cos(4.67554978713 + 63.7358983034*t)
	X3 += 0.00000455887*np.cos(3.17331985662 + 85.8272988312*t)
	X3 += 0.00000428312*np.cos(4.09419341772 + 73.297125859*t)
	X3 += 0.00000408432*np.cos(3.72971926457 + 76.2660712756*t)
	X3 += 0.00000446893*np.cos(5.00810179500 + 71.6002048296*t)
	X3 += 0.00000424302*np.cos(2.81325875072 + 77.962992305*t)
	X3 += 0.00000344605*np.cos(2.22416564687 + 11.0457002639*t)
	X3 += 0.00000253001*np.cos(2.51182572008 + 3.9321532631*t)
	X3 += 0.00000188565*np.cos(0.81232221065 + 74.7815985673*t)
	X3 += 0.00000132014*np.cos(5.73012783198 + 138.5174968707*t)
	X3 += 0.00000120517*np.cos(5.48054814455 + 18.1592472647*t)
	X3 += 0.00000121340*np.cos(5.32278814741 + 145.6310438715*t)
	X3 += 0.00000081059*np.cos(0.31859981536 + 3.1813937377*t)
	X3 += 0.00000052581*np.cos(3.32426714386 + 224.3447957019*t)
	X3 += 0.00000050989*np.cos(2.38152145113 + 131.4039498699*t)
	X3 += 0.00000041352*np.cos(0.40988109551 + 56.6223513026*t)
	X3 += 0.00000045947*np.cos(2.93842177968 + 22.0914005278*t)
	X3 += 0.00000034956*np.cos(6.15180077697 + 151.0476698429*t)
	X3 += 0.00000034550*np.cos(1.01095270214 + 92.940845832*t)
	X3 += 0.00000028439*np.cos(5.71063354637 + 160.6088973985*t)
	X3 += 0.00000026418*np.cos(1.14627019293 + 153.4953503977*t)
	X3 += 0.00000019493*np.cos(4.40804069151 + 67.6680515665*t)
	X3 += 0.00000018709*np.cos(3.44807838704 + 81.8951455681*t)
	X3 += 0.00000019345*np.cos(2.38872118054 + 52.6901980395*t)
	X3 += 0.00000019435*np.cos(1.54656365767 + 65.2203710117*t)
	X3 += 0.00000015539*np.cos(2.03476393843 + 87.3117715395*t)
	X3 += 0.00000017211*np.cos(4.69608865329 + 127.4717966068*t)
	X3 += 0.00000020752*np.cos(0.21287415066 + 84.3428261229*t)
	X3 += 0.00000015215*np.cos(6.23002900092 + 148.0787244263*t)
	X3 += 0.00000017277*np.cos(1.24548498498 + 146.3818033969*t)
	X3 += 0.00000008759*np.cos(5.81652723830 + 62.2514255951*t)
	X3 += 0.00000008663*np.cos(4.72691646144 + 96.8729990951*t)
	X3 += 0.00000008078*np.cos(1.45894890773 + 220.4126424388*t)
	X3 += 0.00000007709*np.cos(1.22903169891 + 152.7445908723*t)
	X3 += 0.00000007875*np.cos(6.06848254483 + 195.1398481733*t)
	X3 += 0.00000006892*np.cos(0.42290386096 + 69.1525242748*t)
	X3 += 0.00000006892*np.cos(1.11490592145 + 80.4106728598*t)
	X3 += 0.00000006519*np.cos(3.51359374451 + 45.5766510387*t)
	X3 += 0.00000006131*np.cos(2.69408003257 + 134.5853436076*t)
	X3 += 0.00000005790*np.cos(1.86113898169 + 72.3339180125*t)
	X3 += 0.00000005692*np.cos(5.22115952238 + 209.3669421749*t)
	X3 += 0.00000005554*np.cos(2.84174026294 + 77.2292791221*t)
	X3 += 0.00000005258*np.cos(5.36467321323 + 120.358249606*t)
	X3 += 0.00000004995*np.cos(5.03278494168 + 298.2326223919*t)
	X3 += 0.00000004060*np.cos(3.84816850322 + 312.4597163935*t)
	X3 += 0.00000004420*np.cos(3.88854721697 + 80.1982245387*t)
	X3 += 0.00000004556*np.cos(1.09932074044 + 29.2049475286*t)
	X3 += 0.00000003855*np.cos(0.19744489675 + 59.8037450403*t)
	X3 += 0.00000003803*np.cos(3.44223491498 + 202.2533951741*t)
	X3 += 0.00000003701*np.cos(1.66917958581 + 213.299095438*t)
	X3 += 0.00000003772*np.cos(2.02816040987 + 71.8126531507*t)
	X3 += 0.00000003772*np.cos(2.65124202613 + 77.7505439839*t)
	X3 += 0.00000003524*np.cos(3.84299077479 + 635.9651330509*t)
	X3 += 0.00000003428*np.cos(4.80423314667 + 621.7380390493*t)
	X3 += 0.00000003564*np.cos(2.97403981010 + 70.1157321213*t)
	X3 += 0.00000003564*np.cos(1.70536262591 + 79.4474650133*t)
	X3 += 0.00000003288*np.cos(4.66534694390 + 384.0599212231*t)
	X3 += 0.00000003244*np.cos(4.05420822900 + 611.5861106627*t)
	X3 += 0.00000003804*np.cos(0.20143822235 + 258.8757464767*t)
	X3 += 0.00000003341*np.cos(3.06249611780 + 472.1748419147*t)
	X3 += 0.00000002934*np.cos(4.39080953923 + 273.1028404783*t)
	X3 += 0.00000003244*np.cos(2.13702777798 + 408.4389436113*t)
	X3 += 0.00000002805*np.cos(4.46431718602 + 984.6003316219*t)
	X3 += 0.00000003534*np.cos(0.59650948026 + 69.3649725959*t)
	X3 += 0.00000002809*np.cos(6.27616204819 + 647.0108333148*t)
	X3 += 0.00000002709*np.cos(2.28251220521 + 486.4019359163*t)
	X3 += 0.00000002603*np.cos(5.72903828346 + 415.5524906121*t)
	X3 += 0.00000002593*np.cos(3.12410002979 + 199.0720014364*t)
	X3 += 0.00000002640*np.cos(2.22058817761 + 288.0806940053*t)
	X3 += 0.00000002668*np.cos(2.78786175094 + 376.1956146969*t)
	X3 += 0.00000002998*np.cos(3.96389098534 + 73.0846775379*t)
	X3 += 0.00000002998*np.cos(0.71551145066 + 76.4785195967*t)
	X3 += 0.00000002563*np.cos(1.54843699395 + 216.4804891757*t)
	X3 += 0.00000002358*np.cos(0.87971471502 + 624.919432787*t)
	X3 += 0.00000002219*np.cos(3.00732305327 + 391.1734682239*t)
	return X3*t*t*t




def Uranus_X4 (t): # 10 terms of order 4

	X4 = 0.
	X4 -= 0.00000062987
	X4 += 0.00000034199*np.cos(0.42702885820 + 63.7358983034*t)
	X4 += 0.00000026702*np.cos(5.34493737706 + 149.5631971346*t)
	X4 += 0.00000027042*np.cos(1.11625109948 + 85.8272988312*t)
	X4 += 0.00000016293*np.cos(3.62714711041 + 18.1592472647*t)
	X4 += 0.00000006899*np.cos(4.21539961908 + 131.4039498699*t)
	X4 += 0.00000005852*np.cos(2.32484296944 + 56.6223513026*t)
	X4 += 0.00000005227*np.cos(5.41079816474 + 92.940845832*t)
	X4 += 0.00000002362*np.cos(0.90248563878 + 284.1485407422*t)
	X4 += 0.00000002295*np.cos(3.03607980943 + 365.9006739584*t)
	return X4*t*t*t*t




def Uranus_X5 (t): # 1 term of order 5

	X5 = 0.
	X5 += 0.00000000000
	return X5*t*t*t*t*t




def Uranus_Y0 (t): # 1411 terms of order 0

	Y0 = 0.
	Y0 += 19.16434475791*np.cos(3.91045677275 + 74.7815985673*t)
	Y0 += 0.44388525091*np.cos(0.08884126943 + 149.5631971346*t)
	Y0 -= 0.16222255941
	Y0 += 0.14755311401*np.cos(1.85423292905 + 73.297125859*t)
	Y0 += 0.14122904825*np.cos(2.82489928705 + 76.2660712756*t)
	Y0 += 0.06249939655*np.cos(3.56960238469 + 1.4844727083*t)
	Y0 += 0.01542607086*np.cos(2.55041543170 + 224.3447957019*t)
	Y0 += 0.01442293466*np.cos(1.08004535633 + 148.0787244263*t)
	Y0 += 0.00938950136*np.cos(0.09277492739 + 11.0457002639*t)
	Y0 += 0.00650307020*np.cos(2.76144565363 + 63.7358983034*t)
	Y0 += 0.00657314387*np.cos(5.28830720039 + 151.0476698429*t)
	Y0 += 0.00621305207*np.cos(1.48795124826 + 77.7505439839*t)
	Y0 += 0.00541938502*np.cos(3.24476518729 + 71.8126531507*t)
	Y0 += 0.00547449443*np.cos(2.06038015757 + 85.8272988312*t)
	Y0 += 0.00459611215*np.cos(2.33745675699 + 2.9689454166*t)
	Y0 += 0.00387905368*np.cos(4.62027047251 + 138.5174968707*t)
	Y0 += 0.00144026146*np.cos(0.75015758735 + 70.8494453042*t)
	Y0 += 0.00135284941*np.cos(3.93970261854 + 78.7137518304*t)
	Y0 += 0.00120431731*np.cos(2.53138588744 + 39.6175083461*t)
	Y0 += 0.00124862444*np.cos(0.94315799565 + 111.4301614968*t)
	Y0 += 0.00111199717*np.cos(3.55163790142 + 222.8603229936*t)
	Y0 += 0.00104503352*np.cos(2.33345670641 + 146.594251718*t)
	Y0 += 0.00108550063*np.cos(6.02230047678 + 35.1640902212*t)
	Y0 += 0.00063570927*np.cos(5.01204999475 + 299.1263942692*t)
	Y0 += 0.00053287586*np.cos(2.38436439892 + 3.9321532631*t)
	Y0 += 0.00063771339*np.cos(2.15607569061 + 109.9456887885*t)
	Y0 += 0.00060797570*np.cos(3.73070787340 + 38.1330356378*t)
	Y0 += 0.00039220442*np.cos(1.11841144768 + 4.4534181249*t)
	Y0 += 0.00034204008*np.cos(0.92405447828 + 65.2203710117*t)
	Y0 += 0.00034332981*np.cos(1.46696953800 + 225.8292684102*t)
	Y0 += 0.00034536961*np.cos(0.27613229331 + 79.2350166922*t)
	Y0 += 0.00039259031*np.cos(5.75909949077 + 202.2533951741*t)
	Y0 += 0.00026157159*np.cos(3.74095916304 + 9.5612275556*t)
	Y0 += 0.00023426309*np.cos(2.52740094518 + 145.6310438715*t)
	Y0 += 0.00022932162*np.cos(3.94455708202 + 84.3428261229*t)
	Y0 += 0.00031814882*np.cos(3.96860117340 + 152.5321425512*t)
	Y0 += 0.00025235989*np.cos(4.45141520694 + 70.3281804424*t)
	Y0 += 0.00025902590*np.cos(1.06899231907 + 213.299095438*t)
	Y0 += 0.00028371248*np.cos(4.44714636367 + 184.7272873558*t)
	Y0 += 0.00026651934*np.cos(4.53944389687 + 160.6088973985*t)
	Y0 += 0.00019665349*np.cos(3.96350065335 + 74.6697239827*t)
	Y0 += 0.00019642987*np.cos(0.71577796385 + 74.8934731519*t)
	Y0 += 0.00019838446*np.cos(5.29115100742 + 12.5301729722*t)
	Y0 += 0.00015537967*np.cos(1.87863275460 + 52.6901980395*t)
	Y0 += 0.00020715948*np.cos(4.93996485297 + 36.6485629295*t)
	Y0 += 0.00020115100*np.cos(3.45473780762 + 127.4717966068*t)
	Y0 += 0.00020050993*np.cos(2.90386377392 + 22.0914005278*t)
	Y0 += 0.00019900975*np.cos(6.11072709584 + 112.9146342051*t)
	Y0 += 0.00018124970*np.cos(0.98477642246 + 33.6796175129*t)
	Y0 += 0.00015203524*np.cos(1.31307053626 + 41.1019810544*t)
	Y0 += 0.00011238530*np.cos(4.54508332436 + 71.6002048296*t)
	Y0 += 0.00013948178*np.cos(4.70475195371 + 221.3758502853*t)
	Y0 += 0.00010819255*np.cos(0.12807059988 + 77.962992305*t)
	Y0 += 0.00013589092*np.cos(0.98313830596 + 87.3117715395*t)
	Y0 += 0.00012407787*np.cos(4.64945783340 + 72.3339180125*t)
	Y0 += 0.00011531140*np.cos(0.20190074645 + 77.2292791221*t)
	Y0 += 0.00008736150*np.cos(3.39874828293 + 186.2117600641*t)
	Y0 += 0.00007093587*np.cos(6.01613487245 + 297.6419215609*t)
	Y0 += 0.00006408245*np.cos(3.93246367895 + 62.2514255951*t)
	Y0 += 0.00006261153*np.cos(0.14258542752 + 153.4953503977*t)
	Y0 += 0.00007856014*np.cos(1.12354254831 + 340.7708920448*t)
	Y0 += 0.00005516018*np.cos(1.73758326119 + 140.001969579*t)
	Y0 += 0.00005556643*np.cos(3.68095215063 + 145.1097790097*t)
	Y0 += 0.00005368405*np.cos(2.55422957958 + 75.3028634291*t)
	Y0 += 0.00005350948*np.cos(2.12171493922 + 74.2603337055*t)
	Y0 += 0.00004508794*np.cos(5.82224064821 + 66.70484372*t)
	Y0 += 0.00004290374*np.cos(5.54490766551 + 265.9892934775*t)
	Y0 += 0.00005013871*np.cos(3.11907749268 + 18.1592472647*t)
	Y0 += 0.00004326138*np.cos(5.70135056853 + 183.2428146475*t)
	Y0 += 0.00004750018*np.cos(3.38678300054 + 73.8183907208*t)
	Y0 += 0.00004444318*np.cos(5.00535023482 + 114.3991069134*t)
	Y0 += 0.00003314154*np.cos(5.23054574329 + 82.8583534146*t)
	Y0 += 0.00004509054*np.cos(1.31254342829 + 75.7448064138*t)
	Y0 += 0.00003553107*np.cos(6.18906516846 + 5.9378908332*t)
	Y0 += 0.00003267474*np.cos(3.51091793230 + 7.1135470008*t)
	Y0 += 0.00003575402*np.cos(5.83965751946 + 137.0330241624*t)
	Y0 += 0.00002880734*np.cos(1.19038424330 + 373.9079928365*t)
	Y0 += 0.00002594155*np.cos(4.93691413537 + 96.8729990951*t)
	Y0 += 0.00002559357*np.cos(2.87184237678 + 80.1982245387*t)
	Y0 += 0.00002676616*np.cos(1.61805362044 + 305.3461693927*t)
	Y0 += 0.00002246530*np.cos(5.80081898763 + 108.4612160802*t)
	Y0 += 0.00002474483*np.cos(2.21173751117 + 32.1951448046*t)
	Y0 += 0.00002060991*np.cos(6.24178596384 + 56.6223513026*t)
	Y0 += 0.00001958711*np.cos(4.80807045815 + 20.6069278195*t)
	Y0 += 0.00002227451*np.cos(5.34765264557 + 80.7194894005*t)
	Y0 += 0.00001937874*np.cos(0.49529839431 + 74.8297826771*t)
	Y0 += 0.00001937871*np.cos(4.18462288684 + 74.7334144575*t)
	Y0 += 0.00002164382*np.cos(0.47581392325 + 3.1813937377*t)
	Y0 += 0.00002138407*np.cos(2.63817804331 + 74.5209661364*t)
	Y0 += 0.00002130909*np.cos(2.04143912495 + 75.0422309982*t)
	Y0 += 0.00001787737*np.cos(0.32096699926 + 2.4476805548*t)
	Y0 += 0.00002212861*np.cos(0.61491281306 + 259.5088859231*t)
	Y0 += 0.00001889369*np.cos(3.92852240171 + 300.6108669775*t)
	Y0 += 0.00002275258*np.cos(1.55666401505 + 131.4039498699*t)
	Y0 += 0.00001925946*np.cos(6.00527473515 + 159.1244246902*t)
	Y0 += 0.00001802494*np.cos(4.16218259902 + 74.6215398729*t)
	Y0 += 0.00001796292*np.cos(0.51761494342 + 74.9416572617*t)
	Y0 += 0.00002240648*np.cos(0.47739127862 + 181.7583419392*t)
	Y0 += 0.00001626134*np.cos(3.70023731184 + 191.2076949102*t)
	Y0 += 0.00001862236*np.cos(0.10443785448 + 42.5864537627*t)
	Y0 += 0.00002177437*np.cos(2.80437422101 + 479.2883889155*t)
	Y0 += 0.00001896184*np.cos(4.26975898003 + 14.977853527*t)
	Y0 += 0.00001489632*np.cos(4.93446380217 + 220.4126424388*t)
	Y0 += 0.00002045249*np.cos(5.17400788104 + 835.0371344873*t)
	Y0 += 0.00001887812*np.cos(2.75000237791 + 154.0166152595*t)
	Y0 += 0.00001794754*np.cos(0.16290844853 + 227.3137411185*t)
	Y0 += 0.00001346599*np.cos(3.89240128209 + 288.0806940053*t)
	Y0 += 0.00001572826*np.cos(5.93367812903 + 219.891377577*t)
	Y0 += 0.00001424804*np.cos(5.10004758033 + 92.940845832*t)
	Y0 += 0.00001267766*np.cos(0.92771324396 + 404.5067903482*t)
	Y0 += 0.00001588897*np.cos(4.15115668974 + 39.3568759152*t)
	Y0 += 0.00001269786*np.cos(1.09685727529 + 142.4496501338*t)
	Y0 += 0.00001291065*np.cos(5.67425699047 + 68.8437077341*t)
	Y0 += 0.00001416917*np.cos(0.72597245494 + 235.3904959658*t)
	Y0 += 0.00001165315*np.cos(0.51071041452 + 81.8951455681*t)
	Y0 += 0.00001035262*np.cos(1.20639876458 + 5.4166259714*t)
	Y0 += 0.00001009454*np.cos(0.45375065997 + 74.0308390419*t)
	Y0 += 0.00001220696*np.cos(1.84988185963 + 211.8146227297*t)
	Y0 += 0.00000997784*np.cos(4.22640788890 + 75.5323580927*t)
	Y0 += 0.00001222886*np.cos(2.27306099902 + 187.6962327724*t)
	Y0 += 0.00001337666*np.cos(3.74890794163 + 380.12776796*t)
	Y0 += 0.00001151803*np.cos(0.46579056125 + 128.9562693151*t)
	Y0 += 0.00001149114*np.cos(0.85101218281 + 296.1574488526*t)
	Y0 += 0.00001163762*np.cos(5.51157783762 + 230.5645708254*t)
	Y0 += 0.00001192292*np.cos(0.68084398426 + 99.1606209555*t)
	Y0 += 0.00001151286*np.cos(4.01147735438 + 67.6680515665*t)
	Y0 += 0.00001189801*np.cos(4.01778306134 + 50.4025761791*t)
	Y0 += 0.00001015998*np.cos(1.00290501307 + 35.4247226521*t)
	Y0 += 0.00000923365*np.cos(5.76874685766 + 54.1746707478*t)
	Y0 += 0.00000855559*np.cos(4.49004561030 + 68.1893164283*t)
	Y0 += 0.00000911338*np.cos(0.12254293382 + 149.45132255*t)
	Y0 += 0.00000856856*np.cos(6.21758865027 + 89.7594520943*t)
	Y0 += 0.00001051606*np.cos(3.96907647535 + 14.0146456805*t)
	Y0 += 0.00000835264*np.cos(5.34437105960 + 59.8037450403*t)
	Y0 += 0.00000909788*np.cos(3.15839878322 + 149.6750717192*t)
	Y0 += 0.00000739228*np.cos(2.48875340751 + 277.0349937414*t)
	Y0 += 0.00000973381*np.cos(0.64028748776 + 218.4069048687*t)
	Y0 += 0.00000952790*np.cos(1.24773830053 + 106.9767433719*t)
	Y0 += 0.00000891414*np.cos(1.82007872482 + 23.5758732361*t)
	Y0 += 0.00000898007*np.cos(0.53150446248 + 110.2063212194*t)
	Y0 += 0.00000896763*np.cos(0.51927845768 + 200.7689224658*t)
	Y0 += 0.00000662758*np.cos(0.25796780548 + 81.3738807063*t)
	Y0 += 0.00000863768*np.cos(3.46041862039 + 162.0933701068*t)
	Y0 += 0.00000623013*np.cos(2.99649402595 + 51.2057253312*t)
	Y0 += 0.00000597805*np.cos(1.07147770615 + 134.5853436076*t)
	Y0 += 0.00000766040*np.cos(0.89351020566 + 68.5618234438*t)
	Y0 += 0.00000626173*np.cos(0.14763136288 + 24.3790223882*t)
	Y0 += 0.00000661316*np.cos(3.91236554284 + 8.0767548473*t)
	Y0 += 0.00000746242*np.cos(2.79717552793 + 760.25553592*t)
	Y0 += 0.00000643424*np.cos(5.98383236425 + 88.7962442478*t)
	Y0 += 0.00000703568*np.cos(1.49945377005 + 203.7378678824*t)
	Y0 += 0.00000581277*np.cos(0.83588836575 + 28.5718080822*t)
	Y0 += 0.00000528413*np.cos(0.71044436153 + 146.3818033969*t)
	Y0 += 0.00000695636*np.cos(4.49767435966 + 617.8058857862*t)
	Y0 += 0.00000604018*np.cos(2.75780757245 + 195.1398481733*t)
	Y0 += 0.00000536175*np.cos(1.52084605210 + 116.4260963429*t)
	Y0 += 0.00000560350*np.cos(1.79729642400 + 69.3649725959*t)
	Y0 += 0.00000486886*np.cos(5.78724669907 + 415.5524906121*t)
	Y0 += 0.00000587456*np.cos(2.33741613601 + 152.0108776894*t)
	Y0 += 0.00000666586*np.cos(4.63314190172 + 6.2197751235*t)
	Y0 += 0.00000505972*np.cos(0.95984060933 + 157.6399519819*t)
	Y0 += 0.00000550782*np.cos(5.85625308842 + 260.9933586314*t)
	Y0 += 0.00000588886*np.cos(4.62064969642 + 258.0244132148*t)
	Y0 += 0.00000445581*np.cos(5.33271706288 + 329.7251917809*t)
	Y0 += 0.00000516860*np.cos(0.74712751258 + 351.8165923087*t)
	Y0 += 0.00000618901*np.cos(4.52549231118 + 125.9873238985*t)
	Y0 += 0.00000517809*np.cos(5.54012472390 + 209.3669421749*t)
	Y0 += 0.00000449585*np.cos(2.60457386268 + 543.0242872189*t)
	Y0 += 0.00000488079*np.cos(5.04403350813 + 73.4090004436*t)
	Y0 += 0.00000563065*np.cos(3.08986059602 + 155.7829722581*t)
	Y0 += 0.00000537029*np.cos(3.75711795413 + 81.0013736908*t)
	Y0 += 0.00000435630*np.cos(2.19413803718 + 372.4235201282*t)
	Y0 += 0.00000472431*np.cos(1.72063683793 + 180.2738692309*t)
	Y0 += 0.00000418634*np.cos(0.40340567628 + 95.3885263868*t)
	Y0 += 0.00000514049*np.cos(3.83742451002 + 115.8835796217*t)
	Y0 += 0.00000419613*np.cos(6.21605224514 + 41.6444977756*t)
	Y0 += 0.00000390364*np.cos(4.39316702257 + 152.7445908723*t)
	Y0 += 0.00000354100*np.cos(5.26264151031 + 46.2097904851*t)
	Y0 += 0.00000369010*np.cos(4.11078638826 + 144.1465711632*t)
	Y0 += 0.00000374623*np.cos(1.90215093451 + 73.1852512744*t)
	Y0 += 0.00000426261*np.cos(0.89836299897 + 141.4864422873*t)
	Y0 += 0.00000381449*np.cos(3.63961245738 + 114.1384744825*t)
	Y0 += 0.00000317869*np.cos(4.93937891025 + 33.1371007917*t)
	Y0 += 0.00000325976*np.cos(2.61924421042 + 228.276948965*t)
	Y0 += 0.00000354526*np.cos(4.66410291093 + 214.7835681463*t)
	Y0 += 0.00000405067*np.cos(0.76651664121 + 255.0554677982*t)
	Y0 += 0.00000401800*np.cos(2.67393126462 + 490.3340891794*t)
	Y0 += 0.00000324278*np.cos(4.97703425119 + 7.4223635415*t)
	Y0 += 0.00000399889*np.cos(5.30927861895 + 529.6909650946*t)
	Y0 += 0.00000316354*np.cos(3.43209926093 + 30.7106720963*t)
	Y0 += 0.00000287093*np.cos(5.24491427364 + 45.5766510387*t)
	Y0 += 0.00000277004*np.cos(4.21620590877 + 6.592282139*t)
	Y0 += 0.00000318464*np.cos(0.45911675628 + 120.358249606*t)
	Y0 += 0.00000311815*np.cos(0.79978809612 + 147.1155165798*t)
	Y0 += 0.00000337472*np.cos(3.60594773618 + 150.5264049811*t)
	Y0 += 0.00000255714*np.cos(6.18037150203 + 19.1224551112*t)
	Y0 += 0.00000246583*np.cos(1.17774433989 + 554.0699874828*t)
	Y0 += 0.00000252403*np.cos(5.01154358916 + 150.0844619964*t)
	Y0 += 0.00000230070*np.cos(5.35619295971 + 60.7669528868*t)
	Y0 += 0.00000278047*np.cos(5.88865683969 + 29.2049475286*t)
	Y0 += 0.00000302295*np.cos(0.43076728879 + 984.6003316219*t)
	Y0 += 0.00000265211*np.cos(1.11226453547 + 28.3111756513*t)
	Y0 += 0.00000227327*np.cos(3.78561264808 + 120.9913890524*t)
	Y0 += 0.00000198785*np.cos(3.18797196563 + 69.6737891366*t)
	Y0 += 0.00000222192*np.cos(3.44393515493 + 47.6942631934*t)
	Y0 += 0.00000219949*np.cos(5.18094249145 + 44.070926471*t)
	Y0 += 0.00000210545*np.cos(3.35124491126 + 0.5212648618*t)
	Y0 += 0.00000227699*np.cos(1.88879274658 + 216.9224321604*t)
	Y0 += 0.00000257536*np.cos(0.30399822270 + 1289.9465010146*t)
	Y0 += 0.00000231681*np.cos(2.78093325899 + 46.470422916*t)
	Y0 += 0.00000239720*np.cos(6.19793297710 + 756.3233826569*t)
	Y0 += 0.00000214437*np.cos(1.18016591525 + 189.1807054807*t)
	Y0 += 0.00000233297*np.cos(2.18609372572 + 339.2864193365*t)
	Y0 += 0.00000234130*np.cos(3.14530755107 + 342.2553647531*t)
	Y0 += 0.00000175836*np.cos(1.53408491826 + 57.255490749*t)
	Y0 += 0.00000167756*np.cos(5.59398995995 + 30.0562807905*t)
	Y0 += 0.00000216757*np.cos(0.90936155593 + 135.5485514541*t)
	Y0 += 0.00000173749*np.cos(4.28628512648 + 681.5417840896*t)
	Y0 += 0.00000164586*np.cos(0.70747217893 + 468.2426886516*t)
	Y0 += 0.00000203490*np.cos(5.82940017414 + 148.5999892881*t)
	Y0 += 0.00000163450*np.cos(1.53200906891 + 79.889407998*t)
	Y0 += 0.00000179581*np.cos(5.36487860827 + 103.3534066495*t)
	Y0 += 0.00000159175*np.cos(3.51044775078 + 17.5261078183*t)
	Y0 += 0.00000165292*np.cos(5.36941198819 + 154.979823106*t)
	Y0 += 0.00000192957*np.cos(5.12177898736 + 0.9632078465*t)
	Y0 += 0.00000185802*np.cos(3.99560320824 + 73.88782669*t)
	Y0 += 0.00000185802*np.cos(0.68379922776 + 75.6753704446*t)
	Y0 += 0.00000163127*np.cos(0.33878389027 + 264.5048207692*t)
	Y0 += 0.00000187130*np.cos(4.63207698177 + 149.0419322728*t)
	Y0 += 0.00000185821*np.cos(5.76008843913 + 76.154196691*t)
	Y0 += 0.00000154158*np.cos(4.43250509665 + 206.1855484372*t)
	Y0 += 0.00000175560*np.cos(4.41849512958 + 333.657345044*t)
	Y0 += 0.00000202867*np.cos(0.92934842891 + 291.7040307277*t)
	Y0 += 0.00000157912*np.cos(4.13655140282 + 82.2039621088*t)
	Y0 += 0.00000140539*np.cos(0.81828536865 + 426.598190876*t)
	Y0 += 0.00000178492*np.cos(0.39921147736 + 685.4739373527*t)
	Y0 += 0.00000137687*np.cos(3.65255922607 + 448.6895914038*t)
	Y0 += 0.00000152639*np.cos(2.03301679425 + 233.9060232575*t)
	Y0 += 0.00000154719*np.cos(4.66548925160 + 294.6729761443*t)
	Y0 += 0.00000137993*np.cos(0.49895867902 + 16.6747745564*t)
	Y0 += 0.00000161861*np.cos(2.54166020189 + 105.4922706636*t)
	Y0 += 0.00000130404*np.cos(4.56696904208 + 76.4785195967*t)
	Y0 += 0.00000128155*np.cos(2.45134447197 + 156.1554792736*t)
	Y0 += 0.00000146437*np.cos(3.06416525256 + 334.2904844904*t)
	Y0 += 0.00000157530*np.cos(1.02260224406 + 347.8844390456*t)
	Y0 += 0.00000150896*np.cos(1.84344856748 + 103.0927742186*t)
	Y0 += 0.00000120105*np.cos(5.04807417968 + 130.4407420234*t)
	Y0 += 0.00000127914*np.cos(5.91612723274 + 61.448276443*t)
	Y0 += 0.00000141971*np.cos(4.67692245942 + 173.9422195228*t)
	Y0 += 0.00000116798*np.cos(2.79975011606 + 692.5874843535*t)
	Y0 += 0.00000145866*np.cos(4.72508344563 + 24.1183899573*t)
	Y0 += 0.00000140467*np.cos(4.49862691968 + 286.596221297*t)
	Y0 += 0.00000121897*np.cos(4.89621303002 + 79.4474650133*t)
	Y0 += 0.00000113904*np.cos(5.19950219884 + 13.3333221243*t)
	Y0 += 0.00000143237*np.cos(4.38802400895 + 628.8515860501*t)
	Y0 += 0.00000128986*np.cos(3.45591214307 + 254.9435932136*t)
	Y0 += 0.00000135174*np.cos(1.15418631167 + 171.6545976624*t)
	Y0 += 0.00000125769*np.cos(3.85907526779 + 98.3574718034*t)
	Y0 += 0.00000105739*np.cos(5.13563496088 + 66.9172920411*t)
	Y0 += 0.00000107892*np.cos(0.10090598897 + 375.3924655448*t)
	Y0 += 0.00000128792*np.cos(1.53820246543 + 155.5010879678*t)
	Y0 += 0.00000103751*np.cos(0.09858727182 + 54.3347294422*t)
	Y0 += 0.00000136546*np.cos(4.44396318920 + 909.8187330546*t)
	Y0 += 0.00000114357*np.cos(4.80183924958 + 273.1028404783*t)
	Y0 += 0.00000098940*np.cos(1.32720716375 + 27.0873353739*t)
	Y0 += 0.00000101658*np.cos(0.35890468314 + 362.8622925726*t)
	Y0 += 0.00000096174*np.cos(2.53649545857 + 258.8757464767*t)
	Y0 += 0.00000109802*np.cos(5.86019231369 + 143.6253063014*t)
	Y0 += 0.00000106158*np.cos(2.64028524201 + 302.0953396858*t)
	Y0 += 0.00000112226*np.cos(3.46253936917 + 92.3077063856*t)
	Y0 += 0.00000113987*np.cos(2.05059638924 + 253.5709950899*t)
	Y0 += 0.00000109155*np.cos(3.69281386772 + 55.6591434561*t)
	Y0 += 0.00000097687*np.cos(1.51458618418 + 76.7873361374*t)
	Y0 += 0.00000093010*np.cos(1.80257495113 + 93.9040536785*t)
	Y0 += 0.00000113624*np.cos(1.22774403773 + 604.4725636619*t)
	Y0 += 0.00000099120*np.cos(5.09958883998 + 149.3025647037*t)
	Y0 += 0.00000092794*np.cos(1.47028932852 + 43.2890291783*t)
	Y0 += 0.00000089934*np.cos(2.95642515081 + 149.6113812444*t)
	Y0 += 0.00000090777*np.cos(2.91730470316 + 267.4737661858*t)
	Y0 += 0.00000089603*np.cos(1.04619916818 + 295.1942410061*t)
	Y0 += 0.00000110540*np.cos(2.03204732442 + 19.643719973*t)
	Y0 += 0.00000089934*np.cos(0.36256511993 + 149.5150130248*t)
	Y0 += 0.00000087921*np.cos(4.32670648553 + 74.1484591209*t)
	Y0 += 0.00000087921*np.cos(0.35269595047 + 75.4147380137*t)
	Y0 += 0.00000086241*np.cos(4.53063306110 + 76.42612997*t)
	Y0 += 0.00000116258*np.cos(4.19923354698 + 1215.1649024473*t)
	Y0 += 0.00000112324*np.cos(5.22657359082 + 228.7982138268*t)
	Y0 += 0.00000106862*np.cos(1.56894230537 + 81.682697247*t)
	Y0 += 0.00000105689*np.cos(5.90750871349 + 100.3844612329*t)
	Y0 += 0.00000082024*np.cos(5.83270282365 + 82.6459050935*t)
	Y0 += 0.00000083480*np.cos(2.97873123693 + 149.723255829*t)
	Y0 += 0.00000087612*np.cos(4.09200889540 + 58.1068240109*t)
	Y0 += 0.00000098663*np.cos(5.28681160540 + 88.1149206916*t)
	Y0 += 0.00000086521*np.cos(5.77990029279 + 6.9010986797*t)
	Y0 += 0.00000080076*np.cos(0.46711196257 + 73.1370671646*t)
	Y0 += 0.00000099120*np.cos(4.50258673794 + 149.8238295655*t)
	Y0 += 0.00000076677*np.cos(5.83936897150 + 73.5577582899*t)
	Y0 += 0.00000104152*np.cos(3.12500840636 + 210.3301500214*t)
	Y0 += 0.00000075760*np.cos(6.09966718025 + 218.9281697305*t)
	Y0 += 0.00000090975*np.cos(0.83013329096 + 98.8999885246*t)
	Y0 += 0.00000074732*np.cos(5.25299025162 + 5.1078094307*t)
	Y0 += 0.00000083480*np.cos(0.34025903382 + 149.4031384402*t)
	Y0 += 0.00000084005*np.cos(3.28553283014 + 370.9390474199*t)
	Y0 += 0.00000105110*np.cos(1.09488557735 + 328.3525936572*t)
	Y0 += 0.00000074870*np.cos(5.30985523542 + 119.5069163441*t)
	Y0 += 0.00000074569*np.cos(4.55789803256 + 95.2284676924*t)
	Y0 += 0.00000074010*np.cos(4.76626906432 + 189.7232222019*t)
	Y0 += 0.00000075625*np.cos(3.30145293663 + 217.2312487011*t)
	Y0 += 0.00000077135*np.cos(0.02896321430 + 26.0235537909*t)
	Y0 += 0.00000090374*np.cos(1.46851586145 + 17.2654753874*t)
	Y0 += 0.00000086483*np.cos(1.70654125720 + 192.6921676185*t)
	Y0 += 0.00000069347*np.cos(5.01480404732 + 16.04163511*t)
	Y0 += 0.00000078846*np.cos(4.72561130487 + 262.4778313397*t)
	Y0 += 0.00000082091*np.cos(1.66303062044 + 175.1660598002*t)
	Y0 += 0.00000070186*np.cos(5.97826233723 + 820.0592809603*t)
	Y0 += 0.00000067869*np.cos(2.38336846275 + 606.7601855223*t)
	Y0 += 0.00000077397*np.cos(3.19409744954 + 310.1720945331*t)
	Y0 += 0.00000087004*np.cos(1.62284282986 + 894.8408795276*t)
	Y0 += 0.00000065829*np.cos(0.35938438379 + 73.9784494152*t)
	Y0 += 0.00000065829*np.cos(4.32001805221 + 75.5847477194*t)
	Y0 += 0.00000078542*np.cos(3.84154583566 + 50.66320861*t)
	Y0 += 0.00000077422*np.cos(6.17876938790 + 70.0462961521*t)
	Y0 += 0.00000075104*np.cos(3.21476153585 + 25.6028626656*t)
	Y0 += 0.00000073253*np.cos(2.97393986372 + 178.7893965226*t)
	Y0 += 0.00000085207*np.cos(3.04618638130 + 173.6815870919*t)
	Y0 += 0.00000087752*np.cos(5.06850205613 + 331.3215390738*t)
	Y0 += 0.00000080077*np.cos(3.13117992910 + 16.4623262353*t)
	Y0 += 0.00000083450*np.cos(4.82134683307 + 480.7728616238*t)
	Y0 += 0.00000070498*np.cos(2.80104084260 + 76.3779458602*t)
	Y0 += 0.00000079920*np.cos(3.87030192885 + 477.8039162072*t)
	Y0 += 0.00000078743*np.cos(2.65459072812 + 15.4991183888*t)
	Y0 += 0.00000080994*np.cos(0.84859852290 + 332.8060117821*t)
	Y0 += 0.00000075507*np.cos(2.06743974265 + 67.0773507355*t)
	Y0 += 0.00000058964*np.cos(1.82902730542 + 44.7253177768*t)
	Y0 += 0.00000070112*np.cos(1.28299080418 + 167.7224443993*t)
	Y0 += 0.00000077992*np.cos(1.70300103619 + 70.1157321213*t)
	Y0 += 0.00000077639*np.cos(1.49248726131 + 71.1582618449*t)
	Y0 += 0.00000066387*np.cos(6.24095505973 + 125.1841747464*t)
	Y0 += 0.00000059375*np.cos(1.96681230683 + 403.0223176399*t)
	Y0 += 0.00000054636*np.cos(6.18572063318 + 71.8608372605*t)
	Y0 += 0.00000064315*np.cos(6.09090612220 + 472.1748419147*t)
	Y0 += 0.00000052973*np.cos(4.46113364221 + 831.1049812242*t)
	Y0 += 0.00000065857*np.cos(4.49486698909 + 7.8643065262*t)
	Y0 += 0.00000053827*np.cos(0.67127500874 + 67.3592350258*t)
	Y0 += 0.00000060264*np.cos(4.31075800997 + 454.9093665273*t)
	Y0 += 0.00000053991*np.cos(3.01146704045 + 148.8124376092*t)
	Y0 += 0.00000051867*np.cos(4.77686720248 + 77.7023598741*t)
	Y0 += 0.00000070395*np.cos(3.20554541979 + 78.4049352897*t)
	Y0 += 0.00000056126*np.cos(2.54058148898 + 65.3804297061*t)
	Y0 += 0.00000059491*np.cos(6.08727466304 + 256.5399405065*t)
	Y0 += 0.00000061624*np.cos(2.19426288431 + 290.2195580194*t)
	Y0 += 0.00000061333*np.cos(5.64664423158 + 1364.7280995819*t)
	Y0 += 0.00000057149*np.cos(0.50053166486 + 31.6526280834*t)
	Y0 += 0.00000055249*np.cos(4.98968823058 + 74.4090915518*t)
	Y0 += 0.00000055249*np.cos(5.97289951260 + 75.1541055828*t)
	Y0 += 0.00000053798*np.cos(0.50648861767 + 13.4933808187*t)
	Y0 += 0.00000049301*np.cos(5.39744243512 + 76.0054388447*t)
	Y0 += 0.00000067640*np.cos(0.64240183724 + 278.5194664497*t)
	Y0 += 0.00000062225*np.cos(2.60564950826 + 82.4858463991*t)
	Y0 += 0.00000049881*np.cos(0.72603310338 + 91.4563731237*t)
	Y0 += 0.00000053743*np.cos(2.89411156731 + 14.2270940016*t)
	Y0 += 0.00000051406*np.cos(1.10843247300 + 101.8689339412*t)
	Y0 += 0.00000052229*np.cos(3.14515157585 + 184.9879197867*t)
	Y0 += 0.00000056294*np.cos(0.03303123026 + 142.9709149956*t)
	Y0 += 0.00000048570*np.cos(1.04696116864 + 48.9181034708*t)
	Y0 += 0.00000065078*np.cos(2.28307091556 + 237.6781178262*t)
	Y0 += 0.00000061846*np.cos(3.01358019450 + 61.2882177486*t)
	Y0 += 0.00000047590*np.cos(2.58646137213 + 224.2329211173*t)
	Y0 += 0.00000048035*np.cos(4.24298529357 + 43.1289704839*t)
	Y0 += 0.00000046688*np.cos(3.14104089569 + 106.2741679563*t)
	Y0 += 0.00000057708*np.cos(2.71180344965 + 303.8616966844*t)
	Y0 += 0.00000053190*np.cos(4.73802617636 + 79.5169009825*t)
	Y0 += 0.00000045467*np.cos(3.56475248959 + 69.1525242748*t)
	Y0 += 0.00000054456*np.cos(5.91606185436 + 236.8749686741*t)
	Y0 += 0.00000054466*np.cos(2.17820102905 + 74.1272072615*t)
	Y0 += 0.00000054466*np.cos(2.50120140695 + 75.4359898731*t)
	Y0 += 0.00000057370*np.cos(2.72607672194 + 486.4019359163*t)
	Y0 += 0.00000049209*np.cos(5.59180020112 + 177.8743727859*t)
	Y0 += 0.00000048903*np.cos(5.20790489853 + 122.4758617607*t)
	Y0 += 0.00000043958*np.cos(3.51862818809 + 57.5161231799*t)
	Y0 += 0.00000049065*np.cos(0.32033940212 + 55.7710180407*t)
	Y0 += 0.00000052405*np.cos(0.06300352006 + 58.7399634573*t)
	Y0 += 0.00000047603*np.cos(2.13905443526 + 84.1827674285*t)
	Y0 += 0.00000059452*np.cos(2.64459100980 + 117.36805233*t)
	Y0 += 0.00000042464*np.cos(0.34761416357 + 150.31395666*t)
	Y0 += 0.00000042224*np.cos(5.36565135834 + 31.492569389*t)
	Y0 += 0.00000056913*np.cos(0.53808385027 + 25.0603459444*t)
	Y0 += 0.00000053599*np.cos(6.09401185678 + 767.3690829208*t)
	Y0 += 0.00000045165*np.cos(1.62137110390 + 167.0893049529*t)
	Y0 += 0.00000044202*np.cos(4.50403074571 + 70.5888128733*t)
	Y0 += 0.00000055389*np.cos(1.25826751876 + 365.0011565867*t)
	Y0 += 0.00000055355*np.cos(2.74861110912 + 198.321241911*t)
	Y0 += 0.00000039625*np.cos(1.62185662608 + 72.4939767069*t)
	Y0 += 0.00000042295*np.cos(3.26980829888 + 232.4215505492*t)
	Y0 += 0.00000039728*np.cos(2.20105143608 + 88.274979386*t)
	Y0 += 0.00000052918*np.cos(5.55529236777 + 117.9105690512*t)
	Y0 += 0.00000037996*np.cos(3.64573952570 + 154.6710065653*t)
	Y0 += 0.00000047398*np.cos(5.61862934792 + 75.6329318292*t)
	Y0 += 0.00000047398*np.cos(5.34395839526 + 73.9302653054*t)
	Y0 += 0.00000045095*np.cos(5.09840444946 + 393.4610900843*t)
	Y0 += 0.00000041021*np.cos(0.17537188201 + 78.9743842613*t)
	Y0 += 0.00000049970*np.cos(3.55869944978 + 7.7042478318*t)
	Y0 += 0.00000042300*np.cos(6.01494050164 + 22.633917249*t)
	Y0 += 0.00000037354*np.cos(4.23058347236 + 49.7212526229*t)
	Y0 += 0.00000037062*np.cos(4.20186306066 + 397.3932433474*t)
	Y0 += 0.00000047477*np.cos(5.62213666350 + 224.4566702865*t)
	Y0 += 0.00000043525*np.cos(3.17935260457 + 25.8634950965*t)
	Y0 += 0.00000040051*np.cos(3.79235506158 + 306.830642101*t)
	Y0 += 0.00000047665*np.cos(4.06141529894 + 73.0846775379*t)
	Y0 += 0.00000040170*np.cos(2.45770060358 + 164.5410506616*t)
	Y0 += 0.00000037768*np.cos(5.10288059528 + 91.2439248026*t)
	Y0 += 0.00000047287*np.cos(1.81083449786 + 199.2844497575*t)
	Y0 += 0.00000035861*np.cos(4.71491046915 + 136.0698163159*t)
	Y0 += 0.00000039296*np.cos(4.64777796591 + 29.226199388*t)
	Y0 += 0.00000050065*np.cos(2.94906045687 + 51.8870488874*t)
	Y0 += 0.00000047358*np.cos(0.94380667353 + 836.5216071956*t)
	Y0 += 0.00000044940*np.cos(2.63982634792 + 142.1408335931*t)
	Y0 += 0.00000046274*np.cos(6.24438375030 + 833.552661779*t)
	Y0 += 0.00000043875*np.cos(4.01578111231 + 57.1436161644*t)
	Y0 += 0.00000036388*np.cos(2.84792168696 + 165.6048322446*t)
	Y0 += 0.00000040903*np.cos(0.28712839168 + 411.620337349*t)
	Y0 += 0.00000037380*np.cos(1.64167768184 + 180.1619946463*t)
	Y0 += 0.00000037167*np.cos(4.49302460920 + 226.7924762567*t)
	Y0 += 0.00000035944*np.cos(0.68720378876 + 184.0941479094*t)
	Y0 += 0.00000033709*np.cos(3.11818030790 + 77.0692204277*t)
	Y0 += 0.00000035019*np.cos(4.74760141554 + 35.685355083*t)
	Y0 += 0.00000032558*np.cos(5.73366744278 + 1.3725981237*t)
	Y0 += 0.00000034531*np.cos(4.78443809928 + 132.8884225782*t)
	Y0 += 0.00000037298*np.cos(4.64646918432 + 0.8031491521*t)
	Y0 += 0.00000036838*np.cos(3.14836254781 + 215.4379594521*t)
	Y0 += 0.00000033520*np.cos(5.76793055388 + 248.7238180901*t)
	Y0 += 0.00000037511*np.cos(4.02111882433 + 94.4253185403*t)
	Y0 += 0.00000041562*np.cos(2.19963752791 + 163.5778428151*t)
	Y0 += 0.00000034188*np.cos(2.03037659091 + 335.7749571987*t)
	Y0 += 0.00000030713*np.cos(4.33324653529 + 31.5407534988*t)
	Y0 += 0.00000037212*np.cos(4.24423846684 + 93.7921790939*t)
	Y0 += 0.00000038967*np.cos(5.47430356472 + 142.6620984549*t)
	Y0 += 0.00000030838*np.cos(5.30049970793 + 90.8232336773*t)
	Y0 += 0.00000037309*np.cos(5.79272926143 + 124.5028511902*t)
	Y0 += 0.00000036881*np.cos(2.80082144083 + 75.3722993983*t)
	Y0 += 0.00000036881*np.cos(1.87858099517 + 74.1908977363*t)
	Y0 += 0.00000029994*np.cos(5.29887577504 + 530.6541729411*t)
	Y0 += 0.00000029320*np.cos(4.04523159344 + 745.277682393*t)
	Y0 += 0.00000039558*np.cos(5.86592561925 + 58.6280888727*t)
	Y0 += 0.00000031552*np.cos(3.77229684904 + 8.9068362498*t)
	Y0 += 0.00000032231*np.cos(0.69404916107 + 80.4106728598*t)
	Y0 += 0.00000029341*np.cos(4.80197600433 + 32.2433289144*t)
	Y0 += 0.00000039957*np.cos(1.71495531420 + 1744.8558675419*t)
	Y0 += 0.00000034894*np.cos(3.35588948339 + 143.3434220111*t)
	Y0 += 0.00000034738*np.cos(4.24812442276 + 42.5382696529*t)
	Y0 += 0.00000033579*np.cos(2.35670120676 + 92.0470739547*t)
	Y0 += 0.00000029397*np.cos(1.38889152740 + 958.576777831*t)
	Y0 += 0.00000029047*np.cos(2.54832074149 + 114.9416236346*t)
	Y0 += 0.00000028957*np.cos(2.18112842604 + 528.7277572481*t)
	Y0 += 0.00000029867*np.cos(3.73972221138 + 100.6450936638*t)
	Y0 += 0.00000027969*np.cos(0.61782090444 + 0.7507595254*t)
	Y0 += 0.00000034543*np.cos(2.36055310688 + 326.8681209489*t)
	Y0 += 0.00000034957*np.cos(0.34059593072 + 229.0800981171*t)
	Y0 += 0.00000026858*np.cos(1.15133785291 + 55.1378785943*t)
	Y0 += 0.00000029985*np.cos(4.74522232026 + 90.2807169561*t)
	Y0 += 0.00000032127*np.cos(4.54419877632 + 48.7580447764*t)
	Y0 += 0.00000032003*np.cos(3.49913714494 + 216.2680408546*t)
	Y0 += 0.00000028073*np.cos(5.56516198967 + 123.5396433437*t)
	Y0 += 0.00000027051*np.cos(1.46048880013 + 27.7204748203*t)
	Y0 += 0.00000027412*np.cos(3.17327799326 + 221.1634019642*t)
	Y0 += 0.00000033594*np.cos(2.01380545416 + 157.2674449664*t)
	Y0 += 0.00000037009*np.cos(5.77608967408 + 4.7353024152*t)
	Y0 += 0.00000031328*np.cos(2.07043626780 + 66.1835788582*t)
	Y0 += 0.00000027737*np.cos(0.71377469191 + 141.6988906084*t)
	Y0 += 0.00000026861*np.cos(3.33466740983 + 151.260118164*t)
	Y0 += 0.00000025516*np.cos(0.94690360002 + 284.1485407422*t)
	Y0 += 0.00000029332*np.cos(0.72314041835 + 8.5980197091*t)
	Y0 += 0.00000032143*np.cos(3.34008688936 + 1033.3583763983*t)
	Y0 += 0.00000026982*np.cos(2.84411833096 + 11.1575748485*t)
	Y0 += 0.00000034665*np.cos(5.24249308046 + 367.9701020033*t)
	Y0 += 0.00000026014*np.cos(4.66149750775 + 447.2051186955*t)
	Y0 += 0.00000033090*np.cos(4.94655582915 + 54.2865453324*t)
	Y0 += 0.00000025835*np.cos(3.54054842127 + 68.3011910129*t)
	Y0 += 0.00000024959*np.cos(5.49903630568 + 275.5505210331*t)
	Y0 += 0.00000024051*np.cos(0.02716967400 + 328.2407190726*t)
	Y0 += 0.00000026341*np.cos(1.11426693133 + 40.1600250673*t)
	Y0 += 0.00000023755*np.cos(6.10350487990 + 969.6224780949*t)
	Y0 += 0.00000025931*np.cos(0.50543349829 + 3.6233367224*t)
	Y0 += 0.00000032528*np.cos(0.20784726930 + 619.2903584945*t)
	Y0 += 0.00000025701*np.cos(0.62652000537 + 75.8935642601*t)
	Y0 += 0.00000025701*np.cos(4.05288243063 + 73.6696328745*t)
	Y0 += 0.00000028109*np.cos(6.07343558644 + 10.9338256793*t)
	Y0 += 0.00000030666*np.cos(1.81550555962 + 1140.38330388*t)
	Y0 += 0.00000025568*np.cos(0.30969823578 + 58.319272332*t)
	Y0 += 0.00000029542*np.cos(0.38908166418 + 565.1156877467*t)
	Y0 += 0.00000022965*np.cos(0.17434191029 + 188.9200730498*t)
	Y0 += 0.00000024997*np.cos(2.87330598675 + 2.2876218604*t)
	Y0 += 0.00000031000*np.cos(0.89906724200 + 227.5261894396*t)
	Y0 += 0.00000030628*np.cos(5.09784088338 + 90.9351082619*t)
	Y0 += 0.00000031484*np.cos(1.73913654546 + 97.6761482472*t)
	Y0 += 0.00000027480*np.cos(2.89233602186 + 25.2727942655*t)
	Y0 += 0.00000029792*np.cos(5.55171985100 + 616.3214130779*t)
	Y0 += 0.00000022571*np.cos(2.16687004586 + 70.6369969831*t)
	Y0 += 0.00000031058*np.cos(1.43279206593 + 401.6497195162*t)
	Y0 += 0.00000028415*np.cos(4.12348230751 + 405.9912630565*t)
	Y0 += 0.00000027161*np.cos(4.09025835610 + 104.8378793578*t)
	Y0 += 0.00000022243*np.cos(5.02281912723 + 85.9391734158*t)
	Y0 += 0.00000021822*np.cos(3.86589404722 + 34.62157350*t)
	Y0 += 0.00000023957*np.cos(3.62192659965 + 541.5398145106*t)
	Y0 += 0.00000023717*np.cos(3.96570662024 + 45.5553991793*t)
	Y0 += 0.00000023243*np.cos(1.06350780602 + 414.0680179038*t)
	Y0 += 0.00000024086*np.cos(2.70821760397 + 170.1701249541*t)
	Y0 += 0.00000028861*np.cos(0.64319686646 + 67.9286839974*t)
	Y0 += 0.00000022545*np.cos(2.64769317985 + 162.8965192589*t)
	Y0 += 0.00000022291*np.cos(0.79512014451 + 107.918699359*t)
	Y0 += 0.00000029192*np.cos(1.84655840013 + 1439.5096981492*t)
	Y0 += 0.00000022861*np.cos(1.72642949501 + 103.9865460959*t)
	Y0 += 0.00000021013*np.cos(1.29008318671 + 81.2620061217*t)
	Y0 += 0.00000024367*np.cos(4.94112415487 + 49.1787359017*t)
	Y0 += 0.00000023467*np.cos(3.95998507699 + 107.4980082337*t)
	Y0 += 0.00000020957*np.cos(2.51273700262 + 78.9262001515*t)
	Y0 += 0.00000025080*np.cos(0.62990903054 + 92.4195809702*t)
	Y0 += 0.00000020122*np.cos(5.07116177077 + 140.9651774255*t)
	Y0 += 0.00000027799*np.cos(0.96209912473 + 369.4545747116*t)
	Y0 += 0.00000020414*np.cos(3.43556230714 + 221.8971151471*t)
	Y0 += 0.00000020276*np.cos(3.99181745831 + 43.2408450685*t)
	Y0 += 0.00000020094*np.cos(6.08072379833 + 143.9341228421*t)
	Y0 += 0.00000023389*np.cos(2.70050292963 + 52.1476813183*t)
	Y0 += 0.00000020822*np.cos(3.66007416491 + 77.489911553*t)
	Y0 += 0.00000020822*np.cos(1.01932827109 + 72.0732855816*t)
	Y0 += 0.00000019167*np.cos(2.51195058548 + 9.4011688612*t)
	Y0 += 0.00000022130*np.cos(3.28604969599 + 252.0865223816*t)
	Y0 += 0.00000019238*np.cos(1.86487710128 + 144.8973306886*t)
	Y0 += 0.00000019379*np.cos(1.50967733121 + 22.8945496799*t)
	Y0 += 0.00000021476*np.cos(3.77193446657 + 104.0077979553*t)
	Y0 += 0.00000018640*np.cos(1.24369440348 + 289.5651667136*t)
	Y0 += 0.00000022426*np.cos(2.04135195791 + 37.8724032069*t)
	Y0 += 0.00000023788*np.cos(5.93558688968 + 166.828672522*t)
	Y0 += 0.00000021707*np.cos(2.83253969325 + 31.2319369581*t)
	Y0 += 0.00000022639*np.cos(5.17912426997 + 248.4631856592*t)
	Y0 += 0.00000021539*np.cos(5.04355745874 + 64.4866578288*t)
	Y0 += 0.00000018477*np.cos(0.61233843943 + 381.0909758065*t)
	Y0 += 0.00000024739*np.cos(4.02369602783 + 81.6345131372*t)
	Y0 += 0.00000018430*np.cos(3.77934306901 + 379.1645601135*t)
	Y0 += 0.00000018049*np.cos(2.34270181480 + 133.1008708993*t)
	Y0 += 0.00000020494*np.cos(1.10086101935 + 147.9668498417*t)
	Y0 += 0.00000024959*np.cos(3.08477269046 + 40.8413486235*t)
	Y0 += 0.00000020027*np.cos(2.84908153496 + 156.6767441354*t)
	Y0 += 0.00000021566*np.cos(5.83658853708 + 225.3080035484*t)
	Y0 += 0.00000017391*np.cos(2.86052058946 + 72.7758609972*t)
	Y0 += 0.00000017620*np.cos(5.07184757883 + 303.0585475323*t)
	Y0 += 0.00000021389*np.cos(4.38799405242 + 232.0490435337*t)
	Y0 += 0.00000019107*np.cos(5.96319659112 + 17.6379824029*t)
	Y0 += 0.00000019829*np.cos(0.44940833294 + 531.978586955*t)
	Y0 += 0.00000023483*np.cos(3.29343789705 + 19.0105805266*t)
	Y0 += 0.00000016980*np.cos(3.51859662271 + 75.2391729543*t)
	Y0 += 0.00000016980*np.cos(1.16080581329 + 74.3240241803*t)
	Y0 += 0.00000022320*np.cos(5.66281470091 + 10.0824924174*t)
	Y0 += 0.00000020030*np.cos(0.25164752666 + 14.5571624017*t)
	Y0 += 0.00000016607*np.cos(1.47546084960 + 241.6102710893*t)
	Y0 += 0.00000016233*np.cos(3.90399450150 + 312.4597163935*t)
	Y0 += 0.00000018599*np.cos(4.26067496372 + 148.1905990109*t)
	Y0 += 0.00000021037*np.cos(4.42353418044 + 624.919432787*t)
	Y0 += 0.00000021300*np.cos(6.02101806289 + 95.2766518022*t)
	Y0 += 0.00000016064*np.cos(6.13846823459 + 117.3198682202*t)
	Y0 += 0.00000021612*np.cos(4.01322800375 + 758.7710632117*t)
	Y0 += 0.00000020855*np.cos(3.17986464297 + 331.2096644892*t)
	Y0 += 0.00000018484*np.cos(1.63013404137 + 905.8865797915*t)
	Y0 += 0.00000017265*np.cos(0.34376874392 + 20.4468691251*t)
	Y0 += 0.00000021485*np.cos(5.60817683212 + 1670.0742689746*t)
	Y0 += 0.00000019349*np.cos(2.53812164115 + 363.5166838784*t)
	Y0 += 0.00000021183*np.cos(2.76279313413 + 129.9194771616*t)
	Y0 += 0.00000019142*np.cos(1.99614767689 + 408.4389436113*t)
	Y0 += 0.00000017881*np.cos(0.09108273346 + 190.665178189*t)
	Y0 += 0.00000016009*np.cos(0.73172853687 + 75.6116799698*t)
	Y0 += 0.00000016009*np.cos(3.94767389914 + 73.9515171648*t)
	Y0 += 0.00000018321*np.cos(5.20071762389 + 106.0135355254*t)
	Y0 += 0.00000019988*np.cos(4.01527692746 + 376.1956146969*t)
	Y0 += 0.00000018460*np.cos(1.62901612902 + 135.336103133*t)
	Y0 += 0.00000014946*np.cos(4.73172529633 + 73.3453099688*t)
	Y0 += 0.00000014946*np.cos(3.08926979326 + 76.2178871658*t)
	Y0 += 0.00000014826*np.cos(5.27106391752 + 63.847772888*t)
	Y0 += 0.00000014632*np.cos(3.70605916082 + 610.6923387854*t)
	Y0 += 0.00000014573*np.cos(5.69303672241 + 76.3142553854*t)
	Y0 += 0.00000014573*np.cos(2.12795836718 + 73.2489417492*t)
	Y0 += 0.00000014515*np.cos(6.13046180828 + 63.6240237188*t)
	Y0 += 0.00000018651*np.cos(0.33014377517 + 107.0249274817*t)
	Y0 += 0.00000015824*np.cos(1.02280522095 + 194.2885149114*t)
	Y0 += 0.00000014109*np.cos(6.15042431458 + 535.9107402181*t)
	Y0 += 0.00000019143*np.cos(4.20856207695 + 154.2984995498*t)
	Y0 += 0.00000017350*np.cos(4.77489944031 + 378.6432952517*t)
	Y0 += 0.00000017090*np.cos(5.84373455865 + 85.0765393058*t)
	Y0 += 0.00000017407*np.cos(2.05882445866 + 550.1378342197*t)
	Y0 += 0.00000013418*np.cos(2.06565331098 + 69.7856637212*t)
	Y0 += 0.00000013545*np.cos(2.20526550754 + 280.9671470045*t)
	Y0 += 0.00000016062*np.cos(0.58179678004 + 73.0364934281*t)
	Y0 += 0.00000016062*np.cos(0.95601300237 + 76.5267037065*t)
	Y0 += 0.00000015772*np.cos(3.90429897443 + 193.655375465*t)
	Y0 += 0.00000015368*np.cos(3.62887419403 + 60.5545045657*t)
	Y0 += 0.00000013244*np.cos(3.08157777565 + 501.3797894433*t)
	Y0 += 0.00000013094*np.cos(2.58882404011 + 12.0089081104*t)
	Y0 += 0.00000015317*np.cos(2.17090544987 + 134.0640787458*t)
	Y0 += 0.00000015934*np.cos(2.11466320925 + 703.6331846174*t)
	Y0 += 0.00000013153*np.cos(1.19799339989 + 224.8660605637*t)
	Y0 += 0.00000012895*np.cos(5.70317715970 + 883.7951792637*t)
	Y0 += 0.00000016329*np.cos(5.52724127720 + 176.6505325085*t)
	Y0 += 0.00000014158*np.cos(5.60862153409 + 147.5574595645*t)
	Y0 += 0.00000014094*np.cos(6.17561270564 + 39.0962434843*t)
	Y0 += 0.00000012513*np.cos(1.91122287401 + 195.7729876197*t)
	Y0 += 0.00000013295*np.cos(2.36096395500 + 322.6116447801*t)
	Y0 += 0.00000013527*np.cos(3.07687060542 + 76.1060125812*t)
	Y0 += 0.00000013527*np.cos(4.74412448417 + 73.4571845534*t)
	Y0 += 0.00000013958*np.cos(4.48591449080 + 60.112561581*t)
	Y0 += 0.00000016443*np.cos(2.74987558168 + 83.3796182764*t)
	Y0 += 0.00000012655*np.cos(3.47988510950 + 749.2098356561*t)
	Y0 += 0.00000016510*np.cos(3.74296742734 + 121.8427223143*t)
	Y0 += 0.00000016814*np.cos(4.41075674576 + 336.8387387817*t)
	Y0 += 0.00000012292*np.cos(2.75806341567 + 79.7775334134*t)
	Y0 += 0.00000016510*np.cos(5.52233148572 + 285.1117485887*t)
	Y0 += 0.00000015553*np.cos(2.92654153303 + 64.6991061499*t)
	Y0 += 0.00000012189*np.cos(2.65532986668 + 842.1506814881*t)
	Y0 += 0.00000016677*np.cos(5.76088073458 + 381.6122406683*t)
	Y0 += 0.00000011943*np.cos(0.42213661289 + 59.2824801785*t)
	Y0 += 0.00000013363*np.cos(4.43976529562 + 172.1971143836*t)
	Y0 += 0.00000016588*np.cos(1.61054621410 + 438.2982824457*t)
	Y0 += 0.00000011847*np.cos(1.60289765228 + 417.0369633204*t)
	Y0 += 0.00000014834*np.cos(0.90690489444 + 115.3623147599*t)
	Y0 += 0.00000013008*np.cos(2.89351174908 + 1097.0942747017*t)
	Y0 += 0.00000015159*np.cos(4.93130097290 + 118.0706277456*t)
	Y0 += 0.00000014519*np.cos(0.73690474458 + 1819.6374661092*t)
	Y0 += 0.00000011811*np.cos(3.34660929802 + 34.5309507748*t)
	Y0 += 0.00000013353*np.cos(3.47302692091 + 288.7350853111*t)
	Y0 += 0.00000012331*np.cos(2.92269904453 + 83.6884348171*t)
	Y0 += 0.00000011578*np.cos(0.67710449732 + 65.3322455963*t)
	Y0 += 0.00000012173*np.cos(0.17117716363 + 44.0921783304*t)
	Y0 += 0.00000011367*np.cos(2.45902849811 + 59.5912967192*t)
	Y0 += 0.00000011935*np.cos(1.38104691130 + 256.4280659219*t)
	Y0 += 0.00000011301*np.cos(4.33131047313 + 164.1203595363*t)
	Y0 += 0.00000015572*np.cos(2.77819126893 + 1059.3819301892*t)
	Y0 += 0.00000011090*np.cos(2.16461595995 + 55.8715917772*t)
	Y0 += 0.00000014191*np.cos(1.71094245264 + 124.2904028691*t)
	Y0 += 0.00000014583*np.cos(1.19984511600 + 406.1031376411*t)
	Y0 += 0.00000010768*np.cos(1.68225273790 + 466.7582159433*t)
	Y0 += 0.00000014342*np.cos(5.38282831087 + 404.6186649328*t)
	Y0 += 0.00000014813*np.cos(2.99911907613 + 47.061123747*t)
	Y0 += 0.00000012785*np.cos(0.10611241376 + 205.2223405907*t)
	Y0 += 0.00000010863*np.cos(1.57144632008 + 229.7614216733*t)
	Y0 += 0.00000010621*np.cos(0.35908343988 + 11.848849416*t)
	Y0 += 0.00000010749*np.cos(1.01461165684 + 151.850818995*t)
	Y0 += 0.00000011670*np.cos(4.42259077763 + 308.6876218248*t)
	Y0 += 0.00000010623*np.cos(1.71988698919 + 263.0203480609*t)
	Y0 += 0.00000014228*np.cos(1.61253324116 + 84.8640909847*t)
	Y0 += 0.00000012571*np.cos(0.54413812047 + 113.8778420516*t)
	Y0 += 0.00000010562*np.cos(1.47699734752 + 1108.1399749656*t)
	Y0 += 0.00000012234*np.cos(1.57689217779 + 118.8737768977*t)
	Y0 += 0.00000010485*np.cos(5.82765239186 + 105.380396079*t)
	Y0 += 0.00000010472*np.cos(0.27867447645 + 49.5088043018*t)
	Y0 += 0.00000012612*np.cos(3.14058189465 + 353.301065017*t)
	Y0 += 0.00000012785*np.cos(2.00022068392 + 757.8078553652*t)
	Y0 += 0.00000011539*np.cos(5.68756950373 + 75.3510475389*t)
	Y0 += 0.00000011539*np.cos(5.27501823945 + 74.2121495957*t)
	Y0 += 0.00000012272*np.cos(5.06355303230 + 1171.875873269*t)
	Y0 += 0.00000010737*np.cos(2.71181422069 + 552.5855147745*t)
	Y0 += 0.00000012562*np.cos(4.92895921367 + 109.3125493421*t)
	Y0 += 0.00000011375*np.cos(3.81808860702 + 546.956440482*t)
	Y0 += 0.00000011684*np.cos(1.21377406309 + 180.7951340927*t)
	Y0 += 0.00000010812*np.cos(0.46430555571 + 89.0086925689*t)
	Y0 += 0.00000010443*np.cos(0.81812110978 + 361.3778198643*t)
	Y0 += 0.00000009949*np.cos(5.61451137404 + 422.6660376129*t)
	Y0 += 0.00000011051*np.cos(5.41716692141 + 544.5087599272*t)
	Y0 += 0.00000009781*np.cos(4.00229890423 + 84.2309515383*t)
	Y0 += 0.00000010654*np.cos(3.65009209614 + 263.962304048*t)
	Y0 += 0.00000011318*np.cos(5.77251608576 + 43.5496616092*t)
	Y0 += 0.00000010734*np.cos(0.19349032271 + 89.4506355536*t)
	Y0 += 0.00000010593*np.cos(2.48672884196 + 71.7007785661*t)
	Y0 += 0.00000011184*np.cos(2.96936696687 + 150.3663462867*t)
	Y0 += 0.00000010242*np.cos(4.17472240690 + 177.3049238143*t)
	Y0 += 0.00000009899*np.cos(0.22320056950 + 207.8824694666*t)
	Y0 += 0.00000009406*np.cos(5.72421215324 + 69.3125829692*t)
	Y0 += 0.00000009406*np.cos(5.23837558994 + 80.2506141654*t)
	Y0 += 0.00000010031*np.cos(2.07665198858 + 63.9965307343*t)
	Y0 += 0.00000010094*np.cos(5.87961753510 + 69.9556734269*t)
	Y0 += 0.00000010841*np.cos(5.97074169778 + 483.2205421786*t)
	Y0 += 0.00000011965*np.cos(0.93110019198 + 754.8389099486*t)
	Y0 += 0.00000009710*np.cos(1.20269401520 + 217.4436970222*t)
	Y0 += 0.00000012674*np.cos(3.40700922514 + 337.8019466282*t)
	Y0 += 0.00000009823*np.cos(5.16832300250 + 153.186533857*t)
	Y0 += 0.00000010267*np.cos(5.20465459401 + 680.0573113813*t)
	Y0 += 0.00000011562*np.cos(5.23123134702 + 827.9235874865*t)
	Y0 += 0.00000010929*np.cos(3.11765296554 + 318.679491517*t)
	Y0 += 0.00000010742*np.cos(2.74602550756 + 400.1652468079*t)
	Y0 += 0.00000009954*np.cos(5.11935965746 + 79.6075237077*t)
	Y0 += 0.00000010258*np.cos(2.86914578171 + 443.8636662634*t)
	Y0 += 0.00000011193*np.cos(1.53824976312 + 112.6540017742*t)
	Y0 += 0.00000010112*np.cos(4.81465770550 + 196.6243208816*t)
	Y0 += 0.00000011236*np.cos(3.60322881200 + 679.2541622292*t)
	Y0 += 0.00000010391*np.cos(4.28740979080 + 30.5987975117*t)
	Y0 += 0.00000011035*np.cos(5.05306501350 + 204.7010757289*t)
	Y0 += 0.00000010257*np.cos(4.72952295598 + 30.6894202369*t)
	Y0 += 0.00000009597*np.cos(4.87795279417 + 292.0128472684*t)
	Y0 += 0.00000008297*np.cos(1.38743135300 + 674.4282370888*t)
	Y0 += 0.00000009433*np.cos(2.11672031795 + 670.4960838257*t)
	Y0 += 0.00000009226*np.cos(5.25948012740 + 73.8665748306*t)
	Y0 += 0.00000009226*np.cos(5.70310761578 + 75.696622304*t)
	Y0 += 0.00000008939*np.cos(3.07673404041 + 89.5993933999*t)
	Y0 += 0.00000009330*np.cos(6.27464135739 + 52.8020726241*t)
	Y0 += 0.00000009204*np.cos(2.03165690946 + 223.3815878554*t)
	Y0 += 0.00000008087*np.cos(0.84671801172 + 1022.3126761344*t)
	Y0 += 0.00000008842*np.cos(2.84360080314 + 437.6438911399*t)
	Y0 += 0.00000008044*np.cos(0.83166336147 + 77.1174045375*t)
	Y0 += 0.00000008044*np.cos(3.84773907453 + 72.4457925971*t)
	Y0 += 0.00000009956*np.cos(3.13550139505 + 366.485629295*t)
	Y0 += 0.00000007894*np.cos(2.51479045228 + 93.6916053574*t)
	Y0 += 0.00000009501*np.cos(3.98117068682 + 156.4642958143*t)
	Y0 += 0.00000009347*np.cos(0.34595654844 + 156.9855606761*t)
	Y0 += 0.00000008617*np.cos(2.59732031386 + 85.5666664003*t)
	Y0 += 0.00000008225*np.cos(5.33680321913 + 216.4804891757*t)
	Y0 += 0.00000008401*np.cos(2.71464714030 + 329.8370663655*t)
	Y0 += 0.00000007936*np.cos(2.06795339406 + 108.982480942*t)
	Y0 += 0.00000008607*np.cos(4.69707918551 + 62.9327491513*t)
	Y0 += 0.00000010505*np.cos(1.49273427538 + 210.8514148832*t)
	Y0 += 0.00000008920*np.cos(0.85529826739 + 118.0224436358*t)
	Y0 += 0.00000007747*np.cos(4.85251993051 + 208.8456773131*t)
	Y0 += 0.00000007543*np.cos(3.14113560246 + 77.016830801*t)
	Y0 += 0.00000007543*np.cos(4.67985948713 + 72.5463663336*t)
	Y0 += 0.00000008486*np.cos(3.16231049397 + 77.8624185685*t)
	Y0 += 0.00000007930*np.cos(5.13848606814 + 230.9370778409*t)
	Y0 += 0.00000007488*np.cos(2.09615005282 + 89.9719004154*t)
	Y0 += 0.00000008340*np.cos(3.52186355299 + 37.1698277913*t)
	Y0 += 0.00000007543*np.cos(5.65107781150 + 75.5153117502*t)
	Y0 += 0.00000007543*np.cos(2.16991727809 + 74.0478853844*t)
	Y0 += 0.00000009123*np.cos(1.47378498626 + 683.9894646444*t)
	Y0 += 0.00000008473*np.cos(3.11905002019 + 71.0095039986*t)
	Y0 += 0.00000008473*np.cos(1.56035241581 + 78.553693136*t)
	Y0 += 0.00000008637*np.cos(4.56259611109 + 253.4591205053*t)
	Y0 += 0.00000007840*np.cos(3.43391206110 + 1044.4040766622*t)
	Y0 += 0.00000007312*np.cos(0.20999433254 + 369.0820676961*t)
	Y0 += 0.00000009186*np.cos(1.99613458826 + 100.8051523582*t)
	Y0 += 0.00000007227*np.cos(5.27786714168 + 131.9252147317*t)
	Y0 += 0.00000007647*np.cos(0.27276712122 + 148.6694252573*t)
	Y0 += 0.00000007673*np.cos(3.99246895228 + 241.8709035202*t)
	Y0 += 0.00000008239*np.cos(2.52689364089 + 115.6229471908*t)
	Y0 += 0.00000008505*np.cos(3.92674400530 + 20.4950532349*t)
	Y0 += 0.00000008732*np.cos(3.10661058228 + 36.9091953604*t)
	Y0 += 0.00000008904*np.cos(1.84053282944 + 59.9638037347*t)
	Y0 += 0.00000007003*np.cos(5.60751778626 + 144.4553877039*t)
	Y0 += 0.00000008055*np.cos(1.54563741873 + 175.4266922311*t)
	Y0 += 0.00000007930*np.cos(3.93554290215 + 140.6563608848*t)
	Y0 += 0.00000007954*np.cos(4.06223295515 + 86.7905066777*t)
	Y0 += 0.00000006971*np.cos(1.96112655679 + 130.552616608*t)
	Y0 += 0.00000007835*np.cos(3.64665015583 + 325.3836482406*t)
	Y0 += 0.00000007607*np.cos(5.47726914934 + 409.0720830577*t)
	Y0 += 0.00000007074*np.cos(5.74851895878 + 350.3321196004*t)
	Y0 += 0.00000008543*np.cos(4.21577343156 + 304.1223291153*t)
	Y0 += 0.00000007388*np.cos(2.81311142997 + 33.0252262071*t)
	Y0 += 0.00000006809*np.cos(1.02610659483 + 561.1835344836*t)
	Y0 += 0.00000009209*np.cos(1.79255399765 + 474.9468453752*t)
	Y0 += 0.00000007310*np.cos(0.91958252559 + 21.1494445407*t)
	Y0 += 0.00000007536*np.cos(1.59048100371 + 425.1137181677*t)
	Y0 += 0.00000006559*np.cos(2.37613579061 + 129.1163280095*t)
	Y0 += 0.00000006623*np.cos(2.99305112717 + 44.6134431922*t)
	Y0 += 0.00000006791*np.cos(5.66453776650 + 41.7563723602*t)
	Y0 += 0.00000006957*np.cos(3.22863530078 + 753.1419889192*t)
	Y0 += 0.00000006851*np.cos(2.70895202823 + 301.4140161296*t)
	Y0 += 0.00000008444*np.cos(4.00381650923 + 344.7030453079*t)
	Y0 += 0.00000008617*np.cos(3.14518586851 + 150.4569690119*t)
	Y0 += 0.00000008448*np.cos(4.10192395818 + 249.9476583675*t)
	Y0 += 0.00000007676*np.cos(4.83442648042 + 60.2244361656*t)
	Y0 += 0.00000008927*np.cos(0.03475451069 + 749.5823426716*t)
	Y0 += 0.00000007702*np.cos(0.93795377619 + 237.4174853953*t)
	Y0 += 0.00000007174*np.cos(5.62425988881 + 445.7206459872*t)
	Y0 += 0.00000008136*np.cos(2.59047898473 + 927.9779803193*t)
	Y0 += 0.00000007105*np.cos(0.97447995190 + 6456.8800576977*t)
	Y0 += 0.00000007753*np.cos(4.97931501017 + 259.769518354*t)
	Y0 += 0.00000007998*np.cos(3.33317303740 + 403.1341922245*t)
	Y0 += 0.00000008396*np.cos(5.65756277879 + 514.7131115676*t)
	Y0 += 0.00000007507*np.cos(1.58185957582 + 298.2326223919*t)
	Y0 += 0.00000006716*np.cos(3.41190297117 + 810.6581120991*t)
	Y0 += 0.00000006636*np.cos(2.29732416607 + 497.4476361802*t)
	Y0 += 0.00000008204*np.cos(6.11947201971 + 763.4369296577*t)
	Y0 += 0.00000007310*np.cos(4.44939190727 + 188.6594406189*t)
	Y0 += 0.00000006185*np.cos(3.32365881402 + 401.5378449316*t)
	Y0 += 0.00000006266*np.cos(3.00305385805 + 14.8177948326*t)
	Y0 += 0.00000006391*np.cos(2.36254726924 + 212.3358875915*t)
	Y0 += 0.00000006736*np.cos(5.90647943809 + 271.61836777*t)
	Y0 += 0.00000007863*np.cos(3.74840739322 + 688.6553310904*t)
	Y0 += 0.00000006511*np.cos(5.73708048389 + 214.2623032845*t)
	Y0 += 0.00000007626*np.cos(5.84248316757 + 21.9795259432*t)
	Y0 += 0.00000006593*np.cos(0.92513779202 + 230.8252032563*t)
	Y0 += 0.00000007097*np.cos(0.55476052949 + 62.7726904569*t)
	Y0 += 0.00000006285*np.cos(2.50242046736 + 262.0571402144*t)
	Y0 += 0.00000007294*np.cos(5.22341373335 + 139.4807047172*t)
	Y0 += 0.00000007446*np.cos(0.25886416117 + 396.5419100855*t)
	Y0 += 0.00000006091*np.cos(1.01124713854 + 112.3933693433*t)
	Y0 += 0.00000008032*np.cos(0.83846257555 + 223.8235308401*t)
	Y0 += 0.00000005742*np.cos(4.76669456538 + 20202.22629672009*t)
	Y0 += 0.00000007250*np.cos(5.71919114487 + 1065.6017053127*t)
	Y0 += 0.00000006665*np.cos(2.98305275448 + 436.8138097374*t)
	Y0 += 0.00000007231*np.cos(5.43466319964 + 267.2131337549*t)
	Y0 += 0.00000006949*np.cos(3.01532739453 + 197.7999770492*t)
	Y0 += 0.00000006362*np.cos(2.10485537221 + 33.9402499438*t)
	Y0 += 0.00000006445*np.cos(5.63279998806 + 332.1728723357*t)
	Y0 += 0.00000005915*np.cos(3.81845923426 + 87.0511391086*t)
	Y0 += 0.00000005915*np.cos(0.86094320174 + 62.512058026*t)
	Y0 += 0.00000005541*np.cos(2.05931234771 + 21.1976286505*t)
	Y0 += 0.00000006293*np.cos(2.98872336268 + 178.1350052168*t)
	Y0 += 0.00000006922*np.cos(3.28593901075 + 407.5876103494*t)
	Y0 += 0.00000005625*np.cos(0.99982812641 + 42.0651889009*t)
	Y0 += 0.00000005495*np.cos(0.83010161211 + 158.9643659958*t)
	Y0 += 0.00000005484*np.cos(2.05186117586 + 293.7097682978*t)
	Y0 += 0.00000005543*np.cos(5.96744481273 + 188.2387494936*t)
	Y0 += 0.00000006364*np.cos(3.80553369638 + 809.0135806964*t)
	Y0 += 0.00000005577*np.cos(4.10482519606 + 168.6856522458*t)
	Y0 += 0.00000006551*np.cos(0.83934641149 + 1514.2912967165*t)
	Y0 += 0.00000007077*np.cos(5.51744981315 + 441.2672278623*t)
	Y0 += 0.00000006689*np.cos(5.42351008501 + 170.7126416753*t)
	Y0 += 0.00000006276*np.cos(4.68795182405 + 96.7611245105*t)
	Y0 += 0.00000007570*np.cos(1.01180557606 + 358.9301393095*t)
	Y0 += 0.00000005509*np.cos(4.78231890598 + 1235.6117715724*t)
	Y0 += 0.00000006352*np.cos(3.79204185042 + 369.9758395734*t)
	Y0 += 0.00000005383*np.cos(6.27032111126 + 817.7716590999*t)
	Y0 += 0.00000005492*np.cos(0.69694956792 + 89.338760969*t)
	Y0 += 0.00000005488*np.cos(2.09536181568 + 136.2298750103*t)
	Y0 += 0.00000006116*np.cos(2.19989108028 + 252.6559713532*t)
	Y0 += 0.00000005209*np.cos(0.50325710014 + 354.9979860464*t)
	Y0 += 0.00000006649*np.cos(3.14952088065 + 5994.9951559861*t)
	Y0 += 0.00000006243*np.cos(0.48442739628 + 86.6304479833*t)
	Y0 += 0.00000005460*np.cos(5.86544531140 + 27.7417266797*t)
	Y0 += 0.00000006432*np.cos(3.35626050583 + 524.2743391232*t)
	Y0 += 0.00000006045*np.cos(2.75503960638 + 181.0557665236*t)
	Y0 += 0.00000007138*np.cos(3.09631574158 + 2199.7652340692*t)
	Y0 += 0.00000005574*np.cos(6.17476595947 + 358.4088744477*t)
	Y0 += 0.00000005121*np.cos(1.19398299131 + 823.9914342234*t)
	Y0 += 0.00000005631*np.cos(2.90023214886 + 67.8804998876*t)
	Y0 += 0.00000005479*np.cos(2.12392901319 + 229.340730548*t)
	Y0 += 0.00000005296*np.cos(1.73996111678 + 65.8747623175*t)
	Y0 += 0.00000004956*np.cos(2.57399481330 + 450.1740641121*t)
	Y0 += 0.00000005382*np.cos(5.25698246848 + 269.9214467406*t)
	Y0 += 0.00000004899*np.cos(1.18975478010 + 123.0183784819*t)
	Y0 += 0.00000005115*np.cos(4.35560444308 + 691.1030116452*t)
	Y0 += 0.00000006347*np.cos(4.93421901844 + 300.8927512678*t)
	Y0 += 0.00000005407*np.cos(2.11877006223 + 147.9186657319*t)
	Y0 += 0.00000005610*np.cos(4.82031208158 + 164.3809919672*t)
	Y0 += 0.00000005903*np.cos(3.13251711248 + 1595.2926704073*t)
	Y0 += 0.00000006409*np.cos(4.61295823604 + 9925.2048522057*t)
	Y0 += 0.00000005054*np.cos(1.52779715235 + 343.7398374614*t)
	Y0 += 0.00000005898*np.cos(1.17168914170 + 711.4493070338*t)
	Y0 += 0.00000005465*np.cos(4.18395388726 + 49.6518166537*t)
	Y0 += 0.00000004962*np.cos(1.68095727826 + 40.2506477925*t)
	Y0 += 0.00000006619*np.cos(5.58001607792 + 104.5772469269*t)
	Y0 += 0.00000006198*np.cos(4.10613906306 + 29.7474642498*t)
	Y0 += 0.00000005637*np.cos(4.27082303931 + 461.1291416508*t)
	Y0 += 0.00000005966*np.cos(6.21670107028 + 475.3562356524*t)
	Y0 += 0.00000004734*np.cos(3.12449796048 + 1246.6574718363*t)
	Y0 += 0.00000005562*np.cos(1.99066275349 + 97.4155158163*t)
	Y0 += 0.00000005517*np.cos(0.15734159045 + 85.7154242466*t)
	Y0 += 0.00000005675*np.cos(3.90753165469 + 373.0142209592*t)
	Y0 += 0.00000005678*np.cos(2.45575163692 + 1291.4309737229*t)
	Y0 += 0.00000005473*np.cos(1.31181892044 + 118.8525250383*t)
	Y0 += 0.00000005562*np.cos(4.75165226491 + 469.7271613599*t)
	Y0 += 0.00000004792*np.cos(3.51144392647 + 257.3912737684*t)
	Y0 += 0.00000005402*np.cos(4.88902304378 + 170.0100662597*t)
	Y0 += 0.00000004598*np.cos(2.05332533302 + 155.1922714271*t)
	Y0 += 0.00000006214*np.cos(1.35052411760 + 442.7517005706*t)
	Y0 += 0.00000004980*np.cos(3.11819833041 + 527.2432845398*t)
	Y0 += 0.00000005988*np.cos(0.50320541583 + 194.1766403268*t)
	Y0 += 0.00000006196*np.cos(3.32366686883 + 612.1768114937*t)
	Y0 += 0.00000004509*np.cos(2.39066728384 + 106.4342266507*t)
	Y0 += 0.00000004989*np.cos(3.48472287325 + 53.653405886*t)
	Y0 += 0.00000006128*np.cos(1.41218645179 + 1288.4620283063*t)
	Y0 += 0.00000004508*np.cos(5.33731589869 + 240.3864308119*t)
	Y0 += 0.00000006167*np.cos(2.29263489637 + 206.706813299*t)
	Y0 += 0.00000004598*np.cos(1.27745263577 + 224.084163271*t)
	Y0 += 0.00000004907*np.cos(1.07886754186 + 470.6903692064*t)
	Y0 += 0.00000005173*np.cos(4.14114765790 + 635.9651330509*t)
	Y0 += 0.00000004359*np.cos(3.91866659735 + 294.3004691288*t)
	Y0 += 0.00000004518*np.cos(5.13302342435 + 529.851023789*t)
	Y0 += 0.00000004648*np.cos(3.41738055483 + 191.3195694948*t)
	Y0 += 0.00000004527*np.cos(4.89681935281 + 100.0543928328*t)
	Y0 += 0.00000004675*np.cos(0.74793286059 + 818.574808252*t)
	Y0 += 0.00000004894*np.cos(4.91824021653 + 127.5836711914*t)
	Y0 += 0.00000004503*np.cos(2.34824315382 + 529.5309064002*t)
	Y0 += 0.00000005755*np.cos(3.47614160575 + 896.3253522359*t)
	Y0 += 0.00000005038*np.cos(2.04655318056 + 346.3999663373*t)
	Y0 += 0.00000005109*np.cos(5.61003161097 + 44.9859502077*t)
	Y0 += 0.00000005415*np.cos(1.93853282815 + 193.9160078959*t)
	Y0 += 0.00000004870*np.cos(3.01914083748 + 1072.7152523135*t)
	Y0 += 0.00000004502*np.cos(5.84898608016 + 523.4711899711*t)
	Y0 += 0.00000005508*np.cos(4.72051414998 + 487.8864086246*t)
	Y0 += 0.00000005946*np.cos(4.65667500042 + 457.1969883877*t)
	Y0 += 0.00000004672*np.cos(2.79859052481 + 178.677521938*t)
	Y0 += 0.00000004318*np.cos(0.99378487572 + 1578.0271950199*t)
	Y0 += 0.00000004654*np.cos(3.23017033482 + 316.3918696566*t)
	Y0 += 0.00000005743*np.cos(3.56115198872 + 246.4361962297*t)
	Y0 += 0.00000005256*np.cos(0.82645339083 + 453.424893819*t)
	Y0 += 0.00000005380*np.cos(3.43490881372 + 444.2361732789*t)
	Y0 += 0.00000005597*np.cos(0.78287898333 + 771.1042942278*t)
	Y0 += 0.00000004689*np.cos(4.33230942667 + 213.9534867438*t)
	Y0 += 0.00000005661*np.cos(0.85799990392 + 315.1680293792*t)
	Y0 += 0.00000004910*np.cos(4.65280709692 + 1019.7644218431*t)
	Y0 += 0.00000004836*np.cos(2.67069000347 + 555.5544601911*t)
	Y0 += 0.00000005667*np.cos(5.10831237910 + 476.3194434989*t)
	Y0 += 0.00000004814*np.cos(4.45560046617 + 3041.4860324306*t)
	Y0 += 0.00000004196*np.cos(5.83265732730 + 181.6464673546*t)
	Y0 += 0.00000005081*np.cos(5.50274003196 + 223.4510238246*t)
	Y0 += 0.00000004121*np.cos(2.65208008966 + 95.9792272178*t)
	Y0 += 0.00000004119*np.cos(2.13510129984 + 2120.2483330867*t)
	Y0 += 0.00000004381*np.cos(3.00238354556 + 192.8040422031*t)
	Y0 += 0.00000004915*np.cos(5.97704604569 + 280.003939158*t)
	Y0 += 0.00000004692*np.cos(0.21351515154 + 335.1418177523*t)
	Y0 += 0.00000004739*np.cos(2.65624104210 + 25788.776747305*t)
	Y0 += 0.00000004505*np.cos(0.42320594676 + 158.7519176747*t)
	Y0 += 0.00000005697*np.cos(2.84928936803 + 772.5887669361*t)
	Y0 += 0.00000005524*np.cos(4.68675383722 + 491.8185618877*t)
	Y0 += 0.00000004207*np.cos(0.70498638267 + 1158.5425511447*t)
	Y0 += 0.00000004302*np.cos(2.50410696302 + 99.8419445117*t)
	Y0 += 0.00000004499*np.cos(1.69054737728 + 227.5956254088*t)
	Y0 += 0.00000004986*np.cos(0.94681765821 + 683.0262567979*t)
	Y0 += 0.00000005388*np.cos(0.76342177995 + 236.5024616586*t)
	Y0 += 0.00000005239*np.cos(3.48835357503 + 236.1936451179*t)
	Y0 += 0.00000005420*np.cos(3.85541340494 + 196.8367692027*t)
	Y0 += 0.00000003985*np.cos(1.74985561339 + 765.8846102125*t)
	Y0 += 0.00000005017*np.cos(2.82902794302 + 305.6068018236*t)
	Y0 += 0.00000005549*np.cos(2.55013138496 + 296.7481496836*t)
	Y0 += 0.00000003959*np.cos(3.93854751155 + 150.9357952583*t)
	Y0 += 0.00000003964*np.cos(5.16439207994 + 898.7730327907*t)
	Y0 += 0.00000004546*np.cos(0.76152857132 + 44.1828010556*t)
	Y0 += 0.00000004191*np.cos(1.28952699952 + 305.4580439773*t)
	Y0 += 0.00000003906*np.cos(1.61614597487 + 36.1754821775*t)
	Y0 += 0.00000004353*np.cos(6.26093399379 + 1360.7959463188*t)
	Y0 += 0.00000003887*np.cos(5.52990086078 + 1020.025054274*t)
	Y0 += 0.00000003999*np.cos(5.39158640547 + 55.8192021505*t)
	Y0 += 0.00000003999*np.cos(5.57100133771 + 93.7439949841*t)
	Y0 += 0.00000004086*np.cos(2.82476260110 + 168.5737776612*t)
	Y0 += 0.00000004059*np.cos(3.71867492753 + 605.275712814*t)
	Y0 += 0.00000004152*np.cos(2.40430598219 + 957.0923051227*t)
	Y0 += 0.00000004621*np.cos(4.84012764065 + 887.7273325268*t)
	Y0 += 0.00000003988*np.cos(4.88917159380 + 838.218528225*t)
	Y0 += 0.00000004087*np.cos(3.31579342541 + 770.3380283374*t)
	Y0 += 0.00000003954*np.cos(2.90730336124 + 383.3091616977*t)
	Y0 += 0.00000004413*np.cos(4.73853343073 + 215.7467759928*t)
	Y0 += 0.00000003919*np.cos(5.97203131124 + 325.9530972122*t)
	Y0 += 0.00000003864*np.cos(4.39331560943 + 661.0949149645*t)
	Y0 += 0.00000003999*np.cos(1.24873798049 + 532.8723588323*t)
	Y0 += 0.00000003829*np.cos(0.14712587806 + 627.3671133418*t)
	Y0 += 0.00000004658*np.cos(1.00953022027 + 621.7380390493*t)
	Y0 += 0.00000004055*np.cos(5.20456503366 + 139.1718881765*t)
	Y0 += 0.00000004774*np.cos(3.44138717156 + 379.0158022672*t)
	Y0 += 0.00000003836*np.cos(5.86821877824 + 980.6681783588*t)
	Y0 += 0.00000004300*np.cos(5.49265158827 + 302.637856407*t)
	Y0 += 0.00000003731*np.cos(2.11144668658 + 138.4056222861*t)
	Y0 += 0.00000004472*np.cos(3.91234474083 + 302.3772239761*t)
	Y0 += 0.00000004415*np.cos(3.74731379047 + 484.917463208*t)
	Y0 += 0.00000003879*np.cos(3.47723723889 + 525.4981794006*t)
	Y0 += 0.00000004584*np.cos(2.02399047239 + 30.1681553751*t)
	Y0 += 0.00000004326*np.cos(6.02567448655 + 1325.3712236667*t)
	Y0 += 0.00000004430*np.cos(2.72703097214 + 781.5961769224*t)
	Y0 += 0.00000003918*np.cos(3.85941866753 + 367.8582274187*t)
	Y0 += 0.00000003721*np.cos(0.89189960470 + 1474.9344208013*t)
	Y0 += 0.00000004770*np.cos(2.09028108448 + 589.3459522886*t)
	Y0 += 0.00000005123*np.cos(0.20460862447 + 786.2309056011*t)
	Y0 += 0.00000003737*np.cos(4.07017660543 + 909.9306076392*t)
	Y0 += 0.00000004851*np.cos(2.61214772786 + 893.3564068193*t)
	Y0 += 0.00000003662*np.cos(1.79348143509 + 137.5542890242*t)
	Y0 += 0.00000004682*np.cos(4.98128078945 + 374.7111419886*t)
	Y0 += 0.00000004268*np.cos(4.11953895138 + 847.5673074595*t)
	Y0 += 0.00000003781*np.cos(1.78800192594 + 1041.2226829245*t)
	Y0 += 0.00000004629*np.cos(5.06095468669 + 324.7292569348*t)
	Y0 += 0.00000003764*np.cos(3.93531242815 + 68.631259413*t)
	Y0 += 0.00000003764*np.cos(3.88568266144 + 80.9319377216*t)
	Y0 += 0.00000004074*np.cos(5.32356906771 + 121.2520214833*t)
	Y0 += 0.00000003647*np.cos(0.37271083980 + 154.5591319807*t)
	Y0 += 0.00000004248*np.cos(1.59557710453 + 291.1190753911*t)
	Y0 += 0.00000003625*np.cos(5.03930311956 + 243.0947437976*t)
	Y0 += 0.00000004702*np.cos(4.20458650202 + 292.8159964205*t)
	Y0 += 0.00000003671*np.cos(2.67932521049 + 699.7010313543*t)
	Y0 += 0.00000004647*np.cos(4.59791942784 + 700.7761137854*t)
	Y0 += 0.00000004582*np.cos(4.27719752642 + 119.3950417595*t)
	Y0 += 0.00000003607*np.cos(2.92960383588 + 812.9457339595*t)
	Y0 += 0.00000004176*np.cos(4.53729438891 + 305.2342948081*t)
	Y0 += 0.00000004107*np.cos(3.02040976577 + 1169.3276189777*t)
	Y0 += 0.00000004274*np.cos(5.55202962588 + 310.9752436852*t)
	Y0 += 0.00000004644*np.cos(4.88019478247 + 636.6677084665*t)
	Y0 += 0.00000004216*np.cos(1.83174409680 + 473.659314623*t)
	Y0 += 0.00000003589*np.cos(4.99117677975 + 1340.3490771937*t)
	Y0 += 0.00000004183*np.cos(4.66392569183 + 1574.8458012822*t)
	Y0 += 0.00000004020*np.cos(4.11186979424 + 356.9244017394*t)
	Y0 += 0.00000004670*np.cos(1.56528512709 + 695.0351649083*t)
	Y0 += 0.00000003845*np.cos(4.50189530325 + 419.4846438752*t)
	Y0 += 0.00000003973*np.cos(3.86247061466 + 523.7530742614*t)
	Y0 += 0.00000004284*np.cos(5.48575256159 + 686.958410061*t)
	Y0 += 0.00000004097*np.cos(1.83593259138 + 6137.4448061199*t)
	Y0 += 0.00000004758*np.cos(1.54259600301 + 901.9544265284*t)
	Y0 += 0.00000004866*np.cos(0.38498763434 + 822.8794685306*t)
	Y0 += 0.00000003661*np.cos(1.38674719917 + 320.1639642253*t)
	Y0 += 0.00000004418*np.cos(6.09138093441 + 658.6472344097*t)
	Y0 += 0.00000003744*np.cos(0.23704621175 + 1254.5217783625*t)
	Y0 += 0.00000004110*np.cos(0.50850463101 + 511.5317178299*t)
	Y0 += 0.00000003432*np.cos(4.78365888244 + 694.0719570618*t)
	Y0 += 0.00000003863*np.cos(5.74425607755 + 48.2367799146*t)
	Y0 += 0.00000003837*np.cos(1.38885578297 + 761.7400086283*t)
	Y0 += 0.00000004432*np.cos(5.42306462039 + 1685.0521225016*t)
	Y0 += 0.00000003835*np.cos(0.13280488709 + 313.42292424*t)
	Y0 += 0.00000004779*np.cos(2.94544355989 + 16.6110840816*t)
	Y0 += 0.00000003364*np.cos(5.63413232593 + 1049.8207026336*t)
	Y0 += 0.00000004033*np.cos(3.10416870974 + 548.6533615114*t)
	Y0 += 0.00000003551*np.cos(5.33275323151 + 1385.174968707*t)
	Y0 += 0.00000004361*np.cos(4.27096901239 + 1031.87390369*t)
	Y0 += 0.00000003751*np.cos(0.56092257594 + 1282.8329540138*t)
	Y0 += 0.00000004206*np.cos(0.51867441574 + 435.1962105851*t)
	Y0 += 0.00000004643*np.cos(5.10102532835 + 6170.1612157863*t)
	Y0 += 0.00000003760*np.cos(5.29873313532 + 314.9073969483*t)
	Y0 += 0.00000003474*np.cos(1.81599961423 + 182.6096752011*t)
	Y0 += 0.00000003898*np.cos(4.83910213339 + 1056.4129847726*t)
	Y0 += 0.00000003948*np.cos(3.45809672503 + 270.1820791715*t)
	Y0 += 0.00000004025*np.cos(6.22179651521 + 432.2272651685*t)
	Y0 += 0.00000003592*np.cos(4.53264605132 + 250.6020496733*t)
	Y0 += 0.00000003866*np.cos(3.25864749062 + 10067.6545023395*t)
	Y0 += 0.00000003972*np.cos(4.86850120198 + 185.5786206177*t)
	Y0 += 0.00000003287*np.cos(5.02792890637 + 321.7603115182*t)
	Y0 += 0.00000004589*np.cos(6.17659620498 + 25483.43057791229*t)
	Y0 += 0.00000004308*np.cos(1.72886095548 + 516.0488264296*t)
	Y0 += 0.00000003824*np.cos(4.86838182782 + 6129.5804995937*t)
	Y0 += 0.00000003914*np.cos(1.59286207365 + 254.0922599517*t)
	Y0 += 0.00000004276*np.cos(5.28912748249 + 1034.8428491066*t)
	Y0 += 0.00000004580*np.cos(1.69358758590 + 2736.1398630379*t)
	Y0 += 0.00000003932*np.cos(5.67503368913 + 16.1535096946*t)
	Y0 += 0.00000004157*np.cos(4.37604672561 + 771.3012361839*t)
	Y0 += 0.00000003357*np.cos(5.26599059550 + 1182.9215735329*t)
	Y0 += 0.00000003802*np.cos(0.31702655607 + 498.4108440267*t)
	Y0 += 0.00000004524*np.cos(2.81439668092 + 526.9826521089*t)
	Y0 += 0.00000004197*np.cos(0.13935063439 + 630.3360587584*t)
	Y0 += 0.00000003980*np.cos(0.47806410404 + 433.190473015*t)
	Y0 += 0.00000003885*np.cos(5.95792292094 + 442.639825986*t)
	Y0 += 0.00000003519*np.cos(1.85756489257 + 613.8737325231*t)
	Y0 += 0.00000003513*np.cos(2.88278756465 + 188.0263011725*t)
	Y0 += 0.00000003436*np.cos(2.22930515523 + 517.4214245533*t)
	Y0 += 0.00000004478*np.cos(3.59865678356 + 439.782755154*t)
	Y0 += 0.00000003180*np.cos(4.31533563775 + 280.2163874791*t)
	Y0 += 0.00000003268*np.cos(2.43000508529 + 59.0005958882*t)
	Y0 += 0.00000003917*np.cos(3.58109182364 + 487.1045113319*t)
	Y0 += 0.00000003161*np.cos(0.04314663008 + 2002.9808544932*t)
	Y0 += 0.00000004307*np.cos(3.08432026736 + 269.0701134787*t)
	Y0 += 0.00000003534*np.cos(4.93365648849 + 78039.36462902068*t)
	Y0 += 0.00000003334*np.cos(5.87424656754 + 409.9234163196*t)
	Y0 += 0.00000003534*np.cos(1.66332277497 + 293.188503436*t)
	Y0 += 0.00000003178*np.cos(4.19263695155 + 1886.5547581503*t)
	Y0 += 0.00000004221*np.cos(3.28486189404 + 102.5020733876*t)
	Y0 += 0.00000003880*np.cos(6.15502337563 + 395.0574373772*t)
	Y0 += 0.00000003252*np.cos(5.49171969627 + 1016.0929010109*t)
	Y0 += 0.00000003211*np.cos(3.96787240218 + 151.5689347047*t)
	Y0 += 0.00000003204*np.cos(5.65877015739 + 1134.1635287565*t)
	Y0 += 0.00000003516*np.cos(2.35584399507 + 470.4934272503*t)
	Y0 += 0.00000003360*np.cos(6.04785619263 + 391.976617376*t)
	Y0 += 0.00000004375*np.cos(0.24053416584 + 10100.3709120059*t)
	Y0 += 0.00000003602*np.cos(1.87398401659 + 450.7165808333*t)
	Y0 += 0.00000003390*np.cos(3.82992900330 + 5909.1678571549*t)
	Y0 += 0.00000003129*np.cos(5.68080322000 + 367.5975949878*t)
	Y0 += 0.00000003895*np.cos(5.38443342197 + 908.3342603463*t)
	Y0 += 0.00000003088*np.cos(2.91502414964 + 828.8173593638*t)
	Y0 += 0.00000004286*np.cos(2.93382005841 + 502.8642621516*t)
	Y0 += 0.00000003547*np.cos(5.90190558732 + 38.6061163898*t)
	Y0 += 0.00000003069*np.cos(2.00421290803 + 53.3233374859*t)
	Y0 += 0.00000003066*np.cos(3.18232490188 + 978.9712573294*t)
	Y0 += 0.00000003876*np.cos(5.24050330423 + 757.2865905034*t)
	Y0 += 0.00000003602*np.cos(0.00785737841 + 10059.7901958133*t)
	Y0 += 0.00000003701*np.cos(3.32793381044 + 669.0116111174*t)
	Y0 += 0.00000003492*np.cos(3.18924557683 + 473.4623726669*t)
	Y0 += 0.00000003277*np.cos(5.58265745425 + 302.8984888379*t)
	Y0 += 0.00000003972*np.cos(0.62147303592 + 980.146913497*t)
	Y0 += 0.00000003045*np.cos(0.45901625314 + 1190.7858800591*t)
	Y0 += 0.00000003556*np.cos(1.72055863101 + 366.1131222795*t)
	Y0 += 0.00000003047*np.cos(2.13930792847 + 74.5691502462*t)
	Y0 += 0.00000003047*np.cos(5.68168716112 + 74.9940468884*t)
	Y0 += 0.00000003604*np.cos(3.76279864957 + 362.0322111701*t)
	Y0 += 0.00000003631*np.cos(3.48017920050 + 2175.386211681*t)
	Y0 += 0.00000004281*np.cos(6.17088765144 + 469.1364605289*t)
	Y0 += 0.00000004032*np.cos(2.53505702317 + 243.3553762285*t)
	Y0 += 0.00000003319*np.cos(5.00194008223 + 102.523325247*t)
	Y0 += 0.00000003678*np.cos(2.04259335984 + 798.3885715578*t)
	Y0 += 0.00000003020*np.cos(1.70332824071 + 643.8294395771*t)
	Y0 += 0.00000003542*np.cos(1.77314432935 + 376.9463742223*t)
	Y0 += 0.00000004108*np.cos(3.83404968637 + 488.8496164711*t)
	Y0 += 0.00000003154*np.cos(5.49016454601 + 6533.1461289733*t)
	Y0 += 0.00000003365*np.cos(4.21348165403 + 1372.6447957348*t)
	Y0 += 0.00000003450*np.cos(0.04029729019 + 1205.9761819072*t)
	Y0 += 0.00000002993*np.cos(5.76942655237 + 182.279606801*t)
	Y0 += 0.00000003359*np.cos(6.11527569072 + 576.1613880106*t)
	Y0 += 0.00000003108*np.cos(3.36297518119 + 759.2923280735*t)
	Y0 += 0.00000004142*np.cos(0.48490269718 + 614.8369403696*t)
	Y0 += 0.00000004137*np.cos(1.16115371523 + 436.1594184316*t)
	Y0 += 0.00000003894*np.cos(3.31652794041 + 1894.4190646765*t)
	Y0 += 0.00000004107*np.cos(4.13508560420 + 549.7284439425*t)
	Y0 += 0.00000002976*np.cos(4.40870494577 + 1095.6098019934*t)
	Y0 += 0.00000003429*np.cos(2.03603945431 + 244.791664827*t)
	Y0 += 0.00000003551*np.cos(4.79004764777 + 261.9565664779*t)
	Y0 += 0.00000003571*np.cos(1.73924705151 + 245.5424243524*t)
	Y0 += 0.00000004116*np.cos(0.91321363317 + 195.4004806042*t)
	Y0 += 0.00000003764*np.cos(2.15920959028 + 751.0668153799*t)
	Y0 += 0.00000004087*np.cos(5.51343159668 + 6663.2036179514*t)
	Y0 += 0.00000002940*np.cos(0.97064608288 + 380.8785274854*t)
	Y0 += 0.00000002922*np.cos(5.32735300987 + 94.7553869404*t)
	Y0 += 0.00000002922*np.cos(5.63523473331 + 54.8078101942*t)
	Y0 += 0.00000002944*np.cos(3.31043387588 + 1257.7031721002*t)
	Y0 += 0.00000003189*np.cos(5.25244551844 + 9839.3775533745*t)
	Y0 += 0.00000003792*np.cos(1.83880598690 + 1147.4968508808*t)
	Y0 += 0.00000002928*np.cos(6.15649738369 + 47.2735720681*t)
	Y0 += 0.00000002914*np.cos(3.43637767180 + 379.3770084346*t)
	Y0 += 0.00000004097*np.cos(3.23026292909 + 2885.7030601725*t)
	Y0 += 0.00000003882*np.cos(0.33608583935 + 583.4080614554*t)
	Y0 += 0.00000004053*np.cos(1.43700749488 + 25632.99377504689*t)
	Y0 += 0.00000003746*np.cos(5.29804876077 + 5985.4339284305*t)
	Y0 += 0.00000003715*np.cos(1.78912631656 + 764.921402366*t)
	Y0 += 0.00000002876*np.cos(2.46513366154 + 90.5626012464*t)
	Y0 += 0.00000003840*np.cos(5.45031778630 + 827.1728279611*t)
	Y0 += 0.00000003496*np.cos(1.71669892763 + 3114.7831582896*t)
	Y0 += 0.00000003871*np.cos(1.99142366153 + 511.5954083047*t)
	Y0 += 0.00000002948*np.cos(1.96340890716 + 78338.49102328988*t)
	Y0 += 0.00000002901*np.cos(2.21466410541 + 493.5154829171*t)
	Y0 += 0.00000002872*np.cos(4.35227364990 + 429.7795846137*t)
	Y0 += 0.00000002938*np.cos(5.00889886419 + 590.2454696603*t)
	Y0 += 0.00000003898*np.cos(2.74281508905 + 669.6929346736*t)
	Y0 += 0.00000003354*np.cos(4.29548223894 + 632.0329797878*t)
	Y0 += 0.00000003036*np.cos(2.72434442822 + 328.9220426288*t)
	Y0 += 0.00000003002*np.cos(0.18956003485 + 1061.6695520496*t)
	Y0 += 0.00000003276*np.cos(3.00636571119 + 520.129737539*t)
	Y0 += 0.00000003016*np.cos(2.64916865285 + 132.5796060375*t)
	Y0 += 0.00000003851*np.cos(4.25270851705 + 224.9354965329*t)
	Y0 += 0.00000003686*np.cos(5.67893032773 + 477.9157907918*t)
	Y0 += 0.00000003319*np.cos(1.56808296540 + 323.5054166574*t)
	Y0 += 0.00000003801*np.cos(5.95545646315 + 3117.7521037062*t)
	Y0 += 0.00000002836*np.cos(1.20341125847 + 373.535485821*t)
	Y0 += 0.00000003186*np.cos(1.44507525550 + 53.6321540266*t)
	Y0 += 0.00000003504*np.cos(0.16804844040 + 6272.0301497275*t)
	Y0 += 0.00000003733*np.cos(1.03466079195 + 909.70685847*t)
	Y0 += 0.00000003219*np.cos(1.56423135935 + 519.6084726772*t)
	Y0 += 0.00000003184*np.cos(1.08716105218 + 5982.4649830139*t)
	Y0 += 0.00000003789*np.cos(2.99891680203 + 1054.9285120643*t)
	Y0 += 0.00000002984*np.cos(5.13821226511 + 162.635886828*t)
	Y0 += 0.00000003563*np.cos(5.99821639641 + 1336.4169239306*t)
	Y0 += 0.00000002902*np.cos(0.22050049109 + 47.2211824414*t)
	Y0 += 0.00000002902*np.cos(4.45890194491 + 102.3420146932*t)
	Y0 += 0.00000003516*np.cos(5.73369868016 + 1094.8066528413*t)
	Y0 += 0.00000003254*np.cos(5.74820689948 + 482.3692089167*t)
	Y0 += 0.00000003939*np.cos(1.61262063639 + 6096.8640899273*t)
	Y0 += 0.00000002921*np.cos(1.87863990334 + 340.8827666294*t)
	Y0 += 0.00000002802*np.cos(0.40865505421 + 1592.0418407004*t)
	Y0 += 0.00000003387*np.cos(6.19933351520 + 25862.073873164*t)
	Y0 += 0.00000003884*np.cos(0.65443948228 + 10593.413314171*t)
	Y0 += 0.00000002852*np.cos(3.40843040314 + 2118.7638603784*t)
	Y0 += 0.00000002854*np.cos(3.71549072767 + 227.9681324243*t)
	Y0 += 0.00000003870*np.cos(0.74129906666 + 2124.9836355019*t)
	Y0 += 0.00000003048*np.cos(4.51779447707 + 6530.1771835567*t)
	Y0 += 0.00000002791*np.cos(1.68241228451 + 698.0041103249*t)
	Y0 += 0.00000003265*np.cos(0.17507793485 + 265.7286610466*t)
	Y0 += 0.00000003666*np.cos(3.65480173708 + 415.6643651967*t)
	Y0 += 0.00000003430*np.cos(1.34035853413 + 748.0978699633*t)
	Y0 += 0.00000002806*np.cos(4.02233962356 + 281.4884118663*t)
	Y0 += 0.00000002775*np.cos(2.76210601485 + 551.7823656224*t)
	Y0 += 0.00000003696*np.cos(4.15453207290 + 25865.04281858059*t)
	Y0 += 0.00000002816*np.cos(0.52106074112 + 294.5611015597*t)
	Y0 += 0.00000002804*np.cos(3.60450579406 + 2088.8081533244*t)
	Y0 += 0.00000002766*np.cos(0.96756499866 + 1600.1185955477*t)
	Y0 += 0.00000002753*np.cos(2.67377558669 + 1160.8301730051*t)
	Y0 += 0.00000003634*np.cos(1.43359949431 + 77.6386693993*t)
	Y0 += 0.00000003634*np.cos(0.10421028810 + 71.9245277353*t)
	Y0 += 0.00000003082*np.cos(4.33431584897 + 436.7501192626*t)
	Y0 += 0.00000003846*np.cos(4.24087562170 + 113.4571509263*t)
	Y0 += 0.00000002933*np.cos(6.06497119365 + 829.6205085159*t)
	Y0 += 0.00000002835*np.cos(4.82037050662 + 778.4147831847*t)
	Y0 += 0.00000003310*np.cos(2.22728155735 + 201.2901873276*t)
	Y0 += 0.00000003647*np.cos(1.66673052655 + 9991.9096959257*t)
	Y0 += 0.00000002957*np.cos(2.32106806068 + 53.5839699168*t)
	Y0 += 0.00000002835*np.cos(2.43989307879 + 323.2447842265*t)
	Y0 += 0.00000002912*np.cos(4.17865979485 + 428.0826635843*t)
	Y0 += 0.00000003176*np.cos(0.90264657780 + 529.4303326637*t)
	Y0 += 0.00000003230*np.cos(4.05101926110 + 554.1818620674*t)
	Y0 += 0.00000003594*np.cos(0.23253704183 + 6061.6999997061*t)
	Y0 += 0.00000003560*np.cos(5.55379390271 + 623.4349600787*t)
	Y0 += 0.00000003090*np.cos(0.25190671199 + 529.9515975255*t)
	Y0 += 0.00000002843*np.cos(3.58407040366 + 1447.4263943021*t)
	Y0 += 0.00000002762*np.cos(3.04100014906 + 465.273743235*t)
	Y0 += 0.00000002975*np.cos(2.63804412296 + 224.1847370075*t)
	Y0 += 0.00000002965*np.cos(2.13824743631 + 1586.1039498672*t)
	Y0 += 0.00000002997*np.cos(3.56715815371 + 29.7956483596*t)
	Y0 += 0.00000003017*np.cos(5.24948877556 + 829.4080601948*t)
	Y0 += 0.00000002748*np.cos(3.72166746073 + 1755.9015678058*t)
	Y0 += 0.00000002985*np.cos(2.48649457568 + 753.3544372403*t)
	Y0 += 0.00000002708*np.cos(1.50130862618 + 457.3570470821*t)
	Y0 += 0.00000003710*np.cos(1.48433193644 + 905.3653149297*t)
	Y0 += 0.00000002723*np.cos(5.37610390085 + 1606.3383706712*t)
	Y0 += 0.00000003498*np.cos(0.43668593773 + 9915.6436246501*t)
	Y0 += 0.00000002713*np.cos(4.37303090454 + 1533.2536931333*t)
	Y0 += 0.00000002941*np.cos(6.11824676700 + 147.8662761052*t)
	Y0 += 0.00000003151*np.cos(0.24418588736 + 430.5303441391*t)
	Y0 += 0.00000003425*np.cos(0.17462176427 + 914.4845995006*t)
	Y0 += 0.00000003382*np.cos(1.70671662802 + 881.5075574033*t)
	Y0 += 0.00000002973*np.cos(3.93511754722 + 384.0599212231*t)
	Y0 += 0.00000002967*np.cos(2.94512740245 + 1541.8517128424*t)
	Y0 += 0.00000003519*np.cos(1.73310854320 + 6354.8885031421*t)
	Y0 += 0.00000002666*np.cos(2.78512581244 + 96.2398596487*t)
	Y0 += 0.00000003354*np.cos(0.53706358244 + 919.3799606102*t)
	Y0 += 0.00000003062*np.cos(5.84703572260 + 1062.5633239269*t)
	Y0 += 0.00000002798*np.cos(4.80243373625 + 112.4939430798*t)
	Y0 += 0.00000002683*np.cos(3.33087133648 + 199.0720014364*t)
	Y0 += 0.00000003460*np.cos(4.46783856107 + 156.043604689*t)
	Y0 += 0.00000002982*np.cos(2.51020549025 + 9912.6746792335*t)
	Y0 += 0.00000002640*np.cos(3.23926189708 + 487.1526954417*t)
	Y0 += 0.00000002709*np.cos(0.30663917652 + 187.2755416471*t)
	Y0 += 0.00000003518*np.cos(2.12743549234 + 1136.4511506169*t)
	Y0 += 0.00000003486*np.cos(3.53728933221 + 313.9441891018*t)
	Y0 += 0.00000003709*np.cos(3.03522154561 + 10027.0737861469*t)
	Y0 += 0.00000003061*np.cos(2.34062051277 + 789.4604834486*t)
	Y0 += 0.00000003010*np.cos(0.65377897818 + 1605.5876111458*t)
	Y0 += 0.00000002904*np.cos(2.32569156001 + 1456.0244140112*t)
	Y0 += 0.00000003053*np.cos(1.71668201402 + 997.9336537462*t)
	Y0 += 0.00000002743*np.cos(6.27362704729 + 678.3603903519*t)
	Y0 += 0.00000002969*np.cos(5.75647236111 + 1830.6831663731*t)
	Y0 += 0.00000003651*np.cos(1.08114724446 + 26542.81250810149*t)
	Y0 += 0.00000002889*np.cos(1.97248432294 + 1585.9438911728*t)
	Y0 += 0.00000002727*np.cos(5.15143966251 + 1063.8353483141*t)
	Y0 += 0.00000002848*np.cos(5.07132119764 + 395.9087706391*t)
	Y0 += 0.00000002634*np.cos(5.98468816235 + 608.2446582306*t)
	Y0 += 0.00000002901*np.cos(4.64274585102 + 1541.1179996595*t)
	Y0 += 0.00000002941*np.cos(1.21210665628 + 12564.6672272745*t)
	Y0 += 0.00000003304*np.cos(0.86856001646 + 273.1510245881*t)
	Y0 += 0.00000003386*np.cos(0.57596770758 + 387.2413149608*t)
	Y0 += 0.00000002627*np.cos(2.39653571473 + 1452.8430202735*t)
	Y0 += 0.00000003041*np.cos(4.27587243964 + 752.5512880882*t)
	Y0 += 0.00000002718*np.cos(5.16293058088 + 52325.36948028299*t)
	Y0 += 0.00000003133*np.cos(1.68560262061 + 838.9692877504*t)
	Y0 += 0.00000003085*np.cos(2.35859653048 + 93.531546663*t)
	Y0 += 0.00000002906*np.cos(2.44478802558 + 1322.9235431119*t)
	Y0 += 0.00000003597*np.cos(4.95428287884 + 132.0370893163*t)
	Y0 += 0.00000002678*np.cos(5.06105300688 + 951.4632308302*t)
	Y0 += 0.00000003123*np.cos(3.33951755709 + 623.2225117576*t)
	Y0 += 0.00000003367*np.cos(0.37689386562 + 247.8300462128*t)
	Y0 += 0.00000003472*np.cos(1.87505610471 + 552.6973893591*t)
	Y0 += 0.00000003166*np.cos(2.20892033116 + 12567.6361726911*t)
	Y0 += 0.00000003387*np.cos(3.15594347013 + 10285.0981993617*t)
	Y0 += 0.00000003300*np.cos(3.72087032435 + 440.8947208468*t)
	Y0 += 0.00000003236*np.cos(2.72076744752 + 412.5835451955*t)
	Y0 += 0.00000002557*np.cos(1.79723576941 + 537.3952129264*t)
	Y0 += 0.00000002560*np.cos(1.10053759744 + 2117.2793876701*t)
	Y0 += 0.00000002831*np.cos(2.72459987741 + 539.773457512*t)
	Y0 += 0.00000003376*np.cos(1.67356612440 + 10202.2398459471*t)
	Y0 += 0.00000003188*np.cos(2.12663576409 + 769.6198215195*t)
	Y0 += 0.00000003464*np.cos(4.16794893326 + 161.4120465506*t)
	Y0 += 0.00000002781*np.cos(5.73975225276 + 1268.7488723641*t)
	Y0 += 0.00000003014*np.cos(5.61429333063 + 1544.0869450761*t)
	Y0 += 0.00000003298*np.cos(4.97310496761 + 463.2467538055*t)
	Y0 += 0.00000002524*np.cos(3.68420351785 + 960.0612505393*t)
	Y0 += 0.00000003187*np.cos(3.05030888971 + 196.8849533125*t)
	Y0 += 0.00000002787*np.cos(5.49834615270 + 229.4526051326*t)
	Y0 += 0.00000003097*np.cos(3.52576662964 + 1553.6481726317*t)
	Y0 += 0.00000002679*np.cos(0.04691756129 + 1374.1292684431*t)
	Y0 += 0.00000003315*np.cos(0.94177030624 + 807.7528571573*t)
	Y0 += 0.00000002630*np.cos(4.76272198714 + 743.7932096847*t)
	Y0 += 0.00000002929*np.cos(1.45546976184 + 304.2342036999*t)
	Y0 += 0.00000002983*np.cos(1.81727185185 + 936.6454359976*t)
	Y0 += 0.00000003184*np.cos(3.60984848538 + 480.8847362084*t)
	Y0 += 0.00000002864*np.cos(0.19987911757 + 2192.6516870684*t)
	Y0 += 0.00000002513*np.cos(3.00481326052 + 20278.49236799569*t)
	Y0 += 0.00000003268*np.cos(3.74882408270 + 2424.1100297711*t)
	Y0 += 0.00000003101*np.cos(2.50688447718 + 657.4233941323*t)
	Y0 += 0.00000003267*np.cos(4.76208168321 + 737.4246767149*t)
	Y0 += 0.00000002692*np.cos(2.92740740512 + 339.3982939211*t)
	Y0 += 0.00000003124*np.cos(4.14366392888 + 586.377006872*t)
	Y0 += 0.00000002517*np.cos(4.27302625046 + 583.8656358424*t)
	Y0 += 0.00000003352*np.cos(0.45988110388 + 697.8071683688*t)
	Y0 += 0.00000002806*np.cos(4.14739692323 + 351.7047177241*t)
	Y0 += 0.00000003457*np.cos(3.00986343392 + 809.2373298656*t)
	Y0 += 0.00000002544*np.cos(2.76607764684 + 262.8078997398*t)
	Y0 += 0.00000003384*np.cos(5.68724975258 + 1056.2005364515*t)
	Y0 += 0.00000002549*np.cos(1.11525653405 + 410.1358646407*t)
	Y0 += 0.00000002570*np.cos(3.71065706169 + 584.8288436889*t)
	Y0 += 0.00000003040*np.cos(0.67193319059 + 52174.32181044009*t)
	Y0 += 0.00000002505*np.cos(1.51987196875 + 382.1335055301*t)
	Y0 += 0.00000002718*np.cos(0.91308619680 + 351.9284668933*t)
	Y0 += 0.00000002512*np.cos(0.55220125147 + 826.4391147782*t)
	Y0 += 0.00000003139*np.cos(3.92383754684 + 938.1299087059*t)
	Y0 += 0.00000002672*np.cos(4.27622188274 + 319.5732633943*t)
	Y0 += 0.00000002663*np.cos(4.68514908243 + 587.7977891055*t)
	Y0 += 0.00000003119*np.cos(5.12688430370 + 849.2642284889*t)
	Y0 += 0.00000002482*np.cos(5.55805123332 + 213.2509113282*t)
	Y0 += 0.00000002480*np.cos(2.47061439934 + 213.3472795478*t)
	Y0 += 0.00000002427*np.cos(2.03247076769 + 20275.52342257909*t)
	Y0 += 0.00000002941*np.cos(4.11705902960 + 581.1573228567*t)
	Y0 += 0.00000002796*np.cos(3.05213138528 + 598.5346728287*t)
	Y0 += 0.00000002732*np.cos(1.88140426939 + 1332.4847706675*t)
	Y0 += 0.00000002438*np.cos(5.93929793621 + 395.105621487*t)
	Y0 += 0.00000002430*np.cos(5.98723272672 + 1404.0849754971*t)
	Y0 += 0.00000002421*np.cos(3.87174798038 + 1159.3457002968*t)
	Y0 += 0.00000003017*np.cos(0.07530862396 + 626.4039054953*t)
	Y0 += 0.00000002419*np.cos(0.67634283278 + 101.6083015103*t)
	Y0 += 0.00000003294*np.cos(5.11603242406 + 415.2918581812*t)
	Y0 += 0.00000003091*np.cos(5.60736082610 + 911.515654084*t)
	Y0 += 0.00000002923*np.cos(4.44263378398 + 239.1625905345*t)
	Y0 += 0.00000002424*np.cos(1.25508260924 + 243.8978929497*t)
	Y0 += 0.00000002693*np.cos(0.57305838132 + 299.7170951002*t)
	Y0 += 0.00000003109*np.cos(4.52636545098 + 45.0341343175*t)
	Y0 += 0.00000002834*np.cos(4.62881913391 + 540.0553418023*t)
	Y0 += 0.00000002704*np.cos(5.26938493529 + 988.532484885*t)
	Y0 += 0.00000002931*np.cos(6.24282698359 + 173.1390703707*t)
	Y0 += 0.00000002783*np.cos(3.74686867266 + 889.2118052351*t)
	Y0 += 0.00000002376*np.cos(3.93854491753 + 1928.1992559259*t)
	Y0 += 0.00000002928*np.cos(3.84949885104 + 609.2078660771*t)
	Y0 += 0.00000002536*np.cos(4.52810767132 + 1330.7878496381*t)
	Y0 += 0.00000002571*np.cos(4.97875573478 + 1536.2226385499*t)
	Y0 += 0.00000002402*np.cos(3.02566960132 + 482.2573343321*t)
	Y0 += 0.00000002667*np.cos(0.08605014098 + 257.9125386302*t)
	Y0 += 0.00000002446*np.cos(3.55712633832 + 1327.8189042215*t)
	Y0 += 0.00000002936*np.cos(5.43084141603 + 1424.5318446222*t)
	Y0 += 0.00000002990*np.cos(4.21802632552 + 106.8648687873*t)
	Y0 += 0.00000002473*np.cos(1.24525371169 + 1407.2663692348*t)
	Y0 += 0.00000003304*np.cos(1.01660703804 + 653.2306084383*t)
	Y0 += 0.00000003237*np.cos(2.56557965333 + 394.9455627926*t)
	Y0 += 0.00000003085*np.cos(3.83028822685 + 1057.8974574809*t)
	Y0 += 0.00000002346*np.cos(5.14974725027 + 1211.2327491842*t)
	Y0 += 0.00000002710*np.cos(0.34192435133 + 1012.9115072732*t)
	Y0 += 0.00000002716*np.cos(5.47695438076 + 444.8268741099*t)
	Y0 += 0.00000002887*np.cos(5.24452328663 + 138.6293714553*t)
	Y0 += 0.00000002421*np.cos(2.29541366768 + 672.9437643805*t)
	Y0 += 0.00000002354*np.cos(3.20939683542 + 1522.2079928694*t)
	Y0 += 0.00000002796*np.cos(2.30140691707 + 291.0496394219*t)
	Y0 += 0.00000002759*np.cos(0.69873056680 + 274.0660483248*t)
	Y0 += 0.00000002341*np.cos(3.48938979666 + 1811.773159583*t)
	Y0 += 0.00000003229*np.cos(3.79365838838 + 476.4313180835*t)
	Y0 += 0.00000003251*np.cos(0.33431351861 + 83.1671699553*t)
	Y0 += 0.00000002562*np.cos(1.57334927608 + 696.5196376166*t)
	Y0 += 0.00000002339*np.cos(0.49543749317 + 334.5511169213*t)
	Y0 += 0.00000003028*np.cos(1.40154871551 + 479.4002635001*t)
	Y0 += 0.00000002358*np.cos(2.81370331769 + 1117.7012025212*t)
	Y0 += 0.00000002323*np.cos(1.27765520019 + 386.3475430835*t)
	Y0 += 0.00000002536*np.cos(5.06956843952 + 207.3612046048*t)
	Y0 += 0.00000002332*np.cos(6.18372771815 + 274.5873131866*t)
	Y0 += 0.00000002908*np.cos(5.49277538439 + 650.9429865779*t)
	Y0 += 0.00000002357*np.cos(2.87538390843 + 378.1220303899*t)
	Y0 += 0.00000002524*np.cos(4.12720854166 + 441.1553532777*t)
	Y0 += 0.00000002876*np.cos(4.06628438217 + 6812.766815086*t)
	Y0 += 0.00000003196*np.cos(4.27507120094 + 3267.3153008408*t)
	Y0 += 0.00000003198*np.cos(2.47530039454 + 26014.60601571519*t)
	Y0 += 0.00000002550*np.cos(3.69428121427 + 0.3725070155*t)
	Y0 += 0.00000002566*np.cos(1.92901626939 + 1699.2792165032*t)
	Y0 += 0.00000002830*np.cos(0.44131453952 + 1310.3933701397*t)
	Y0 += 0.00000002662*np.cos(5.07234973989 + 271.4059194489*t)
	Y0 += 0.00000002360*np.cos(2.93302472978 + 1297.0600480154*t)
	Y0 += 0.00000002609*np.cos(1.38212057067 + 1402.8611352197*t)
	Y0 += 0.00000002444*np.cos(5.39930706114 + 175.820451106*t)
	Y0 += 0.00000002345*np.cos(1.75996538528 + 268.9582388941*t)
	Y0 += 0.00000002922*np.cos(2.46467683220 + 1599.9585368533*t)
	Y0 += 0.00000002333*np.cos(4.96787363671 + 173.0484476455*t)
	Y0 += 0.00000003176*np.cos(3.13360533407 + 349.3689117539*t)
	Y0 += 0.00000002674*np.cos(5.89637390339 + 519.0177718462*t)
	Y0 += 0.00000002585*np.cos(5.75668127095 + 754.0357607965*t)
	Y0 += 0.00000002274*np.cos(2.20397387999 + 325.7930385178*t)
	Y0 += 0.00000002991*np.cos(2.24695380440 + 625.9945152181*t)
	Y0 += 0.00000002297*np.cos(3.64732215382 + 1186.853726796*t)
	Y0 += 0.00000002289*np.cos(0.18602310852 + 764.1876891831*t)
	Y0 += 0.00000002426*np.cos(1.18176367445 + 57.7980074702*t)
	Y0 += 0.00000002781*np.cos(1.71828175775 + 122.0551706354*t)
	Y0 += 0.00000002771*np.cos(5.78898116165 + 431.3334932912*t)
	Y0 += 0.00000002315*np.cos(2.30897495417 + 290.3683158657*t)
	Y0 += 0.00000003167*np.cos(3.17998251025 + 26161.20026743319*t)
	Y0 += 0.00000002812*np.cos(0.30378867410 + 317.8763423649*t)
	Y0 += 0.00000002567*np.cos(5.96612214384 + 63.4752658725*t)
	Y0 += 0.00000002988*np.cos(2.07029207874 + 459.0539681115*t)
	Y0 += 0.00000002633*np.cos(4.26374072305 + 1055.4497769261*t)
	Y0 += 0.00000002282*np.cos(0.94739204341 + 811.4612612512*t)
	Y0 += 0.00000003122*np.cos(6.04989173004 + 939.6143814142*t)
	Y0 += 0.00000002437*np.cos(5.09941116678 + 376.8769382531*t)
	Y0 += 0.00000002474*np.cos(1.06279254184 + 668.2084619653*t)
	Y0 += 0.00000002258*np.cos(1.11320177291 + 714.6788848813*t)
	Y0 += 0.00000002764*np.cos(4.48820557495 + 730.4598875604*t)
	Y0 += 0.00000002259*np.cos(3.10988614223 + 113.3877149571*t)
	Y0 += 0.00000002598*np.cos(3.43909924140 + 763.2244813366*t)
	Y0 += 0.00000002663*np.cos(1.29799990848 + 412.3229127646*t)
	Y0 += 0.00000003160*np.cos(2.89419390415 + 3795.5217932271*t)
	Y0 += 0.00000003073*np.cos(4.51064673286 + 533.8355666788*t)
	Y0 += 0.00000002358*np.cos(4.32524569167 + 582.3811631341*t)
	Y0 += 0.00000002903*np.cos(2.47602120581 + 650.0492147006*t)
	Y0 += 0.00000002235*np.cos(2.54876348474 + 1321.4390704036*t)
	Y0 += 0.00000003142*np.cos(4.67154281030 + 725.0914456988*t)
	Y0 += 0.00000002795*np.cos(5.48464550951 + 10742.9765113056*t)
	Y0 += 0.00000002476*np.cos(2.98955635425 + 347.9326231554*t)
	Y0 += 0.00000002240*np.cos(5.07382933289 + 503.6674113037*t)
	Y0 += 0.00000002227*np.cos(5.09224345859 + 3259.1471642584*t)
	Y0 += 0.00000002477*np.cos(2.43769900185 + 821.5437536686*t)
	Y0 += 0.00000002287*np.cos(4.33583576059 + 1023.7971488427*t)
	Y0 += 0.00000002275*np.cos(1.69598721089 + 872.9095376942*t)
	Y0 += 0.00000002222*np.cos(3.53508839460 + 567.8240007324*t)
	Y0 += 0.00000003088*np.cos(4.00968174537 + 230.2826865351*t)
	Y0 += 0.00000002224*np.cos(5.85972920055 + 1258.4539316256*t)
	Y0 += 0.00000002685*np.cos(1.40856509045 + 303.5798123941*t)
	Y0 += 0.00000002261*np.cos(3.38321360452 + 123.960334469*t)
	Y0 += 0.00000002935*np.cos(1.94498224386 + 714.4182524504*t)
	Y0 += 0.00000002414*np.cos(5.05858383723 + 360.5477384618*t)
	Y0 += 0.00000002435*np.cos(2.03044146979 + 355.7487455718*t)
	Y0 += 0.00000002219*np.cos(2.99148584824 + 620.253566341*t)
	Y0 += 0.00000003094*np.cos(4.98104987238 + 3413.9095525588*t)
	Y0 += 0.00000002710*np.cos(4.45593115194 + 659.674132731*t)
	Y0 += 0.00000002209*np.cos(1.41204774183 + 1119.1856752295*t)
	Y0 += 0.00000002655*np.cos(0.05464835282 + 104.5290628171*t)
	Y0 += 0.00000002358*np.cos(6.22232256487 + 1367.6970449985*t)
	Y0 += 0.00000002230*np.cos(3.64177230224 + 442.3791935551*t)
	Y0 += 0.00000002421*np.cos(1.45420989199 + 449.2802922348*t)
	Y0 += 0.00000002330*np.cos(0.84390251807 + 820.8100404857*t)
	Y0 += 0.00000002493*np.cos(1.52678527478 + 316.6525020875*t)
	Y0 += 0.00000002973*np.cos(0.44453553813 + 526.5095713569*t)
	Y0 += 0.00000002712*np.cos(2.90893885884 + 770.5504766585*t)
	Y0 += 0.00000002758*np.cos(2.91988907092 + 1381.2428154439*t)
	Y0 += 0.00000002673*np.cos(1.39898893375 + 983.1158589136*t)
	Y0 += 0.00000002340*np.cos(2.12360206268 + 972.0701586497*t)
	Y0 += 0.00000002847*np.cos(0.89078483426 + 219.5188705615*t)
	Y0 += 0.00000002458*np.cos(2.25842855808 + 1448.9108670104*t)
	Y0 += 0.00000002627*np.cos(1.91388837247 + 768.8535556291*t)
	return Y0




def Uranus_Y1 (t): # 634 terms of order 1

	Y1 = 0.
	Y1 += 0.02157902502
	Y1 += 0.00739195286*np.cos(4.43963987365 + 149.5631971346*t)
	Y1 += 0.00238535521*np.cos(3.76882481679 + 73.297125859*t)
	Y1 += 0.00229380743*np.cos(0.91089104293 + 76.2660712756*t)
	Y1 += 0.00110133819*np.cos(4.00844673444 + 11.0457002639*t)
	Y1 += 0.00094974903*np.cos(5.07141531968 + 63.7358983034*t)
	Y1 += 0.00081470719*np.cos(5.92275377361 + 85.8272988312*t)
	Y1 += 0.00045455130*np.cos(0.73292269945 + 138.5174968707*t)
	Y1 += 0.00051366624*np.cos(0.61847245463 + 224.3447957019*t)
	Y1 += 0.00038294306*np.cos(5.01873585224 + 70.8494453042*t)
	Y1 += 0.00036144546*np.cos(5.94859451726 + 78.7137518304*t)
	Y1 += 0.00032419094*np.cos(4.32617246805 + 74.7815985673*t)
	Y1 += 0.00021672326*np.cos(3.36607324420 + 151.0476698429*t)
	Y1 += 0.00019424370*np.cos(6.01841918370 + 77.7505439839*t)
	Y1 += 0.00017392494*np.cos(4.96098883366 + 71.8126531507*t)
	Y1 += 0.00014991169*np.cos(3.97176856758 + 3.9321532631*t)
	Y1 += 0.00007732367*np.cos(0.04256630122 + 71.6002048296*t)
	Y1 += 0.00007438492*np.cos(4.63165436478 + 77.962992305*t)
	Y1 += 0.00006979238*np.cos(0.83723520791 + 145.6310438715*t)
	Y1 += 0.00007321559*np.cos(0.66348425538 + 2.9689454166*t)
	Y1 += 0.00007595636*np.cos(1.19807643487 + 148.0787244263*t)
	Y1 += 0.00004376824*np.cos(2.17182724016 + 160.6088973985*t)
	Y1 += 0.00003962568*np.cos(3.18042711824 + 65.2203710117*t)
	Y1 += 0.00004117202*np.cos(6.19931612790 + 22.0914005278*t)
	Y1 += 0.00002848200*np.cos(3.32823493525 + 213.299095438*t)
	Y1 += 0.00002690065*np.cos(1.78946471198 + 9.5612275556*t)
	Y1 += 0.00002628159*np.cos(2.97459067399 + 12.5301729722*t)
	Y1 += 0.00003174617*np.cos(3.08131638838 + 299.1263942692*t)
	Y1 += 0.00002227510*np.cos(4.89407437055 + 87.3117715395*t)
	Y1 += 0.00002821206*np.cos(1.83130010947 + 84.3428261229*t)
	Y1 += 0.00002510693*np.cos(1.27166561854 + 18.1592472647*t)
	Y1 += 0.00002224655*np.cos(3.21541108798 + 72.3339180125*t)
	Y1 += 0.00001929662*np.cos(4.68383962079 + 52.6901980395*t)
	Y1 += 0.00001707606*np.cos(5.60415260609 + 127.4717966068*t)
	Y1 += 0.00001620819*np.cos(2.18676505386 + 153.4953503977*t)
	Y1 += 0.00001939375*np.cos(0.82770216932 + 39.6175083461*t)
	Y1 += 0.00001555611*np.cos(2.56681954823 + 73.8183907208*t)
	Y1 += 0.00001595703*np.cos(4.79558057860 + 79.2350166922*t)
	Y1 += 0.00001476550*np.cos(2.10111459539 + 75.7448064138*t)
	Y1 += 0.00001531355*np.cos(2.14701519407 + 152.5321425512*t)
	Y1 += 0.00001744564*np.cos(1.67897185084 + 77.2292791221*t)
	Y1 += 0.00001713945*np.cos(1.82334975258 + 222.8603229936*t)
	Y1 += 0.00001705184*np.cos(5.82532917611 + 225.8292684102*t)
	Y1 += 0.00001739019*np.cos(3.82452086292 + 146.594251718*t)
	Y1 += 0.00001291753*np.cos(6.19666243545 + 70.3281804424*t)
	Y1 += 0.00001458526*np.cos(5.10147126404 + 3.1813937377*t)
	Y1 += 0.00001234914*np.cos(5.69239889831 + 4.4534181249*t)
	Y1 += 0.00001075108*np.cos(1.76286452034 + 56.6223513026*t)
	Y1 += 0.00001035661*np.cos(6.12642568708 + 62.2514255951*t)
	Y1 += 0.00000978675*np.cos(5.23202231955 + 74.8934731519*t)
	Y1 += 0.00000977123*np.cos(5.73086540533 + 74.6697239827*t)
	Y1 += 0.00001114523*np.cos(3.41304662369 + 131.4039498699*t)
	Y1 += 0.00001050191*np.cos(3.84176879347 + 109.9456887885*t)
	Y1 += 0.00000764556*np.cos(1.17341120063 + 1.4844727083*t)
	Y1 += 0.00000746231*np.cos(3.21375560117 + 92.940845832*t)
	Y1 += 0.00000863486*np.cos(1.70213605381 + 7.1135470008*t)
	Y1 += 0.00000649263*np.cos(4.91621635684 + 80.1982245387*t)
	Y1 += 0.00000665473*np.cos(1.92732409009 + 96.8729990951*t)
	Y1 += 0.00000514504*np.cos(2.01976952661 + 2.4476805548*t)
	Y1 += 0.00000490123*np.cos(1.93462283883 + 137.0330241624*t)
	Y1 += 0.00000462421*np.cos(3.24923248258 + 220.4126424388*t)
	Y1 += 0.00000478372*np.cos(5.86972981999 + 41.1019810544*t)
	Y1 += 0.00000413484*np.cos(2.21776453713 + 66.70484372*t)
	Y1 += 0.00000408932*np.cos(5.05029212723 + 81.8951455681*t)
	Y1 += 0.00000430008*np.cos(5.76371058355 + 67.6680515665*t)
	Y1 += 0.00000390965*np.cos(0.01692722229 + 14.977853527*t)
	Y1 += 0.00000347208*np.cos(2.52660480727 + 146.3818033969*t)
	Y1 += 0.00000343163*np.cos(2.84832361417 + 142.4496501338*t)
	Y1 += 0.00000288668*np.cos(2.84411301863 + 5.4166259714*t)
	Y1 += 0.00000326058*np.cos(4.27079067798 + 112.9146342051*t)
	Y1 += 0.00000283888*np.cos(2.51516272259 + 82.8583534146*t)
	Y1 += 0.00000295927*np.cos(5.21796998105 + 145.1097790097*t)
	Y1 += 0.00000254703*np.cos(4.68299688590 + 235.3904959658*t)
	Y1 += 0.00000262038*np.cos(2.33202621667 + 265.9892934775*t)
	Y1 += 0.00000242648*np.cos(3.08926209887 + 202.2533951741*t)
	Y1 += 0.00000281688*np.cos(2.62609779716 + 33.6796175129*t)
	Y1 += 0.00000246615*np.cos(3.74974069088 + 159.1244246902*t)
	Y1 += 0.00000238731*np.cos(4.48116112932 + 195.1398481733*t)
	Y1 += 0.00000235460*np.cos(2.06524150362 + 20.6069278195*t)
	Y1 += 0.00000217418*np.cos(2.68089080319 + 152.7445908723*t)
	Y1 += 0.00000212386*np.cos(0.50246377589 + 191.2076949102*t)
	Y1 += 0.00000233899*np.cos(5.10353028418 + 108.4612160802*t)
	Y1 += 0.00000207801*np.cos(3.08224092011 + 140.001969579*t)
	Y1 += 0.00000207635*np.cos(3.86068846030 + 209.3669421749*t)
	Y1 += 0.00000196429*np.cos(0.57807688307 + 36.6485629295*t)
	Y1 += 0.00000192273*np.cos(5.17224479052 + 23.5758732361*t)
	Y1 += 0.00000228062*np.cos(4.16741377080 + 297.6419215609*t)
	Y1 += 0.00000170887*np.cos(2.87499673493 + 128.9562693151*t)
	Y1 += 0.00000166214*np.cos(4.46057308613 + 5.9378908332*t)
	Y1 += 0.00000153690*np.cos(5.62788233695 + 288.0806940053*t)
	Y1 += 0.00000153433*np.cos(1.12899903219 + 162.0933701068*t)
	Y1 += 0.00000192082*np.cos(5.54389138204 + 373.9079928365*t)
	Y1 += 0.00000154183*np.cos(1.68184245790 + 14.0146456805*t)
	Y1 += 0.00000151315*np.cos(2.23944413846 + 120.358249606*t)
	Y1 += 0.00000143602*np.cos(4.22422388284 + 211.8146227297*t)
	Y1 += 0.00000140781*np.cos(3.78365682991 + 29.2049475286*t)
	Y1 += 0.00000140280*np.cos(3.58846256331 + 80.7194894005*t)
	Y1 += 0.00000132953*np.cos(6.02568481572 + 69.3649725959*t)
	Y1 += 0.00000134104*np.cos(5.15983441194 + 39.3568759152*t)
	Y1 += 0.00000148048*np.cos(1.44770358695 + 186.2117600641*t)
	Y1 += 0.00000132976*np.cos(5.88157760376 + 68.5618234438*t)
	Y1 += 0.00000141943*np.cos(3.15577853409 + 114.3991069134*t)
	Y1 += 0.00000132366*np.cos(2.36046311842 + 89.7594520943*t)
	Y1 += 0.00000116164*np.cos(1.93633920538 + 33.1371007917*t)
	Y1 += 0.00000121388*np.cos(2.55708768907 + 305.3461693927*t)
	Y1 += 0.00000120180*np.cos(1.31156651928 + 50.4025761791*t)
	Y1 += 0.00000109658*np.cos(3.65858083856 + 88.7962442478*t)
	Y1 += 0.00000121042*np.cos(0.94635099828 + 154.0166152595*t)
	Y1 += 0.00000129213*np.cos(5.11047627816 + 277.0349937414*t)
	Y1 += 0.00000103287*np.cos(2.14115463817 + 144.1465711632*t)
	Y1 += 0.00000132665*np.cos(0.92310657218 + 45.5766510387*t)
	Y1 += 0.00000099826*np.cos(4.30501972687 + 116.4260963429*t)
	Y1 += 0.00000133005*np.cos(1.50572985923 + 54.1746707478*t)
	Y1 += 0.00000097949*np.cos(1.13745216002 + 68.8437077341*t)
	Y1 += 0.00000116279*np.cos(4.59183976429 + 227.3137411185*t)
	Y1 += 0.00000122911*np.cos(2.00108270900 + 300.6108669775*t)
	Y1 += 0.00000113171*np.cos(2.92188560176 + 41.6444977756*t)
	Y1 += 0.00000102740*np.cos(3.77682647354 + 152.0108776894*t)
	Y1 += 0.00000099169*np.cos(5.05768073348 + 81.0013736908*t)
	Y1 += 0.00000088574*np.cos(5.72775893336 + 51.2057253312*t)
	Y1 += 0.00000081762*np.cos(4.69931003053 + 228.276948965*t)
	Y1 += 0.00000078887*np.cos(6.26808021618 + 206.1855484372*t)
	Y1 += 0.00000079364*np.cos(5.80781207422 + 110.2063212194*t)
	Y1 += 0.00000084751*np.cos(4.63943321098 + 42.5864537627*t)
	Y1 += 0.00000074096*np.cos(4.96998974307 + 148.5999892881*t)
	Y1 += 0.00000074141*np.cos(4.55571817657 + 150.5264049811*t)
	Y1 += 0.00000082217*np.cos(3.90199656887 + 32.1951448046*t)
	Y1 += 0.00000073369*np.cos(3.78616054456 + 95.3885263868*t)
	Y1 += 0.00000067806*np.cos(4.96424501696 + 16.6747745564*t)
	Y1 += 0.00000072487*np.cos(3.98596197296 + 404.5067903482*t)
	Y1 += 0.00000074821*np.cos(0.35383184429 + 230.5645708254*t)
	Y1 += 0.00000078217*np.cos(5.99310047424 + 6.2197751235*t)
	Y1 += 0.00000070370*np.cos(3.33409179388 + 24.3790223882*t)
	Y1 += 0.00000065371*np.cos(0.36077041000 + 125.9873238985*t)
	Y1 += 0.00000066071*np.cos(3.24550620947 + 28.5718080822*t)
	Y1 += 0.00000072887*np.cos(1.09355029854 + 183.2428146475*t)
	Y1 += 0.00000069241*np.cos(6.09410442093 + 333.657345044*t)
	Y1 += 0.00000060712*np.cos(4.27659918370 + 70.1157321213*t)
	Y1 += 0.00000060413*np.cos(1.36799815983 + 149.6750717192*t)
	Y1 += 0.00000057620*np.cos(3.55372227271 + 79.4474650133*t)
	Y1 += 0.00000056648*np.cos(2.57503504059 + 76.4785195967*t)
	Y1 += 0.00000056672*np.cos(5.25529010016 + 73.0846775379*t)
	Y1 += 0.00000053184*np.cos(2.10404044877 + 329.7251917809*t)
	Y1 += 0.00000055714*np.cos(4.81847283322 + 157.6399519819*t)
	Y1 += 0.00000059955*np.cos(5.61090007511 + 347.8844390456*t)
	Y1 += 0.00000051504*np.cos(5.93084548399 + 147.1155165798*t)
	Y1 += 0.00000050001*np.cos(5.84434201212 + 134.5853436076*t)
	Y1 += 0.00000049866*np.cos(1.52305095949 + 68.1893164283*t)
	Y1 += 0.00000058100*np.cos(0.15985888800 + 19.643719973*t)
	Y1 += 0.00000047515*np.cos(2.95955648439 + 415.5524906121*t)
	Y1 += 0.00000045006*np.cos(2.01641121240 + 74.0308390419*t)
	Y1 += 0.00000045536*np.cos(0.26368990951 + 7.8643065262*t)
	Y1 += 0.00000045048*np.cos(3.64711734680 + 59.8037450403*t)
	Y1 += 0.00000043941*np.cos(2.65210291918 + 75.5323580927*t)
	Y1 += 0.00000051134*np.cos(4.38322784772 + 155.7829722581*t)
	Y1 += 0.00000040257*np.cos(1.13787486261 + 154.979823106*t)
	Y1 += 0.00000040030*np.cos(4.36727211406 + 258.8757464767*t)
	Y1 += 0.00000042111*np.cos(3.13201506743 + 273.1028404783*t)
	Y1 += 0.00000049915*np.cos(3.76926694425 + 99.1606209555*t)
	Y1 += 0.00000037149*np.cos(1.11299048659 + 14.2270940016*t)
	Y1 += 0.00000037159*np.cos(1.10577356919 + 60.7669528868*t)
	Y1 += 0.00000037694*np.cos(5.68568815838 + 167.7224443993*t)
	Y1 += 0.00000042002*np.cos(2.89346792476 + 66.9172920411*t)
	Y1 += 0.00000036680*np.cos(0.59609772196 + 46.470422916*t)
	Y1 += 0.00000035593*np.cos(3.09945824468 + 81.3738807063*t)
	Y1 += 0.00000044433*np.cos(5.91344147099 + 58.1068240109*t)
	Y1 += 0.00000034621*np.cos(3.25403447019 + 135.5485514541*t)
	Y1 += 0.00000033444*np.cos(2.15331669456 + 149.45132255*t)
	Y1 += 0.00000040026*np.cos(0.39159834861 + 187.6962327724*t)
	Y1 += 0.00000039696*np.cos(0.77265302422 + 38.1330356378*t)
	Y1 += 0.00000037432*np.cos(4.92493835393 + 259.5088859231*t)
	Y1 += 0.00000037429*np.cos(5.50521421633 + 73.88782669*t)
	Y1 += 0.00000037429*np.cos(5.45737352685 + 75.6753704446*t)
	Y1 += 0.00000029920*np.cos(1.20617782649 + 6.592282139*t)
	Y1 += 0.00000030708*np.cos(4.96119928476 + 72.4939767069*t)
	Y1 += 0.00000030708*np.cos(6.00138845842 + 77.0692204277*t)
	Y1 += 0.00000035365*np.cos(1.85149018503 + 82.6459050935*t)
	Y1 += 0.00000028238*np.cos(5.62077678053 + 295.1942410061*t)
	Y1 += 0.00000031960*np.cos(1.56251268347 + 184.7272873558*t)
	Y1 += 0.00000029753*np.cos(1.50045731441 + 120.9913890524*t)
	Y1 += 0.00000031826*np.cos(4.70261915851 + 35.1640902212*t)
	Y1 += 0.00000032435*np.cos(0.91593232743 + 340.7708920448*t)
	Y1 += 0.00000026737*np.cos(3.17698509921 + 43.2890291783*t)
	Y1 += 0.00000028004*np.cos(1.44881585209 + 219.891377577*t)
	Y1 += 0.00000027010*np.cos(0.29668533504 + 143.6253063014*t)
	Y1 += 0.00000025966*np.cos(1.03271015497 + 47.6942631934*t)
	Y1 += 0.00000032420*np.cos(1.55161823742 + 221.3758502853*t)
	Y1 += 0.00000033890*np.cos(4.45443158913 + 171.6545976624*t)
	Y1 += 0.00000031100*np.cos(0.82257402617 + 98.3574718034*t)
	Y1 += 0.00000024170*np.cos(2.05667535306 + 46.2097904851*t)
	Y1 += 0.00000023863*np.cos(4.34223897738 + 218.9281697305*t)
	Y1 += 0.00000025235*np.cos(4.69042871492 + 554.0699874828*t)
	Y1 += 0.00000024285*np.cos(4.08848841154 + 103.0927742186*t)
	Y1 += 0.00000023868*np.cos(4.71660921655 + 57.255490749*t)
	Y1 += 0.00000026245*np.cos(5.22073119767 + 91.4563731237*t)
	Y1 += 0.00000024840*np.cos(1.12612503677 + 25.2727942655*t)
	Y1 += 0.00000024286*np.cos(5.67475253703 + 543.0242872189*t)
	Y1 += 0.00000023341*np.cos(2.85807251066 + 61.448276443*t)
	Y1 += 0.00000022153*np.cos(3.02360784305 + 19.1224551112*t)
	Y1 += 0.00000022896*np.cos(6.01045974333 + 233.9060232575*t)
	Y1 += 0.00000024477*np.cos(1.45234648419 + 472.1748419147*t)
	Y1 += 0.00000023787*np.cos(0.19814851299 + 254.9435932136*t)
	Y1 += 0.00000021858*np.cos(3.23868642667 + 7.4223635415*t)
	Y1 += 0.00000027534*np.cos(4.02405042416 + 111.4301614968*t)
	Y1 += 0.00000020434*np.cos(3.61254005832 + 468.2426886516*t)
	Y1 += 0.00000019975*np.cos(4.73421367097 + 92.0470739547*t)
	Y1 += 0.00000022678*np.cos(5.19431425994 + 217.2312487011*t)
	Y1 += 0.00000018710*np.cos(0.49921896876 + 69.6737891366*t)
	Y1 += 0.00000019101*np.cos(4.03712689896 + 17.2654753874*t)
	Y1 += 0.00000021183*np.cos(1.01722300195 + 486.4019359163*t)
	Y1 += 0.00000022058*np.cos(0.03546832338 + 203.7378678824*t)
	Y1 += 0.00000018128*np.cos(2.18749630503 + 28.3111756513*t)
	Y1 += 0.00000019106*np.cos(2.56999815497 + 200.7689224658*t)
	Y1 += 0.00000018186*np.cos(6.24790113108 + 92.3077063856*t)
	Y1 += 0.00000020451*np.cos(1.98908005437 + 115.8835796217*t)
	Y1 += 0.00000019781*np.cos(0.91026787025 + 198.321241911*t)
	Y1 += 0.00000017183*np.cos(5.92660737259 + 397.3932433474*t)
	Y1 += 0.00000019764*np.cos(5.08996944436 + 296.1574488526*t)
	Y1 += 0.00000017326*np.cos(2.01038402983 + 100.3844612329*t)
	Y1 += 0.00000018336*np.cos(1.67870822944 + 151.260118164*t)
	Y1 += 0.00000016745*np.cos(5.41086655697 + 210.3301500214*t)
	Y1 += 0.00000017082*np.cos(4.18018375218 + 79.889407998*t)
	Y1 += 0.00000017484*np.cos(1.96073499840 + 13.3333221243*t)
	Y1 += 0.00000019041*np.cos(2.05956053972 + 88.1149206916*t)
	Y1 += 0.00000016296*np.cos(1.84927529083 + 351.8165923087*t)
	Y1 += 0.00000016068*np.cos(0.47944220093 + 106.9767433719*t)
	Y1 += 0.00000016333*np.cos(2.08640683311 + 94.4253185403*t)
	Y1 += 0.00000016315*np.cos(0.87407041749 + 24.1183899573*t)
	Y1 += 0.00000016506*np.cos(1.55668384247 + 76.42612997*t)
	Y1 += 0.00000016506*np.cos(3.12271859353 + 73.1370671646*t)
	Y1 += 0.00000015851*np.cos(1.55481798786 + 13.4933808187*t)
	Y1 += 0.00000017915*np.cos(2.25770537418 + 181.7583419392*t)
	Y1 += 0.00000017819*np.cos(4.98834752372 + 221.1634019642*t)
	Y1 += 0.00000021162*np.cos(0.30009257573 + 372.4235201282*t)
	Y1 += 0.00000019752*np.cos(2.68974866734 + 479.2883889155*t)
	Y1 += 0.00000015502*np.cos(2.15644994698 + 30.0562807905*t)
	Y1 += 0.00000018927*np.cos(5.52070855632 + 227.5261894396*t)
	Y1 += 0.00000014861*np.cos(3.07987854112 + 98.8999885246*t)
	Y1 += 0.00000015298*np.cos(6.11050150655 + 55.6591434561*t)
	Y1 += 0.00000015606*np.cos(3.45933082845 + 135.336103133*t)
	Y1 += 0.00000014562*np.cos(1.54309244280 + 50.66320861*t)
	Y1 += 0.00000014149*np.cos(0.55502939857 + 286.596221297*t)
	Y1 += 0.00000016971*np.cos(0.32345770562 + 132.8884225782*t)
	Y1 += 0.00000015562*np.cos(4.88358674295 + 411.620337349*t)
	Y1 += 0.00000014297*np.cos(0.85832234275 + 310.1720945331*t)
	Y1 += 0.00000015313*np.cos(5.16260319735 + 16.4623262353*t)
	Y1 += 0.00000017344*np.cos(3.92150607353 + 260.9933586314*t)
	Y1 += 0.00000016315*np.cos(1.55780267718 + 173.9422195228*t)
	Y1 += 0.00000013683*np.cos(2.35142443147 + 82.2039621088*t)
	Y1 += 0.00000014352*np.cos(5.14132706191 + 30.7106720963*t)
	Y1 += 0.00000013286*np.cos(1.43776614438 + 106.2741679563*t)
	Y1 += 0.00000013851*np.cos(3.40761420285 + 44.070926471*t)
	Y1 += 0.00000013632*np.cos(4.25958638386 + 67.8804998876*t)
	Y1 += 0.00000017416*np.cos(2.62206054100 + 184.0941479094*t)
	Y1 += 0.00000013285*np.cos(1.25115255590 + 6.9010986797*t)
	Y1 += 0.00000012992*np.cos(5.46634955062 + 173.6815870919*t)
	Y1 += 0.00000012917*np.cos(2.89950515923 + 55.1378785943*t)
	Y1 += 0.00000016261*np.cos(0.42831784501 + 64.4866578288*t)
	Y1 += 0.00000012734*np.cos(0.13129280359 + 74.2603337055*t)
	Y1 += 0.00000012734*np.cos(1.40651697882 + 75.3028634291*t)
	Y1 += 0.00000012700*np.cos(0.13947590032 + 57.5161231799*t)
	Y1 += 0.00000012678*np.cos(3.64176703665 + 81.682697247*t)
	Y1 += 0.00000012499*np.cos(0.19514494663 + 32.2433289144*t)
	Y1 += 0.00000016313*np.cos(5.34510275068 + 60.5545045657*t)
	Y1 += 0.00000011970*np.cos(1.46148448616 + 189.7232222019*t)
	Y1 += 0.00000015664*np.cos(4.33058952641 + 760.25553592*t)
	Y1 += 0.00000012007*np.cos(1.57217788805 + 130.4407420234*t)
	Y1 += 0.00000013954*np.cos(4.85323318500 + 141.6988906084*t)
	Y1 += 0.00000012513*np.cos(3.50106291075 + 124.2904028691*t)
	Y1 += 0.00000012404*np.cos(2.56706437369 + 42.5382696529*t)
	Y1 += 0.00000012080*np.cos(3.59336191094 + 74.1272072615*t)
	Y1 += 0.00000012080*np.cos(1.08604052506 + 75.4359898731*t)
	Y1 += 0.00000013527*np.cos(4.25099304738 + 85.0765393058*t)
	Y1 += 0.00000010739*np.cos(4.95844118289 + 93.9040536785*t)
	Y1 += 0.00000010638*np.cos(2.39958748468 + 67.3592350258*t)
	Y1 += 0.00000013832*np.cos(3.79411080267 + 31.6526280834*t)
	Y1 += 0.00000010694*np.cos(5.86503834062 + 156.1554792736*t)
	Y1 += 0.00000010335*np.cos(4.57671004843 + 267.4737661858*t)
	Y1 += 0.00000010526*np.cos(6.26537454607 + 692.5874843535*t)
	Y1 += 0.00000013983*np.cos(0.54426905720 + 8.0767548473*t)
	Y1 += 0.00000010459*np.cos(3.55111688475 + 144.8973306886*t)
	Y1 += 0.00000013782*np.cos(2.66794915751 + 26.0235537909*t)
	Y1 += 0.00000010022*np.cos(5.63565557673 + 426.598190876*t)
	Y1 += 0.00000012990*np.cos(4.63039669972 + 454.9093665273*t)
	Y1 += 0.00000010123*np.cos(3.61491688022 + 236.8749686741*t)
	Y1 += 0.00000010209*np.cos(2.37413106984 + 214.7835681463*t)
	Y1 += 0.00000010000*np.cos(1.03668335124 + 43.1289704839*t)
	Y1 += 0.00000010052*np.cos(1.93897993582 + 49.5088043018*t)
	Y1 += 0.00000009564*np.cos(4.75318483390 + 27.0873353739*t)
	Y1 += 0.00000010954*np.cos(5.27624507129 + 89.0086925689*t)
	Y1 += 0.00000009831*np.cos(1.26050326376 + 54.3347294422*t)
	Y1 += 0.00000009739*np.cos(3.71078555984 + 73.1852512744*t)
	Y1 += 0.00000009739*np.cos(4.11020952975 + 76.3779458602*t)
	Y1 += 0.00000009399*np.cos(0.36630405976 + 17.5261078183*t)
	Y1 += 0.00000012329*np.cos(3.11428019688 + 264.5048207692*t)
	Y1 += 0.00000009910*np.cos(4.74765433533 + 129.9194771616*t)
	Y1 += 0.00000011022*np.cos(1.88722997944 + 685.4739373527*t)
	Y1 += 0.00000009049*np.cos(1.62029156232 + 117.9105690512*t)
	Y1 += 0.00000009890*np.cos(1.84425226351 + 393.4610900843*t)
	Y1 += 0.00000008983*np.cos(5.50495945537 + 284.1485407422*t)
	Y1 += 0.00000008743*np.cos(2.43586486318 + 119.5069163441*t)
	Y1 += 0.00000010035*np.cos(1.72606687342 + 448.6895914038*t)
	Y1 += 0.00000010245*np.cos(2.71391527366 + 624.919432787*t)
	Y1 += 0.00000008574*np.cos(2.98478219061 + 136.0698163159*t)
	Y1 += 0.00000008920*np.cos(4.93954149872 + 207.8824694666*t)
	Y1 += 0.00000008494*np.cos(5.75906792889 + 103.9865460959*t)
	Y1 += 0.00000008571*np.cos(0.25289077209 + 44.7253177768*t)
	Y1 += 0.00000008845*np.cos(3.56613672436 + 88.274979386*t)
	Y1 += 0.00000009060*np.cos(5.60200499628 + 193.655375465*t)
	Y1 += 0.00000008157*np.cos(6.12519482603 + 163.5778428151*t)
	Y1 += 0.00000008186*np.cos(3.64863304960 + 216.4804891757*t)
	Y1 += 0.00000008988*np.cos(4.16085842080 + 617.8058857862*t)
	Y1 += 0.00000010514*np.cos(2.93390720828 + 31.492569389*t)
	Y1 += 0.00000008521*np.cos(6.01861922798 + 155.5010879678*t)
	Y1 += 0.00000009091*np.cos(4.66636258110 + 180.1619946463*t)
	Y1 += 0.00000007714*np.cos(5.39841554155 + 606.7601855223*t)
	Y1 += 0.00000007891*np.cos(5.15570877007 + 47.061123747*t)
	Y1 += 0.00000008187*np.cos(1.13060383176 + 237.6781178262*t)
	Y1 += 0.00000008534*np.cos(1.21999207391 + 61.2882177486*t)
	Y1 += 0.00000008583*np.cos(3.38972104965 + 180.2738692309*t)
	Y1 += 0.00000007464*np.cos(4.06832263488 + 175.1660598002*t)
	Y1 += 0.00000008238*np.cos(4.17466862163 + 40.1600250673*t)
	Y1 += 0.00000008741*np.cos(3.21558804714 + 58.7399634573*t)
	Y1 += 0.00000008402*np.cos(0.03732574180 + 79.5169009825*t)
	Y1 += 0.00000008402*np.cos(4.64207669420 + 70.0462961521*t)
	Y1 += 0.00000007165*np.cos(2.02831415080 + 107.4980082337*t)
	Y1 += 0.00000007086*np.cos(0.34907168874 + 177.8743727859*t)
	Y1 += 0.00000006947*np.cos(1.44539167114 + 362.8622925726*t)
	Y1 += 0.00000007068*np.cos(5.15374688286 + 141.4864422873*t)
	Y1 += 0.00000006780*np.cos(5.59529522880 + 71.1582618449*t)
	Y1 += 0.00000006780*np.cos(5.36729251438 + 78.4049352897*t)
	Y1 += 0.00000006837*np.cos(1.56928861004 + 535.9107402181*t)
	Y1 += 0.00000007083*np.cos(5.90354267352 + 532.8723588323*t)
	Y1 += 0.00000006821*np.cos(3.51404454681 + 142.6620984549*t)
	Y1 += 0.00000006803*np.cos(3.41890384391 + 95.2284676924*t)
	Y1 += 0.00000006501*np.cos(1.06502124468 + 49.7212526229*t)
	Y1 += 0.00000006389*np.cos(5.39586011924 + 114.9416236346*t)
	Y1 += 0.00000007109*np.cos(0.95985317204 + 681.5417840896*t)
	Y1 += 0.00000006748*np.cos(4.09628686708 + 248.7238180901*t)
	Y1 += 0.00000006343*np.cos(3.53135540985 + 118.8737768977*t)
	Y1 += 0.00000006189*np.cos(5.11528797791 + 381.0909758065*t)
	Y1 += 0.00000006189*np.cos(3.97068861187 + 528.7277572481*t)
	Y1 += 0.00000006083*np.cos(3.50534080121 + 530.6541729411*t)
	Y1 += 0.00000006083*np.cos(5.58063530545 + 379.1645601135*t)
	Y1 += 0.00000006160*np.cos(2.27471289907 + 166.828672522*t)
	Y1 += 0.00000006646*np.cos(3.13029644154 + 35.685355083*t)
	Y1 += 0.00000006505*np.cos(5.73653567743 + 121.8427223143*t)
	Y1 += 0.00000007411*np.cos(6.01029958755 + 756.3233826569*t)
	Y1 += 0.00000006639*np.cos(5.56185756319 + 34.5309507748*t)
	Y1 += 0.00000006729*np.cos(0.30990216922 + 550.1378342197*t)
	Y1 += 0.00000006319*np.cos(2.00631988170 + 143.3434220111*t)
	Y1 += 0.00000005834*np.cos(6.26504969506 + 405.9912630565*t)
	Y1 += 0.00000006837*np.cos(4.49077930583 + 375.3924655448*t)
	Y1 += 0.00000006073*np.cos(0.03659246933 + 29.226199388*t)
	Y1 += 0.00000006314*np.cos(0.69574142678 + 109.3125493421*t)
	Y1 += 0.00000005864*np.cos(4.03381742076 + 107.918699359*t)
	Y1 += 0.00000005744*np.cos(3.44099171464 + 610.6923387854*t)
	Y1 += 0.00000005786*np.cos(2.06253816229 + 22.633917249*t)
	Y1 += 0.00000006744*np.cos(5.79309200153 + 27.7204748203*t)
	Y1 += 0.00000005731*np.cos(4.18602677905 + 234.4967240885*t)
	Y1 += 0.00000006425*np.cos(5.93683435781 + 210.8514148832*t)
	Y1 += 0.00000005514*np.cos(0.51259120768 + 232.4215505492*t)
	Y1 += 0.00000005532*np.cos(5.03127867351 + 164.5410506616*t)
	Y1 += 0.00000006346*np.cos(1.14677693060 + 91.2439248026*t)
	Y1 += 0.00000005720*np.cos(2.58484163709 + 319.5732633943*t)
	Y1 += 0.00000005425*np.cos(4.87619567680 + 76.154196691*t)
	Y1 += 0.00000005425*np.cos(2.94479941279 + 73.4090004436*t)
	Y1 += 0.00000005441*np.cos(0.83308003167 + 31.2319369581*t)
	Y1 += 0.00000005384*np.cos(2.24171100613 + 312.4597163935*t)
	Y1 += 0.00000005538*np.cos(3.83190408539 + 125.1841747464*t)
	Y1 += 0.00000005417*np.cos(1.80506715096 + 16.04163511*t)
	Y1 += 0.00000005401*np.cos(3.76183223257 + 192.6921676185*t)
	Y1 += 0.00000005258*np.cos(2.80362988465 + 49.1787359017*t)
	Y1 += 0.00000005433*np.cos(3.95755513981 + 408.4389436113*t)
	Y1 += 0.00000006350*np.cos(1.46370963209 + 90.8232336773*t)
	Y1 += 0.00000005176*np.cos(0.85326249506 + 34.62157350*t)
	Y1 += 0.00000005125*np.cos(5.13388413274 + 440.6822725257*t)
	Y1 += 0.00000006135*np.cos(6.27767935005 + 196.6243208816*t)
	Y1 += 0.00000005237*np.cos(5.43868405923 + 25.6028626656*t)
	Y1 += 0.00000005368*np.cos(0.89833267568 + 293.7097682978*t)
	Y1 += 0.00000005379*np.cos(5.87185859946 + 162.8965192589*t)
	Y1 += 0.00000005870*np.cos(5.68040852955 + 406.1031376411*t)
	Y1 += 0.00000005381*np.cos(4.07892086409 + 322.6116447801*t)
	Y1 += 0.00000005168*np.cos(1.40578632698 + 147.8662761052*t)
	Y1 += 0.00000006514*np.cos(0.78441227240 + 302.0953396858*t)
	Y1 += 0.00000004664*np.cos(2.71832015740 + 114.1384744825*t)
	Y1 += 0.00000006300*np.cos(3.22684324135 + 280.9671470045*t)
	Y1 += 0.00000006034*np.cos(3.28682609944 + 2043.9822618111*t)
	Y1 += 0.00000005359*np.cos(3.34986978299 + 376.9463742223*t)
	Y1 += 0.00000004507*np.cos(3.11041870553 + 100.0543928328*t)
	Y1 += 0.00000006229*np.cos(4.71461433744 + 403.0223176399*t)
	Y1 += 0.00000004918*np.cos(0.79029088221 + 827.9235874865*t)
	Y1 += 0.00000005151*np.cos(6.04977140057 + 301.4140161296*t)
	Y1 += 0.00000004642*np.cos(5.05387110647 + 749.2098356561*t)
	Y1 += 0.00000004545*np.cos(0.31133604476 + 52.1476813183*t)
	Y1 += 0.00000004548*np.cos(2.91482549606 + 995.6460318858*t)
	Y1 += 0.00000005335*np.cos(5.63899771188 + 232.0490435337*t)
	Y1 += 0.00000005746*np.cos(2.20971330343 + 44.0921783304*t)
	Y1 += 0.00000004310*np.cos(2.99240118406 + 122.4758617607*t)
	Y1 += 0.00000004237*np.cos(5.45877268962 + 257.3912737684*t)
	Y1 += 0.00000004658*np.cos(2.67813680523 + 470.6903692064*t)
	Y1 += 0.00000004196*np.cos(2.18196768045 + 221.8971151471*t)
	Y1 += 0.00000004399*np.cos(2.40325632971 + 103.3534066495*t)
	Y1 += 0.00000004273*np.cos(1.66297557695 + 831.1049812242*t)
	Y1 += 0.00000004224*np.cos(1.53482654947 + 501.3797894433*t)
	Y1 += 0.00000004447*np.cos(3.47911962557 + 101.8689339412*t)
	Y1 += 0.00000004161*np.cos(1.51092477357 + 43.5496616092*t)
	Y1 += 0.00000004649*np.cos(3.58736486540 + 216.9224321604*t)
	Y1 += 0.00000004666*np.cos(1.47668507245 + 269.9214467406*t)
	Y1 += 0.00000005340*np.cos(0.41373323217 + 842.1506814881*t)
	Y1 += 0.00000004482*np.cos(3.99832001857 + 21.1976286505*t)
	Y1 += 0.00000004344*np.cos(2.49175585697 + 49.6518166537*t)
	Y1 += 0.00000005029*np.cos(5.57233893622 + 189.1807054807*t)
	Y1 += 0.00000004064*np.cos(2.17885604638 + 48.7580447764*t)
	Y1 += 0.00000004154*np.cos(6.03272866442 + 170.1701249541*t)
	Y1 += 0.00000004207*np.cos(2.38933455026 + 35.4247226521*t)
	Y1 += 0.00000004193*np.cos(0.39448465073 + 383.3091616977*t)
	Y1 += 0.00000004088*np.cos(4.14959391506 + 271.61836777*t)
	Y1 += 0.00000005095*np.cos(1.92013837373 + 107.0249274817*t)
	Y1 += 0.00000004056*np.cos(4.26574461521 + 582.3811631341*t)
	Y1 += 0.00000003901*np.cos(1.77664133977 + 124.5028511902*t)
	Y1 += 0.00000004367*np.cos(4.33100086297 + 595.8745439528*t)
	Y1 += 0.00000004314*np.cos(3.81335461247 + 610.1016379544*t)
	Y1 += 0.00000004251*np.cos(2.07154175904 + 484.917463208*t)
	Y1 += 0.00000004461*np.cos(5.51731052862 + 302.3772239761*t)
	Y1 += 0.00000003869*np.cos(0.14016188548 + 195.7729876197*t)
	Y1 += 0.00000004279*np.cos(4.56457588625 + 178.7893965226*t)
	Y1 += 0.00000004570*np.cos(3.91225052432 + 25.0603459444*t)
	Y1 += 0.00000004401*np.cos(3.00977149914 + 487.8864086246*t)
	Y1 += 0.00000004548*np.cos(0.82682823758 + 223.4510238246*t)
	Y1 += 0.00000004485*np.cos(1.11888066555 + 30.5987975117*t)
	Y1 += 0.00000003991*np.cos(5.99550015236 + 226.7924762567*t)
	Y1 += 0.00000004241*np.cos(2.57418972840 + 336.8387387817*t)
	Y1 += 0.00000004288*np.cos(3.23553398773 + 298.2326223919*t)
	Y1 += 0.00000003708*np.cos(5.12023202898 + 354.9979860464*t)
	Y1 += 0.00000004619*np.cos(3.62651049564 + 422.6660376129*t)
	Y1 += 0.00000003734*np.cos(1.76361036965 + 39.0962434843*t)
	Y1 += 0.00000004251*np.cos(2.89742576428 + 490.3340891794*t)
	Y1 += 0.00000004000*np.cos(1.99013874137 + 1887.3055176757*t)
	Y1 += 0.00000003690*np.cos(2.98863596646 + 219.5188705615*t)
	Y1 += 0.00000003663*np.cos(4.24690858577 + 117.3198682202*t)
	Y1 += 0.00000003848*np.cos(0.32895770154 + 346.3999663373*t)
	Y1 += 0.00000003933*np.cos(1.07124636244 + 181.0557665236*t)
	Y1 += 0.00000003645*np.cos(3.67139942158 + 310.9752436852*t)
	Y1 += 0.00000004290*np.cos(4.85375320990 + 66.1835788582*t)
	Y1 += 0.00000004007*np.cos(1.22645898466 + 142.1408335931*t)
	Y1 += 0.00000004243*np.cos(4.42705400813 + 763.4369296577*t)
	Y1 += 0.00000003472*np.cos(3.01599882925 + 674.4282370888*t)
	Y1 += 0.00000003901*np.cos(0.72185997426 + 204.7010757289*t)
	Y1 += 0.00000004222*np.cos(3.65340879730 + 339.2864193365*t)
	Y1 += 0.00000003712*np.cos(6.24186047009 + 906.849787638*t)
	Y1 += 0.00000003550*np.cos(1.66599820846 + 380.12776796*t)
	Y1 += 0.00000003806*np.cos(1.29154626034 + 253.4591205053*t)
	Y1 += 0.00000003407*np.cos(0.80345297226 + 745.277682393*t)
	Y1 += 0.00000003563*np.cos(2.81255515810 + 820.0592809603*t)
	Y1 += 0.00000003674*np.cos(1.37910752336 + 544.5087599272*t)
	Y1 += 0.00000003398*np.cos(1.39293643700 + 547.8502123593*t)
	Y1 += 0.00000003451*np.cos(4.71165482381 + 1507.1777497157*t)
	Y1 += 0.00000003432*np.cos(1.80612685115 + 184.9879197867*t)
	Y1 += 0.00000004646*np.cos(6.10399526873 + 604.4725636619*t)
	Y1 += 0.00000003459*np.cos(4.46134223293 + 565.1156877467*t)
	Y1 += 0.00000003346*np.cos(6.01104528303 + 672.1406152284*t)
	Y1 += 0.00000003818*np.cos(2.94151510607 + 328.3525936572*t)
	Y1 += 0.00000003429*np.cos(6.20622829232 + 344.7030453079*t)
	Y1 += 0.00000003965*np.cos(0.97771499558 + 256.5399405065*t)
	Y1 += 0.00000003554*np.cos(2.04610695817 + 1368.660252845*t)
	Y1 += 0.00000003526*np.cos(5.33310923745 + 1521.4048437173*t)
	Y1 += 0.00000003359*np.cos(1.51386637492 + 699.7010313543*t)
	Y1 += 0.00000004015*np.cos(5.85187604603 + 442.7517005706*t)
	Y1 += 0.00000003338*np.cos(0.74390697506 + 89.9719004154*t)
	Y1 += 0.00000003345*np.cos(3.86198512192 + 10021.8372800994*t)
	Y1 += 0.00000004153*np.cos(5.41660115880 + 758.7710632117*t)
	Y1 += 0.00000003695*np.cos(2.70272958026 + 328.2407190726*t)
	Y1 += 0.00000003368*np.cos(1.27928746391 + 1050.7839104801*t)
	Y1 += 0.00000003395*np.cos(1.76965627708 + 511.5317178299*t)
	Y1 += 0.00000004273*np.cos(2.05212048520 + 526.5095713569*t)
	Y1 += 0.00000003470*np.cos(2.81336232616 + 1067.9799498983*t)
	Y1 += 0.00000003921*np.cos(4.16917220037 + 657.1627617014*t)
	Y1 += 0.00000003265*np.cos(4.84637270255 + 34.2008823747*t)
	Y1 += 0.00000003245*np.cos(2.64935843871 + 30.6894202369*t)
	Y1 += 0.00000004057*np.cos(1.92979006097 + 229.0800981171*t)
	Y1 += 0.00000003193*np.cos(2.73862671891 + 374.7111419886*t)
	Y1 += 0.00000004246*np.cos(1.67868119422 + 528.2064923863*t)
	Y1 += 0.00000003558*np.cos(1.03311657364 + 781.5961769224*t)
	Y1 += 0.00000004142*np.cos(2.17956762731 + 688.6553310904*t)
	Y1 += 0.00000003759*np.cos(1.15225435707 + 293.188503436*t)
	Y1 += 0.00000003788*np.cos(2.28038708170 + 105.380396079*t)
	Y1 += 0.00000003359*np.cos(1.72618422024 + 370.0452755426*t)
	Y1 += 0.00000004041*np.cos(1.45496139964 + 342.2553647531*t)
	Y1 += 0.00000003940*np.cos(6.00488042203 + 728.762966531*t)
	Y1 += 0.00000003642*np.cos(5.29591498610 + 332.8060117821*t)
	Y1 += 0.00000003291*np.cos(5.82915957363 + 2424.1100297711*t)
	Y1 += 0.00000003279*np.cos(2.78900727949 + 480.7728616238*t)
	Y1 += 0.00000003392*np.cos(3.29246798409 + 291.1190753911*t)
	Y1 += 0.00000003094*np.cos(3.22378474864 + 969.6224780949*t)
	Y1 += 0.00000003177*np.cos(4.90869876026 + 194.2885149114*t)
	Y1 += 0.00000003505*np.cos(0.07757668304 + 51.8870488874*t)
	Y1 += 0.00000003015*np.cos(2.32336060326 + 1053.7528558967*t)
	Y1 += 0.00000004172*np.cos(0.63805328567 + 332.1728723357*t)
	Y1 += 0.00000003794*np.cos(0.72421690887 + 555.5544601911*t)
	Y1 += 0.00000003462*np.cos(4.26980393992 + 609.2078660771*t)
	Y1 += 0.00000003498*np.cos(1.38701853494 + 630.3360587584*t)
	Y1 += 0.00000003255*np.cos(1.55384975988 + 113.8778420516*t)
	Y1 += 0.00000003367*np.cos(5.22184240312 + 477.8039162072*t)
	Y1 += 0.00000003305*np.cos(3.50958885438 + 473.659314623*t)
	Y1 += 0.00000002950*np.cos(3.72868396640 + 406.954470903*t)
	Y1 += 0.00000002947*np.cos(3.18933946169 + 376.1956146969*t)
	Y1 += 0.00000003292*np.cos(1.83930538139 + 329.8370663655*t)
	Y1 += 0.00000003735*np.cos(1.93699651985 + 5983.9494557222*t)
	Y1 += 0.00000003305*np.cos(5.99365370214 + 532.1386456494*t)
	Y1 += 0.00000004087*np.cos(3.98316215178 + 1264.816719101*t)
	Y1 += 0.00000002959*np.cos(0.15625500490 + 15.4991183888*t)
	Y1 += 0.00000002890*np.cos(1.17887202562 + 594.9113361063*t)
	Y1 += 0.00000003669*np.cos(5.34076783991 + 601.5036182453*t)
	Y1 += 0.00000003391*np.cos(3.61279122299 + 531.978586955*t)
	Y1 += 0.00000003109*np.cos(4.06247818410 + 241.6102710893*t)
	Y1 += 0.00000003078*np.cos(0.52431831050 + 432.8179659995*t)
	Y1 += 0.00000003087*np.cos(4.42147892231 + 525.2375469697*t)
	Y1 += 0.00000003368*np.cos(0.00612274205 + 275.5505210331*t)
	Y1 += 0.00000003021*np.cos(2.73984998375 + 833.552661779*t)
	Y1 += 0.00000003359*np.cos(3.37955835963 + 228.7982138268*t)
	Y1 += 0.00000002904*np.cos(2.44331654879 + 90.2807169561*t)
	Y1 += 0.00000002845*np.cos(1.71560345363 + 260.360219185*t)
	Y1 += 0.00000003025*np.cos(0.66197534140 + 483.2205421786*t)
	Y1 += 0.00000003014*np.cos(2.65716293440 + 421.1815649046*t)
	Y1 += 0.00000003527*np.cos(4.24276675904 + 296.7481496836*t)
	Y1 += 0.00000003615*np.cos(1.65868367165 + 156.6767441354*t)
	Y1 += 0.00000002779*np.cos(5.87649617216 + 546.956440482*t)
	Y1 += 0.00000002921*np.cos(1.45515033376 + 6208.2942514241*t)
	Y1 += 0.00000002796*np.cos(3.15510185813 + 106.0135355254*t)
	Y1 += 0.00000003215*np.cos(2.40845979136 + 218.4069048687*t)
	Y1 += 0.00000003773*np.cos(5.65506488806 + 358.0363674322*t)
	Y1 += 0.00000003502*np.cos(3.36040662009 + 9914.1591519418*t)
	Y1 += 0.00000003441*np.cos(5.17758550803 + 689.4060906158*t)
	Y1 += 0.00000003061*np.cos(3.55867760683 + 1737.7423205411*t)
	Y1 += 0.00000002855*np.cos(4.14690275315 + 48.9181034708*t)
	Y1 += 0.00000003388*np.cos(3.10173488011 + 1471.0022675382*t)
	Y1 += 0.00000002724*np.cos(2.78375512607 + 280.2163874791*t)
	Y1 += 0.00000003175*np.cos(3.97316441690 + 1512.8068240082*t)
	Y1 += 0.00000002688*np.cos(0.83078536879 + 395.9087706391*t)
	Y1 += 0.00000002721*np.cos(0.84302891092 + 469.1364605289*t)
	Y1 += 0.00000002898*np.cos(4.64603719753 + 100.8051523582*t)
	Y1 += 0.00000003020*np.cos(0.51676581657 + 469.7271613599*t)
	Y1 += 0.00000002743*np.cos(6.05000396425 + 121.2520214833*t)
	Y1 += 0.00000003366*np.cos(0.59876268346 + 3265.8308281325*t)
	Y1 += 0.00000003085*np.cos(3.00944428171 + 628.8515860501*t)
	Y1 += 0.00000002963*np.cos(0.44605293530 + 541.5398145106*t)
	Y1 += 0.00000002949*np.cos(3.40941244036 + 255.8373650909*t)
	Y1 += 0.00000002727*np.cos(1.85307891248 + 1065.0110044817*t)
	Y1 += 0.00000002981*np.cos(5.45523598966 + 561.1835344836*t)
	Y1 += 0.00000003110*np.cos(1.56881053570 + 626.4039054953*t)
	Y1 += 0.00000003626*np.cos(5.69775666543 + 358.9301393095*t)
	Y1 += 0.00000003329*np.cos(5.08259605272 + 26013.1215430069*t)
	Y1 += 0.00000003374*np.cos(1.02797098727 + 1065.6017053127*t)
	Y1 += 0.00000002647*np.cos(1.71808595583 + 369.0820676961*t)
	Y1 += 0.00000002608*np.cos(1.92579932746 + 531.1754378029*t)
	Y1 += 0.00000002593*np.cos(4.72726217361 + 765.8846102125*t)
	Y1 += 0.00000002767*np.cos(0.34487203406 + 525.7588118315*t)
	Y1 += 0.00000003057*np.cos(6.21505323467 + 1751.9694145427*t)
	Y1 += 0.00000002880*np.cos(2.11509152885 + 369.9758395734*t)
	Y1 += 0.00000003592*np.cos(5.19034496676 + 1062.3508756058*t)
	Y1 += 0.00000003404*np.cos(1.07437209675 + 1104.2078217025*t)
	Y1 += 0.00000003123*np.cos(1.19886702583 + 384.2723695442*t)
	Y1 += 0.00000002555*np.cos(1.50474150838 + 668.2084619653*t)
	Y1 += 0.00000002936*np.cos(1.30698566586 + 349.3689117539*t)
	Y1 += 0.00000002878*np.cos(4.46393670354 + 6058.7310542895*t)
	Y1 += 0.00000003159*np.cos(2.83033258065 + 1336.4169239306*t)
	Y1 += 0.00000002804*np.cos(0.44967384090 + 2111.6503133776*t)
	Y1 += 0.00000002703*np.cos(5.49524346251 + 104.0077979553*t)
	Y1 += 0.00000002727*np.cos(6.17906602741 + 591.9423906897*t)
	Y1 += 0.00000002675*np.cos(1.17744867197 + 731.9443602687*t)
	Y1 += 0.00000002863*np.cos(1.36639259323 + 637.4496057592*t)
	Y1 += 0.00000002673*np.cos(4.52643518421 + 188.0263011725*t)
	Y1 += 0.00000002510*np.cos(1.15119413127 + 1258.4539316256*t)
	Y1 += 0.00000002508*np.cos(4.64584835668 + 58.319272332*t)
	Y1 += 0.00000002522*np.cos(2.97708735282 + 115.3623147599*t)
	Y1 += 0.00000002587*np.cos(3.00667195954 + 274.0660483248*t)
	Y1 += 0.00000002614*np.cos(1.51553905536 + 710.7467316182*t)
	Y1 += 0.00000002528*np.cos(2.67128255093 + 698.216558646*t)
	Y1 += 0.00000002660*np.cos(1.71574009269 + 159.7151255212*t)
	Y1 += 0.00000002623*np.cos(2.85599045349 + 10138.5039476437*t)
	Y1 += 0.00000002899*np.cos(0.96731641272 + 620.253566341*t)
	Y1 += 0.00000002890*np.cos(1.74392727178 + 361.3778198643*t)
	Y1 += 0.00000003276*np.cos(6.16884433819 + 436.7501192626*t)
	Y1 += 0.00000003222*np.cos(5.36285287700 + 420.9691165835*t)
	Y1 += 0.00000002812*np.cos(1.64142224314 + 282.6640680339*t)
	Y1 += 0.00000002497*np.cos(4.16307526782 + 40.5807161926*t)
	Y1 += 0.00000002497*np.cos(0.51632716818 + 108.982480942*t)
	Y1 += 0.00000002509*np.cos(1.35310476503 + 43.2408450685*t)
	Y1 += 0.00000002516*np.cos(3.39431422644 + 1197.8994270599*t)
	Y1 += 0.00000002682*np.cos(1.47035618217 + 771.3012361839*t)
	Y1 += 0.00000002890*np.cos(2.24537565953 + 678.3603903519*t)
	Y1 += 0.00000003365*np.cos(2.19461743302 + 278.5194664497*t)
	Y1 += 0.00000002629*np.cos(2.58288671181 + 632.0329797878*t)
	Y1 += 0.00000003210*np.cos(2.69201905729 + 913.7508863177*t)
	Y1 += 0.00000002722*np.cos(2.29818896796 + 947.5310775671*t)
	Y1 += 0.00000002682*np.cos(5.88532422026 + 9988.9407505091*t)
	Y1 += 0.00000003247*np.cos(4.08732574063 + 256.4280659219*t)
	Y1 += 0.00000002408*np.cos(0.47310204864 + 1228.4982245716*t)
	Y1 += 0.00000002354*np.cos(5.43938033767 + 545.4719677737*t)
	Y1 += 0.00000002353*np.cos(3.88526025060 + 74.5691502462*t)
	Y1 += 0.00000002353*np.cos(3.93573483899 + 74.9940468884*t)
	Y1 += 0.00000002656*np.cos(1.88365819066 + 623.2225117576*t)
	Y1 += 0.00000002429*np.cos(5.72370124169 + 390.2102603774*t)
	Y1 += 0.00000002444*np.cos(1.06366859477 + 894.8408795276*t)
	Y1 += 0.00000002491*np.cos(0.63438778395 + 707.5653378805*t)
	Y1 += 0.00000002415*np.cos(0.41649797223 + 843.6351541964*t)
	Y1 += 0.00000003252*np.cos(4.42154696407 + 418.0001711669*t)
	Y1 += 0.00000002334*np.cos(0.24779158408 + 616.3214130779*t)
	Y1 += 0.00000002976*np.cos(3.41026880242 + 80.4106728598*t)
	Y1 += 0.00000003153*np.cos(4.34461658951 + 69.1525242748*t)
	Y1 += 0.00000003024*np.cos(5.65318667869 + 1812.5239191084*t)
	Y1 += 0.00000002378*np.cos(1.24448739687 + 223.3815878554*t)
	Y1 += 0.00000002550*np.cos(1.85100883332 + 335.1418177523*t)
	Y1 += 0.00000002304*np.cos(0.92872058513 + 724.8308132679*t)
	Y1 += 0.00000002315*np.cos(5.89124641812 + 246.9787129509*t)
	Y1 += 0.00000002586*np.cos(3.79185736317 + 623.4349600787*t)
	Y1 += 0.00000002625*np.cos(4.80912360331 + 563.6312150384*t)
	Y1 += 0.00000002528*np.cos(1.99323803493 + 450.4559484024*t)
	Y1 += 0.00000002962*np.cos(2.84656694258 + 370.5665404044*t)
	Y1 += 0.00000002530*np.cos(3.77285579953 + 253.5709950899*t)
	Y1 += 0.00000002717*np.cos(6.02370493813 + 479.4002635001*t)
	Y1 += 0.00000002610*np.cos(2.56475445472 + 3116.2676309979*t)
	Y1 += 0.00000002267*np.cos(3.00681622152 + 464.4705940829*t)
	Y1 += 0.00000002331*np.cos(4.22833309205 + 980.6681783588*t)
	Y1 += 0.00000002485*np.cos(5.71826869254 + 461.1291416508*t)
	Y1 += 0.00000002223*np.cos(0.33085814506 + 53.5839699168*t)
	Y1 += 0.00000002250*np.cos(5.53400951210 + 180.7951340927*t)
	Y1 += 0.00000002252*np.cos(0.57877591071 + 1374.1292684431*t)
	Y1 += 0.00000002868*np.cos(1.11810457004 + 100.6450936638*t)
	Y1 += 0.00000002548*np.cos(3.44201255815 + 595.7144852584*t)
	Y1 += 0.00000002729*np.cos(1.32506308123 + 520.129737539*t)
	Y1 += 0.00000002230*np.cos(4.49028913350 + 417.0369633204*t)
	Y1 += 0.00000002227*np.cos(3.79362555076 + 6144.5583531207*t)
	return Y1*t




def Uranus_Y2 (t): # 238 terms of order 2

	Y2 = 0.
	Y2 -= 0.00034868461
	Y2 += 0.00016588468*np.cos(2.29556740317 + 74.7815985673*t)
	Y2 += 0.00010905147*np.cos(1.45737963668 + 149.5631971346*t)
	Y2 += 0.00007484633*np.cos(2.27968076918 + 11.0457002639*t)
	Y2 += 0.00007964298*np.cos(0.97230247087 + 63.7358983034*t)
	Y2 += 0.00005307100*np.cos(3.20519221878 + 70.8494453042*t)
	Y2 += 0.00005018595*np.cos(1.47518527303 + 78.7137518304*t)
	Y2 += 0.00006713255*np.cos(3.74148881189 + 85.8272988312*t)
	Y2 += 0.00005265170*np.cos(0.54901216905 + 73.297125859*t)
	Y2 += 0.00004864822*np.cos(4.11367426823 + 76.2660712756*t)
	Y2 += 0.00002995853*np.cos(2.49432193549 + 138.5174968707*t)
	Y2 += 0.00002519021*np.cos(1.78896824345 + 71.6002048296*t)
	Y2 += 0.00002418371*np.cos(2.88675006488 + 77.962992305*t)
	Y2 += 0.00002185856*np.cos(5.58862614977 + 3.9321532631*t)
	Y2 += 0.00001035578*np.cos(5.44752448275 + 145.6310438715*t)
	Y2 += 0.00001044459*np.cos(4.27972239360 + 224.3447957019*t)
	Y2 += 0.00000659180*np.cos(5.73048296712 + 18.1592472647*t)
	Y2 += 0.00000496445*np.cos(3.71294537420 + 22.0914005278*t)
	Y2 += 0.00000503264*np.cos(0.65556547194 + 151.0476698429*t)
	Y2 += 0.00000477875*np.cos(1.62059307105 + 72.3339180125*t)
	Y2 += 0.00000484216*np.cos(3.45190804780 + 3.1813937377*t)
	Y2 += 0.00000381403*np.cos(3.62830479384 + 77.7505439839*t)
	Y2 += 0.00000403003*np.cos(6.27429134777 + 160.6088973985*t)
	Y2 += 0.00000333059*np.cos(0.97920205195 + 71.8126531507*t)
	Y2 += 0.00000384754*np.cos(3.16159208089 + 77.2292791221*t)
	Y2 += 0.00000336233*np.cos(4.76282903544 + 65.2203710117*t)
	Y2 += 0.00000292404*np.cos(3.58367735696 + 56.6223513026*t)
	Y2 += 0.00000289620*np.cos(5.24475224875 + 131.4039498699*t)
	Y2 += 0.00000249990*np.cos(1.37715629750 + 127.4717966068*t)
	Y2 += 0.00000301291*np.cos(0.20539719662 + 84.3428261229*t)
	Y2 += 0.00000213294*np.cos(0.42767033738 + 52.6901980395*t)
	Y2 += 0.00000206036*np.cos(1.32796659605 + 92.940845832*t)
	Y2 += 0.00000284114*np.cos(4.23135833063 + 148.0787244263*t)
	Y2 += 0.00000211339*np.cos(4.01130147721 + 153.4953503977*t)
	Y2 += 0.00000198865*np.cos(1.14978553110 + 12.5301729722*t)
	Y2 += 0.00000204876*np.cos(2.67799239908 + 87.3117715395*t)
	Y2 += 0.00000151427*np.cos(5.07559906633 + 213.299095438*t)
	Y2 += 0.00000142723*np.cos(0.10949652735 + 9.5612275556*t)
	Y2 += 0.00000119838*np.cos(6.14846862601 + 7.1135470008*t)
	Y2 += 0.00000098996*np.cos(0.45350083876 + 80.1982245387*t)
	Y2 += 0.00000097068*np.cos(5.58114008285 + 96.8729990951*t)
	Y2 += 0.00000086384*np.cos(0.65961400871 + 299.1263942692*t)
	Y2 += 0.00000106322*np.cos(4.32303636127 + 146.3818033969*t)
	Y2 += 0.00000088292*np.cos(1.19515450864 + 67.6680515665*t)
	Y2 += 0.00000077418*np.cos(3.42602178272 + 81.8951455681*t)
	Y2 += 0.00000100445*np.cos(2.04935236166 + 62.2514255951*t)
	Y2 += 0.00000070729*np.cos(1.55860445086 + 220.4126424388*t)
	Y2 += 0.00000067304*np.cos(1.98742659596 + 14.977853527*t)
	Y2 += 0.00000090127*np.cos(4.05284117214 + 2.9689454166*t)
	Y2 += 0.00000061645*np.cos(0.99125497203 + 152.7445908723*t)
	Y2 += 0.00000062451*np.cos(3.50449733826 + 2.4476805548*t)
	Y2 += 0.00000050857*np.cos(2.57947671273 + 79.2350166922*t)
	Y2 += 0.00000049175*np.cos(3.33707572701 + 225.8292684102*t)
	Y2 += 0.00000047122*np.cos(6.24480457103 + 195.1398481733*t)
	Y2 += 0.00000043658*np.cos(2.08963855451 + 70.3281804424*t)
	Y2 += 0.00000044194*np.cos(2.16514447619 + 209.3669421749*t)
	Y2 += 0.00000041219*np.cos(4.04232816275 + 120.358249606*t)
	Y2 += 0.00000041618*np.cos(6.14356383699 + 152.5321425512*t)
	Y2 += 0.00000044787*np.cos(5.30573896543 + 1.4844727083*t)
	Y2 += 0.00000048896*np.cos(4.61108579721 + 142.4496501338*t)
	Y2 += 0.00000039806*np.cos(1.64663028331 + 29.2049475286*t)
	Y2 += 0.00000036426*np.cos(4.53511032225 + 5.4166259714*t)
	Y2 += 0.00000035147*np.cos(4.19203202972 + 69.3649725959*t)
	Y2 += 0.00000035324*np.cos(3.94582037445 + 137.0330241624*t)
	Y2 += 0.00000034455*np.cos(2.94012534655 + 45.5766510387*t)
	Y2 += 0.00000031548*np.cos(0.08014882734 + 202.2533951741*t)
	Y2 += 0.00000025084*np.cos(2.59672105549 + 23.5758732361*t)
	Y2 += 0.00000025727*np.cos(3.38530289472 + 4.4534181249*t)
	Y2 += 0.00000025905*np.cos(5.51750075147 + 222.8603229936*t)
	Y2 += 0.00000025105*np.cos(6.13712522856 + 20.6069278195*t)
	Y2 += 0.00000027600*np.cos(5.36277971664 + 152.0108776894*t)
	Y2 += 0.00000025241*np.cos(2.50523497126 + 235.3904959658*t)
	Y2 += 0.00000020655*np.cos(1.78642126857 + 206.1855484372*t)
	Y2 += 0.00000021960*np.cos(5.50155148287 + 33.1371007917*t)
	Y2 += 0.00000020191*np.cos(6.02482335285 + 70.1157321213*t)
	Y2 += 0.00000019159*np.cos(0.15180124055 + 146.594251718*t)
	Y2 += 0.00000018561*np.cos(4.26574885795 + 89.7594520943*t)
	Y2 += 0.00000018567*np.cos(1.94117799593 + 159.1244246902*t)
	Y2 += 0.00000019255*np.cos(5.90993836545 + 14.2270940016*t)
	Y2 += 0.00000019020*np.cos(1.80248271648 + 79.4474650133*t)
	Y2 += 0.00000023161*np.cos(4.23174691360 + 39.6175083461*t)
	Y2 += 0.00000016887*np.cos(3.72825385287 + 54.1746707478*t)
	Y2 += 0.00000016486*np.cos(4.35636304940 + 265.9892934775*t)
	Y2 += 0.00000017966*np.cos(0.73075314120 + 73.0846775379*t)
	Y2 += 0.00000017801*np.cos(0.81410786052 + 76.4785195967*t)
	Y2 += 0.00000016355*np.cos(5.49262798093 + 41.6444977756*t)
	Y2 += 0.00000015318*np.cos(0.34171416887 + 144.1465711632*t)
	Y2 += 0.00000017894*np.cos(2.93472052580 + 191.2076949102*t)
	Y2 += 0.00000015137*np.cos(1.53552554645 + 333.657345044*t)
	Y2 += 0.00000014035*np.cos(3.28512675029 + 16.6747745564*t)
	Y2 += 0.00000014322*np.cos(4.50674337635 + 19.643719973*t)
	Y2 += 0.00000014946*np.cos(5.27114717415 + 162.0933701068*t)
	Y2 += 0.00000012956*np.cos(4.83849215643 + 128.9562693151*t)
	Y2 += 0.00000013463*np.cos(3.87039405264 + 347.8844390456*t)
	Y2 += 0.00000014921*np.cos(3.89865314878 + 147.1155165798*t)
	Y2 += 0.00000014742*np.cos(0.24012355053 + 116.4260963429*t)
	Y2 += 0.00000011066*np.cos(5.60988445239 + 25.2727942655*t)
	Y2 += 0.00000010143*np.cos(5.97679605331 + 211.8146227297*t)
	Y2 += 0.00000010722*np.cos(1.34423420021 + 277.0349937414*t)
	Y2 += 0.00000009902*np.cos(1.31072841849 + 51.2057253312*t)
	Y2 += 0.00000010052*np.cos(4.85098798718 + 140.001969579*t)
	Y2 += 0.00000009261*np.cos(3.82300076507 + 167.7224443993*t)
	Y2 += 0.00000011487*np.cos(1.35796386677 + 88.7962442478*t)
	Y2 += 0.00000011729*np.cos(0.42839638233 + 109.9456887885*t)
	Y2 += 0.00000008957*np.cos(3.95902561062 + 66.70484372*t)
	Y2 += 0.00000009943*np.cos(2.73449416367 + 125.9873238985*t)
	Y2 += 0.00000010530*np.cos(2.81641731347 + 340.7708920448*t)
	Y2 += 0.00000008585*np.cos(1.43915440031 + 273.1028404783*t)
	Y2 += 0.00000009262*np.cos(0.25380942211 + 228.276948965*t)
	Y2 += 0.00000008980*np.cos(0.07240673383 + 258.8757464767*t)
	Y2 += 0.00000008113*np.cos(3.49659867366 + 41.1019810544*t)
	Y2 += 0.00000007532*np.cos(3.27091826281 + 89.0086925689*t)
	Y2 += 0.00000007218*np.cos(1.29306244244 + 95.3885263868*t)
	Y2 += 0.00000006506*np.cos(3.76490510734 + 305.3461693927*t)
	Y2 += 0.00000007895*np.cos(1.44148781358 + 58.1068240109*t)
	Y2 += 0.00000008400*np.cos(1.69644708576 + 288.0806940053*t)
	Y2 += 0.00000006266*np.cos(1.22803728787 + 145.1097790097*t)
	Y2 += 0.00000006202*np.cos(2.38239788885 + 24.3790223882*t)
	Y2 += 0.00000006356*np.cos(2.95032284330 + 154.979823106*t)
	Y2 += 0.00000006155*np.cos(5.11379042923 + 135.336103133*t)
	Y2 += 0.00000006766*np.cos(6.24976890449 + 151.260118164*t)
	Y2 += 0.00000005842*np.cos(0.55024185445 + 39.3568759152*t)
	Y2 += 0.00000005958*np.cos(5.37871484808 + 46.470422916*t)
	Y2 += 0.00000005975*np.cos(5.18569044972 + 124.2904028691*t)
	Y2 += 0.00000005696*np.cos(3.21705372191 + 472.1748419147*t)
	Y2 += 0.00000005752*np.cos(1.03860750406 + 60.5545045657*t)
	Y2 += 0.00000005425*np.cos(2.95721172846 + 91.4563731237*t)
	Y2 += 0.00000005099*np.cos(4.07581634888 + 110.2063212194*t)
	Y2 += 0.00000005364*np.cos(0.96162321097 + 75.7448064138*t)
	Y2 += 0.00000005364*np.cos(0.57618657144 + 73.8183907208*t)
	Y2 += 0.00000005063*np.cos(5.63683871438 + 103.0927742186*t)
	Y2 += 0.00000005205*np.cos(2.23672411079 + 216.4804891757*t)
	Y2 += 0.00000004815*np.cos(5.91669724929 + 404.5067903482*t)
	Y2 += 0.00000005249*np.cos(3.54162440174 + 60.7669528868*t)
	Y2 += 0.00000004995*np.cos(5.58752388097 + 486.4019359163*t)
	Y2 += 0.00000004821*np.cos(3.38575445220 + 373.9079928365*t)
	Y2 += 0.00000004599*np.cos(2.03799101392 + 450.9772132642*t)
	Y2 += 0.00000004404*np.cos(1.90821960483 + 171.6545976624*t)
	Y2 += 0.00000005157*np.cos(5.75283583629 + 383.3091616977*t)
	Y2 += 0.00000004748*np.cos(4.37116225746 + 98.3574718034*t)
	Y2 += 0.00000004669*np.cos(3.67388415780 + 49.5088043018*t)
	Y2 += 0.00000004762*np.cos(4.63198019160 + 329.7251917809*t)
	Y2 += 0.00000004287*np.cos(1.19918156505 + 108.4612160802*t)
	Y2 += 0.00000005386*np.cos(4.11798763222 + 227.5261894396*t)
	Y2 += 0.00000004000*np.cos(4.79734715617 + 184.0941479094*t)
	Y2 += 0.00000003921*np.cos(1.00781809287 + 894.8408795276*t)
	Y2 += 0.00000003787*np.cos(1.34077162848 + 397.3932433474*t)
	Y2 += 0.00000004564*np.cos(2.38658597554 + 223.4510238246*t)
	Y2 += 0.00000003744*np.cos(4.87117009195 + 43.2890291783*t)
	Y2 += 0.00000003802*np.cos(5.61691850652 + 155.7829722581*t)
	Y2 += 0.00000003710*np.cos(0.16060396513 + 94.4253185403*t)
	Y2 += 0.00000003673*np.cos(3.56449648462 + 69.1525242748*t)
	Y2 += 0.00000003673*np.cos(1.11490595138 + 80.4106728598*t)
	Y2 += 0.00000003600*np.cos(0.19065704569 + 61.448276443*t)
	Y2 += 0.00000003535*np.cos(1.86154901498 + 1514.2912967165*t)
	Y2 += 0.00000003657*np.cos(3.22119466829 + 849.2642284889*t)
	Y2 += 0.00000003961*np.cos(3.04268397680 + 36.6485629295*t)
	Y2 += 0.00000003434*np.cos(2.88580512636 + 230.5645708254*t)
	Y2 += 0.00000003405*np.cos(3.87857248169 + 295.1942410061*t)
	Y2 += 0.00000004522*np.cos(2.96435934024 + 203.7378678824*t)
	Y2 += 0.00000003531*np.cos(3.17610762377 + 411.620337349*t)
	Y2 += 0.00000003485*np.cos(1.35195294182 + 446.3113468182*t)
	Y2 += 0.00000003245*np.cos(2.89796599726 + 428.0826635843*t)
	Y2 += 0.00000003276*np.cos(0.08848769483 + 32.2433289144*t)
	Y2 += 0.00000003208*np.cos(4.56578033890 + 237.6781178262*t)
	Y2 += 0.00000003504*np.cos(0.77982010393 + 204.7010757289*t)
	Y2 += 0.00000003179*np.cos(4.70754664264 + 1057.8974574809*t)
	Y2 += 0.00000003445*np.cos(0.04871363996 + 753.1419889192*t)
	Y2 += 0.00000003632*np.cos(3.85766982755 + 57.5161231799*t)
	Y2 += 0.00000003159*np.cos(1.29789979439 + 380.12776796*t)
	Y2 += 0.00000003617*np.cos(3.39978483308 + 103.9865460959*t)
	Y2 += 0.00000003793*np.cos(1.38792912334 + 294.3004691288*t)
	Y2 += 0.00000003321*np.cos(3.70449950362 + 460.5384408198*t)
	Y2 += 0.00000003121*np.cos(4.43249349458 + 55.1378785943*t)
	Y2 += 0.00000003208*np.cos(3.77713666696 + 354.9979860464*t)
	Y2 += 0.00000003164*np.cos(1.44848652521 + 1819.6374661092*t)
	Y2 += 0.00000004062*np.cos(1.43575455534 + 112.9146342051*t)
	Y2 += 0.00000003055*np.cos(6.14900289425 + 106.2741679563*t)
	Y2 += 0.00000003327*np.cos(0.69765513922 + 381.6122406683*t)
	Y2 += 0.00000003540*np.cos(2.12097406285 + 956.2891559706*t)
	Y2 += 0.00000003851*np.cos(1.23576525810 + 82.8583534146*t)
	Y2 += 0.00000003454*np.cos(1.09473115664 + 624.919432787*t)
	Y2 += 0.00000003041*np.cos(5.21748882730 + 531.1754378029*t)
	Y2 += 0.00000003545*np.cos(4.52042282129 + 901.9544265284*t)
	Y2 += 0.00000002983*np.cos(2.48436459152 + 422.6660376129*t)
	Y2 += 0.00000003664*np.cos(4.55449595595 + 610.6923387854*t)
	Y2 += 0.00000002957*np.cos(1.81585565871 + 207.6700211455*t)
	Y2 += 0.00000003146*np.cos(4.43411072622 + 1169.5882514086*t)
	Y2 += 0.00000003006*np.cos(4.98418529506 + 291.1190753911*t)
	Y2 += 0.00000003196*np.cos(0.96757140567 + 336.8387387817*t)
	Y2 += 0.00000002923*np.cos(5.33580924726 + 198.321241911*t)
	Y2 += 0.00000002940*np.cos(3.90791054506 + 284.1485407422*t)
	Y2 += 0.00000003170*np.cos(1.66951998253 + 710.7467316182*t)
	Y2 += 0.00000002815*np.cos(2.77743270790 + 254.9435932136*t)
	Y2 += 0.00000003336*np.cos(4.30390109950 + 50.4025761791*t)
	Y2 += 0.00000002836*np.cos(4.48874732911 + 88.1149206916*t)
	Y2 += 0.00000003176*np.cos(4.64659372687 + 479.2883889155*t)
	Y2 += 0.00000002838*np.cos(0.15453414558 + 942.062061969*t)
	Y2 += 0.00000002782*np.cos(6.02038453941 + 429.7795846137*t)
	Y2 += 0.00000003059*np.cos(3.17419847154 + 109.3125493421*t)
	Y2 += 0.00000002929*np.cos(3.80821042876 + 306.830642101*t)
	Y2 += 0.00000003352*np.cos(1.60450384950 + 606.7601855223*t)
	Y2 += 0.00000002656*np.cos(1.22918007705 + 415.5524906121*t)
	Y2 += 0.00000002948*np.cos(1.02017644336 + 180.1619946463*t)
	Y2 += 0.00000002586*np.cos(6.25175921411 + 200.7689224658*t)
	Y2 += 0.00000002982*np.cos(5.27568045991 + 827.1728279611*t)
	Y2 += 0.00000002543*np.cos(5.00768138430 + 358.9301393095*t)
	Y2 += 0.00000003044*np.cos(3.85742807611 + 398.2870152247*t)
	Y2 += 0.00000003450*np.cos(5.56161109812 + 33.6796175129*t)
	Y2 += 0.00000002649*np.cos(0.19906595464 + 387.2413149608*t)
	Y2 += 0.00000002653*np.cos(6.19083949511 + 476.1069951778*t)
	Y2 += 0.00000002656*np.cos(2.26611314470 + 504.561183181*t)
	Y2 += 0.00000002658*np.cos(2.53449256208 + 343.2185725996*t)
	Y2 += 0.00000002512*np.cos(2.72011642094 + 218.9281697305*t)
	Y2 += 0.00000002655*np.cos(1.51011044922 + 297.6419215609*t)
	Y2 += 0.00000002764*np.cos(1.02815159981 + 275.5505210331*t)
	Y2 += 0.00000002619*np.cos(5.02123369052 + 221.3758502853*t)
	Y2 += 0.00000002589*np.cos(3.35286991320 + 681.5417840896*t)
	Y2 += 0.00000002439*np.cos(1.19257109184 + 25.6028626656*t)
	Y2 += 0.00000002613*np.cos(1.99329848731 + 1155.361157407*t)
	Y2 += 0.00000002428*np.cos(5.63777334261 + 714.6788848813*t)
	Y2 += 0.00000002654*np.cos(0.17490588647 + 905.8865797915*t)
	Y2 += 0.00000003170*np.cos(2.01449003883 + 132.8884225782*t)
	Y2 += 0.00000002575*np.cos(1.70882633694 + 461.1291416508*t)
	Y2 += 0.00000002698*np.cos(4.86732070299 + 376.9463742223*t)
	Y2 += 0.00000002602*np.cos(5.27380478496 + 144.8973306886*t)
	Y2 += 0.00000002602*np.cos(5.68878295822 + 4.665866446*t)
	Y2 += 0.00000002340*np.cos(5.27124006260 + 909.8187330546*t)
	Y2 += 0.00000002410*np.cos(4.39403216091 + 969.6224780949*t)
	Y2 += 0.00000002575*np.cos(5.00930018514 + 987.7817253596*t)
	Y2 += 0.00000002387*np.cos(3.47175060090 + 346.1875180162*t)
	Y2 += 0.00000002297*np.cos(2.37697209648 + 983.1158589136*t)
	Y2 += 0.00000002400*np.cos(0.73715855446 + 1282.8329540138*t)
	Y2 += 0.00000002428*np.cos(3.19595816714 + 991.7138786227*t)
	Y2 += 0.00000002377*np.cos(0.83202602714 + 280.2163874791*t)
	Y2 += 0.00000002330*np.cos(2.06975538259 + 227.3137411185*t)
	Y2 += 0.00000002192*np.cos(3.13720960527 + 267.4737661858*t)
	Y2 += 0.00000002721*np.cos(1.30292847611 + 735.8765135318*t)
	return Y2*t*t




def Uranus_Y3 (t): # 75 terms of order 3

	Y3 = 0.
	Y3 += 0.00001214019
	Y3 += 0.00000668539*np.cos(1.35719575778 + 70.8494453042*t)
	Y3 += 0.00000634232*np.cos(3.31949833714 + 78.7137518304*t)
	Y3 += 0.00000580282*np.cos(5.50249893160 + 149.5631971346*t)
	Y3 += 0.00000554688*np.cos(3.11230721382 + 63.7358983034*t)
	Y3 += 0.00000455522*np.cos(1.60057962784 + 85.8272988312*t)
	Y3 += 0.00000428309*np.cos(2.52339539695 + 73.297125859*t)
	Y3 += 0.00000410924*np.cos(2.15904083831 + 76.2660712756*t)
	Y3 += 0.00000446887*np.cos(3.43730189985 + 71.6002048296*t)
	Y3 += 0.00000422459*np.cos(1.24206088889 + 77.962992305*t)
	Y3 += 0.00000354240*np.cos(0.67890104591 + 11.0457002639*t)
	Y3 += 0.00000246686*np.cos(0.94534563236 + 3.9321532631*t)
	Y3 += 0.00000213878*np.cos(5.65915292036 + 74.7815985673*t)
	Y3 += 0.00000132364*np.cos(4.15026512788 + 138.5174968707*t)
	Y3 += 0.00000119450*np.cos(3.90585537641 + 18.1592472647*t)
	Y3 += 0.00000120394*np.cos(3.74665637710 + 145.6310438715*t)
	Y3 += 0.00000088187*np.cos(1.90411105424 + 3.1813937377*t)
	Y3 += 0.00000052632*np.cos(1.75498192807 + 224.3447957019*t)
	Y3 += 0.00000050576*np.cos(0.78027105095 + 131.4039498699*t)
	Y3 += 0.00000053379*np.cos(5.39427276412 + 56.6223513026*t)
	Y3 += 0.00000046166*np.cos(1.35350701377 + 22.0914005278*t)
	Y3 += 0.00000034956*np.cos(4.58100445018 + 151.0476698429*t)
	Y3 += 0.00000034551*np.cos(5.72333746106 + 92.940845832*t)
	Y3 += 0.00000028364*np.cos(4.13984176064 + 160.6088973985*t)
	Y3 += 0.00000026418*np.cos(5.85866043581 + 153.4953503977*t)
	Y3 += 0.00000024290*np.cos(3.47380451115 + 127.4717966068*t)
	Y3 += 0.00000020448*np.cos(2.29388641968 + 52.6901980395*t)
	Y3 += 0.00000018708*np.cos(1.87727467097 + 81.8951455681*t)
	Y3 += 0.00000017870*np.cos(2.76211883479 + 67.6680515665*t)
	Y3 += 0.00000020164*np.cos(6.22457490776 + 65.2203710117*t)
	Y3 += 0.00000015540*np.cos(0.46398262034 + 87.3117715395*t)
	Y3 += 0.00000020752*np.cos(4.92517122004 + 84.3428261229*t)
	Y3 += 0.00000015215*np.cos(4.65923267413 + 148.0787244263*t)
	Y3 += 0.00000017277*np.cos(5.95787288564 + 146.3818033969*t)
	Y3 += 0.00000008774*np.cos(4.29662781061 + 62.2514255951*t)
	Y3 += 0.00000008664*np.cos(3.15614012306 + 96.8729990951*t)
	Y3 += 0.00000008336*np.cos(6.17866331895 + 220.4126424388*t)
	Y3 += 0.00000007548*np.cos(5.79027481592 + 152.7445908723*t)
	Y3 += 0.00000007274*np.cos(0.42348579344 + 209.3669421749*t)
	Y3 += 0.00000006892*np.cos(5.13529284135 + 69.1525242748*t)
	Y3 += 0.00000006892*np.cos(5.82729490183 + 80.4106728598*t)
	Y3 += 0.00000006636*np.cos(1.73465134196 + 195.1398481733*t)
	Y3 += 0.00000006513*np.cos(5.16226282857 + 45.5766510387*t)
	Y3 += 0.00000006716*np.cos(6.05135269504 + 120.358249606*t)
	Y3 += 0.00000006103*np.cos(1.45096139819 + 202.2533951741*t)
	Y3 += 0.00000005554*np.cos(1.27094393615 + 77.2292791221*t)
	Y3 += 0.00000005414*np.cos(5.62961039887 + 69.3649725959*t)
	Y3 += 0.00000005319*np.cos(0.24108290967 + 72.3339180125*t)
	Y3 += 0.00000005023*np.cos(0.31886761727 + 298.2326223919*t)
	Y3 += 0.00000004096*np.cos(1.74642791377 + 59.8037450403*t)
	Y3 += 0.00000004056*np.cos(5.41805385885 + 312.4597163935*t)
	Y3 += 0.00000004420*np.cos(2.31775089018 + 80.1982245387*t)
	Y3 += 0.00000004556*np.cos(5.81167808783 + 29.2049475286*t)
	Y3 += 0.00000003772*np.cos(0.45736408308 + 71.8126531507*t)
	Y3 += 0.00000003772*np.cos(1.08044569933 + 77.7505439839*t)
	Y3 += 0.00000003522*np.cos(2.27206270731 + 635.9651330509*t)
	Y3 += 0.00000003471*np.cos(3.83894807943 + 486.4019359163*t)
	Y3 += 0.00000003427*np.cos(3.23330507919 + 621.7380390493*t)
	Y3 += 0.00000003564*np.cos(1.40324348330 + 70.1157321213*t)
	Y3 += 0.00000003564*np.cos(0.13456629911 + 79.4474650133*t)
	Y3 += 0.00000003245*np.cos(2.48350812643 + 611.5861106627*t)
	Y3 += 0.00000003106*np.cos(3.95294824397 + 462.0229135281*t)
	Y3 += 0.00000003058*np.cos(4.98861382553 + 472.1748419147*t)
	Y3 += 0.00000002838*np.cos(4.20089846346 + 422.6660376129*t)
	Y3 += 0.00000003736*np.cos(1.94889984594 + 258.8757464767*t)
	Y3 += 0.00000002795*np.cos(5.98115561353 + 273.1028404783*t)
	Y3 += 0.00000002807*np.cos(4.70523398072 + 647.0108333148*t)
	Y3 += 0.00000002640*np.cos(0.64993830115 + 288.0806940053*t)
	Y3 += 0.00000002579*np.cos(1.56012171684 + 199.0720014364*t)
	Y3 += 0.00000002672*np.cos(4.35858426427 + 376.1956146969*t)
	Y3 += 0.00000002507*np.cos(4.31322403686 + 134.5853436076*t)
	Y3 += 0.00000003134*np.cos(0.16461922297 + 408.4389436113*t)
	Y3 += 0.00000002998*np.cos(2.39309465855 + 73.0846775379*t)
	Y3 += 0.00000002998*np.cos(5.42790043104 + 76.4785195967*t)
	Y3 += 0.00000002218*np.cos(4.57446080069 + 391.1734682239*t)
	return Y3*t*t*t




def Uranus_Y4 (t): # 10 terms of order 4

	Y4 = 0.
	Y4 += 0.00000049430
	Y4 += 0.00000034198*np.cos(5.13940292251 + 63.7358983034*t)
	Y4 += 0.00000026702*np.cos(3.77414105026 + 149.5631971346*t)
	Y4 += 0.00000027044*np.cos(5.82865569544 + 85.8272988312*t)
	Y4 += 0.00000016281*np.cos(2.05669737682 + 18.1592472647*t)
	Y4 += 0.00000006674*np.cos(2.47653692518 + 131.4039498699*t)
	Y4 += 0.00000007990*np.cos(0.88303095823 + 56.6223513026*t)
	Y4 += 0.00000005228*np.cos(3.84002419343 + 92.940845832*t)
	Y4 += 0.00000002294*np.cos(4.60700787690 + 365.9006739584*t)
	Y4 += 0.00000002483*np.cos(2.14187723981 + 284.1485407422*t)
	return Y4*t*t*t*t




def Uranus_Y5 (t): # 1 term of order 5

	Y5 = 0.
	Y5 += 0.00000000000
	return Y5*t*t*t*t*t




def Uranus_Z0 (t): # 232 terms of order 0

	Z0 = 0.
	Z0 += 0.25876996652*np.cos(2.61861278845 + 74.7815985673*t)
	Z0 -= 0.01775471434
	Z0 += 0.00599290075*np.cos(5.08119534568 + 149.5631971346*t)
	Z0 += 0.00190282274*np.cos(1.61654207891 + 76.2660712756*t)
	Z0 += 0.00190873655*np.cos(0.57869366179 + 73.297125859*t)
	Z0 += 0.00084625392*np.cos(2.26025774942 + 1.4844727083*t)
	Z0 += 0.00030733539*np.cos(0.23570745974 + 63.7358983034*t)
	Z0 += 0.00020842052*np.cos(1.26054208091 + 224.3447957019*t)
	Z0 += 0.00019733410*np.cos(6.04314596336 + 148.0787244263*t)
	Z0 += 0.00012537530*np.cos(5.17169051466 + 11.0457002639*t)
	Z0 += 0.00014582183*np.cos(6.14852624696 + 71.8126531507*t)
	Z0 += 0.00008855669*np.cos(4.03774505739 + 151.0476698429*t)
	Z0 += 0.00008239051*np.cos(0.34223137462 + 77.7505439839*t)
	Z0 += 0.00007950169*np.cos(0.72564903051 + 85.8272988312*t)
	Z0 += 0.00006868135*np.cos(0.81403748021 + 2.9689454166*t)
	Z0 += 0.00005648720*np.cos(3.45324719543 + 138.5174968707*t)
	Z0 += 0.00002578399*np.cos(5.19696447390 + 111.4301614968*t)
	Z0 += 0.00002965471*np.cos(6.14354111880 + 35.1640902212*t)
	Z0 += 0.00001884104*np.cos(2.61192472648 + 78.7137518304*t)
	Z0 += 0.00002330304*np.cos(5.72640226150 + 70.8494453042*t)
	Z0 += 0.00002006709*np.cos(0.75959407190 + 39.6175083461*t)
	Z0 += 0.00001743154*np.cos(1.20586281789 + 146.594251718*t)
	Z0 += 0.00002037011*np.cos(0.95353587037 + 70.3281804424*t)
	Z0 += 0.00001512017*np.cos(0.10355104309 + 213.299095438*t)
	Z0 += 0.00001508924*np.cos(2.26195448553 + 222.8603229936*t)
	Z0 += 0.00001215921*np.cos(3.32019275533 + 38.1330356378*t)
	Z0 += 0.00001082736*np.cos(2.62872874057 + 108.4612160802*t)
	Z0 += 0.00001051968*np.cos(0.75560753840 + 109.9456887885*t)
	Z0 += 0.00000860142*np.cos(3.72285572975 + 299.1263942692*t)
	Z0 += 0.00000816182*np.cos(3.95303779460 + 52.6901980395*t)
	Z0 += 0.00000655382*np.cos(3.87077980521 + 36.6485629295*t)
	Z0 += 0.00000712421*np.cos(1.08343941878 + 3.9321532631*t)
	Z0 += 0.00000561959*np.cos(1.87601204328 + 351.8165923087*t)
	Z0 += 0.00000618657*np.cos(5.77033241076 + 4.4534181249*t)
	Z0 += 0.00000526378*np.cos(3.88178280084 + 112.9146342051*t)
	Z0 += 0.00000622898*np.cos(5.56100734055 + 202.2533951741*t)
	Z0 += 0.00000464130*np.cos(0.20598822419 + 225.8292684102*t)
	Z0 += 0.00000448110*np.cos(2.70547740286 + 145.1097790097*t)
	Z0 += 0.00000421562*np.cos(3.66721349765 + 184.7272873558*t)
	Z0 += 0.00000458133*np.cos(5.49113221489 + 79.2350166922*t)
	Z0 += 0.00000437386*np.cos(1.24892718921 + 33.6796175129*t)
	Z0 += 0.00000393617*np.cos(1.25018492386 + 62.2514255951*t)
	Z0 += 0.00000424721*np.cos(2.73945218102 + 152.5321425512*t)
	Z0 += 0.00000465359*np.cos(3.24015058631 + 127.4717966068*t)
	Z0 += 0.00000350450*np.cos(2.57788261436 + 84.3428261229*t)
	Z0 += 0.00000375747*np.cos(3.20459646801 + 160.6088973985*t)
	Z0 += 0.00000313152*np.cos(1.32117543131 + 145.6310438715*t)
	Z0 += 0.00000284456*np.cos(1.70356835837 + 22.0914005278*t)
	Z0 += 0.00000265517*np.cos(2.67172684401 + 74.6697239827*t)
	Z0 += 0.00000258948*np.cos(4.12921582346 + 12.5301729722*t)
	Z0 += 0.00000325409*np.cos(2.48214857847 + 9.5612275556*t)
	Z0 += 0.00000261414*np.cos(5.78536193801 + 41.1019810544*t)
	Z0 += 0.00000237721*np.cos(0.80288483705 + 65.2203710117*t)
	Z0 += 0.00000223998*np.cos(3.91250165407 + 221.3758502853*t)
	Z0 += 0.00000220626*np.cos(3.93529110558 + 106.9767433719*t)
	Z0 += 0.00000265210*np.cos(5.70721287265 + 74.8934731519*t)
	Z0 += 0.00000260727*np.cos(0.26432051819 + 277.0349937414*t)
	Z0 += 0.00000201268*np.cos(5.94906398723 + 87.3117715395*t)
	Z0 += 0.00000165472*np.cos(3.54108848226 + 490.3340891794*t)
	Z0 += 0.00000216763*np.cos(2.14355016573 + 68.8437077341*t)
	Z0 += 0.00000166510*np.cos(3.37208863092 + 72.3339180125*t)
	Z0 += 0.00000144942*np.cos(3.24374054293 + 56.6223513026*t)
	Z0 += 0.00000151752*np.cos(3.25335981894 + 71.6002048296*t)
	Z0 += 0.00000145795*np.cos(5.12147352849 + 77.962992305*t)
	Z0 += 0.00000155998*np.cos(5.19284812595 + 77.2292791221*t)
	Z0 += 0.00000123397*np.cos(2.06100256833 + 186.2117600641*t)
	Z0 += 0.00000123620*np.cos(1.96019194023 + 288.0806940053*t)
	Z0 += 0.00000100136*np.cos(2.82301109906 + 114.3991069134*t)
	Z0 += 0.00000095939*np.cos(4.72085119752 + 297.6419215609*t)
	Z0 += 0.00000093120*np.cos(2.91989514468 + 181.7583419392*t)
	Z0 += 0.00000109824*np.cos(3.74385247499 + 67.6680515665*t)
	Z0 += 0.00000085882*np.cos(5.10268841297 + 153.4953503977*t)
	Z0 += 0.00000087546*np.cos(5.06531594976 + 183.2428146475*t)
	Z0 += 0.00000107550*np.cos(1.08025777979 + 340.7708920448*t)
	Z0 += 0.00000081507*np.cos(4.03891440133 + 143.6253063014*t)
	Z0 += 0.00000072499*np.cos(1.26231939492 + 75.3028634291*t)
	Z0 += 0.00000066852*np.cos(5.37638250776 + 265.9892934775*t)
	Z0 += 0.00000061441*np.cos(1.93112217884 + 18.1592472647*t)
	Z0 += 0.00000062039*np.cos(4.48334461215 + 66.70484372*t)
	Z0 += 0.00000073016*np.cos(1.75514255931 + 415.5524906121*t)
	Z0 += 0.00000064039*np.cos(2.09527812031 + 73.8183907208*t)
	Z0 += 0.00000056535*np.cos(5.23288988461 + 628.8515860501*t)
	Z0 += 0.00000070290*np.cos(4.25243387975 + 137.0330241624*t)
	Z0 += 0.00000062161*np.cos(0.01243451360 + 75.7448064138*t)
	Z0 += 0.00000072251*np.cos(0.83002325085 + 74.2603337055*t)
	Z0 += 0.00000054171*np.cos(2.56946172290 + 32.1951448046*t)
	Z0 += 0.00000051593*np.cos(2.16146254563 + 54.1746707478*t)
	Z0 += 0.00000057081*np.cos(4.52969105049 + 5.9378908332*t)
	Z0 += 0.00000050182*np.cos(3.95193155421 + 82.8583534146*t)
	Z0 += 0.00000059321*np.cos(0.59787435734 + 140.001969579*t)
	Z0 += 0.00000046178*np.cos(0.49809404707 + 131.4039498699*t)
	Z0 += 0.00000046517*np.cos(3.03683183762 + 59.8037450403*t)
	Z0 += 0.00000042340*np.cos(3.04902220404 + 218.4069048687*t)
	Z0 += 0.00000039090*np.cos(6.17926332920 + 373.9079928365*t)
	Z0 += 0.00000043400*np.cos(4.99216593131 + 258.0244132148*t)
	Z0 += 0.00000039572*np.cos(5.35887385465 + 219.891377577*t)
	Z0 += 0.00000045294*np.cos(3.04833112737 + 7.1135470008*t)
	Z0 += 0.00000034900*np.cos(1.59769199954 + 80.1982245387*t)
	Z0 += 0.00000034920*np.cos(3.23679252932 + 380.12776796*t)
	Z0 += 0.00000036403*np.cos(1.98850437514 + 81.8951455681*t)
	Z0 += 0.00000032126*np.cos(3.27298565306 + 191.2076949102*t)
	Z0 += 0.00000034349*np.cos(5.21152504802 + 105.4922706636*t)
	Z0 += 0.00000032231*np.cos(3.61065476446 + 20.6069278195*t)
	Z0 += 0.00000030653*np.cos(3.85781563016 + 426.598190876*t)
	Z0 += 0.00000036837*np.cos(3.48760382716 + 96.8729990951*t)
	Z0 += 0.00000030915*np.cos(4.60433376269 + 42.5864537627*t)
	Z0 += 0.00000028644*np.cos(5.75510160651 + 259.5088859231*t)
	Z0 += 0.00000028856*np.cos(1.34653259405 + 74.5209661364*t)
	Z0 += 0.00000028208*np.cos(4.66642323140 + 159.1244246902*t)
	Z0 += 0.00000029731*np.cos(4.37509990489 + 80.7194894005*t)
	Z0 += 0.00000029315*np.cos(5.03629852507 + 51.2057253312*t)
	Z0 += 0.00000025879*np.cos(3.05776566988 + 8.0767548473*t)
	Z0 += 0.00000026096*np.cos(5.48691240270 + 74.8297826771*t)
	Z0 += 0.00000025646*np.cos(2.63747057104 + 300.6108669775*t)
	Z0 += 0.00000025720*np.cos(2.42332626332 + 305.3461693927*t)
	Z0 += 0.00000025191*np.cos(6.16170714892 + 99.1606209555*t)
	Z0 += 0.00000026096*np.cos(2.89305157919 + 74.7334144575*t)
	Z0 += 0.00000025722*np.cos(4.26142211768 + 180.2738692309*t)
	Z0 += 0.00000024190*np.cos(5.50922979275 + 74.9416572617*t)
	Z0 += 0.00000026128*np.cos(0.13440940381 + 835.0371344873*t)
	Z0 += 0.00000024161*np.cos(5.19499722816 + 227.3137411185*t)
	Z0 += 0.00000027066*np.cos(3.36936938207 + 554.0699874828*t)
	Z0 += 0.00000029888*np.cos(1.80973859163 + 3.1813937377*t)
	Z0 += 0.00000025184*np.cos(1.53219969036 + 154.0166152595*t)
	Z0 += 0.00000029189*np.cos(2.73786672090 + 479.2883889155*t)
	Z0 += 0.00000026685*np.cos(2.98667762458 + 14.977853527*t)
	Z0 += 0.00000021405*np.cos(5.98546374988 + 529.6909650946*t)
	Z0 += 0.00000022295*np.cos(3.75337744344 + 39.3568759152*t)
	Z0 += 0.00000028696*np.cos(0.74986873597 + 75.0422309982*t)
	Z0 += 0.00000020972*np.cos(3.17916896424 + 255.0554677982*t)
	Z0 += 0.00000021014*np.cos(0.66302313851 + 767.3690829208*t)
	Z0 += 0.00000020577*np.cos(0.98634295841 + 116.4260963429*t)
	Z0 += 0.00000024248*np.cos(2.87116663203 + 74.6215398729*t)
	Z0 += 0.00000021752*np.cos(5.26140008123 + 294.6729761443*t)
	Z0 += 0.00000023545*np.cos(3.16204155741 + 67.3592350258*t)
	Z0 += 0.00000019430*np.cos(5.66067717228 + 235.3904959658*t)
	Z0 += 0.00000022220*np.cos(3.72262913359 + 92.940845832*t)
	Z0 += 0.00000021468*np.cos(5.59192826712 + 2.4476805548*t)
	Z0 += 0.00000016392*np.cos(0.73044725202 + 142.4496501338*t)
	Z0 += 0.00000017210*np.cos(0.87217558692 + 404.5067903482*t)
	Z0 += 0.00000015780*np.cos(5.95091393024 + 296.1574488526*t)
	Z0 += 0.00000018777*np.cos(0.60348363638 + 211.8146227297*t)
	Z0 += 0.00000015523*np.cos(1.76138162430 + 41.6444977756*t)
	Z0 += 0.00000014937*np.cos(3.30334657462 + 206.1855484372*t)
	Z0 += 0.00000017311*np.cos(0.80301716069 + 187.6962327724*t)
	Z0 += 0.00000016318*np.cos(3.13602300249 + 28.3111756513*t)
	Z0 += 0.00000015443*np.cos(2.76173273635 + 14.0146456805*t)
	Z0 += 0.00000014941*np.cos(1.86976831313 + 203.7378678824*t)
	Z0 += 0.00000013508*np.cos(1.11474597705 + 984.6003316219*t)
	Z0 += 0.00000014962*np.cos(4.21276743909 + 454.9093665273*t)
	Z0 += 0.00000015178*np.cos(2.79287665181 + 50.4025761791*t)
	Z0 += 0.00000013092*np.cos(5.16479782395 + 74.0308390419*t)
	Z0 += 0.00000013024*np.cos(1.54167247979 + 115.8835796217*t)
	Z0 += 0.00000013756*np.cos(4.44130044058 + 216.9224321604*t)
	Z0 += 0.00000012912*np.cos(2.65544175682 + 75.5323580927*t)
	Z0 += 0.00000014560*np.cos(0.31573630495 + 200.7689224658*t)
	Z0 += 0.00000016675*np.cos(4.45252615374 + 125.9873238985*t)
	Z0 += 0.00000013750*np.cos(6.21844937284 + 5.4166259714*t)
	Z0 += 0.00000013992*np.cos(2.89612356381 + 60.7669528868*t)
	Z0 += 0.00000014717*np.cos(3.86957450354 + 220.4126424388*t)
	Z0 += 0.00000013034*np.cos(0.55043059925 + 23.5758732361*t)
	Z0 += 0.00000012728*np.cos(0.85266689337 + 110.2063212194*t)
	Z0 += 0.00000011409*np.cos(3.39650826181 + 291.7040307277*t)
	Z0 += 0.00000011138*np.cos(2.91935975246 + 68.1893164283*t)
	Z0 += 0.00000011850*np.cos(4.83551999164 + 149.45132255*t)
	Z0 += 0.00000011862*np.cos(5.50185243281 + 331.3215390738*t)
	Z0 += 0.00000012269*np.cos(2.11880702802 + 162.0933701068*t)
	Z0 += 0.00000011814*np.cos(5.31010267521 + 142.1408335931*t)
	Z0 += 0.00000010875*np.cos(0.14632073584 + 128.9562693151*t)
	Z0 += 0.00000010636*np.cos(3.41354811558 + 286.596221297*t)
	Z0 += 0.00000010932*np.cos(0.17212866351 + 230.5645708254*t)
	Z0 += 0.00000013012*np.cos(6.00108633545 + 256.5399405065*t)
	Z0 += 0.00000010662*np.cos(5.52797089925 + 35.4247226521*t)
	Z0 += 0.00000011802*np.cos(1.58760278423 + 149.6750717192*t)
	Z0 += 0.00000011677*np.cos(2.40931590777 + 81.0013736908*t)
	Z0 += 0.00000009947*np.cos(4.00367169516 + 760.25553592*t)
	Z0 += 0.00000011956*np.cos(5.08786325344 + 89.7594520943*t)
	Z0 += 0.00000009140*np.cos(4.92826513743 + 81.3738807063*t)
	Z0 += 0.00000008569*np.cos(5.36608418229 + 28.5718080822*t)
	Z0 += 0.00000009334*np.cos(0.45928779675 + 120.358249606*t)
	Z0 += 0.00000009162*np.cos(3.71396614183 + 362.8622925726*t)
	Z0 += 0.00000008487*np.cos(1.72924017920 + 24.3790223882*t)
	Z0 += 0.00000009947*np.cos(5.60590635849 + 68.5618234438*t)
	Z0 += 0.00000007461*np.cos(2.32031732682 + 905.8865797915*t)
	Z0 += 0.00000008997*np.cos(2.37965677543 + 195.1398481733*t)
	Z0 += 0.00000007366*np.cos(6.15565920052 + 135.5485514541*t)
	Z0 += 0.00000007592*np.cos(0.05052252659 + 69.3649725959*t)
	Z0 += 0.00000009926*np.cos(4.65530352311 + 88.7962442478*t)
	Z0 += 0.00000007471*np.cos(5.67091902966 + 367.9701020033*t)
	Z0 += 0.00000009010*np.cos(5.15786385091 + 692.5874843535*t)
	Z0 += 0.00000006852*np.cos(5.42203185877 + 146.3818033969*t)
	Z0 += 0.00000006805*np.cos(3.79379417792 + 214.7835681463*t)
	Z0 += 0.00000007423*np.cos(0.10794595769 + 293.188503436*t)
	Z0 += 0.00000007905*np.cos(4.25870316750 + 260.9933586314*t)
	Z0 += 0.00000008094*np.cos(4.30080188984 + 617.8058857862*t)
	Z0 += 0.00000007684*np.cos(1.67030681336 + 114.1384744825*t)
	Z0 += 0.00000007620*np.cos(0.76643908895 + 152.0108776894*t)
	Z0 += 0.00000006240*np.cos(3.84416768971 + 30.7106720963*t)
	Z0 += 0.00000008334*np.cos(0.23758565081 + 565.1156877467*t)
	Z0 += 0.00000006097*np.cos(5.10863235559 + 329.7251917809*t)
	Z0 += 0.00000005988*np.cos(1.11565079117 + 372.4235201282*t)
	Z0 += 0.00000007252*np.cos(6.05773736503 + 6.2197751235*t)
	Z0 += 0.00000006028*np.cos(5.24025259251 + 95.3885263868*t)
	Z0 += 0.00000006452*np.cos(3.16931764705 + 316.3918696566*t)
	Z0 += 0.00000006289*np.cos(3.47252263966 + 73.4090004436*t)
	Z0 += 0.00000006000*np.cos(5.61195390119 + 157.6399519819*t)
	Z0 += 0.00000005425*np.cos(1.81773059325 + 647.0108333148*t)
	Z0 += 0.00000005756*np.cos(0.60729000613 + 45.5766510387*t)
	Z0 += 0.00000005331*np.cos(0.57774785878 + 462.0229135281*t)
	Z0 += 0.00000005807*np.cos(2.22669544081 + 358.9301393095*t)
	Z0 += 0.00000006423*np.cos(3.59829285171 + 536.8045120954*t)
	Z0 += 0.00000005826*np.cos(5.23125320066 + 284.1485407422*t)
	Z0 += 0.00000006532*np.cos(3.68538415222 + 278.5194664497*t)
	Z0 += 0.00000005337*np.cos(2.55697146693 + 543.0242872189*t)
	Z0 += 0.00000005214*np.cos(3.23506131011 + 7.4223635415*t)
	Z0 += 0.00000005726*np.cos(0.79025128961 + 483.2205421786*t)
	Z0 += 0.00000006176*np.cos(4.09929403804 + 328.3525936572*t)
	Z0 += 0.00000006858*np.cos(5.69002837482 + 141.4864422873*t)
	Z0 += 0.00000005025*np.cos(2.82710574399 + 152.7445908723*t)
	Z0 += 0.00000004960*np.cos(3.86366490265 + 46.2097904851*t)
	Z0 += 0.00000005299*np.cos(0.28596890733 + 0.9632078465*t)
	Z0 += 0.00000004711*np.cos(1.04008534095 + 1332.4847706675*t)
	Z0 += 0.00000004610*np.cos(5.85854264972 + 433.7117378768*t)
	Z0 += 0.00000005322*np.cos(5.53930777799 + 477.9157907918*t)
	Z0 += 0.00000004560*np.cos(5.18525746864 + 1215.1649024473*t)
	Z0 += 0.00000004528*np.cos(5.38100183232 + 983.1158589136*t)
	Z0 += 0.00000004640*np.cos(1.37720813333 + 121.2520214833*t)
	Z0 += 0.00000004414*np.cos(5.22232716227 + 909.8187330546*t)
	Z0 += 0.00000004365*np.cos(2.15062971711 + 611.5861106627*t)
	Z0 += 0.00000004220*np.cos(3.52810428208 + 10213.285546211*t)
	Z0 += 0.00000004070*np.cos(0.58328613274 + 103.0927742186*t)
	Z0 += 0.00000002610*np.cos(5.41057398526 + 632.7837393132*t)
	return Z0




def Uranus_Z1 (t): # 97 terms of order 1

	Z1 = 0.
	Z1 += 0.00655887992*np.cos(0.01271946942 + 74.7815985673*t)
	Z1 += 0.00049782349
	Z1 += 0.00023873149*np.cos(2.73870549601 + 149.5631971346*t)
	Z1 += 0.00007551644*np.cos(5.49304247639 + 76.2660712756*t)
	Z1 += 0.00005941304*np.cos(3.61254073304 + 73.297125859*t)
	Z1 += 0.00002868429*np.cos(4.17954157878 + 63.7358983034*t)
	Z1 += 0.00002087455*np.cos(5.97858625817 + 1.4844727083*t)
	Z1 += 0.00001827697*np.cos(2.71810813335 + 11.0457002639*t)
	Z1 += 0.00001305063*np.cos(4.52337002195 + 85.8272988312*t)
	Z1 += 0.00001158250*np.cos(5.31913504112 + 224.3447957019*t)
	Z1 += 0.00000734112*np.cos(3.81331728220 + 70.8494453042*t)
	Z1 += 0.00000690304*np.cos(0.01086319936 + 138.5174968707*t)
	Z1 += 0.00000497091*np.cos(4.70518667311 + 78.7137518304*t)
	Z1 += 0.00000525934*np.cos(4.22790148916 + 71.8126531507*t)
	Z1 += 0.00000489133*np.cos(1.79190013789 + 151.0476698429*t)
	Z1 += 0.00000429528*np.cos(4.40758343368 + 77.7505439839*t)
	Z1 += 0.00000390025*np.cos(3.59458303816 + 148.0787244263*t)
	Z1 += 0.00000225115*np.cos(5.02814647582 + 2.9689454166*t)
	Z1 += 0.00000193252*np.cos(2.74882587378 + 3.9321532631*t)
	Z1 += 0.00000119620*np.cos(2.05252714897 + 213.299095438*t)
	Z1 += 0.00000102785*np.cos(3.31502760721 + 77.962992305*t)
	Z1 += 0.00000097903*np.cos(5.85664051124 + 145.6310438715*t)
	Z1 += 0.00000103227*np.cos(5.06943606258 + 71.6002048296*t)
	Z1 += 0.00000106981*np.cos(1.10631744127 + 52.6901980395*t)
	Z1 += 0.00000077286*np.cos(3.72807884402 + 35.1640902212*t)
	Z1 += 0.00000067594*np.cos(0.77601310740 + 160.6088973985*t)
	Z1 += 0.00000063561*np.cos(5.01016684392 + 22.0914005278*t)
	Z1 += 0.00000058625*np.cos(5.17576903593 + 39.6175083461*t)
	Z1 += 0.00000076599*np.cos(1.30683710252 + 65.2203710117*t)
	Z1 += 0.00000055754*np.cos(6.26203252006 + 222.8603229936*t)
	Z1 += 0.00000049390*np.cos(0.96663399742 + 127.4717966068*t)
	Z1 += 0.00000049820*np.cos(5.14835012477 + 56.6223513026*t)
	Z1 += 0.00000053114*np.cos(2.86405621955 + 202.2533951741*t)
	Z1 += 0.00000061715*np.cos(1.55497097388 + 299.1263942692*t)
	Z1 += 0.00000040267*np.cos(0.39282094222 + 9.5612275556*t)
	Z1 += 0.00000039707*np.cos(3.46589599839 + 351.8165923087*t)
	Z1 += 0.00000046592*np.cos(0.38562695814 + 84.3428261229*t)
	Z1 += 0.00000042230*np.cos(1.67068092002 + 12.5301729722*t)
	Z1 += 0.00000034980*np.cos(3.48214299481 + 87.3117715395*t)
	Z1 += 0.00000032124*np.cos(1.84035184320 + 72.3339180125*t)
	Z1 += 0.00000030982*np.cos(6.26917099095 + 38.1330356378*t)
	Z1 += 0.00000030161*np.cos(2.83531415256 + 277.0349937414*t)
	Z1 += 0.00000030675*np.cos(3.22207043880 + 79.2350166922*t)
	Z1 += 0.00000029271*np.cos(3.90806723610 + 4.4534181249*t)
	Z1 += 0.00000035031*np.cos(0.01605949416 + 18.1592472647*t)
	Z1 += 0.00000029257*np.cos(0.62309320704 + 152.5321425512*t)
	Z1 += 0.00000028570*np.cos(5.63486898483 + 67.6680515665*t)
	Z1 += 0.00000033047*np.cos(4.30651825800 + 225.8292684102*t)
	Z1 += 0.00000029182*np.cos(3.18810576540 + 36.6485629295*t)
	Z1 += 0.00000031136*np.cos(5.16649564680 + 62.2514255951*t)
	Z1 += 0.00000020989*np.cos(1.27501642305 + 73.8183907208*t)
	Z1 += 0.00000021586*np.cos(0.54298324173 + 77.2292791221*t)
	Z1 += 0.00000019927*np.cos(0.81036596459 + 75.7448064138*t)
	Z1 += 0.00000018562*np.cos(0.85762153591 + 153.4953503977*t)
	Z1 += 0.00000018352*np.cos(3.66430920732 + 74.8934731519*t)
	Z1 += 0.00000019408*np.cos(5.44238978557 + 70.3281804424*t)
	Z1 += 0.00000017432*np.cos(3.55134001048 + 111.4301614968*t)
	Z1 += 0.00000016838*np.cos(2.40850940993 + 131.4039498699*t)
	Z1 += 0.00000016213*np.cos(4.59517640131 + 146.594251718*t)
	Z1 += 0.00000019909*np.cos(0.11299264852 + 3.1813937377*t)
	Z1 += 0.00000015050*np.cos(0.50059176616 + 184.7272873558*t)
	Z1 += 0.00000011825*np.cos(5.13623111208 + 490.3340891794*t)
	Z1 += 0.00000012768*np.cos(4.41440359004 + 288.0806940053*t)
	Z1 += 0.00000011567*np.cos(6.19733666092 + 81.8951455681*t)
	Z1 += 0.00000012658*np.cos(4.96483571441 + 74.6697239827*t)
	Z1 += 0.00000011291*np.cos(1.09075883157 + 7.1135470008*t)
	Z1 += 0.00000011020*np.cos(4.01199960071 + 41.1019810544*t)
	Z1 += 0.00000011009*np.cos(1.85422919049 + 92.940845832*t)
	Z1 += 0.00000009701*np.cos(2.49773741126 + 265.9892934775*t)
	Z1 += 0.00000009647*np.cos(0.66790581742 + 137.0330241624*t)
	Z1 += 0.00000009256*np.cos(2.08101585823 + 112.9146342051*t)
	Z1 += 0.00000009599*np.cos(6.16046184188 + 191.2076949102*t)
	Z1 += 0.00000008018*np.cos(3.39964779966 + 80.1982245387*t)
	Z1 += 0.00000007441*np.cos(4.22707529633 + 415.5524906121*t)
	Z1 += 0.00000007613*np.cos(4.06305624916 + 109.9456887885*t)
	Z1 += 0.00000006685*np.cos(0.85215242388 + 108.4612160802*t)
	Z1 += 0.00000008996*np.cos(0.44928083852 + 96.8729990951*t)
	Z1 += 0.00000007423*np.cos(4.54199037166 + 340.7708920448*t)
	Z1 += 0.00000006668*np.cos(0.68169549965 + 66.70484372*t)
	Z1 += 0.00000005579*np.cos(4.88979641865 + 195.1398481733*t)
	Z1 += 0.00000005519*np.cos(2.03513310636 + 297.6419215609*t)
	Z1 += 0.00000005256*np.cos(5.05648891239 + 14.977853527*t)
	Z1 += 0.00000005023*np.cos(1.26471022025 + 703.6331846174*t)
	Z1 += 0.00000004978*np.cos(0.45168703793 + 33.1371007917*t)
	Z1 += 0.00000004978*np.cos(4.29826949554 + 419.4846438752*t)
	Z1 += 0.00000005364*np.cos(4.36091994553 + 33.6796175129*t)
	Z1 += 0.00000005204*np.cos(4.71563303529 + 41.6444977756*t)
	Z1 += 0.00000004871*np.cos(5.02687879729 + 206.1855484372*t)
	Z1 += 0.00000005839*np.cos(2.93959194280 + 142.4496501338*t)
	Z1 += 0.00000004681*np.cos(3.79452774373 + 617.8058857862*t)
	Z1 += 0.00000004676*np.cos(1.50550222970 + 835.0371344873*t)
	Z1 += 0.00000004901*np.cos(0.59194496069 + 2.4476805548*t)
	Z1 += 0.00000004468*np.cos(4.41715426535 + 116.4260963429*t)
	Z1 += 0.00000004000*np.cos(2.27201951910 + 220.4126424388*t)
	Z1 += 0.00000003270*np.cos(1.75799271188 + 536.8045120954*t)
	Z1 += 0.00000003003*np.cos(5.68771752375 + 426.598190876*t)
	Z1 += 0.00000002586*np.cos(3.01944725018 + 639.897286314*t)
	return Z1*t




def Uranus_Z2 (t): # 33 terms of order 2

	Z2 = 0.
	Z2 += 0.00014697217*np.cos(1.75149164608 + 74.7815985673*t)
	Z2 -= 0.00001601722
	Z2 += 0.00000257139*np.cos(5.91766895295 + 73.297125859*t)
	Z2 += 0.00000247413*np.cos(5.67197956903 + 149.5631971346*t)
	Z2 += 0.00000121840*np.cos(0.75865025350 + 11.0457002639*t)
	Z2 += 0.00000094450*np.cos(2.21235560116 + 76.2660712756*t)
	Z2 += 0.00000113629*np.cos(2.28365428558 + 85.8272988312*t)
	Z2 += 0.00000083530*np.cos(1.80920128029 + 70.8494453042*t)
	Z2 += 0.00000065243*np.cos(0.36612733106 + 78.7137518304*t)
	Z2 += 0.00000047174*np.cos(1.41711995616 + 1.4844727083*t)
	Z2 += 0.00000043727*np.cos(1.83013988872 + 138.5174968707*t)
	Z2 += 0.00000034300*np.cos(1.54028391235 + 77.962992305*t)
	Z2 += 0.00000033009*np.cos(5.75228726463 + 63.7358983034*t)
	Z2 += 0.00000033193*np.cos(0.57224102909 + 71.6002048296*t)
	Z2 += 0.00000027913*np.cos(4.45469138185 + 3.9321532631*t)
	Z2 += 0.00000022890*np.cos(2.72301959951 + 224.3447957019*t)
	Z2 += 0.00000013762*np.cos(3.75389258483 + 145.6310438715*t)
	Z2 += 0.00000011942*np.cos(0.71017756424 + 71.8126531507*t)
	Z2 += 0.00000010375*np.cos(5.43438514766 + 151.0476698429*t)
	Z2 += 0.00000008582*np.cos(4.15703770704 + 18.1592472647*t)
	Z2 += 0.00000007110*np.cos(3.80523625157 + 454.9093665273*t)
	Z2 += 0.00000007300*np.cos(2.04486459139 + 77.7505439839*t)
	Z2 += 0.00000008616*np.cos(0.77209239310 + 206.1855484372*t)
	Z2 += 0.00000006450*np.cos(2.13573948824 + 22.0914005278*t)
	Z2 += 0.00000006088*np.cos(3.53327516895 + 213.299095438*t)
	Z2 += 0.00000005761*np.cos(3.36869478839 + 52.6901980395*t)
	Z2 += 0.00000007863*np.cos(4.25003313419 + 148.0787244263*t)
	Z2 += 0.00000006205*np.cos(0.04948675860 + 72.3339180125*t)
	Z2 += 0.00000006691*np.cos(4.45146912577 + 160.6088973985*t)
	Z2 += 0.00000005214*np.cos(5.54906714219 + 127.4717966068*t)
	Z2 += 0.00000006205*np.cos(2.26614295646 + 56.6223513026*t)
	Z2 += 0.00000006094*np.cos(4.96640467601 + 3.1813937377*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	return Z2*t*t




def Uranus_Z3 (t): # 12 terms of order 3

	Z3 = 0.
	Z3 += 0.00000406961*np.cos(3.16314034460 + 74.7815985673*t)
	Z3 -= 0.00000034199
	Z3 += 0.00000011311*np.cos(4.44380758422 + 149.5631971346*t)
	Z3 += 0.00000008361*np.cos(1.72705039556 + 63.7358983034*t)
	Z3 += 0.00000008312*np.cos(1.10371780340 + 73.297125859*t)
	Z3 += 0.00000009244*np.cos(5.94272369985 + 70.8494453042*t)
	Z3 += 0.00000007905*np.cos(0.43984657946 + 76.2660712756*t)
	Z3 += 0.00000008589*np.cos(1.88103909904 + 78.7137518304*t)
	Z3 += 0.00000006893*np.cos(6.12079288343 + 85.8272988312*t)
	Z3 += 0.00000005797*np.cos(1.86650914141 + 71.6002048296*t)
	Z3 += 0.00000005504*np.cos(5.95485140431 + 77.962992305*t)
	Z3 += 0.00000004869*np.cos(4.99593945023 + 11.0457002639*t)
	return Z3*t*t*t




def Uranus_Z4 (t): # 1 term of order 4

	Z4 = 0.
	Z4 += 0.00000000000
	return Z4*t*t*t*t




def Uranus_Z5 (t): # 1 term of order 5

	Z5 = 0.
	Z5 += 0.00000000000
	return Z5*t*t*t*t*t







def Neptune_X0 (t): # 720 terms of order 0

	X0 = 0.
	X0 += 30.05734568801*np.cos(5.31211340030 + 38.1330356378*t)
	X0 -= 0.27050789973
	X0 += 0.13504578270*np.cos(3.50075407055 + 76.2660712756*t)
	X0 += 0.15725280871*np.cos(0.11319072402 + 36.6485629295*t)
	X0 += 0.14934353052*np.cos(1.08499398649 + 39.6175083461*t)
	X0 += 0.02597449604*np.cos(1.99590330725 + 1.4844727083*t)
	X0 += 0.00990668211*np.cos(5.37690139386 + 74.7815985673*t)
	X0 += 0.00823755467*np.cos(1.43221512492 + 35.1640902212*t)
	X0 += 0.00817566529*np.cos(0.78180136001 + 2.9689454166*t)
	X0 += 0.00565506338*np.cos(5.98964911841 + 41.1019810544*t)
	X0 += 0.00308146172*np.cos(0.39998862713 + 73.297125859*t)
	X0 += 0.00135901755*np.cos(5.54688721933 + 77.7505439839*t)
	X0 += 0.00090960996*np.cos(1.68910476933 + 114.3991069134*t)
	X0 += 0.00069038680*np.cos(5.83469111908 + 4.4534181249*t)
	X0 += 0.00060811221*np.cos(2.62589871314 + 33.6796175129*t)
	X0 += 0.00054713428*np.cos(1.55804647862 + 71.8126531507*t)
	X0 += 0.00028887848*np.cos(4.78966833702 + 42.5864537627*t)
	X0 += 0.00012614574*np.cos(3.57008196751 + 112.9146342051*t)
	X0 += 0.00012743164*np.cos(2.73728741519 + 111.4301614968*t)
	X0 += 0.00007541736*np.cos(2.77784746848 + 70.3281804424*t)
	X0 += 0.00008004318*np.cos(1.63965626260 + 108.4612160802*t)
	X0 += 0.00006464842*np.cos(4.62580066013 + 5.9378908332*t)
	X0 += 0.00005565860*np.cos(3.82502185953 + 32.1951448046*t)
	X0 += 0.00004654361*np.cos(0.10385887980 + 37.611770776*t)
	X0 += 0.00004733138*np.cos(4.09748778484 + 79.2350166922*t)
	X0 += 0.00004557247*np.cos(1.09712669317 + 38.6543004996*t)
	X0 += 0.00004322550*np.cos(2.37744780188 + 38.084851528*t)
	X0 += 0.00004315539*np.cos(5.10473142056 + 38.1812197476*t)
	X0 += 0.00004089036*np.cos(1.99429048244 + 37.1698277913*t)
	X0 += 0.00004249674*np.cos(5.63324475823 + 28.5718080822*t)
	X0 += 0.00003920412*np.cos(5.49263784865 + 39.0962434843*t)
	X0 += 0.00003951848*np.cos(2.29996934110 + 98.8999885246*t)
	X0 += 0.00003322735*np.cos(4.68798591938 + 4.192785694*t)
	X0 += 0.00003108292*np.cos(1.84434543409 + 47.6942631934*t)
	X0 += 0.00003260095*np.cos(1.81839652878 + 145.1097790097*t)
	X0 += 0.00002720471*np.cos(3.82305971632 + 109.9456887885*t)
	X0 += 0.00002522938*np.cos(4.66296126912 + 312.1990839626*t)
	X0 += 0.00001887430*np.cos(3.20485417792 + 35.685355083*t)
	X0 += 0.00001648985*np.cos(4.06990666591 + 30.0562807905*t)
	X0 += 0.00001826700*np.cos(3.58024318649 + 44.070926471*t)
	X0 += 0.00001681255*np.cos(4.27560304282 + 40.5807161926*t)
	X0 += 0.00001533383*np.cos(1.17732211665 + 38.0211610532*t)
	X0 += 0.00001527526*np.cos(0.02173640246 + 38.2449102224*t)
	X0 += 0.00002084772*np.cos(2.83683424533 + 137.0330241624*t)
	X0 += 0.00001615063*np.cos(2.91063835010 + 106.9767433719*t)
	X0 += 0.00001265797*np.cos(3.42037275447 + 46.2097904851*t)
	X0 += 0.00001560429*np.cos(0.55865739143 + 37.8724032069*t)
	X0 += 0.00001545705*np.cos(0.64028780672 + 38.3936680687*t)
	X0 += 0.00001271543*np.cos(2.74412981229 + 33.9402499438*t)
	X0 += 0.00001387922*np.cos(3.71814330952 + 115.8835796217*t)
	X0 += 0.00001228939*np.cos(2.78878211792 + 72.0732855816*t)
	X0 += 0.00001448439*np.cos(1.98814317259 + 181.7583419392*t)
	X0 += 0.00001170078*np.cos(3.98594689041 + 8.0767548473*t)
	X0 += 0.00001080795*np.cos(4.75485636019 + 42.3258213318*t)
	X0 += 0.00001157153*np.cos(2.64764912073 + 148.0787244263*t)
	X0 += 0.00000942722*np.cos(3.99861076677 + 68.8437077341*t)
	X0 += 0.00000720854*np.cos(6.16925850812 + 152.5321425512*t)
	X0 += 0.00000608265*np.cos(4.49563700854 + 35.212274331*t)
	X0 += 0.00000714969*np.cos(3.09121631507 + 143.6253063014*t)
	X0 += 0.00000633834*np.cos(3.41692648170 + 7.4223635415*t)
	X0 += 0.00000554473*np.cos(2.98634397776 + 41.0537969446*t)
	X0 += 0.00000566306*np.cos(5.02809882280 + 30.7106720963*t)
	X0 += 0.00000679542*np.cos(2.15673681356 + 218.4069048687*t)
	X0 += 0.00000463140*np.cos(2.74436643796 + 31.5407534988*t)
	X0 += 0.00000451619*np.cos(4.62757040522 + 44.7253177768*t)
	X0 += 0.00000528038*np.cos(0.34505105111 + 0.9632078465*t)
	X0 += 0.00000406092*np.cos(5.51084213663 + 6.592282139*t)
	X0 += 0.00000417926*np.cos(5.14685971892 + 7.1135470008*t)
	X0 += 0.00000488648*np.cos(3.82538448334 + 146.594251718*t)
	X0 += 0.00000451197*np.cos(0.88413360893 + 213.299095438*t)
	X0 += 0.00000306843*np.cos(2.62651223895 + 60.7669528868*t)
	X0 += 0.00000405411*np.cos(5.31947629009 + 31.019488637*t)
	X0 += 0.00000337082*np.cos(1.72339969429 + 0.5212648618*t)
	X0 += 0.00000346164*np.cos(3.26507470705 + 180.2738692309*t)
	X0 += 0.00000382398*np.cos(0.21680708235 + 487.3651437628*t)
	X0 += 0.00000300555*np.cos(5.17683306682 + 84.3428261229*t)
	X0 += 0.00000336250*np.cos(2.14824434860 + 45.2465826386*t)
	X0 += 0.00000333233*np.cos(2.32861862173 + 255.0554677982*t)
	X0 += 0.00000268060*np.cos(3.30852177378 + 36.7604375141*t)
	X0 += 0.00000227848*np.cos(0.72373981071 + 149.5631971346*t)
	X0 += 0.00000264760*np.cos(4.12724083445 + 39.5056337615*t)
	X0 += 0.00000314641*np.cos(2.72704648029 + 388.4651552382*t)
	X0 += 0.00000226971*np.cos(4.59278380480 + 274.0660483248*t)
	X0 += 0.00000284466*np.cos(3.36180727616 + 12.5301729722*t)
	X0 += 0.00000242743*np.cos(2.06472522938 + 14.0146456805*t)
	X0 += 0.00000226154*np.cos(2.83844512995 + 80.7194894005*t)
	X0 += 0.00000233075*np.cos(4.15738074001 + 105.4922706636*t)
	X0 += 0.00000239672*np.cos(0.55843257386 + 27.0873353739*t)
	X0 += 0.00000265940*np.cos(4.11954506638 + 944.9828232758*t)
	X0 += 0.00000190998*np.cos(2.32419774896 + 69.1525242748*t)
	X0 += 0.00000203230*np.cos(0.60054564924 + 415.2918581812*t)
	X0 += 0.00000176465*np.cos(0.14731264750 + 36.5366883449*t)
	X0 += 0.00000177003*np.cos(0.09240613438 + 24.1183899573*t)
	X0 += 0.00000185282*np.cos(3.31492482279 + 175.1660598002*t)
	X0 += 0.00000175209*np.cos(1.12575721851 + 39.7293829307*t)
	X0 += 0.00000176810*np.cos(3.44067665667 + 216.9224321604*t)
	X0 += 0.00000172706*np.cos(4.71160173811 + 11.0457002639*t)
	X0 += 0.00000136077*np.cos(3.29430588709 + 9.5612275556*t)
	X0 += 0.00000134759*np.cos(5.48177520941 + 75.7448064138*t)
	X0 += 0.00000179189*np.cos(3.95792517028 + 183.2428146475*t)
	X0 += 0.00000129174*np.cos(5.91949003083 + 43.2408450685*t)
	X0 += 0.00000124092*np.cos(0.33312196832 + 82.8583534146*t)
	X0 += 0.00000121226*np.cos(5.10584282456 + 37.9205873167*t)
	X0 += 0.00000129049*np.cos(3.80684882859 + 36.8610112506*t)
	X0 += 0.00000120117*np.cos(2.36053032404 + 38.3454839589*t)
	X0 += 0.00000169037*np.cos(2.49417096791 + 291.7040307277*t)
	X0 += 0.00000121138*np.cos(1.49666213233 + 33.0252262071*t)
	X0 += 0.00000129442*np.cos(2.36907122801 + 45.5553991793*t)
	X0 += 0.00000144638*np.cos(0.63080734164 + 49.1787359017*t)
	X0 += 0.00000122915*np.cos(3.67433552159 + 39.405060025*t)
	X0 += 0.00000154797*np.cos(1.74840367711 + 77.2292791221*t)
	X0 += 0.00000137925*np.cos(1.86763348155 + 151.0476698429*t)
	X0 += 0.00000106839*np.cos(0.57301677365 + 5.1078094307*t)
	X0 += 0.00000103540*np.cos(5.25634656769 + 40.8413486235*t)
	X0 += 0.00000102917*np.cos(2.29532659562 + 35.4247226521*t)
	X0 += 0.00000111109*np.cos(5.21447473078 + 67.3592350258*t)
	X0 += 0.00000127422*np.cos(4.11355026342 + 63.7358983034*t)
	X0 += 0.00000110050*np.cos(4.33896766039 + 142.1408335931*t)
	X0 += 0.00000085104*np.cos(4.79018193091 + 36.4361146084*t)
	X0 += 0.00000119617*np.cos(5.01817354003 + 25.6028626656*t)
	X0 += 0.00000085710*np.cos(5.93681198924 + 106.0135355254*t)
	X0 += 0.00000092947*np.cos(5.45424466758 + 62.2514255951*t)
	X0 += 0.00000092567*np.cos(3.21456499053 + 32.7164096664*t)
	X0 += 0.00000080200*np.cos(2.69199800753 + 39.8299566672*t)
	X0 += 0.00000086613*np.cos(1.38012091187 + 100.3844612329*t)
	X0 += 0.00000094922*np.cos(3.61296023449 + 253.5709950899*t)
	X0 += 0.00000072986*np.cos(1.82355507012 + 22.633917249*t)
	X0 += 0.00000100254*np.cos(2.52703279512 + 453.424893819*t)
	X0 += 0.00000072027*np.cos(0.11366561346 + 36.6967470393*t)
	X0 += 0.00000089060*np.cos(1.32938886500 + 251.4321310758*t)
	X0 += 0.00000096664*np.cos(4.11397655268 + 219.891377577*t)
	X0 += 0.00000077348*np.cos(5.31146277396 + 5.4166259714*t)
	X0 += 0.00000087618*np.cos(2.77500684022 + 65.2203710117*t)
	X0 += 0.00000065520*np.cos(4.00996666370 + 66.70484372*t)
	X0 += 0.00000087258*np.cos(2.66760530100 + 328.3525936572*t)
	X0 += 0.00000072807*np.cos(4.23052254217 + 43.5496616092*t)
	X0 += 0.00000065817*np.cos(1.42821896659 + 36.1272980677*t)
	X0 += 0.00000063662*np.cos(2.21155835394 + 8.9068362498*t)
	X0 += 0.00000073980*np.cos(5.56439585580 + 2.7083129857*t)
	X0 += 0.00000075165*np.cos(0.26221144253 + 97.4155158163*t)
	X0 += 0.00000062934*np.cos(1.53666713803 + 2.9207613068*t)
	X0 += 0.00000060042*np.cos(6.23591295978 + 29.226199388*t)
	X0 += 0.00000068141*np.cos(3.95659956363 + 6.9010986797*t)
	X0 += 0.00000071609*np.cos(2.05679246101 + 662.531203563*t)
	X0 += 0.00000057327*np.cos(0.88500496532 + 15.4991183888*t)
	X0 += 0.00000050470*np.cos(1.08386527084 + 36.9091953604*t)
	X0 += 0.00000055782*np.cos(4.51929442479 + 178.7893965226*t)
	X0 += 0.00000065197*np.cos(0.94675037786 + 2.4476805548*t)
	X0 += 0.00000048927*np.cos(1.27232208261 + 19.0105805266*t)
	X0 += 0.00000046774*np.cos(0.83941291963 + 3.9321532631*t)
	X0 += 0.00000059504*np.cos(4.28371174513 + 256.5399405065*t)
	X0 += 0.00000045642*np.cos(2.17627625563 + 117.36805233*t)
	X0 += 0.00000052496*np.cos(3.77774414174 + 290.2195580194*t)
	X0 += 0.00000055922*np.cos(6.18484136645 + 221.3758502853*t)
	X0 += 0.00000045277*np.cos(0.21515321589 + 1.2238402774*t)
	X0 += 0.00000043900*np.cos(2.24943568390 + 32.5039613453*t)
	X0 += 0.00000038369*np.cos(0.36602739792 + 39.3568759152*t)
	X0 += 0.00000049423*np.cos(3.88247230281 + 525.4981794006*t)
	X0 += 0.00000038844*np.cos(0.98004799212 + 41.7563723602*t)
	X0 += 0.00000038213*np.cos(0.28030398995 + 75.3028634291*t)
	X0 += 0.00000035904*np.cos(0.17178502657 + 449.232108125*t)
	X0 += 0.00000047341*np.cos(2.81338610634 + 365.0011565867*t)
	X0 += 0.00000038163*np.cos(5.23367376836 + 43.7621099303*t)
	X0 += 0.00000042228*np.cos(5.64690940917 + 76.7873361374*t)
	X0 += 0.00000045759*np.cos(4.75988756419 + 491.5579294568*t)
	X0 += 0.00000042160*np.cos(4.48656614621 + 31.2319369581*t)
	X0 += 0.00000035247*np.cos(0.20766798411 + 34.5096989154*t)
	X0 += 0.00000033509*np.cos(5.65652422418 + 67.8804998876*t)
	X0 += 0.00000046369*np.cos(0.60505439950 + 529.6909650946*t)
	X0 += 0.00000033002*np.cos(6.08090918909 + 85.8272988312*t)
	X0 += 0.00000033085*np.cos(4.59560243545 + 34.2008823747*t)
	X0 += 0.00000034352*np.cos(1.08288982986 + 33.4671691918*t)
	X0 += 0.00000034964*np.cos(2.01236505402 + 3.6233367224*t)
	X0 += 0.00000040831*np.cos(2.58095758724 + 310.7146112543*t)
	X0 += 0.00000038618*np.cos(2.31716832803 + 50.66320861*t)
	X0 += 0.00000038069*np.cos(2.31012373841 + 78.7137518304*t)
	X0 += 0.00000041713*np.cos(2.16213866054 + 1021.2488945514*t)
	X0 += 0.00000038281*np.cos(0.30795321775 + 5.6772584023*t)
	X0 += 0.00000038880*np.cos(3.29381198979 + 76.3142553854*t)
	X0 += 0.00000032480*np.cos(2.52481312116 + 184.7272873558*t)
	X0 += 0.00000034672*np.cos(4.48294008385 + 319.3126309634*t)
	X0 += 0.00000039604*np.cos(4.60072832158 + 563.6312150384*t)
	X0 += 0.00000040526*np.cos(0.03726110727 + 258.0244132148*t)
	X0 += 0.00000038880*np.cos(0.56654650956 + 76.2178871658*t)
	X0 += 0.00000032755*np.cos(5.57869647430 + 91.7864415238*t)
	X0 += 0.00000034456*np.cos(1.65821047826 + 305.0855369618*t)
	X0 += 0.00000037777*np.cos(4.45977183034 + 293.188503436*t)
	X0 += 0.00000037422*np.cos(2.84624206227 + 17.5261078183*t)
	X0 += 0.00000028459*np.cos(0.11299014227 + 42.7989020838*t)
	X0 += 0.00000029505*np.cos(2.15133939286 + 70.8494453042*t)
	X0 += 0.00000034974*np.cos(3.54684672078 + 313.6835566709*t)
	X0 += 0.00000026519*np.cos(6.20266976376 + 57.255490749*t)
	X0 += 0.00000028786*np.cos(4.65055968537 + 215.4379594521*t)
	X0 += 0.00000031496*np.cos(4.10798902830 + 21.9795259432*t)
	X0 += 0.00000027524*np.cos(3.42975034397 + 69.3649725959*t)
	X0 += 0.00000025982*np.cos(5.38913791843 + 104.0077979553*t)
	X0 += 0.00000022617*np.cos(3.46251776478 + 36.6003788197*t)
	X0 += 0.00000023432*np.cos(4.24731386395 + 35.2759648058*t)
	X0 += 0.00000028085*np.cos(2.83450558708 + 11.3063326948*t)
	X0 += 0.00000026520*np.cos(0.30917290380 + 186.2117600641*t)
	X0 += 0.00000021423*np.cos(0.87822750242 + 39.6656924559*t)
	X0 += 0.00000023164*np.cos(2.59103009569 + 68.1893164283*t)
	X0 += 0.00000026754*np.cos(3.94781592186 + 326.8681209489*t)
	X0 += 0.00000024636*np.cos(2.36566879926 + 20.4950532349*t)
	X0 += 0.00000022719*np.cos(2.73465617885 + 79.1868325824*t)
	X0 += 0.00000019952*np.cos(5.26630019767 + 64.9597385808*t)
	X0 += 0.00000022482*np.cos(0.72349643385 + 39.5693242363*t)
	X0 += 0.00000020858*np.cos(3.23577482504 + 40.9901064698*t)
	X0 += 0.00000020327*np.cos(0.04331485179 + 37.478644332*t)
	X0 += 0.00000020327*np.cos(1.15567976096 + 38.7874269436*t)
	X0 += 0.00000025245*np.cos(2.97720937219 + 401.6497195162*t)
	X0 += 0.00000023422*np.cos(0.91668385938 + 135.5485514541*t)
	X0 += 0.00000023863*np.cos(0.28305954716 + 294.6729761443*t)
	X0 += 0.00000024398*np.cos(4.63603670592 + 329.8370663655*t)
	X0 += 0.00000019831*np.cos(6.14231002572 + 129.9194771616*t)
	X0 += 0.00000022713*np.cos(5.70775452731 + 1436.5407527326*t)
	X0 += 0.00000017728*np.cos(2.77443598476 + 17.6379824029*t)
	X0 += 0.00000016188*np.cos(2.57356791106 + 37.4998961914*t)
	X0 += 0.00000016188*np.cos(4.90861200887 + 38.7661750842*t)
	X0 += 0.00000020858*np.cos(4.67505251944 + 58.7399634573*t)
	X0 += 0.00000018213*np.cos(1.92094691523 + 138.5174968707*t)
	X0 += 0.00000015724*np.cos(1.88925867017 + 154.0166152595*t)
	X0 += 0.00000018916*np.cos(5.47002152686 + 40.1387732079*t)
	X0 += 0.00000015658*np.cos(0.27239863208 + 72.3339180125*t)
	X0 += 0.00000014928*np.cos(0.78464894996 + 33.9884340536*t)
	X0 += 0.00000015400*np.cos(4.89570509053 + 55.7710180407*t)
	X0 += 0.00000015003*np.cos(6.06837299592 + 20.6069278195*t)
	X0 += 0.00000018609*np.cos(3.38782333097 + 54.2865453324*t)
	X0 += 0.00000018700*np.cos(1.12219613883 + 59.2824801785*t)
	X0 += 0.00000013971*np.cos(5.11256155147 + 76.5267037065*t)
	X0 += 0.00000019162*np.cos(2.49858178805 + 81.3738807063*t)
	X0 += 0.00000013966*np.cos(4.45404032739 + 235.933012687*t)
	X0 += 0.00000015424*np.cos(6.09858524641 + 209.106309744*t)
	X0 += 0.00000014889*np.cos(0.97067379700 + 52.1476813183*t)
	X0 += 0.00000017322*np.cos(1.69350571733 + 73.8183907208*t)
	X0 += 0.00000015360*np.cos(1.34896859320 + 8.385571388*t)
	X0 += 0.00000012911*np.cos(0.41434577054 + 42.277637222*t)
	X0 += 0.00000012914*np.cos(2.32697196177 + 107.2855599126*t)
	X0 += 0.00000014253*np.cos(4.87402416011 + 252.0865223816*t)
	X0 += 0.00000014745*np.cos(1.55174834608 + 82.2039621088*t)
	X0 += 0.00000014464*np.cos(0.67357368235 + 110.2063212194*t)
	X0 += 0.00000014840*np.cos(0.62836398949 + 43.8102940401*t)
	X0 += 0.00000015476*np.cos(4.71667567197 + 366.485629295*t)
	X0 += 0.00000014964*np.cos(4.12823484692 + 363.5166838784*t)
	X0 += 0.00000012269*np.cos(4.97560513030 + 76.0054388447*t)
	X0 += 0.00000012794*np.cos(5.90055335939 + 26.826702943*t)
	X0 += 0.00000014352*np.cos(2.03450798266 + 73.5577582899*t)
	X0 += 0.00000014292*np.cos(5.66547183054 + 700.6642392008*t)
	X0 += 0.00000012251*np.cos(1.18824411089 + 47.0398718876*t)
	X0 += 0.00000013656*np.cos(5.33984015976 + 19.1224551112*t)
	X0 += 0.00000012109*np.cos(2.10142430456 + 32.7645937762*t)
	X0 += 0.00000015463*np.cos(3.88973407461 + 837.6972633632*t)
	X0 += 0.00000011481*np.cos(5.22670638350 + 38.9631170403*t)
	X0 += 0.00000011481*np.cos(2.25547353644 + 37.3029542353*t)
	X0 += 0.00000011455*np.cos(1.21185103334 + 529.1697002328*t)
	X0 += 0.00000012137*np.cos(2.33016774123 + 42.0651889009*t)
	X0 += 0.00000013771*np.cos(4.49397894473 + 76.3779458602*t)
	X0 += 0.00000010692*np.cos(4.35159490002 + 187.6962327724*t)
	X0 += 0.00000011035*np.cos(3.16468611086 + 530.2122299564*t)
	X0 += 0.00000011498*np.cos(5.58046420166 + 140.6563608848*t)
	X0 += 0.00000011769*np.cos(4.24181618457 + 275.5505210331*t)
	X0 += 0.00000013663*np.cos(0.43266174776 + 331.3215390738*t)
	X0 += 0.00000013308*np.cos(3.10907233961 + 438.2982824457*t)
	X0 += 0.00000013771*np.cos(5.64956481971 + 76.154196691*t)
	X0 += 0.00000013632*np.cos(2.86683636247 + 45.0341343175*t)
	X0 += 0.00000010275*np.cos(2.33816907673 + 567.8240007324*t)
	X0 += 0.00000011419*np.cos(4.80118839377 + 403.1341922245*t)
	X0 += 0.00000010218*np.cos(0.15937912520 + 65.8747623175*t)
	X0 += 0.00000010240*np.cos(2.91846738700 + 80.4588569696*t)
	X0 += 0.00000010031*np.cos(5.38075579726 + 43.5014774994*t)
	X0 += 0.00000009814*np.cos(2.48786918599 + 21.1494445407*t)
	X0 += 0.00000008767*np.cos(2.04264115651 + 624.3981679252*t)
	X0 += 0.00000009004*np.cos(0.37183459802 + 101.8689339412*t)
	X0 += 0.00000010223*np.cos(5.22522199427 + 120.9913890524*t)
	X0 += 0.00000010189*np.cos(2.58985496469 + 21.4582610814*t)
	X0 += 0.00000008414*np.cos(2.47005781008 + 377.1588225434*t)
	X0 += 0.00000009753*np.cos(0.08887858960 + 168.0525127994*t)
	X0 += 0.00000010361*np.cos(0.01486429648 + 119.5069163441*t)
	X0 += 0.00000007927*np.cos(0.93746230599 + 906.849787638*t)
	X0 += 0.00000008736*np.cos(3.99247403211 + 459.3627846522*t)
	X0 += 0.00000008454*np.cos(2.52377850488 + 144.1465711632*t)
	X0 += 0.00000007805*np.cos(5.67359329262 + 350.3321196004*t)
	X0 += 0.00000008986*np.cos(4.29352626319 + 400.1652468079*t)
	X0 += 0.00000009026*np.cos(4.77784842124 + 347.9326231554*t)
	X0 += 0.00000008418*np.cos(1.48515415206 + 77.489911553*t)
	X0 += 0.00000008357*np.cos(3.54470219620 + 480.251596762*t)
	X0 += 0.00000007446*np.cos(5.58644401851 + 987.5692770385*t)
	X0 += 0.00000007909*np.cos(5.04849479665 + 288.7350853111*t)
	X0 += 0.00000007092*np.cos(0.01343269779 + 452.9036289572*t)
	X0 += 0.00000007067*np.cos(1.92910668924 + 453.9461586808*t)
	X0 += 0.00000007404*np.cos(1.00296550334 + 75.0422309982*t)
	X0 += 0.00000007700*np.cos(4.42811621635 + 118.0224436358*t)
	X0 += 0.00000006426*np.cos(5.00634728978 + 107.4980082337*t)
	X0 += 0.00000007909*np.cos(1.64368221183 + 36.3879304986*t)
	X0 += 0.00000007909*np.cos(2.69690505451 + 39.878140777*t)
	X0 += 0.00000007754*np.cos(0.07292672861 + 494.4786907636*t)
	X0 += 0.00000006970*np.cos(5.77988712105 + 177.3049238143*t)
	X0 += 0.00000007571*np.cos(2.81738030709 + 23.4639986515*t)
	X0 += 0.00000007039*np.cos(0.87709076060 + 367.9701020033*t)
	X0 += 0.00000007803*np.cos(3.85480058958 + 314.9073969483*t)
	X0 += 0.00000007837*np.cos(0.36694469487 + 1093.0615477021*t)
	X0 += 0.00000006766*np.cos(1.51640472707 + 55.6591434561*t)
	X0 += 0.00000007959*np.cos(0.38379928039 + 170.9732741062*t)
	X0 += 0.00000008362*np.cos(0.62230895069 + 709.9648343255*t)
	X0 += 0.00000005947*np.cos(2.49604652491 + 52213.9393187862*t)
	X0 += 0.00000007549*np.cos(3.25574232293 + 474.9468453752*t)
	X0 += 0.00000007372*np.cos(4.88713041971 + 54.8078101942*t)
	X0 += 0.00000008092*np.cos(4.51194576141 + 485.8806710545*t)
	X0 += 0.00000005719*np.cos(4.96252073817 + 321.7603115182*t)
	X0 += 0.00000005900*np.cos(4.92603535036 + 52061.40717623499*t)
	X0 += 0.00000006554*np.cos(0.27333269638 + 912.7876784712*t)
	X0 += 0.00000005908*np.cos(1.13635211477 + 27.7417266797*t)
	X0 += 0.00000006694*np.cos(5.53088277716 + 488.8496164711*t)
	X0 += 0.00000005654*np.cos(3.04044893090 + 12604.2847356206*t)
	X0 += 0.00000005758*np.cos(2.82344058849 + 29.7956483596*t)
	X0 += 0.00000005270*np.cos(3.46742834680 + 6167.1922703697*t)
	X0 += 0.00000005679*np.cos(5.91775882963 + 16.9835910971*t)
	X0 += 0.00000005209*np.cos(4.02195461829 + 1654.0326338646*t)
	X0 += 0.00000005748*np.cos(2.93833293745 + 169.228168967*t)
	X0 += 0.00000005146*np.cos(0.81172839256 + 46.5186070258*t)
	X0 += 0.00000005080*np.cos(4.32167771768 + 565.1156877467*t)
	X0 += 0.00000006475*np.cos(2.52363278034 + 590.8304249969*t)
	X0 += 0.00000004984*np.cos(4.89088171253 + 10097.4019665893*t)
	X0 += 0.00000005318*np.cos(5.22697439239 + 44.2833747921*t)
	X0 += 0.00000006699*np.cos(2.95046041231 + 2156.8968960162*t)
	X0 += 0.00000005689*np.cos(3.61134391402 + 277.0349937414*t)
	X0 += 0.00000005125*np.cos(0.87728916070 + 134.0640787458*t)
	X0 += 0.00000005296*np.cos(1.30832920931 + 281.1795953256*t)
	X0 += 0.00000005041*np.cos(2.52183329138 + 272.5815756165*t)
	X0 += 0.00000005994*np.cos(5.89267771496 + 93.2709142321*t)
	X0 += 0.00000006298*np.cos(3.64971867049 + 271.6665518798*t)
	X0 += 0.00000006131*np.cos(6.28127551683 + 6318.2399402126*t)
	X0 += 0.00000005671*np.cos(5.73125915161 + 674.8007441043*t)
	X0 += 0.00000005685*np.cos(1.71151397749 + 1165.3954657146*t)
	X0 += 0.00000006215*np.cos(5.21725938550 + 439.782755154*t)
	X0 += 0.00000005454*np.cos(5.93543303674 + 711.4493070338*t)
	X0 += 0.00000005004*np.cos(0.53392408006 + 74.2603337055*t)
	X0 += 0.00000005683*np.cos(5.96405963657 + 381.3516082374*t)
	X0 += 0.00000006127*np.cos(3.68765217385 + 132.8884225782*t)
	X0 += 0.00000005114*np.cos(2.52635469399 + 1120.148883076*t)
	X0 += 0.00000004541*np.cos(1.42631237936 + 1272.6810256272*t)
	X0 += 0.00000004937*np.cos(0.66427869101 + 222.8603229936*t)
	X0 += 0.00000005871*np.cos(0.03409903197 + 528.4671248172*t)
	X0 += 0.00000004765*np.cos(6.27332561370 + 32.4557772355*t)
	X0 += 0.00000005821*np.cos(1.41981947590 + 10248.4496364322*t)
	X0 += 0.00000004944*np.cos(2.31703723493 + 601.7642506762*t)
	X0 += 0.00000004353*np.cos(4.24245486384 + 104.5290628171*t)
	X0 += 0.00000004949*np.cos(4.42793316106 + 1474.6737883704*t)
	X0 += 0.00000005244*np.cos(2.33675009562 + 73.3453099688*t)
	X0 += 0.00000004483*np.cos(2.44008975730 + 384.2723695442*t)
	X0 += 0.00000006063*np.cos(4.76042504867 + 749.5823426716*t)
	X0 += 0.00000006008*np.cos(4.59294328840 + 712.9337797421*t)
	X0 += 0.00000005922*np.cos(4.37134416172 + 286.596221297*t)
	X0 += 0.00000004270*np.cos(4.24481246454 + 1577.766562589*t)
	X0 += 0.00000005100*np.cos(4.49472750722 + 436.8138097374*t)
	X0 += 0.00000005572*np.cos(0.87437668538 + 291.0496394219*t)
	X0 += 0.00000004336*np.cos(5.80102982405 + 53.653405886*t)
	X0 += 0.00000004427*np.cos(3.00156208244 + 189.1807054807*t)
	X0 += 0.00000005872*np.cos(4.92613662106 + 786.2309056011*t)
	X0 += 0.00000005402*np.cos(0.44313805730 + 283.6272758804*t)
	X0 += 0.00000004646*np.cos(2.87775185163 + 13286.1836355236*t)
	X0 += 0.00000004330*np.cos(4.99573580513 + 323.2447842265*t)
	X0 += 0.00000005508*np.cos(4.27724254397 + 177.8743727859*t)
	X0 += 0.00000005348*np.cos(1.42468170559 + 24.6396548191*t)
	X0 += 0.00000005637*np.cos(0.14931346796 + 738.7972748386*t)
	X0 += 0.00000004084*np.cos(3.35816370949 + 765.6239777816*t)
	X0 += 0.00000004090*np.cos(3.49305404275 + 531.1754378029*t)
	X0 += 0.00000005537*np.cos(0.40882285275 + 6247.9117597702*t)
	X0 += 0.00000004851*np.cos(1.58937686331 + 635.1832357582*t)
	X0 += 0.00000004873*np.cos(4.65006489170 + 52.8020726241*t)
	X0 += 0.00000004929*np.cos(4.04798789647 + 224.3447957019*t)
	X0 += 0.00000004424*np.cos(1.37849633956 + 20388.4380567842*t)
	X0 += 0.00000004182*np.cos(1.11763449341 + 6606.4432548323*t)
	X0 += 0.00000004293*np.cos(4.65873972226 + 46.470422916*t)
	X0 += 0.00000004687*np.cos(2.55927316823 + 57.1436161644*t)
	X0 += 0.00000004492*np.cos(0.09912701965 + 52177.29075585669*t)
	X0 += 0.00000004073*np.cos(0.18029210803 + 949.4362414007*t)
	X0 += 0.00000004546*np.cos(6.17479319899 + 304.2342036999*t)
	X0 += 0.00000004593*np.cos(0.14821025071 + 1025.4416802454*t)
	X0 += 0.00000005309*np.cos(1.83025168176 + 10178.1214559898*t)
	X0 += 0.00000005106*np.cos(4.66521026314 + 244.318584075*t)
	X0 += 0.00000003943*np.cos(5.68046671600 + 983.1158589136*t)
	X0 += 0.00000004125*np.cos(2.89106799019 + 426.598190876*t)
	X0 += 0.00000004451*np.cos(2.42081887138 + 31.9826964835*t)
	X0 += 0.00000005048*np.cos(3.95079504111 + 344.9636777388*t)
	X0 += 0.00000004075*np.cos(3.74781422402 + 381.6122406683*t)
	X0 += 0.00000004566*np.cos(2.52866726205 + 395.578702239*t)
	X0 += 0.00000004268*np.cos(2.59269065059 + 373.9079928365*t)
	X0 += 0.00000005380*np.cos(5.09445719710 + 822.8794685306*t)
	X0 += 0.00000003828*np.cos(2.28077620608 + 2138.4770163206*t)
	X0 += 0.00000004629*np.cos(0.97704654494 + 122.4758617607*t)
	X0 += 0.00000003798*np.cos(1.54874176080 + 356.9244017394*t)
	X0 += 0.00000004699*np.cos(5.86825441333 + 214.7835681463*t)
	X0 += 0.00000004711*np.cos(0.43747301673 + 52252.07235442399*t)
	X0 += 0.00000004135*np.cos(2.59411177803 + 502.8642621516*t)
	X0 += 0.00000004557*np.cos(1.38768168102 + 598.5346728287*t)
	X0 += 0.00000004181*np.cos(5.11735243081 + 566.600160455*t)
	X0 += 0.00000004508*np.cos(1.58263794497 + 454.9093665273*t)
	X0 += 0.00000004789*np.cos(2.68691233842 + 627.4789879264*t)
	X0 += 0.00000004021*np.cos(0.14455396364 + 6603.4743094157*t)
	X0 += 0.00000003998*np.cos(1.09645845612 + 404.6186649328*t)
	X0 += 0.00000005168*np.cos(4.77485406558 + 25520.07914084179*t)
	X0 += 0.00000004982*np.cos(0.79282576066 + 746.613397255*t)
	X0 += 0.00000004150*np.cos(3.86319378874 + 27.1992099585*t)
	X0 += 0.00000004801*np.cos(5.49483042971 + 14.6690369863*t)
	X0 += 0.00000003623*np.cos(2.29456392722 + 1665.3389665594*t)
	X0 += 0.00000004634*np.cos(1.79138092130 + 3227.6977924947*t)
	X0 += 0.00000003578*np.cos(3.41081414860 + 562.1467423301*t)
	X0 += 0.00000005002*np.cos(0.73296305202 + 207.3612046048*t)
	X0 += 0.00000004528*np.cos(0.00000058789 + 156.1554792736*t)
	X0 += 0.00000003545*np.cos(0.22127482902 + 220.4126424388*t)
	X0 += 0.00000004557*np.cos(6.27517956469 + 25974.98850736909*t)
	X0 += 0.00000004482*np.cos(1.70549789369 + 342.3672393377*t)
	X0 += 0.00000003500*np.cos(5.68635267780 + 127.4717966068*t)
	X0 += 0.00000004343*np.cos(0.66907601244 + 320.2758388099*t)
	X0 += 0.00000004304*np.cos(0.63784520720 + 12567.6361726911*t)
	X0 += 0.00000004419*np.cos(2.74352120250 + 639.897286314*t)
	X0 += 0.00000003477*np.cos(2.08101295124 + 665.2395165487*t)
	X0 += 0.00000004798*np.cos(5.23928869630 + 529.9515975255*t)
	X0 += 0.00000003640*np.cos(2.22735931846 + 2565.0752071966*t)
	X0 += 0.00000003563*np.cos(5.37461192631 + 12451.7525930694*t)
	X0 += 0.00000004754*np.cos(1.43687878008 + 6209.7787241324*t)
	X0 += 0.00000003524*np.cos(0.09982422546 + 116.5379709275*t)
	X0 += 0.00000003429*np.cos(4.73422293878 + 529.8028396792*t)
	X0 += 0.00000004288*np.cos(5.11733557108 + 23.9059416362*t)
	X0 += 0.00000003406*np.cos(5.88978743881 + 529.57909051*t)
	X0 += 0.00000004348*np.cos(1.52420534934 + 20312.17198550859*t)
	X0 += 0.00000004586*np.cos(5.24207029293 + 180.8433182025*t)
	X0 += 0.00000004280*np.cos(4.42469296513 + 274.6354972964*t)
	X0 += 0.00000003682*np.cos(5.50568401276 + 362.0322111701*t)
	X0 += 0.00000003789*np.cos(4.29352909475 + 3101.879719292*t)
	X0 += 0.00000003850*np.cos(5.92538233044 + 12564.6672272745*t)
	X0 += 0.00000003783*np.cos(0.26937653478 + 1614.4151255185*t)
	X0 += 0.00000003396*np.cos(5.57790342649 + 528.2064923863*t)
	X0 += 0.00000003904*np.cos(0.00422291412 + 370.0452755426*t)
	X0 += 0.00000003847*np.cos(4.08783535627 + 309.230138546*t)
	X0 += 0.00000004231*np.cos(5.35914188830 + 31.2801210679*t)
	X0 += 0.00000003745*np.cos(4.70896682883 + 1025.7023126763*t)
	X0 += 0.00000004284*np.cos(4.97414982566 + 396.5419100855*t)
	X0 += 0.00000003701*np.cos(4.85663387765 + 452.2010535416*t)
	X0 += 0.00000003347*np.cos(4.91535911747 + 20351.7894938547*t)
	X0 += 0.00000003395*np.cos(1.40872683921 + 524.0137066923*t)
	X0 += 0.00000003937*np.cos(1.24135990872 + 1617.3840709351*t)
	X0 += 0.00000003363*np.cos(2.31838707303 + 245.4942402426*t)
	X0 += 0.00000004210*np.cos(3.40661968746 + 511.5954083047*t)
	X0 += 0.00000004189*np.cos(6.16499968875 + 101.6083015103*t)
	X0 += 0.00000003291*np.cos(1.79038639081 + 266.952501324*t)
	X0 += 0.00000003303*np.cos(1.16442176517 + 241.6102710893*t)
	X0 += 0.00000003260*np.cos(1.97534300235 + 537.7677199419*t)
	X0 += 0.00000004526*np.cos(4.55401830095 + 525.5463635104*t)
	X0 += 0.00000004095*np.cos(0.39427917449 + 355.4399290311*t)
	X0 += 0.00000003340*np.cos(1.53848524846 + 70.5888128733*t)
	X0 += 0.00000003337*np.cos(4.80809338870 + 358.4088744477*t)
	X0 += 0.00000004017*np.cos(5.38609718462 + 52174.32181044009*t)
	X0 += 0.00000003276*np.cos(1.95664041088 + 1306.621275571*t)
	X0 += 0.00000003413*np.cos(2.47241228275 + 95.931043108*t)
	X0 += 0.00000003855*np.cos(0.59056751589 + 518.3846323998*t)
	X0 += 0.00000003876*np.cos(4.34459044793 + 142.9709149956*t)
	X0 += 0.00000003214*np.cos(3.94236457757 + 20348.82054843809*t)
	X0 += 0.00000003190*np.cos(2.24966920840 + 282.1428031721*t)
	X0 += 0.00000003764*np.cos(4.32235978597 + 165.0835673828*t)
	X0 += 0.00000004204*np.cos(3.91117850559 + 206.1855484372*t)
	X0 += 0.00000004430*np.cos(5.37916512247 + 529.4303326637*t)
	X0 += 0.00000004064*np.cos(1.03324547829 + 6130.5437074402*t)
	X0 += 0.00000003168*np.cos(2.29019531672 + 389.9496279465*t)
	X0 += 0.00000003270*np.cos(1.09904911575 + 78.4049352897*t)
	X0 += 0.00000003918*np.cos(4.20592331317 + 375.6743498351*t)
	X0 += 0.00000003674*np.cos(0.49264943249 + 183.7640795093*t)
	X0 += 0.00000003132*np.cos(1.00357717013 + 1589.0728952838*t)
	X0 += 0.00000004040*np.cos(5.13378490075 + 433.190473015*t)
	X0 += 0.00000004129*np.cos(3.44624039864 + 26048.28563322809*t)
	X0 += 0.00000004022*np.cos(1.72078809654 + 1477.5945496772*t)
	X0 += 0.00000004003*np.cos(4.72382540422 + 94.7553869404*t)
	X0 += 0.00000003490*np.cos(4.40733409487 + 326.4261779642*t)
	X0 += 0.00000003594*np.cos(6.06724074887 + 217.4436970222*t)
	X0 += 0.00000004060*np.cos(6.06087877396 + 51.6264164565*t)
	X0 += 0.00000003107*np.cos(5.38240325046 + 28.6836826668*t)
	X0 += 0.00000003298*np.cos(0.37071499296 + 102.523325247*t)
	X0 += 0.00000003259*np.cos(5.62261943256 + 658.1259695479*t)
	X0 += 0.00000003428*np.cos(1.24134798478 + 2351.7761117586*t)
	X0 += 0.00000003385*np.cos(0.30663786918 + 661.0949149645*t)
	X0 += 0.00000003446*np.cos(2.55581154573 + 1509.8378785916*t)
	X0 += 0.00000003299*np.cos(0.15502724919 + 1404.0849754971*t)
	X0 += 0.00000003278*np.cos(3.68951046288 + 942.0138778592*t)
	X0 += 0.00000003097*np.cos(1.38268112354 + 259.5088859231*t)
	X0 += 0.00000003173*np.cos(5.46641752741 + 1401.1160300805*t)
	X0 += 0.00000003195*np.cos(5.62363661230 + 353.301065017*t)
	X0 += 0.00000003696*np.cos(1.82603150668 + 14.5571624017*t)
	X0 += 0.00000004114*np.cos(5.50609992924 + 771.1042942278*t)
	X0 += 0.00000004114*np.cos(1.87436741693 + 1049.5600702027*t)
	X0 += 0.00000004012*np.cos(2.15080865585 + 52.3601296394*t)
	X0 += 0.00000004178*np.cos(4.90426814037 + 978.9230732196*t)
	X0 += 0.00000004200*np.cos(2.08730033523 + 943.4983505675*t)
	X0 += 0.00000003057*np.cos(4.32315122802 + 354.7855377253*t)
	X0 += 0.00000003505*np.cos(1.49229918444 + 458.8415197904*t)
	X0 += 0.00000003328*np.cos(0.06468317259 + 519.6084726772*t)
	X0 += 0.00000003022*np.cos(1.87271736515 + 460.5384408198*t)
	X0 += 0.00000003231*np.cos(4.61368527250 + 401.0647641796*t)
	X0 += 0.00000003726*np.cos(0.55317699448 + 1096.2429414398*t)
	X0 += 0.00000004101*np.cos(1.40890174425 + 875.830299001*t)
	X0 += 0.00000003792*np.cos(0.75463890542 + 111.6907939277*t)
	X0 += 0.00000003984*np.cos(5.40932060866 + 476.4313180835*t)
	X0 += 0.00000003839*np.cos(2.45651233746 + 10060.7534036598*t)
	X0 += 0.00000003012*np.cos(1.81750409287 + 225.8292684102*t)
	X0 += 0.00000003475*np.cos(5.19319328694 + 325.3836482406*t)
	X0 += 0.00000004113*np.cos(5.70053139080 + 141.4864422873*t)
	X0 += 0.00000004192*np.cos(0.29273630154 + 2772.7884259674*t)
	X0 += 0.00000003670*np.cos(1.51746404309 + 57.84619158*t)
	X0 += 0.00000002960*np.cos(2.20143035616 + 2461.982432978*t)
	X0 += 0.00000003331*np.cos(0.81282265497 + 10134.0505295188*t)
	X0 += 0.00000004044*np.cos(2.80116908409 + 25596.3452121174*t)
	X0 += 0.00000003310*np.cos(0.63021323746 + 1586.1039498672*t)
	X0 += 0.00000003012*np.cos(0.24750674481 + 347.3631741838*t)
	X0 += 0.00000003466*np.cos(4.73899873914 + 1151.168371713*t)
	X0 += 0.00000003184*np.cos(3.93786877135 + 554.0699874828*t)
	X0 += 0.00000002938*np.cos(0.92092579208 + 600.2797779679*t)
	X0 += 0.00000002951*np.cos(5.58078877076 + 33.7278016227*t)
	X0 += 0.00000002951*np.cos(5.04298380276 + 42.5382696529*t)
	X0 += 0.00000002924*np.cos(0.08510684138 + 394.0942295307*t)
	X0 += 0.00000003314*np.cos(1.64856662940 + 939.3537489833*t)
	X0 += 0.00000003031*np.cos(2.75127174781 + 156451.15277816958*t)
	X0 += 0.00000002967*np.cos(0.01380343554 + 6.1503391543*t)
	X0 += 0.00000002995*np.cos(3.55719578836 + 139.9537854692*t)
	X0 += 0.00000003250*np.cos(3.50402124851 + 709.0498105888*t)
	X0 += 0.00000003365*np.cos(1.74314879420 + 642.6055992997*t)
	X0 += 0.00000003420*np.cos(0.98621583591 + 302.7497309916*t)
	X0 += 0.00000003811*np.cos(3.32959588229 + 732.97125859*t)
	X0 += 0.00000003227*np.cos(1.44273528458 + 406.1031376411*t)
	X0 += 0.00000002917*np.cos(2.25862979793 + 83.3796182764*t)
	X0 += 0.00000003196*np.cos(5.84285969983 + 362.8622925726*t)
	X0 += 0.00000003158*np.cos(1.18152049723 + 539.773457512*t)
	X0 += 0.00000002810*np.cos(5.14801331317 + 1592.0418407004*t)
	X0 += 0.00000003159*np.cos(4.14441699779 + 197.7999770492*t)
	X0 += 0.00000003306*np.cos(6.11095094695 + 748.0978699633*t)
	X0 += 0.00000003823*np.cos(2.80947819413 + 10139.988420352*t)
	X0 += 0.00000002779*np.cos(6.24138111214 + 956.2891559706*t)
	X0 += 0.00000003793*np.cos(0.88752668902 + 104.5772469269*t)
	X0 += 0.00000003750*np.cos(3.47948196612 + 235.0179889503*t)
	X0 += 0.00000003349*np.cos(1.74325912375 + 671.8317986877*t)
	X0 += 0.00000003752*np.cos(5.81571997623 + 303.6010642535*t)
	X0 += 0.00000002794*np.cos(1.88518054847 + 344.7030453079*t)
	X0 += 0.00000003227*np.cos(5.73842438744 + 6203.8408332992*t)
	X0 += 0.00000002780*np.cos(4.56507186185 + 285.1117485887*t)
	X0 += 0.00000003509*np.cos(0.85163274980 + 1440.7335384266*t)
	X0 += 0.00000002906*np.cos(0.69691325438 + 175.820451106*t)
	X0 += 0.00000002773*np.cos(0.67900305993 + 341.7340998913*t)
	X0 += 0.00000003254*np.cos(6.24947816889 + 1019.7644218431*t)
	X0 += 0.00000003447*np.cos(3.53963683079 + 499.895316735*t)
	X0 += 0.00000003057*np.cos(1.34588220916 + 52.6901980395*t)
	X0 += 0.00000003057*np.cos(6.13629771077 + 23.5758732361*t)
	X0 += 0.00000003579*np.cos(2.43695495203 + 532.8723588323*t)
	X0 += 0.00000002817*np.cos(3.26706196757 + 210.3783341312*t)
	X0 += 0.00000002934*np.cos(4.00235406128 + 79.889407998*t)
	X0 += 0.00000002724*np.cos(0.93671377498 + 22.9427337897*t)
	X0 += 0.00000002733*np.cos(3.50715929429 + 262.4778313397*t)
	X0 += 0.00000003357*np.cos(4.72658826456 + 1227.4344429886*t)
	X0 += 0.00000002841*np.cos(6.20044524987 + 622.9136952169*t)
	X0 += 0.00000002681*np.cos(1.11809321449 + 24.9484713598*t)
	X0 += 0.00000002817*np.cos(5.86922240468 + 450.7165808333*t)
	X0 += 0.00000002756*np.cos(3.02634259211 + 1476.1582610787*t)
	X0 += 0.00000002964*np.cos(1.04680434048 + 488.5889840402*t)
	X0 += 0.00000003490*np.cos(2.85082275685 + 664.1275508559*t)
	X0 += 0.00000002933*np.cos(3.56739414458 + 1549.4553869377*t)
	X0 += 0.00000003112*np.cos(1.11035723120 + 525.2375469697*t)
	X0 += 0.00000003326*np.cos(2.12303836543 + 44.9859502077*t)
	X0 += 0.00000003487*np.cos(1.90425333258 + 526.5095713569*t)
	X0 += 0.00000002774*np.cos(1.98967291895 + 56.6223513026*t)
	X0 += 0.00000002630*np.cos(1.12693493815 + 2751.5475996916*t)
	X0 += 0.00000002849*np.cos(5.95945882711 + 213.9534867438*t)
	X0 += 0.00000002619*np.cos(2.30223540587 + 521.6142102473*t)
	X0 += 0.00000003053*np.cos(3.21227175566 + 946.4672959841*t)
	X0 += 0.00000002610*np.cos(5.59279367957 + 419.4846438752*t)
	X0 += 0.00000002696*np.cos(0.02934814329 + 170.7126416753*t)
	X0 += 0.00000003127*np.cos(3.04511447359 + 225.3080035484*t)
	X0 += 0.00000002815*np.cos(0.75877175602 + 1371.5810141518*t)
	X0 += 0.00000002700*np.cos(4.45466881016 + 963.4027029714*t)
	X0 += 0.00000003417*np.cos(3.07102354924 + 1055.1891444952*t)
	X0 += 0.00000003026*np.cos(0.53178244298 + 464.7312265138*t)
	X0 += 0.00000002777*np.cos(1.65856987776 + 238.6413256727*t)
	X0 += 0.00000002673*np.cos(4.60039823041 + 531.6967026647*t)
	X0 += 0.00000002677*np.cos(1.34892572100 + 673.8375362578*t)
	X0 += 0.00000002586*np.cos(1.81370129822 + 952.0963702766*t)
	X0 += 0.00000003089*np.cos(6.09015444975 + 340.5102596139*t)
	X0 += 0.00000002583*np.cos(6.14761245757 + 411.0990724872*t)
	X0 += 0.00000003011*np.cos(5.63133480804 + 638.1521811748*t)
	X0 += 0.00000003257*np.cos(1.52474283809 + 305.7186764082*t)
	X0 += 0.00000002639*np.cos(1.77948465499 + 1558.0534066468*t)
	X0 += 0.00000002647*np.cos(3.85259975875 + 418.2608035978*t)
	X0 += 0.00000003265*np.cos(1.54950325507 + 24.4908969728*t)
	X0 += 0.00000002938*np.cos(5.49430233325 + 1012.8633231634*t)
	X0 += 0.00000003134*np.cos(2.43567242699 + 959.2099172774*t)
	X0 += 0.00000002704*np.cos(4.48994870880 + 260.9933586314*t)
	X0 += 0.00000002644*np.cos(1.01962883809 + 508.3503240922*t)
	X0 += 0.00000002764*np.cos(4.98220772432 + 410.8384400563*t)
	X0 += 0.00000002541*np.cos(4.73625533432 + 908.3342603463*t)
	X0 += 0.00000003445*np.cos(2.56425659412 + 891.3294173898*t)
	X0 += 0.00000002766*np.cos(2.69251127285 + 57.7980074702*t)
	X0 += 0.00000002629*np.cos(0.50662483303 + 881.5075574033*t)
	X0 += 0.00000003149*np.cos(4.87348132813 + 227.9681324243*t)
	X0 += 0.00000003052*np.cos(3.24537522514 + 463.5073862364*t)
	X0 += 0.00000002969*np.cos(2.91028630885 + 482.9599097477*t)
	X0 += 0.00000002529*np.cos(0.59005799785 + 800.8362521126*t)
	X0 += 0.00000002776*np.cos(5.74905232493 + 113.1270825262*t)
	X0 += 0.00000003048*np.cos(4.65674657724 + 473.4623726669*t)
	X0 += 0.00000002922*np.cos(1.12479586101 + 244.0097675343*t)
	X0 += 0.00000002607*np.cos(4.21790184644 + 1512.8068240082*t)
	X0 += 0.00000002591*np.cos(1.76339808480 + 1190.7858800591*t)
	X0 += 0.00000002485*np.cos(1.72931036722 + 393.5729646689*t)
	X0 += 0.00000003144*np.cos(0.01982679605 + 1504.2088042991*t)
	X0 += 0.00000002818*np.cos(3.61898689320 + 49.0668613171*t)
	X0 += 0.00000003275*np.cos(2.20152854585 + 769.8167634756*t)
	X0 += 0.00000002471*np.cos(1.23010498360 + 411.3597049181*t)
	X0 += 0.00000003340*np.cos(3.12134960773 + 172.2452984934*t)
	X0 += 0.00000002972*np.cos(0.30228215717 + 569.0478410098*t)
	X0 += 0.00000003186*np.cos(1.74073125344 + 149.0419322728*t)
	X0 += 0.00000003367*np.cos(1.91743580007 + 20.0374788479*t)
	X0 += 0.00000002882*np.cos(0.03762702324 + 340.8827666294*t)
	X0 += 0.00000002660*np.cos(0.43081795741 + 573.4530750249*t)
	X0 += 0.00000002436*np.cos(4.39571941383 + 1625.7214582133*t)
	X0 += 0.00000002821*np.cos(5.66862729029 + 402.6922492398*t)
	X0 += 0.00000003412*np.cos(1.27006964431 + 772.5887669361*t)
	X0 += 0.00000003170*np.cos(0.53683800465 + 1011.3788504551*t)
	X0 += 0.00000002845*np.cos(4.17449695566 + 425.3743505986*t)
	X0 += 0.00000003402*np.cos(4.85307522182 + 89.9082099406*t)
	X0 += 0.00000003398*np.cos(3.55399056219 + 769.6198215195*t)
	X0 += 0.00000002437*np.cos(0.05670653494 + 189.8350967865*t)
	X0 += 0.00000003032*np.cos(4.25383054569 + 237.9869343669*t)
	X0 += 0.00000003400*np.cos(2.91219723907 + 533.8355666788*t)
	X0 += 0.00000002671*np.cos(2.67939607146 + 409.6627838887*t)
	X0 += 0.00000002771*np.cos(4.92893090510 + 608.877797677*t)
	X0 += 0.00000003091*np.cos(1.88244262661 + 379.0158022672*t)
	X0 += 0.00000003003*np.cos(5.65412222590 + 416.7763308895*t)
	X0 += 0.00000002397*np.cos(6.05494110587 + 841.8900490572*t)
	X0 += 0.00000002655*np.cos(2.90453219642 + 625.6701923124*t)
	X0 += 0.00000003241*np.cos(6.13124318449 + 353.0404325861*t)
	X0 += 0.00000003176*np.cos(3.29731094880 + 301.1533836987*t)
	X0 += 0.00000003364*np.cos(4.63792927454 + 2849.054497243*t)
	X0 += 0.00000002613*np.cos(4.56119092841 + 561.8861098992*t)
	X0 += 0.00000002506*np.cos(5.01609439183 + 1447.8470854274*t)
	X0 += 0.00000003329*np.cos(5.91925424243 + 66.3960271793*t)
	X0 += 0.00000002425*np.cos(4.19851782109 + 288.0806940053*t)
	X0 += 0.00000002503*np.cos(5.31932296128 + 1012.6508748423*t)
	X0 += 0.00000002698*np.cos(1.69371611112 + 78149.31031780918*t)
	X0 += 0.00000002373*np.cos(4.96473366948 + 131.0951333292*t)
	X0 += 0.00000002850*np.cos(5.75651173443 + 316.6525020875*t)
	X0 += 0.00000002548*np.cos(5.85319231329 + 1624.236985505*t)
	X0 += 0.00000003326*np.cos(2.34088602919 + 346.1393339064*t)
	X0 += 0.00000002419*np.cos(6.00632380308 + 527.6852275245*t)
	X0 += 0.00000002628*np.cos(2.68041444146 + 305.3461693927*t)
	X0 += 0.00000002362*np.cos(5.34786616359 + 905.3653149297*t)
	X0 += 0.00000003116*np.cos(2.31725423336 + 6171.6456884946*t)
	X0 += 0.00000002735*np.cos(4.77197048747 + 1205.9761819072*t)
	X0 += 0.00000002351*np.cos(1.00989589789 + 487.6257761937*t)
	X0 += 0.00000003264*np.cos(0.98644966743 + 1507.1777497157*t)
	X0 += 0.00000002343*np.cos(5.30414272180 + 570.7447620392*t)
	X0 += 0.00000003242*np.cos(3.43781809479 + 978.6624407887*t)
	X0 += 0.00000002327*np.cos(1.94695161209 + 490.0734567485*t)
	X0 += 0.00000002871*np.cos(4.23439916590 + 154.6710065653*t)
	X0 += 0.00000002369*np.cos(4.33013696090 + 419.2240114443*t)
	X0 += 0.00000002891*np.cos(5.96526238067 + 51.7751743028*t)
	X0 += 0.00000002345*np.cos(2.80678169901 + 454.1756533444*t)
	X0 += 0.00000002329*np.cos(1.75923687263 + 1477.642733787*t)
	X0 += 0.00000002340*np.cos(5.41993486888 + 452.6741342936*t)
	X0 += 0.00000002471*np.cos(5.85334195437 + 878.5386119867*t)
	X0 += 0.00000003119*np.cos(3.73163278907 + 1435.0562800243*t)
	X0 += 0.00000002460*np.cos(0.98834029380 + 173.6815870919*t)
	X0 += 0.00000003148*np.cos(5.33900856192 + 1122.8571960617*t)
	X0 += 0.00000002494*np.cos(0.79353995081 + 1187.8169346425*t)
	X0 += 0.00000002324*np.cos(0.85149013777 + 1515.7757694248*t)
	X0 += 0.00000003045*np.cos(4.58970934616 + 477.3308354552*t)
	X0 += 0.00000002701*np.cos(3.94900738069 + 2005.8492261733*t)
	X0 += 0.00000003122*np.cos(4.87352367476 + 1230.3552042954*t)
	X0 += 0.00000002809*np.cos(5.67078157868 + 317.8281582551*t)
	X0 += 0.00000003209*np.cos(5.65172771419 + 15.1266113733*t)
	X0 += 0.00000002946*np.cos(6.27125306316 + 186.472392495*t)
	X0 += 0.00000002409*np.cos(1.16807097154 + 70.6369969831*t)
	X0 += 0.00000002546*np.cos(3.78661896416 + 422.7142217227*t)
	X0 += 0.00000002855*np.cos(6.04151843237 + 414.0680179038*t)
	X0 += 0.00000002992*np.cos(3.74091272105 + 10101.8553847142*t)
	X0 += 0.00000002722*np.cos(2.16495029711 + 49.4393683326*t)
	X0 += 0.00000002346*np.cos(0.85350513182 + 52137.67324751059*t)
	X0 += 0.00000002745*np.cos(1.25308857006 + 591.9423906897*t)
	X0 += 0.00000002251*np.cos(1.84603626039 + 22.8945496799*t)
	X0 += 0.00000002380*np.cos(0.86688341144 + 429.5189521828*t)
	X0 += 0.00000002655*np.cos(2.72088990937 + 484.3961983462*t)
	X0 += 0.00000003005*np.cos(3.02374335144 + 1929.5831548977*t)
	X0 += 0.00000002944*np.cos(5.80795120544 + 497.1870037493*t)
	X0 += 0.00000002290*np.cos(3.41119288308 + 455.4306313891*t)
	X0 += 0.00000002226*np.cos(2.09977732289 + 47.5823886088*t)
	X0 += 0.00000002380*np.cos(5.70190719886 + 398.6807740996*t)
	X0 += 0.00000002235*np.cos(4.93872079635 + 877.1023233882*t)
	X0 += 0.00000002965*np.cos(5.31321105098 + 451.9404211107*t)
	X0 += 0.00000002228*np.cos(0.14871984610 + 29.7474642498*t)
	X0 += 0.00000002719*np.cos(1.98957096467 + 177.8261886761*t)
	X0 += 0.00000002353*np.cos(2.64987133570 + 278.5194664497*t)
	X0 += 0.00000002999*np.cos(2.06886611056 + 1926.6142094811*t)
	X0 += 0.00000002695*np.cos(3.57859697492 + 6284.5603226997*t)
	X0 += 0.00000003103*np.cos(5.25954578672 + 859.5280314601*t)
	X0 += 0.00000002841*np.cos(1.89822722034 + 2080.6308247406*t)
	X0 += 0.00000002247*np.cos(4.99448806399 + 635.70450062*t)
	X0 += 0.00000002718*np.cos(3.94432671112 + 1082.0158474382*t)
	X0 += 0.00000002266*np.cos(3.32415490093 + 621.4774066184*t)
	X0 += 0.00000002805*np.cos(4.65550300998 + 1438.0252254409*t)
	X0 += 0.00000002204*np.cos(3.20467222541 + 443.1299530805*t)
	X0 += 0.00000002983*np.cos(2.11840545429 + 601.5036182453*t)
	X0 += 0.00000002983*np.cos(0.96467854341 + 783.2619601845*t)
	X0 += 0.00000002226*np.cos(6.16264010648 + 1189.3014073508*t)
	X0 += 0.00000002825*np.cos(5.72066778195 + 1131.1945833399*t)
	X0 += 0.00000002513*np.cos(2.67603480531 + 407.2151033339*t)
	X0 += 0.00000002449*np.cos(6.26391680561 + 545.2750258176*t)
	X0 += 0.00000002823*np.cos(1.28631955107 + 411.147256597*t)
	X0 += 0.00000002976*np.cos(1.45407959506 + 1014.3477958717*t)
	X0 += 0.00000002341*np.cos(1.72462609263 + 440.6822725257*t)
	X0 += 0.00000002539*np.cos(4.85191300379 + 12566.1516999828*t)
	X0 += 0.00000002148*np.cos(6.10633698376 + 248.7238180901*t)
	X0 += 0.00000002704*np.cos(4.82066135933 + 382.8360809457*t)
	X0 += 0.00000002370*np.cos(0.24236554874 + 132.8402384684*t)
	X0 += 0.00000002336*np.cos(4.17366212174 + 495.4900827199*t)
	X0 += 0.00000002232*np.cos(2.42169508541 + 158.3736651648*t)
	X0 += 0.00000002471*np.cos(3.93681150847 + 658.1896600227*t)
	return X0




def Neptune_X1 (t): # 291 terms of order 1

	X1 = 0.
	X1 += 0.00255827017*np.cos(2.01935687782 + 36.6485629295*t)
	X1 += 0.00243112812*np.cos(5.46214905602 + 39.6175083461*t)
	X1 += 0.00118382753*np.cos(2.88255085978 + 76.2660712756*t)
	X1 -= 0.00039261522
	X1 += 0.00021923572*np.cos(3.20156162709 + 35.1640902212*t)
	X1 += 0.00017458926*np.cos(4.26349403115 + 41.1019810544*t)
	X1 += 0.00013130617*np.cos(5.36424961848 + 2.9689454166*t)
	X1 += 0.00005086527*np.cos(1.92377354729 + 38.1330356378*t)
	X1 += 0.00004909885*np.cos(2.09371107061 + 73.297125859*t)
	X1 += 0.00002745912*np.cos(4.06264400609 + 77.7505439839*t)
	X1 += 0.00002204414*np.cos(4.38855639521 + 33.6796175129*t)
	X1 += 0.00002168719*np.cos(4.11768012563 + 4.4534181249*t)
	X1 += 0.00001572202*np.cos(1.07606611589 + 114.3991069134*t)
	X1 += 0.00001344022*np.cos(3.03802059051 + 42.5864537627*t)
	X1 += 0.00001284677*np.cos(6.02457823347 + 74.7815985673*t)
	X1 += 0.00000865247*np.cos(1.66600949831 + 37.611770776*t)
	X1 += 0.00000849963*np.cos(5.81599544749 + 38.6543004996*t)
	X1 += 0.00000921680*np.cos(3.34426545736 + 71.8126531507*t)
	X1 += 0.00000637551*np.cos(5.41077728291 + 1.4844727083*t)
	X1 += 0.00000501158*np.cos(1.71336416584 + 28.5718080822*t)
	X1 += 0.00000477774*np.cos(4.41606171374 + 98.8999885246*t)
	X1 += 0.00000454020*np.cos(1.71446347956 + 35.685355083*t)
	X1 += 0.00000410057*np.cos(5.76580004770 + 40.5807161926*t)
	X1 += 0.00000366899*np.cos(5.76755714114 + 47.6942631934*t)
	X1 += 0.00000301105*np.cos(2.88798068983 + 5.9378908332*t)
	X1 += 0.00000261005*np.cos(5.58341588259 + 32.1951448046*t)
	X1 += 0.00000208502*np.cos(4.50403508407 + 70.3281804424*t)
	X1 += 0.00000172634*np.cos(4.41668100139 + 33.9402499438*t)
	X1 += 0.00000156880*np.cos(2.59636158964 + 79.2350166922*t)
	X1 += 0.00000152545*np.cos(0.58200211092 + 30.0562807905*t)
	X1 += 0.00000150774*np.cos(3.03955693857 + 42.3258213318*t)
	X1 += 0.00000161730*np.cos(0.79247603617 + 31.019488637*t)
	X1 += 0.00000132841*np.cos(1.62575223921 + 8.0767548473*t)
	X1 += 0.00000134574*np.cos(0.39220827354 + 45.2465826386*t)
	X1 += 0.00000115906*np.cos(1.81847065740 + 44.070926471*t)
	X1 += 0.00000111639*np.cos(0.63975084587 + 46.2097904851*t)
	X1 += 0.00000110293*np.cos(6.26561040615 + 35.212274331*t)
	X1 += 0.00000113312*np.cos(3.44493924211 + 7.1135470008*t)
	X1 += 0.00000100459*np.cos(1.21320933829 + 41.0537969446*t)
	X1 += 0.00000109047*np.cos(3.08916188250 + 112.9146342051*t)
	X1 += 0.00000088218*np.cos(4.22122102145 + 60.7669528868*t)
	X1 += 0.00000051114*np.cos(6.03439734344 + 111.4301614968*t)
	X1 += 0.00000051602*np.cos(4.02001213822 + 69.1525242748*t)
	X1 += 0.00000048159*np.cos(6.22092546220 + 2.9207613068*t)
	X1 += 0.00000042059*np.cos(1.68843052596 + 44.7253177768*t)
	X1 += 0.00000042530*np.cos(1.67291335129 + 7.4223635415*t)
	X1 += 0.00000039462*np.cos(5.84050948012 + 31.5407534988*t)
	X1 += 0.00000039310*np.cos(0.94345147546 + 12.5301729722*t)
	X1 += 0.00000037940*np.cos(2.73822096384 + 6.592282139*t)
	X1 += 0.00000037655*np.cos(5.98798322385 + 14.0146456805*t)
	X1 += 0.00000040840*np.cos(5.54850725123 + 109.9456887885*t)
	X1 += 0.00000036848*np.cos(2.85564848871 + 84.3428261229*t)
	X1 += 0.00000035231*np.cos(6.25325402099 + 274.0660483248*t)
	X1 += 0.00000036952*np.cos(5.72145792762 + 68.8437077341*t)
	X1 += 0.00000033599*np.cos(0.51632981099 + 30.7106720963*t)
	X1 += 0.00000038296*np.cos(4.30335137765 + 4.192785694*t)
	X1 += 0.00000031035*np.cos(2.95099562096 + 27.0873353739*t)
	X1 += 0.00000033084*np.cos(2.45856880831 + 115.8835796217*t)
	X1 += 0.00000026640*np.cos(2.51311389510 + 24.1183899573*t)
	X1 += 0.00000030543*np.cos(4.02100472961 + 22.633917249*t)
	X1 += 0.00000024422*np.cos(4.35428875793 + 106.0135355254*t)
	X1 += 0.00000022126*np.cos(1.26007098345 + 175.1660598002*t)
	X1 += 0.00000021409*np.cos(0.20432330860 + 63.7358983034*t)
	X1 += 0.00000019878*np.cos(1.01805826985 + 32.7164096664*t)
	X1 += 0.00000019870*np.cos(0.94595354813 + 5.4166259714*t)
	X1 += 0.00000019754*np.cos(4.49000211469 + 49.1787359017*t)
	X1 += 0.00000019249*np.cos(6.01423960566 + 6.9010986797*t)
	X1 += 0.00000022151*np.cos(4.48090838716 + 106.9767433719*t)
	X1 += 0.00000016511*np.cos(2.54729348191 + 43.2408450685*t)
	X1 += 0.00000016978*np.cos(1.10703451835 + 91.7864415238*t)
	X1 += 0.00000016400*np.cos(5.02426125494 + 33.0252262071*t)
	X1 += 0.00000015948*np.cos(1.13749320372 + 25.6028626656*t)
	X1 += 0.00000017239*np.cos(0.18394173571 + 11.3063326948*t)
	X1 += 0.00000015925*np.cos(2.36095647166 + 11.0457002639*t)
	X1 += 0.00000018246*np.cos(3.22627946510 + 72.0732855816*t)
	X1 += 0.00000015590*np.cos(5.48957045033 + 39.405060025*t)
	X1 += 0.00000015590*np.cos(1.99260946960 + 36.8610112506*t)
	X1 += 0.00000015469*np.cos(0.19931734817 + 43.5496616092*t)
	X1 += 0.00000016590*np.cos(2.76837407696 + 33.4671691918*t)
	X1 += 0.00000019347*np.cos(5.63496726797 + 152.5321425512*t)
	X1 += 0.00000015976*np.cos(1.65044105294 + 62.2514255951*t)
	X1 += 0.00000015454*np.cos(2.75555291329 + 319.3126309634*t)
	X1 += 0.00000015621*np.cos(0.66768589768 + 9.5612275556*t)
	X1 += 0.00000016781*np.cos(3.20518911865 + 305.0855369618*t)
	X1 += 0.00000013461*np.cos(3.85768784107 + 82.8583534146*t)
	X1 += 0.00000015069*np.cos(1.17614399880 + 79.1868325824*t)
	X1 += 0.00000014471*np.cos(0.40529532028 + 108.4612160802*t)
	X1 += 0.00000012751*np.cos(0.61425113640 + 45.5553991793*t)
	X1 += 0.00000012373*np.cos(2.42103444520 + 31.2319369581*t)
	X1 += 0.00000013293*np.cos(4.71511953086 + 42.7989020838*t)
	X1 += 0.00000010966*np.cos(3.53790147295 + 100.3844612329*t)
	X1 += 0.00000011029*np.cos(3.82526067822 + 5.1078094307*t)
	X1 += 0.00000011199*np.cos(1.46876166558 + 415.2918581812*t)
	X1 += 0.00000010323*np.cos(2.47237024135 + 97.4155158163*t)
	X1 += 0.00000011362*np.cos(1.53250494310 + 129.9194771616*t)
	X1 += 0.00000010927*np.cos(5.58985591811 + 137.0330241624*t)
	X1 += 0.00000009718*np.cos(5.65627708700 + 251.4321310758*t)
	X1 += 0.00000010632*np.cos(4.66474891406 + 143.6253063014*t)
	X1 += 0.00000008257*np.cos(0.24275587757 + 70.8494453042*t)
	X1 += 0.00000008691*np.cos(3.86130716302 + 32.5039613453*t)
	X1 += 0.00000007714*np.cos(5.08135063656 + 65.2203710117*t)
	X1 += 0.00000007336*np.cos(5.00488818837 + 15.4991183888*t)
	X1 += 0.00000009601*np.cos(0.96952666662 + 80.7194894005*t)
	X1 += 0.00000007826*np.cos(4.02401038086 + 76.7873361374*t)
	X1 += 0.00000007134*np.cos(3.62090129613 + 43.7621099303*t)
	X1 += 0.00000007924*np.cos(6.12971551056 + 75.7448064138*t)
	X1 += 0.00000006105*np.cos(1.54425967217 + 69.3649725959*t)
	X1 += 0.00000006646*np.cos(5.79555279451 + 105.4922706636*t)
	X1 += 0.00000005999*np.cos(0.85410630839 + 64.9597385808*t)
	X1 += 0.00000005760*np.cos(1.96229416439 + 449.232108125*t)
	X1 += 0.00000006294*np.cos(0.53403647313 + 66.70484372*t)
	X1 += 0.00000006423*np.cos(5.04711326278 + 678.0303219518*t)
	X1 += 0.00000005483*np.cos(4.29890655108 + 42.0651889009*t)
	X1 += 0.00000005483*np.cos(3.18327336885 + 34.2008823747*t)
	X1 += 0.00000006239*np.cos(5.78066557799 + 17.5261078183*t)
	X1 += 0.00000005325*np.cos(4.39759585927 + 19.0105805266*t)
	X1 += 0.00000005928*np.cos(5.59840511102 + 146.594251718*t)
	X1 += 0.00000005857*np.cos(1.07253151439 + 144.1465711632*t)
	X1 += 0.00000004910*np.cos(5.04787179940 + 45.0341343175*t)
	X1 += 0.00000005250*np.cos(4.87798799534 + 0.9632078465*t)
	X1 += 0.00000004802*np.cos(3.33573258260 + 39.0962434843*t)
	X1 += 0.00000004731*np.cos(2.77828322823 + 36.1272980677*t)
	X1 += 0.00000004731*np.cos(1.56230403811 + 40.1387732079*t)
	X1 += 0.00000005910*np.cos(6.11806155370 + 6168.676743078*t)
	X1 += 0.00000004700*np.cos(6.23394740585 + 50.66320861*t)
	X1 += 0.00000005127*np.cos(0.06950186450 + 141.1776257466*t)
	X1 += 0.00000005322*np.cos(3.67014675991 + 1104.6285128278*t)
	X1 += 0.00000004891*np.cos(1.27934912329 + 525.4981794006*t)
	X1 += 0.00000004984*np.cos(3.03175558664 + 1090.4014188262*t)
	X1 += 0.00000004689*np.cos(1.24271093395 + 1067.9799498983*t)
	X1 += 0.00000005562*np.cos(1.26403171450 + 10098.8864392976*t)
	X1 += 0.00000004554*np.cos(4.70928992460 + 310.7146112543*t)
	X1 += 0.00000005456*np.cos(4.82255320187 + 180.2738692309*t)
	X1 += 0.00000004432*np.cos(2.40637892199 + 415.5524906121*t)
	X1 += 0.00000005811*np.cos(1.70824669110 + 1409.7140497896*t)
	X1 += 0.00000004436*np.cos(6.17265977038 + 235.933012687*t)
	X1 += 0.00000004285*np.cos(5.97555084089 + 1050.7839104801*t)
	X1 += 0.00000004088*np.cos(5.45738792077 + 423.4167971383*t)
	X1 += 0.00000005027*np.cos(4.43953393933 + 21.4582610814*t)
	X1 += 0.00000004383*np.cos(1.45471238269 + 463.5073862364*t)
	X1 += 0.00000004109*np.cos(1.73853839233 + 416.7763308895*t)
	X1 += 0.00000004013*np.cos(1.39690454418 + 104275.34649502118*t)
	X1 += 0.00000003962*np.cos(4.02083994540 + 979.1837056505*t)
	X1 += 0.00000003944*np.cos(3.78374455005 + 119.5069163441*t)
	X1 += 0.00000005073*np.cos(3.58206440503 + 1498.5797300066*t)
	X1 += 0.00000004227*np.cos(1.48710021916 + 534.1443832195*t)
	X1 += 0.00000005297*np.cos(0.84181982797 + 532.8723588323*t)
	X1 += 0.00000004054*np.cos(4.02883092677 + 429.7795846137*t)
	X1 += 0.00000005189*np.cos(3.49830366024 + 526.5095713569*t)
	X1 += 0.00000004154*np.cos(3.55675550682 + 518.3846323998*t)
	X1 += 0.00000003893*np.cos(2.68408756029 + 200.7689224658*t)
	X1 += 0.00000004367*np.cos(1.71153576533 + 58.7399634573*t)
	X1 += 0.00000005128*np.cos(2.54279972354 + 10175.1525105732*t)
	X1 += 0.00000004422*np.cos(1.14605401219 + 291.7040307277*t)
	X1 += 0.00000004039*np.cos(3.79988856423 + 1623.0131452276*t)
	X1 += 0.00000004823*np.cos(2.78490253436 + 418.0001711669*t)
	X1 += 0.00000003653*np.cos(5.08334267684 + 1131.4552157708*t)
	X1 += 0.00000003718*np.cos(0.22957714216 + 1065.0110044817*t)
	X1 += 0.00000004093*np.cos(3.83316780565 + 2.4476805548*t)
	X1 += 0.00000003651*np.cos(2.25318014325 + 1127.2624300768*t)
	X1 += 0.00000003663*np.cos(0.70030067491 + 1558.0534066468*t)
	X1 += 0.00000004729*np.cos(3.76762082532 + 420.9691165835*t)
	X1 += 0.00000004053*np.cos(3.31682258179 + 921.0768816396*t)
	X1 += 0.00000003490*np.cos(5.25996362598 + 987.0480121767*t)
	X1 += 0.00000003715*np.cos(6.02152182000 + 254.3528923826*t)
	X1 += 0.00000003488*np.cos(1.23861460695 + 187.6962327724*t)
	X1 += 0.00000003781*np.cos(6.03707098362 + 142.1408335931*t)
	X1 += 0.00000003538*np.cos(3.09032216842 + 57.255490749*t)
	X1 += 0.00000003838*np.cos(1.99819885333 + 980.146913497*t)
	X1 += 0.00000003312*np.cos(0.35984652911 + 1543.8263126452*t)
	X1 += 0.00000004048*np.cos(4.68172394542 + 979.9344651759*t)
	X1 += 0.00000004414*np.cos(3.57495160384 + 1062.3508756058*t)
	X1 += 0.00000003396*np.cos(1.65466087062 + 29.226199388*t)
	X1 += 0.00000003269*np.cos(3.89052626844 + 173.6815870919*t)
	X1 += 0.00000003292*np.cos(0.34317097377 + 807.9497991134*t)
	X1 += 0.00000003353*np.cos(3.87387665600 + 10289.5516174866*t)
	X1 += 0.00000003214*np.cos(2.40790041435 + 569.3084734407*t)
	X1 += 0.00000003353*np.cos(3.19691958235 + 157.6399519819*t)
	X1 += 0.00000003205*np.cos(5.22491937078 + 275.5505210331*t)
	X1 += 0.00000003339*np.cos(3.69633473042 + 443.3424014016*t)
	X1 += 0.00000003188*np.cos(1.05808548340 + 361.3778198643*t)
	X1 += 0.00000003156*np.cos(4.66487374477 + 432.0842528166*t)
	X1 += 0.00000003814*np.cos(1.96828078057 + 449.2802922348*t)
	X1 += 0.00000003757*np.cos(3.59915858611 + 296.1574488526*t)
	X1 += 0.00000003253*np.cos(2.44863579444 + 485.9288551643*t)
	X1 += 0.00000003708*np.cos(3.41997179462 + 67.8804998876*t)
	X1 += 0.00000003138*np.cos(5.35146333173 + 347.3631741838*t)
	X1 += 0.00000003111*np.cos(1.23256444922 + 1014.1353475506*t)
	X1 += 0.00000003273*np.cos(0.62821512161 + 67.3592350258*t)
	X1 += 0.00000003075*np.cos(3.24417591182 + 392.6579409322*t)
	X1 += 0.00000003139*np.cos(4.67078123701 + 159.1244246902*t)
	X1 += 0.00000003466*np.cos(1.90283209224 + 2145.5905633214*t)
	X1 += 0.00000003286*np.cos(3.39700457012 + 435.1962105851*t)
	X1 += 0.00000003365*np.cos(5.23578168473 + 480.251596762*t)
	X1 += 0.00000003226*np.cos(0.77463438425 + 104.0077979553*t)
	X1 += 0.00000003004*np.cos(3.95534262032 + 1055.1891444952*t)
	X1 += 0.00000003610*np.cos(3.04477218983 + 54.8078101942*t)
	X1 += 0.00000003307*np.cos(0.01423748255 + 215.4379594521*t)
	X1 += 0.00000002940*np.cos(4.36795909810 + 385.4962098216*t)
	X1 += 0.00000003945*np.cos(2.79969659377 + 59.2824801785*t)
	X1 += 0.00000002968*np.cos(2.85170581645 + 613.070583371*t)
	X1 += 0.00000003097*np.cos(0.90779595391 + 1471.7530270636*t)
	X1 += 0.00000003097*np.cos(2.85041412828 + 1395.486955788*t)
	X1 += 0.00000003954*np.cos(3.86301765432 + 113.1270825262*t)
	X1 += 0.00000003013*np.cos(3.06603983213 + 120.9913890524*t)
	X1 += 0.00000003254*np.cos(1.06070967217 + 26.826702943*t)
	X1 += 0.00000003015*np.cos(4.16456065382 + 180.7951340927*t)
	X1 += 0.00000003195*np.cos(1.29465154302 + 53.653405886*t)
	X1 += 0.00000002827*np.cos(1.93939794239 + 429.5671362926*t)
	X1 += 0.00000003348*np.cos(5.12244556536 + 6284.5603226997*t)
	X1 += 0.00000003192*np.cos(3.12235363786 + 659.6104422562*t)
	X1 += 0.00000002884*np.cos(0.87269814613 + 384.2723695442*t)
	X1 += 0.00000002760*np.cos(5.94996539141 + 151.0476698429*t)
	X1 += 0.00000002825*np.cos(2.88754308804 + 222.8603229936*t)
	X1 += 0.00000003228*np.cos(0.42456565829 + 52.3601296394*t)
	X1 += 0.00000003229*np.cos(1.43633693191 + 1050.9963588012*t)
	X1 += 0.00000002969*np.cos(4.62299601646 + 494.4786907636*t)
	X1 += 0.00000003293*np.cos(4.55907332992 + 389.9496279465*t)
	X1 += 0.00000003021*np.cos(1.39291744542 + 328.3525936572*t)
	X1 += 0.00000002728*np.cos(2.36980566306 + 432.2272651685*t)
	X1 += 0.00000003171*np.cos(0.25949973316 + 10214.7700189193*t)
	X1 += 0.00000002674*np.cos(0.72178755844 + 158.3736651648*t)
	X1 += 0.00000002900*np.cos(5.80036387854 + 559.2259810233*t)
	X1 += 0.00000002631*np.cos(5.78145236431 + 2008.557539159*t)
	X1 += 0.00000002746*np.cos(2.70236789350 + 326.4261779642*t)
	X1 += 0.00000002613*np.cos(1.03972751145 + 181.7583419392*t)
	X1 += 0.00000002578*np.cos(0.39826319336 + 395.578702239*t)
	X1 += 0.00000002972*np.cos(5.82390511647 + 986.0848043302*t)
	X1 += 0.00000002889*np.cos(3.27140995337 + 493.0424021651*t)
	X1 += 0.00000003058*np.cos(1.52176908977 + 6281.5913772831*t)
	X1 += 0.00000002662*np.cos(5.96768311032 + 77.2292791221*t)
	X1 += 0.00000002851*np.cos(4.47719750517 + 186.472392495*t)
	X1 += 0.00000002597*np.cos(2.61768111732 + 10213.285546211*t)
	X1 += 0.00000003036*np.cos(0.45935275351 + 947.9517686924*t)
	X1 += 0.00000002545*np.cos(1.75453755938 + 135.5485514541*t)
	X1 += 0.00000002832*np.cos(4.50108476662 + 419.7452763061*t)
	X1 += 0.00000002876*np.cos(2.10216025772 + 844.810810364*t)
	X1 += 0.00000003317*np.cos(1.96174488177 + 500.1559491659*t)
	X1 += 0.00000002633*np.cos(4.56986397211 + 351.8165923087*t)
	X1 += 0.00000003228*np.cos(0.62756457944 + 23.9059416362*t)
	X1 += 0.00000003031*np.cos(4.13021586758 + 406.1031376411*t)
	X1 += 0.00000002905*np.cos(5.28583709714 + 573.4530750249*t)
	X1 += 0.00000002821*np.cos(2.57918372241 + 830.5837163624*t)
	X1 += 0.00000003321*np.cos(2.30535884361 + 450.2435000813*t)
	X1 += 0.00000003117*np.cos(3.17172825469 + 457.5694954032*t)
	X1 += 0.00000002905*np.cos(2.94721635384 + 10211.8010735027*t)
	X1 += 0.00000002523*np.cos(1.58172967198 + 647.0108333148*t)
	X1 += 0.00000002459*np.cos(2.17148212862 + 450.9772132642*t)
	X1 += 0.00000002634*np.cos(1.77671637215 + 946.4672959841*t)
	X1 += 0.00000002454*np.cos(4.84991028942 + 195.7729876197*t)
	X1 += 0.00000002649*np.cos(2.48860749245 + 425.3743505986*t)
	X1 += 0.00000002388*np.cos(0.63742146004 + 149.5631971346*t)
	X1 += 0.00000002552*np.cos(1.80363120718 + 1062.5633239269*t)
	X1 += 0.00000003008*np.cos(0.87346015647 + 255.0554677982*t)
	X1 += 0.00000002387*np.cos(3.61269624808 + 654.1243803156*t)
	X1 += 0.00000002439*np.cos(6.16956725964 + 462.9861213746*t)
	X1 += 0.00000002496*np.cos(4.85342512068 + 147.1155165798*t)
	X1 += 0.00000002382*np.cos(1.69880476699 + 176.6505325085*t)
	X1 += 0.00000002542*np.cos(2.61921706713 + 481.4754370394*t)
	X1 += 0.00000002365*np.cos(4.31555837151 + 107.2855599126*t)
	X1 += 0.00000002440*np.cos(2.91303067806 + 525.2375469697*t)
	X1 += 0.00000002469*np.cos(3.87144882031 + 707.7777862016*t)
	X1 += 0.00000003120*np.cos(5.91740925150 + 456.6062875567*t)
	X1 += 0.00000002587*np.cos(0.02225757299 + 401.0647641796*t)
	X1 += 0.00000002364*np.cos(3.05940926328 + 562.1467423301*t)
	X1 += 0.00000002464*np.cos(3.73409380833 + 141.4864422873*t)
	X1 += 0.00000002261*np.cos(4.82065961888 + 644.090072008*t)
	X1 += 0.00000002305*np.cos(4.50071607030 + 103.3534066495*t)
	X1 += 0.00000002890*np.cos(3.55796481313 + 834.7765020564*t)
	X1 += 0.00000002896*np.cos(2.29071785178 + 1685.0521225016*t)
	X1 += 0.00000002247*np.cos(1.68393756499 + 172.1971143836*t)
	X1 += 0.00000003162*np.cos(3.56274388676 + 594.6507036754*t)
	X1 += 0.00000002330*np.cos(5.29361089740 + 118.0224436358*t)
	X1 += 0.00000002303*np.cos(4.39822090888 + 2080.6308247406*t)
	X1 += 0.00000002845*np.cos(4.98553259670 + 216.9224321604*t)
	X1 += 0.00000002249*np.cos(0.46641290866 + 381.3516082374*t)
	X1 += 0.00000002388*np.cos(5.32433039951 + 598.8434893694*t)
	X1 += 0.00000002325*np.cos(4.96634833764 + 443.1299530805*t)
	X1 += 0.00000002406*np.cos(0.99201934800 + 248.4631856592*t)
	X1 += 0.00000002550*np.cos(3.02131610984 + 186.2117600641*t)
	X1 += 0.00000002494*np.cos(5.74497783529 + 457.617679513*t)
	X1 += 0.00000002233*np.cos(5.94425595046 + 709.0498105888*t)
	X1 += 0.00000002338*np.cos(4.30382783057 + 210.3301500214*t)
	X1 += 0.00000002661*np.cos(0.55742494786 + 313.6835566709*t)
	X1 += 0.00000002261*np.cos(3.67500719544 + 29.7474642498*t)
	X1 += 0.00000002581*np.cos(1.20121862874 + 134.1122628556*t)
	X1 += 0.00000002300*np.cos(0.62755528396 + 986.2972526513*t)
	X1 += 0.00000002201*np.cos(2.78496364835 + 605.9570363702*t)
	X1 += 0.00000002160*np.cos(0.97578185075 + 666.723989257*t)
	X1 += 0.00000002601*np.cos(2.58714323338 + 363.5166838784*t)
	X1 += 0.00000002510*np.cos(3.00871814837 + 411.147256597*t)
	return X1*t




def Neptune_X2 (t): # 83 terms of order 2

	X2 = 0.
	X2 += 0.00005415923
	X2 += 0.00004536283*np.cos(5.02700751836 + 36.6485629295*t)
	X2 += 0.00004350766*np.cos(2.45420254304 + 39.6175083461*t)
	X2 += 0.00003092965*np.cos(0.62250463031 + 38.1330356378*t)
	X2 += 0.00002163703*np.cos(1.79218168368 + 76.2660712756*t)
	X2 += 0.00000390868*np.cos(5.67643483980 + 35.1640902212*t)
	X2 += 0.00000301339*np.cos(1.81737258860 + 41.1019810544*t)
	X2 += 0.00000204562*np.cos(2.46637556893 + 2.9689454166*t)
	X2 += 0.00000114478*np.cos(0.05970217764 + 35.685355083*t)
	X2 += 0.00000105947*np.cos(1.13935993640 + 40.5807161926*t)
	X2 += 0.00000058848*np.cos(0.36832119544 + 33.6796175129*t)
	X2 += 0.00000075617*np.cos(5.00631742776 + 73.297125859*t)
	X2 += 0.00000042438*np.cos(1.72858209444 + 4.4534181249*t)
	X2 += 0.00000038264*np.cos(0.89872407937 + 42.5864537627*t)
	X2 += 0.00000036749*np.cos(3.24065406410 + 74.7815985673*t)
	X2 += 0.00000035530*np.cos(6.14443151264 + 98.8999885246*t)
	X2 += 0.00000035469*np.cos(2.49879881601 + 31.019488637*t)
	X2 += 0.00000031377*np.cos(3.39614780530 + 28.5718080822*t)
	X2 += 0.00000029746*np.cos(4.97662789524 + 45.2465826386*t)
	X2 += 0.00000033708*np.cos(0.17905425482 + 114.3991069134*t)
	X2 += 0.00000024149*np.cos(4.08389627261 + 47.6942631934*t)
	X2 += 0.00000022345*np.cos(1.66756805038 + 7.1135470008*t)
	X2 += 0.00000013387*np.cos(5.67702783503 + 71.8126531507*t)
	X2 += 0.00000013244*np.cos(6.12117040896 + 60.7669528868*t)
	X2 += 0.00000010889*np.cos(6.06268907903 + 33.9402499438*t)
	X2 += 0.00000009255*np.cos(1.47588015526 + 42.3258213318*t)
	X2 += 0.00000009574*np.cos(5.80039438832 + 69.1525242748*t)
	X2 += 0.00000007182*np.cos(1.45190405642 + 32.1951448046*t)
	X2 += 0.00000006548*np.cos(2.27346931818 + 30.0562807905*t)
	X2 += 0.00000006676*np.cos(4.85540898830 + 258.5456780766*t)
	X2 += 0.00000005636*np.cos(6.20411302010 + 8.0767548473*t)
	X2 += 0.00000007261*np.cos(0.17295213925 + 1097.514965827*t)
	X2 += 0.00000005245*np.cos(6.05612030557 + 44.070926471*t)
	X2 += 0.00000005419*np.cos(1.81242809053 + 106.0135355254*t)
	X2 += 0.00000005082*np.cos(5.15938723406 + 46.2097904851*t)
	X2 += 0.00000004497*np.cos(1.00605030530 + 77.7505439839*t)
	X2 += 0.00000004688*np.cos(2.52139140874 + 221.8971151471*t)
	X2 += 0.00000005379*np.cos(5.86338428053 + 22.633917249*t)
	X2 += 0.00000004607*np.cos(4.89101822521 + 549.4041210368*t)
	X2 += 0.00000004257*np.cos(5.51428448379 + 204.7010757289*t)
	X2 += 0.00000003916*np.cos(0.21419237233 + 207.6700211455*t)
	X2 += 0.00000004041*np.cos(4.96590021637 + 305.0855369618*t)
	X2 += 0.00000003733*np.cos(1.01856203412 + 319.3126309634*t)
	X2 += 0.00000004831*np.cos(1.26416720319 + 214.7835681463*t)
	X2 += 0.00000003396*np.cos(2.79106131830 + 357.4456666012*t)
	X2 += 0.00000004181*np.cos(2.68977197250 + 944.9828232758*t)
	X2 += 0.00000003288*np.cos(1.44958811131 + 408.1783111804*t)
	X2 += 0.00000003252*np.cos(3.23869149834 + 129.9194771616*t)
	X2 += 0.00000003340*np.cos(0.65707077966 + 531.1754378029*t)
	X2 += 0.00000003932*np.cos(3.66246303483 + 91.7864415238*t)
	X2 += 0.00000003032*np.cos(3.12518020583 + 536.8045120954*t)
	X2 += 0.00000004202*np.cos(6.23259715436 + 312.1990839626*t)
	X2 += 0.00000002967*np.cos(1.04477632375 + 860.3099287528*t)
	X2 += 0.00000003232*np.cos(6.17114444671 + 381.3516082374*t)
	X2 += 0.00000003974*np.cos(2.04911285469 + 336.1050255988*t)
	X2 += 0.00000002824*np.cos(0.97334571055 + 666.723989257*t)
	X2 += 0.00000002892*np.cos(2.20180750253 + 395.578702239*t)
	X2 += 0.00000003008*np.cos(0.14288636846 + 343.2185725996*t)
	X2 += 0.00000002897*np.cos(4.88154449805 + 529.6909650946*t)
	X2 += 0.00000002999*np.cos(1.27873117021 + 937.869276275*t)
	X2 += 0.00000002700*np.cos(1.72730755228 + 274.0660483248*t)
	X2 += 0.00000003346*np.cos(4.64302623913 + 1162.4747044078*t)
	X2 += 0.00000002937*np.cos(1.58157160137 + 235.933012687*t)
	X2 += 0.00000002582*np.cos(0.48526698652 + 1073.6090241908*t)
	X2 += 0.00000002698*np.cos(1.69470540963 + 1014.1353475506*t)
	X2 += 0.00000002525*np.cos(6.16854621620 + 26.826702943*t)
	X2 += 0.00000002542*np.cos(4.22296666068 + 1265.5674786264*t)
	X2 += 0.00000002750*np.cos(1.76657551757 + 563.6312150384*t)
	X2 += 0.00000002684*np.cos(5.74017908638 + 454.9093665273*t)
	X2 += 0.00000002503*np.cos(0.34100010690 + 425.1137181677*t)
	X2 += 0.00000002430*np.cos(1.71657698790 + 453.424893819*t)
	X2 += 0.00000002617*np.cos(5.33445521302 + 952.0963702766*t)
	X2 += 0.00000002548*np.cos(2.04428426743 + 990.2294059144*t)
	X2 += 0.00000002948*np.cos(2.96095474902 + 149.5631971346*t)
	X2 += 0.00000003247*np.cos(5.53464063966 + 532.8723588323*t)
	X2 += 0.00000002343*np.cos(1.93598481849 + 981.6313862053*t)
	X2 += 0.00000002501*np.cos(1.67413189665 + 669.6447505638*t)
	X2 += 0.00000003183*np.cos(5.08887587731 + 526.5095713569*t)
	X2 += 0.00000002637*np.cos(5.26103624829 + 175.1660598002*t)
	X2 += 0.00000002481*np.cos(5.56753943853 + 655.4176565622*t)
	X2 += 0.00000002569*np.cos(4.22624598741 + 464.7312265138*t)
	X2 += 0.00000002273*np.cos(5.59760233612 + 491.5579294568*t)
	X2 += 0.00000002790*np.cos(1.90430778774 + 487.3651437628*t)
	return X2*t*t




def Neptune_X3 (t): # 27 terms of order 3

	X3 = 0.
	X3 += 0.00000192703*np.cos(0.83849647680 + 36.6485629295*t)
	X3 += 0.00000182218*np.cos(0.36067577276 + 39.6175083461*t)
	X3 += 0.00000182887
	X3 += 0.00000131073*np.cos(3.72972175765 + 38.1330356378*t)
	X3 += 0.00000085922*np.cos(0.42809925886 + 76.2660712756*t)
	X3 += 0.00000021976*np.cos(1.93069967198 + 35.1640902212*t)
	X3 += 0.00000019807*np.cos(5.55148029927 + 41.1019810544*t)
	X3 += 0.00000014731*np.cos(0.03027459708 + 7.1135470008*t)
	X3 += 0.00000006772*np.cos(1.19678873353 + 69.1525242748*t)
	X3 += 0.00000004517*np.cos(3.28893171686 + 45.2465826386*t)
	X3 += 0.00000004523*np.cos(4.18701361894 + 31.019488637*t)
	X3 += 0.00000003656*np.cos(0.60147675763 + 968.888764912*t)
	X3 += 0.00000003608*np.cos(1.40249586983 + 98.8999885246*t)
	X3 += 0.00000003303*np.cos(2.07889949921 + 498.6714764576*t)
	X3 += 0.00000003199*np.cos(1.67328032210 + 1519.920371009*t)
	X3 += 0.00000003498*np.cos(3.27477583513 + 408.1783111804*t)
	X3 += 0.00000003304*np.cos(2.24746558473 + 422.405405182*t)
	X3 += 0.00000002689*np.cos(0.89931829838 + 440.8252848776*t)
	X3 += 0.00000002639*np.cos(0.45729158440 + 305.0855369618*t)
	X3 += 0.00000002646*np.cos(5.61686631803 + 462.0229135281*t)
	X3 += 0.00000002542*np.cos(5.76347988377 + 444.8268741099*t)
	X3 += 0.00000002473*np.cos(5.63336776666 + 319.3126309634*t)
	X3 += 0.00000002357*np.cos(0.46206172917 + 447.7958195265*t)
	X3 += 0.00000002875*np.cos(5.22512426905 + 853.196381752*t)
	X3 += 0.00000002279*np.cos(4.63710471266 + 459.0539681115*t)
	X3 += 0.00000003062*np.cos(3.11781513902 + 484.444382456*t)
	X3 += 0.00000002147*np.cos(2.63610173419 + 175.1660598002*t)
	return X3*t*t*t




def Neptune_X4 (t): # 5 terms of order 4

	X4 = 0.
	X4 += 0.00000004229*np.cos(1.43244844928 + 515.463871093*t)
	X4 += 0.00000004334*np.cos(5.41647101628 + 433.7117378768*t)
	X4 += 0.00000003547*np.cos(5.75562173057 + 990.2294059144*t)
	X4 += 0.00000003155*np.cos(4.85323856001 + 467.6519878206*t)
	X4 += 0.00000002587*np.cos(0.06465867421 + 227.5261894396*t)
	return X4*t*t*t*t




def Neptune_X5 (t): # 1 term of order 5

	X5 = 0.
	X5 += 0.00000000000
	return X5*t*t*t*t*t




def Neptune_Y0 (t): # 693 terms of order 0

	Y0 = 0.
	Y0 += 30.05900907352*np.cos(3.74086294715 + 38.1330356378*t)
	Y0 -= 0.30171988148
	Y0 += 0.13505308635*np.cos(1.92949466968 + 76.2660712756*t)
	Y0 += 0.15705776296*np.cos(4.82539969469 + 36.6485629295*t)
	Y0 += 0.14935398681*np.cos(5.79694896309 + 39.6175083461*t)
	Y0 += 0.02584389323*np.cos(0.42549727257 + 1.4844727083*t)
	Y0 += 0.00990408083*np.cos(3.80555424385 + 74.7815985673*t)
	Y0 += 0.00815165481*np.cos(5.49429738442 + 2.9689454166*t)
	Y0 += 0.00582164520*np.cos(6.19633859980 + 35.1640902212*t)
	Y0 += 0.00565547830*np.cos(4.41843013268 + 41.1019810544*t)
	Y0 += 0.00305149662*np.cos(5.11023952334 + 73.297125859*t)
	Y0 += 0.00135911904*np.cos(3.97565894083 + 77.7505439839*t)
	Y0 += 0.00090966163*np.cos(0.11783850542 + 114.3991069134*t)
	Y0 += 0.00068788416*np.cos(4.26391987401 + 4.4534181249*t)
	Y0 += 0.00028891942*np.cos(3.21848982783 + 42.5864537627*t)
	Y0 += 0.00020079747*np.cos(1.19788749777 + 33.6796175129*t)
	Y0 += 0.00012613423*np.cos(1.99783010734 + 112.9146342051*t)
	Y0 += 0.00012822727*np.cos(1.16749515319 + 111.4301614968*t)
	Y0 += 0.00008768580*np.cos(3.23487156950 + 108.4612160802*t)
	Y0 += 0.00006439265*np.cos(3.05453259951 + 5.9378908332*t)
	Y0 += 0.00005316026*np.cos(0.78719997386 + 71.8126531507*t)
	Y0 += 0.00004650708*np.cos(4.81540983294 + 37.611770776*t)
	Y0 += 0.00004734186*np.cos(2.52644981654 + 79.2350166922*t)
	Y0 += 0.00004557247*np.cos(5.80951552318 + 38.6543004996*t)
	Y0 += 0.00004322550*np.cos(0.80665145881 + 38.084851528*t)
	Y0 += 0.00004315539*np.cos(3.53393506841 + 38.1812197476*t)
	Y0 += 0.00004089036*np.cos(0.42349446479 + 37.1698277913*t)
	Y0 += 0.00004247643*np.cos(4.06355336504 + 28.5718080822*t)
	Y0 += 0.00003932515*np.cos(3.91607592815 + 39.0962434843*t)
	Y0 += 0.00003930135*np.cos(3.86614178174 + 98.8999885246*t)
	Y0 += 0.00003323991*np.cos(3.11674274385 + 4.192785694*t)
	Y0 += 0.00003112636*np.cos(0.27319642944 + 47.6942631934*t)
	Y0 += 0.00003373281*np.cos(3.39616255650 + 145.1097790097*t)
	Y0 += 0.00002668054*np.cos(2.31251521781 + 109.9456887885*t)
	Y0 += 0.00002523042*np.cos(6.23400745185 + 312.1990839626*t)
	Y0 += 0.00001888827*np.cos(1.63364331324 + 35.685355083*t)
	Y0 += 0.00001647474*np.cos(2.50010254963 + 30.0562807905*t)
	Y0 += 0.00001826390*np.cos(2.00938305966 + 44.070926471*t)
	Y0 += 0.00001681258*np.cos(2.70480318579 + 40.5807161926*t)
	Y0 += 0.00001533383*np.cos(5.88971113590 + 38.0211610532*t)
	Y0 += 0.00001527526*np.cos(4.73412534395 + 38.2449102224*t)
	Y0 += 0.00002058823*np.cos(4.38545017091 + 137.0330241624*t)
	Y0 += 0.00001720954*np.cos(4.49400805134 + 106.9767433719*t)
	Y0 += 0.00001314116*np.cos(1.80386443362 + 46.2097904851*t)
	Y0 += 0.00001731599*np.cos(4.14499314089 + 70.3281804424*t)
	Y0 += 0.00001559193*np.cos(5.27114846878 + 37.8724032069*t)
	Y0 += 0.00001545705*np.cos(5.35267669439 + 38.3936680687*t)
	Y0 += 0.00001242929*np.cos(1.10242173566 + 33.9402499438*t)
	Y0 += 0.00001388024*np.cos(2.14792830412 + 115.8835796217*t)
	Y0 += 0.00001467042*np.cos(3.56226463770 + 181.7583419392*t)
	Y0 += 0.00001227926*np.cos(1.21334651843 + 72.0732855816*t)
	Y0 += 0.00001080807*np.cos(3.18401661435 + 42.3258213318*t)
	Y0 += 0.00001111708*np.cos(5.51669920239 + 8.0767548473*t)
	Y0 += 0.00001173918*np.cos(1.08646707548 + 148.0787244263*t)
	Y0 += 0.00000720856*np.cos(4.59836049727 + 152.5321425512*t)
	Y0 += 0.00000608825*np.cos(2.92430662163 + 35.212274331*t)
	Y0 += 0.00000730763*np.cos(4.66633801542 + 143.6253063014*t)
	Y0 += 0.00000631807*np.cos(1.84632009649 + 7.4223635415*t)
	Y0 += 0.00000553106*np.cos(1.41499357343 + 41.0537969446*t)
	Y0 += 0.00000685011*np.cos(3.73017585433 + 218.4069048687*t)
	Y0 += 0.00000463231*np.cos(1.17324835377 + 31.5407534988*t)
	Y0 += 0.00000515088*np.cos(1.92209565801 + 0.9632078465*t)
	Y0 += 0.00000390093*np.cos(0.79231945944 + 6.592282139*t)
	Y0 += 0.00000409853*np.cos(3.60235870480 + 7.1135470008*t)
	Y0 += 0.00000349284*np.cos(4.32031199243 + 60.7669528868*t)
	Y0 += 0.00000454486*np.cos(5.59238815601 + 213.299095438*t)
	Y0 += 0.00000321807*np.cos(3.29433287410 + 44.7253177768*t)
	Y0 += 0.00000349862*np.cos(0.19787949770 + 0.5212648618*t)
	Y0 += 0.00000393916*np.cos(3.78100833011 + 31.019488637*t)
	Y0 += 0.00000349029*np.cos(4.83858968730 + 180.2738692309*t)
	Y0 += 0.00000343010*np.cos(5.48051962983 + 68.8437077341*t)
	Y0 += 0.00000382160*np.cos(1.78928133965 + 487.3651437628*t)
	Y0 += 0.00000294995*np.cos(3.61077261532 + 84.3428261229*t)
	Y0 += 0.00000336173*np.cos(0.57726127805 + 45.2465826386*t)
	Y0 += 0.00000257398*np.cos(4.11483645770 + 32.1951448046*t)
	Y0 += 0.00000334170*np.cos(3.90094190194 + 255.0554677982*t)
	Y0 += 0.00000268060*np.cos(1.73772593259 + 36.7604375141*t)
	Y0 += 0.00000225831*np.cos(5.46176539310 + 149.5631971346*t)
	Y0 += 0.00000317150*np.cos(1.14704440253 + 388.4651552382*t)
	Y0 += 0.00000264760*np.cos(2.55644401603 + 39.5056337615*t)
	Y0 += 0.00000227226*np.cos(6.16115950447 + 274.0660483248*t)
	Y0 += 0.00000285525*np.cos(1.78929303289 + 12.5301729722*t)
	Y0 += 0.00000249102*np.cos(5.73547996252 + 105.4922706636*t)
	Y0 += 0.00000252180*np.cos(5.24389175498 + 27.0873353739*t)
	Y0 += 0.00000242394*np.cos(0.49323094252 + 14.0146456805*t)
	Y0 += 0.00000226119*np.cos(1.26707727523 + 80.7194894005*t)
	Y0 += 0.00000265738*np.cos(5.67029686231 + 944.9828232758*t)
	Y0 += 0.00000190279*np.cos(0.75836937752 + 69.1525242748*t)
	Y0 += 0.00000202599*np.cos(2.17083509018 + 415.2918581812*t)
	Y0 += 0.00000188731*np.cos(2.54330566064 + 146.594251718*t)
	Y0 += 0.00000176465*np.cos(4.85970219043 + 36.5366883449*t)
	Y0 += 0.00000184011*np.cos(3.15845741611 + 11.0457002639*t)
	Y0 += 0.00000202771*np.cos(4.96195983984 + 175.1660598002*t)
	Y0 += 0.00000175209*np.cos(5.83814563218 + 39.7293829307*t)
	Y0 += 0.00000178926*np.cos(5.00860456688 + 216.9224321604*t)
	Y0 += 0.00000142340*np.cos(3.85429789127 + 75.7448064138*t)
	Y0 += 0.00000152465*np.cos(0.17890470659 + 30.7106720963*t)
	Y0 += 0.00000121226*np.cos(3.53504657259 + 37.9205873167*t)
	Y0 += 0.00000129049*np.cos(2.23605298372 + 36.8610112506*t)
	Y0 += 0.00000120580*np.cos(0.82135679727 + 38.3454839589*t)
	Y0 += 0.00000168916*np.cos(4.06766309411 + 291.7040307277*t)
	Y0 += 0.00000121139*np.cos(6.20886903488 + 33.0252262071*t)
	Y0 += 0.00000129291*np.cos(0.79819261590 + 45.5553991793*t)
	Y0 += 0.00000144727*np.cos(5.34205062943 + 49.1787359017*t)
	Y0 += 0.00000140927*np.cos(3.81630631334 + 62.2514255951*t)
	Y0 += 0.00000122915*np.cos(2.10353868683 + 39.405060025*t)
	Y0 += 0.00000154987*np.cos(0.18057956757 + 77.2292791221*t)
	Y0 += 0.00000141907*np.cos(2.54889093491 + 63.7358983034*t)
	Y0 += 0.00000106636*np.cos(2.14652349217 + 5.1078094307*t)
	Y0 += 0.00000136858*np.cos(0.31000643808 + 151.0476698429*t)
	Y0 += 0.00000127651*np.cos(1.61797740136 + 24.1183899573*t)
	Y0 += 0.00000103774*np.cos(5.23985408179 + 82.8583534146*t)
	Y0 += 0.00000103541*np.cos(3.68555193560 + 40.8413486235*t)
	Y0 += 0.00000104338*np.cos(0.71903696521 + 35.4247226521*t)
	Y0 += 0.00000112775*np.cos(5.91862646573 + 142.1408335931*t)
	Y0 += 0.00000085104*np.cos(3.21938618950 + 36.4361146084*t)
	Y0 += 0.00000084714*np.cos(1.24083880355 + 106.0135355254*t)
	Y0 += 0.00000080200*np.cos(1.12120105955 + 39.8299566672*t)
	Y0 += 0.00000080651*np.cos(4.46119779414 + 43.2408450685*t)
	Y0 += 0.00000095561*np.cos(5.17989417251 + 253.5709950899*t)
	Y0 += 0.00000086636*np.cos(1.72075571690 + 32.7164096664*t)
	Y0 += 0.00000089108*np.cos(1.19110769467 + 65.2203710117*t)
	Y0 += 0.00000072027*np.cos(4.82605488845 + 36.6967470393*t)
	Y0 += 0.00000088318*np.cos(5.41825797102 + 183.2428146475*t)
	Y0 += 0.00000098752*np.cos(4.10402325327 + 453.424893819*t)
	Y0 += 0.00000088317*np.cos(6.06004454477 + 251.4321310758*t)
	Y0 += 0.00000076684*np.cos(3.73090414964 + 5.4166259714*t)
	Y0 += 0.00000093279*np.cos(5.68894100641 + 219.891377577*t)
	Y0 += 0.00000065264*np.cos(3.45003589917 + 22.633917249*t)
	Y0 += 0.00000089782*np.cos(4.22695019307 + 328.3525936572*t)
	Y0 += 0.00000086785*np.cos(3.43022621793 + 2.9207613068*t)
	Y0 += 0.00000063401*np.cos(2.48145559824 + 66.70484372*t)
	Y0 += 0.00000065816*np.cos(6.14059953900 + 36.1272980677*t)
	Y0 += 0.00000061713*np.cos(1.59254388600 + 9.5612275556*t)
	Y0 += 0.00000070037*np.cos(2.66080141001 + 43.5496616092*t)
	Y0 += 0.00000079478*np.cos(1.84510198490 + 97.4155158163*t)
	Y0 += 0.00000078248*np.cos(2.49403717232 + 2.4476805548*t)
	Y0 += 0.00000062933*np.cos(0.64057863200 + 8.9068362498*t)
	Y0 += 0.00000073954*np.cos(3.98099646145 + 2.7083129857*t)
	Y0 += 0.00000066880*np.cos(2.36643058062 + 6.9010986797*t)
	Y0 += 0.00000071436*np.cos(3.63061707587 + 662.531203563*t)
	Y0 += 0.00000050999*np.cos(6.24103150567 + 81.3738807063*t)
	Y0 += 0.00000057112*np.cos(5.59708369933 + 15.4991183888*t)
	Y0 += 0.00000050175*np.cos(5.79472499755 + 36.9091953604*t)
	Y0 += 0.00000056658*np.cos(6.09916963696 + 178.7893965226*t)
	Y0 += 0.00000066579*np.cos(5.88081965598 + 256.5399405065*t)
	Y0 += 0.00000049126*np.cos(5.99676989074 + 19.0105805266*t)
	Y0 += 0.00000046095*np.cos(5.61403681139 + 3.9321532631*t)
	Y0 += 0.00000049655*np.cos(0.48945385113 + 67.3592350258*t)
	Y0 += 0.00000045696*np.cos(0.60387908345 + 117.36805233*t)
	Y0 += 0.00000053146*np.cos(5.35170219678 + 290.2195580194*t)
	Y0 += 0.00000042302*np.cos(0.99480139810 + 350.3321196004*t)
	Y0 += 0.00000044133*np.cos(0.68971110137 + 32.5039613453*t)
	Y0 += 0.00000038369*np.cos(5.07841592272 + 39.3568759152*t)
	Y0 += 0.00000037226*np.cos(1.76949738974 + 449.232108125*t)
	Y0 += 0.00000047967*np.cos(1.20644576657 + 184.7272873558*t)
	Y0 += 0.00000049103*np.cos(4.38398749958 + 365.0011565867*t)
	Y0 += 0.00000038213*np.cos(4.99269256462 + 75.3028634291*t)
	Y0 += 0.00000038164*np.cos(3.66287288490 + 43.7621099303*t)
	Y0 += 0.00000042228*np.cos(4.07611308238 + 76.7873361374*t)
	Y0 += 0.00000039999*np.cos(5.33062554241 + 525.4981794006*t)
	Y0 += 0.00000033451*np.cos(4.52176861027 + 85.8272988312*t)
	Y0 += 0.00000035247*np.cos(4.92005791007 + 34.5096989154*t)
	Y0 += 0.00000034352*np.cos(5.79528055074 + 33.4671691918*t)
	Y0 += 0.00000034934*np.cos(3.58611441149 + 3.6233367224*t)
	Y0 += 0.00000043747*np.cos(0.65030388705 + 1021.2488945514*t)
	Y0 += 0.00000044835*np.cos(5.29523477413 + 529.6909650946*t)
	Y0 += 0.00000042770*np.cos(4.64750259870 + 221.3758502853*t)
	Y0 += 0.00000042143*np.cos(4.16070477408 + 310.7146112543*t)
	Y0 += 0.00000031032*np.cos(3.07192392014 + 34.2008823747*t)
	Y0 += 0.00000038644*np.cos(0.74635128857 + 50.66320861*t)
	Y0 += 0.00000043440*np.cos(6.05926343808 + 293.188503436*t)
	Y0 += 0.00000039137*np.cos(1.18677641846 + 17.5261078183*t)
	Y0 += 0.00000038296*np.cos(0.74146003376 + 78.7137518304*t)
	Y0 += 0.00000042792*np.cos(2.99005867070 + 563.6312150384*t)
	Y0 += 0.00000038592*np.cos(5.03144247012 + 5.6772584023*t)
	Y0 += 0.00000036104*np.cos(3.26215719500 + 305.0855369618*t)
	Y0 += 0.00000031916*np.cos(3.07583047003 + 100.3844612329*t)
	Y0 += 0.00000038880*np.cos(1.72301566300 + 76.3142553854*t)
	Y0 += 0.00000034218*np.cos(6.05031588107 + 319.3126309634*t)
	Y0 += 0.00000032863*np.cos(0.86693212611 + 91.7864415238*t)
	Y0 += 0.00000038880*np.cos(5.27893548994 + 76.2178871658*t)
	Y0 += 0.00000030115*np.cos(0.56768748627 + 70.8494453042*t)
	Y0 += 0.00000035779*np.cos(5.16217379760 + 313.6835566709*t)
	Y0 += 0.00000028459*np.cos(4.82537701506 + 42.7989020838*t)
	Y0 += 0.00000029235*np.cos(0.69125716429 + 104.0077979553*t)
	Y0 += 0.00000026519*np.cos(4.63186876706 + 57.255490749*t)
	Y0 += 0.00000028574*np.cos(6.23007121275 + 215.4379594521*t)
	Y0 += 0.00000025169*np.cos(5.68190155068 + 41.7563723602*t)
	Y0 += 0.00000024722*np.cos(0.61246284145 + 67.8804998876*t)
	Y0 += 0.00000031275*np.cos(2.53634049089 + 21.9795259432*t)
	Y0 += 0.00000030924*np.cos(4.82038266230 + 258.0244132148*t)
	Y0 += 0.00000027750*np.cos(0.78341232060 + 20.4950532349*t)
	Y0 += 0.00000025867*np.cos(1.45419307115 + 29.226199388*t)
	Y0 += 0.00000022617*np.cos(1.89172143712 + 36.6003788197*t)
	Y0 += 0.00000027381*np.cos(5.53374987736 + 326.8681209489*t)
	Y0 += 0.00000027996*np.cos(1.26059646108 + 11.3063326948*t)
	Y0 += 0.00000022661*np.cos(2.67324352863 + 35.2759648058*t)
	Y0 += 0.00000023105*np.cos(1.02789421532 + 68.1893164283*t)
	Y0 += 0.00000021423*np.cos(5.59061648306 + 39.6656924559*t)
	Y0 += 0.00000023857*np.cos(1.12720373626 + 79.1868325824*t)
	Y0 += 0.00000024878*np.cos(5.05248618384 + 186.2117600641*t)
	Y0 += 0.00000022482*np.cos(5.43588448434 + 39.5693242363*t)
	Y0 += 0.00000020858*np.cos(1.66497743007 + 40.9901064698*t)
	Y0 += 0.00000020327*np.cos(4.75570383217 + 37.478644332*t)
	Y0 += 0.00000020327*np.cos(5.86806874135 + 38.7874269436*t)
	Y0 += 0.00000020347*np.cos(1.57461185465 + 79.889407998*t)
	Y0 += 0.00000026742*np.cos(2.06777516870 + 69.3649725959*t)
	Y0 += 0.00000026150*np.cos(4.54647431825 + 401.6497195162*t)
	Y0 += 0.00000026622*np.cos(6.23032651920 + 329.8370663655*t)
	Y0 += 0.00000024533*np.cos(2.43312465982 + 135.5485514541*t)
	Y0 += 0.00000020394*np.cos(4.71453634367 + 25.6028626656*t)
	Y0 += 0.00000017358*np.cos(2.96107862647 + 19.1224551112*t)
	Y0 += 0.00000022708*np.cos(0.96197477786 + 1436.5407527326*t)
	Y0 += 0.00000019425*np.cos(1.39256956278 + 129.9194771616*t)
	Y0 += 0.00000017267*np.cos(5.46335597919 + 8.385571388*t)
	Y0 += 0.00000016188*np.cos(1.00277158426 + 37.4998961914*t)
	Y0 += 0.00000016188*np.cos(3.33781568208 + 38.7661750842*t)
	Y0 += 0.00000020858*np.cos(3.10425163550 + 58.7399634573*t)
	Y0 += 0.00000015707*np.cos(3.50343459132 + 76.0054388447*t)
	Y0 += 0.00000015770*np.cos(0.31796217276 + 154.0166152595*t)
	Y0 += 0.00000018916*np.cos(3.89922376406 + 40.1387732079*t)
	Y0 += 0.00000020217*np.cos(3.30428806071 + 138.5174968707*t)
	Y0 += 0.00000015927*np.cos(4.45409863881 + 20.6069278195*t)
	Y0 += 0.00000014928*np.cos(5.49703930308 + 33.9884340536*t)
	Y0 += 0.00000015013*np.cos(5.01721951400 + 72.3339180125*t)
	Y0 += 0.00000014368*np.cos(2.18139483772 + 64.9597385808*t)
	Y0 += 0.00000018891*np.cos(1.79248356945 + 54.2865453324*t)
	Y0 += 0.00000013971*np.cos(3.54176522468 + 76.5267037065*t)
	Y0 += 0.00000014104*np.cos(6.03208738537 + 235.933012687*t)
	Y0 += 0.00000015044*np.cos(5.68379159337 + 52.1476813183*t)
	Y0 += 0.00000017462*np.cos(0.12266713363 + 73.8183907208*t)
	Y0 += 0.00000014910*np.cos(5.51849832601 + 110.2063212194*t)
	Y0 += 0.00000015639*np.cos(5.12006925014 + 294.6729761443*t)
	Y0 += 0.00000014466*np.cos(0.20879849179 + 252.0865223816*t)
	Y0 += 0.00000012911*np.cos(5.12673316373 + 42.277637222*t)
	Y0 += 0.00000016679*np.cos(0.03644331108 + 366.485629295*t)
	Y0 += 0.00000012558*np.cos(2.35128873124 + 17.6379824029*t)
	Y0 += 0.00000015259*np.cos(5.71498593196 + 363.5166838784*t)
	Y0 += 0.00000012654*np.cos(0.78790100004 + 107.2855599126*t)
	Y0 += 0.00000014739*np.cos(6.26294958243 + 82.2039621088*t)
	Y0 += 0.00000014840*np.cos(5.34075097309 + 43.8102940401*t)
	Y0 += 0.00000013262*np.cos(0.88619404716 + 140.6563608848*t)
	Y0 += 0.00000016323*np.cos(1.14438470315 + 209.106309744*t)
	Y0 += 0.00000014786*np.cos(0.43719851869 + 73.5577582899*t)
	Y0 += 0.00000014382*np.cos(3.56047268856 + 55.7710180407*t)
	Y0 += 0.00000014984*np.cos(4.30438809136 + 144.1465711632*t)
	Y0 += 0.00000012251*np.cos(5.90062937206 + 47.0398718876*t)
	Y0 += 0.00000015703*np.cos(5.46040046735 + 837.6972633632*t)
	Y0 += 0.00000012109*np.cos(0.53062972107 + 32.7645937762*t)
	Y0 += 0.00000013513*np.cos(0.91285117036 + 700.6642392008*t)
	Y0 += 0.00000012545*np.cos(2.45122296577 + 59.2824801785*t)
	Y0 += 0.00000011481*np.cos(3.65591005670 + 38.9631170403*t)
	Y0 += 0.00000011481*np.cos(0.68467720964 + 37.3029542353*t)
	Y0 += 0.00000011450*np.cos(5.92277753697 + 529.1697002328*t)
	Y0 += 0.00000012138*np.cos(0.75939056044 + 42.0651889009*t)
	Y0 += 0.00000011369*np.cos(4.22990884648 + 491.5579294568*t)
	Y0 += 0.00000013771*np.cos(2.92318261793 + 76.3779458602*t)
	Y0 += 0.00000010515*np.cos(5.00012997140 + 29.7474642498*t)
	Y0 += 0.00000011037*np.cos(1.59367536895 + 530.2122299564*t)
	Y0 += 0.00000014023*np.cos(4.71711117819 + 438.2982824457*t)
	Y0 += 0.00000013771*np.cos(4.07876849292 + 76.154196691*t)
	Y0 += 0.00000011388*np.cos(5.82336480036 + 275.5505210331*t)
	Y0 += 0.00000013632*np.cos(1.29603623201 + 45.0341343175*t)
	Y0 += 0.00000009579*np.cos(2.83158132605 + 187.6962327724*t)
	Y0 += 0.00000010240*np.cos(1.34767092464 + 80.4588569696*t)
	Y0 += 0.00000010031*np.cos(3.80995736605 + 43.5014774994*t)
	Y0 += 0.00000009848*np.cos(4.06297078079 + 21.1494445407*t)
	Y0 += 0.00000008838*np.cos(0.60129548280 + 31.9826964835*t)
	Y0 += 0.00000010236*np.cos(1.02234093861 + 567.8240007324*t)
	Y0 += 0.00000008589*np.cos(3.55092767401 + 624.3981679252*t)
	Y0 += 0.00000008203*np.cos(1.76403717973 + 26.826702943*t)
	Y0 += 0.00000010189*np.cos(1.01906144330 + 21.4582610814*t)
	Y0 += 0.00000008398*np.cos(4.04456231507 + 377.1588225434*t)
	Y0 += 0.00000008304*np.cos(2.39003084321 + 134.0640787458*t)
	Y0 += 0.00000008411*np.cos(1.72467942701 + 65.8747623175*t)
	Y0 += 0.00000009437*np.cos(3.67779728767 + 120.9913890524*t)
	Y0 += 0.00000009161*np.cos(1.61650804237 + 168.0525127994*t)
	Y0 += 0.00000008815*np.cos(6.02934552375 + 118.0224436358*t)
	Y0 += 0.00000007463*np.cos(2.48732321090 + 906.849787638*t)
	Y0 += 0.00000008823*np.cos(5.89404127363 + 400.1652468079*t)
	Y0 += 0.00000009179*np.cos(3.20176458842 + 347.9326231554*t)
	Y0 += 0.00000008725*np.cos(0.47809414858 + 488.8496164711*t)
	Y0 += 0.00000007336*np.cos(6.05634956480 + 55.6591434561*t)
	Y0 += 0.00000007834*np.cos(0.39352619436 + 288.7350853111*t)
	Y0 += 0.00000008418*np.cos(6.19754313245 + 77.489911553*t)
	Y0 += 0.00000007503*np.cos(0.80961405135 + 601.7642506762*t)
	Y0 += 0.00000007092*np.cos(1.58410367915 + 452.9036289572*t)
	Y0 += 0.00000007051*np.cos(4.75521965029 + 107.4980082337*t)
	Y0 += 0.00000007054*np.cos(3.50385522249 + 453.9461586808*t)
	Y0 += 0.00000007892*np.cos(5.32145099179 + 331.3215390738*t)
	Y0 += 0.00000008800*np.cos(4.91519929298 + 738.7972748386*t)
	Y0 += 0.00000009132*np.cos(0.27141964250 + 403.1341922245*t)
	Y0 += 0.00000007404*np.cos(5.71529438134 + 75.0422309982*t)
	Y0 += 0.00000008119*np.cos(5.04264305327 + 480.251596762*t)
	Y0 += 0.00000006452*np.cos(3.40705432376 + 321.7603115182*t)
	Y0 += 0.00000007569*np.cos(3.42743646666 + 14.2270940016*t)
	Y0 += 0.00000007909*np.cos(0.07288588503 + 36.3879304986*t)
	Y0 += 0.00000007909*np.cos(1.12610872772 + 39.878140777*t)
	Y0 += 0.00000007571*np.cos(1.24658812739 + 23.4639986515*t)
	Y0 += 0.00000008060*np.cos(1.96863458429 + 170.9732741062*t)
	Y0 += 0.00000006254*np.cos(5.31529575739 + 31.2319369581*t)
	Y0 += 0.00000006145*np.cos(3.68131640631 + 95.931043108*t)
	Y0 += 0.00000007446*np.cos(1.64376609736 + 494.4786907636*t)
	Y0 += 0.00000007743*np.cos(5.98250694250 + 485.8806710545*t)
	Y0 += 0.00000008112*np.cos(4.88482380649 + 474.9468453752*t)
	Y0 += 0.00000005958*np.cos(0.93024333893 + 52213.9393187862*t)
	Y0 += 0.00000007372*np.cos(3.31633020357 + 54.8078101942*t)
	Y0 += 0.00000005900*np.cos(0.21363110756 + 52061.40717623499*t)
	Y0 += 0.00000005721*np.cos(0.87653097313 + 119.5069163441*t)
	Y0 += 0.00000005708*np.cos(3.61595873676 + 101.8689339412*t)
	Y0 += 0.00000006572*np.cos(1.63899943387 + 1055.1891444952*t)
	Y0 += 0.00000006415*np.cos(1.00783296315 + 57.1436161644*t)
	Y0 += 0.00000005655*np.cos(1.46939704442 + 12604.2847356206*t)
	Y0 += 0.00000005758*np.cos(1.25264684646 + 29.7956483596*t)
	Y0 += 0.00000005689*np.cos(2.70796041900 + 27.7417266797*t)
	Y0 += 0.00000005833*np.cos(5.17859920603 + 6643.0918177618*t)
	Y0 += 0.00000005270*np.cos(5.03822957270 + 6167.1922703697*t)
	Y0 += 0.00000007248*np.cos(4.01687388867 + 674.8007441043*t)
	Y0 += 0.00000005679*np.cos(4.34696650563 + 16.9835910971*t)
	Y0 += 0.00000005669*np.cos(0.58371555281 + 325.3836482406*t)
	Y0 += 0.00000006785*np.cos(2.01979401520 + 320.2758388099*t)
	Y0 += 0.00000005146*np.cos(5.52411388267 + 46.5186070258*t)
	Y0 += 0.00000005563*np.cos(1.07076628954 + 177.3049238143*t)
	Y0 += 0.00000006459*np.cos(2.74428008755 + 561.8861098992*t)
	Y0 += 0.00000005641*np.cos(4.53093052368 + 169.228168967*t)
	Y0 += 0.00000005102*np.cos(5.95106118882 + 104.5290628171*t)
	Y0 += 0.00000006475*np.cos(0.95285677251 + 590.8304249969*t)
	Y0 += 0.00000004984*np.cos(0.17849748817 + 10097.4019665893*t)
	Y0 += 0.00000005318*np.cos(3.65617561778 + 44.2833747921*t)
	Y0 += 0.00000006698*np.cos(1.37970257226 + 2156.8968960162*t)
	Y0 += 0.00000005102*np.cos(4.10086430688 + 272.5815756165*t)
	Y0 += 0.00000006099*np.cos(4.39394748533 + 381.3516082374*t)
	Y0 += 0.00000006449*np.cos(2.10358230790 + 709.9648343255*t)
	Y0 += 0.00000005371*np.cos(2.83521536139 + 281.1795953256*t)
	Y0 += 0.00000005983*np.cos(1.18036159161 + 93.2709142321*t)
	Y0 += 0.00000005697*np.cos(5.30790889567 + 32.4557772355*t)
	Y0 += 0.00000005331*np.cos(6.17628884181 + 436.8138097374*t)
	Y0 += 0.00000004882*np.cos(5.40055208431 + 246.9787129509*t)
	Y0 += 0.00000005664*np.cos(0.14227860017 + 1165.3954657146*t)
	Y0 += 0.00000006265*np.cos(3.02320284237 + 712.9337797421*t)
	Y0 += 0.00000006257*np.cos(3.18970636511 + 749.5823426716*t)
	Y0 += 0.00000004422*np.cos(6.11311760626 + 1272.6810256272*t)
	Y0 += 0.00000005749*np.cos(4.70940713962 + 6318.2399402126*t)
	Y0 += 0.00000005244*np.cos(0.76594899514 + 73.3453099688*t)
	Y0 += 0.00000004687*np.cos(0.05970229608 + 154.6710065653*t)
	Y0 += 0.00000006024*np.cos(2.70591736862 + 16.1535096946*t)
	Y0 += 0.00000006055*np.cos(3.35592086463 + 786.2309056011*t)
	Y0 += 0.00000004256*np.cos(5.81861406949 + 1577.766562589*t)
	Y0 += 0.00000004744*np.cos(2.30871852548 + 20388.4380567842*t)
	Y0 += 0.00000004224*np.cos(3.85505933502 + 384.2723695442*t)
	Y0 += 0.00000005572*np.cos(5.58677445095 + 291.0496394219*t)
	Y0 += 0.00000004336*np.cos(1.08884506787 + 53.653405886*t)
	Y0 += 0.00000004427*np.cos(1.43078660757 + 189.1807054807*t)
	Y0 += 0.00000004646*np.cos(4.44852785946 + 13286.1836355236*t)
	Y0 += 0.00000005455*np.cos(6.13369565092 + 10248.4496364322*t)
	Y0 += 0.00000005506*np.cos(2.70125463056 + 177.8743727859*t)
	Y0 += 0.00000005348*np.cos(6.13707313462 + 24.6396548191*t)
	Y0 += 0.00000004263*np.cos(1.71615977146 + 116.5379709275*t)
	Y0 += 0.00000005586*np.cos(5.12131239872 + 6247.9117597702*t)
	Y0 += 0.00000004095*np.cos(4.92531108562 + 765.6239777816*t)
	Y0 += 0.00000004106*np.cos(1.44325025450 + 229.4526051326*t)
	Y0 += 0.00000004293*np.cos(3.08793992867 + 46.470422916*t)
	Y0 += 0.00000004179*np.cos(2.68815352879 + 6606.4432548323*t)
	Y0 += 0.00000004405*np.cos(2.78639984040 + 525.2375469697*t)
	Y0 += 0.00000004492*np.cos(4.81151850667 + 52177.29075585669*t)
	Y0 += 0.00000005356*np.cos(0.26035194623 + 10178.1214559898*t)
	Y0 += 0.00000004594*np.cos(4.86059374922 + 1025.4416802454*t)
	Y0 += 0.00000005497*np.cos(3.52369768206 + 822.8794685306*t)
	Y0 += 0.00000004739*np.cos(4.49674016741 + 748.0978699633*t)
	Y0 += 0.00000003831*np.cos(3.46478372931 + 358.4088744477*t)
	Y0 += 0.00000004407*np.cos(6.01604198660 + 1474.6737883704*t)
	Y0 += 0.00000004720*np.cos(2.46699564231 + 224.3447957019*t)
	Y0 += 0.00000004268*np.cos(1.02190157209 + 373.9079928365*t)
	Y0 += 0.00000003828*np.cos(3.85155221391 + 2138.4770163206*t)
	Y0 += 0.00000004629*np.cos(5.68952565176 + 122.4758617607*t)
	Y0 += 0.00000004209*np.cos(5.35232309867 + 222.8603229936*t)
	Y0 += 0.00000004188*np.cos(1.40584099517 + 426.598190876*t)
	Y0 += 0.00000003878*np.cos(2.73400813081 + 248.4631856592*t)
	Y0 += 0.00000004711*np.cos(5.14988231608 + 52252.07235442399*t)
	Y0 += 0.00000004137*np.cos(1.02283052398 + 502.8642621516*t)
	Y0 += 0.00000003913*np.cos(2.19914530622 + 340.7708920448*t)
	Y0 += 0.00000004036*np.cos(2.59695668161 + 323.2447842265*t)
	Y0 += 0.00000004789*np.cos(1.11613633059 + 627.4789879264*t)
	Y0 += 0.00000004021*np.cos(1.71533090158 + 6603.4743094157*t)
	Y0 += 0.00000005158*np.cos(0.06197002151 + 25520.07914084179*t)
	Y0 += 0.00000004150*np.cos(2.29240072248 + 27.1992099585*t)
	Y0 += 0.00000003623*np.cos(0.72378614024 + 1665.3389665594*t)
	Y0 += 0.00000003628*np.cos(3.54191838705 + 245.4942402426*t)
	Y0 += 0.00000003638*np.cos(1.65350968405 + 356.9244017394*t)
	Y0 += 0.00000004633*np.cos(3.36223883244 + 3227.6977924947*t)
	Y0 += 0.00000004495*np.cos(2.34764530148 + 1082.0158474382*t)
	Y0 += 0.00000004556*np.cos(1.56285275727 + 25974.98850736909*t)
	Y0 += 0.00000004448*np.cos(0.59169500385 + 439.782755154*t)
	Y0 += 0.00000003736*np.cos(3.55985310407 + 1477.642733787*t)
	Y0 += 0.00000004062*np.cos(1.28480363945 + 531.1754378029*t)
	Y0 += 0.00000004482*np.cos(0.13472188586 + 342.3672393377*t)
	Y0 += 0.00000004832*np.cos(4.17903118792 + 711.4493070338*t)
	Y0 += 0.00000004304*np.cos(5.35023670233 + 12567.6361726911*t)
	Y0 += 0.00000004090*np.cos(3.11155721539 + 52.8020726241*t)
	Y0 += 0.00000003474*np.cos(3.43354239291 + 208.8456773131*t)
	Y0 += 0.00000004798*np.cos(3.66851235007 + 529.9515975255*t)
	Y0 += 0.00000003640*np.cos(3.79813532629 + 2565.0752071966*t)
	Y0 += 0.00000003563*np.cos(0.66219107190 + 12451.7525930694*t)
	Y0 += 0.00000003896*np.cos(5.66725528317 + 309.230138546*t)
	Y0 += 0.00000003630*np.cos(1.95419731413 + 102.523325247*t)
	Y0 += 0.00000004224*np.cos(1.96301767676 + 170.7126416753*t)
	Y0 += 0.00000003429*np.cos(3.16344899428 + 529.8028396792*t)
	Y0 += 0.00000003750*np.cos(5.62514445600 + 367.9701020033*t)
	Y0 += 0.00000003858*np.cos(4.35402557601 + 12564.6672272745*t)
	Y0 += 0.00000003406*np.cos(4.31901352995 + 529.57909051*t)
	Y0 += 0.00000004592*np.cos(3.67019464881 + 180.8433182025*t)
	Y0 += 0.00000004348*np.cos(3.09498417743 + 20312.17198550859*t)
	Y0 += 0.00000003718*np.cos(3.94455232665 + 1543.8263126452*t)
	Y0 += 0.00000003789*np.cos(5.86430510258 + 3101.879719292*t)
	Y0 += 0.00000003962*np.cos(1.44055691643 + 156.1554792736*t)
	Y0 += 0.00000003784*np.cos(3.13803423783 + 1025.7023126763*t)
	Y0 += 0.00000003783*np.cos(1.84015347157 + 1614.4151255185*t)
	Y0 += 0.00000003904*np.cos(1.57499522111 + 370.0452755426*t)
	Y0 += 0.00000003768*np.cos(2.79060889293 + 244.0097675343*t)
	Y0 += 0.00000004323*np.cos(3.40196315582 + 396.5419100855*t)
	Y0 += 0.00000003889*np.cos(1.92710943330 + 318.7913661016*t)
	Y0 += 0.00000004231*np.cos(3.78834773529 + 31.2801210679*t)
	Y0 += 0.00000003762*np.cos(3.80686947951 + 172.1971143836*t)
	Y0 += 0.00000004183*np.cos(2.28077109622 + 560.6622696218*t)
	Y0 += 0.00000003373*np.cos(0.27134181716 + 406.1031376411*t)
	Y0 += 0.00000003589*np.cos(1.28008934312 + 213.9534867438*t)
	Y0 += 0.00000004411*np.cos(0.78391353364 + 14.6690369863*t)
	Y0 += 0.00000004665*np.cos(5.07475421890 + 511.5954083047*t)
	Y0 += 0.00000004578*np.cos(4.98719208778 + 636.6677084665*t)
	Y0 += 0.00000003344*np.cos(0.20269311780 + 20351.7894938547*t)
	Y0 += 0.00000003343*np.cos(3.36731339079 + 266.952501324*t)
	Y0 += 0.00000004659*np.cos(1.91786652417 + 283.6272758804*t)
	Y0 += 0.00000003934*np.cos(2.81187873937 + 1617.3840709351*t)
	Y0 += 0.00000004317*np.cos(0.54045162973 + 343.4792050305*t)
	Y0 += 0.00000004494*np.cos(2.91108734034 + 875.830299001*t)
	Y0 += 0.00000003367*np.cos(1.26388427784 + 127.4717966068*t)
	Y0 += 0.00000003334*np.cos(4.17218736759 + 1654.0326338646*t)
	Y0 += 0.00000003375*np.cos(4.92015915490 + 1120.148883076*t)
	Y0 += 0.00000004526*np.cos(2.98323504249 + 525.5463635104*t)
	Y0 += 0.00000003322*np.cos(2.54606866108 + 485.9288551643*t)
	Y0 += 0.00000003665*np.cos(3.52551062197 + 149.0419322728*t)
	Y0 += 0.00000004043*np.cos(2.86822695235 + 244.318584075*t)
	Y0 += 0.00000004025*np.cos(3.81474412988 + 52174.32181044009*t)
	Y0 += 0.00000003276*np.cos(3.52741641871 + 1306.621275571*t)
	Y0 += 0.00000003582*np.cos(4.69883870215 + 304.2342036999*t)
	Y0 += 0.00000003214*np.cos(5.51314151631 + 20348.82054843809*t)
	Y0 += 0.00000003963*np.cos(3.65925057541 + 638.1521811748*t)
	Y0 += 0.00000004060*np.cos(2.86201358830 + 274.6354972964*t)
	Y0 += 0.00000003523*np.cos(4.77119709375 + 519.6084726772*t)
	Y0 += 0.00000003975*np.cos(3.44195970194 + 14.5571624017*t)
	Y0 += 0.00000003753*np.cos(5.89334012623 + 165.0835673828*t)
	Y0 += 0.00000004414*np.cos(1.19641019879 + 395.578702239*t)
	Y0 += 0.00000004430*np.cos(3.80838860586 + 529.4303326637*t)
	Y0 += 0.00000004064*np.cos(2.60400557319 + 6130.5437074402*t)
	Y0 += 0.00000004077*np.cos(3.56169074183 + 433.190473015*t)
	Y0 += 0.00000003918*np.cos(5.77638473911 + 375.6743498351*t)
	Y0 += 0.00000004035*np.cos(1.15563671039 + 1012.8633231634*t)
	Y0 += 0.00000004022*np.cos(0.15001208871 + 1477.5945496772*t)
	Y0 += 0.00000004060*np.cos(4.49007922984 + 51.6264164565*t)
	Y0 += 0.00000003107*np.cos(3.81160980428 + 28.6836826668*t)
	Y0 += 0.00000003259*np.cos(0.91021107093 + 658.1259695479*t)
	Y0 += 0.00000003428*np.cos(2.81212399261 + 2351.7761117586*t)
	Y0 += 0.00000003114*np.cos(0.48888256375 + 537.7677199419*t)
	Y0 += 0.00000003382*np.cos(1.87715401308 + 661.0949149645*t)
	Y0 += 0.00000003297*np.cos(1.72555035248 + 1404.0849754971*t)
	Y0 += 0.00000003278*np.cos(5.26020148085 + 942.0138778592*t)
	Y0 += 0.00000003415*np.cos(5.95641164263 + 326.4261779642*t)
	Y0 += 0.00000003172*np.cos(2.65677028436 + 78.4049352897*t)
	Y0 += 0.00000003173*np.cos(0.75400916256 + 1401.1160300805*t)
	Y0 += 0.00000003445*np.cos(0.57992543307 + 385.5443939314*t)
	Y0 += 0.00000003092*np.cos(3.82983550635 + 815.0633461142*t)
	Y0 += 0.00000004196*np.cos(1.28994281273 + 25596.3452121174*t)
	Y0 += 0.00000004113*np.cos(3.44521319517 + 1049.5600702027*t)
	Y0 += 0.00000004012*np.cos(0.58003601548 + 52.3601296394*t)
	Y0 += 0.00000003869*np.cos(3.98538549617 + 555.0331953293*t)
	Y0 += 0.00000003402*np.cos(5.33322683123 + 1586.1039498672*t)
	Y0 += 0.00000004107*np.cos(0.17888822879 + 978.9230732196*t)
	Y0 += 0.00000003231*np.cos(6.18446393138 + 401.0647641796*t)
	Y0 += 0.00000003726*np.cos(5.26558629383 + 1096.2429414398*t)
	Y0 += 0.00000003792*np.cos(5.46703170313 + 111.6907939277*t)
	Y0 += 0.00000004172*np.cos(3.66727884339 + 943.4983505675*t)
	Y0 += 0.00000003049*np.cos(2.69618553184 + 241.6102710893*t)
	Y0 += 0.00000003839*np.cos(4.02727251163 + 10060.7534036598*t)
	Y0 += 0.00000003471*np.cos(3.16777535295 + 1158.2819187138*t)
	Y0 += 0.00000003427*np.cos(2.68341078344 + 206.1855484372*t)
	Y0 += 0.00000003679*np.cos(3.11256178045 + 635.1832357582*t)
	Y0 += 0.00000003673*np.cos(3.08820607068 + 57.84619158*t)
	Y0 += 0.00000002998*np.cos(5.59775307383 + 477.3308354552*t)
	Y0 += 0.00000004182*np.cos(1.86290426872 + 2772.7884259674*t)
	Y0 += 0.00000002961*np.cos(3.77220636399 + 2461.982432978*t)
	Y0 += 0.00000003331*np.cos(2.38360679146 + 10134.0505295188*t)
	Y0 += 0.00000003222*np.cos(4.49696787843 + 134.1122628556*t)
	Y0 += 0.00000002942*np.cos(2.47257439653 + 78225.57638908479*t)
	Y0 += 0.00000003465*np.cos(0.02644864750 + 1151.168371713*t)
	Y0 += 0.00000002968*np.cos(0.19544643382 + 225.8292684102*t)
	Y0 += 0.00000002951*np.cos(4.00999244396 + 33.7278016227*t)
	Y0 += 0.00000002951*np.cos(3.47218747597 + 42.5382696529*t)
	Y0 += 0.00000003159*np.cos(5.46095797219 + 103.3534066495*t)
	Y0 += 0.00000002923*np.cos(1.51122952452 + 266.1011680621*t)
	Y0 += 0.00000003904*np.cos(5.01890959329 + 558.0021407459*t)
	Y0 += 0.00000003304*np.cos(5.45541068856 + 500.1559491659*t)
	Y0 += 0.00000003313*np.cos(3.21903075571 + 939.3537489833*t)
	Y0 += 0.00000003031*np.cos(4.32204775564 + 156451.15277816958*t)
	Y0 += 0.00000002967*np.cos(4.72619666771 + 6.1503391543*t)
	Y0 += 0.00000002968*np.cos(2.87474467824 + 285.1117485887*t)
	Y0 += 0.00000003252*np.cos(1.92891892698 + 709.0498105888*t)
	Y0 += 0.00000002995*np.cos(5.12818568753 + 139.9537854692*t)
	Y0 += 0.00000002869*np.cos(6.22345325556 + 908.3342603463*t)
	Y0 += 0.00000003354*np.cos(0.17083659229 + 642.6055992997*t)
	Y0 += 0.00000002992*np.cos(4.15289545754 + 54.1746707478*t)
	Y0 += 0.00000002918*np.cos(0.68789446711 + 83.3796182764*t)
	Y0 += 0.00000003752*np.cos(4.99091008637 + 277.0349937414*t)
	Y0 += 0.00000003767*np.cos(2.26354266856 + 746.613397255*t)
	Y0 += 0.00000003591*np.cos(3.52985610370 + 697.8071683688*t)
	Y0 += 0.00000002822*np.cos(0.67588438863 + 953.5808429849*t)
	Y0 += 0.00000003829*np.cos(0.44509657076 + 452.2010535416*t)
	Y0 += 0.00000003196*np.cos(4.27208369200 + 362.8622925726*t)
	Y0 += 0.00000003158*np.cos(5.89392762358 + 539.773457512*t)
	Y0 += 0.00000002804*np.cos(5.67449178767 + 419.4846438752*t)
	Y0 += 0.00000003759*np.cos(3.90160360925 + 6171.6456884946*t)
	Y0 += 0.00000002818*np.cos(4.56341241055 + 956.2891559706*t)
	Y0 += 0.00000003828*np.cos(2.81642582089 + 635.70450062*t)
	Y0 += 0.00000002810*np.cos(3.57724875595 + 1592.0418407004*t)
	Y0 += 0.00000003159*np.cos(5.71540609516 + 197.7999770492*t)
	Y0 += 0.00000002859*np.cos(3.51261942327 + 665.2395165487*t)
	Y0 += 0.00000003761*np.cos(5.75801604585 + 490.3340891794*t)
	Y0 += 0.00000003659*np.cos(1.19068403505 + 347.3631741838*t)
	Y0 += 0.00000003228*np.cos(1.02601169957 + 6203.8408332992*t)
	Y0 += 0.00000003747*np.cos(1.09466936594 + 303.6010642535*t)
	Y0 += 0.00000003529*np.cos(3.52069989175 + 608.877797677*t)
	Y0 += 0.00000003272*np.cos(3.28969455529 + 384.5811860849*t)
	Y0 += 0.00000002878*np.cos(1.18069074049 + 450.7165808333*t)
	Y0 += 0.00000003291*np.cos(2.82888188182 + 297.6419215609*t)
	Y0 += 0.00000003419*np.cos(0.93085492324 + 416.7763308895*t)
	Y0 += 0.00000003057*np.cos(6.05827118955 + 52.6901980395*t)
	Y0 += 0.00000003057*np.cos(4.56550138397 + 23.5758732361*t)
	Y0 += 0.00000003444*np.cos(1.97050046415 + 499.895316735*t)
	Y0 += 0.00000003586*np.cos(4.87689429521 + 26048.28563322809*t)
	Y0 += 0.00000002816*np.cos(1.69651250485 + 210.3783341312*t)
	Y0 += 0.00000002746*np.cos(5.14557483567 + 353.301065017*t)
	Y0 += 0.00000002856*np.cos(1.48878669355 + 622.9136952169*t)
	Y0 += 0.00000003026*np.cos(0.08398557744 + 473.4623726669*t)
	Y0 += 0.00000002724*np.cos(5.64910692637 + 22.9427337897*t)
	Y0 += 0.00000002733*np.cos(1.93635956483 + 262.4778313397*t)
	Y0 += 0.00000002681*np.cos(5.83048600091 + 24.9484713598*t)
	Y0 += 0.00000002788*np.cos(0.34873307438 + 191.3195694948*t)
	Y0 += 0.00000003585*np.cos(0.35139284692 + 526.5095713569*t)
	Y0 += 0.00000003490*np.cos(1.28004674902 + 664.1275508559*t)
	Y0 += 0.00000002906*np.cos(1.95591954273 + 172.2452984934*t)
	Y0 += 0.00000002975*np.cos(0.71741646583 + 959.2099172774*t)
	Y0 += 0.00000002819*np.cos(2.27061898938 + 175.820451106*t)
	Y0 += 0.00000003326*np.cos(0.55223927312 + 44.9859502077*t)
	Y0 += 0.00000003512*np.cos(0.85731283605 + 532.8723588323*t)
	Y0 += 0.00000002630*np.cos(5.83934423750 + 2751.5475996916*t)
	Y0 += 0.00000002629*np.cos(1.45398599785 + 411.0990724872*t)
	Y0 += 0.00000002625*np.cos(0.73055263025 + 521.6142102473*t)
	Y0 += 0.00000002964*np.cos(3.34204295239 + 112.3933693433*t)
	Y0 += 0.00000003127*np.cos(1.47433846576 + 225.3080035484*t)
	Y0 += 0.00000002779*np.cos(3.22942892779 + 238.6413256727*t)
	Y0 += 0.00000002700*np.cos(2.88389280233 + 963.4027029714*t)
	Y0 += 0.00000002669*np.cos(3.02940521402 + 531.6967026647*t)
	Y0 += 0.00000003084*np.cos(1.37449239492 + 340.5102596139*t)
	Y0 += 0.00000003257*np.cos(6.23717182736 + 305.7186764082*t)
	Y0 += 0.00000003265*np.cos(6.26189223545 + 24.4908969728*t)
	Y0 += 0.00000003588*np.cos(1.33471140759 + 533.8355666788*t)
	Y0 += 0.00000002552*np.cos(4.72678171304 + 183.7640795093*t)
	Y0 += 0.00000002725*np.cos(5.17313059039 + 74.2603337055*t)
	Y0 += 0.00000003107*np.cos(4.58148059690 + 217.4436970222*t)
	Y0 += 0.00000002644*np.cos(5.73203813744 + 508.3503240922*t)
	Y0 += 0.00000002980*np.cos(5.25252236279 + 464.7312265138*t)
	Y0 += 0.00000002763*np.cos(0.26992068136 + 410.8384400563*t)
	Y0 += 0.00000003044*np.cos(0.78066290550 + 369.4545747116*t)
	Y0 += 0.00000003444*np.cos(0.99359024005 + 891.3294173898*t)
	Y0 += 0.00000002533*np.cos(2.16115259070 + 800.8362521126*t)
	Y0 += 0.00000002531*np.cos(1.24865571639 + 90.9351082619*t)
	Y0 += 0.00000002742*np.cos(4.26902058467 + 57.7980074702*t)
	Y0 += 0.00000002699*np.cos(4.28647148756 + 1624.236985505*t)
	Y0 += 0.00000002571*np.cos(5.76801473818 + 600.2797779679*t)
	Y0 += 0.00000002640*np.cos(5.59732374708 + 212.4690140355*t)
	Y0 += 0.00000003109*np.cos(2.22094458109 + 518.3846323998*t)
	Y0 += 0.00000003359*np.cos(5.32993220851 + 10101.8553847142*t)
	Y0 += 0.00000002577*np.cos(3.39414147622 + 1447.8470854274*t)
	Y0 += 0.00000002531*np.cos(5.14072751464 + 495.4900827199*t)
	Y0 += 0.00000002589*np.cos(3.33391775373 + 1190.7858800591*t)
	Y0 += 0.00000003144*np.cos(1.59060373508 + 1504.2088042991*t)
	Y0 += 0.00000002806*np.cos(3.97574190040 + 23.9059416362*t)
	Y0 += 0.00000002818*np.cos(2.04818576489 + 49.0668613171*t)
	Y0 += 0.00000003340*np.cos(3.88359437905 + 769.8167634756*t)
	Y0 += 0.00000003153*np.cos(4.36180740333 + 51.7751743028*t)
	Y0 += 0.00000003026*np.cos(4.66102274842 + 784.7464328928*t)
	Y0 += 0.00000002471*np.cos(2.80088362924 + 411.3597049181*t)
	Y0 += 0.00000002460*np.cos(3.66139459125 + 12528.018664345*t)
	Y0 += 0.00000002504*np.cos(1.42658135509 + 464.4705940829*t)
	Y0 += 0.00000002972*np.cos(5.01469145652 + 569.0478410098*t)
	Y0 += 0.00000003209*np.cos(6.19742042150 + 1438.0252254409*t)
	Y0 += 0.00000002508*np.cos(3.04158933835 + 260.9933586314*t)
	Y0 += 0.00000002443*np.cos(2.82612634968 + 1625.7214582133*t)
	Y0 += 0.00000002666*np.cos(5.14460585253 + 573.4530750249*t)
	Y0 += 0.00000002719*np.cos(1.78358967618 + 140.001969579*t)
	Y0 += 0.00000002710*np.cos(3.15364430478 + 564.8550553158*t)
	Y0 += 0.00000002821*np.cos(4.09785128246 + 402.6922492398*t)
	Y0 += 0.00000003412*np.cos(5.98247894366 + 772.5887669361*t)
	Y0 += 0.00000002898*np.cos(5.66734281961 + 394.0942295307*t)
	Y0 += 0.00000003170*np.cos(2.10761426115 + 1011.3788504551*t)
	Y0 += 0.00000002763*np.cos(3.87249057954 + 460.5384408198*t)
	Y0 += 0.00000003091*np.cos(0.31166661878 + 379.0158022672*t)
	Y0 += 0.00000002656*np.cos(4.25147351533 + 409.6627838887*t)
	Y0 += 0.00000003176*np.cos(4.86808797019 + 301.1533836987*t)
	Y0 += 0.00000002660*np.cos(4.25235969165 + 305.3461693927*t)
	Y0 += 0.00000003357*np.cos(3.91151745014 + 346.1393339064*t)
	Y0 += 0.00000002698*np.cos(3.26449493257 + 78149.31031780918*t)
	Y0 += 0.00000002398*np.cos(5.70459817283 + 1552.4243323543*t)
	Y0 += 0.00000002703*np.cos(0.98862354260 + 113.1270825262*t)
	Y0 += 0.00000002373*np.cos(0.25239158359 + 131.0951333292*t)
	Y0 += 0.00000002425*np.cos(1.33980716631 + 1337.640764208*t)
	Y0 += 0.00000003236*np.cos(3.48022046721 + 20.0374788479*t)
	Y0 += 0.00000003005*np.cos(4.72212645567 + 353.0404325861*t)
	Y0 += 0.00000003313*np.cos(3.05727882934 + 2849.054497243*t)
	Y0 += 0.00000002414*np.cos(4.43559153994 + 527.6852275245*t)
	Y0 += 0.00000002740*np.cos(3.20105219862 + 1205.9761819072*t)
	Y0 += 0.00000002361*np.cos(0.63552853687 + 905.3653149297*t)
	Y0 += 0.00000002344*np.cos(3.90185772151 + 132.5796060375*t)
	Y0 += 0.00000003257*np.cos(1.23406689856 + 66.3960271793*t)
	Y0 += 0.00000003261*np.cos(2.55696433264 + 1507.1777497157*t)
	Y0 += 0.00000003046*np.cos(2.42869966903 + 1549.4553869377*t)
	Y0 += 0.00000003241*np.cos(5.00909929345 + 978.6624407887*t)
	Y0 += 0.00000002369*np.cos(5.90091572070 + 419.2240114443*t)
	Y0 += 0.00000003118*np.cos(5.98461423520 + 694.8382229522*t)
	Y0 += 0.00000003117*np.cos(5.30714013024 + 1435.0562800243*t)
	Y0 += 0.00000002380*np.cos(1.01356203535 + 983.1158589136*t)
	Y0 += 0.00000002345*np.cos(4.37755770684 + 454.1756533444*t)
	Y0 += 0.00000002409*np.cos(5.05182598735 + 142.6620984549*t)
	Y0 += 0.00000002340*np.cos(0.70752556953 + 452.6741342936*t)
	Y0 += 0.00000003067*np.cos(2.87058661092 + 458.8415197904*t)
	Y0 += 0.00000002360*np.cos(2.65452039382 + 288.0806940053*t)
	Y0 += 0.00000003202*np.cos(3.29438781750 + 89.9082099406*t)
	Y0 += 0.00000002306*np.cos(4.04052258509 + 6246.4272870619*t)
	Y0 += 0.00000002494*np.cos(2.36431688660 + 1187.8169346425*t)
	Y0 += 0.00000002341*np.cos(2.23011474527 + 341.7340998913*t)
	Y0 += 0.00000002676*np.cos(0.23734342327 + 259.5088859231*t)
	Y0 += 0.00000002809*np.cos(0.95837285337 + 317.8281582551*t)
	Y0 += 0.00000002952*np.cos(4.69782080306 + 186.472392495*t)
	Y0 += 0.00000002881*np.cos(2.69226614245 + 237.9869343669*t)
	Y0 += 0.00000003199*np.cos(3.69041975198 + 859.5280314601*t)
	Y0 += 0.00000002613*np.cos(3.70839499487 + 557.741508315*t)
	Y0 += 0.00000002256*np.cos(3.51118945147 + 981.6313862053*t)
	Y0 += 0.00000002722*np.cos(0.59414923439 + 49.4393683326*t)
	Y0 += 0.00000002900*np.cos(3.88889529638 + 771.1042942278*t)
	Y0 += 0.00000002254*np.cos(3.41702005424 + 22.8945496799*t)
	Y0 += 0.00000002359*np.cos(0.77313093683 + 673.8375362578*t)
	Y0 += 0.00000003049*np.cos(2.13225938920 + 1512.8068240082*t)
	Y0 += 0.00000002380*np.cos(2.43766202246 + 429.5189521828*t)
	Y0 += 0.00000002655*np.cos(4.29166946925 + 484.3961983462*t)
	Y0 += 0.00000003050*np.cos(3.30523538204 + 1230.3552042954*t)
	Y0 += 0.00000002933*np.cos(5.65910757918 + 314.9073969483*t)
	Y0 += 0.00000002665*np.cos(2.19981222171 + 554.0699874828*t)
	Y0 += 0.00000003004*np.cos(4.59441165035 + 1929.5831548977*t)
	Y0 += 0.00000002290*np.cos(4.98200725775 + 455.4306313891*t)
	Y0 += 0.00000002295*np.cos(0.63099781114 + 497.1870037493*t)
	Y0 += 0.00000002226*np.cos(0.52897697548 + 47.5823886088*t)
	Y0 += 0.00000002250*np.cos(0.37232537057 + 70.5888128733*t)
	Y0 += 0.00000002246*np.cos(2.01432880382 + 381.6122406683*t)
	Y0 += 0.00000002231*np.cos(3.37106298565 + 877.1023233882*t)
	Y0 += 0.00000002718*np.cos(3.56030002906 + 177.8261886761*t)
	Y0 += 0.00000002999*np.cos(3.63964247571 + 1926.6142094811*t)
	Y0 += 0.00000003064*np.cos(0.13823970452 + 317.8763423649*t)
	Y0 += 0.00000002235*np.cos(1.60629117936 + 189.8350967865*t)
	Y0 += 0.00000002691*np.cos(2.01006398440 + 6284.5603226997*t)
	Y0 += 0.00000002682*np.cos(2.34959792980 + 422.7142217227*t)
	Y0 += 0.00000002204*np.cos(4.77544823324 + 443.1299530805*t)
	Y0 += 0.00000002284*np.cos(1.53609675955 + 250.6020496733*t)
	Y0 += 0.00000002451*np.cos(2.05863878190 + 487.6257761937*t)
	Y0 += 0.00000002255*np.cos(4.89734227454 + 621.4774066184*t)
	Y0 += 0.00000002185*np.cos(5.42597293866 + 498.6714764576*t)
	Y0 += 0.00000002178*np.cos(2.98451517510 + 6243.4583416453*t)
	Y0 += 0.00000002615*np.cos(1.24260500772 + 639.897286314*t)
	Y0 += 0.00000002201*np.cos(1.45024762713 + 1189.3014073508*t)
	Y0 += 0.00000002173*np.cos(5.45923533629 + 10176.6369832815*t)
	Y0 += 0.00000002854*np.cos(2.57422930194 + 591.9423906897*t)
	Y0 += 0.00000002677*np.cos(4.97646613444 + 528.4671248172*t)
	Y0 += 0.00000002975*np.cos(3.02476240292 + 1014.3477958717*t)
	Y0 += 0.00000002339*np.cos(3.29514264160 + 440.6822725257*t)
	Y0 += 0.00000002303*np.cos(2.30070066113 + 1371.5810141518*t)
	Y0 += 0.00000002471*np.cos(4.24204271273 + 407.2151033339*t)
	Y0 += 0.00000002539*np.cos(5.75288212233 + 425.3743505986*t)
	Y0 += 0.00000002373*np.cos(1.81297882236 + 132.8402384684*t)
	Y0 += 0.00000002381*np.cos(0.08013730606 + 141.1776257466*t)
	Y0 += 0.00000002332*np.cos(5.93678984392 + 70.6369969831*t)
	Y0 += 0.00000002628*np.cos(2.85649388220 + 459.3627846522*t)
	Y0 += 0.00000002319*np.cos(2.81891636177 + 26011.6370702986*t)
	Y0 += 0.00000002378*np.cos(2.89965220331 + 952.0963702766*t)
	Y0 += 0.00000002232*np.cos(3.99247109324 + 158.3736651648*t)
	return Y0




def Neptune_Y1 (t): # 287 terms of order 1

	Y1 = 0.
	Y1 -= 0.00352941377
	Y1 += 0.00256112241*np.cos(0.44757496381 + 36.6485629295*t)
	Y1 += 0.00243135236*np.cos(3.89099801420 + 39.6175083461*t)
	Y1 += 0.00118411800*np.cos(1.31131262408 + 76.2660712756*t)
	Y1 += 0.00021935569*np.cos(1.63124087146 + 35.1640902212*t)
	Y1 += 0.00017461450*np.cos(2.69229907252 + 41.1019810544*t)
	Y1 += 0.00012992380*np.cos(3.79578633002 + 2.9689454166*t)
	Y1 += 0.00004955216*np.cos(0.51750137679 + 73.297125859*t)
	Y1 += 0.00002746565*np.cos(2.49189874649 + 77.7505439839*t)
	Y1 += 0.00002145481*np.cos(2.54768447291 + 4.4534181249*t)
	Y1 += 0.00001572289*np.cos(5.78853350711 + 114.3991069134*t)
	Y1 += 0.00001565725*np.cos(2.89846266272 + 33.6796175129*t)
	Y1 += 0.00001458269*np.cos(1.61835542699 + 38.1330356378*t)
	Y1 += 0.00001343731*np.cos(1.46712622109 + 42.5864537627*t)
	Y1 += 0.00001292006*np.cos(4.45882418895 + 74.7815985673*t)
	Y1 += 0.00000865987*np.cos(0.09556314885 + 37.611770776*t)
	Y1 += 0.00000849963*np.cos(4.24519893359 + 38.6543004996*t)
	Y1 += 0.00000921004*np.cos(1.77511422595 + 71.8126531507*t)
	Y1 += 0.00000535973*np.cos(2.93053797020 + 1.4844727083*t)
	Y1 += 0.00000500998*np.cos(0.14254169132 + 28.5718080822*t)
	Y1 += 0.00000471868*np.cos(5.96893505289 + 98.8999885246*t)
	Y1 += 0.00000453930*np.cos(0.14360437422 + 35.685355083*t)
	Y1 += 0.00000410057*np.cos(4.19500269960 + 40.5807161926*t)
	Y1 += 0.00000366899*np.cos(4.19675799066 + 47.6942631934*t)
	Y1 += 0.00000299214*np.cos(1.31497587337 + 5.9378908332*t)
	Y1 += 0.00000170466*np.cos(2.89252858677 + 33.9402499438*t)
	Y1 += 0.00000156618*np.cos(1.02374224930 + 79.2350166922*t)
	Y1 += 0.00000152553*np.cos(5.29478475308 + 30.0562807905*t)
	Y1 += 0.00000150776*np.cos(1.46874533276 + 42.3258213318*t)
	Y1 += 0.00000162840*np.cos(5.51940419316 + 31.019488637*t)
	Y1 += 0.00000130379*np.cos(3.20301703119 + 8.0767548473*t)
	Y1 += 0.00000121024*np.cos(5.30860647354 + 46.2097904851*t)
	Y1 += 0.00000134658*np.cos(5.10386276839 + 45.2465826386*t)
	Y1 += 0.00000115930*np.cos(0.24759979383 + 44.070926471*t)
	Y1 += 0.00000110293*np.cos(4.69481506643 + 35.212274331*t)
	Y1 += 0.00000108388*np.cos(1.92093584532 + 7.1135470008*t)
	Y1 += 0.00000099370*np.cos(5.93175202972 + 41.0537969446*t)
	Y1 += 0.00000090585*np.cos(4.23396273741 + 32.1951448046*t)
	Y1 += 0.00000108365*np.cos(1.52289786655 + 112.9146342051*t)
	Y1 += 0.00000089894*np.cos(5.88234203408 + 60.7669528868*t)
	Y1 += 0.00000066255*np.cos(3.24522261219 + 70.3281804424*t)
	Y1 += 0.00000051314*np.cos(2.44370363881 + 69.1525242748*t)
	Y1 += 0.00000048991*np.cos(1.56239422724 + 2.9207613068*t)
	Y1 += 0.00000046503*np.cos(4.42005243760 + 111.4301614968*t)
	Y1 += 0.00000044006*np.cos(4.05809370238 + 109.9456887885*t)
	Y1 += 0.00000042570*np.cos(0.10123710589 + 7.4223635415*t)
	Y1 += 0.00000039580*np.cos(5.66153770824 + 12.5301729722*t)
	Y1 += 0.00000039462*np.cos(4.26971503039 + 31.5407534988*t)
	Y1 += 0.00000037352*np.cos(1.59078851213 + 274.0660483248*t)
	Y1 += 0.00000038035*np.cos(4.30959223543 + 6.592282139*t)
	Y1 += 0.00000037948*np.cos(4.41684438344 + 14.0146456805*t)
	Y1 += 0.00000041772*np.cos(2.67664940250 + 4.192785694*t)
	Y1 += 0.00000035716*np.cos(1.28021180129 + 84.3428261229*t)
	Y1 += 0.00000033039*np.cos(1.36957718323 + 27.0873353739*t)
	Y1 += 0.00000033108*np.cos(0.88651710158 + 115.8835796217*t)
	Y1 += 0.00000030599*np.cos(5.59281389749 + 22.633917249*t)
	Y1 += 0.00000028690*np.cos(6.13341530240 + 106.9767433719*t)
	Y1 += 0.00000022862*np.cos(6.27256302631 + 44.7253177768*t)
	Y1 += 0.00000023139*np.cos(5.90845460360 + 106.0135355254*t)
	Y1 += 0.00000022382*np.cos(2.74288661925 + 175.1660598002*t)
	Y1 += 0.00000021638*np.cos(5.65601132085 + 5.4166259714*t)
	Y1 += 0.00000020371*np.cos(6.06747996518 + 62.2514255951*t)
	Y1 += 0.00000019878*np.cos(5.73044951888 + 32.7164096664*t)
	Y1 += 0.00000019754*np.cos(2.91920405761 + 49.1787359017*t)
	Y1 += 0.00000019233*np.cos(4.44323447748 + 6.9010986797*t)
	Y1 += 0.00000019579*np.cos(4.08479579857 + 24.1183899573*t)
	Y1 += 0.00000018318*np.cos(4.93707103969 + 63.7358983034*t)
	Y1 += 0.00000017014*np.cos(2.67275243455 + 91.7864415238*t)
	Y1 += 0.00000016336*np.cos(0.81498116086 + 11.0457002639*t)
	Y1 += 0.00000016400*np.cos(3.45346659376 + 33.0252262071*t)
	Y1 += 0.00000017244*np.cos(4.89548915279 + 11.3063326948*t)
	Y1 += 0.00000015590*np.cos(3.91877412354 + 39.405060025*t)
	Y1 += 0.00000015590*np.cos(0.42181314281 + 36.8610112506*t)
	Y1 += 0.00000015469*np.cos(4.91170345861 + 43.5496616092*t)
	Y1 += 0.00000016590*np.cos(1.19757976992 + 33.4671691918*t)
	Y1 += 0.00000019347*np.cos(4.06420216347 + 152.5321425512*t)
	Y1 += 0.00000015990*np.cos(5.86394572836 + 79.1868325824*t)
	Y1 += 0.00000014554*np.cos(4.25295399683 + 319.3126309634*t)
	Y1 += 0.00000014467*np.cos(5.15039251213 + 108.4612160802*t)
	Y1 += 0.00000012917*np.cos(4.09621487061 + 97.4155158163*t)
	Y1 += 0.00000016538*np.cos(4.71752472587 + 305.0855369618*t)
	Y1 += 0.00000012751*np.cos(5.32663710068 + 45.5553991793*t)
	Y1 += 0.00000013293*np.cos(3.14432068639 + 42.7989020838*t)
	Y1 += 0.00000011036*np.cos(5.39688163697 + 5.1078094307*t)
	Y1 += 0.00000011107*np.cos(0.75452281256 + 43.2408450685*t)
	Y1 += 0.00000012061*np.cos(1.63427149054 + 72.0732855816*t)
	Y1 += 0.00000010719*np.cos(3.07022445403 + 415.2918581812*t)
	Y1 += 0.00000011499*np.cos(3.05217795552 + 129.9194771616*t)
	Y1 += 0.00000010082*np.cos(4.02342989288 + 251.4321310758*t)
	Y1 += 0.00000011438*np.cos(0.01538881296 + 143.6253063014*t)
	Y1 += 0.00000008946*np.cos(6.14010235660 + 69.3649725959*t)
	Y1 += 0.00000008867*np.cos(4.98782186872 + 70.8494453042*t)
	Y1 += 0.00000009057*np.cos(2.51513096487 + 82.8583534146*t)
	Y1 += 0.00000008691*np.cos(2.29051265602 + 32.5039613453*t)
	Y1 += 0.00000007714*np.cos(3.51057462873 + 65.2203710117*t)
	Y1 += 0.00000008270*np.cos(1.13810834747 + 105.4922706636*t)
	Y1 += 0.00000007980*np.cos(4.52758219936 + 9.5612275556*t)
	Y1 += 0.00000007336*np.cos(3.43409658476 + 15.4991183888*t)
	Y1 += 0.00000009601*np.cos(5.68191241461 + 80.7194894005*t)
	Y1 += 0.00000008959*np.cos(3.92082324720 + 146.594251718*t)
	Y1 += 0.00000007060*np.cos(5.58846404838 + 64.9597385808*t)
	Y1 += 0.00000007826*np.cos(2.45321405406 + 76.7873361374*t)
	Y1 += 0.00000007134*np.cos(2.05010275252 + 43.7621099303*t)
	Y1 += 0.00000007998*np.cos(5.93005561135 + 6244.9428143536*t)
	Y1 += 0.00000006729*np.cos(2.56827053883 + 144.1465711632*t)
	Y1 += 0.00000006573*np.cos(6.28006224390 + 25.6028626656*t)
	Y1 += 0.00000006341*np.cos(5.24912051627 + 66.70484372*t)
	Y1 += 0.00000007564*np.cos(1.06571720473 + 10175.1525105732*t)
	Y1 += 0.00000006428*np.cos(3.47621435986 + 678.0303219518*t)
	Y1 += 0.00000005483*np.cos(2.72811022429 + 42.0651889009*t)
	Y1 += 0.00000005483*np.cos(1.61247704205 + 34.2008823747*t)
	Y1 += 0.00000005441*np.cos(3.41928615882 + 449.232108125*t)
	Y1 += 0.00000006239*np.cos(4.20987230620 + 17.5261078183*t)
	Y1 += 0.00000005939*np.cos(4.74218001055 + 75.7448064138*t)
	Y1 += 0.00000005390*np.cos(3.54636234855 + 81.3738807063*t)
	Y1 += 0.00000005182*np.cos(3.16168083040 + 525.4981794006*t)
	Y1 += 0.00000005222*np.cos(4.93016626365 + 39.0962434843*t)
	Y1 += 0.00000005325*np.cos(2.82680294530 + 19.0105805266*t)
	Y1 += 0.00000004910*np.cos(3.47707268498 + 45.0341343175*t)
	Y1 += 0.00000005250*np.cos(0.16559323231 + 0.9632078465*t)
	Y1 += 0.00000004731*np.cos(1.20748690143 + 36.1272980677*t)
	Y1 += 0.00000004731*np.cos(6.27469301850 + 40.1387732079*t)
	Y1 += 0.00000005910*np.cos(1.40564906034 + 6168.676743078*t)
	Y1 += 0.00000004700*np.cos(4.66313687747 + 50.66320861*t)
	Y1 += 0.00000005127*np.cos(1.64028838320 + 141.1776257466*t)
	Y1 += 0.00000005321*np.cos(2.09943183100 + 1104.6285128278*t)
	Y1 += 0.00000005523*np.cos(0.16906422296 + 180.2738692309*t)
	Y1 += 0.00000004982*np.cos(1.46132044511 + 1090.4014188262*t)
	Y1 += 0.00000004689*np.cos(5.95510315658 + 1067.9799498983*t)
	Y1 += 0.00000005562*np.cos(2.83480459801 + 10098.8864392976*t)
	Y1 += 0.00000004432*np.cos(0.83560291416 + 415.5524906121*t)
	Y1 += 0.00000004616*np.cos(6.01316355451 + 291.7040307277*t)
	Y1 += 0.00000004476*np.cos(1.46463751196 + 235.933012687*t)
	Y1 += 0.00000004225*np.cos(3.28869103693 + 416.7763308895*t)
	Y1 += 0.00000004293*np.cos(4.40423090446 + 1050.7839104801*t)
	Y1 += 0.00000004363*np.cos(1.54131949663 + 493.0424021651*t)
	Y1 += 0.00000004088*np.cos(3.88661191294 + 423.4167971383*t)
	Y1 += 0.00000005207*np.cos(2.06476816654 + 313.6835566709*t)
	Y1 += 0.00000005027*np.cos(2.86874047797 + 21.4582610814*t)
	Y1 += 0.00000004076*np.cos(0.66240216055 + 1127.2624300768*t)
	Y1 += 0.00000004013*np.cos(2.96768055201 + 104275.34649502118*t)
	Y1 += 0.00000004526*np.cos(1.70990186850 + 921.0768816396*t)
	Y1 += 0.00000003962*np.cos(5.59161595323 + 979.1837056505*t)
	Y1 += 0.00000005073*np.cos(5.15284041286 + 1498.5797300066*t)
	Y1 += 0.00000005320*np.cos(3.36313436060 + 1409.7140497896*t)
	Y1 += 0.00000004227*np.cos(6.19959499735 + 534.1443832195*t)
	Y1 += 0.00000004054*np.cos(2.45805491894 + 429.7795846137*t)
	Y1 += 0.00000005259*np.cos(5.55262009555 + 532.8723588323*t)
	Y1 += 0.00000005226*np.cos(1.93617859736 + 526.5095713569*t)
	Y1 += 0.00000003934*np.cos(2.24314037395 + 67.3592350258*t)
	Y1 += 0.00000004367*np.cos(0.14073509950 + 58.7399634573*t)
	Y1 += 0.00000004788*np.cos(2.92950139342 + 137.0330241624*t)
	Y1 += 0.00000004039*np.cos(5.37066457206 + 1623.0131452276*t)
	Y1 += 0.00000004159*np.cos(0.13477801653 + 500.1559491659*t)
	Y1 += 0.00000004139*np.cos(5.19531357710 + 518.3846323998*t)
	Y1 += 0.00000004832*np.cos(1.21348865282 + 418.0001711669*t)
	Y1 += 0.00000004017*np.cos(6.16070359357 + 310.7146112543*t)
	Y1 += 0.00000003726*np.cos(4.94146146407 + 1065.0110044817*t)
	Y1 += 0.00000003625*np.cos(1.85386744343 + 1022.7333672597*t)
	Y1 += 0.00000003887*np.cos(0.79597881268 + 913.9633346388*t)
	Y1 += 0.00000004341*np.cos(1.50696795030 + 366.485629295*t)
	Y1 += 0.00000003592*np.cos(0.47546131414 + 381.3516082374*t)
	Y1 += 0.00000004729*np.cos(2.19682932875 + 420.9691165835*t)
	Y1 += 0.00000003490*np.cos(0.54755432663 + 987.0480121767*t)
	Y1 += 0.00000004057*np.cos(0.64472041756 + 485.9288551643*t)
	Y1 += 0.00000003715*np.cos(1.30911252065 + 254.3528923826*t)
	Y1 += 0.00000003488*np.cos(5.95100033083 + 187.6962327724*t)
	Y1 += 0.00000003485*np.cos(0.03809274459 + 68.8437077341*t)
	Y1 += 0.00000003664*np.cos(1.69662357801 + 807.9497991134*t)
	Y1 += 0.00000003538*np.cos(1.51952071989 + 57.255490749*t)
	Y1 += 0.00000003838*np.cos(3.56891114817 + 980.146913497*t)
	Y1 += 0.00000004165*np.cos(4.46350696624 + 59.2824801785*t)
	Y1 += 0.00000003318*np.cos(5.85573072328 + 565.1156877467*t)
	Y1 += 0.00000003420*np.cos(4.82347868865 + 1028.3624415522*t)
	Y1 += 0.00000003759*np.cos(2.39206131226 + 107.4980082337*t)
	Y1 += 0.00000004048*np.cos(6.25249995325 + 979.9344651759*t)
	Y1 += 0.00000003296*np.cos(3.06238445589 + 176.6505325085*t)
	Y1 += 0.00000004414*np.cos(2.00416419002 + 1062.3508756058*t)
	Y1 += 0.00000003382*np.cos(3.22744171540 + 29.226199388*t)
	Y1 += 0.00000003384*np.cos(5.39221030070 + 1543.8263126452*t)
	Y1 += 0.00000003626*np.cos(1.61404627502 + 215.4379594521*t)
	Y1 += 0.00000003353*np.cos(2.30310064817 + 10289.5516174866*t)
	Y1 += 0.00000003213*np.cos(0.83729921110 + 569.3084734407*t)
	Y1 += 0.00000003353*np.cos(1.62614357452 + 157.6399519819*t)
	Y1 += 0.00000003339*np.cos(5.26711707260 + 443.3424014016*t)
	Y1 += 0.00000003188*np.cos(2.62886149123 + 361.3778198643*t)
	Y1 += 0.00000004305*np.cos(4.82335484115 + 67.8804998876*t)
	Y1 += 0.00000003156*np.cos(6.23564975260 + 432.0842528166*t)
	Y1 += 0.00000003757*np.cos(2.02840243925 + 296.1574488526*t)
	Y1 += 0.00000003956*np.cos(2.45889174563 + 837.6972633632*t)
	Y1 += 0.00000003138*np.cos(0.63906502937 + 347.3631741838*t)
	Y1 += 0.00000003097*np.cos(1.67133697086 + 392.6579409322*t)
	Y1 += 0.00000003407*np.cos(4.50916961239 + 911.042573332*t)
	Y1 += 0.00000003139*np.cos(3.10000522918 + 159.1244246902*t)
	Y1 += 0.00000003057*np.cos(0.53956960156 + 275.5505210331*t)
	Y1 += 0.00000003466*np.cos(3.47360810007 + 2145.5905633214*t)
	Y1 += 0.00000003286*np.cos(1.82621148682 + 435.1962105851*t)
	Y1 += 0.00000003023*np.cos(5.51732785208 + 1055.1891444952*t)
	Y1 += 0.00000003660*np.cos(3.52092865004 + 449.2802922348*t)
	Y1 += 0.00000003080*np.cos(4.35867233934 + 457.617679513*t)
	Y1 += 0.00000003610*np.cos(1.47397187781 + 54.8078101942*t)
	Y1 += 0.00000002934*np.cos(5.93987994099 + 385.4962098216*t)
	Y1 += 0.00000002968*np.cos(1.28092864924 + 613.070583371*t)
	Y1 += 0.00000003097*np.cos(4.42119013611 + 1395.486955788*t)
	Y1 += 0.00000003072*np.cos(2.35160808374 + 104.0077979553*t)
	Y1 += 0.00000002928*np.cos(3.61628849687 + 1131.4552157708*t)
	Y1 += 0.00000002964*np.cos(5.82221270663 + 529.6909650946*t)
	Y1 += 0.00000003216*np.cos(2.85672087782 + 53.653405886*t)
	Y1 += 0.00000003013*np.cos(1.49528242656 + 120.9913890524*t)
	Y1 += 0.00000003941*np.cos(5.42722030012 + 113.1270825262*t)
	Y1 += 0.00000002827*np.cos(0.36861231244 + 429.5671362926*t)
	Y1 += 0.00000003348*np.cos(3.55163029540 + 6284.5603226997*t)
	Y1 += 0.00000002761*np.cos(4.37904322361 + 151.0476698429*t)
	Y1 += 0.00000003177*np.cos(5.67750443438 + 1558.0534066468*t)
	Y1 += 0.00000003228*np.cos(5.13697528251 + 52.3601296394*t)
	Y1 += 0.00000002840*np.cos(2.42348379224 + 384.2723695442*t)
	Y1 += 0.00000002845*np.cos(5.41520284472 + 145.1097790097*t)
	Y1 += 0.00000002870*np.cos(2.30263492521 + 388.4651552382*t)
	Y1 += 0.00000003021*np.cos(6.10532674477 + 328.3525936572*t)
	Y1 += 0.00000003099*np.cos(0.00256943840 + 494.4786907636*t)
	Y1 += 0.00000002734*np.cos(0.79845484023 + 432.2272651685*t)
	Y1 += 0.00000003171*np.cos(4.97186997436 + 10214.7700189193*t)
	Y1 += 0.00000003188*np.cos(0.38503108962 + 480.251596762*t)
	Y1 += 0.00000002674*np.cos(2.29256356627 + 158.3736651648*t)
	Y1 += 0.00000002902*np.cos(4.22938715950 + 559.2259810233*t)
	Y1 += 0.00000002631*np.cos(4.21067635648 + 2008.557539159*t)
	Y1 += 0.00000003633*np.cos(4.69734452582 + 491.5579294568*t)
	Y1 += 0.00000002695*np.cos(4.24750819850 + 326.4261779642*t)
	Y1 += 0.00000002765*np.cos(5.71162682199 + 248.4631856592*t)
	Y1 += 0.00000002852*np.cos(2.90612685298 + 186.472392495*t)
	Y1 += 0.00000003051*np.cos(6.23496246125 + 6281.5913772831*t)
	Y1 += 0.00000003392*np.cos(2.32329544675 + 278.2588340188*t)
	Y1 += 0.00000002837*np.cos(6.07083243848 + 419.7452763061*t)
	Y1 += 0.00000002865*np.cos(4.16931772851 + 830.5837163624*t)
	Y1 += 0.00000002675*np.cos(1.31332124432 + 525.2375469697*t)
	Y1 += 0.00000002860*np.cos(3.66488634500 + 844.810810364*t)
	Y1 += 0.00000002565*np.cos(5.86862143229 + 348.8476468921*t)
	Y1 += 0.00000002904*np.cos(2.17328621808 + 906.849787638*t)
	Y1 += 0.00000003031*np.cos(2.55943985975 + 406.1031376411*t)
	Y1 += 0.00000002908*np.cos(3.71503425447 + 573.4530750249*t)
	Y1 += 0.00000003246*np.cos(4.06096110514 + 183.2428146475*t)
	Y1 += 0.00000002723*np.cos(4.44833095962 + 2.4476805548*t)
	Y1 += 0.00000002453*np.cos(0.39357442205 + 526.9826521089*t)
	Y1 += 0.00000003321*np.cos(3.87616257520 + 450.2435000813*t)
	Y1 += 0.00000003117*np.cos(4.74251087639 + 457.5694954032*t)
	Y1 += 0.00000002935*np.cos(1.67483427090 + 403.1341922245*t)
	Y1 += 0.00000002899*np.cos(1.37722380308 + 10211.8010735027*t)
	Y1 += 0.00000002458*np.cos(3.74216842693 + 450.9772132642*t)
	Y1 += 0.00000002490*np.cos(0.03400718295 + 647.0108333148*t)
	Y1 += 0.00000002614*np.cos(3.35465019548 + 946.4672959841*t)
	Y1 += 0.00000002454*np.cos(3.27913428159 + 195.7729876197*t)
	Y1 += 0.00000002539*np.cos(5.12479568135 + 149.5631971346*t)
	Y1 += 0.00000002412*np.cos(2.52729370230 + 846.0828347512*t)
	Y1 += 0.00000002878*np.cos(2.01178758298 + 947.9517686924*t)
	Y1 += 0.00000002546*np.cos(0.23206052693 + 1062.5633239269*t)
	Y1 += 0.00000002790*np.cos(5.78270630930 + 697.743477894*t)
	Y1 += 0.00000002387*np.cos(2.04192024025 + 654.1243803156*t)
	Y1 += 0.00000002443*np.cos(2.11904462744 + 693.55069220*t)
	Y1 += 0.00000002439*np.cos(1.45718608643 + 462.9861213746*t)
	Y1 += 0.00000002435*np.cos(0.99424789953 + 477.3308354552*t)
	Y1 += 0.00000002581*np.cos(4.06244202199 + 425.3743505986*t)
	Y1 += 0.00000002334*np.cos(1.68184256681 + 555.0331953293*t)
	Y1 += 0.00000002362*np.cos(0.36460504865 + 351.8165923087*t)
	Y1 += 0.00000002369*np.cos(2.75840527054 + 107.2855599126*t)
	Y1 += 0.00000002535*np.cos(4.19023254986 + 481.4754370394*t)
	Y1 += 0.00000003120*np.cos(1.20504579288 + 456.6062875567*t)
	Y1 += 0.00000002587*np.cos(1.59303622302 + 401.0647641796*t)
	Y1 += 0.00000002426*np.cos(2.07131427970 + 1050.9963588012*t)
	Y1 += 0.00000002261*np.cos(3.24988095731 + 644.090072008*t)
	Y1 += 0.00000002749*np.cos(0.33097945934 + 216.9224321604*t)
	Y1 += 0.00000002394*np.cos(0.13381278422 + 147.1155165798*t)
	Y1 += 0.00000002966*np.cos(4.08510494827 + 219.891377577*t)
	Y1 += 0.00000002896*np.cos(0.71994184395 + 1685.0521225016*t)
	Y1 += 0.00000002459*np.cos(3.66216487095 + 1019.7644218431*t)
	Y1 += 0.00000002325*np.cos(0.25393903829 + 443.1299530805*t)
	Y1 += 0.00000002385*np.cos(3.75336774830 + 598.8434893694*t)
	Y1 += 0.00000002853*np.cos(5.16708681764 + 170.7126416753*t)
	Y1 += 0.00000002219*np.cos(2.47902567598 + 558.0021407459*t)
	Y1 += 0.00000002857*np.cos(5.13991932453 + 834.7765020564*t)
	Y1 += 0.00000002233*np.cos(4.37347994263 + 709.0498105888*t)
	Y1 += 0.00000002336*np.cos(2.73654472145 + 210.3301500214*t)
	Y1 += 0.00000002258*np.cos(5.24636256977 + 29.7474642498*t)
	Y1 += 0.00000002504*np.cos(4.69350029091 + 659.6104422562*t)
	Y1 += 0.00000002398*np.cos(5.59175728161 + 23.9059416362*t)
	Y1 += 0.00000002300*np.cos(2.19835194508 + 986.2972526513*t)
	Y1 += 0.00000002198*np.cos(1.21301903023 + 605.9570363702*t)
	Y1 += 0.00000002643*np.cos(4.92601181391 + 14.2270940016*t)
	return Y1*t




def Neptune_Y2 (t): # 79 terms of order 2

	Y2 = 0.
	Y2 += 0.00004539421*np.cos(3.45613207922 + 36.6485629295*t)
	Y2 += 0.00004347956*np.cos(0.88317230351 + 39.6175083461*t)
	Y2 -= 0.00003651208
	Y2 += 0.00003058647*np.cos(5.31956613665 + 38.1330356378*t)
	Y2 += 0.00002163809*np.cos(0.22086532214 + 76.2660712756*t)
	Y2 += 0.00000394632*np.cos(4.10915465726 + 35.1640902212*t)
	Y2 += 0.00000301094*np.cos(0.24659723217 + 41.1019810544*t)
	Y2 += 0.00000186626*np.cos(0.85138234128 + 2.9689454166*t)
	Y2 += 0.00000114478*np.cos(4.77209191510 + 35.685355083*t)
	Y2 += 0.00000105947*np.cos(5.85174809888 + 40.5807161926*t)
	Y2 += 0.00000074114*np.cos(3.45086633035 + 73.297125859*t)
	Y2 += 0.00000055174*np.cos(5.66551452151 + 1.4844727083*t)
	Y2 += 0.00000048440*np.cos(4.96907121134 + 33.6796175129*t)
	Y2 += 0.00000040074*np.cos(0.15979944642 + 4.4534181249*t)
	Y2 += 0.00000038264*np.cos(5.61111117498 + 42.5864537627*t)
	Y2 += 0.00000036741*np.cos(1.66899943529 + 74.7815985673*t)
	Y2 += 0.00000034068*np.cos(1.35876855791 + 98.8999885246*t)
	Y2 += 0.00000035542*np.cos(0.93237309219 + 31.019488637*t)
	Y2 += 0.00000031377*np.cos(1.82535381711 + 28.5718080822*t)
	Y2 += 0.00000032195*np.cos(3.40544588666 + 45.2465826386*t)
	Y2 += 0.00000033753*np.cos(4.89394943800 + 114.3991069134*t)
	Y2 += 0.00000024149*np.cos(2.51309690251 + 47.6942631934*t)
	Y2 += 0.00000021599*np.cos(0.13027047872 + 7.1135470008*t)
	Y2 += 0.00000017601*np.cos(4.23571655619 + 71.8126531507*t)
	Y2 += 0.00000012773*np.cos(1.36566781679 + 60.7669528868*t)
	Y2 += 0.00000010585*np.cos(4.37749847574 + 33.9402499438*t)
	Y2 += 0.00000009255*np.cos(6.18826752854 + 42.3258213318*t)
	Y2 += 0.00000009614*np.cos(4.21849838607 + 69.1525242748*t)
	Y2 += 0.00000006548*np.cos(0.70267550536 + 30.0562807905*t)
	Y2 += 0.00000006050*np.cos(6.11606563250 + 32.1951448046*t)
	Y2 += 0.00000006682*np.cos(3.28438142988 + 258.5456780766*t)
	Y2 += 0.00000005625*np.cos(1.49377279665 + 8.0767548473*t)
	Y2 += 0.00000007253*np.cos(4.88574084344 + 1097.514965827*t)
	Y2 += 0.00000005245*np.cos(4.48532162531 + 44.070926471*t)
	Y2 += 0.00000005436*np.cos(3.37011457963 + 106.0135355254*t)
	Y2 += 0.00000004786*np.cos(3.69029400651 + 46.2097904851*t)
	Y2 += 0.00000004497*np.cos(5.71847029312 + 77.7505439839*t)
	Y2 += 0.00000004688*np.cos(0.95059652202 + 221.8971151471*t)
	Y2 += 0.00000005380*np.cos(1.15105932580 + 22.633917249*t)
	Y2 += 0.00000004607*np.cos(0.17860892586 + 549.4041210368*t)
	Y2 += 0.00000004266*np.cos(3.94282464621 + 204.7010757289*t)
	Y2 += 0.00000003835*np.cos(1.55364159137 + 536.8045120954*t)
	Y2 += 0.00000003916*np.cos(4.92658748989 + 207.6700211455*t)
	Y2 += 0.00000004138*np.cos(0.27513803340 + 305.0855369618*t)
	Y2 += 0.00000003671*np.cos(2.58949786953 + 319.3126309634*t)
	Y2 += 0.00000004833*np.cos(5.97669363185 + 214.7835681463*t)
	Y2 += 0.00000003533*np.cos(1.40857053777 + 206.1855484372*t)
	Y2 += 0.00000003288*np.cos(3.02036611242 + 408.1783111804*t)
	Y2 += 0.00000003149*np.cos(1.48284827660 + 343.2185725996*t)
	Y2 += 0.00000003347*np.cos(5.37102947878 + 531.1754378029*t)
	Y2 += 0.00000003932*np.cos(5.23322820132 + 91.7864415238*t)
	Y2 += 0.00000003754*np.cos(4.23519325050 + 944.9828232758*t)
	Y2 += 0.00000002967*np.cos(5.75718562310 + 860.3099287528*t)
	Y2 += 0.00000002924*np.cos(5.76000036541 + 103.0927742186*t)
	Y2 += 0.00000003974*np.cos(3.61988886252 + 336.1050255988*t)
	Y2 += 0.00000002818*np.cos(4.60765817864 + 1028.3624415522*t)
	Y2 += 0.00000002906*np.cos(2.33273313695 + 666.723989257*t)
	Y2 += 0.00000002999*np.cos(2.84956030053 + 937.869276275*t)
	Y2 += 0.00000003346*np.cos(3.07225023130 + 1162.4747044078*t)
	Y2 += 0.00000002925*np.cos(3.14539168453 + 235.933012687*t)
	Y2 += 0.00000002577*np.cos(5.19659933863 + 1073.6090241908*t)
	Y2 += 0.00000002576*np.cos(1.40688347976 + 26.826702943*t)
	Y2 += 0.00000002537*np.cos(3.31911455778 + 453.424893819*t)
	Y2 += 0.00000002542*np.cos(2.65219065285 + 1265.5674786264*t)
	Y2 += 0.00000002513*np.cos(3.13540704008 + 274.0660483248*t)
	Y2 += 0.00000002512*np.cos(5.05292759621 + 425.1137181677*t)
	Y2 += 0.00000002715*np.cos(3.33675296654 + 563.6312150384*t)
	Y2 += 0.00000002676*np.cos(1.03964391295 + 454.9093665273*t)
	Y2 += 0.00000002948*np.cos(1.39017874119 + 149.5631971346*t)
	Y2 += 0.00000003237*np.cos(3.96277689550 + 532.8723588323*t)
	Y2 += 0.00000002343*np.cos(3.50680783274 + 981.6313862053*t)
	Y2 += 0.00000002501*np.cos(3.24490790448 + 669.6447505638*t)
	Y2 += 0.00000002600*np.cos(2.68967944960 + 518.3846323998*t)
	Y2 += 0.00000003192*np.cos(3.51988755581 + 526.5095713569*t)
	Y2 += 0.00000002481*np.cos(0.85513013918 + 655.4176565622*t)
	Y2 += 0.00000002569*np.cos(2.65543572954 + 464.7312265138*t)
	Y2 += 0.00000003029*np.cos(4.41598697999 + 129.9194771616*t)
	Y2 += 0.00000002469*np.cos(5.36564537139 + 952.0963702766*t)
	Y2 += 0.00000002911*np.cos(1.43497141751 + 312.1990839626*t)
	return Y2*t*t




def Neptune_Y3 (t): # 28 terms of order 3

	Y3 = 0.
	Y3 += 0.00000192703*np.cos(5.55088601013 + 36.6485629295*t)
	Y3 += 0.00000182218*np.cos(5.07306416874 + 39.6175083461*t)
	Y3 += 0.00000178702
	Y3 += 0.00000130731*np.cos(2.18169161636 + 38.1330356378*t)
	Y3 += 0.00000085913*np.cos(5.13938436433 + 76.2660712756*t)
	Y3 += 0.00000021976*np.cos(0.35990434774 + 35.1640902212*t)
	Y3 += 0.00000019807*np.cos(3.98068286016 + 41.1019810544*t)
	Y3 += 0.00000014300*np.cos(4.78800593446 + 7.1135470008*t)
	Y3 += 0.00000006772*np.cos(5.90918311556 + 69.1525242748*t)
	Y3 += 0.00000004516*np.cos(1.71813250497 + 45.2465826386*t)
	Y3 += 0.00000004524*np.cos(2.61630263117 + 31.019488637*t)
	Y3 += 0.00000003668*np.cos(2.97575518967 + 98.8999885246*t)
	Y3 += 0.00000003656*np.cos(2.17225276546 + 968.888764912*t)
	Y3 += 0.00000003625*np.cos(4.19846251857 + 484.444382456*t)
	Y3 += 0.00000003199*np.cos(3.24405632993 + 1519.920371009*t)
	Y3 += 0.00000003498*np.cos(4.84555442740 + 408.1783111804*t)
	Y3 += 0.00000003304*np.cos(3.81824435305 + 422.405405182*t)
	Y3 += 0.00000003504*np.cos(3.04074125117 + 498.6714764576*t)
	Y3 += 0.00000002689*np.cos(5.61172759773 + 440.8252848776*t)
	Y3 += 0.00000002662*np.cos(2.02690818443 + 305.0855369618*t)
	Y3 += 0.00000002644*np.cos(0.90420046363 + 462.0229135281*t)
	Y3 += 0.00000002578*np.cos(5.32866422293 + 395.578702239*t)
	Y3 += 0.00000002542*np.cos(1.05107150537 + 444.8268741099*t)
	Y3 += 0.00000002471*np.cos(0.92256756337 + 319.3126309634*t)
	Y3 += 0.00000002354*np.cos(2.03258956751 + 447.7958195265*t)
	Y3 += 0.00000002876*np.cos(3.65434826122 + 853.196381752*t)
	Y3 += 0.00000002279*np.cos(6.20788162950 + 459.0539681115*t)
	Y3 += 0.00000002147*np.cos(1.06532572636 + 175.1660598002*t)
	return Y3*t*t*t




def Neptune_Y4 (t): # 5 terms of order 4

	Y4 = 0.
	Y4 += 0.00000004229*np.cos(6.14485774863 + 515.463871093*t)
	Y4 += 0.00000004334*np.cos(3.84569500845 + 433.7117378768*t)
	Y4 += 0.00000003547*np.cos(1.04321243122 + 990.2294059144*t)
	Y4 += 0.00000003155*np.cos(0.14082926066 + 467.6519878206*t)
	Y4 += 0.00000002586*np.cos(4.77727956483 + 227.5261894396*t)
	return Y4*t*t*t*t




def Neptune_Y5 (t): # 1 term of order 5

	Y5 = 0.
	Y5 += 0.00000000000
	return Y5*t*t*t*t*t




def Neptune_Z0 (t): # 126 terms of order 0

	Z0 = 0.
	Z0 += 0.92861252357*np.cos(1.44103930199 + 38.1330356378*t)
	Z0 += 0.01244825806
	Z0 += 0.00474309033*np.cos(2.52218768352 + 36.6485629295*t)
	Z0 += 0.00451964646*np.cos(3.50949727943 + 39.6175083461*t)
	Z0 += 0.00417539868*np.cos(5.91308871390 + 76.2660712756*t)
	Z0 += 0.00084101913*np.cos(4.38932612685 + 1.4844727083*t)
	Z0 += 0.00032204313*np.cos(1.48923465055 + 74.7815985673*t)
	Z0 += 0.00030871862*np.cos(3.29017492215 + 35.1640902212*t)
	Z0 += 0.00025811465*np.cos(3.19303929710 + 2.9689454166*t)
	Z0 += 0.00016864457*np.cos(2.13251137546 + 41.1019810544*t)
	Z0 += 0.00009774680*np.cos(2.80201767484 + 73.297125859*t)
	Z0 += 0.00004119576*np.cos(1.67942813460 + 77.7505439839*t)
	Z0 += 0.00002818034*np.cos(4.10661077794 + 114.3991069134*t)
	Z0 += 0.00002868677*np.cos(4.27011526203 + 33.6796175129*t)
	Z0 += 0.00002213464*np.cos(1.96045135168 + 4.4534181249*t)
	Z0 += 0.00001865261*np.cos(5.05510390418 + 71.8126531507*t)
	Z0 += 0.00000840177*np.cos(0.94268885160 + 42.5864537627*t)
	Z0 += 0.00000457516*np.cos(5.71650412080 + 108.4612160802*t)
	Z0 += 0.00000530252*np.cos(0.85800267793 + 111.4301614968*t)
	Z0 += 0.00000490859*np.cos(6.07827301209 + 112.9146342051*t)
	Z0 += 0.00000331254*np.cos(0.29304964526 + 70.3281804424*t)
	Z0 += 0.00000277675*np.cos(1.45401569135 + 148.0787244263*t)
	Z0 += 0.00000274474*np.cos(5.42657022437 + 32.1951448046*t)
	Z0 += 0.00000205306*np.cos(0.75818737085 + 5.9378908332*t)
	Z0 += 0.00000173516*np.cos(5.85498030099 + 145.1097790097*t)
	Z0 += 0.00000141275*np.cos(1.73147597657 + 28.5718080822*t)
	Z0 += 0.00000139093*np.cos(1.67466701191 + 184.7272873558*t)
	Z0 += 0.00000143647*np.cos(2.51620047812 + 37.611770776*t)
	Z0 += 0.00000136955*np.cos(0.20339778664 + 79.2350166922*t)
	Z0 += 0.00000126296*np.cos(4.40661385040 + 37.1698277913*t)
	Z0 += 0.00000120906*np.cos(1.61767636602 + 39.0962434843*t)
	Z0 += 0.00000111761*np.cos(6.20948230785 + 98.8999885246*t)
	Z0 += 0.00000140758*np.cos(3.50944989694 + 38.6543004996*t)
	Z0 += 0.00000111589*np.cos(4.18561395578 + 47.6942631934*t)
	Z0 += 0.00000133509*np.cos(4.78977105547 + 38.084851528*t)
	Z0 += 0.00000102622*np.cos(0.81673762159 + 4.192785694*t)
	Z0 += 0.00000133292*np.cos(1.23386935925 + 38.1812197476*t)
	Z0 += 0.00000098771*np.cos(0.72335005782 + 106.9767433719*t)
	Z0 += 0.00000074559*np.cos(2.31518880439 + 312.1990839626*t)
	Z0 += 0.00000074401*np.cos(5.99935727164 + 181.7583419392*t)
	Z0 += 0.00000073141*np.cos(1.80069951634 + 137.0330241624*t)
	Z0 += 0.00000066838*np.cos(1.87185330904 + 221.3758502853*t)
	Z0 += 0.00000058303*np.cos(5.61662561548 + 35.685355083*t)
	Z0 += 0.00000051685*np.cos(6.02831347649 + 44.070926471*t)
	Z0 += 0.00000051928*np.cos(0.40473854286 + 40.5807161926*t)
	Z0 += 0.00000048182*np.cos(2.97141991737 + 37.8724032069*t)
	Z0 += 0.00000049439*np.cos(1.66178905717 + 68.8437077341*t)
	Z0 += 0.00000047742*np.cos(3.05261105371 + 38.3936680687*t)
	Z0 += 0.00000046428*np.cos(2.66596739242 + 146.594251718*t)
	Z0 += 0.00000050936*np.cos(0.19994012329 + 30.0562807905*t)
	Z0 += 0.00000041127*np.cos(6.05239303825 + 115.8835796217*t)
	Z0 += 0.00000055537*np.cos(2.11977296055 + 109.9456887885*t)
	Z0 += 0.00000041357*np.cos(0.86667380713 + 143.6253063014*t)
	Z0 += 0.00000037856*np.cos(5.19945796177 + 72.0732855816*t)
	Z0 += 0.00000047361*np.cos(3.58964541604 + 38.0211610532*t)
	Z0 += 0.00000034690*np.cos(1.47398766326 + 8.0767548473*t)
	Z0 += 0.00000037349*np.cos(5.15067903040 + 33.9402499438*t)
	Z0 += 0.00000034386*np.cos(6.15246630929 + 218.4069048687*t)
	Z0 += 0.00000047180*np.cos(2.43405967107 + 38.2449102224*t)
	Z0 += 0.00000034730*np.cos(1.39045518365 + 213.299095438*t)
	Z0 += 0.00000035742*np.cos(0.34857928455 + 149.5631971346*t)
	Z0 += 0.00000033382*np.cos(0.88396990078 + 42.3258213318*t)
	Z0 += 0.00000033071*np.cos(2.02572550598 + 258.0244132148*t)
	Z0 += 0.00000038849*np.cos(5.79294381756 + 46.2097904851*t)
	Z0 += 0.00000027605*np.cos(2.81540405940 + 183.2428146475*t)
	Z0 += 0.00000024616*np.cos(0.40597272412 + 30.7106720963*t)
	Z0 += 0.00000021716*np.cos(0.90792314747 + 175.1660598002*t)
	Z0 += 0.00000021634*np.cos(3.25469228647 + 388.4651552382*t)
	Z0 += 0.00000020384*np.cos(5.80954414865 + 7.4223635415*t)
	Z0 += 0.00000018640*np.cos(1.06424642993 + 180.2738692309*t)
	Z0 += 0.00000016716*np.cos(0.02332590259 + 255.0554677982*t)
	Z0 += 0.00000018790*np.cos(0.62408059806 + 35.212274331*t)
	Z0 += 0.00000016990*np.cos(2.19726523790 + 294.6729761443*t)
	Z0 += 0.00000016083*np.cos(4.20629091415 + 0.9632078465*t)
	Z0 += 0.00000021571*np.cos(2.39337706760 + 152.5321425512*t)
	Z0 += 0.00000017009*np.cos(1.33850584943 + 7.1135470008*t)
	Z0 += 0.00000017102*np.cos(5.39964889794 + 41.0537969446*t)
	Z0 += 0.00000015218*np.cos(2.93182248771 + 219.891377577*t)
	Z0 += 0.00000014757*np.cos(2.02029526083 + 105.4922706636*t)
	Z0 += 0.00000013582*np.cos(0.99222619680 + 44.7253177768*t)
	Z0 += 0.00000011309*np.cos(4.15253392707 + 487.3651437628*t)
	Z0 += 0.00000012521*np.cos(0.41449986025 + 186.2117600641*t)
	Z0 += 0.00000012363*np.cos(3.07599476497 + 6.592282139*t)
	Z0 += 0.00000010825*np.cos(4.13817476053 + 0.5212648618*t)
	Z0 += 0.00000014304*np.cos(5.15644933777 + 31.5407534988*t)
	Z0 += 0.00000009355*np.cos(1.23360360711 + 216.9224321604*t)
	Z0 += 0.00000008774*np.cos(5.77195684843 + 12.5301729722*t)
	Z0 += 0.00000008445*np.cos(0.17584724644 + 291.7040307277*t)
	Z0 += 0.00000008927*np.cos(2.36869187243 + 331.3215390738*t)
	Z0 += 0.00000009613*np.cos(0.28151591238 + 60.7669528868*t)
	Z0 += 0.00000008279*np.cos(5.72084525545 + 36.7604375141*t)
	Z0 += 0.00000009111*np.cos(3.49027191661 + 45.2465826386*t)
	Z0 += 0.00000008178*np.cos(0.25637861075 + 39.5056337615*t)
	Z0 += 0.00000008598*np.cos(3.10287346009 + 256.5399405065*t)
	Z0 += 0.00000009489*np.cos(4.94205919676 + 151.0476698429*t)
	Z0 += 0.00000008564*np.cos(2.15904622462 + 274.0660483248*t)
	Z0 += 0.00000007474*np.cos(2.93279436008 + 27.0873353739*t)
	Z0 += 0.00000007132*np.cos(1.50971234331 + 944.9828232758*t)
	Z0 += 0.00000007642*np.cos(5.56097006597 + 187.6962327724*t)
	Z0 += 0.00000007705*np.cos(1.54152595157 + 84.3428261229*t)
	Z0 += 0.00000006896*np.cos(4.71453324740 + 406.1031376411*t)
	Z0 += 0.00000006090*np.cos(4.48506819561 + 415.2918581812*t)
	Z0 += 0.00000006316*np.cos(0.59502514374 + 453.424893819*t)
	Z0 += 0.00000006177*np.cos(5.20115334051 + 80.7194894005*t)
	Z0 += 0.00000006324*np.cos(2.18406254461 + 142.1408335931*t)
	Z0 += 0.00000005646*np.cos(0.76840537906 + 11.0457002639*t)
	Z0 += 0.00000006102*np.cos(5.58764378724 + 662.531203563*t)
	Z0 += 0.00000006269*np.cos(1.95162790177 + 605.9570363702*t)
	Z0 += 0.00000005591*np.cos(5.20631788297 + 14.0146456805*t)
	Z0 += 0.00000004914*np.cos(1.39906038110 + 253.5709950899*t)
	Z0 += 0.00000004610*np.cos(5.85854264972 + 433.7117378768*t)
	Z0 += 0.00000004519*np.cos(2.07610590431 + 2042.4977891028*t)
	Z0 += 0.00000005681*np.cos(4.80791039970 + 641.1211265914*t)
	Z0 += 0.00000006294*np.cos(0.56936923702 + 31.019488637*t)
	Z0 += 0.00000004758*np.cos(2.54312258712 + 367.9701020033*t)
	Z0 += 0.00000004406*np.cos(0.33696669222 + 328.3525936572*t)
	Z0 += 0.00000004390*np.cos(5.08949604858 + 286.596221297*t)
	Z0 += 0.00000004678*np.cos(4.87546696295 + 442.7517005706*t)
	Z0 += 0.00000004407*np.cos(5.58110402011 + 252.0865223816*t)
	Z0 += 0.00000004305*np.cos(1.31724140028 + 493.0424021651*t)
	Z0 += 0.00000004770*np.cos(1.62157166125 + 316.3918696566*t)
	Z0 += 0.00000005314*np.cos(3.45452371926 + 103.0927742186*t)
	Z0 += 0.00000004169*np.cos(2.48226227386 + 529.6909650946*t)
	Z0 += 0.00000005064*np.cos(1.68192340688 + 419.4846438752*t)
	Z0 += 0.00000002610*np.cos(5.41057398526 + 632.7837393132*t)
	Z0 += 0.00000002750*np.cos(3.06858398648 + 10213.285546211*t)
	return Z0




def Neptune_Z1 (t): # 33 terms of order 1

	Z1 = 0.
	Z1 += 0.00154877961*np.cos(2.14239038882 + 38.1330356378*t)
	Z1 += 0.00007783708*np.cos(4.40146905905 + 36.6485629295*t)
	Z1 += 0.00009597674
	Z1 += 0.00006862414*np.cos(1.65930160610 + 39.6175083461*t)
	Z1 += 0.00003891340*np.cos(5.46760868569 + 76.2660712756*t)
	Z1 += 0.00000794811*np.cos(5.98635430889 + 35.1640902212*t)
	Z1 += 0.00000506405*np.cos(0.44976388514 + 41.1019810544*t)
	Z1 += 0.00000374315*np.cos(1.56222971632 + 2.9689454166*t)
	Z1 += 0.00000177485*np.cos(4.37166358766 + 73.297125859*t)
	Z1 += 0.00000183128*np.cos(5.40794621153 + 1.4844727083*t)
	Z1 += 0.00000105442*np.cos(2.35241365385 + 74.7815985673*t)
	Z1 += 0.00000079923*np.cos(0.27163282735 + 77.7505439839*t)
	Z1 += 0.00000064900*np.cos(0.27452505078 + 4.4534181249*t)
	Z1 += 0.00000064916*np.cos(0.65218136897 + 33.6796175129*t)
	Z1 += 0.00000050481*np.cos(3.57774720787 + 114.3991069134*t)
	Z1 += 0.00000040463*np.cos(5.47127522302 + 42.5864537627*t)
	Z1 += 0.00000033263*np.cos(5.25282819024 + 71.8126531507*t)
	Z1 += 0.00000026739*np.cos(4.07806359670 + 37.611770776*t)
	Z1 += 0.00000026252*np.cos(1.94513334993 + 38.6543004996*t)
	Z1 += 0.00000015477*np.cos(4.12583404955 + 28.5718080822*t)
	Z1 += 0.00000012100*np.cos(3.10752065642 + 111.4301614968*t)
	Z1 += 0.00000014021*np.cos(4.12685780506 + 35.685355083*t)
	Z1 += 0.00000012665*np.cos(1.89493761132 + 40.5807161926*t)
	Z1 += 0.00000014126*np.cos(2.27105401422 + 98.8999885246*t)
	Z1 += 0.00000010241*np.cos(1.88890726131 + 137.0330241624*t)
	Z1 += 0.00000011332*np.cos(1.89669399414 + 47.6942631934*t)
	Z1 += 0.00000009264*np.cos(5.30245876403 + 5.9378908332*t)
	Z1 += 0.00000007474*np.cos(4.96934284190 + 112.9146342051*t)
	Z1 += 0.00000004941*np.cos(1.82747100488 + 213.299095438*t)
	Z1 += 0.00000004978*np.cos(4.29826949554 + 419.4846438752*t)
	Z1 += 0.00000006008*np.cos(0.92667374096 + 70.3281804424*t)
	Z1 += 0.00000004388*np.cos(6.14545946311 + 7.1135470008*t)
	Z1 += 0.00000002586*np.cos(3.01944725018 + 639.897286314*t)
	return Z1*t




def Neptune_Z2 (t): # 10 terms of order 2

	Z2 = 0.
	Z2 += 0.00001264840*np.cos(1.91401498992 + 38.1330356378*t)
	Z2 += 0.00000130346*np.cos(1.12728833394 + 36.6485629295*t)
	Z2 += 0.00000127993*np.cos(4.77241139328 + 39.6175083461*t)
	Z2 += 0.00000063370*np.cos(4.37315671512 + 76.2660712756*t)
	Z2 -= 0.00000034955
	Z2 += 0.00000012004*np.cos(1.70952552971 + 35.1640902212*t)
	Z2 += 0.00000009304*np.cos(4.23010808782 + 41.1019810544*t)
	Z2 += 0.00000004160*np.cos(1.77543920837 + 220.4126424388*t)
	Z2 += 0.00000004161*np.cos(0.18246750825 + 206.1855484372*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	return Z2*t*t




def Neptune_Z3 (t): # 2 terms of order 3

	Z3 = 0.
	Z3 += 0.00000124222*np.cos(3.06928911462 + 38.1330356378*t)
	Z3 += 0.00000004438*np.cos(3.98008913039 + 36.6485629295*t)
	return Z3*t*t*t




def Neptune_Z4 (t): # 1 term of order 4

	Z4 = 0.
	Z4 += 0.00000000000
	return Z4*t*t*t*t




def Neptune_Z5 (t): # 1 term of order 5

	Z5 = 0.
	Z5 += 0.00000000000
	return Z5*t*t*t*t*t






def Sun_X0 (t): # 1293 terms of order 0

	X0 = 0.
	X0 += 0.00495672739*np.cos(3.74107356792 + 529.6909650946*t)
	X0 += 0.00271802376*np.cos(4.01601149775 + 213.299095438*t)
	X0 += 0.00155435675*np.cos(2.17052050061 + 38.1330356378*t)
	X0 += 0.00083792997*np.cos(2.33967985523 + 74.7815985673*t)
	X0 += 0.00029374249
	X0 += 0.00012013079*np.cos(4.09073224903 + 1059.3819301892*t)
	X0 += 0.00007577257*np.cos(3.24151897354 + 426.598190876*t)
	X0 += 0.00001941380*np.cos(1.01219474101 + 206.1855484372*t)
	X0 += 0.00001940649*np.cos(4.79769963661 + 149.5631971346*t)
	X0 += 0.00001888831*np.cos(3.89252804366 + 220.4126424388*t)
	X0 += 0.00001434208*np.cos(3.86895363775 + 522.5774180938*t)
	X0 += 0.00001406367*np.cos(0.47598335150 + 536.8045120954*t)
	X0 += 0.00001185835*np.cos(0.77770585045 + 76.2660712756*t)
	X0 += 0.00000813685*np.cos(3.25483611884 + 36.6485629295*t)
	X0 += 0.00000767074*np.cos(4.22743731914 + 39.6175083461*t)
	X0 += 0.00000624814*np.cos(0.27936466811 + 73.297125859*t)
	X0 += 0.00000436640*np.cos(4.44044655092 + 1589.0728952838*t)
	X0 += 0.00000379145*np.cos(5.15640874752 + 7.1135470008*t)
	X0 += 0.00000315393*np.cos(6.15699854629 + 419.4846438752*t)
	X0 += 0.00000308784*np.cos(2.49456658747 + 639.897286314*t)
	X0 += 0.00000278795*np.cos(4.93431870348 + 110.2063212194*t)
	X0 += 0.00000303993*np.cos(4.89507841707 + 6283.0758499914*t)
	X0 += 0.00000227188*np.cos(5.27839813806 + 103.0927742186*t)
	X0 += 0.00000216162*np.cos(5.80298032120 + 316.3918696566*t)
	X0 += 0.00000176764*np.cos(0.03416525046 + 10213.285546211*t)
	X0 += 0.00000135792*np.cos(2.00151020964 + 1.4844727083*t)
	X0 += 0.00000116993*np.cos(2.42475255571 + 632.7837393132*t)
	X0 += 0.00000105413*np.cos(3.12332213850 + 433.7117378768*t)
	X0 += 0.00000097988*np.cos(3.02626461372 + 1052.2683831884*t)
	X0 += 0.00000109101*np.cos(3.15781282608 + 1162.4747044078*t)
	X0 += 0.00000069588*np.cos(0.82196495080 + 1066.49547719*t)
	X0 += 0.00000056882*np.cos(1.32304578699 + 949.1756089698*t)
	X0 += 0.00000066120*np.cos(0.27653561007 + 846.0828347512*t)
	X0 += 0.00000063189*np.cos(5.79436684832 + 148.0787244263*t)
	X0 += 0.00000063139*np.cos(0.73209797865 + 224.3447957019*t)
	X0 += 0.00000048979*np.cos(3.06244424367 + 3340.6124266998*t)
	X0 += 0.00000037824*np.cos(4.58891701161 + 35.1640902212*t)
	X0 += 0.00000031150*np.cos(1.37429681895 + 63.7358983034*t)
	X0 += 0.00000030682*np.cos(4.22246917155 + 11.0457002639*t)
	X0 += 0.00000028741*np.cos(3.71398829023 + 151.0476698429*t)
	X0 += 0.00000028580*np.cos(2.84721981555 + 41.1019810544*t)
	X0 += 0.00000023782*np.cos(3.76207354349 + 227.5261894396*t)
	X0 += 0.00000023267*np.cos(0.46827104623 + 85.8272988312*t)
	X0 += 0.00000022744*np.cos(1.67012539714 + 71.8126531507*t)
	X0 += 0.00000018818*np.cos(4.79056538983 + 2118.7638603784*t)
	X0 += 0.00000022286*np.cos(3.93734569173 + 2.9689454166*t)
	X0 += 0.00000021992*np.cos(0.11232184552 + 77.7505439839*t)
	X0 += 0.00000020026*np.cos(4.02923197304 + 209.3669421749*t)
	X0 += 0.00000019681*np.cos(0.87544248531 + 217.2312487011*t)
	X0 += 0.00000019075*np.cos(5.91973929854 + 202.2533951741*t)
	X0 += 0.00000016571*np.cos(2.54911337935 + 735.8765135318*t)
	X0 += 0.00000015738*np.cos(5.27754524439 + 742.9900605326*t)
	X0 += 0.00000018319*np.cos(3.06472848621 + 323.5054166574*t)
	X0 += 0.00000017360*np.cos(3.01137661271 + 138.5174968707*t)
	X0 += 0.00000015488*np.cos(4.00542220967 + 515.463871093*t)
	X0 += 0.00000016367*np.cos(1.83137880912 + 853.196381752*t)
	X0 += 0.00000011229*np.cos(1.18029367551 + 199.0720014364*t)
	X0 += 0.00000010836*np.cos(0.34161370756 + 543.9180590962*t)
	X0 += 0.00000011587*np.cos(0.61075744193 + 525.7588118315*t)
	X0 += 0.00000011447*np.cos(3.72704255770 + 533.6231183577*t)
	X0 += 0.00000007920*np.cos(2.43547958386 + 1478.8665740644*t)
	X0 += 0.00000008322*np.cos(3.52503621824 + 1692.1656695024*t)
	X0 += 0.00000007185*np.cos(3.51955509534 + 216.4804891757*t)
	X0 += 0.00000007015*np.cos(1.38855213071 + 210.1177017003*t)
	X0 += 0.00000007120*np.cos(2.46055859947 + 415.5524906121*t)
	X0 += 0.00000006867*np.cos(4.39735582882 + 117.3198682202*t)
	X0 += 0.00000007226*np.cos(4.04267257839 + 1265.5674786264*t)
	X0 += 0.00000006955*np.cos(2.86501952800 + 956.2891559706*t)
	X0 += 0.00000007493*np.cos(5.01430547428 + 14.2270940016*t)
	X0 += 0.00000006597*np.cos(2.37676813421 + 647.0108333148*t)
	X0 += 0.00000007380*np.cos(3.27302208820 + 1581.959348283*t)
	X0 += 0.00000006401*np.cos(5.30226825802 + 95.9792272178*t)
	X0 += 0.00000006244*np.cos(5.44473078234 + 70.8494453042*t)
	X0 += 0.00000005074*np.cos(4.24610777191 + 526.5095713569*t)
	X0 += 0.00000004978*np.cos(0.09070559075 + 532.8723588323*t)
	X0 += 0.00000005875*np.cos(2.36907113150 + 78.7137518304*t)
	X0 += 0.00000006109*np.cos(5.67990095410 + 111.4301614968*t)
	X0 += 0.00000006233*np.cos(1.25490462048 + 26087.9031415742*t)
	X0 += 0.00000004359*np.cos(0.60967414268 + 1375.7737998458*t)
	X0 += 0.00000004712*np.cos(4.78612693635 + 114.3991069134*t)
	X0 += 0.00000005185*np.cos(1.85847454376 + 222.8603229936*t)
	X0 += 0.00000003758*np.cos(1.16737031996 + 1596.1864422846*t)
	X0 += 0.00000004288*np.cos(1.51938558324 + 277.0349937414*t)
	X0 += 0.00000004598*np.cos(0.76405567220 + 146.594251718*t)
	X0 += 0.00000003754*np.cos(1.04640420137 + 490.3340891794*t)
	X0 += 0.00000002821*np.cos(3.43414737256 + 299.1263942692*t)
	X0 += 0.00000003418*np.cos(2.52366884638 + 351.8165923087*t)
	X0 += 0.00000002655*np.cos(2.90453219642 + 625.6701923124*t)
	X0 += 0.00000002982*np.cos(0.59289983624 + 109.9456887885*t)
	X0 += 0.00000002539*np.cos(4.85191300379 + 12566.1516999828*t)
	X0 += 0.00000002283*np.cos(3.40048550603 + 6681.2248533996*t)
	X0 += 0.00000002336*np.cos(5.79016324229 + 33.6796175129*t)
	X0 += 0.00000002549*np.cos(0.03994924305 + 1169.5882514086*t)
	X0 += 0.00000002289*np.cos(2.78836600930 + 1045.1548361876*t)
	X0 += 0.00000001945*np.cos(3.29102485680 + 1155.361157407*t)
	X0 += 0.00000001859*np.cos(2.69741164079 + 4.4534181249*t)
	X0 += 0.00000001646*np.cos(3.01660183388 + 440.8252848776*t)
	X0 += 0.00000001539*np.cos(5.57331447211 + 65.2203710117*t)
	X0 += 0.00000001433*np.cos(1.48123692595 + 942.062061969*t)
	X0 += 0.00000001390*np.cos(6.12238564495 + 412.3710968744*t)
	X0 += 0.00000001413*np.cos(1.64650599332 + 42.5864537627*t)
	X0 += 0.00000001483*np.cos(1.40459440941 + 210.8514148832*t)
	X0 += 0.00000001423*np.cos(5.98922157377 + 225.8292684102*t)
	X0 += 0.00000001472*np.cos(3.48774945967 + 215.7467759928*t)
	X0 += 0.00000001090*np.cos(2.83082031323 + 422.6660376129*t)
	X0 += 0.00000001047*np.cos(0.50899510052 + 309.2783226558*t)
	X0 += 0.00000001369*np.cos(5.12813131118 + 79.2350166922*t)
	X0 += 0.00000001022*np.cos(0.96352485877 + 145.6310438715*t)
	X0 += 0.00000001422*np.cos(2.40975714524 + 152.5321425512*t)
	X0 += 0.00000001034*np.cos(3.22353796512 + 1795.258443721*t)
	X0 += 0.00000000979*np.cos(2.33360006154 + 84.3428261229*t)
	X0 += 0.00000000966*np.cos(6.19909761751 + 1272.6810256272*t)
	X0 += 0.00000001090*np.cos(2.86573865299 + 70.3281804424*t)
	X0 += 0.00000001075*np.cos(0.57961253778 + 212.3358875915*t)
	X0 += 0.00000001070*np.cos(4.31120526838 + 214.2623032845*t)
	X0 += 0.00000001244*np.cos(2.87441597074 + 184.7272873558*t)
	X0 += 0.00000001098*np.cos(2.95983802473 + 137.0330241624*t)
	X0 += 0.00000000891*np.cos(5.14100716567 + 2648.454825473*t)
	X0 += 0.00000000889*np.cos(3.98790631605 + 213.2509113282*t)
	X0 += 0.00000000889*np.cos(0.90251570889 + 213.3472795478*t)
	X0 += 0.00000000967*np.cos(4.53246389020 + 437.6438911399*t)
	X0 += 0.00000000819*np.cos(0.57163728715 + 529.6427809848*t)
	X0 += 0.00000000819*np.cos(3.76946397274 + 529.7391492044*t)
	X0 += 0.00000000811*np.cos(2.26915207928 + 288.0806940053*t)
	X0 += 0.00000001037*np.cos(4.27554240329 + 527.2432845398*t)
	X0 += 0.00000001031*np.cos(0.06363683037 + 532.1386456494*t)
	X0 += 0.00000000797*np.cos(4.06306935733 + 203.7378678824*t)
	X0 += 0.00000000859*np.cos(2.39272132973 + 74.6697239827*t)
	X0 += 0.00000000858*np.cos(5.42820178780 + 74.8934731519*t)
	X0 += 0.00000000734*np.cos(5.35841388096 + 112.9146342051*t)
	X0 += 0.00000000709*np.cos(1.92302056629 + 628.8515860501*t)
	X0 += 0.00000000926*np.cos(2.97025862788 + 160.6088973985*t)
	X0 += 0.00000000826*np.cos(3.32684274495 + 838.9692877504*t)
	X0 += 0.00000000648*np.cos(2.95455543165 + 2008.557539159*t)
	X0 += 0.00000000692*np.cos(2.83117936839 + 9.5612275556*t)
	X0 += 0.00000000598*np.cos(0.91405116799 + 20426.571092422*t)
	X0 += 0.00000000624*np.cos(0.50120316917 + 430.5303441391*t)
	X0 += 0.00000000599*np.cos(3.24438777522 + 2111.6503133776*t)
	X0 += 0.00000000832*np.cos(2.20242516999 + 380.12776796*t)
	X0 += 0.00000000662*np.cos(4.47978464665 + 1063.3140834523*t)
	X0 += 0.00000000616*np.cos(5.14603483362 + 1368.660252845*t)
	X0 += 0.00000000639*np.cos(3.15793381912 + 12.5301729722*t)
	X0 += 0.00000000599*np.cos(0.38463092695 + 423.4167971383*t)
	X0 += 0.00000000648*np.cos(3.43475812975 + 528.7277572481*t)
	X0 += 0.00000000646*np.cos(0.90574398043 + 530.6541729411*t)
	X0 += 0.00000000635*np.cos(4.30621635713 + 52175.8062831484*t)
	X0 += 0.00000000547*np.cos(3.88827567459 + 2221.856634597*t)
	X0 += 0.00000000538*np.cos(6.04102038970 + 127.4717966068*t)
	X0 += 0.00000000542*np.cos(0.91953382373 + 1055.4497769261*t)
	X0 += 0.00000000672*np.cos(3.08200615608 + 221.3758502853*t)
	X0 += 0.00000000566*np.cos(2.70414246898 + 728.762966531*t)
	X0 += 0.00000000490*np.cos(2.97472409276 + 71.6002048296*t)
	X0 += 0.00000000649*np.cos(1.32346646305 + 22.0914005278*t)
	X0 += 0.00000000471*np.cos(4.83320292258 + 77.962992305*t)
	X0 += 0.00000000623*np.cos(2.85969660852 + 330.6189636582*t)
	X0 += 0.00000000652*np.cos(2.72637797985 + 388.4651552382*t)
	X0 += 0.00000000468*np.cos(0.69788003422 + 1073.6090241908*t)
	X0 += 0.00000000574*np.cos(5.66932742997 + 87.3117715395*t)
	X0 += 0.00000000605*np.cos(1.98317483331 + 984.6003316219*t)
	X0 += 0.00000000541*np.cos(3.08246188636 + 72.3339180125*t)
	X0 += 0.00000000467*np.cos(5.34128135139 + 212.7778305762*t)
	X0 += 0.00000000466*np.cos(5.83324087524 + 213.8203602998*t)
	X0 += 0.00000000418*np.cos(2.75937640828 + 429.7795846137*t)
	X0 += 0.00000000462*np.cos(1.66174622090 + 860.3099287528*t)
	X0 += 0.00000000511*np.cos(4.91405448075 + 77.2292791221*t)
	X0 += 0.00000000384*np.cos(0.64251152112 + 340.7708920448*t)
	X0 += 0.00000000354*np.cos(2.54868316520 + 62.2514255951*t)
	X0 += 0.00000000395*np.cos(3.93999186550 + 52.6901980395*t)
	X0 += 0.00000000406*np.cos(2.27584736071 + 350.3321196004*t)
	X0 += 0.00000000396*np.cos(1.99989177453 + 145.1097790097*t)
	X0 += 0.00000000385*np.cos(6.13244198192 + 909.8187330546*t)
	X0 += 0.00000000313*np.cos(3.62090724113 + 234.6397364404*t)
	X0 += 0.00000000382*np.cos(1.81523910449 + 186.2117600641*t)
	X0 += 0.00000000301*np.cos(0.77539464542 + 3.9321532631*t)
	X0 += 0.00000000400*np.cos(1.38752434540 + 454.9093665273*t)
	X0 += 0.00000000372*np.cos(4.82853244691 + 3.1813937377*t)
	X0 += 0.00000000288*np.cos(0.91857388482 + 1905.4647649404*t)
	X0 += 0.00000000308*np.cos(2.68902321898 + 362.8622925726*t)
	X0 += 0.00000000335*np.cos(0.71030115582 + 200.7689224658*t)
	X0 += 0.00000000311*np.cos(4.44573637765 + 297.6419215609*t)
	X0 += 0.00000000264*np.cos(3.81456195150 + 1485.9801210652*t)
	X0 += 0.00000000289*np.cos(1.92464337356 + 529.1697002328*t)
	X0 += 0.00000000366*np.cos(2.92406939426 + 604.4725636619*t)
	X0 += 0.00000000288*np.cos(2.41719522186 + 530.2122299564*t)
	X0 += 0.00000000314*np.cos(1.84357518690 + 108.4612160802*t)
	X0 += 0.00000000262*np.cos(4.15566435137 + 1258.4539316256*t)
	X0 += 0.00000000274*np.cos(1.54026728979 + 565.1156877467*t)
	X0 += 0.00000000268*np.cos(0.19545433539 + 140.001969579*t)
	X0 += 0.00000000320*np.cos(0.32229958420 + 703.6331846174*t)
	X0 += 0.00000000243*np.cos(0.44342371962 + 1062.5633239269*t)
	X0 += 0.00000000248*np.cos(0.09445957496 + 210.3783341312*t)
	X0 += 0.00000000248*np.cos(4.79327801971 + 216.2198567448*t)
	X0 += 0.00000000241*np.cos(3.24545153339 + 37.611770776*t)
	X0 += 0.00000000255*np.cos(4.90697050745 + 153.4953503977*t)
	X0 += 0.00000000237*np.cos(3.72326482255 + 212.5483359126*t)
	X0 += 0.00000000236*np.cos(1.16575065097 + 214.0498549634*t)
	X0 += 0.00000000236*np.cos(4.23871934676 + 38.6543004996*t)
	X0 += 0.00000000252*np.cos(4.61065643475 + 209.106309744*t)
	X0 += 0.00000000247*np.cos(0.27272991614 + 217.491881132*t)
	X0 += 0.00000000225*np.cos(3.38119852586 + 223.5940361765*t)
	X0 += 0.00000000224*np.cos(5.51904045547 + 38.084851528*t)
	X0 += 0.00000000223*np.cos(1.96313876697 + 38.1812197476*t)
	X0 += 0.00000000245*np.cos(4.21060733239 + 173.9422195228*t)
	X0 += 0.00000000217*np.cos(1.51605950497 + 2125.8774073792*t)
	X0 += 0.00000000234*np.cos(0.55106604784 + 74.2603337055*t)
	X0 += 0.00000000233*np.cos(0.98887023825 + 75.3028634291*t)
	X0 += 0.00000000247*np.cos(0.56642494969 + 252.6559713532*t)
	X0 += 0.00000000204*np.cos(0.84533704687 + 18.1592472647*t)
	X0 += 0.00000000282*np.cos(1.41766310537 + 563.6312150384*t)
	X0 += 0.00000000207*np.cos(5.75479453376 + 142.4496501338*t)
	X0 += 0.00000000204*np.cos(0.27721513871 + 417.0369633204*t)
	X0 += 0.00000000195*np.cos(4.23402090499 + 66.70484372*t)
	X0 += 0.00000000211*np.cos(5.13588313603 + 37.1698277913*t)
	X0 += 0.00000000215*np.cos(0.35886038032 + 1699.2792165032*t)
	X0 += 0.00000000227*np.cos(5.15751336106 + 207.8824694666*t)
	X0 += 0.00000000203*np.cos(2.35104519506 + 39.0962434843*t)
	X0 += 0.00000000202*np.cos(4.05217682796 + 207.6700211455*t)
	X0 += 0.00000000182*np.cos(3.89203001563 + 1898.3512179396*t)
	X0 += 0.00000000219*np.cos(6.03807342488 + 218.7157214094*t)
	X0 += 0.00000000206*np.cos(5.35930784504 + 88.865680217*t)
	X0 += 0.00000000188*np.cos(2.43290559306 + 1471.7530270636*t)
	X0 += 0.00000000185*np.cos(4.15018423748 + 508.3503240922*t)
	X0 += 0.00000000195*np.cos(0.82662766477 + 218.9281697305*t)
	X0 += 0.00000000224*np.cos(4.06529944699 + 1056.2005364515*t)
	X0 += 0.00000000172*np.cos(2.96155542160 + 526.7702037878*t)
	X0 += 0.00000000186*np.cos(0.73069210814 + 554.0699874828*t)
	X0 += 0.00000000194*np.cos(2.50663265946 + 28.5718080822*t)
	X0 += 0.00000000169*np.cos(1.38093325803 + 532.6117264014*t)
	X0 += 0.00000000192*np.cos(3.08542976535 + 1574.8458012822*t)
	X0 += 0.00000000217*np.cos(3.59114151623 + 124.433415221*t)
	X0 += 0.00000000176*np.cos(1.20681960915 + 525.4981794006*t)
	X0 += 0.00000000172*np.cos(5.60194767636 + 211.8146227297*t)
	X0 += 0.00000000160*np.cos(3.73878048271 + 10021.8372800994*t)
	X0 += 0.00000000188*np.cos(3.44598602635 + 569.0478410098*t)
	X0 += 0.00000000158*np.cos(0.33551046271 + 528.9402055692*t)
	X0 += 0.00000000157*np.cos(4.00545168863 + 530.44172462*t)
	X0 += 0.00000000177*np.cos(0.70756419313 + 32.1951448046*t)
	X0 += 0.00000000191*np.cos(4.12314886390 + 183.2428146475*t)
	X0 += 0.00000000179*np.cos(1.49110102879 + 5.9378908332*t)
	X0 += 0.00000000170*np.cos(5.83704197169 + 305.3461693927*t)
	X0 += 0.00000000207*np.cos(1.81656116060 + 73.8183907208*t)
	X0 += 0.00000000175*np.cos(1.28027815287 + 217.964961884*t)
	X0 += 0.00000000148*np.cos(4.39633643688 + 519.3960243561*t)
	X0 += 0.00000000147*np.cos(3.63497942528 + 82.8583534146*t)
	X0 += 0.00000000203*np.cos(2.54569209930 + 453.424893819*t)
	X0 += 0.00000000191*np.cos(5.96603240618 + 425.1137181677*t)
	X0 += 0.00000000148*np.cos(3.53096991388 + 414.0680179038*t)
	X0 += 0.00000000200*np.cos(0.25134097583 + 1439.5096981492*t)
	X0 += 0.00000000165*np.cos(5.22234420384 + 231.4583427027*t)
	X0 += 0.00000000141*np.cos(5.69421526925 + 408.4389436113*t)
	X0 += 0.00000000191*np.cos(6.04625942487 + 75.7448064138*t)
	X0 += 0.00000000178*np.cos(3.84899225076 + 1685.0521225016*t)
	X0 += 0.00000000149*np.cos(3.15621899577 + 533.8837507886*t)
	X0 += 0.00000000157*np.cos(3.61532012746 + 208.633228992*t)
	X0 += 0.00000000153*np.cos(4.99836680146 + 47.6942631934*t)
	X0 += 0.00000000184*np.cos(2.16301573772 + 1021.2488945514*t)
	X0 += 0.00000000139*np.cos(5.84452648935 + 373.9079928365*t)
	X0 += 0.00000000138*np.cos(5.61172177506 + 214.7835681463*t)
	X0 += 0.00000000129*np.cos(1.54390762080 + 203.0041546995*t)
	X0 += 0.00000000128*np.cos(5.24161490581 + 479.2883889155*t)
	X0 += 0.00000000130*np.cos(2.26702486739 + 654.1243803156*t)
	X0 += 0.00000000144*np.cos(1.54442458059 + 4.192785694*t)
	X0 += 0.00000000139*np.cos(1.22510407970 + 251.4321310758*t)
	X0 += 0.00000000160*np.cos(5.11540883899 + 265.9892934775*t)
	X0 += 0.00000000121*np.cos(5.05113331022 + 56.6223513026*t)
	X0 += 0.00000000115*np.cos(6.22459411775 + 539.9859058331*t)
	X0 += 0.00000000114*np.cos(0.09813992796 + 213.1872208534*t)
	X0 += 0.00000000114*np.cos(4.79116773360 + 213.4109700226*t)
	X0 += 0.00000000123*np.cos(5.10501021239 + 98.8999885246*t)
	X0 += 0.00000000116*np.cos(0.64506154486 + 524.0618908021*t)
	X0 += 0.00000000115*np.cos(3.69498632982 + 535.3200393871*t)
	X0 += 0.00000000127*np.cos(0.63003020942 + 540.7366653585*t)
	X0 += 0.00000000118*np.cos(0.24752969879 + 983.1158589136*t)
	X0 += 0.00000000118*np.cos(0.19804778544 + 525.0250986486*t)
	X0 += 0.00000000100*np.cos(3.71645704441 + 529.851023789*t)
	X0 += 0.00000000100*np.cos(0.62422783083 + 529.5309064002*t)
	X0 += 0.00000000102*np.cos(1.31527898088 + 963.4027029714*t)
	X0 += 0.00000000099*np.cos(1.87542989608 + 198.321241911*t)
	X0 += 0.00000000111*np.cos(1.30109743855 + 80.1982245387*t)
	X0 += 0.00000000096*np.cos(4.17152569130 + 213.5115437591*t)
	X0 += 0.00000000096*np.cos(0.71778197027 + 213.0866471169*t)
	X0 += 0.00000000099*np.cos(0.19873228449 + 551.031606097*t)
	X0 += 0.00000000112*np.cos(3.45345978303 + 2324.9494088156*t)
	X0 += 0.00000000111*np.cos(4.13924061941 + 534.3568315406*t)
	X0 += 0.00000000117*np.cos(1.76475239313 + 524.2743391232*t)
	X0 += 0.00000000125*np.cos(4.85236761160 + 21.3406410024*t)
	X0 += 0.00000000095*np.cos(5.28465176922 + 327.4375699205*t)
	X0 += 0.00000000115*np.cos(2.57406093768 + 535.107591066*t)
	X0 += 0.00000000100*np.cos(2.94090698274 + 195.1398481733*t)
	X0 += 0.00000000097*np.cos(1.07440129398 + 78263.70942472259*t)
	X0 += 0.00000000096*np.cos(0.06385619665 + 35.685355083*t)
	X0 += 0.00000000113*np.cos(1.72263005108 + 114.1384744825*t)
	X0 += 0.00000000091*np.cos(0.08598161680 + 1802.3719907218*t)
	X0 += 0.00000000089*np.cos(3.16908258340 + 1382.8873468466*t)
	X0 += 0.00000000102*np.cos(4.42228976166 + 219.891377577*t)
	X0 += 0.00000000086*np.cos(2.85915032438 + 228.276948965*t)
	X0 += 0.00000000100*np.cos(3.39323367399 + 96.8729990951*t)
	X0 += 0.00000000084*np.cos(2.61330768505 + 74.7334144575*t)
	X0 += 0.00000000084*np.cos(5.20716850754 + 74.8297826771*t)
	X0 += 0.00000000114*np.cos(1.15232105885 + 177.8743727859*t)
	X0 += 0.00000000087*np.cos(1.13401038923 + 40.5807161926*t)
	X0 += 0.00000000081*np.cos(3.33902328234 + 191.2076949102*t)
	X0 += 0.00000000093*np.cos(1.06738164563 + 74.5209661364*t)
	X0 += 0.00000000093*np.cos(0.46802035326 + 75.0422309982*t)
	X0 += 0.00000000079*np.cos(4.31891477024 + 38.0211610532*t)
	X0 += 0.00000000079*np.cos(3.16332905605 + 38.2449102224*t)
	X0 += 0.00000000080*np.cos(1.40233563562 + 191.9584544356*t)
	X0 += 0.00000000079*np.cos(4.46070108071 + 278.5194664497*t)
	X0 += 0.00000000080*np.cos(3.95392779576 + 175.1660598002*t)
	X0 += 0.00000000083*np.cos(2.35608099285 + 300.6108669775*t)
	X0 += 0.00000000078*np.cos(0.92843223712 + 30.0562807905*t)
	X0 += 0.00000000097*np.cos(5.32653372215 + 259.5088859231*t)
	X0 += 0.00000000077*np.cos(2.50991636518 + 205.2223405907*t)
	X0 += 0.00000000085*np.cos(0.43515691954 + 44.070926471*t)
	X0 += 0.00000000096*np.cos(6.24127646307 + 131.4039498699*t)
	X0 += 0.00000000091*np.cos(3.88112259566 + 80.7194894005*t)
	X0 += 0.00000000078*np.cos(2.59112277976 + 74.6215398729*t)
	X0 += 0.00000000078*np.cos(5.22948432343 + 74.9416572617*t)
	X0 += 0.00000000075*np.cos(2.21732650708 + 302.164775655*t)
	X0 += 0.00000000072*np.cos(4.81698863150 + 213.5597278689*t)
	X0 += 0.00000000072*np.cos(0.07231943414 + 213.0384630071*t)
	X0 += 0.00000000096*np.cos(4.24511131293 + 483.2205421786*t)
	X0 += 0.00000000069*np.cos(3.45966511571 + 529.4785167735*t)
	X0 += 0.00000000069*np.cos(0.88102053266 + 529.9034134157*t)
	X0 += 0.00000000094*np.cos(3.68180477512 + 248.7238180901*t)
	X0 += 0.00000000077*np.cos(3.59376629306 + 518.6452648307*t)
	X0 += 0.00000000066*np.cos(2.02327672376 + 635.9651330509*t)
	X0 += 0.00000000064*np.cos(3.46792160676 + 2214.7430875962*t)
	X0 += 0.00000000063*np.cos(3.22324471895 + 20.6069278195*t)
	X0 += 0.00000000084*np.cos(0.70408445885 + 424.1505103212*t)
	X0 += 0.00000000082*np.cos(1.17323562782 + 154.0166152595*t)
	X0 += 0.00000000065*np.cos(5.99619164093 + 284.1485407422*t)
	X0 += 0.00000000076*np.cos(3.59374291647 + 831.8557407496*t)
	X0 += 0.00000000081*np.cos(3.70025004502 + 37.8724032069*t)
	X0 += 0.00000000069*np.cos(2.58402361347 + 275.5505210331*t)
	X0 += 0.00000000071*np.cos(3.88813675038 + 835.0371344873*t)
	X0 += 0.00000000080*np.cos(3.78188046031 + 38.3936680687*t)
	X0 += 0.00000000073*np.cos(0.88865626886 + 115.8835796217*t)
	X0 += 0.00000000069*np.cos(2.49762583501 + 511.5317178299*t)
	X0 += 0.00000000058*np.cos(0.25471831888 + 46.2097904851*t)
	X0 += 0.00000000068*np.cos(1.09479629612 + 643.8294395771*t)
	X0 += 0.00000000079*np.cos(5.72688311333 + 531.1754378029*t)
	X0 += 0.00000000079*np.cos(0.46444983025 + 404.5067903482*t)
	X0 += 0.00000000077*np.cos(4.08353330283 + 618.5566453116*t)
	X0 += 0.00000000056*np.cos(1.44522132533 + 842.1506814881*t)
	X0 += 0.00000000062*np.cos(0.88771657360 + 99.1606209555*t)
	X0 += 0.00000000065*np.cos(1.84460485390 + 547.8502123593*t)
	X0 += 0.00000000062*np.cos(4.06674027154 + 68.8437077341*t)
	X0 += 0.00000000061*np.cos(0.01100073598 + 121.2520214833*t)
	X0 += 0.00000000076*np.cos(4.86986651697 + 528.2064923863*t)
	X0 += 0.00000000075*np.cos(4.71498755910 + 227.3137411185*t)
	X0 += 0.00000000061*np.cos(3.81064825215 + 650.9429865779*t)
	X0 += 0.00000000064*np.cos(4.29409388919 + 159.1244246902*t)
	X0 += 0.00000000061*np.cos(2.96999279527 + 429.0458714308*t)
	X0 += 0.00000000057*np.cos(3.46227126270 + 92.940845832*t)
	X0 += 0.00000000068*np.cos(0.43233787470 + 219.4494345923*t)
	X0 += 0.00000000059*np.cos(5.80351575464 + 33.9402499438*t)
	X0 += 0.00000000062*np.cos(5.86330508473 + 2.4476805548*t)
	X0 += 0.00000000062*np.cos(6.09623774456 + 425.6349830295*t)
	X0 += 0.00000000051*np.cos(5.10012533555 + 1048.3362299253*t)
	X0 += 0.00000000054*np.cos(3.07019079387 + 59.8037450403*t)
	X0 += 0.00000000050*np.cos(1.48104982763 + 960.2213092337*t)
	X0 += 0.00000000059*np.cos(5.90527689512 + 72.0732855816*t)
	X0 += 0.00000000050*np.cos(0.12167728428 + 426.6463749858*t)
	X0 += 0.00000000064*np.cos(4.78297114148 + 269.9214467406*t)
	X0 += 0.00000000050*np.cos(4.78368432558 + 514.7131115676*t)
	X0 += 0.00000000051*np.cos(5.96112457648 + 387.2413149608*t)
	X0 += 0.00000000055*np.cos(1.61378048542 + 42.3258213318*t)
	X0 += 0.00000000051*np.cos(3.43355246408 + 2641.3412784722*t)
	X0 += 0.00000000063*np.cos(1.40789341724 + 750.1036075334*t)
	X0 += 0.00000000050*np.cos(3.20702872042 + 426.5500067662*t)
	X0 += 0.00000000063*np.cos(3.98505374586 + 494.2662424425*t)
	X0 += 0.00000000053*np.cos(2.43583780027 + 2428.0421830342*t)
	X0 += 0.00000000047*np.cos(5.83569926578 + 544.6688186216*t)
	X0 += 0.00000000048*np.cos(2.00982466333 + 39.3568759152*t)
	X0 += 0.00000000055*np.cos(5.26856872787 + 81.8951455681*t)
	X0 += 0.00000000059*np.cos(2.11187321665 + 488.8496164711*t)
	X0 += 0.00000000063*np.cos(4.17349551052 + 1364.7280995819*t)
	X0 += 0.00000000054*np.cos(3.62421804697 + 427.5613987225*t)
	X0 += 0.00000000052*np.cos(4.38844382678 + 210.5907824523*t)
	X0 += 0.00000000051*np.cos(0.50117453824 + 216.0074084237*t)
	X0 += 0.00000000046*np.cos(4.79961635192 + 106.2741679563*t)
	X0 += 0.00000000050*np.cos(4.62538441124 + 1056.9342496344*t)
	X0 += 0.00000000048*np.cos(1.32358795195 + 501.3797894433*t)
	X0 += 0.00000000050*np.cos(1.09462754777 + 355.7487455718*t)
	X0 += 0.00000000044*np.cos(5.16479782395 + 74.0308390419*t)
	X0 += 0.00000000044*np.cos(3.40081468635 + 2538.2485042536*t)
	X0 += 0.00000000055*np.cos(2.70454523909 + 14.977853527*t)
	X0 += 0.00000000057*np.cos(3.17248775727 + 491.8185618877*t)
	X0 += 0.00000000043*np.cos(0.99595677376 + 213.4591541324*t)
	X0 += 0.00000000043*np.cos(3.89366939283 + 213.1390367436*t)
	X0 += 0.00000000043*np.cos(2.65544175682 + 75.5323580927*t)
	X0 += 0.00000000043*np.cos(0.76354191371 + 220.4608265486*t)
	X0 += 0.00000000054*np.cos(0.68459749075 + 187.6962327724*t)
	X0 += 0.00000000057*np.cos(0.63863230611 + 1061.829610744*t)
	X0 += 0.00000000050*np.cos(5.56308110598 + 296.1574488526*t)
	X0 += 0.00000000047*np.cos(0.24841658475 + 1279.794572628*t)
	X0 += 0.00000000041*np.cos(4.51930257295 + 128.9562693151*t)
	X0 += 0.00000000056*np.cos(5.45458264580 + 1057.8974574809*t)
	X0 += 0.00000000053*np.cos(1.93518633525 + 601.7642506762*t)
	X0 += 0.00000000045*np.cos(5.49394122920 + 3178.1457905676*t)
	X0 += 0.00000000047*np.cos(5.03443210464 + 679.2541622292*t)
	X0 += 0.00000000054*np.cos(4.48267339963 + 207.1487562837*t)
	X0 += 0.00000000040*np.cos(4.11879245377 + 1059.430114299*t)
	X0 += 0.00000000042*np.cos(3.87088947499 + 220.364458329*t)
	X0 += 0.00000000046*np.cos(4.69192941021 + 10.2949407385*t)
	X0 += 0.00000000051*np.cos(5.74770428324 + 344.7030453079*t)
	X0 += 0.00000000054*np.cos(1.04857075083 + 188.9200730498*t)
	X0 += 0.00000000041*np.cos(2.70677059989 + 67.6680515665*t)
	X0 += 0.00000000044*np.cos(0.29252718625 + 179.3588454942*t)
	X0 += 0.00000000044*np.cos(1.83547130154 + 289.5651667136*t)
	X0 += 0.00000000040*np.cos(4.83551999164 + 149.45132255*t)
	X0 += 0.00000000040*np.cos(0.02735864866 + 436.1594184316*t)
	X0 += 0.00000000047*np.cos(2.80270200743 + 1038.0412891868*t)
	X0 += 0.00000000037*np.cos(3.31019033964 + 1788.1448967202*t)
	X0 += 0.00000000045*np.cos(2.39073394193 + 358.9301393095*t)
	X0 += 0.00000000047*np.cos(1.00325671943 + 523.5406259403*t)
	X0 += 0.00000000036*np.cos(2.92998162283 + 68.1893164283*t)
	X0 += 0.00000000036*np.cos(4.28412749882 + 2751.5475996916*t)
	X0 += 0.00000000040*np.cos(0.92098132614 + 1059.3337460794*t)
	X0 += 0.00000000038*np.cos(5.64242804993 + 212.0270710508*t)
	X0 += 0.00000000037*np.cos(5.53010012107 + 214.5711198252*t)
	X0 += 0.00000000039*np.cos(2.30481475888 + 1514.2912967165*t)
	X0 += 0.00000000040*np.cos(0.87236752974 + 497.4476361802*t)
	X0 += 0.00000000035*np.cos(4.30307025009 + 672.1406152284*t)
	X0 += 0.00000000047*np.cos(2.48361583884 + 50.4025761791*t)
	X0 += 0.00000000035*np.cos(4.65523345776 + 89.7594520943*t)
	X0 += 0.00000000035*np.cos(5.32328344021 + 69.1525242748*t)
	X0 += 0.00000000043*np.cos(2.91924315729 + 312.4597163935*t)
	X0 += 0.00000000040*np.cos(1.58760278423 + 149.6750717192*t)
	X0 += 0.00000000042*np.cos(3.33159283750 + 535.8413042489*t)
	X0 += 0.00000000036*np.cos(3.18170063426 + 144.1465711632*t)
	X0 += 0.00000000033*np.cos(2.37919979646 + 54.1746707478*t)
	X0 += 0.00000000044*np.cos(3.78834210571 + 237.6781178262*t)
	X0 += 0.00000000035*np.cos(1.74685819003 + 529.9515975255*t)
	X0 += 0.00000000035*np.cos(2.59415719377 + 529.4303326637*t)
	X0 += 0.00000000032*np.cos(4.15757729853 + 206.1373643274*t)
	X0 += 0.00000000040*np.cos(4.91765336511 + 1593.0050485469*t)
	X0 += 0.00000000032*np.cos(0.69603648293 + 522.529233984*t)
	X0 += 0.00000000044*np.cos(0.60569420427 + 1512.8068240082*t)
	X0 += 0.00000000034*np.cos(3.91727152081 + 522.6256022036*t)
	X0 += 0.00000000032*np.cos(4.94879963135 + 81.3738807063*t)
	X0 += 0.00000000036*np.cos(3.21789957686 + 143.6253063014*t)
	X0 += 0.00000000034*np.cos(5.20057828474 + 1361.5467058442*t)
	X0 += 0.00000000032*np.cos(4.93095676351 + 767.3690829208*t)
	X0 += 0.00000000036*np.cos(3.05228952146 + 106.9767433719*t)
	X0 += 0.00000000031*np.cos(1.35404435495 + 35.212274331*t)
	X0 += 0.00000000033*np.cos(1.35404998174 + 1060.3451380357*t)
	X0 += 0.00000000032*np.cos(4.80881910582 + 18849.2275499742*t)
	X0 += 0.00000000036*np.cos(1.23021540997 + 181.0557665236*t)
	X0 += 0.00000000029*np.cos(1.24410667204 + 1585.1407420207*t)
	X0 += 0.00000000030*np.cos(5.47125895037 + 458.8415197904*t)
	X0 += 0.00000000030*np.cos(1.04324019127 + 206.233732547*t)
	X0 += 0.00000000033*np.cos(3.71848916507 + 245.5424243524*t)
	X0 += 0.00000000034*np.cos(3.84184270652 + 92.0470739547*t)
	X0 += 0.00000000029*np.cos(4.54475250390 + 426.0769260142*t)
	X0 += 0.00000000027*np.cos(2.00149954913 + 643.0786800517*t)
	X0 += 0.00000000029*np.cos(0.41759634551 + 536.7563279856*t)
	X0 += 0.00000000027*np.cos(4.36788488657 + 113.3877149571*t)
	X0 += 0.00000000026*np.cos(3.63270001708 + 536.8526962052*t)
	X0 += 0.00000000030*np.cos(4.55790675044 + 247.2393453818*t)
	X0 += 0.00000000031*np.cos(2.95281812365 + 567.8240007324*t)
	X0 += 0.00000000026*np.cos(4.09640475404 + 2001.4439921582*t)
	X0 += 0.00000000026*np.cos(2.06712180785 + 312.1990839626*t)
	X0 += 0.00000000027*np.cos(4.56810285368 + 558.0021407459*t)
	X0 += 0.00000000026*np.cos(2.19672734069 + 528.4189407074*t)
	X0 += 0.00000000033*np.cos(5.60590635849 + 68.5618234438*t)
	X0 += 0.00000000026*np.cos(2.14391745890 + 530.9629894818*t)
	X0 += 0.00000000034*np.cos(2.24082486732 + 81.0013736908*t)
	X0 += 0.00000000032*np.cos(3.06209611372 + 885.4397106664*t)
	X0 += 0.00000000027*np.cos(0.11026948051 + 69.3649725959*t)
	X0 += 0.00000000029*np.cos(5.32028981868 + 181.7583419392*t)
	X0 += 0.00000000024*np.cos(6.14830012198 + 41.0537969446*t)
	X0 += 0.00000000031*np.cos(0.66559323336 + 235.3904959658*t)
	X0 += 0.00000000027*np.cos(4.38319692097 + 88.7962442478*t)
	X0 += 0.00000000026*np.cos(5.05798020797 + 427.1194557378*t)
	X0 += 0.00000000026*np.cos(0.46301099062 + 206.706813299*t)
	X0 += 0.00000000023*np.cos(5.42203185877 + 146.3818033969*t)
	X0 += 0.00000000024*np.cos(2.92749869616 + 447.9388318784*t)
	X0 += 0.00000000026*np.cos(2.59525206009 + 746.9222137957*t)
	X0 += 0.00000000023*np.cos(5.88384962075 + 31.5407534988*t)
	X0 += 0.00000000031*np.cos(3.78497688028 + 1058.4187223427*t)
	X0 += 0.00000000023*np.cos(1.70061470411 + 934.9485149682*t)
	X0 += 0.00000000023*np.cos(1.81054497604 + 14.0146456805*t)
	X0 += 0.00000000026*np.cos(4.93016524161 + 342.2553647531*t)
	X0 += 0.00000000029*np.cos(0.23984449899 + 23.5758732361*t)
	X0 += 0.00000000023*np.cos(2.53647453704 + 523.0986829556*t)
	X0 += 0.00000000027*np.cos(3.05550059377 + 258.0244132148*t)
	X0 += 0.00000000029*np.cos(1.56958922292 + 1023.9572075371*t)
	X0 += 0.00000000021*np.cos(3.01607737644 + 420.9691165835*t)
	X0 += 0.00000000022*np.cos(1.08435169766 + 491.5579294568*t)
	X0 += 0.00000000028*np.cos(1.89166907104 + 162.0933701068*t)
	X0 += 0.00000000026*np.cos(0.76643908895 + 152.0108776894*t)
	X0 += 0.00000000026*np.cos(0.06021608153 + 1158.5425511447*t)
	X0 += 0.00000000024*np.cos(4.28461358360 + 260.9933586314*t)
	X0 += 0.00000000023*np.cos(2.51081319916 + 4.665866446*t)
	X0 += 0.00000000022*np.cos(2.53548727754 + 337.732510659*t)
	X0 += 0.00000000024*np.cos(3.30132330920 + 1134.1635287565*t)
	X0 += 0.00000000021*np.cos(1.80330951791 + 536.2832472336*t)
	X0 += 0.00000000021*np.cos(3.62446848832 + 521.6142102473*t)
	X0 += 0.00000000020*np.cos(3.10946208664 + 692.5874843535*t)
	X0 += 0.00000000020*np.cos(2.83591185309 + 212.0752551606*t)
	X0 += 0.00000000020*np.cos(2.05371431350 + 214.5229357154*t)
	X0 += 0.00000000020*np.cos(5.53175498038 + 630.3360587584*t)
	X0 += 0.00000000020*np.cos(2.96877128550 + 2104.5367663768*t)
	X0 += 0.00000000026*np.cos(0.67723932625 + 776.9303104764*t)
	X0 += 0.00000000023*np.cos(3.14028242096 + 495.7507151508*t)
	X0 += 0.00000000022*np.cos(5.46738021368 + 391.1734682239*t)
	X0 += 0.00000000019*np.cos(5.79794377748 + 2.9207613068*t)
	X0 += 0.00000000023*np.cos(4.74205819227 + 353.301065017*t)
	X0 += 0.00000000021*np.cos(6.19036413024 + 320.3240229197*t)
	X0 += 0.00000000019*np.cos(5.50124179878 + 423.6774295692*t)
	X0 += 0.00000000021*np.cos(5.57097088010 + 621.7380390493*t)
	X0 += 0.00000000019*np.cos(1.03272558133 + 1603.2999892854*t)
	X0 += 0.00000000019*np.cos(1.51428153438 + 44.7253177768*t)
	X0 += 0.00000000020*np.cos(3.04457317761 + 211.6021744086*t)
	X0 += 0.00000000021*np.cos(3.47252263966 + 73.4090004436*t)
	X0 += 0.00000000020*np.cos(0.64353479758 + 372.4235201282*t)
	X0 += 0.00000000019*np.cos(1.69613741566 + 6.1503391543*t)
	X0 += 0.00000000023*np.cos(0.24495600934 + 561.934294009*t)
	X0 += 0.00000000020*np.cos(5.61075502521 + 157.6399519819*t)
	X0 += 0.00000000021*np.cos(4.72389831021 + 134.5853436076*t)
	X0 += 0.00000000023*np.cos(5.41241581728 + 8.0767548473*t)
	X0 += 0.00000000018*np.cos(3.20573786676 + 2531.1349572528*t)
	X0 += 0.00000000018*np.cos(5.75169680594 + 99.9113804809*t)
	X0 += 0.00000000018*np.cos(4.12538298541 + 104351.61256629678*t)
	X0 += 0.00000000017*np.cos(1.49131618722 + 953.1077622329*t)
	X0 += 0.00000000020*np.cos(3.28882834991 + 696.5196376166*t)
	X0 += 0.00000000019*np.cos(5.05188282673 + 1098.7388061044*t)
	X0 += 0.00000000018*np.cos(3.28242315954 + 184.9879197867*t)
	X0 += 0.00000000017*np.cos(3.04543466944 + 230.5645708254*t)
	X0 += 0.00000000023*np.cos(6.00963896724 + 916.9322800554*t)
	X0 += 0.00000000017*np.cos(3.20560881801 + 267.4737661858*t)
	X0 += 0.00000000018*np.cos(3.88202573179 + 182.279606801*t)
	X0 += 0.00000000023*np.cos(6.25048261828 + 6.2197751235*t)
	X0 += 0.00000000018*np.cos(2.54015443097 + 31.019488637*t)
	X0 += 0.00000000019*np.cos(0.27995809484 + 7.4223635415*t)
	X0 += 0.00000000017*np.cos(5.12544427579 + 600.5404103988*t)
	X0 += 0.00000000021*np.cos(4.27520120566 + 286.596221297*t)
	X0 += 0.00000000017*np.cos(2.82710574399 + 152.7445908723*t)
	X0 += 0.00000000020*np.cos(3.15496505590 + 1166.4068576709*t)
	X0 += 0.00000000019*np.cos(0.93260332932 + 778.4147831847*t)
	X0 += 0.00000000017*np.cos(0.71577565405 + 537.7677199419*t)
	X0 += 0.00000000017*np.cos(0.80031134767 + 526.9826521089*t)
	X0 += 0.00000000019*np.cos(5.70255270090 + 220.9339073006*t)
	X0 += 0.00000000016*np.cos(0.85872562979 + 125.9873238985*t)
	X0 += 0.00000000016*np.cos(1.29170718466 + 241.6102710893*t)
	X0 += 0.00000000017*np.cos(0.67834725691 + 32.2433289144*t)
	X0 += 0.00000000016*np.cos(1.08234577224 + 2435.155730035*t)
	X0 += 0.00000000016*np.cos(2.63929129920 + 436.8931316145*t)
	X0 += 0.00000000016*np.cos(0.09975901912 + 135.5485514541*t)
	X0 += 0.00000000017*np.cos(2.24648465702 + 2744.4340526908*t)
	X0 += 0.00000000020*np.cos(5.59753462144 + 141.4864422873*t)
	X0 += 0.00000000016*np.cos(3.01487400340 + 627.3671133418*t)
	X0 += 0.00000000016*np.cos(0.71201836603 + 2228.9701815978*t)
	X0 += 0.00000000017*np.cos(1.83689902078 + 214.9960164674*t)
	X0 += 0.00000000020*np.cos(4.00993370051 + 505.3119427064*t)
	X0 += 0.00000000015*np.cos(3.31455438934 + 1049.0869894507*t)
	X0 += 0.00000000015*np.cos(2.20607541706 + 319.5732633943*t)
	X0 += 0.00000000018*np.cos(1.47352611971 + 576.1613880106*t)
	X0 += 0.00000000016*np.cos(6.07005900395 + 636.7158925763*t)
	X0 += 0.00000000016*np.cos(5.19901196241 + 731.9443602687*t)
	X0 += 0.00000000018*np.cos(0.61423288161 + 1969.2006632438*t)
	X0 += 0.00000000016*np.cos(0.38827434188 + 416.3032501375*t)
	X0 += 0.00000000016*np.cos(5.12479514781 + 95.3885263868*t)
	X0 += 0.00000000017*np.cos(1.84286799688 + 221.1634019642*t)
	X0 += 0.00000000015*np.cos(3.57429118232 + 532.3992780803*t)
	X0 += 0.00000000015*np.cos(0.29047743947 + 617.8058857862*t)
	X0 += 0.00000000015*np.cos(5.08007114480 + 7.065362891*t)
	X0 += 0.00000000015*np.cos(4.08934218455 + 988.532484885*t)
	X0 += 0.00000000016*np.cos(3.89518074256 + 273.1028404783*t)
	X0 += 0.00000000016*np.cos(4.69568881762 + 107.0249274817*t)
	X0 += 0.00000000018*np.cos(1.55087961326 + 24.3790223882*t)
	X0 += 0.00000000018*np.cos(2.58391340476 + 421.93232443*t)
	X0 += 0.00000000014*np.cos(2.01138855049 + 211.8628068395*t)
	X0 += 0.00000000014*np.cos(2.87823761610 + 214.7353840365*t)
	X0 += 0.00000000016*np.cos(0.32998009587 + 73.1852512744*t)
	X0 += 0.00000000015*np.cos(4.43527029177 + 444.7574381407*t)
	X0 += 0.00000000014*np.cos(2.27226995206 + 1058.8606653274*t)
	X0 += 0.00000000017*np.cos(3.47272468105 + 439.1283638482*t)
	X0 += 0.00000000015*np.cos(4.98128142959 + 51.2057253312*t)
	X0 += 0.00000000018*np.cos(3.88128660770 + 523.4711899711*t)
	X0 += 0.00000000014*np.cos(3.53454927143 + 219.6618829134*t)
	X0 += 0.00000000015*np.cos(1.90941686167 + 30.7106720963*t)
	X0 += 0.00000000013*np.cos(5.70370503525 + 5.4166259714*t)
	X0 += 0.00000000014*np.cos(2.58219550011 + 292.0128472684*t)
	X0 += 0.00000000018*np.cos(5.28683736240 + 45.2465826386*t)
	X0 += 0.00000000014*np.cos(1.68702875678 + 1070.4276304531*t)
	X0 += 0.00000000014*np.cos(5.78637079670 + 430.79097657*t)
	X0 += 0.00000000015*np.cos(2.01136997449 + 199.2844497575*t)
	X0 += 0.00000000014*np.cos(4.00457707297 + 429.5189521828*t)
	X0 += 0.00000000013*np.cos(2.97004270413 + 425.8474313506*t)
	X0 += 0.00000000014*np.cos(0.97437425190 + 282.4516197128*t)
	X0 += 0.00000000017*np.cos(1.83348947424 + 1151.4290041439*t)
	X0 += 0.00000000014*np.cos(4.78996313082 + 2015.6710861598*t)
	X0 += 0.00000000013*np.cos(4.21520509231 + 1585.8915015461*t)
	X0 += 0.00000000017*np.cos(0.48416118894 + 535.9107402181*t)
	X0 += 0.00000000013*np.cos(3.45936802493 + 46.470422916*t)
	X0 += 0.00000000016*np.cos(5.76249012660 + 418.5214360287*t)
	X0 += 0.00000000013*np.cos(3.90798490709 + 598.8434893694*t)
	X0 += 0.00000000016*np.cos(5.22774546552 + 638.4128136057*t)
	X0 += 0.00000000013*np.cos(0.46709169716 + 498.6714764576*t)
	X0 += 0.00000000013*np.cos(0.79337465407 + 1592.2542890215*t)
	X0 += 0.00000000015*np.cos(4.25318608646 + 945.2434557067*t)
	X0 += 0.00000000016*np.cos(5.92993311098 + 347.8844390456*t)
	X0 += 0.00000000014*np.cos(0.16692912019 + 36.7604375141*t)
	X0 += 0.00000000012*np.cos(3.75584044196 + 421.1815649046*t)
	X0 += 0.00000000013*np.cos(1.87797520486 + 2655.5683724738*t)
	X0 += 0.00000000013*np.cos(4.07633589921 + 13362.4497067992*t)
	X0 += 0.00000000015*np.cos(2.90133577623 + 205.4347889118*t)
	X0 += 0.00000000014*np.cos(2.49938225869 + 1550.939859646*t)
	X0 += 0.00000000012*np.cos(4.01378199978 + 597.3590166611*t)
	X0 += 0.00000000012*np.cos(3.84453802064 + 560.7104537316*t)
	X0 += 0.00000000012*np.cos(3.79179070423 + 35.4247226521*t)
	X0 += 0.00000000012*np.cos(1.71351399381 + 339.2864193365*t)
	X0 += 0.00000000014*np.cos(5.52394393779 + 147.1155165798*t)
	X0 += 0.00000000016*np.cos(1.82129928700 + 1289.9465010146*t)
	X0 += 0.00000000014*np.cos(1.39672973940 + 192.6921676185*t)
	X0 += 0.00000000014*np.cos(0.98564818086 + 39.5056337615*t)
	X0 += 0.00000000014*np.cos(2.01080991907 + 7.1617311106*t)
	X0 += 0.00000000012*np.cos(4.15404190165 + 2317.8358618148*t)
	X0 += 0.00000000011*np.cos(0.00734522377 + 938.1299087059*t)
	X0 += 0.00000000012*np.cos(5.35882506787 + 608.404716925*t)
	X0 += 0.00000000012*np.cos(0.86405998048 + 166.828672522*t)
	X0 += 0.00000000012*np.cos(5.95648425326 + 527.9940440652*t)
	X0 += 0.00000000012*np.cos(4.66738670229 + 531.387886124*t)
	X0 += 0.00000000011*np.cos(3.36881418888 + 33.1371007917*t)
	X0 += 0.00000000014*np.cos(2.76750382786 + 1059.903195051*t)
	X0 += 0.00000000015*np.cos(2.03673871596 + 150.5264049811*t)
	X0 += 0.00000000013*np.cos(6.23673461623 + 432.2272651685*t)
	X0 += 0.00000000012*np.cos(3.91938817205 + 116.4260963429*t)
	X0 += 0.00000000013*np.cos(5.47892889469 + 205.6642835754*t)
	X0 += 0.00000000011*np.cos(2.09919951698 + 5.6290742925*t)
	X0 += 0.00000000012*np.cos(2.30318503256 + 120.9913890524*t)
	X0 += 0.00000000011*np.cos(4.76409724067 + 528.2546764961*t)
	X0 += 0.00000000011*np.cos(5.85977371488 + 531.1272536931*t)
	X0 += 0.00000000011*np.cos(1.36669731999 + 206.9363079626*t)
	X0 += 0.00000000010*np.cos(0.52628058703 + 427.3489504014*t)
	X0 += 0.00000000011*np.cos(2.96498568744 + 629.6023455755*t)
	X0 += 0.00000000011*np.cos(3.44074661251 + 150.0844619964*t)
	X0 += 0.00000000010*np.cos(3.96428676306 + 1891.2376709388*t)
	X0 += 0.00000000011*np.cos(3.59458961446 + 1148.2476104062*t)
	X0 += 0.00000000013*np.cos(5.16830110187 + 428.0826635843*t)
	X0 += 0.00000000011*np.cos(2.85370771355 + 209.1544938538*t)
	X0 += 0.00000000010*np.cos(0.83219814671 + 210.3301500214*t)
	X0 += 0.00000000011*np.cos(1.00519361513 + 244.318584075*t)
	X0 += 0.00000000014*np.cos(4.25769082986 + 381.6122406683*t)
	X0 += 0.00000000012*np.cos(1.00985107812 + 28.3111756513*t)
	X0 += 0.00000000010*np.cos(4.22443079945 + 415.2918581812*t)
	X0 += 0.00000000014*np.cos(1.44401516208 + 1173.5204046717*t)
	X0 += 0.00000000011*np.cos(4.32318890062 + 27.0873353739*t)
	X0 += 0.00000000010*np.cos(4.38248905741 + 605.9570363702*t)
	X0 += 0.00000000013*np.cos(3.98017256784 + 212.4053235607*t)
	X0 += 0.00000000013*np.cos(0.90945359875 + 214.1928673153*t)
	X0 += 0.00000000010*np.cos(1.51395699369 + 867.4234757536*t)
	X0 += 0.00000000011*np.cos(2.02395638599 + 217.4436970222*t)
	X0 += 0.00000000013*np.cos(3.28064944943 + 378.6432952517*t)
	X0 += 0.00000000010*np.cos(4.77279277602 + 181.806526049*t)
	X0 += 0.00000000013*np.cos(4.73304249071 + 60.7669528868*t)
	X0 += 0.00000000011*np.cos(1.50524823194 + 760.25553592*t)
	X0 += 0.00000000013*np.cos(2.90587483400 + 721.6494195302*t)
	X0 += 0.00000000010*np.cos(0.58477845760 + 460.5384408198*t)
	X0 += 0.00000000009*np.cos(3.68049453811 + 1159.2933106701*t)
	X0 += 0.00000000012*np.cos(1.24750093919 + 1041.2226829245*t)
	X0 += 0.00000000010*np.cos(0.54444836634 + 431.264057322*t)
	X0 += 0.00000000010*np.cos(3.86442437133 + 546.956440482*t)
	X0 += 0.00000000009*np.cos(5.73768781210 + 405.2575498736*t)
	X0 += 0.00000000012*np.cos(4.72677764054 + 450.9772132642*t)
	X0 += 0.00000000012*np.cos(3.19048334390 + 738.7972748386*t)
	X0 += 0.00000000011*np.cos(5.44274383166 + 218.4069048687*t)
	X0 += 0.00000000009*np.cos(5.75989455513 + 1165.6560981455*t)
	X0 += 0.00000000009*np.cos(5.59272866151 + 528.4671248172*t)
	X0 += 0.00000000009*np.cos(0.03279656103 + 465.9550667912*t)
	X0 += 0.00000000008*np.cos(5.03177372934 + 530.914805372*t)
	X0 += 0.00000000009*np.cos(0.70755225378 + 754.0357607965*t)
	X0 += 0.00000000009*np.cos(1.62201862141 + 69.6737891366*t)
	X0 += 0.00000000009*np.cos(1.64864876033 + 41.6444977756*t)
	X0 += 0.00000000008*np.cos(4.86069962324 + 405.9912630565*t)
	X0 += 0.00000000008*np.cos(3.04567788139 + 131.5469622218*t)
	X0 += 0.00000000008*np.cos(3.30595652486 + 1056.4611688824*t)
	X0 += 0.00000000010*np.cos(1.63940870221 + 448.6895914038*t)
	X0 += 0.00000000008*np.cos(3.29997540369 + 192.8522263129*t)
	X0 += 0.00000000011*np.cos(1.68540938250 + 1020.025054274*t)
	X0 += 0.00000000008*np.cos(6.03813286552 + 361.3778198643*t)
	X0 += 0.00000000010*np.cos(5.98984255240 + 381.3516082374*t)
	X0 += 0.00000000009*np.cos(4.70828980485 + 0.7507595254*t)
	X0 += 0.00000000010*np.cos(5.89858083622 + 189.1807054807*t)
	X0 += 0.00000000008*np.cos(0.33717409862 + 464.7312265138*t)
	X0 += 0.00000000008*np.cos(0.99970183807 + 6.592282139*t)
	X0 += 0.00000000009*np.cos(3.28890530109 + 36.5366883449*t)
	X0 += 0.00000000010*np.cos(3.77821648391 + 530.5847369719*t)
	X0 += 0.00000000010*np.cos(0.56246916446 + 528.7971932173*t)
	X0 += 0.00000000009*np.cos(4.72230764398 + 556.5176680376*t)
	X0 += 0.00000000008*np.cos(4.43807120661 + 422.405405182*t)
	X0 += 0.00000000009*np.cos(4.29850392051 + 29.2049475286*t)
	X0 += 0.00000000008*np.cos(3.85222972174 + 100.3844612329*t)
	X0 += 0.00000000008*np.cos(6.23579223483 + 411.620337349*t)
	X0 += 0.00000000008*np.cos(0.68482481630 + 1058.6311706638*t)
	X0 += 0.00000000008*np.cos(4.91506773158 + 533.8355666788*t)
	X0 += 0.00000000008*np.cos(0.46834372601 + 462.0229135281*t)
	X0 += 0.00000000008*np.cos(5.78385088790 + 0.5212648618*t)
	X0 += 0.00000000008*np.cos(6.22890340169 + 79.889407998*t)
	X0 += 0.00000000008*np.cos(3.94629223845 + 333.657345044*t)
	X0 += 0.00000000009*np.cos(4.26734987210 + 39.7293829307*t)
	X0 += 0.00000000008*np.cos(2.98826447179 + 120.358249606*t)
	X0 += 0.00000000007*np.cos(4.89759618258 + 521.8266585684*t)
	X0 += 0.00000000007*np.cos(4.81486070504 + 412.5835451955*t)
	X0 += 0.00000000007*np.cos(0.15046277095 + 313.2104759189*t)
	X0 += 0.00000000009*np.cos(2.63948646596 + 395.578702239*t)
	X0 += 0.00000000009*np.cos(0.18123663037 + 710.7467316182*t)
	X0 += 0.00000000007*np.cos(0.10534331873 + 244.791664827*t)
	X0 += 0.00000000008*np.cos(5.75679711029 + 525.5463635104*t)
	X0 += 0.00000000007*np.cos(4.59358863317 + 19.1224551112*t)
	X0 += 0.00000000007*np.cos(5.72649982853 + 537.5552716208*t)
	X0 += 0.00000000010*np.cos(0.23615439292 + 456.3938392356*t)
	X0 += 0.00000000007*np.cos(1.58965037142 + 233.7459645631*t)
	X0 += 0.00000000008*np.cos(1.73038484337 + 1062.302691496*t)
	X0 += 0.00000000010*np.cos(3.49567833493 + 259.769518354*t)
	X0 += 0.00000000008*np.cos(3.78820033364 + 103.3534066495*t)
	X0 += 0.00000000007*np.cos(3.52893695460 + 1064.7985561606*t)
	X0 += 0.00000000007*np.cos(3.50458401378 + 1063.5747158832*t)
	X0 += 0.00000000009*np.cos(4.25855108963 + 148.5999892881*t)
	X0 += 0.00000000008*np.cos(4.35494896361 + 1060.1326897146*t)
	X0 += 0.00000000007*np.cos(4.18123300134 + 216.2680408546*t)
	X0 += 0.00000000008*np.cos(6.18508958274 + 129.9194771616*t)
	X0 += 0.00000000008*np.cos(1.89853583330 + 214.9436268407*t)
	X0 += 0.00000000008*np.cos(2.99109033329 + 211.6545640353*t)
	X0 += 0.00000000007*np.cos(0.72133340576 + 229.9738699944*t)
	X0 += 0.00000000009*np.cos(2.82114719216 + 2957.7331481288*t)
	X0 += 0.00000000007*np.cos(3.54737716837 + 212.4959462859*t)
	X0 += 0.00000000007*np.cos(1.34224899822 + 214.1022445901*t)
	X0 += 0.00000000008*np.cos(2.42480688145 + 73.88782669*t)
	X0 += 0.00000000008*np.cos(5.39618820814 + 75.6753704446*t)
	X0 += 0.00000000008*np.cos(3.72293090245 + 49.1787359017*t)
	X0 += 0.00000000007*np.cos(5.95875655215 + 1054.7160637432*t)
	X0 += 0.00000000008*np.cos(3.07286040894 + 149.0419322728*t)
	X0 += 0.00000000008*np.cos(4.99659134331 + 280.9671470045*t)
	X0 += 0.00000000007*np.cos(5.96564353962 + 357.4456666012*t)
	X0 += 0.00000000009*np.cos(3.89981919489 + 2854.6403739102*t)
	X0 += 0.00000000007*np.cos(5.04857218291 + 329.7251917809*t)
	X0 += 0.00000000007*np.cos(3.86168937650 + 154.979823106*t)
	X0 += 0.00000000008*np.cos(3.12816807705 + 294.6729761443*t)
	X0 += 0.00000000007*np.cos(3.78332896542 + 952.3570027075*t)
	X0 += 0.00000000008*np.cos(5.73133921156 + 1201.831580323*t)
	X0 += 0.00000000007*np.cos(0.36133441585 + 2332.0629558164*t)
	X0 += 0.00000000006*np.cos(3.01172168751 + 2847.5268269094*t)
	X0 += 0.00000000007*np.cos(3.48727268248 + 420.4478517217*t)
	X0 += 0.00000000006*np.cos(1.96425017097 + 37.9205873167*t)
	X0 += 0.00000000007*np.cos(0.66525617500 + 36.8610112506*t)
	X0 += 0.00000000006*np.cos(5.50212297763 + 38.3454839589*t)
	X0 += 0.00000000006*np.cos(5.63043166558 + 426.4863162914*t)
	X0 += 0.00000000006*np.cos(4.63825478592 + 33.0252262071*t)
	X0 += 0.00000000009*np.cos(4.10279491097 + 602.9880909536*t)
	X0 += 0.00000000006*np.cos(1.19826616917 + 55.6591434561*t)
	X0 += 0.00000000007*np.cos(1.79305149357 + 849.2642284889*t)
	X0 += 0.00000000006*np.cos(3.29356764845 + 457.617679513*t)
	X0 += 0.00000000007*np.cos(4.46483659098 + 207.0793203145*t)
	X0 += 0.00000000006*np.cos(5.47075643317 + 857.1285350151*t)
	X0 += 0.00000000006*np.cos(6.25757589401 + 57.255490749*t)
	X0 += 0.00000000006*np.cos(0.06512506807 + 224.6054281328*t)
	X0 += 0.00000000006*np.cos(3.59601043985 + 1912.5783119412*t)
	X0 += 0.00000000006*np.cos(4.04027416405 + 426.7100654606*t)
	X0 += 0.00000000007*np.cos(6.14448582917 + 1060.8664028975*t)
	X0 += 0.00000000007*np.cos(4.94594921512 + 3337.0893083508*t)
	X0 += 0.00000000006*np.cos(1.48251823620 + 92.3077063856*t)
	X0 += 0.00000000007*np.cos(4.32054884833 + 3344.1355450488*t)
	X0 += 0.00000000006*np.cos(4.67134101381 + 223.3334037456*t)
	X0 += 0.00000000006*np.cos(0.53274286800 + 39.405060025*t)
	X0 += 0.00000000006*np.cos(4.26003431797 + 1251.3403846248*t)
	X0 += 0.00000000008*np.cos(4.10145064477 + 76.154196691*t)
	X0 += 0.00000000006*np.cos(0.83091105650 + 155.7829722581*t)
	X0 += 0.00000000006*np.cos(3.53728434401 + 1035.002907801*t)
	X0 += 0.00000000006*np.cos(2.41219986345 + 241.8709035202*t)
	X0 += 0.00000000006*np.cos(0.51482671448 + 7.6348118626*t)
	X0 += 0.00000000006*np.cos(5.22034396444 + 392.6579409322*t)
	X0 += 0.00000000007*np.cos(1.54740986712 + 1055.1891444952*t)
	X0 += 0.00000000006*np.cos(0.43830851001 + 219.5188705615*t)
	X0 += 0.00000000006*np.cos(2.07146984114 + 162.8965192589*t)
	X0 += 0.00000000006*np.cos(0.65626106294 + 402.2191684878*t)
	X0 += 0.00000000006*np.cos(0.85946852291 + 156.1554792736*t)
	X0 += 0.00000000006*np.cos(5.34953429692 + 531.3354964973*t)
	X0 += 0.00000000006*np.cos(5.27433665863 + 528.0464336919*t)
	X0 += 0.00000000007*np.cos(1.90233313085 + 945.9942152321*t)
	X0 += 0.00000000006*np.cos(1.32173573792 + 498.1983957056*t)
	X0 += 0.00000000006*np.cos(5.47616505716 + 81.7521332162*t)
	X0 += 0.00000000007*np.cos(2.66511124480 + 82.2039621088*t)
	X0 += 0.00000000006*np.cos(2.99272955808 + 76.4785195967*t)
	X0 += 0.00000000006*np.cos(0.28522323423 + 156.6767441354*t)
	X0 += 0.00000000006*np.cos(3.25560830629 + 130.4407420234*t)
	X0 += 0.00000000006*np.cos(1.49336841119 + 334.2904844904*t)
	X0 += 0.00000000006*np.cos(2.78868028616 + 810.6581120991*t)
	X0 += 0.00000000006*np.cos(4.05189163556 + 1276.6131788903*t)
	X0 += 0.00000000006*np.cos(0.74648713132 + 45.5766510387*t)
	X0 += 0.00000000005*np.cos(1.56723570226 + 1091.6252591036*t)
	X0 += 0.00000000005*np.cos(5.16689514098 + 486.4019359163*t)
	X0 += 0.00000000006*np.cos(5.69647372175 + 432.0148168474*t)
	X0 += 0.00000000005*np.cos(5.97606140060 + 513.2286388593*t)
	X0 += 0.00000000005*np.cos(2.80547070168 + 43.2408450685*t)
	X0 += 0.00000000006*np.cos(4.20221293198 + 112.6540017742*t)
	X0 += 0.00000000005*np.cos(3.42063212174 + 426.8106391971*t)
	X0 += 0.00000000006*np.cos(5.53567196142 + 343.2185725996*t)
	X0 += 0.00000000005*np.cos(6.25007370789 + 426.3857425549*t)
	X0 += 0.00000000005*np.cos(2.11475391410 + 40.8413486235*t)
	X0 += 0.00000000005*np.cos(1.07114948574 + 1176.7017984094*t)
	X0 += 0.00000000006*np.cos(4.35018202282 + 555.5544601911*t)
	X0 += 0.00000000007*np.cos(3.25502109518 + 480.7728616238*t)
	X0 += 0.00000000006*np.cos(5.50591480598 + 45.5553991793*t)
	X0 += 0.00000000006*np.cos(2.11503907739 + 1053.9653042178*t)
	X0 += 0.00000000006*np.cos(0.11648592918 + 905.8865797915*t)
	X0 += 0.00000000006*np.cos(4.34609955932 + 61.448276443*t)
	X0 += 0.00000000005*np.cos(4.48746056535 + 1064.0477966352*t)
	X0 += 0.00000000005*np.cos(4.64780966762 + 546.1532913299*t)
	X0 += 0.00000000007*np.cos(2.80124535661 + 739.8086667949*t)
	X0 += 0.00000000006*np.cos(0.09149219033 + 175.4266922311*t)
	X0 += 0.00000000005*np.cos(5.86719012624 + 850.0149880143*t)
	X0 += 0.00000000005*np.cos(4.52187462738 + 831.1049812242*t)
	X0 += 0.00000000007*np.cos(1.01801357612 + 141.2258098564*t)
	X0 += 0.00000000006*np.cos(1.87732236496 + 707.5653378805*t)
	X0 += 0.00000000005*np.cos(0.07074556893 + 477.8039162072*t)
	X0 += 0.00000000006*np.cos(6.25947656335 + 1053.7528558967*t)
	X0 += 0.00000000005*np.cos(3.10917828323 + 230.7075831773*t)
	X0 += 0.00000000005*np.cos(3.31582229343 + 79.4474650133*t)
	X0 += 0.00000000005*np.cos(0.97346840268 + 1059.2218714948*t)
	X0 += 0.00000000005*np.cos(6.26376043409 + 419.532827985*t)
	X0 += 0.00000000005*np.cos(3.37579261237 + 66.9172920411*t)
	X0 += 0.00000000006*np.cos(0.99308338453 + 908.3342603463*t)
	X0 += 0.00000000005*np.cos(1.98839166500 + 3060.8259223474*t)
	X0 += 0.00000000006*np.cos(6.22377861122 + 264.5048207692*t)
	X0 += 0.00000000005*np.cos(4.45167685413 + 240.3864308119*t)
	X0 += 0.00000000005*np.cos(2.95473256444 + 199.9657733137*t)
	X0 += 0.00000000006*np.cos(2.33487799441 + 0.9632078465*t)
	X0 += 0.00000000006*np.cos(0.92085079421 + 423.6292454594*t)
	X0 += 0.00000000005*np.cos(5.29580913561 + 17.5261078183*t)
	X0 += 0.00000000005*np.cos(2.71857840469 + 263.7016716171*t)
	X0 += 0.00000000005*np.cos(3.77881171215 + 2634.2277314714*t)
	X0 += 0.00000000005*np.cos(3.53192616999 + 88.1149206916*t)
	X0 += 0.00000000006*np.cos(2.68640681528 + 42.5382696529*t)
	X0 += 0.00000000005*np.cos(4.93516969960 + 543.0242872189*t)
	X0 += 0.00000000005*np.cos(0.63675156838 + 171.6545976624*t)
	X0 += 0.00000000005*np.cos(3.63699488756 + 6279.5527316424*t)
	X0 += 0.00000000005*np.cos(3.01156282125 + 6286.5989683404*t)
	X0 += 0.00000000005*np.cos(4.38214412277 + 550.1378342197*t)
	X0 += 0.00000000006*np.cos(0.22930701912 + 206.3979967583*t)
	X0 += 0.00000000005*np.cos(4.80699392718 + 54.3347294422*t)
	X0 += 0.00000000005*np.cos(1.86321803706 + 552.5855147745*t)
	X0 += 0.00000000006*np.cos(6.25058895655 + 155.5010879678*t)
	X0 += 0.00000000005*np.cos(1.93476799444 + 226.6324175623*t)
	X0 += 0.00000000005*np.cos(4.06630537724 + 1059.5419888836*t)
	X0 += 0.00000000005*np.cos(4.82159245737 + 375.3924655448*t)
	X0 += 0.00000000004*np.cos(2.73598330927 + 642.3449668688*t)
	X0 += 0.00000000006*np.cos(0.67056603152 + 512.4254897072*t)
	X0 += 0.00000000005*np.cos(1.15267682699 + 1493.093668066*t)
	X0 += 0.00000000005*np.cos(0.27747044087 + 1069.6768709277*t)
	X0 += 0.00000000005*np.cos(3.52972228707 + 285.3723810196*t)
	X0 += 0.00000000004*np.cos(6.25556999942 + 220.3007678542*t)
	X0 += 0.00000000004*np.cos(1.64858927732 + 36.4361146084*t)
	X0 += 0.00000000005*np.cos(5.33131270004 + 172.4577468145*t)
	X0 += 0.00000000005*np.cos(4.87742365971 + 1677.9385755008*t)
	X0 += 0.00000000004*np.cos(6.27927534054 + 211.2933578679*t)
	X0 += 0.00000000004*np.cos(4.89353613323 + 215.3048330081*t)
	X0 += 0.00000000005*np.cos(4.90086872027 + 220.2001941177*t)
	X0 += 0.00000000005*np.cos(6.21439512691 + 637.4496057592*t)
	X0 += 0.00000000005*np.cos(4.65890918275 + 512.2824773553*t)
	X0 += 0.00000000005*np.cos(1.28078583936 + 724.8308132679*t)
	X0 += 0.00000000004*np.cos(6.19234387362 + 509.2440959695*t)
	X0 += 0.00000000005*np.cos(2.18198362724 + 107.7586406646*t)
	X0 += 0.00000000005*np.cos(1.62861230846 + 364.3467652809*t)
	X0 += 0.00000000005*np.cos(6.05836432635 + 199.8057146193*t)
	X0 += 0.00000000005*np.cos(5.81548506359 + 203.8979265768*t)
	X0 += 0.00000000005*np.cos(3.57390612265 + 233.9060232575*t)
	X0 += 0.00000000005*np.cos(3.08908573078 + 419.4364597654*t)
	X0 += 0.00000000006*np.cos(4.40106876451 + 256.5399405065*t)
	X0 += 0.00000000005*np.cos(2.29103192715 + 782.3469364478*t)
	X0 += 0.00000000004*np.cos(4.56650617837 + 0.1118745846*t)
	X0 += 0.00000000005*np.cos(0.07297233694 + 32.7164096664*t)
	X0 += 0.00000000004*np.cos(5.83359066112 + 39.8299566672*t)
	X0 += 0.00000000004*np.cos(0.56516359810 + 1080.7225711916*t)
	X0 += 0.00000000006*np.cos(3.13906767677 + 593.426863398*t)
	X0 += 0.00000000005*np.cos(2.31158885429 + 98.3574718034*t)
	X0 += 0.00000000004*np.cos(4.96541612753 + 195.7729876197*t)
	X0 += 0.00000000004*np.cos(5.67115944458 + 1127.0499817557*t)
	X0 += 0.00000000004*np.cos(1.60737367789 + 1489.9122743283*t)
	X0 += 0.00000000005*np.cos(1.62517014838 + 25.6028626656*t)
	X0 += 0.00000000004*np.cos(2.40061325089 + 58.1068240109*t)
	X0 += 0.00000000005*np.cos(1.06948878908 + 302.0953396858*t)
	X0 += 0.00000000005*np.cos(3.58042687309 + 409.9234163196*t)
	X0 += 0.00000000004*np.cos(5.35653580706 + 222.7002642992*t)
	X0 += 0.00000000004*np.cos(4.06609488545 + 426.8588233069*t)
	X0 += 0.00000000004*np.cos(2.60346786398 + 441.576044403*t)
	X0 += 0.00000000004*np.cos(0.23300105047 + 93.9040536785*t)
	X0 += 0.00000000004*np.cos(5.60461099527 + 426.3375584451*t)
	X0 += 0.00000000005*np.cos(5.17494898485 + 668.2084619653*t)
	X0 += 0.00000000004*np.cos(3.52879251319 + 149.3025647037*t)
	X0 += 0.00000000004*np.cos(5.56101865812 + 1578.0271950199*t)
	X0 += 0.00000000004*np.cos(0.14381117442 + 970.5162499722*t)
	X0 += 0.00000000004*np.cos(1.38562882401 + 149.6113812444*t)
	X0 += 0.00000000004*np.cos(6.12960118533 + 348.8476468921*t)
	X0 += 0.00000000004*np.cos(1.38463224406 + 512.1648572763*t)
	X0 += 0.00000000005*np.cos(3.10990191439 + 170.0100662597*t)
	X0 += 0.00000000004*np.cos(3.06553092210 + 519.656656787*t)
	X0 += 0.00000000005*np.cos(1.28224947279 + 757.2171545342*t)
	X0 += 0.00000000005*np.cos(3.94680491377 + 1065.0110044817*t)
	X0 += 0.00000000004*np.cos(4.66347910913 + 220.5245170234*t)
	X0 += 0.00000000004*np.cos(2.17156919397 + 472.1748419147*t)
	X0 += 0.00000000005*np.cos(1.44837843510 + 702.1487119091*t)
	X0 += 0.00000000004*np.cos(3.58468959797 + 469.8872200543*t)
	X0 += 0.00000000004*np.cos(5.07495410032 + 149.5150130248*t)
	X0 += 0.00000000004*np.cos(2.00328764995 + 1012.9115072732*t)
	X0 += 0.00000000004*np.cos(4.06678976074 + 980.6681783588*t)
	X0 += 0.00000000004*np.cos(3.87454314122 + 3171.0322435668*t)
	X0 += 0.00000000004*np.cos(5.04483866646 + 420.005908737*t)
	X0 += 0.00000000004*np.cos(4.42105300635 + 73.5577582899*t)
	X0 += 0.00000000004*np.cos(0.91808329819 + 196.6243208816*t)
	X0 += 0.00000000004*np.cos(2.75591015873 + 74.1484591209*t)
	X0 += 0.00000000004*np.cos(5.06508493086 + 75.4147380137*t)
	X0 += 0.00000000004*np.cos(2.95983673431 + 76.42612997*t)
	X0 += 0.00000000004*np.cos(2.95605354194 + 547.2170729129*t)
	X0 += 0.00000000004*np.cos(1.86055139375 + 434.6749457233*t)
	X0 += 0.00000000004*np.cos(0.35994914656 + 554.8207470082*t)
	X0 += 0.00000000004*np.cos(4.24181231038 + 105.4922706636*t)
	X0 += 0.00000000004*np.cos(3.25525826705 + 36.6967470393*t)
	X0 += 0.00000000004*np.cos(3.43887250550 + 241.7532834412*t)
	X0 += 0.00000000004*np.cos(2.04104726622 + 1894.4190646765*t)
	X0 += 0.00000000005*np.cos(4.79668909650 + 251.1714986449*t)
	X0 += 0.00000000004*np.cos(0.74241453708 + 303.8616966844*t)
	X0 += 0.00000000005*np.cos(3.65577645782 + 228.7982138268*t)
	X0 += 0.00000000004*np.cos(3.60324160920 + 2207.6295405954*t)
	X0 += 0.00000000004*np.cos(5.50781222588 + 991.7138786227*t)
	X0 += 0.00000000005*np.cos(4.95348326539 + 306.830642101*t)
	X0 += 0.00000000004*np.cos(3.13526908304 + 254.9435932136*t)
	X0 += 0.00000000005*np.cos(6.28132440672 + 81.682697247*t)
	X0 += 0.00000000004*np.cos(0.09955372013 + 230.8252032563*t)
	X0 += 0.00000000004*np.cos(5.14767051376 + 111.1695290659*t)
	X0 += 0.00000000004*np.cos(5.69029445241 + 107.2855599126*t)
	X0 += 0.00000000005*np.cos(1.81491003474 + 1025.4416802454*t)
	X0 += 0.00000000004*np.cos(0.23827089423 + 502.8642621516*t)
	X0 += 0.00000000004*np.cos(3.03403218377 + 864.2420820159*t)
	X0 += 0.00000000004*np.cos(4.26189559841 + 82.6459050935*t)
	X0 += 0.00000000004*np.cos(1.40793491013 + 149.723255829*t)
	X0 += 0.00000000004*np.cos(6.19905331529 + 19.643719973*t)
	X0 += 0.00000000005*np.cos(2.43683958020 + 705.1176573257*t)
	X0 += 0.00000000004*np.cos(1.45153572664 + 572.2292347475*t)
	X0 += 0.00000000004*np.cos(2.13774051943 + 258.8757464767*t)
	X0 += 0.00000000004*np.cos(5.40099325431 + 1087.6931058405*t)
	X0 += 0.00000000004*np.cos(1.38867112725 + 567.5633683015*t)
	X0 += 0.00000000004*np.cos(5.53765573189 + 580.0935412737*t)
	X0 += 0.00000000004*np.cos(6.27057119053 + 394.3548619616*t)
	X0 += 0.00000000003*np.cos(3.45288650377 + 140.9651774255*t)
	X0 += 0.00000000004*np.cos(5.36284964319 + 100.6450936638*t)
	X0 += 0.00000000003*np.cos(0.89310088564 + 130439.51570787099*t)
	X0 += 0.00000000004*np.cos(5.80893733291 + 1587.5884225755*t)
	X0 += 0.00000000004*np.cos(2.89095140471 + 1567.7322542814*t)
	X0 += 0.00000000004*np.cos(4.52643489849 + 143.9341228421*t)
	X0 += 0.00000000004*np.cos(0.96145989389 + 2042.4977891028*t)
	X0 += 0.00000000004*np.cos(3.96859441386 + 193.655375465*t)
	X0 += 0.00000000004*np.cos(5.02425178015 + 238.5718897035*t)
	X0 += 0.00000000004*np.cos(5.11695904237 + 110.1581371096*t)
	X0 += 0.00000000003*np.cos(5.17950094296 + 73.1370671646*t)
	X0 += 0.00000000004*np.cos(2.93179041114 + 149.8238295655*t)
	X0 += 0.00000000003*np.cos(4.76622902140 + 611.4430983108*t)
	X0 += 0.00000000004*np.cos(1.09513559040 + 188.1693135244*t)
	X0 += 0.00000000004*np.cos(0.25248020511 + 180.2738692309*t)
	X0 += 0.00000000004*np.cos(5.28426892997 + 67.3592350258*t)
	X0 += 0.00000000004*np.cos(5.35419077202 + 775.233389447*t)
	X0 += 0.00000000003*np.cos(3.52142207371 + 280.003939158*t)
	X0 += 0.00000000003*np.cos(1.23056459844 + 1059.5943785103*t)
	X0 += 0.00000000003*np.cos(0.75885628840 + 589.4947101349*t)
	X0 += 0.00000000003*np.cos(4.16966612993 + 3067.9394693482*t)
	X0 += 0.00000000004*np.cos(5.70802804049 + 1215.1649024473*t)
	X0 += 0.00000000004*np.cos(5.05264801420 + 149.4031384402*t)
	X0 += 0.00000000004*np.cos(0.63582211896 + 386.9806825299*t)
	X0 += 0.00000000004*np.cos(1.71469452484 + 370.9390474199*t)
	X0 += 0.00000000003*np.cos(0.94878833235 + 714.6788848813*t)
	X0 += 0.00000000003*np.cos(1.50958836322 + 531.6967026647*t)
	X0 += 0.00000000003*np.cos(4.73293055490 + 26.0235537909*t)
	X0 += 0.00000000003*np.cos(2.83054697992 + 527.6852275245*t)
	X0 += 0.00000000004*np.cos(5.92517735863 + 547.0994528339*t)
	X0 += 0.00000000004*np.cos(1.08892988858 + 43.5496616092*t)
	X0 += 0.00000000003*np.cos(3.80935500835 + 119.5069163441*t)
	X0 += 0.00000000004*np.cos(1.25315522683 + 76.3779458602*t)
	X0 += 0.00000000003*np.cos(4.56981162018 + 36.1272980677*t)
	X0 += 0.00000000003*np.cos(2.80378740729 + 1049.8207026336*t)
	X0 += 0.00000000004*np.cos(1.41709455573 + 173.6815870919*t)
	X0 += 0.00000000004*np.cos(2.46761078183 + 295.0512286542*t)
	X0 += 0.00000000004*np.cos(1.80919366799 + 256.5881246163*t)
	X0 += 0.00000000003*np.cos(5.87177945625 + 135.336103133*t)
	X0 += 0.00000000003*np.cos(0.22690805842 + 203.2647871304*t)
	X0 += 0.00000000003*np.cos(2.83010447093 + 487.3651437628*t)
	X0 += 0.00000000004*np.cos(5.00226658838 + 739.0579072695*t)
	X0 += 0.00000000003*np.cos(5.86628100650 + 254.1404440615*t)
	X0 += 0.00000000003*np.cos(5.68498847387 + 639.9454704238*t)
	X0 += 0.00000000004*np.cos(3.50280012196 + 331.3215390738*t)
	X0 += 0.00000000003*np.cos(1.79235109505 + 110.2545053292*t)
	X0 += 0.00000000004*np.cos(5.36814372477 + 638.9340784675*t)
	X0 += 0.00000000003*np.cos(3.80920918148 + 1059.1694818681*t)
	X0 += 0.00000000003*np.cos(3.33130153368 + 274.0660483248*t)
	X0 += 0.00000000004*np.cos(5.97762333728 + 432.7485300303*t)
	X0 += 0.00000000003*np.cos(2.19320354072 + 1077.5411774539*t)
	X0 += 0.00000000003*np.cos(5.89724642359 + 43.2890291783*t)
	X0 += 0.00000000004*np.cos(6.06160976341 + 221.8971151471*t)
	X0 += 0.00000000004*np.cos(1.24083966170 + 815.0633461142*t)
	X0 += 0.00000000004*np.cos(1.33706645929 + 987.3086446076*t)
	X0 += 0.00000000004*np.cos(4.05650089284 + 196.0336200506*t)
	X0 += 0.00000000004*np.cos(1.06568745313 + 82.4858463991*t)
	X0 += 0.00000000003*np.cos(4.91752202451 + 206.2974230218*t)
	X0 += 0.00000000004*np.cos(2.69006131865 + 812.1425848074*t)
	X0 += 0.00000000003*np.cos(4.95770426549 + 201.9927627432*t)
	X0 += 0.00000000003*np.cos(2.48720016782 + 639.8491022042*t)
	X0 += 0.00000000004*np.cos(4.76320757504 + 226.7924762567*t)
	X0 += 0.00000000003*np.cos(2.47509856918 + 570.5323137181*t)
	X0 += 0.00000000003*np.cos(1.28045803659 + 539.7252734022*t)
	X0 += 0.00000000003*np.cos(4.43001668817 + 142.1408335931*t)
	X0 += 0.00000000003*np.cos(0.26851143457 + 16.04163511*t)
	X0 += 0.00000000004*np.cos(4.09050768363 + 986.0848043302*t)
	X0 += 0.00000000003*np.cos(4.27178324734 + 189.7232222019*t)
	X0 += 0.00000000004*np.cos(2.42280320221 + 2.7083129857*t)
	X0 += 0.00000000003*np.cos(5.07177336417 + 73.9784494152*t)
	X0 += 0.00000000003*np.cos(2.74922172542 + 75.5847477194*t)
	X0 += 0.00000000003*np.cos(2.94228501166 + 186.472392495*t)
	X0 += 0.00000000003*np.cos(3.24022391586 + 196.8367692027*t)
	X0 += 0.00000000004*np.cos(0.46903738793 + 1123.1178284926*t)
	X0 += 0.00000000003*np.cos(1.17647652114 + 61.2882177486*t)
	X0 += 0.00000000004*np.cos(1.54977795976 + 16.4623262353*t)
	X0 += 0.00000000003*np.cos(1.05692758404 + 31.492569389*t)
	X0 += 0.00000000003*np.cos(3.14008156083 + 262.4778313397*t)
	X0 += 0.00000000004*np.cos(2.10094499782 + 977.4867846211*t)
	X0 += 0.00000000003*np.cos(4.60797849528 + 70.0462961521*t)
	X0 += 0.00000000003*np.cos(3.39936446935 + 24.1183899573*t)
	X0 += 0.00000000003*np.cos(2.68939857071 + 3274.1250177854*t)
	X0 += 0.00000000003*np.cos(3.13208663729 + 468.2426886516*t)
	X0 += 0.00000000003*np.cos(2.05468089692 + 119.767548775*t)
	X0 += 0.00000000003*np.cos(1.50445590295 + 522.6892926784*t)
	X0 += 0.00000000003*np.cos(2.83622974542 + 536.6926375108*t)
	X0 += 0.00000000003*np.cos(4.24753418587 + 1269.4996318895*t)
	X0 += 0.00000000003*np.cos(0.06386018467 + 433.7599219866*t)
	X0 += 0.00000000003*np.cos(4.00822188770 + 504.561183181*t)
	X0 += 0.00000000003*np.cos(0.39985292097 + 76.7873361374*t)
	X0 += 0.00000000003*np.cos(2.94792508306 + 640.8604941605*t)
	X0 += 0.00000000003*np.cos(1.03128411434 + 1591.5205758386*t)
	X0 += 0.00000000004*np.cos(1.48263789161 + 109.2431133729*t)
	X0 += 0.00000000003*np.cos(5.46315849990 + 219.1406180516*t)
	X0 += 0.00000000003*np.cos(4.86651190509 + 3281.2385647862*t)
	X0 += 0.00000000003*np.cos(6.15520330614 + 194.1766403268*t)
	X0 += 0.00000000003*np.cos(4.97547279217 + 1586.625214729*t)
	X0 += 0.00000000003*np.cos(4.20682047645 + 334.5511169213*t)
	X0 += 0.00000000003*np.cos(2.72699112849 + 504.4181708291*t)
	X0 += 0.00000000003*np.cos(0.67418030776 + 406.954470903*t)
	X0 += 0.00000000003*np.cos(3.15892697874 + 433.663553767*t)
	X0 += 0.00000000003*np.cos(3.63739450025 + 423.8898778903*t)
	X0 += 0.00000000003*np.cos(1.54816733466 + 403.0223176399*t)
	X0 += 0.00000000003*np.cos(4.57883962911 + 572.9799942729*t)
	X0 += 0.00000000003*np.cos(1.52961235336 + 229.7614216733*t)
	X0 += 0.00000000003*np.cos(4.22545792443 + 36.9091953604*t)
	X0 += 0.00000000003*np.cos(0.12995290876 + 117.36805233*t)
	X0 += 0.00000000003*np.cos(4.16548884137 + 967.3348562345*t)
	X0 += 0.00000000003*np.cos(1.91141494309 + 240.125798381*t)
	X0 += 0.00000000003*np.cos(5.55886339362 + 332.8060117821*t)
	X0 += 0.00000000003*np.cos(0.49665437181 + 67.0773507355*t)
	X0 += 0.00000000003*np.cos(3.57780301242 + 176.6505325085*t)
	X0 += 0.00000000003*np.cos(2.23422402451 + 911.3032057629*t)
	X0 += 0.00000000003*np.cos(1.59884335861 + 554.9637593601*t)
	X0 += 0.00000000003*np.cos(5.00397045800 + 594.6507036754*t)
	X0 += 0.00000000002*np.cos(2.99942126405 + 95.2284676924*t)
	X0 += 0.00000000002*np.cos(2.40803733663 + 326.6868103951*t)
	X0 += 0.00000000003*np.cos(3.22197969145 + 79.5169009825*t)
	X0 += 0.00000000003*np.cos(0.83721030457 + 16.6747745564*t)
	X0 += 0.00000000003*np.cos(3.92030488432 + 238.4288773516*t)
	X0 += 0.00000000003*np.cos(6.03331138047 + 429.3065038617*t)
	X0 += 0.00000000003*np.cos(0.13209247291 + 70.1157321213*t)
	X0 += 0.00000000003*np.cos(0.22682424097 + 206.0736738526*t)
	X0 += 0.00000000003*np.cos(0.36288338054 + 25.2727942655*t)
	X0 += 0.00000000002*np.cos(2.77884523525 + 3163.918696566*t)
	X0 += 0.00000000003*np.cos(6.20488030565 + 71.1582618449*t)
	X0 += 0.00000000002*np.cos(0.24490397723 + 426.7582495704*t)
	X0 += 0.00000000003*np.cos(0.93888874769 + 1065.6017053127*t)
	X0 += 0.00000000002*np.cos(3.14261659631 + 426.4381321816*t)
	X0 += 0.00000000002*np.cos(2.59923028230 + 2420.9286360334*t)
	X0 += 0.00000000003*np.cos(1.79414521699 + 30639.856638633*t)
	X0 += 0.00000000003*np.cos(0.54825517106 + 5223.6939198022*t)
	X0 += 0.00000000003*np.cos(3.05410924296 + 539.2521926502*t)
	X0 += 0.00000000002*np.cos(4.61492764589 + 71.8608372605*t)
	X0 += 0.00000000003*np.cos(1.23810833026 + 536.91638668*t)
	X0 += 0.00000000003*np.cos(3.10257731811 + 522.4655435092*t)
	X0 += 0.00000000003*np.cos(3.74114935593 + 824.7421937488*t)
	X0 += 0.00000000003*np.cos(4.15041076765 + 520.129737539*t)
	X0 += 0.00000000003*np.cos(5.57861200970 + 649.4585138696*t)
	X0 += 0.00000000002*np.cos(1.20650158776 + 325.9530972122*t)
	X0 += 0.00000000003*np.cos(4.60094776462 + 14143.4952424306*t)
	X0 += 0.00000000003*np.cos(1.64598439202 + 389.9496279465*t)
	X0 += 0.00000000002*np.cos(5.42610406528 + 194.3890886479*t)
	X0 += 0.00000000002*np.cos(2.13751781140 + 661.2379273164*t)
	X0 += 0.00000000002*np.cos(5.77911104169 + 685.4739373527*t)
	X0 += 0.00000000003*np.cos(4.03703631420 + 453.6855262499*t)
	X0 += 0.00000000003*np.cos(1.16315937393 + 570.7447620392*t)
	X0 += 0.00000000003*np.cos(1.35227925748 + 1438.0252254409*t)
	X0 += 0.00000000003*np.cos(4.08732834854 + 187.4356003415*t)
	X0 += 0.00000000002*np.cos(6.18518169410 + 1074.3597837162*t)
	X0 += 0.00000000002*np.cos(5.66000038201 + 1474.9344208013*t)
	X0 += 0.00000000003*np.cos(1.49592875924 + 310.1720945331*t)
	X0 += 0.00000000003*np.cos(2.81154703953 + 7.8643065262*t)
	X0 += 0.00000000002*np.cos(1.44067071366 + 148.8124376092*t)
	X0 += 0.00000000002*np.cos(3.20606735784 + 77.7023598741*t)
	X0 += 0.00000000003*np.cos(2.53528580832 + 538.2889848037*t)
	X0 += 0.00000000003*np.cos(1.80539984005 + 521.0929453855*t)
	X0 += 0.00000000003*np.cos(1.62326858020 + 78.4049352897*t)
	X0 += 0.00000000003*np.cos(3.03232861785 + 522.7898664149*t)
	X0 += 0.00000000003*np.cos(1.30835703052 + 536.5920637743*t)
	X0 += 0.00000000002*np.cos(1.26208844735 + 1053.2315910349*t)
	X0 += 0.00000000002*np.cos(0.96979540290 + 65.3804297061*t)
	X0 += 0.00000000002*np.cos(0.71301262063 + 239.1625905345*t)
	X0 += 0.00000000002*np.cos(5.33265989690 + 1090.4014188262*t)
	X0 += 0.00000000002*np.cos(0.47625782923 + 3340.5951730476*t)
	X0 += 0.00000000002*np.cos(2.50702946072 + 3340.629680352*t)
	X0 += 0.00000000003*np.cos(5.09521237124 + 204.7010757289*t)
	X0 += 0.00000000002*np.cos(1.24505774654 + 295.1942410061*t)
	X0 += 0.00000000002*np.cos(3.30323765115 + 530.324104541*t)
	X0 += 0.00000000002*np.cos(1.03744799722 + 529.0578256482*t)
	X0 += 0.00000000002*np.cos(5.72234573912 + 207.4575728244*t)
	X0 += 0.00000000002*np.cos(2.62733117707 + 255.8373650909*t)
	X0 += 0.00000000002*np.cos(5.16721331017 + 13.4933808187*t)
	X0 += 0.00000000003*np.cos(5.13399706478 + 354.5249052944*t)
	X0 += 0.00000000003*np.cos(6.08282410016 + 526.722019678*t)
	X0 += 0.00000000003*np.cos(4.54104685539 + 532.6599105112*t)
	X0 += 0.00000000002*np.cos(0.44163304191 + 167.0893049529*t)
	X0 += 0.00000000002*np.cos(5.37532129852 + 22.633917249*t)
	X0 += 0.00000000002*np.cos(1.90967634944 + 944.9828232758*t)
	X0 += 0.00000000002*np.cos(5.21294925833 + 31.6526280834*t)
	X0 += 0.00000000003*np.cos(3.80441487846 + 380.3884003909*t)
	X0 += 0.00000000002*np.cos(3.41889190378 + 74.4090915518*t)
	X0 += 0.00000000002*np.cos(4.40210318581 + 75.1541055828*t)
	X0 += 0.00000000003*np.cos(0.66816474530 + 1094.8066528413*t)
	X0 += 0.00000000002*np.cos(3.56112540301 + 806.725958836*t)
	X0 += 0.00000000002*np.cos(4.46844174027 + 1589.1210793936*t)
	X0 += 0.00000000003*np.cos(2.95111966473 + 418.0001711669*t)
	X0 += 0.00000000002*np.cos(4.82679835752 + 102.1295663721*t)
	X0 += 0.00000000002*np.cos(2.58391066888 + 2043.9822618111*t)
	X0 += 0.00000000002*np.cos(5.74670707009 + 232.2091022281*t)
	X0 += 0.00000000002*np.cos(1.52408993850 + 249.9476583675*t)
	X0 += 0.00000000002*np.cos(4.43918079155 + 366.7944458357*t)
	X0 += 0.00000000002*np.cos(3.41297750019 + 172.2452984934*t)
	X0 += 0.00000000003*np.cos(2.93230657226 + 12036.4607348882*t)
	X0 += 0.00000000002*np.cos(0.00612328663 + 902.7051860538*t)
	X0 += 0.00000000002*np.cos(5.75373194008 + 48.9181034708*t)
	X0 += 0.00000000002*np.cos(3.35674586948 + 1.2238402774*t)
	X0 += 0.00000000003*np.cos(2.32905407901 + 1440.9941708575*t)
	X0 += 0.00000000002*np.cos(2.09399044010 + 103.0445901088*t)
	X0 += 0.00000000002*np.cos(5.39102833749 + 32.5039613453*t)
	X0 += 0.00000000002*np.cos(5.55196010525 + 2122.6960136415*t)
	X0 += 0.00000000002*np.cos(1.01566504534 + 224.2329211173*t)
	X0 += 0.00000000002*np.cos(3.03116665599 + 732.6951197941*t)
	X0 += 0.00000000002*np.cos(0.86649084433 + 842.9014410135*t)
	X0 += 0.00000000003*np.cos(3.68606434925 + 343.7398374614*t)
	X0 += 0.00000000003*np.cos(6.02117511548 + 18073.7049386502*t)
	X0 += 0.00000000003*np.cos(3.05460049513 + 17.2654753874*t)
	X0 += 0.00000000002*np.cos(5.41073772136 + 91.4563731237*t)
	X0 += 0.00000000002*np.cos(4.89151612035 + 425.3261664888*t)
	X0 += 0.00000000002*np.cos(0.59126331404 + 1067.4586850365*t)
	X0 += 0.00000000002*np.cos(4.62107232093 + 376.1956146969*t)
	X0 += 0.00000000002*np.cos(4.76752444087 + 142.9709149956*t)
	X0 += 0.00000000002*np.cos(3.52994258207 + 76.0054388447*t)
	X0 += 0.00000000003*np.cos(5.68565572016 + 562.1467423301*t)
	X0 += 0.00000000002*np.cos(5.27306326646 + 103.1409583284*t)
	X0 += 0.00000000002*np.cos(4.65855264132 + 28.4541880032*t)
	X0 += 0.00000000002*np.cos(3.65134273934 + 2950.619601128*t)
	X0 += 0.00000000003*np.cos(5.26984585000 + 1130.2313754934*t)
	X0 += 0.00000000002*np.cos(2.52670317471 + 756.3233826569*t)
	X0 += 0.00000000002*np.cos(3.52271104157 + 122.4758617607*t)
	X0 += 0.00000000002*np.cos(5.51577569640 + 291.262087743*t)
	X0 += 0.00000000002*np.cos(0.60740470225 + 74.1272072615*t)
	X0 += 0.00000000002*np.cos(0.93040508016 + 75.4359898731*t)
	X0 += 0.00000000002*np.cos(5.77645664148 + 1819.6374661092*t)
	X0 += 0.00000000003*np.cos(0.60498836032 + 1261.6353253633*t)
	X0 += 0.00000000002*np.cos(1.85555664567 + 1464.6394800628*t)
	X0 += 0.00000000002*np.cos(2.06434259625 + 535.5324877082*t)
	X0 += 0.00000000002*np.cos(2.27634305212 + 523.849442481*t)
	X0 += 0.00000000002*np.cos(4.12164064571 + 41.7563723602*t)
	X0 += 0.00000000002*np.cos(1.96400730017 + 57.5161231799*t)
	X0 += 0.00000000002*np.cos(4.77918976037 + 427.8702152632*t)
	X0 += 0.00000000003*np.cos(5.01002784894 + 2281.2304965106*t)
	X0 += 0.00000000002*np.cos(3.90181444901 + 84.9335269539*t)
	X0 += 0.00000000002*np.cos(3.84718355216 + 5.1078094307*t)
	X0 += 0.00000000003*np.cos(0.54601814517 + 451.9404211107*t)
	X0 += 0.00000000002*np.cos(0.56832772908 + 84.1827674285*t)
	X0 += 0.00000000002*np.cos(0.11787362118 + 1286.9081196288*t)
	X0 += 0.00000000002*np.cos(2.44604509044 + 373.0142209592*t)
	X0 += 0.00000000002*np.cos(2.76104934362 + 1254.5217783625*t)
	X0 += 0.00000000002*np.cos(1.80073602945 + 268.9582388941*t)
	X0 += 0.00000000002*np.cos(5.06000314395 + 150.31395666*t)
	X0 += 0.00000000003*np.cos(6.16475379508 + 190.4045457581*t)
	X0 += 0.00000000002*np.cos(1.91940270557 + 1553.6481726317*t)
	X0 += 0.00000000002*np.cos(0.31114054153 + 115.6229471908*t)
	X0 += 0.00000000003*np.cos(5.00377912422 + 236.1936451179*t)
	X0 += 0.00000000002*np.cos(4.64476266878 + 125.1841747464*t)
	X0 += 0.00000000002*np.cos(5.25070372187 + 25.0603459444*t)
	X0 += 0.00000000002*np.cos(4.42006573357 + 501.2367770914*t)
	X0 += 0.00000000002*np.cos(5.28801843822 + 128.3655684841*t)
	X0 += 0.00000000002*np.cos(3.02249467823 + 70.5888128733*t)
	X0 += 0.00000000002*np.cos(5.10744435319 + 7.7042478318*t)
	X0 += 0.00000000002*np.cos(5.35861260445 + 8.9068362498*t)
	X0 += 0.00000000002*np.cos(3.04911385331 + 170.7608257851*t)
	X0 += 0.00000000002*np.cos(2.09208111477 + 43.7621099303*t)
	X0 += 0.00000000002*np.cos(2.58715268947 + 1482.7987273275*t)
	X0 += 0.00000000002*np.cos(1.55803959969 + 105.5404547734*t)
	X0 += 0.00000000002*np.cos(4.27483694362 + 2942.4634232916*t)
	X0 += 0.00000000002*np.cos(3.64312531265 + 395.105621487*t)
	X0 += 0.00000000002*np.cos(3.78724123103 + 397.3932433474*t)
	X0 += 0.00000000002*np.cos(5.30289713782 + 1208.9451273238*t)
	X0 += 0.00000000002*np.cos(3.47367432068 + 2352.8661537718*t)
	X0 += 0.00000000002*np.cos(3.34926063770 + 34.5096989154*t)
	X0 += 0.00000000002*np.cos(1.28746156532 + 856.3777754897*t)
	X0 += 0.00000000002*np.cos(1.82250579965 + 1590.0361031303*t)
	X0 += 0.00000000002*np.cos(2.88017496092 + 90.8232336773*t)
	X0 += 0.00000000002*np.cos(0.86569328720 + 25.1297819136*t)
	X0 += 0.00000000002*np.cos(5.82517984367 + 3707.8367556622*t)
	X0 += 0.00000000002*np.cos(0.05106366865 + 72.4939767069*t)
	X0 += 0.00000000002*np.cos(4.70387132819 + 19.0105805266*t)
	X0 += 0.00000000002*np.cos(6.10472383058 + 488.63716815*t)
	X0 += 0.00000000002*np.cos(0.63038290420 + 88.274979386*t)
	X0 += 0.00000000002*np.cos(4.31395354097 + 586.3133163972*t)
	X0 += 0.00000000002*np.cos(1.45400978186 + 34.2008823747*t)
	X0 += 0.00000000002*np.cos(3.44171606671 + 821.703812363*t)
	X0 += 0.00000000002*np.cos(5.54085692156 + 487.1526954417*t)
	X0 += 0.00000000002*np.cos(4.19575798942 + 328.9220426288*t)
	X0 += 0.00000000002*np.cos(3.92682506750 + 1415.130675761*t)
	X0 += 0.00000000002*np.cos(4.22448248345 + 33.4671691918*t)
	X0 += 0.00000000002*np.cos(4.19192180047 + 58.319272332*t)
	X0 += 0.00000000002*np.cos(2.09427155308 + 1059.6425626201*t)
	X0 += 0.00000000002*np.cos(0.74372474115 + 110.7275860812*t)
	X0 += 0.00000000002*np.cos(3.81738357773 + 639.3760214522*t)
	X0 += 0.00000000002*np.cos(1.79308957531 + 3377.217792004*t)
	X0 += 0.00000000002*np.cos(4.44858286586 + 5753.3848848968*t)
	X0 += 0.00000000002*np.cos(2.75611972077 + 1051.3051753419*t)
	X0 += 0.00000000002*np.cos(2.43399105921 + 104.0559820651*t)
	X0 += 0.00000000002*np.cos(0.51120251384 + 1432.3961511484*t)
	X0 += 0.00000000002*np.cos(4.06827469318 + 1052.3165672982*t)
	X0 += 0.00000000002*np.cos(3.68132699390 + 1065.5322693435*t)
	X0 += 0.00000000002*np.cos(0.58609306122 + 990.2294059144*t)
	X0 += 0.00000000002*np.cos(4.72195055580 + 418.9633790134*t)
	X0 += 0.00000000002*np.cos(2.29134701681 + 384.0599212231*t)
	X0 += 0.00000000002*np.cos(4.04783302113 + 75.6329318292*t)
	X0 += 0.00000000002*np.cos(3.77316206846 + 73.9302653054*t)
	X0 += 0.00000000002*np.cos(1.27063061264 + 1589.024711174*t)
	X0 += 0.00000000002*np.cos(2.99346636217 + 447.2051186955*t)
	X0 += 0.00000000002*np.cos(4.88775575304 + 78.9743842613*t)
	X0 += 0.00000000002*np.cos(1.08474615002 + 503.8274699981*t)
	X0 += 0.00000000002*np.cos(1.40748927321 + 77.0692204277*t)
	X0 += 0.00000000002*np.cos(4.05134033671 + 224.4566702865*t)
	X0 += 0.00000000002*np.cos(2.49061752629 + 73.0846775379*t)
	X0 += 0.00000000002*np.cos(3.53154397673 + 91.2439248026*t)
	X0 += 0.00000000002*np.cos(0.86951502887 + 995.6460318858*t)
	X0 += 0.00000000002*np.cos(3.23309081096 + 215.9592243139*t)
	X0 += 0.00000000002*np.cos(1.65653535563 + 210.6389665621*t)
	X0 += 0.00000000002*np.cos(1.49658387647 + 709.0498105888*t)
	X0 += 0.00000000002*np.cos(2.50150285724 + 369.9758395734*t)
	X0 += 0.00000000002*np.cos(0.24570435319 + 109.6850563576*t)
	X0 += 0.00000000002*np.cos(2.15125665155 + 195.8906076987*t)
	X0 += 0.00000000002*np.cos(3.20943467045 + 1446.62324515*t)
	X0 += 0.00000000002*np.cos(4.61049328066 + 104.5772469269*t)
	X0 += 0.00000000002*np.cos(5.41117792365 + 1128.534454464*t)
	X0 += 0.00000000002*np.cos(0.46801985063 + 1268.7488723641*t)
	X0 += 0.00000000002*np.cos(3.46586788072 + 1578.7779545453*t)
	X0 += 0.00000000002*np.cos(1.38960202572 + 51.8870488874*t)
	X0 += 0.00000000002*np.cos(5.26444342978 + 1363.2436268736*t)
	X0 += 0.00000000002*np.cos(3.39317903533 + 76.2178871658*t)
	X0 += 0.00000000002*np.cos(4.99250310895 + 3738.761430108*t)
	X0 += 0.00000000002*np.cos(6.24731872709 + 55.1378785943*t)
	X0 += 0.00000000002*np.cos(0.58724309766 + 313.9441891018*t)
	X0 += 0.00000000002*np.cos(4.75847324755 + 1994.3304451574*t)
	X0 += 0.00000000002*np.cos(3.44954587134 + 5.6772584023*t)
	X0 += 0.00000000002*np.cos(2.42612359762 + 516.1975842759*t)
	X0 += 0.00000000002*np.cos(1.91456205075 + 543.1843459133*t)
	X0 += 0.00000000002*np.cos(2.52619967964 + 836.5216071956*t)
	X0 += 0.00000000002*np.cos(2.25904701884 + 6812.766815086*t)
	X0 += 0.00000000002*np.cos(1.29082175295 + 5621.8429232104*t)
	X0 += 0.00000000002*np.cos(3.55324813170 + 769.8167634756*t)
	X0 += 0.00000000002*np.cos(6.14691167648 + 76.3142553854*t)
	X0 += 0.00000000002*np.cos(2.08850902011 + 93.531546663*t)
	X0 += 0.00000000002*np.cos(4.33445271140 + 640.4185511758*t)
	X0 += 0.00000000002*np.cos(0.90445180404 + 683.1863154923*t)
	X0 += 0.00000000002*np.cos(5.35980800044 + 4705.7323075436*t)
	X0 += 0.00000000002*np.cos(3.71153973175 + 433.190473015*t)
	X0 += 0.00000000002*np.cos(0.54219297827 + 1688.2335162393*t)
	X0 += 0.00000000002*np.cos(6.23579594747 + 208.1912860073*t)
	X0 += 0.00000000002*np.cos(3.24568687761 + 502.6036297207*t)
	X0 += 0.00000000002*np.cos(3.05472992905 + 700.6642392008*t)
	X0 += 0.00000000002*np.cos(4.56030783124 + 293.188503436*t)
	X0 += 0.00000000001*np.cos(2.62311467688 + 774.0095491696*t)
	X0 += 0.00000000002*np.cos(4.26036104093 + 1340.3490771937*t)
	X0 += 0.00000000002*np.cos(2.54528509700 + 232.0490435337*t)
	X0 += 0.00000000001*np.cos(0.40719946484 + 184.0941479094*t)
	X0 += 0.00000000002*np.cos(5.54653763357 + 451.7279727896*t)
	X0 += 0.00000000002*np.cos(3.78961228004 + 1696.0978227655*t)
	X0 += 0.00000000002*np.cos(6.21479839139 + 0.8031491521*t)
	return X0




def Sun_X1 (t): # 816 terms of order 1

	X1 = 0.
	X1 -= 0.00001296073
	X1 += 0.00000897419*np.cos(1.12892005450 + 426.598190876*t)
	X1 += 0.00000776911*np.cos(2.70600396412 + 206.1855484372*t)
	X1 += 0.00000753636*np.cos(2.19131779736 + 220.4126424388*t)
	X1 += 0.00000606034*np.cos(3.24815679698 + 1059.3819301892*t)
	X1 += 0.00000572567*np.cos(5.56994506134 + 522.5774180938*t)
	X1 += 0.00000561520*np.cos(5.05742214407 + 536.8045120954*t)
	X1 += 0.00000101075*np.cos(3.47363025932 + 7.1135470008*t)
	X1 += 0.00000072584*np.cos(0.36521293891 + 639.897286314*t)
	X1 += 0.00000087530*np.cos(1.66279295561 + 419.4846438752*t)
	X1 += 0.00000053691*np.cos(1.32771189808 + 433.7117378768*t)
	X1 += 0.00000057424*np.cos(4.25022395061 + 213.299095438*t)
	X1 += 0.00000044073*np.cos(3.59873993683 + 1589.0728952838*t)
	X1 += 0.00000031012*np.cos(4.88786083215 + 1052.2683831884*t)
	X1 += 0.00000032089*np.cos(0.97023379672 + 529.6909650946*t)
	X1 += 0.00000030164*np.cos(5.48452294664 + 1066.49547719*t)
	X1 += 0.00000032092*np.cos(2.84692417916 + 149.5631971346*t)
	X1 += 0.00000021371*np.cos(0.56918433581 + 316.3918696566*t)
	X1 += 0.00000018990*np.cos(2.06104675595 + 227.5261894396*t)
	X1 += 0.00000014015*np.cos(4.17777922613 + 110.2063212194*t)
	X1 += 0.00000015885*np.cos(5.78017661291 + 76.2660712756*t)
	X1 += 0.00000012374*np.cos(5.70562636316 + 515.463871093*t)
	X1 += 0.00000013243*np.cos(5.16075891864 + 36.6485629295*t)
	X1 += 0.00000011847*np.cos(3.05476901979 + 632.7837393132*t)
	X1 += 0.00000012487*np.cos(2.32002507803 + 39.6175083461*t)
	X1 += 0.00000010223*np.cos(2.19747174258 + 73.297125859*t)
	X1 += 0.00000009014*np.cos(2.86872754290 + 199.0720014364*t)
	X1 += 0.00000008667*np.cos(4.92419711400 + 543.9180590962*t)
	X1 += 0.00000007754*np.cos(3.01431732345 + 949.1756089698*t)
	X1 += 0.00000007535*np.cos(2.70484475866 + 103.0927742186*t)
	X1 += 0.00000005483*np.cos(6.01106223961 + 853.196381752*t)
	X1 += 0.00000005158*np.cos(1.94900517603 + 209.3669421749*t)
	X1 += 0.00000005079*np.cos(2.96229494906 + 217.2312487011*t)
	X1 += 0.00000004653*np.cos(1.72782369127 + 216.4804891757*t)
	X1 += 0.00000004541*np.cos(3.17727011849 + 210.1177017003*t)
	X1 += 0.00000004456*np.cos(0.76977956324 + 323.5054166574*t)
	X1 += 0.00000004233*np.cos(3.49063898076 + 63.7358983034*t)
	X1 += 0.00000004095*np.cos(0.51793431422 + 647.0108333148*t)
	X1 += 0.00000004989*np.cos(3.32377727482 + 14.2270940016*t)
	X1 += 0.00000004320*np.cos(4.28845188920 + 735.8765135318*t)
	X1 += 0.00000003445*np.cos(4.34972240938 + 85.8272988312*t)
	X1 += 0.00000003338*np.cos(2.34738225115 + 11.0457002639*t)
	X1 += 0.00000003244*np.cos(6.04240714038 + 526.5095713569*t)
	X1 += 0.00000003181*np.cos(4.57837074085 + 532.8723588323*t)
	X1 += 0.00000002903*np.cos(4.79566936964 + 525.7588118315*t)
	X1 += 0.00000002864*np.cos(5.82538312855 + 533.6231183577*t)
	X1 += 0.00000002876*np.cos(2.69265723530 + 117.3198682202*t)
	X1 += 0.00000002833*np.cos(2.05576755359 + 202.2533951741*t)
	X1 += 0.00000002514*np.cos(0.74093420826 + 95.9792272178*t)
	X1 += 0.00000002853*np.cos(3.94856804554 + 2118.7638603784*t)
	X1 += 0.00000002055*np.cos(5.42893438245 + 138.5174968707*t)
	X1 += 0.00000001996*np.cos(3.76028525032 + 742.9900605326*t)
	X1 += 0.00000001910*np.cos(1.96850101416 + 956.2891559706*t)
	X1 += 0.00000001768*np.cos(5.91092694669 + 1596.1864422846*t)
	X1 += 0.00000001668*np.cos(3.43481125656 + 70.8494453042*t)
	X1 += 0.00000001570*np.cos(4.37765395011 + 78.7137518304*t)
	X1 += 0.00000001491*np.cos(1.26055544534 + 440.8252848776*t)
	X1 += 0.00000001809*np.cos(5.00719339450 + 1581.959348283*t)
	X1 += 0.00000001561*np.cos(4.53702050944 + 1045.1548361876*t)
	X1 += 0.00000001447*np.cos(1.95238298727 + 74.7815985673*t)
	X1 += 0.00000001645*np.cos(3.97870726126 + 224.3447957019*t)
	X1 += 0.00000001161*np.cos(4.49256510074 + 625.6701923124*t)
	X1 += 0.00000001133*np.cos(0.06024843139 + 35.1640902212*t)
	X1 += 0.00000000999*np.cos(5.67443465200 + 1265.5674786264*t)
	X1 += 0.00000000882*np.cos(1.12105057835 + 41.1019810544*t)
	X1 += 0.00000000938*np.cos(4.56608679745 + 1169.5882514086*t)
	X1 += 0.00000000943*np.cos(1.78153635749 + 151.0476698429*t)
	X1 += 0.00000000965*np.cos(1.55576378944 + 412.3710968744*t)
	X1 += 0.00000000769*np.cos(3.16951506066 + 942.062061969*t)
	X1 += 0.00000000768*np.cos(4.99147918103 + 1155.361157407*t)
	X1 += 0.00000000711*np.cos(3.39057215594 + 71.8126531507*t)
	X1 += 0.00000000719*np.cos(4.52061983489 + 77.7505439839*t)
	X1 += 0.00000000572*np.cos(2.30412060804 + 309.2783226558*t)
	X1 += 0.00000000724*np.cos(3.25902076369 + 1162.4747044078*t)
	X1 += 0.00000000510*np.cos(3.90147691268 + 277.0349937414*t)
	X1 += 0.00000000486*np.cos(0.82245463791 + 422.6660376129*t)
	X1 += 0.00000000456*np.cos(2.75853729890 + 1692.1656695024*t)
	X1 += 0.00000000391*np.cos(5.30832534377 + 1073.6090241908*t)
	X1 += 0.00000000374*np.cos(1.92168872074 + 234.6397364404*t)
	X1 += 0.00000000384*np.cos(0.93539249733 + 330.6189636582*t)
	X1 += 0.00000000371*np.cos(5.54353838421 + 415.5524906121*t)
	X1 += 0.00000000353*np.cos(1.18721605495 + 846.0828347512*t)
	X1 += 0.00000000335*np.cos(6.05401158140 + 860.3099287528*t)
	X1 += 0.00000000337*np.cos(4.75525977824 + 71.6002048296*t)
	X1 += 0.00000000324*np.cos(2.28921417158 + 423.4167971383*t)
	X1 += 0.00000000324*np.cos(3.05393333292 + 77.962992305*t)
	X1 += 0.00000000384*np.cos(3.06685995823 + 1478.8665740644*t)
	X1 += 0.00000000316*np.cos(0.91375113764 + 429.7795846137*t)
	X1 += 0.00000000361*np.cos(2.21089537404 + 2.9689454166*t)
	X1 += 0.00000000305*np.cos(5.55791649320 + 145.6310438715*t)
	X1 += 0.00000000374*np.cos(4.41343415577 + 728.762966531*t)
	X1 += 0.00000000383*np.cos(6.13188528401 + 210.8514148832*t)
	X1 += 0.00000000380*np.cos(5.05058792236 + 215.7467759928*t)
	X1 += 0.00000000338*np.cos(5.87862918623 + 148.0787244263*t)
	X1 += 0.00000000255*np.cos(2.25536828287 + 437.6438911399*t)
	X1 += 0.00000000311*np.cos(5.13228886176 + 838.9692877504*t)
	X1 += 0.00000000237*np.cos(2.28726007142 + 3.9321532631*t)
	X1 += 0.00000000266*np.cos(5.06649873732 + 38.1330356378*t)
	X1 += 0.00000000234*np.cos(1.60395818860 + 223.5940361765*t)
	X1 += 0.00000000221*np.cos(5.85413979591 + 508.3503240922*t)
	X1 += 0.00000000234*np.cos(4.87225306441 + 1272.6810256272*t)
	X1 += 0.00000000200*np.cos(6.03453757404 + 1375.7737998458*t)
	X1 += 0.00000000178*np.cos(1.95406607532 + 6681.2248533996*t)
	X1 += 0.00000000199*np.cos(2.97222353917 + 430.5303441391*t)
	X1 += 0.00000000188*np.cos(1.83168099087 + 124.433415221*t)
	X1 += 0.00000000173*np.cos(0.50653444879 + 1368.660252845*t)
	X1 += 0.00000000166*np.cos(4.99522557947 + 1062.5633239269*t)
	X1 += 0.00000000181*np.cos(4.29985084119 + 2648.454825473*t)
	X1 += 0.00000000156*np.cos(2.86107001845 + 12566.1516999828*t)
	X1 += 0.00000000164*np.cos(2.91444613296 + 3.1813937377*t)
	X1 += 0.00000000174*np.cos(1.61176269489 + 65.2203710117*t)
	X1 += 0.00000000163*np.cos(0.77052245905 + 88.865680217*t)
	X1 += 0.00000000153*np.cos(0.79359507111 + 160.6088973985*t)
	X1 += 0.00000000154*np.cos(6.16274455061 + 519.3960243561*t)
	X1 += 0.00000000140*np.cos(5.84592048082 + 1258.4539316256*t)
	X1 += 0.00000000138*np.cos(5.22139410630 + 1055.4497769261*t)
	X1 += 0.00000000132*np.cos(0.46806671232 + 654.1243803156*t)
	X1 += 0.00000000134*np.cos(3.33556330332 + 203.0041546995*t)
	X1 += 0.00000000120*np.cos(0.17691589754 + 1063.3140834523*t)
	X1 += 0.00000000118*np.cos(4.77280443966 + 551.031606097*t)
	X1 += 0.00000000120*np.cos(4.45697558744 + 539.9859058331*t)
	X1 += 0.00000000140*np.cos(5.86589845886 + 1056.2005364515*t)
	X1 += 0.00000000111*np.cos(5.69390808885 + 222.8603229936*t)
	X1 += 0.00000000111*np.cos(0.03988488946 + 2125.8774073792*t)
	X1 += 0.00000000133*np.cos(4.62837772547 + 22.0914005278*t)
	X1 += 0.00000000144*np.cos(1.47900802038 + 299.1263942692*t)
	X1 += 0.00000000134*np.cos(3.16966777445 + 21.3406410024*t)
	X1 += 0.00000000139*np.cos(2.94662252756 + 1485.9801210652*t)
	X1 += 0.00000000097*np.cos(5.41467539027 + 18.1592472647*t)
	X1 += 0.00000000096*np.cos(3.08170402360 + 191.9584544356*t)
	X1 += 0.00000000120*np.cos(4.77545420807 + 1574.8458012822*t)
	X1 += 0.00000000094*np.cos(3.31739742370 + 87.3117715395*t)
	X1 += 0.00000000101*np.cos(1.27086316315 + 33.6796175129*t)
	X1 += 0.00000000122*np.cos(0.24302263595 + 84.3428261229*t)
	X1 += 0.00000000096*np.cos(5.16231260208 + 2111.6503133776*t)
	X1 += 0.00000000097*np.cos(5.87982327909 + 217.964961884*t)
	X1 += 0.00000000087*np.cos(3.32576161903 + 231.4583427027*t)
	X1 += 0.00000000097*np.cos(1.64179644592 + 72.3339180125*t)
	X1 += 0.00000000089*np.cos(5.45720829907 + 628.8515860501*t)
	X1 += 0.00000000088*np.cos(5.00348782624 + 1699.2792165032*t)
	X1 += 0.00000000081*np.cos(1.26377078095 + 12.5301729722*t)
	X1 += 0.00000000086*np.cos(3.03921945697 + 127.4717966068*t)
	X1 += 0.00000000085*np.cos(5.30523639998 + 208.633228992*t)
	X1 += 0.00000000080*np.cos(4.03019573108 + 1471.7530270636*t)
	X1 += 0.00000000076*np.cos(5.75771357218 + 288.0806940053*t)
	X1 += 0.00000000096*np.cos(6.22255663987 + 203.7378678824*t)
	X1 += 0.00000000076*np.cos(0.40948960322 + 362.8622925726*t)
	X1 += 0.00000000072*np.cos(3.81559276845 + 302.164775655*t)
	X1 += 0.00000000075*np.cos(1.95113506965 + 525.0250986486*t)
	X1 += 0.00000000069*np.cos(4.21368560293 + 114.3991069134*t)
	X1 += 0.00000000068*np.cos(0.64071253014 + 153.4953503977*t)
	X1 += 0.00000000068*np.cos(0.16388050208 + 9.5612275556*t)
	X1 += 0.00000000068*np.cos(0.99582401938 + 73.8183907208*t)
	X1 += 0.00000000071*np.cos(2.38708525663 + 534.3568315406*t)
	X1 += 0.00000000064*np.cos(0.53528518109 + 75.7448064138*t)
	X1 += 0.00000000066*np.cos(6.17786477200 + 42.5864537627*t)
	X1 += 0.00000000061*np.cos(2.88776849923 + 207.8824694666*t)
	X1 += 0.00000000060*np.cos(2.02282855033 + 218.7157214094*t)
	X1 += 0.00000000070*np.cos(0.83559773197 + 52.6901980395*t)
	X1 += 0.00000000059*np.cos(1.24623136375 + 408.4389436113*t)
	X1 += 0.00000000067*np.cos(0.58534149028 + 152.5321425512*t)
	X1 += 0.00000000076*np.cos(0.10784891475 + 77.2292791221*t)
	X1 += 0.00000000064*np.cos(3.30054842989 + 79.2350166922*t)
	X1 += 0.00000000061*np.cos(0.45486168004 + 56.6223513026*t)
	X1 += 0.00000000055*np.cos(3.57207397234 + 340.7708920448*t)
	X1 += 0.00000000055*np.cos(3.08168513239 + 200.7689224658*t)
	X1 += 0.00000000076*np.cos(2.25541605095 + 146.594251718*t)
	X1 += 0.00000000060*np.cos(5.32793915897 + 831.8557407496*t)
	X1 += 0.00000000054*np.cos(2.83216128661 + 1.4844727083*t)
	X1 += 0.00000000066*np.cos(5.83578469159 + 618.5566453116*t)
	X1 += 0.00000000058*np.cos(0.97037460116 + 4.4534181249*t)
	X1 += 0.00000000051*np.cos(3.56752380688 + 225.8292684102*t)
	X1 += 0.00000000058*np.cos(3.10263152972 + 2221.856634597*t)
	X1 += 0.00000000051*np.cos(4.54732927101 + 62.2514255951*t)
	X1 += 0.00000000064*np.cos(5.43530311047 + 1685.0521225016*t)
	X1 += 0.00000000050*np.cos(4.84629478021 + 195.1398481733*t)
	X1 += 0.00000000049*np.cos(2.64059175393 + 2008.557539159*t)
	X1 += 0.00000000052*np.cos(4.61821041475 + 70.3281804424*t)
	X1 += 0.00000000049*np.cos(4.31351627712 + 350.3321196004*t)
	X1 += 0.00000000051*np.cos(1.79926614465 + 210.3783341312*t)
	X1 += 0.00000000051*np.cos(3.07938265367 + 216.2198567448*t)
	X1 += 0.00000000049*np.cos(5.92307582908 + 963.4027029714*t)
	X1 += 0.00000000053*np.cos(1.27341801656 + 142.4496501338*t)
	X1 += 0.00000000045*np.cos(4.80760215190 + 37.611770776*t)
	X1 += 0.00000000050*np.cos(4.51633294079 + 1038.0412891868*t)
	X1 += 0.00000000044*np.cos(5.63991949724 + 524.2743391232*t)
	X1 += 0.00000000044*np.cos(2.67440279390 + 38.6543004996*t)
	X1 += 0.00000000044*np.cos(4.98395147244 + 535.107591066*t)
	X1 += 0.00000000042*np.cos(4.06880389963 + 20426.571092422*t)
	X1 += 0.00000000058*np.cos(5.77065508757 + 1795.258443721*t)
	X1 += 0.00000000043*np.cos(4.16006907854 + 74.6697239827*t)
	X1 += 0.00000000043*np.cos(3.66062507509 + 74.8934731519*t)
	X1 += 0.00000000049*np.cos(5.77857770467 + 207.6700211455*t)
	X1 += 0.00000000049*np.cos(1.81278199589 + 131.4039498699*t)
	X1 += 0.00000000047*np.cos(2.28831256912 + 109.9456887885*t)
	X1 += 0.00000000039*np.cos(1.67338261788 + 1382.8873468466*t)
	X1 += 0.00000000041*np.cos(2.93602685311 + 10.2949407385*t)
	X1 += 0.00000000038*np.cos(4.40087475081 + 703.6331846174*t)
	X1 += 0.00000000046*np.cos(5.36914408518 + 218.9281697305*t)
	X1 += 0.00000000037*np.cos(4.39032344034 + 511.5317178299*t)
	X1 += 0.00000000035*np.cos(5.85809750059 + 565.1156877467*t)
	X1 += 0.00000000035*np.cos(6.22608295766 + 547.8502123593*t)
	X1 += 0.00000000038*np.cos(3.93290315553 + 490.3340891794*t)
	X1 += 0.00000000034*np.cos(5.54907603693 + 750.1036075334*t)
	X1 += 0.00000000037*np.cos(6.26293750649 + 635.9651330509*t)
	X1 += 0.00000000038*np.cos(5.99103573925 + 483.2205421786*t)
	X1 += 0.00000000035*np.cos(4.68155089578 + 526.7702037878*t)
	X1 += 0.00000000035*np.cos(5.94254789616 + 532.6117264014*t)
	X1 += 0.00000000031*np.cos(1.18565768932 + 447.9388318784*t)
	X1 += 0.00000000030*np.cos(0.44298905817 + 209.106309744*t)
	X1 += 0.00000000030*np.cos(1.59264152747 + 92.940845832*t)
	X1 += 0.00000000030*np.cos(4.44526322933 + 217.491881132*t)
	X1 += 0.00000000035*np.cos(1.72609608211 + 265.9892934775*t)
	X1 += 0.00000000028*np.cos(3.34466525843 + 80.1982245387*t)
	X1 += 0.00000000027*np.cos(4.35707854664 + 1279.794572628*t)
	X1 += 0.00000000031*np.cos(5.18940920282 + 424.1505103212*t)
	X1 += 0.00000000033*np.cos(0.34449594524 + 269.9214467406*t)
	X1 += 0.00000000027*np.cos(4.81466818286 + 1802.3719907218*t)
	X1 += 0.00000000025*np.cos(2.29154386905 + 10021.8372800994*t)
	X1 += 0.00000000027*np.cos(5.82028492837 + 1898.3512179396*t)
	X1 += 0.00000000023*np.cos(1.56475852877 + 650.9429865779*t)
	X1 += 0.00000000023*np.cos(4.85605613315 + 35.685355083*t)
	X1 += 0.00000000023*np.cos(4.85338065767 + 28.5718080822*t)
	X1 += 0.00000000022*np.cos(0.71803323367 + 337.732510659*t)
	X1 += 0.00000000023*np.cos(0.11555144192 + 643.0786800517*t)
	X1 += 0.00000000023*np.cos(4.51155345742 + 284.1485407422*t)
	X1 += 0.00000000023*np.cos(6.22294900930 + 191.2076949102*t)
	X1 += 0.00000000021*np.cos(0.34726135597 + 137.0330241624*t)
	X1 += 0.00000000021*np.cos(2.62420739411 + 40.5807161926*t)
	X1 += 0.00000000021*np.cos(3.37519693925 + 934.9485149682*t)
	X1 += 0.00000000021*np.cos(2.93989832001 + 525.4981794006*t)
	X1 += 0.00000000023*np.cos(4.92629143648 + 540.7366653585*t)
	X1 += 0.00000000023*np.cos(0.59531277141 + 1361.5467058442*t)
	X1 += 0.00000000025*np.cos(0.38304523465 + 96.8729990951*t)
	X1 += 0.00000000027*np.cos(6.21242304915 + 1905.4647649404*t)
	X1 += 0.00000000020*np.cos(5.54734924390 + 251.4321310758*t)
	X1 += 0.00000000024*np.cos(4.91328411886 + 219.4494345923*t)
	X1 += 0.00000000020*np.cos(3.55117744188 + 81.8951455681*t)
	X1 += 0.00000000021*np.cos(1.17914689008 + 344.7030453079*t)
	X1 += 0.00000000017*np.cos(1.99727427214 + 479.2883889155*t)
	X1 += 0.00000000018*np.cos(2.62651922515 + 47.6942631934*t)
	X1 += 0.00000000018*np.cos(2.61349776359 + 113.3877149571*t)
	X1 += 0.00000000017*np.cos(4.48959133859 + 235.3904959658*t)
	X1 += 0.00000000018*np.cos(0.65002779822 + 66.70484372*t)
	X1 += 0.00000000018*np.cos(0.82070318043 + 436.8931316145*t)
	X1 += 0.00000000016*np.cos(5.70285177091 + 1603.2999892854*t)
	X1 += 0.00000000017*np.cos(0.76245918828 + 909.8187330546*t)
	X1 += 0.00000000018*np.cos(0.68490378171 + 358.9301393095*t)
	X1 += 0.00000000017*np.cos(1.44060402818 + 533.8837507886*t)
	X1 += 0.00000000016*np.cos(5.33794185960 + 10213.285546211*t)
	X1 += 0.00000000019*np.cos(0.01647605955 + 207.1487562837*t)
	X1 += 0.00000000017*np.cos(1.09605096689 + 417.0369633204*t)
	X1 += 0.00000000016*np.cos(5.18072747317 + 1788.1448967202*t)
	X1 += 0.00000000017*np.cos(5.41405900055 + 497.4476361802*t)
	X1 += 0.00000000017*np.cos(0.59320479310 + 2.4476805548*t)
	X1 += 0.00000000016*np.cos(5.49478140063 + 175.1660598002*t)
	X1 += 0.00000000017*np.cos(2.77441209647 + 52175.8062831484*t)
	X1 += 0.00000000016*np.cos(4.29457970004 + 67.6680515665*t)
	X1 += 0.00000000015*np.cos(5.15304621208 + 220.4608265486*t)
	X1 += 0.00000000015*np.cos(4.99636225149 + 518.6452648307*t)
	X1 += 0.00000000015*np.cos(0.95581113217 + 146.3818033969*t)
	X1 += 0.00000000014*np.cos(2.27264864715 + 416.3032501375*t)
	X1 += 0.00000000019*np.cos(3.55838458417 + 554.0699874828*t)
	X1 += 0.00000000014*np.cos(5.18725769632 + 1049.0869894507*t)
	X1 += 0.00000000014*np.cos(5.07734306466 + 351.8165923087*t)
	X1 += 0.00000000014*np.cos(4.66254689609 + 429.0458714308*t)
	X1 += 0.00000000015*np.cos(0.87904326630 + 4.665866446*t)
	X1 += 0.00000000015*np.cos(5.80214824265 + 181.0557665236*t)
	X1 += 0.00000000016*np.cos(3.48059820580 + 404.5067903482*t)
	X1 += 0.00000000012*np.cos(1.90118101257 + 636.7158925763*t)
	X1 += 0.00000000013*np.cos(0.94980339171 + 82.8583534146*t)
	X1 += 0.00000000013*np.cos(5.40390266847 + 245.5424243524*t)
	X1 += 0.00000000013*np.cos(5.40346920033 + 205.2223405907*t)
	X1 += 0.00000000013*np.cos(5.26586760806 + 501.3797894433*t)
	X1 += 0.00000000012*np.cos(5.96461527769 + 867.4234757536*t)
	X1 += 0.00000000013*np.cos(4.74446229064 + 14.977853527*t)
	X1 += 0.00000000012*np.cos(1.33415706168 + 99.9113804809*t)
	X1 += 0.00000000011*np.cos(1.32350368373 + 131.5469622218*t)
	X1 += 0.00000000011*np.cos(5.26972998156 + 2214.7430875962*t)
	X1 += 0.00000000013*np.cos(3.64005382686 + 145.1097790097*t)
	X1 += 0.00000000012*np.cos(2.37418300803 + 211.8146227297*t)
	X1 += 0.00000000011*np.cos(4.64269453516 + 3178.1457905676*t)
	X1 += 0.00000000014*np.cos(4.59700663399 + 721.6494195302*t)
	X1 += 0.00000000010*np.cos(5.89161262846 + 214.0498549634*t)
	X1 += 0.00000000012*np.cos(5.63886804458 + 198.321241911*t)
	X1 += 0.00000000010*np.cos(4.79225001159 + 2104.5367663768*t)
	X1 += 0.00000000010*np.cos(4.24154253223 + 121.2520214833*t)
	X1 += 0.00000000010*np.cos(3.07835250801 + 643.8294395771*t)
	X1 += 0.00000000011*np.cos(0.76353498081 + 59.8037450403*t)
	X1 += 0.00000000010*np.cos(2.52434543093 + 444.7574381407*t)
	X1 += 0.00000000010*np.cos(6.02081320033 + 289.5651667136*t)
	X1 += 0.00000000011*np.cos(6.11985601662 + 206.1373643274*t)
	X1 += 0.00000000011*np.cos(3.53222769228 + 108.4612160802*t)
	X1 += 0.00000000010*np.cos(2.48035088853 + 32.1951448046*t)
	X1 += 0.00000000010*np.cos(1.19722150187 + 405.2575498736*t)
	X1 += 0.00000000009*np.cos(1.11423953703 + 152.7445908723*t)
	X1 += 0.00000000009*np.cos(5.33634723608 + 212.5483359126*t)
	X1 += 0.00000000013*np.cos(3.43354905286 + 114.1384744825*t)
	X1 += 0.00000000009*np.cos(2.12559306586 + 177.8743727859*t)
	X1 += 0.00000000009*np.cos(1.49177357269 + 140.001969579*t)
	X1 += 0.00000000009*np.cos(1.26040337097 + 98.8999885246*t)
	X1 += 0.00000000009*np.cos(2.46965123782 + 112.9146342051*t)
	X1 += 0.00000000010*np.cos(1.61631506112 + 604.4725636619*t)
	X1 += 0.00000000009*np.cos(1.39179110846 + 33.9402499438*t)
	X1 += 0.00000000009*np.cos(4.92060353422 + 275.5505210331*t)
	X1 += 0.00000000009*np.cos(0.24943313990 + 319.5732633943*t)
	X1 += 0.00000000010*np.cos(5.40172694346 + 1592.2542890215*t)
	X1 += 0.00000000010*np.cos(3.63300622629 + 373.9079928365*t)
	X1 += 0.00000000008*np.cos(5.39656213021 + 1148.2476104062*t)
	X1 += 0.00000000009*np.cos(0.88869633066 + 69.1525242748*t)
	X1 += 0.00000000010*np.cos(3.67062813456 + 2015.6710861598*t)
	X1 += 0.00000000011*np.cos(5.20033100734 + 842.1506814881*t)
	X1 += 0.00000000008*np.cos(2.92168007680 + 134.5853436076*t)
	X1 += 0.00000000009*np.cos(1.92127276195 + 561.934294009*t)
	X1 += 0.00000000008*np.cos(5.71207072786 + 1585.1407420207*t)
	X1 += 0.00000000008*np.cos(6.02739823377 + 5.9378908332*t)
	X1 += 0.00000000010*np.cos(4.18673679862 + 436.1594184316*t)
	X1 += 0.00000000008*np.cos(2.51541014083 + 214.7835681463*t)
	X1 += 0.00000000008*np.cos(2.20996366081 + 159.1244246902*t)
	X1 += 0.00000000009*np.cos(0.07320142790 + 414.0680179038*t)
	X1 += 0.00000000008*np.cos(2.77771386082 + 248.7238180901*t)
	X1 += 0.00000000008*np.cos(6.18114959216 + 42.3258213318*t)
	X1 += 0.00000000010*np.cos(2.59673239232 + 297.6419215609*t)
	X1 += 0.00000000008*np.cos(5.54190257529 + 2001.4439921582*t)
	X1 += 0.00000000007*np.cos(5.62789688432 + 576.1613880106*t)
	X1 += 0.00000000009*np.cos(0.97094953096 + 621.7380390493*t)
	X1 += 0.00000000007*np.cos(4.63407107324 + 629.6023455755*t)
	X1 += 0.00000000008*np.cos(2.62449520780 + 355.7487455718*t)
	X1 += 0.00000000007*np.cos(0.88436036706 + 81.7521332162*t)
	X1 += 0.00000000008*np.cos(4.12633327906 + 31.019488637*t)
	X1 += 0.00000000007*np.cos(1.73606122812 + 320.3240229197*t)
	X1 += 0.00000000007*np.cos(3.72377229422 + 30.0562807905*t)
	X1 += 0.00000000007*np.cos(1.42009283525 + 427.5613987225*t)
	X1 += 0.00000000007*np.cos(0.50663219979 + 2655.5683724738*t)
	X1 += 0.00000000007*np.cos(4.46046826267 + 69.3649725959*t)
	X1 += 0.00000000007*np.cos(2.34948998718 + 327.4375699205*t)
	X1 += 0.00000000008*np.cos(6.01739816809 + 1585.8915015461*t)
	X1 += 0.00000000007*np.cos(0.49384776945 + 20.6069278195*t)
	X1 += 0.00000000007*np.cos(2.00283015490 + 528.9402055692*t)
	X1 += 0.00000000007*np.cos(2.33785549347 + 530.44172462*t)
	X1 += 0.00000000007*np.cos(5.38166348747 + 2228.9701815978*t)
	X1 += 0.00000000008*np.cos(1.11506407502 + 144.1465711632*t)
	X1 += 0.00000000008*np.cos(0.93716006393 + 458.8415197904*t)
	X1 += 0.00000000007*np.cos(6.10220034684 + 278.5194664497*t)
	X1 += 0.00000000008*np.cos(2.79730190848 + 454.9093665273*t)
	X1 += 0.00000000007*np.cos(2.42892547010 + 3340.6124266998*t)
	X1 += 0.00000000007*np.cos(1.89853865756 + 1048.3362299253*t)
	X1 += 0.00000000007*np.cos(4.41206005071 + 387.2413149608*t)
	X1 += 0.00000000007*np.cos(3.97484854685 + 425.6349830295*t)
	X1 += 0.00000000007*np.cos(1.42151002751 + 5.4166259714*t)
	X1 += 0.00000000007*np.cos(5.07915922145 + 431.264057322*t)
	X1 += 0.00000000007*np.cos(2.71768486617 + 106.2741679563*t)
	X1 += 0.00000000006*np.cos(4.29538257753 + 1158.5425511447*t)
	X1 += 0.00000000006*np.cos(6.11632456545 + 601.7642506762*t)
	X1 += 0.00000000008*np.cos(5.23426576880 + 228.276948965*t)
	X1 += 0.00000000007*np.cos(0.03631337685 + 558.0021407459*t)
	X1 += 0.00000000006*np.cos(5.40318267434 + 1159.2933106701*t)
	X1 += 0.00000000007*np.cos(5.97408505998 + 221.3758502853*t)
	X1 += 0.00000000007*np.cos(3.36399257591 + 953.1077622329*t)
	X1 += 0.00000000007*np.cos(3.53380092713 + 45.2465826386*t)
	X1 += 0.00000000006*np.cos(1.72178265563 + 241.7532834412*t)
	X1 += 0.00000000006*np.cos(1.09642732127 + 983.1158589136*t)
	X1 += 0.00000000006*np.cos(3.96501540302 + 1165.6560981455*t)
	X1 += 0.00000000006*np.cos(6.07126258740 + 186.2117600641*t)
	X1 += 0.00000000007*np.cos(4.39225179954 + 421.93232443*t)
	X1 += 0.00000000006*np.cos(1.88152710036 + 313.2104759189*t)
	X1 += 0.00000000006*np.cos(3.62770311218 + 23.5758732361*t)
	X1 += 0.00000000007*np.cos(1.33257665947 + 230.7075831773*t)
	X1 += 0.00000000006*np.cos(5.21774017886 + 1166.4068576709*t)
	X1 += 0.00000000006*np.cos(2.09071241554 + 80.7194894005*t)
	X1 += 0.00000000006*np.cos(2.93345991787 + 2538.2485042536*t)
	X1 += 0.00000000006*np.cos(3.92931387452 + 107.0249274817*t)
	X1 += 0.00000000006*np.cos(3.52705318347 + 81.0013736908*t)
	X1 += 0.00000000006*np.cos(4.30034572218 + 426.6463749858*t)
	X1 += 0.00000000006*np.cos(5.86623781176 + 1891.2376709388*t)
	X1 += 0.00000000007*np.cos(0.54906813870 + 99.1606209555*t)
	X1 += 0.00000000005*np.cos(5.12395207497 + 494.2662424425*t)
	X1 += 0.00000000006*np.cos(3.21075948460 + 1041.2226829245*t)
	X1 += 0.00000000006*np.cos(1.75222718681 + 421.1815649046*t)
	X1 += 0.00000000006*np.cos(4.58966840558 + 188.9200730498*t)
	X1 += 0.00000000006*np.cos(4.31078821920 + 68.5618234438*t)
	X1 += 0.00000000006*np.cos(3.12401775256 + 35.212274331*t)
	X1 += 0.00000000005*np.cos(4.95793416059 + 44.070926471*t)
	X1 += 0.00000000006*np.cos(0.78943135240 + 89.7594520943*t)
	X1 += 0.00000000005*np.cos(0.05325753010 + 92.0470739547*t)
	X1 += 0.00000000005*np.cos(5.82406538706 + 78263.70942472259*t)
	X1 += 0.00000000005*np.cos(3.76241459004 + 46.2097904851*t)
	X1 += 0.00000000005*np.cos(6.03822128054 + 162.0933701068*t)
	X1 += 0.00000000005*np.cos(2.23177245413 + 205.4347889118*t)
	X1 += 0.00000000005*np.cos(0.49940419683 + 1593.0050485469*t)
	X1 += 0.00000000005*np.cos(1.32106578434 + 505.3119427064*t)
	X1 += 0.00000000005*np.cos(1.27162244422 + 128.9562693151*t)
	X1 += 0.00000000005*np.cos(6.02567132030 + 50.4025761791*t)
	X1 += 0.00000000005*np.cos(3.76864982971 + 916.9322800554*t)
	X1 += 0.00000000005*np.cos(5.98811310538 + 1251.3403846248*t)
	X1 += 0.00000000005*np.cos(5.08443772017 + 1080.7225711916*t)
	X1 += 0.00000000005*np.cos(4.35480199188 + 41.0537969446*t)
	X1 += 0.00000000005*np.cos(0.27144803161 + 14.0146456805*t)
	X1 += 0.00000000005*np.cos(2.21719938925 + 29.2049475286*t)
	X1 += 0.00000000005*np.cos(0.64236900268 + 312.4597163935*t)
	X1 += 0.00000000005*np.cos(5.65873857560 + 154.0166152595*t)
	X1 += 0.00000000005*np.cos(2.08957091919 + 88.7962442478*t)
	X1 += 0.00000000005*np.cos(1.16644086335 + 439.1283638482*t)
	X1 += 0.00000000006*np.cos(0.18425926990 + 512.2824773553*t)
	X1 += 0.00000000005*np.cos(5.06579671013 + 778.4147831847*t)
	X1 += 0.00000000005*np.cos(4.03598888492 + 347.8844390456*t)
	X1 += 0.00000000006*np.cos(5.19947528170 + 696.5196376166*t)
	X1 += 0.00000000005*np.cos(4.83208640963 + 1069.6768709277*t)
	X1 += 0.00000000005*np.cos(0.32110795784 + 237.6781178262*t)
	X1 += 0.00000000004*np.cos(5.60132825306 + 54.1746707478*t)
	X1 += 0.00000000005*np.cos(5.02121943499 + 498.6714764576*t)
	X1 += 0.00000000004*np.cos(0.18629796423 + 611.4430983108*t)
	X1 += 0.00000000004*np.cos(6.10975670784 + 672.1406152284*t)
	X1 += 0.00000000006*np.cos(1.10181232960 + 426.5500067662*t)
	X1 += 0.00000000006*np.cos(3.44356759950 + 2751.5475996916*t)
	X1 += 0.00000000004*np.cos(4.65745435403 + 710.7467316182*t)
	X1 += 0.00000000004*np.cos(5.82103664757 + 68.8437077341*t)
	X1 += 0.00000000004*np.cos(0.38923128315 + 33.1371007917*t)
	X1 += 0.00000000005*np.cos(4.10075455899 + 295.0512286542*t)
	X1 += 0.00000000004*np.cos(6.13793028784 + 849.2642284889*t)
	X1 += 0.00000000005*np.cos(3.04296923489 + 166.828672522*t)
	X1 += 0.00000000004*np.cos(4.09060007695 + 679.2541622292*t)
	X1 += 0.00000000005*np.cos(0.43029706877 + 300.6108669775*t)
	X1 += 0.00000000005*np.cos(5.60265196005 + 560.7104537316*t)
	X1 += 0.00000000004*np.cos(5.71270004089 + 2317.8358618148*t)
	X1 += 0.00000000004*np.cos(0.03133309464 + 1070.4276304531*t)
	X1 += 0.00000000004*np.cos(2.20603900112 + 152.0108776894*t)
	X1 += 0.00000000005*np.cos(3.37195934008 + 600.5404103988*t)
	X1 += 0.00000000004*np.cos(2.81783859224 + 18849.2275499742*t)
	X1 += 0.00000000004*np.cos(5.70730765847 + 757.2171545342*t)
	X1 += 0.00000000004*np.cos(4.89642578031 + 746.9222137957*t)
	X1 += 0.00000000004*np.cos(2.01320988474 + 952.3570027075*t)
	X1 += 0.00000000004*np.cos(2.35947871248 + 32.2433289144*t)
	X1 += 0.00000000004*np.cos(1.76727070040 + 196.0336200506*t)
	X1 += 0.00000000005*np.cos(3.76952781970 + 945.9942152321*t)
	X1 += 0.00000000004*np.cos(4.20593460992 + 312.1990839626*t)
	X1 += 0.00000000004*np.cos(4.73926385495 + 970.5162499722*t)
	X1 += 0.00000000004*np.cos(2.79716874555 + 1064.0477966352*t)
	X1 += 0.00000000004*np.cos(2.82246202066 + 221.1634019642*t)
	X1 += 0.00000000004*np.cos(2.12545244622 + 182.279606801*t)
	X1 += 0.00000000004*np.cos(1.43142376081 + 381.3516082374*t)
	X1 += 0.00000000005*np.cos(4.45815571512 + 432.2272651685*t)
	X1 += 0.00000000004*np.cos(2.85017144667 + 111.4301614968*t)
	X1 += 0.00000000004*np.cos(2.18178993259 + 429.5189521828*t)
	X1 += 0.00000000004*np.cos(2.02829629760 + 2324.9494088156*t)
	X1 += 0.00000000003*np.cos(0.36593642535 + 661.2379273164*t)
	X1 += 0.00000000003*np.cos(2.50436473789 + 227.3137411185*t)
	X1 += 0.00000000004*np.cos(4.77848701199 + 39.3568759152*t)
	X1 += 0.00000000003*np.cos(2.18678252584 + 554.8207470082*t)
	X1 += 0.00000000003*np.cos(0.76702918347 + 305.3461693927*t)
	X1 += 0.00000000004*np.cos(0.93894074157 + 395.578702239*t)
	X1 += 0.00000000003*np.cos(3.68196370494 + 430.79097657*t)
	X1 += 0.00000000004*np.cos(4.72067463717 + 739.8086667949*t)
	X1 += 0.00000000003*np.cos(3.39918692904 + 148.5999892881*t)
	X1 += 0.00000000003*np.cos(2.98492148205 + 150.5264049811*t)
	X1 += 0.00000000004*np.cos(4.61834987541 + 1567.7322542814*t)
	X1 += 0.00000000003*np.cos(4.79247542483 + 776.9303104764*t)
	X1 += 0.00000000004*np.cos(2.95758390869 + 28.4541880032*t)
	X1 += 0.00000000004*np.cos(5.90076378151 + 333.657345044*t)
	X1 += 0.00000000003*np.cos(6.03930326769 + 501.2367770914*t)
	X1 += 0.00000000003*np.cos(2.21681410383 + 95.3885263868*t)
	X1 += 0.00000000003*np.cos(2.96697672144 + 230.5645708254*t)
	X1 += 0.00000000003*np.cos(1.63786396323 + 129.9194771616*t)
	X1 += 0.00000000004*np.cos(4.08612721092 + 547.0994528339*t)
	X1 += 0.00000000003*np.cos(3.06913547506 + 498.1983957056*t)
	X1 += 0.00000000004*np.cos(2.82714729830 + 196.6243208816*t)
	X1 += 0.00000000003*np.cos(2.17576074669 + 1912.5783119412*t)
	X1 += 0.00000000003*np.cos(5.41020261567 + 824.7421937488*t)
	X1 += 0.00000000003*np.cos(2.45469871287 + 426.0769260142*t)
	X1 += 0.00000000003*np.cos(0.84101342334 + 116.4260963429*t)
	X1 += 0.00000000003*np.cos(1.03874549825 + 343.2185725996*t)
	X1 += 0.00000000003*np.cos(1.27584004466 + 6.2197751235*t)
	X1 += 0.00000000003*np.cos(1.67770860005 + 432.0148168474*t)
	X1 += 0.00000000003*np.cos(4.22153393656 + 192.6921676185*t)
	X1 += 0.00000000003*np.cos(4.98713677428 + 5849.3641121146*t)
	X1 += 0.00000000003*np.cos(5.22474916763 + 2641.3412784722*t)
	X1 += 0.00000000004*np.cos(5.07760201807 + 120.358249606*t)
	X1 += 0.00000000003*np.cos(4.31083751682 + 199.2844497575*t)
	X1 += 0.00000000003*np.cos(4.50515541147 + 206.706813299*t)
	X1 += 0.00000000003*np.cos(5.03611538738 + 2531.1349572528*t)
	X1 += 0.00000000003*np.cos(0.32735782546 + 1677.9385755008*t)
	X1 += 0.00000000003*np.cos(3.35928289924 + 617.8058857862*t)
	X1 += 0.00000000003*np.cos(5.98284253672 + 1176.7017984094*t)
	X1 += 0.00000000003*np.cos(5.93604764982 + 199.9657733137*t)
	X1 += 0.00000000003*np.cos(0.15864298137 + 181.806526049*t)
	X1 += 0.00000000003*np.cos(3.83753118245 + 767.3690829208*t)
	X1 += 0.00000000003*np.cos(3.13870341668 + 238.5718897035*t)
	X1 += 0.00000000003*np.cos(0.88857544064 + 280.9671470045*t)
	X1 += 0.00000000003*np.cos(1.76672622395 + 184.9879197867*t)
	X1 += 0.00000000003*np.cos(0.13059670468 + 9779.5738083342*t)
	X1 += 0.00000000003*np.cos(5.59700163318 + 188.1693135244*t)
	X1 += 0.00000000003*np.cos(4.39376494016 + 5863.5912061162*t)
	X1 += 0.00000000003*np.cos(2.94626386944 + 427.1194557378*t)
	X1 += 0.00000000003*np.cos(1.15993783311 + 214.5711198252*t)
	X1 += 0.00000000003*np.cos(3.72968833348 + 212.0270710508*t)
	X1 += 0.00000000003*np.cos(5.82526425441 + 183.2428146475*t)
	X1 += 0.00000000003*np.cos(5.66974308007 + 597.3590166611*t)
	X1 += 0.00000000003*np.cos(2.11878502294 + 938.1299087059*t)
	X1 += 0.00000000003*np.cos(2.70578954491 + 70.1157321213*t)
	X1 += 0.00000000003*np.cos(2.71071593720 + 244.318584075*t)
	X1 += 0.00000000003*np.cos(5.17953229739 + 6283.0758499914*t)
	X1 += 0.00000000003*np.cos(2.62947969432 + 13362.4497067992*t)
	X1 += 0.00000000003*np.cos(2.23503383883 + 1054.7160637432*t)
	X1 += 0.00000000003*np.cos(4.64843102467 + 960.2213092337*t)
	X1 += 0.00000000003*np.cos(4.22175495253 + 1151.4290041439*t)
	X1 += 0.00000000003*np.cos(4.09497069020 + 125.9873238985*t)
	X1 += 0.00000000003*np.cos(5.23676365506 + 226.6324175623*t)
	X1 += 0.00000000003*np.cos(0.39574105192 + 60.7669528868*t)
	X1 += 0.00000000003*np.cos(2.13098881113 + 504.561183181*t)
	X1 += 0.00000000003*np.cos(4.60406501990 + 563.6312150384*t)
	X1 += 0.00000000003*np.cos(5.82108922989 + 9793.8009023358*t)
	X1 += 0.00000000003*np.cos(1.73522050697 + 259.769518354*t)
	X1 += 0.00000000003*np.cos(6.08038714022 + 149.6750717192*t)
	X1 += 0.00000000003*np.cos(5.51903133796 + 537.5552716208*t)
	X1 += 0.00000000003*np.cos(5.10483961759 + 521.8266585684*t)
	X1 += 0.00000000003*np.cos(5.85692122235 + 1061.829610744*t)
	X1 += 0.00000000003*np.cos(2.83018527589 + 45.5766510387*t)
	X1 += 0.00000000002*np.cos(5.66029360253 + 238.4288773516*t)
	X1 += 0.00000000003*np.cos(4.63213846260 + 156.6767441354*t)
	X1 += 0.00000000002*np.cos(3.20563938367 + 1098.7388061044*t)
	X1 += 0.00000000003*np.cos(4.37539611593 + 637.4496057592*t)
	X1 += 0.00000000002*np.cos(1.95949487891 + 79.4474650133*t)
	X1 += 0.00000000003*np.cos(3.78613377964 + 1056.9342496344*t)
	X1 += 0.00000000002*np.cos(3.68449438188 + 73.0846775379*t)
	X1 += 0.00000000003*np.cos(5.88221114322 + 173.9422195228*t)
	X1 += 0.00000000003*np.cos(0.12090995758 + 556.5176680376*t)
	X1 += 0.00000000002*np.cos(5.87195838570 + 546.956440482*t)
	X1 += 0.00000000002*np.cos(1.80666306483 + 51.2057253312*t)
	X1 += 0.00000000002*np.cos(4.71389438607 + 244.791664827*t)
	X1 += 0.00000000003*np.cos(5.59387329695 + 214.1928673153*t)
	X1 += 0.00000000003*np.cos(5.57893817682 + 212.4053235607*t)
	X1 += 0.00000000003*np.cos(5.87145753665 + 206.233732547*t)
	X1 += 0.00000000002*np.cos(0.98099262453 + 76.4785195967*t)
	X1 += 0.00000000003*np.cos(5.05169913357 + 835.0371344873*t)
	X1 += 0.00000000002*np.cos(4.69270870737 + 41.6444977756*t)
	X1 += 0.00000000002*np.cos(3.07933280861 + 2.9207613068*t)
	X1 += 0.00000000002*np.cos(5.96102457870 + 115.8835796217*t)
	X1 += 0.00000000002*np.cos(5.84439942146 + 988.532484885*t)
	X1 += 0.00000000002*np.cos(4.22057328903 + 411.620337349*t)
	X1 += 0.00000000002*np.cos(3.07427023889 + 241.6102710893*t)
	X1 += 0.00000000002*np.cos(2.15953223516 + 220.364458329*t)
	X1 += 0.00000000002*np.cos(4.83002317955 + 44.7253177768*t)
	X1 += 0.00000000002*np.cos(4.34159551824 + 147.1155165798*t)
	X1 += 0.00000000002*np.cos(3.25147426067 + 157.6399519819*t)
	X1 += 0.00000000002*np.cos(6.22909594933 + 68.1893164283*t)
	X1 += 0.00000000002*np.cos(5.99986367103 + 572.2292347475*t)
	X1 += 0.00000000002*np.cos(1.76847441893 + 945.2434557067*t)
	X1 += 0.00000000002*np.cos(4.23776936289 + 258.8757464767*t)
	X1 += 0.00000000002*np.cos(4.07656311136 + 195.8906076987*t)
	X1 += 0.00000000002*np.cos(6.12219570995 + 1053.9653042178*t)
	X1 += 0.00000000002*np.cos(5.26519798505 + 2634.2277314714*t)
	X1 += 0.00000000003*np.cos(2.08325877934 + 273.1028404783*t)
	X1 += 0.00000000002*np.cos(5.45719874151 + 2207.6295405954*t)
	X1 += 0.00000000002*np.cos(2.69891682653 + 31.5407534988*t)
	X1 += 0.00000000002*np.cos(4.65322784248 + 464.7312265138*t)
	X1 += 0.00000000002*np.cos(0.68877998920 + 326.6868103951*t)
	X1 += 0.00000000002*np.cos(1.54342763175 + 1514.2912967165*t)
	X1 += 0.00000000002*np.cos(5.05038014737 + 2332.0629558164*t)
	X1 += 0.00000000002*np.cos(5.70604656370 + 2428.0421830342*t)
	X1 += 0.00000000002*np.cos(0.76679338551 + 864.2420820159*t)
	X1 += 0.00000000002*np.cos(0.08872445361 + 627.3671133418*t)
	X1 += 0.00000000002*np.cos(4.97696650064 + 7.8643065262*t)
	X1 += 0.00000000002*np.cos(1.41587506820 + 186.472392495*t)
	X1 += 0.00000000002*np.cos(4.90160886685 + 19.643719973*t)
	X1 += 0.00000000002*np.cos(2.84488836077 + 282.4516197128*t)
	X1 += 0.00000000002*np.cos(2.50699363400 + 523.4711899711*t)
	X1 += 0.00000000002*np.cos(6.03013579767 + 267.4737661858*t)
	X1 += 0.00000000002*np.cos(0.08102935559 + 1059.3337460794*t)
	X1 += 0.00000000002*np.cos(1.08130659238 + 75.5323580927*t)
	X1 += 0.00000000002*np.cos(4.54265391700 + 394.3548619616*t)
	X1 += 0.00000000002*np.cos(4.45634281901 + 1286.9081196288*t)
	X1 += 0.00000000002*np.cos(4.40052405784 + 357.4456666012*t)
	X1 += 0.00000000002*np.cos(1.94249998948 + 535.9107402181*t)
	X1 += 0.00000000002*np.cos(4.80707243004 + 732.6951197941*t)
	X1 += 0.00000000002*np.cos(4.72811584701 + 504.4181708291*t)
	X1 += 0.00000000002*np.cos(5.17849087896 + 1173.5204046717*t)
	X1 += 0.00000000002*np.cos(4.17690491777 + 58.1068240109*t)
	X1 += 0.00000000002*np.cos(4.79407538459 + 531.3354964973*t)
	X1 += 0.00000000002*np.cos(5.82979557096 + 528.0464336919*t)
	X1 += 0.00000000002*np.cos(4.77090803448 + 106.9767433719*t)
	X1 += 0.00000000002*np.cos(1.85666729270 + 5230.807466803*t)
	X1 += 0.00000000002*np.cos(0.46794009593 + 74.0308390419*t)
	X1 += 0.00000000002*np.cos(3.07644471579 + 638.4128136057*t)
	X1 += 0.00000000002*np.cos(1.70447924784 + 567.8240007324*t)
	X1 += 0.00000000002*np.cos(4.83147814855 + 462.0229135281*t)
	X1 += 0.00000000002*np.cos(5.34995803850 + 1064.7985561606*t)
	X1 += 0.00000000002*np.cos(4.71503750449 + 339.2864193365*t)
	X1 += 0.00000000002*np.cos(3.66972283721 + 6275.9623029906*t)
	X1 += 0.00000000002*np.cos(5.82774570357 + 570.7447620392*t)
	X1 += 0.00000000002*np.cos(0.36996486200 + 1077.5411774539*t)
	X1 += 0.00000000002*np.cos(2.99864654611 + 6290.1893969922*t)
	X1 += 0.00000000002*np.cos(5.89575539937 + 554.9637593601*t)
	X1 += 0.00000000002*np.cos(5.35433718528 + 24.3790223882*t)
	X1 += 0.00000000002*np.cos(0.17078922213 + 1062.302691496*t)
	X1 += 0.00000000002*np.cos(5.96069714244 + 193.655375465*t)
	X1 += 0.00000000002*np.cos(5.85026211666 + 154.979823106*t)
	X1 += 0.00000000002*np.cos(5.09382172588 + 10206.1719992102*t)
	X1 += 0.00000000002*np.cos(2.19933251375 + 5216.5803728014*t)
	X1 += 0.00000000002*np.cos(3.28048159506 + 9161.0171630226*t)
	X1 += 0.00000000002*np.cos(4.42548217115 + 10220.3990932118*t)
	X1 += 0.00000000002*np.cos(2.11847224279 + 569.0478410098*t)
	X1 += 0.00000000002*np.cos(1.66214826527 + 329.7251917809*t)
	X1 += 0.00000000002*np.cos(1.82469698841 + 211.0114735776*t)
	X1 += 0.00000000002*np.cos(3.06492917818 + 215.5867172984*t)
	X1 += 0.00000000002*np.cos(2.66030590923 + 491.5579294568*t)
	X1 += 0.00000000002*np.cos(4.70492555049 + 427.3489504014*t)
	X1 += 0.00000000002*np.cos(5.88430235005 + 1493.093668066*t)
	X1 += 0.00000000002*np.cos(1.10144811653 + 66.9172920411*t)
	X1 += 0.00000000002*np.cos(1.16175872406 + 4.192785694*t)
	X1 += 0.00000000002*np.cos(3.42991525266 + 1464.6394800628*t)
	X1 += 0.00000000002*np.cos(4.91436824618 + 143.6253063014*t)
	X1 += 0.00000000002*np.cos(3.10817166857 + 724.8308132679*t)
	X1 += 0.00000000002*np.cos(1.55531267246 + 81.3738807063*t)
	X1 += 0.00000000002*np.cos(3.62536164954 + 9146.790069021*t)
	X1 += 0.00000000002*np.cos(5.04065827219 + 187.6962327724*t)
	X1 += 0.00000000002*np.cos(2.67415847604 + 26087.9031415742*t)
	X1 += 0.00000000002*np.cos(5.60102698501 + 252.6559713532*t)
	X1 += 0.00000000002*np.cos(5.46898520908 + 420.9691165835*t)
	X1 += 0.00000000002*np.cos(6.09258827455 + 27.0873353739*t)
	X1 += 0.00000000002*np.cos(2.94502486646 + 1058.4187223427*t)
	X1 += 0.00000000002*np.cos(4.08187877349 + 432.7485300303*t)
	X1 += 0.00000000002*np.cos(3.61443075565 + 240.125798381*t)
	X1 += 0.00000000002*np.cos(5.65009707542 + 856.3777754897*t)
	X1 += 0.00000000002*np.cos(3.27884048323 + 1059.430114299*t)
	X1 += 0.00000000002*np.cos(1.64246455207 + 850.0149880143*t)
	X1 += 0.00000000002*np.cos(6.09523803123 + 254.9435932136*t)
	X1 += 0.00000000002*np.cos(0.71670817869 + 422.405405182*t)
	X1 += 0.00000000002*np.cos(0.32743953279 + 233.9060232575*t)
	X1 += 0.00000000001*np.cos(1.27357471225 + 692.5874843535*t)
	X1 += 0.00000000001*np.cos(5.71027351936 + 598.8434893694*t)
	X1 += 0.00000000002*np.cos(3.88249776155 + 16.6747745564*t)
	X1 += 0.00000000002*np.cos(1.32065865878 + 1354.4331588434*t)
	X1 += 0.00000000002*np.cos(1.65556728265 + 423.6774295692*t)
	X1 += 0.00000000001*np.cos(0.58252036777 + 149.45132255*t)
	X1 += 0.00000000001*np.cos(2.59126482066 + 104351.61256629678*t)
	X1 += 0.00000000001*np.cos(1.66511864767 + 135.5485514541*t)
	X1 += 0.00000000001*np.cos(4.35611825493 + 488.8496164711*t)
	X1 += 0.00000000002*np.cos(4.12919054520 + 472.1748419147*t)
	X1 += 0.00000000002*np.cos(3.35281572358 + 259.5088859231*t)
	X1 += 0.00000000001*np.cos(5.98950987548 + 380.12776796*t)
	X1 += 0.00000000002*np.cos(1.49224150054 + 46.470422916*t)
	X1 += 0.00000000001*np.cos(2.59892052650 + 842.9014410135*t)
	X1 += 0.00000000002*np.cos(1.10996459174 + 107.7586406646*t)
	X1 += 0.00000000001*np.cos(6.11020465279 + 1269.4996318895*t)
	X1 += 0.00000000001*np.cos(1.93408892654 + 334.5511169213*t)
	X1 += 0.00000000001*np.cos(4.86392383935 + 1056.4611688824*t)
	X1 += 0.00000000002*np.cos(0.41484490796 + 1060.3451380357*t)
	X1 += 0.00000000001*np.cos(6.21496538157 + 120.9913890524*t)
	X1 += 0.00000000001*np.cos(5.96508447084 + 295.1942410061*t)
	X1 += 0.00000000001*np.cos(2.35700148574 + 731.9443602687*t)
	X1 += 0.00000000002*np.cos(0.12944457006 + 528.2064923863*t)
	X1 += 0.00000000001*np.cos(0.42141916596 + 100.3844612329*t)
	X1 += 0.00000000002*np.cos(4.25008133081 + 531.1754378029*t)
	X1 += 0.00000000001*np.cos(4.09243466493 + 361.3778198643*t)
	X1 += 0.00000000001*np.cos(0.06888156594 + 650.1922270525*t)
	X1 += 0.00000000002*np.cos(1.29142425022 + 342.2553647531*t)
	X1 += 0.00000000002*np.cos(3.93441788953 + 73.88782669*t)
	X1 += 0.00000000002*np.cos(3.88657720006 + 75.6753704446*t)
	X1 += 0.00000000001*np.cos(4.00918268916 + 291.262087743*t)
	X1 += 0.00000000001*np.cos(4.86763403109 + 418.5214360287*t)
	X1 += 0.00000000002*np.cos(0.87941207602 + 22.633917249*t)
	X1 += 0.00000000001*np.cos(2.26131456382 + 1134.1635287565*t)
	X1 += 0.00000000001*np.cos(3.39973234519 + 1091.6252591036*t)
	X1 += 0.00000000002*np.cos(5.20576421985 + 229.9738699944*t)
	X1 += 0.00000000001*np.cos(3.80665140196 + 977.4867846211*t)
	X1 += 0.00000000002*np.cos(1.43699981154 + 135.336103133*t)
	X1 += 0.00000000001*np.cos(3.39040295796 + 72.4939767069*t)
	X1 += 0.00000000001*np.cos(4.43059213163 + 77.0692204277*t)
	X1 += 0.00000000001*np.cos(3.68911426193 + 28.3111756513*t)
	X1 += 0.00000000001*np.cos(0.06682128601 + 2435.155730035*t)
	X1 += 0.00000000002*np.cos(0.28068362619 + 82.6459050935*t)
	X1 += 0.00000000001*np.cos(3.90626140266 + 1474.9344208013*t)
	X1 += 0.00000000001*np.cos(4.81479347545 + 7.4223635415*t)
	X1 += 0.00000000001*np.cos(2.85093455480 + 264.5048207692*t)
	X1 += 0.00000000002*np.cos(3.86505635220 + 373.0142209592*t)
	X1 += 0.00000000001*np.cos(2.82185616810 + 2854.6403739102*t)
	X1 += 0.00000000001*np.cos(5.41176457713 + 460.5384408198*t)
	X1 += 0.00000000001*np.cos(5.87635748580 + 622.4887985747*t)
	X1 += 0.00000000001*np.cos(4.88694979217 + 448.6895914038*t)
	X1 += 0.00000000001*np.cos(0.08510205605 + 1439.5096981492*t)
	X1 += 0.00000000001*np.cos(4.30626286387 + 558.1451530978*t)
	X1 += 0.00000000001*np.cos(2.28666887283 + 201.5196819912*t)
	X1 += 0.00000000001*np.cos(5.74454994735 + 225.0785088848*t)
	X1 += 0.00000000001*np.cos(1.61439651017 + 43.2890291783*t)
	X1 += 0.00000000001*np.cos(1.13435582386 + 491.8185618877*t)
	X1 += 0.00000000001*np.cos(2.50722732103 + 428.0826635843*t)
	X1 += 0.00000000001*np.cos(2.13180457144 + 425.1137181677*t)
	X1 += 0.00000000001*np.cos(4.21829463481 + 171.6545976624*t)
	X1 += 0.00000000001*np.cos(1.57867099023 + 1446.62324515*t)
	X1 += 0.00000000001*np.cos(3.11157358189 + 486.4019359163*t)
	X1 += 0.00000000001*np.cos(5.26544792083 + 409.9234163196*t)
	X1 += 0.00000000001*np.cos(3.40882163500 + 991.7138786227*t)
	X1 += 0.00000000001*np.cos(0.65853973663 + 369.9758395734*t)
	X1 += 0.00000000001*np.cos(5.56246258005 + 364.3467652809*t)
	X1 += 0.00000000001*np.cos(6.18216495405 + 219.891377577*t)
	X1 += 0.00000000001*np.cos(5.50149603324 + 1364.7280995819*t)
	X1 += 0.00000000001*np.cos(5.93032445805 + 397.3932433474*t)
	X1 += 0.00000000001*np.cos(3.72028829304 + 1482.0479678021*t)
	X1 += 0.00000000001*np.cos(4.16100559677 + 292.0128472684*t)
	X1 += 0.00000000001*np.cos(1.74557134787 + 658.0565335787*t)
	X1 += 0.00000000001*np.cos(3.71108727404 + 30.7106720963*t)
	X1 += 0.00000000001*np.cos(1.36102591366 + 405.9912630565*t)
	X1 += 0.00000000001*np.cos(5.53493951631 + 98.3574718034*t)
	X1 += 0.00000000001*np.cos(3.20826811396 + 739.0579072695*t)
	X1 += 0.00000000001*np.cos(4.81360803734 + 418.0001711669*t)
	X1 += 0.00000000001*np.cos(2.95719853912 + 760.25553592*t)
	X1 += 0.00000000001*np.cos(4.34129397896 + 433.7599219866*t)
	X1 += 0.00000000001*np.cos(1.01250363366 + 189.7232222019*t)
	X1 += 0.00000000001*np.cos(2.05345607455 + 1063.5747158832*t)
	X1 += 0.00000000001*np.cos(4.15965092344 + 32.7164096664*t)
	X1 += 0.00000000001*np.cos(4.02615146793 + 205.6642835754*t)
	X1 += 0.00000000001*np.cos(4.97316771909 + 1482.7987273275*t)
	X1 += 0.00000000001*np.cos(1.34840946110 + 49.1787359017*t)
	X1 += 0.00000000001*np.cos(4.93954054254 + 211.6021744086*t)
	X1 += 0.00000000001*np.cos(3.09167827764 + 214.9960164674*t)
	X1 += 0.00000000001*np.cos(1.00415696487 + 42.5382696529*t)
	X1 += 0.00000000001*np.cos(6.10394251446 + 520.129737539*t)
	X1 += 0.00000000001*np.cos(1.37833578750 + 539.2521926502*t)
	X1 += 0.00000000001*np.cos(3.66003441536 + 91.4563731237*t)
	X1 += 0.00000000001*np.cos(5.12019954840 + 2950.619601128*t)
	X1 += 0.00000000001*np.cos(5.82940135224 + 25.2727942655*t)
	X1 += 0.00000000001*np.cos(4.74415523197 + 2847.5268269094*t)
	X1 += 0.00000000001*np.cos(6.08256832629 + 184.7272873558*t)
	X1 += 0.00000000001*np.cos(4.00485563595 + 220.9339073006*t)
	X1 += 0.00000000001*np.cos(1.28728933920 + 61.448276443*t)
	X1 += 0.00000000001*np.cos(0.12787415558 + 1994.3304451574*t)
	X1 += 0.00000000001*np.cos(2.04042873617 + 120.5012619579*t)
	X1 += 0.00000000001*np.cos(1.89844688907 + 214.9436268407*t)
	X1 += 0.00000000001*np.cos(2.99117927752 + 211.6545640353*t)
	X1 += 0.00000000001*np.cos(1.24686220221 + 255.8373650909*t)
	X1 += 0.00000000001*np.cos(0.09250165170 + 2758.6611466924*t)
	X1 += 0.00000000001*np.cos(3.44214231182 + 236.8749686741*t)
	X1 += 0.00000000001*np.cos(5.08329137058 + 536.8526962052*t)
	X1 += 0.00000000001*np.cos(2.39898693138 + 522.529233984*t)
	X1 += 0.00000000001*np.cos(4.97941561605 + 409.1897031367*t)
	X1 += 0.00000000001*np.cos(2.23852980219 + 1141.1340634054*t)
	X1 += 0.00000000001*np.cos(3.81472179136 + 4164.311989613*t)
	X1 += 0.00000000001*np.cos(0.84677509527 + 561.1835344836*t)
	X1 += 0.00000000001*np.cos(5.06722077891 + 203.2647871304*t)
	X1 += 0.00000000001*np.cos(2.96399804127 + 223.3334037456*t)
	X1 += 0.00000000001*np.cos(3.39417260546 + 201.9927627432*t)
	X1 += 0.00000000001*np.cos(4.63704621472 + 224.6054281328*t)
	X1 += 0.00000000001*np.cos(1.49964352937 + 19.1224551112*t)
	X1 += 0.00000000001*np.cos(1.75417378722 + 170.0100662597*t)
	X1 += 0.00000000001*np.cos(6.02217025923 + 1969.2006632438*t)
	X1 += 0.00000000001*np.cos(4.61481035864 + 1792.0770499833*t)
	X1 += 0.00000000001*np.cos(0.08910157331 + 586.3133163972*t)
	X1 += 0.00000000001*np.cos(0.87058362856 + 5223.6939198022*t)
	X1 += 0.00000000001*np.cos(5.46509070565 + 1578.7779545453*t)
	X1 += 0.00000000001*np.cos(5.61041821670 + 441.576044403*t)
	X1 += 0.00000000001*np.cos(5.68888613550 + 43.2408450685*t)
	X1 += 0.00000000001*np.cos(5.37444796629 + 162.8965192589*t)
	X1 += 0.00000000001*np.cos(4.61104870401 + 614.6244920485*t)
	X1 += 0.00000000001*np.cos(3.15763537463 + 57.255490749*t)
	X1 += 0.00000000001*np.cos(5.24497685943 + 8094.5216858326*t)
	X1 += 0.00000000001*np.cos(2.07025389201 + 1432.3961511484*t)
	X1 += 0.00000000001*np.cos(2.56537562687 + 406.954470903*t)
	X1 += 0.00000000001*np.cos(1.88266860135 + 33.0252262071*t)
	X1 += 0.00000000001*np.cos(1.88548024295 + 536.7563279856*t)
	X1 += 0.00000000001*np.cos(5.59679805901 + 522.6256022036*t)
	X1 += 0.00000000001*np.cos(4.27908585730 + 25.6028626656*t)
	X1 += 0.00000000001*np.cos(3.32553438930 + 11.3063326948*t)
	X1 += 0.00000000001*np.cos(0.21845956153 + 2310.722314814*t)
	X1 += 0.00000000001*np.cos(0.56867940841 + 425.8474313506*t)
	X1 += 0.00000000001*np.cos(5.59956576048 + 17.2654753874*t)
	X1 += 0.00000000001*np.cos(1.13669105471 + 92.7978334801*t)
	X1 += 0.00000000001*np.cos(5.86399735915 + 112.6540017742*t)
	X1 += 0.00000000001*np.cos(0.08468681151 + 72.0732855816*t)
	X1 += 0.00000000001*np.cos(1.81702147996 + 55.1378785943*t)
	X1 += 0.00000000001*np.cos(6.27132094307 + 88.1149206916*t)
	X1 += 0.00000000001*np.cos(3.27101446720 + 128.3655684841*t)
	X1 += 0.00000000001*np.cos(1.94200993300 + 543.0242872189*t)
	X1 += 0.00000000001*np.cos(2.34797779674 + 39.405060025*t)
	X1 += 0.00000000001*np.cos(5.13420212319 + 36.8610112506*t)
	X1 += 0.00000000001*np.cos(4.75257565939 + 1475.6851803267*t)
	X1 += 0.00000000001*np.cos(4.79225958960 + 2420.9286360334*t)
	X1 += 0.00000000001*np.cos(5.21161368051 + 69.6737891366*t)
	X1 += 0.00000000001*np.cos(3.34091000176 + 43.5496616092*t)
	X1 += 0.00000000001*np.cos(5.84335194757 + 84.9335269539*t)
	X1 += 0.00000000001*np.cos(5.48259367770 + 388.4651552382*t)
	X1 += 0.00000000001*np.cos(2.61679859079 + 141.6988906084*t)
	X1 += 0.00000000001*np.cos(4.27805808099 + 473.068613792*t)
	X1 += 0.00000000001*np.cos(2.24894173705 + 220.5245170234*t)
	X1 += 0.00000000001*np.cos(2.17515370211 + 9153.9036160218*t)
	X1 += 0.00000000001*np.cos(0.40902941173 + 4856.0843660684*t)
	X1 += 0.00000000001*np.cos(5.90996673055 + 33.4671691918*t)
	X1 += 0.00000000001*np.cos(0.50119334220 + 5746.271337896*t)
	X1 += 0.00000000001*np.cos(5.28040223606 + 2744.4340526908*t)
	X1 += 0.00000000001*np.cos(4.67708488047 + 92.3077063856*t)
	X1 += 0.00000000001*np.cos(0.52946374167 + 344.8460576598*t)
	X1 += 0.00000000001*np.cos(0.68091101551 + 608.404716925*t)
	X1 += 0.00000000001*np.cos(5.75578383817 + 6.592282139*t)
	X1 += 0.00000000001*np.cos(5.37620468100 + 815.0633461142*t)
	X1 += 0.00000000001*np.cos(4.39589347500 + 465.9550667912*t)
	X1 += 0.00000000001*np.cos(3.39131834036 + 8617.0991039264*t)
	X1 += 0.00000000001*np.cos(2.37296526618 + 4649.8988176312*t)
	X1 += 0.00000000001*np.cos(5.41062938075 + 480.7728616238*t)
	X1 += 0.00000000001*np.cos(5.81462045538 + 5636.0650166766*t)
	X1 += 0.00000000001*np.cos(3.24506358284 + 638.9340784675*t)
	X1 += 0.00000000001*np.cos(5.42589937867 + 3810.9295298808*t)
	X1 += 0.00000000001*np.cos(5.89714556688 + 319.3126309634*t)
	X1 += 0.00000000001*np.cos(3.59493782407 + 3067.9394693482*t)
	X1 += 0.00000000001*np.cos(4.62675880255 + 77204.32749453338*t)
	X1 += 0.00000000001*np.cos(2.60938114781 + 79.889407998*t)
	X1 += 0.00000000001*np.cos(4.36806970079 + 55.6591434561*t)
	X1 += 0.00000000001*np.cos(0.41894522450 + 782.3469364478*t)
	X1 += 0.00000000001*np.cos(0.73855914140 + 67.3592350258*t)
	X1 += 0.00000000001*np.cos(0.95723993856 + 455.0523788792*t)
	X1 += 0.00000000001*np.cos(5.26292090915 + 521.6142102473*t)
	X1 += 0.00000000001*np.cos(2.21935739281 + 537.7677199419*t)
	X1 += 0.00000000001*np.cos(3.67538369473 + 8631.326197928*t)
	X1 += 0.00000000001*np.cos(0.75227612652 + 640.8604941605*t)
	X1 += 0.00000000001*np.cos(1.92156948316 + 9676.4810341156*t)
	X1 += 0.00000000001*np.cos(0.08916826567 + 151.260118164*t)
	X1 += 0.00000000001*np.cos(6.25410462651 + 35.4247226521*t)
	X1 += 0.00000000001*np.cos(1.92755185731 + 1059.903195051*t)
	return X1*t




def Sun_X2 (t): # 461 terms of order 2

	X2 = 0.
	X2 += 0.00000160293*np.cos(4.40406062613 + 206.1855484372*t)
	X2 += 0.00000155633*np.cos(0.48183983171 + 220.4126424388*t)
	X2 += 0.00000118222*np.cos(0.99338493688 + 522.5774180938*t)
	X2 += 0.00000115842*np.cos(3.35337160144 + 536.8045120954*t)
	X2 += 0.00000096063*np.cos(5.56707571020 + 213.299095438*t)
	X2 += 0.00000065107*np.cos(5.63089478188 + 426.598190876*t)
	X2 += 0.00000074211*np.cos(2.15619420586 + 529.6909650946*t)
	X2 += 0.00000039505*np.cos(1.98115233273 + 1059.3819301892*t)
	X2 += 0.00000044785
	X2 += 0.00000014232*np.cos(5.82837756444 + 433.7117378768*t)
	X2 += 0.00000013989*np.cos(1.76434060619 + 7.1135470008*t)
	X2 += 0.00000012711*np.cos(3.49149798770 + 419.4846438752*t)
	X2 += 0.00000009321*np.cos(4.71464865506 + 639.897286314*t)
	X2 += 0.00000007707*np.cos(0.35647823047 + 227.5261894396*t)
	X2 += 0.00000006797*np.cos(3.87383015136 + 1066.49547719*t)
	X2 += 0.00000005452*np.cos(0.48898137631 + 1052.2683831884*t)
	X2 += 0.00000005027*np.cos(1.12572622612 + 515.463871093*t)
	X2 += 0.00000003854*np.cos(2.44255859575 + 1589.0728952838*t)
	X2 += 0.00000003667*np.cos(4.56283602529 + 199.0720014364*t)
	X2 += 0.00000003523*np.cos(3.22103209546 + 543.9180590962*t)
	X2 += 0.00000001347*np.cos(2.19024470415 + 316.3918696566*t)
	X2 += 0.00000001405*np.cos(6.22622304401 + 216.4804891757*t)
	X2 += 0.00000001320*np.cos(4.96541286159 + 647.0108333148*t)
	X2 += 0.00000001365*np.cos(4.95810524231 + 210.1177017003*t)
	X2 += 0.00000001687*np.cos(1.62553064962 + 14.2270940016*t)
	X2 += 0.00000001093*np.cos(4.21067890946 + 103.0927742186*t)
	X2 += 0.00000000973*np.cos(4.02172041169 + 853.196381752*t)
	X2 += 0.00000000938*np.cos(4.40679265580 + 632.7837393132*t)
	X2 += 0.00000000848*np.cos(1.52469724284 + 526.5095713569*t)
	X2 += 0.00000000826*np.cos(2.81425975210 + 532.8723588323*t)
	X2 += 0.00000000758*np.cos(0.02371551403 + 209.3669421749*t)
	X2 += 0.00000000733*np.cos(4.88186040762 + 217.2312487011*t)
	X2 += 0.00000000688*np.cos(5.79109380413 + 440.8252848776*t)
	X2 += 0.00000000603*np.cos(5.14215709084 + 323.5054166574*t)
	X2 += 0.00000000624*np.cos(0.96146126905 + 117.3198682202*t)
	X2 += 0.00000000549*np.cos(4.81966003612 + 949.1756089698*t)
	X2 += 0.00000000702*np.cos(0.69460527884 + 74.7815985673*t)
	X2 += 0.00000000546*np.cos(0.01597529774 + 1045.1548361876*t)
	X2 += 0.00000000499*np.cos(2.95394998140 + 110.2063212194*t)
	X2 += 0.00000000510*np.cos(2.48615954177 + 95.9792272178*t)
	X2 += 0.00000000604*np.cos(6.00696167862 + 735.8765135318*t)
	X2 += 0.00000000490*np.cos(2.82889535700 + 525.7588118315*t)
	X2 += 0.00000000488*np.cos(1.51375734651 + 533.6231183577*t)
	X2 += 0.00000000438*np.cos(4.38613869498 + 1596.1864422846*t)
	X2 += 0.00000000519*np.cos(6.10806295653 + 149.5631971346*t)
	X2 += 0.00000000317*np.cos(2.85849486793 + 2118.7638603784*t)
	X2 += 0.00000000353*np.cos(5.67450059858 + 63.7358983034*t)
	X2 += 0.00000000267*np.cos(6.09793545646 + 625.6701923124*t)
	X2 += 0.00000000270*np.cos(0.56801609869 + 1581.959348283*t)
	X2 += 0.00000000335*np.cos(3.28599535784 + 412.3710968744*t)
	X2 += 0.00000000230*np.cos(1.62446688541 + 70.8494453042*t)
	X2 += 0.00000000226*np.cos(0.21648774887 + 234.6397364404*t)
	X2 += 0.00000000257*np.cos(0.55141837710 + 956.2891559706*t)
	X2 += 0.00000000218*np.cos(6.18732888250 + 78.7137518304*t)
	X2 += 0.00000000216*np.cos(0.69406612425 + 11.0457002639*t)
	X2 += 0.00000000283*np.cos(2.17198423111 + 85.8272988312*t)
	X2 += 0.00000000210*np.cos(4.87169565788 + 942.062061969*t)
	X2 += 0.00000000227*np.cos(5.26494518266 + 73.297125859*t)
	X2 += 0.00000000235*np.cos(1.88541486477 + 36.6485629295*t)
	X2 += 0.00000000224*np.cos(5.59487510601 + 39.6175083461*t)
	X2 += 0.00000000228*np.cos(4.22772621951 + 202.2533951741*t)
	X2 += 0.00000000187*np.cos(2.86279402460 + 1169.5882514086*t)
	X2 += 0.00000000167*np.cos(3.64468986986 + 1073.6090241908*t)
	X2 += 0.00000000195*np.cos(0.93545523133 + 224.3447957019*t)
	X2 += 0.00000000158*np.cos(0.41813276311 + 1155.361157407*t)
	X2 += 0.00000000141*np.cos(2.05881354566 + 742.9900605326*t)
	X2 += 0.00000000135*np.cos(0.93601004324 + 138.5174968707*t)
	X2 += 0.00000000149*np.cos(3.11048959872 + 76.2660712756*t)
	X2 += 0.00000000133*np.cos(1.27948900541 + 508.3503240922*t)
	X2 += 0.00000000145*np.cos(4.08945624026 + 309.2783226558*t)
	X2 += 0.00000000126*np.cos(5.33539657707 + 330.6189636582*t)
	X2 += 0.00000000126*np.cos(4.18511285279 + 860.3099287528*t)
	X2 += 0.00000000160*np.cos(3.76409728390 + 38.1330356378*t)
	X2 += 0.00000000115*np.cos(6.09545736763 + 223.5940361765*t)
	X2 += 0.00000000110*np.cos(0.21868987814 + 71.6002048296*t)
	X2 += 0.00000000115*np.cos(5.33896891891 + 429.7795846137*t)
	X2 += 0.00000000105*np.cos(1.31705960331 + 77.962992305*t)
	X2 += 0.00000000127*np.cos(6.12277131240 + 728.762966531*t)
	X2 += 0.00000000106*np.cos(1.49565452639 + 1162.4747044078*t)
	X2 += 0.00000000102*np.cos(5.20836098548 + 422.6660376129*t)
	X2 += 0.00000000084*np.cos(0.06183751259 + 124.433415221*t)
	X2 += 0.00000000074*np.cos(1.07138930276 + 1265.5674786264*t)
	X2 += 0.00000000076*np.cos(4.22098650571 + 423.4167971383*t)
	X2 += 0.00000000071*np.cos(3.05925118734 + 551.031606097*t)
	X2 += 0.00000000082*np.cos(1.68324374227 + 519.3960243561*t)
	X2 += 0.00000000068*np.cos(4.96510846230 + 654.1243803156*t)
	X2 += 0.00000000066*np.cos(2.46864705656 + 88.865680217*t)
	X2 += 0.00000000073*np.cos(1.49901280909 + 21.3406410024*t)
	X2 += 0.00000000058*np.cos(4.77256654994 + 191.9584544356*t)
	X2 += 0.00000000064*np.cos(0.59210224706 + 838.9692877504*t)
	X2 += 0.00000000064*np.cos(2.62531230776 + 539.9859058331*t)
	X2 += 0.00000000064*np.cos(5.15957430521 + 203.0041546995*t)
	X2 += 0.00000000045*np.cos(4.29961594202 + 846.0828347512*t)
	X2 += 0.00000000046*np.cos(3.88547191366 + 145.6310438715*t)
	X2 += 0.00000000047*np.cos(3.31818308830 + 1062.5633239269*t)
	X2 += 0.00000000038*np.cos(1.25489937051 + 1258.4539316256*t)
	X2 += 0.00000000035*np.cos(1.55855229745 + 1692.1656695024*t)
	X2 += 0.00000000036*np.cos(5.46623211848 + 302.164775655*t)
	X2 += 0.00000000034*np.cos(5.64744481308 + 277.0349937414*t)
	X2 += 0.00000000030*np.cos(4.86335561218 + 2125.8774073792*t)
	X2 += 0.00000000035*np.cos(1.25631519996 + 1056.2005364515*t)
	X2 += 0.00000000039*np.cos(0.20293002946 + 1574.8458012822*t)
	X2 += 0.00000000036*np.cos(0.12982829645 + 437.6438911399*t)
	X2 += 0.00000000031*np.cos(3.39518273216 + 1272.6810256272*t)
	X2 += 0.00000000027*np.cos(3.47340764254 + 1055.4497769261*t)
	X2 += 0.00000000029*np.cos(1.32325847141 + 618.5566453116*t)
	X2 += 0.00000000028*np.cos(6.24637219690 + 1038.0412891868*t)
	X2 += 0.00000000027*np.cos(0.82567085480 + 415.5524906121*t)
	X2 += 0.00000000028*np.cos(1.64332966541 + 1485.9801210652*t)
	X2 += 0.00000000026*np.cos(5.05893496491 + 430.5303441391*t)
	X2 += 0.00000000024*np.cos(3.54369543262 + 18.1592472647*t)
	X2 += 0.00000000024*np.cos(0.77717557683 + 831.8557407496*t)
	X2 += 0.00000000023*np.cos(1.45497436681 + 231.4583427027*t)
	X2 += 0.00000000025*np.cos(2.24207971146 + 1368.660252845*t)
	X2 += 0.00000000024*np.cos(3.24916661957 + 2648.454825473*t)
	X2 += 0.00000000021*np.cos(5.72791145125 + 447.9388318784*t)
	X2 += 0.00000000020*np.cos(0.71402000433 + 3.1813937377*t)
	X2 += 0.00000000022*np.cos(5.33490739950 + 151.0476698429*t)
	X2 += 0.00000000019*np.cos(1.74528256840 + 1063.3140834523*t)
	X2 += 0.00000000020*np.cos(3.40302634906 + 1699.2792165032*t)
	X2 += 0.00000000020*np.cos(2.53484218621 + 35.1640902212*t)
	X2 += 0.00000000018*np.cos(1.08092680576 + 10.2949407385*t)
	X2 += 0.00000000021*np.cos(0.04948675860 + 72.3339180125*t)
	X2 += 0.00000000018*np.cos(4.11934903377 + 3.9321532631*t)
	X2 += 0.00000000018*np.cos(5.63577174804 + 1471.7530270636*t)
	X2 += 0.00000000016*np.cos(2.13005908431 + 22.0914005278*t)
	X2 += 0.00000000016*np.cos(5.22446000797 + 1478.8665740644*t)
	X2 += 0.00000000017*np.cos(2.07219008042 + 77.7505439839*t)
	X2 += 0.00000000015*np.cos(4.85349684848 + 1375.7737998458*t)
	X2 += 0.00000000016*np.cos(4.95896524219 + 41.1019810544*t)
	X2 += 0.00000000015*np.cos(5.03114029381 + 160.6088973985*t)
	X2 += 0.00000000014*np.cos(0.47915039682 + 195.1398481733*t)
	X2 += 0.00000000016*np.cos(2.16860864742 + 56.6223513026*t)
	X2 += 0.00000000017*np.cos(1.59080059391 + 77.2292791221*t)
	X2 += 0.00000000014*np.cos(5.69583373076 + 71.8126531507*t)
	X2 += 0.00000000015*np.cos(3.19537134319 + 65.2203710117*t)
	X2 += 0.00000000012*np.cos(5.17033303670 + 337.732510659*t)
	X2 += 0.00000000013*np.cos(3.64691089977 + 131.4039498699*t)
	X2 += 0.00000000013*np.cos(3.14880532464 + 408.4389436113*t)
	X2 += 0.00000000012*np.cos(4.22650218163 + 963.4027029714*t)
	X2 += 0.00000000011*np.cos(0.02603069623 + 511.5317178299*t)
	X2 += 0.00000000010*np.cos(4.31465510142 + 547.8502123593*t)
	X2 += 0.00000000013*np.cos(0.73737685844 + 2111.6503133776*t)
	X2 += 0.00000000010*np.cos(4.67908297368 + 362.8622925726*t)
	X2 += 0.00000000010*np.cos(5.60218831936 + 127.4717966068*t)
	X2 += 0.00000000012*np.cos(0.78764611551 + 1685.0521225016*t)
	X2 += 0.00000000013*np.cos(4.91836873304 + 84.3428261229*t)
	X2 += 0.00000000010*np.cos(5.07263788261 + 934.9485149682*t)
	X2 += 0.00000000012*np.cos(2.66109784913 + 148.0787244263*t)
	X2 += 0.00000000009*np.cos(2.44042399381 + 153.4953503977*t)
	X2 += 0.00000000009*np.cos(0.14966079482 + 1382.8873468466*t)
	X2 += 0.00000000011*np.cos(3.37804748354 + 222.8603229936*t)
	X2 += 0.00000000008*np.cos(6.02198121081 + 92.940845832*t)
	X2 += 0.00000000009*np.cos(2.18518124277 + 269.9214467406*t)
	X2 += 0.00000000009*np.cos(3.55537703082 + 750.1036075334*t)
	X2 += 0.00000000010*np.cos(5.30797415249 + 436.8931316145*t)
	X2 += 0.00000000010*np.cos(1.54068644361 + 203.7378678824*t)
	X2 += 0.00000000010*np.cos(4.52809483758 + 643.0786800517*t)
	X2 += 0.00000000010*np.cos(4.26753045931 + 635.9651330509*t)
	X2 += 0.00000000008*np.cos(3.50970266630 + 52.6901980395*t)
	X2 += 0.00000000008*np.cos(5.86771297817 + 131.5469622218*t)
	X2 += 0.00000000007*np.cos(4.10108572333 + 1603.2999892854*t)
	X2 += 0.00000000007*np.cos(0.40212847913 + 6681.2248533996*t)
	X2 += 0.00000000009*np.cos(2.22913614898 + 1279.794572628*t)
	X2 += 0.00000000007*np.cos(1.45088892995 + 483.2205421786*t)
	X2 += 0.00000000009*np.cos(1.10868456658 + 87.3117715395*t)
	X2 += 0.00000000007*np.cos(1.25840584213 + 12566.1516999828*t)
	X2 += 0.00000000008*np.cos(6.28154480422 + 721.6494195302*t)
	X2 += 0.00000000007*np.cos(4.14213787767 + 867.4234757536*t)
	X2 += 0.00000000008*np.cos(2.28858892249 + 1361.5467058442*t)
	X2 += 0.00000000006*np.cos(5.77664354435 + 12.5301729722*t)
	X2 += 0.00000000006*np.cos(4.05797292086 + 288.0806940053*t)
	X2 += 0.00000000006*np.cos(3.20129483122 + 35.685355083*t)
	X2 += 0.00000000006*np.cos(2.00935271481 + 2221.856634597*t)
	X2 += 0.00000000007*np.cos(3.03626865288 + 142.4496501338*t)
	X2 += 0.00000000006*np.cos(0.92070128524 + 113.3877149571*t)
	X2 += 0.00000000006*np.cos(1.32611782718 + 1795.258443721*t)
	X2 += 0.00000000005*np.cos(4.28095258999 + 40.5807161926*t)
	X2 += 0.00000000007*np.cos(5.58296785201 + 2.9689454166*t)
	X2 += 0.00000000005*np.cos(4.24493371796 + 416.3032501375*t)
	X2 += 0.00000000005*np.cos(2.97162380262 + 405.2575498736*t)
	X2 += 0.00000000005*np.cos(3.61271131032 + 628.8515860501*t)
	X2 += 0.00000000005*np.cos(5.24876798311 + 299.1263942692*t)
	X2 += 0.00000000005*np.cos(0.74450524979 + 1049.0869894507*t)
	X2 += 0.00000000005*np.cos(2.93410844815 + 344.7030453079*t)
	X2 += 0.00000000004*np.cos(4.27653048938 + 265.9892934775*t)
	X2 += 0.00000000004*np.cos(0.02464271840 + 241.7532834412*t)
	X2 += 0.00000000004*np.cos(0.08635272370 + 225.8292684102*t)
	X2 += 0.00000000006*np.cos(5.23548690619 + 200.7689224658*t)
	X2 += 0.00000000004*np.cos(5.16588074385 + 80.1982245387*t)
	X2 += 0.00000000004*np.cos(2.56938347762 + 81.7521332162*t)
	X2 += 0.00000000004*np.cos(4.01088906308 + 96.8729990951*t)
	X2 += 0.00000000005*np.cos(2.75224221162 + 146.3818033969*t)
	X2 += 0.00000000004*np.cos(5.28177641555 + 358.9301393095*t)
	X2 += 0.00000000004*np.cos(5.88554712812 + 67.6680515665*t)
	X2 += 0.00000000004*np.cos(2.88896913186 + 284.1485407422*t)
	X2 += 0.00000000004*np.cos(3.14472523304 + 1802.3719907218*t)
	X2 += 0.00000000005*np.cos(5.86843462535 + 340.7708920448*t)
	X2 += 0.00000000004*np.cos(0.75750831147 + 1148.2476104062*t)
	X2 += 0.00000000004*np.cos(4.00150046482 + 181.0557665236*t)
	X2 += 0.00000000004*np.cos(2.44238421546 + 490.3340891794*t)
	X2 += 0.00000000004*np.cos(5.73327501105 + 650.9429865779*t)
	X2 += 0.00000000003*np.cos(4.84446847204 + 9.5612275556*t)
	X2 += 0.00000000004*np.cos(0.61986604146 + 444.7574381407*t)
	X2 += 0.00000000003*np.cos(3.20404843433 + 424.1505103212*t)
	X2 += 0.00000000003*np.cos(3.74930692682 + 561.934294009*t)
	X2 += 0.00000000005*np.cos(0.45142513016 + 62.2514255951*t)
	X2 += 0.00000000003*np.cos(1.84477177776 + 81.8951455681*t)
	X2 += 0.00000000003*np.cos(1.52504306431 + 501.2367770914*t)
	X2 += 0.00000000003*np.cos(5.55946330424 + 107.0249274817*t)
	X2 += 0.00000000004*np.cos(0.82841475160 + 1788.1448967202*t)
	X2 += 0.00000000003*np.cos(6.02151068856 + 350.3321196004*t)
	X2 += 0.00000000004*np.cos(2.43169796555 + 191.2076949102*t)
	X2 += 0.00000000003*np.cos(1.23636904194 + 10213.285546211*t)
	X2 += 0.00000000003*np.cos(1.92929191460 + 2.4476805548*t)
	X2 += 0.00000000004*np.cos(3.26891108104 + 99.9113804809*t)
	X2 += 0.00000000003*np.cos(0.87507671453 + 245.5424243524*t)
	X2 += 0.00000000003*np.cos(3.50991384903 + 33.6796175129*t)
	X2 += 0.00000000003*np.cos(0.41265687641 + 14.977853527*t)
	X2 += 0.00000000003*np.cos(2.54235804923 + 703.6331846174*t)
	X2 += 0.00000000003*np.cos(5.70821751092 + 152.7445908723*t)
	X2 += 0.00000000003*np.cos(4.19660457850 + 636.7158925763*t)
	X2 += 0.00000000003*np.cos(0.30901128223 + 2104.5367663768*t)
	X2 += 0.00000000003*np.cos(5.78301640092 + 295.0512286542*t)
	X2 += 0.00000000003*np.cos(1.95356715655 + 611.4430983108*t)
	X2 += 0.00000000003*np.cos(3.85793781437 + 351.8165923087*t)
	X2 += 0.00000000003*np.cos(3.04748693631 + 1069.6768709277*t)
	X2 += 0.00000000003*np.cos(2.45534643692 + 2015.6710861598*t)
	X2 += 0.00000000002*np.cos(1.11040820961 + 2008.557539159*t)
	X2 += 0.00000000003*np.cos(2.08626177083 + 235.3904959658*t)
	X2 += 0.00000000003*np.cos(3.31128356539 + 1080.7225711916*t)
	X2 += 0.00000000002*np.cos(4.89027491282 + 661.2379273164*t)
	X2 += 0.00000000002*np.cos(0.08750953819 + 629.6023455755*t)
	X2 += 0.00000000003*np.cos(3.76716252474 + 1592.2542890215*t)
	X2 += 0.00000000002*np.cos(1.36199631852 + 1251.3403846248*t)
	X2 += 0.00000000002*np.cos(4.46447256795 + 99.1606209555*t)
	X2 += 0.00000000003*np.cos(1.61169744064 + 1898.3512179396*t)
	X2 += 0.00000000002*np.cos(4.04823185356 + 565.1156877467*t)
	X2 += 0.00000000002*np.cos(0.39766202841 + 5849.3641121146*t)
	X2 += 0.00000000002*np.cos(1.00867539270 + 79.2350166922*t)
	X2 += 0.00000000002*np.cos(2.75544762010 + 5863.5912061162*t)
	X2 += 0.00000000002*np.cos(5.92578945602 + 404.5067903482*t)
	X2 += 0.00000000002*np.cos(1.82124178733 + 9779.5738083342*t)
	X2 += 0.00000000002*np.cos(4.88213175725 + 319.5732633943*t)
	X2 += 0.00000000002*np.cos(4.17903188614 + 9793.8009023358*t)
	X2 += 0.00000000002*np.cos(5.32635912320 + 2655.5683724738*t)
	X2 += 0.00000000002*np.cos(4.04031673296 + 42.5864537627*t)
	X2 += 0.00000000002*np.cos(0.80305623259 + 824.7421937488*t)
	X2 += 0.00000000002*np.cos(2.67706562881 + 121.2520214833*t)
	X2 += 0.00000000002*np.cos(0.79113384290 + 10021.8372800994*t)
	X2 += 0.00000000002*np.cos(0.52578577848 + 70.3281804424*t)
	X2 += 0.00000000002*np.cos(4.92704633158 + 1905.4647649404*t)
	X2 += 0.00000000002*np.cos(3.82376478290 + 208.633228992*t)
	X2 += 0.00000000002*np.cos(3.50337598721 + 313.2104759189*t)
	X2 += 0.00000000002*np.cos(4.20516065977 + 217.964961884*t)
	X2 += 0.00000000002*np.cos(2.20171652063 + 429.0458714308*t)
	X2 += 0.00000000002*np.cos(4.04146812069 + 757.2171545342*t)
	X2 += 0.00000000002*np.cos(4.57276707328 + 152.5321425512*t)
	X2 += 0.00000000002*np.cos(3.68407924766 + 497.4476361802*t)
	X2 += 0.00000000002*np.cos(3.12072684129 + 970.5162499722*t)
	X2 += 0.00000000002*np.cos(5.64039146960 + 31.019488637*t)
	X2 += 0.00000000002*np.cos(2.66449175860 + 621.7380390493*t)
	X2 += 0.00000000002*np.cos(5.62397521798 + 114.1384744825*t)
	X2 += 0.00000000002*np.cos(2.71705780092 + 558.1451530978*t)
	X2 += 0.00000000002*np.cos(0.99842812351 + 1159.2933106701*t)
	X2 += 0.00000000002*np.cos(0.25455515171 + 28.5718080822*t)
	X2 += 0.00000000002*np.cos(2.22040659610 + 1165.6560981455*t)
	X2 += 0.00000000002*np.cos(3.92283242502 + 114.3991069134*t)
	X2 += 0.00000000002*np.cos(1.35954801363 + 6290.1893969922*t)
	X2 += 0.00000000002*np.cos(0.96949666008 + 2001.4439921582*t)
	X2 += 0.00000000002*np.cos(3.91766003237 + 1585.1407420207*t)
	X2 += 0.00000000002*np.cos(2.70259076444 + 69.3649725959*t)
	X2 += 0.00000000002*np.cos(0.07579249220 + 29.2049475286*t)
	X2 += 0.00000000002*np.cos(1.95715134557 + 20426.571092422*t)
	X2 += 0.00000000002*np.cos(2.31324085719 + 137.0330241624*t)
	X2 += 0.00000000002*np.cos(2.78356822310 + 10220.3990932118*t)
	X2 += 0.00000000002*np.cos(5.28443164212 + 6275.9623029906*t)
	X2 += 0.00000000002*np.cos(5.11875923907 + 59.8037450403*t)
	X2 += 0.00000000002*np.cos(0.11528384136 + 1567.7322542814*t)
	X2 += 0.00000000002*np.cos(1.28330427722 + 1585.8915015461*t)
	X2 += 0.00000000002*np.cos(1.29170969689 + 1891.2376709388*t)
	X2 += 0.00000000002*np.cos(3.17036060360 + 842.1506814881*t)
	X2 += 0.00000000002*np.cos(0.42525813663 + 10206.1719992102*t)
	X2 += 0.00000000001*np.cos(1.14039180766 + 134.5853436076*t)
	X2 += 0.00000000002*np.cos(6.01434378117 + 230.7075831773*t)
	X2 += 0.00000000002*np.cos(1.83503524165 + 45.2465826386*t)
	X2 += 0.00000000002*np.cos(2.04432205632 + 195.8906076987*t)
	X2 += 0.00000000001*np.cos(2.95607721894 + 5.4166259714*t)
	X2 += 0.00000000002*np.cos(1.51663879907 + 5856.4776591154*t)
	X2 += 0.00000000002*np.cos(6.09766096540 + 732.6951197941*t)
	X2 += 0.00000000001*np.cos(2.08902859115 + 436.1594184316*t)
	X2 += 0.00000000001*np.cos(5.19084560823 + 643.8294395771*t)
	X2 += 0.00000000001*np.cos(4.82960303687 + 4.4534181249*t)
	X2 += 0.00000000001*np.cos(0.98099621114 + 175.1660598002*t)
	X2 += 0.00000000002*np.cos(5.31255470217 + 945.9942152321*t)
	X2 += 0.00000000001*np.cos(0.94230361902 + 47.6942631934*t)
	X2 += 0.00000000001*np.cos(0.16035597342 + 5230.807466803*t)
	X2 += 0.00000000002*np.cos(2.94053740817 + 9786.687355335*t)
	X2 += 0.00000000001*np.cos(4.08545074975 + 5216.5803728014*t)
	X2 += 0.00000000001*np.cos(4.15130137250 + 2228.9701815978*t)
	X2 += 0.00000000001*np.cos(3.94337251048 + 576.1613880106*t)
	X2 += 0.00000000002*np.cos(3.39009998333 + 6283.0758499914*t)
	X2 += 0.00000000002*np.cos(4.41839057906 + 479.2883889155*t)
	X2 += 0.00000000001*np.cos(4.16344366662 + 289.5651667136*t)
	X2 += 0.00000000001*np.cos(1.74654140797 + 333.657345044*t)
	X2 += 0.00000000001*np.cos(0.63747447616 + 398.1440028728*t)
	X2 += 0.00000000001*np.cos(3.83236928125 + 251.4321310758*t)
	X2 += 0.00000000001*np.cos(2.88830183457 + 710.7467316182*t)
	X2 += 0.00000000001*np.cos(1.43835440421 + 2214.7430875962*t)
	X2 += 0.00000000001*np.cos(1.58334312085 + 9161.0171630226*t)
	X2 += 0.00000000001*np.cos(5.50845123735 + 9146.790069021*t)
	X2 += 0.00000000001*np.cos(5.26640201275 + 144.1465711632*t)
	X2 += 0.00000000001*np.cos(2.53287432135 + 69.1525242748*t)
	X2 += 0.00000000001*np.cos(1.02588647359 + 23.5758732361*t)
	X2 += 0.00000000001*np.cos(6.03456499421 + 1912.5783119412*t)
	X2 += 0.00000000001*np.cos(3.42071911045 + 501.3797894433*t)
	X2 += 0.00000000001*np.cos(4.59182707838 + 20.6069278195*t)
	X2 += 0.00000000001*np.cos(3.79198387946 + 152.0108776894*t)
	X2 += 0.00000000001*np.cos(0.81639690921 + 2627.1141844706*t)
	X2 += 0.00000000001*np.cos(3.58087506535 + 3178.1457905676*t)
	X2 += 0.00000000001*np.cos(2.45958374643 + 9999.986450773*t)
	X2 += 0.00000000001*np.cos(0.87978448649 + 2641.3412784722*t)
	X2 += 0.00000000001*np.cos(1.04491249500 + 6069.7767545534*t)
	X2 += 0.00000000001*np.cos(5.27106180403 + 953.1077622329*t)
	X2 += 0.00000000001*np.cos(4.80017363401 + 230.5645708254*t)
	X2 += 0.00000000001*np.cos(5.26797429460 + 3789.5888888784*t)
	X2 += 0.00000000001*np.cos(5.02587785483 + 45.5766510387*t)
	X2 += 0.00000000001*np.cos(6.18245782951 + 739.8086667949*t)
	X2 += 0.00000000001*np.cos(3.77212741773 + 320.3240229197*t)
	X2 += 0.00000000001*np.cos(2.15818518991 + 347.8844390456*t)
	X2 += 0.00000000001*np.cos(5.30050841854 + 5223.6939198022*t)
	X2 += 0.00000000001*np.cos(5.04702367820 + 518.6452648307*t)
	X2 += 0.00000000001*np.cos(2.43525462376 + 540.7366653585*t)
	X2 += 0.00000000001*np.cos(1.09106134688 + 120.358249606*t)
	X2 += 0.00000000001*np.cos(5.45018735567 + 395.578702239*t)
	X2 += 0.00000000001*np.cos(2.07086111988 + 1677.9385755008*t)
	X2 += 0.00000000001*np.cos(3.09716587450 + 381.3516082374*t)
	X2 += 0.00000000001*np.cos(5.06573742128 + 166.828672522*t)
	X2 += 0.00000000001*np.cos(2.80620548547 + 156.6767441354*t)
	X2 += 0.00000000001*np.cos(2.59070074660 + 3281.2385647862*t)
	X2 += 0.00000000001*np.cos(6.24084254244 + 196.0336200506*t)
	X2 += 0.00000000001*np.cos(0.24624541410 + 952.3570027075*t)
	X2 += 0.00000000001*np.cos(2.06539501659 + 909.8187330546*t)
	X2 += 0.00000000001*np.cos(3.93074715660 + 33.1371007917*t)
	X2 += 0.00000000001*np.cos(4.58237809092 + 5753.3848848968*t)
	X2 += 0.00000000001*np.cos(3.63938323718 + 1.4844727083*t)
	X2 += 0.00000000001*np.cos(2.31688110369 + 1158.5425511447*t)
	X2 += 0.00000000001*np.cos(1.43177817044 + 2324.9494088156*t)
	X2 += 0.00000000001*np.cos(4.45401480547 + 70.1157321213*t)
	X2 += 0.00000000001*np.cos(4.40398025201 + 106.2741679563*t)
	X2 += 0.00000000001*np.cos(4.86416557145 + 146.594251718*t)
	X2 += 0.00000000001*np.cos(4.78041364461 + 3149.6916025644*t)
	X2 += 0.00000000001*np.cos(2.69493782308 + 89.7594520943*t)
	X2 += 0.00000000001*np.cos(3.05417253299 + 431.264057322*t)
	X2 += 0.00000000001*np.cos(2.13752638117 + 414.0680179038*t)
	X2 += 0.00000000001*np.cos(2.74865313032 + 343.2185725996*t)
	X2 += 0.00000000001*np.cos(5.99960093585 + 9683.5945811164*t)
	X2 += 0.00000000001*np.cos(0.37042289177 + 159.1244246902*t)
	X2 += 0.00000000001*np.cos(5.16248959166 + 326.6868103951*t)
	X2 += 0.00000000001*np.cos(0.21129229286 + 3590.516887442*t)
	X2 += 0.00000000001*np.cos(6.26008785309 + 259.769518354*t)
	X2 += 0.00000000001*np.cos(0.21684015359 + 79.4474650133*t)
	X2 += 0.00000000001*np.cos(2.55079888210 + 1286.9081196288*t)
	X2 += 0.00000000001*np.cos(3.00705640621 + 98.8999885246*t)
	X2 += 0.00000000001*np.cos(0.88846081024 + 1166.4068576709*t)
	X2 += 0.00000000001*np.cos(0.64591436945 + 275.5505210331*t)
	X2 += 0.00000000001*np.cos(3.62650844268 + 849.2642284889*t)
	X2 += 0.00000000001*np.cos(1.73658121284 + 2531.1349572528*t)
	X2 += 0.00000000001*np.cos(1.40139303219 + 3384.3313390048*t)
	X2 += 0.00000000001*np.cos(1.76878800801 + 16.6747745564*t)
	X2 += 0.00000000001*np.cos(4.24463491114 + 572.2292347475*t)
	X2 += 0.00000000001*np.cos(0.81335504228 + 409.1897031367*t)
	X2 += 0.00000000001*np.cos(5.44849084138 + 4694.0029547076*t)
	X2 += 0.00000000001*np.cos(1.22028557906 + 2943.5060541272*t)
	X2 += 0.00000000001*np.cos(1.94295621671 + 2538.2485042536*t)
	X2 += 0.00000000001*np.cos(5.27707866607 + 3370.1042450032*t)
	X2 += 0.00000000001*np.cos(5.44313786008 + 73.0846775379*t)
	X2 += 0.00000000001*np.cos(0.77027981694 + 696.5196376166*t)
	X2 += 0.00000000001*np.cos(0.09516954609 + 554.0699874828*t)
	X2 += 0.00000000001*np.cos(5.09367829068 + 2545.3620512544*t)
	X2 += 0.00000000001*np.cos(5.51009979488 + 76.4785195967*t)
	X2 += 0.00000000001*np.cos(2.52621311197 + 421.93232443*t)
	X2 += 0.00000000001*np.cos(3.10597885207 + 135.336103133*t)
	X2 += 0.00000000001*np.cos(5.89979133925 + 3693.6096616606*t)
	X2 += 0.00000000001*np.cos(1.09065920381 + 41.6444977756*t)
	X2 += 0.00000000001*np.cos(0.91991146152 + 2207.6295405954*t)
	X2 += 0.00000000001*np.cos(0.28268850731 + 188.0263011725*t)
	X2 += 0.00000000001*np.cos(0.58711122088 + 8624.2126509272*t)
	X2 += 0.00000000001*np.cos(0.96994450396 + 205.2223405907*t)
	X2 += 0.00000000001*np.cos(1.45873593041 + 238.5718897035*t)
	X2 += 0.00000000001*np.cos(2.93549274571 + 19.643719973*t)
	X2 += 0.00000000001*np.cos(1.78998474809 + 188.9200730498*t)
	X2 += 0.00000000001*np.cos(2.52048457707 + 1354.4331588434*t)
	X2 += 0.00000000001*np.cos(2.48843067166 + 432.2272651685*t)
	X2 += 0.00000000001*np.cos(0.93594807898 + 2634.2277314714*t)
	X2 += 0.00000000001*np.cos(3.70036835095 + 162.0933701068*t)
	X2 += 0.00000000001*np.cos(2.97957775537 + 60.7669528868*t)
	X2 += 0.00000000001*np.cos(2.36629876922 + 147.1155165798*t)
	X2 += 0.00000000001*np.cos(5.43434577466 + 92.0470739547*t)
	X2 += 0.00000000001*np.cos(1.40978470315 + 2310.722314814*t)
	X2 += 0.00000000001*np.cos(1.58904595106 + 5643.1785636774*t)
	X2 += 0.00000000001*np.cos(0.06796981461 + 2420.9286360334*t)
	X2 += 0.00000000001*np.cos(1.26807180969 + 3803.81598288*t)
	X2 += 0.00000000001*np.cos(3.39708351921 + 229.9738699944*t)
	X2 += 0.00000000001*np.cos(4.63413530097 + 196.6243208816*t)
	X2 += 0.00000000001*np.cos(5.71107254684 + 6062.6632075526*t)
	X2 += 0.00000000001*np.cos(1.10737909998 + 3700.7232086614*t)
	X2 += 0.00000000001*np.cos(0.47224576665 + 9153.9036160218*t)
	X2 += 0.00000000001*np.cos(2.92109642544 + 33.9402499438*t)
	X2 += 0.00000000001*np.cos(4.07034548494 + 1141.1340634054*t)
	X2 += 0.00000000001*np.cos(5.39245908224 + 1464.6394800628*t)
	X2 += 0.00000000001*np.cos(4.53088658665 + 650.1922270525*t)
	X2 += 0.00000000001*np.cos(1.45910530004 + 600.5404103988*t)
	X2 += 0.00000000001*np.cos(5.82199981323 + 3796.7024358792*t)
	X2 += 0.00000000001*np.cos(6.18108836663 + 120.5012619579*t)
	X2 += 0.00000000001*np.cos(2.94885920326 + 561.1835344836*t)
	X2 += 0.00000000001*np.cos(0.87647187809 + 221.3758502853*t)
	X2 += 0.00000000001*np.cos(4.70168321908 + 207.1487562837*t)
	X2 += 0.00000000001*np.cos(3.32953560109 + 219.4494345923*t)
	X2 += 0.00000000001*np.cos(4.88850095992 + 2413.8150890326*t)
	X2 += 0.00000000001*np.cos(2.97783813090 + 9573.388259897*t)
	X2 += 0.00000000001*np.cos(2.10286072462 + 1670.82502850*t)
	X2 += 0.00000000001*np.cos(3.65270448363 + 220.4608265486*t)
	X2 += 0.00000000001*np.cos(4.37851433655 + 206.1373643274*t)
	X2 += 0.00000000001*np.cos(0.61063819752 + 2317.8358618148*t)
	X2 += 0.00000000001*np.cos(4.27756633580 + 51.2057253312*t)
	X2 += 0.00000000001*np.cos(1.80994801683 + 556.5176680376*t)
	X2 += 0.00000000001*np.cos(1.83613026873 + 916.9322800554*t)
	X2 += 0.00000000001*np.cos(0.11024104965 + 1493.093668066*t)
	X2 += 0.00000000001*np.cos(3.71988988186 + 856.3777754897*t)
	X2 += 0.00000000000*np.cos(2.95505775787 + 417.0369633204*t)
	X2 += 0.00000000001*np.cos(5.00605271994 + 344.8460576598*t)
	X2 += 0.00000000001*np.cos(3.17367722916 + 129.9194771616*t)
	X2 += 0.00000000001*np.cos(1.97446309982 + 1994.3304451574*t)
	X2 += 0.00000000001*np.cos(4.17194315865 + 570.7447620392*t)
	X2 += 0.00000000000*np.cos(2.23302803818 + 425.6349830295*t)
	X2 += 0.00000000001*np.cos(6.25221727681 + 421.1815649046*t)
	X2 += 0.00000000000*np.cos(6.24904449571 + 60.5545045657*t)
	X2 += 0.00000000001*np.cos(1.74136183161 + 1987.2168981566*t)
	X2 += 0.00000000000*np.cos(4.03297442833 + 25.2727942655*t)
	X2 += 0.00000000000*np.cos(5.58154855013 + 455.0523788792*t)
	X2 += 0.00000000000*np.cos(5.96874139195 + 427.5613987225*t)
	X2 += 0.00000000001*np.cos(5.94031185502 + 186.472392495*t)
	X2 += 0.00000000000*np.cos(0.21957151560 + 898.7730327907*t)
	X2 += 0.00000000001*np.cos(5.18531568854 + 439.1283638482*t)
	X2 += 0.00000000001*np.cos(0.59883239303 + 373.9079928365*t)
	X2 += 0.00000000000*np.cos(0.50496401101 + 3340.6124266998*t)
	X2 += 0.00000000001*np.cos(2.67987017976 + 913.0001267923*t)
	X2 += 0.00000000000*np.cos(4.61747280885 + 42.3258213318*t)
	X2 += 0.00000000000*np.cos(1.44076539050 + 546.956440482*t)
	X2 += 0.00000000001*np.cos(2.71138947765 + 458.8415197904*t)
	X2 += 0.00000000000*np.cos(2.09722257636 + 305.3461693927*t)
	X2 += 0.00000000000*np.cos(2.58771166540 + 280.9671470045*t)
	X2 += 0.00000000000*np.cos(4.40770012765 + 211.8146227297*t)
	X2 += 0.00000000001*np.cos(6.09627421742 + 173.9422195228*t)
	X2 += 0.00000000000*np.cos(1.77476793187 + 2847.5268269094*t)
	X2 += 0.00000000001*np.cos(3.73904964812 + 116.4260963429*t)
	X2 += 0.00000000000*np.cos(0.78193911574 + 3576.2897934404*t)
	X2 += 0.00000000000*np.cos(1.30108106654 + 2303.6087678132*t)
	X2 += 0.00000000000*np.cos(3.20962690742 + 140.001969579*t)
	X2 += 0.00000000000*np.cos(1.66839826038 + 3259.8979237838*t)
	return X2*t*t




def Sun_X3 (t): # 206 terms of order 3

	X3 = 0.
	X3 += 0.00000022035*np.cos(6.11822426048 + 206.1855484372*t)
	X3 += 0.00000021482*np.cos(5.03368299703 + 220.4126424388*t)
	X3 += 0.00000016291*np.cos(2.71940457791 + 522.5774180938*t)
	X3 += 0.00000015934*np.cos(1.63320186413 + 536.8045120954*t)
	X3 += 0.00000003063*np.cos(3.80201225520 + 426.598190876*t)
	X3 += 0.00000002563*np.cos(4.04702837579 + 433.7117378768*t)
	X3 += 0.00000002101*np.cos(4.92786996750 + 227.5261894396*t)
	X3 += 0.00000001706*np.cos(0.42316599671 + 1059.3819301892*t)
	X3 += 0.00000002008
	X3 += 0.00000001375*np.cos(2.83821817426 + 515.463871093*t)
	X3 += 0.00000001266*np.cos(5.37509106080 + 419.4846438752*t)
	X3 += 0.00000001038*np.cos(2.26994057258 + 1066.49547719*t)
	X3 += 0.00000001000*np.cos(6.26567671131 + 199.0720014364*t)
	X3 += 0.00000000964*np.cos(1.50782014667 + 543.9180590962*t)
	X3 += 0.00000001275*np.cos(0.02482955002 + 7.1135470008*t)
	X3 += 0.00000000845*np.cos(2.83708264275 + 639.897286314*t)
	X3 += 0.00000000678*np.cos(2.36507413871 + 1052.2683831884*t)
	X3 += 0.00000000344*np.cos(1.24961127281 + 213.299095438*t)
	X3 += 0.00000000382*np.cos(6.20559320688 + 14.2270940016*t)
	X3 += 0.00000000291*np.cos(3.14472957178 + 647.0108333148*t)
	X3 += 0.00000000249*np.cos(1.14107482666 + 1589.0728952838*t)
	X3 += 0.00000000214*np.cos(4.03956747124 + 440.8252848776*t)
	X3 += 0.00000000230*np.cos(4.42377888159 + 216.4804891757*t)
	X3 += 0.00000000219*np.cos(0.47150010549 + 210.1177017003*t)
	X3 += 0.00000000129*np.cos(1.79919042809 + 1045.1548361876*t)
	X3 += 0.00000000123*np.cos(2.08253199617 + 853.196381752*t)
	X3 += 0.00000000092*np.cos(4.79503944157 + 234.6397364404*t)
	X3 += 0.00000000086*np.cos(6.10758245301 + 103.0927742186*t)
	X3 += 0.00000000091*np.cos(5.48002372488 + 117.3198682202*t)
	X3 += 0.00000000093*np.cos(5.08172811528 + 529.6909650946*t)
	X3 += 0.00000000075*np.cos(2.87101566525 + 1596.1864422846*t)
	X3 += 0.00000000069*np.cos(4.27897139677 + 95.9792272178*t)
	X3 += 0.00000000073*np.cos(6.02905465950 + 632.7837393132*t)
	X3 += 0.00000000077*np.cos(5.03142217150 + 412.3710968744*t)
	X3 += 0.00000000064*np.cos(3.94993325790 + 316.3918696566*t)
	X3 += 0.00000000056*np.cos(2.99558443348 + 508.3503240922*t)
	X3 += 0.00000000055*np.cos(3.29709092103 + 323.5054166574*t)
	X3 += 0.00000000048*np.cos(1.97191764285 + 1073.6090241908*t)
	X3 += 0.00000000056*np.cos(1.48325794833 + 735.8765135318*t)
	X3 += 0.00000000042*np.cos(1.41375480258 + 625.6701923124*t)
	X3 += 0.00000000039*np.cos(0.30611138474 + 942.062061969*t)
	X3 += 0.00000000036*np.cos(4.59308117276 + 209.3669421749*t)
	X3 += 0.00000000031*np.cos(2.46171091539 + 1581.959348283*t)
	X3 += 0.00000000031*np.cos(1.32072373030 + 551.031606097*t)
	X3 += 0.00000000032*np.cos(0.26519734656 + 217.2312487011*t)
	X3 += 0.00000000033*np.cos(2.32289510783 + 860.3099287528*t)
	X3 += 0.00000000028*np.cos(3.48885797103 + 330.6189636582*t)
	X3 += 0.00000000027*np.cos(3.92096513265 + 149.5631971346*t)
	X3 += 0.00000000029*np.cos(6.05526972992 + 70.8494453042*t)
	X3 += 0.00000000027*np.cos(1.63715408955 + 2118.7638603784*t)
	X3 += 0.00000000028*np.cos(1.74838965252 + 78.7137518304*t)
	X3 += 0.00000000029*np.cos(0.48147029137 + 949.1756089698*t)
	X3 += 0.00000000025*np.cos(4.58797131637 + 124.433415221*t)
	X3 += 0.00000000033*np.cos(4.30649710462 + 223.5940361765*t)
	X3 += 0.00000000032*np.cos(1.93089098387 + 110.2063212194*t)
	X3 += 0.00000000027*np.cos(6.02243954440 + 21.3406410024*t)
	X3 += 0.00000000025*np.cos(1.16107900100 + 1169.5882514086*t)
	X3 += 0.00000000024*np.cos(1.53395713354 + 63.7358983034*t)
	X3 += 0.00000000028*np.cos(1.56238914694 + 728.762966531*t)
	X3 += 0.00000000024*np.cos(3.16134826622 + 654.1243803156*t)
	X3 += 0.00000000023*np.cos(0.20728622886 + 191.9584544356*t)
	X3 += 0.00000000022*np.cos(2.15937343363 + 1155.361157407*t)
	X3 += 0.00000000019*np.cos(0.03186061495 + 85.8272988312*t)
	X3 += 0.00000000019*np.cos(0.95260076413 + 73.297125859*t)
	X3 += 0.00000000022*np.cos(5.27304712373 + 956.2891559706*t)
	X3 += 0.00000000024*np.cos(5.89117970906 + 309.2783226558*t)
	X3 += 0.00000000025*np.cos(3.51115533622 + 429.7795846137*t)
	X3 += 0.00000000024*np.cos(3.53027023690 + 519.3960243561*t)
	X3 += 0.00000000020*np.cos(1.86650914141 + 71.6002048296*t)
	X3 += 0.00000000017*np.cos(4.13765972175 + 88.865680217*t)
	X3 += 0.00000000019*np.cos(5.95485140431 + 77.962992305*t)
	X3 += 0.00000000016*np.cos(0.00550329231 + 202.2533951741*t)
	X3 += 0.00000000020*np.cos(0.77024887951 + 539.9859058331*t)
	X3 += 0.00000000015*np.cos(5.02720184968 + 224.3447957019*t)
	X3 += 0.00000000013*np.cos(0.64071359315 + 76.2660712756*t)
	X3 += 0.00000000016*np.cos(0.70623098744 + 203.0041546995*t)
	X3 += 0.00000000012*np.cos(0.84507236712 + 302.164775655*t)
	X3 += 0.00000000010*np.cos(5.28489326618 + 11.0457002639*t)
	X3 += 0.00000000010*np.cos(3.98008913039 + 36.6485629295*t)
	X3 += 0.00000000012*np.cos(3.35651610375 + 422.6660376129*t)
	X3 += 0.00000000009*np.cos(3.50226842635 + 39.6175083461*t)
	X3 += 0.00000000009*np.cos(1.66650203128 + 1038.0412891868*t)
	X3 += 0.00000000009*np.cos(3.97946790815 + 447.9388318784*t)
	X3 += 0.00000000009*np.cos(3.09433206743 + 618.5566453116*t)
	X3 += 0.00000000008*np.cos(2.36406802666 + 838.9692877504*t)
	X3 += 0.00000000008*np.cos(0.38739265309 + 423.4167971383*t)
	X3 += 0.00000000009*np.cos(1.90795498674 + 1574.8458012822*t)
	X3 += 0.00000000007*np.cos(2.99983273700 + 1258.4539316256*t)
	X3 += 0.00000000007*np.cos(2.49966387854 + 831.8557407496*t)
	X3 += 0.00000000008*np.cos(3.95391486424 + 74.7815985673*t)
	X3 += 0.00000000006*np.cos(2.58853517839 + 138.5174968707*t)
	X3 += 0.00000000007*np.cos(0.08989351607 + 742.9900605326*t)
	X3 += 0.00000000006*np.cos(3.39896707822 + 2125.8774073792*t)
	X3 += 0.00000000005*np.cos(2.18119549382 + 145.6310438715*t)
	X3 += 0.00000000007*np.cos(0.58812910406 + 38.1330356378*t)
	X3 += 0.00000000005*np.cos(2.24425105188 + 195.1398481733*t)
	X3 += 0.00000000004*np.cos(2.85162994822 + 1265.5674786264*t)
	X3 += 0.00000000004*np.cos(3.42359216874 + 337.732510659*t)
	X3 += 0.00000000004*np.cos(2.02888732685 + 18.1592472647*t)
	X3 += 0.00000000005*np.cos(6.19237785082 + 3.9321532631*t)
	X3 += 0.00000000004*np.cos(0.27398248033 + 1485.9801210652*t)
	X3 += 0.00000000004*np.cos(4.28076500111 + 437.6438911399*t)
	X3 += 0.00000000003*np.cos(1.84730058943 + 1699.2792165032*t)
	X3 += 0.00000000004*np.cos(3.46019246895 + 3.1813937377*t)
	X3 += 0.00000000003*np.cos(0.37181135547 + 934.9485149682*t)
	X3 += 0.00000000003*np.cos(4.11129727244 + 131.5469622218*t)
	X3 += 0.00000000003*np.cos(0.39047321949 + 1162.4747044078*t)
	X3 += 0.00000000003*np.cos(3.46901444868 + 436.8931316145*t)
	X3 += 0.00000000003*np.cos(2.41437573614 + 1062.5633239269*t)
	X3 += 0.00000000002*np.cos(3.24274981940 + 611.4430983108*t)
	X3 += 0.00000000003*np.cos(1.10053303206 + 1471.7530270636*t)
	X3 += 0.00000000003*np.cos(1.79512864801 + 1272.6810256272*t)
	X3 += 0.00000000002*np.cos(5.52311410472 + 131.4039498699*t)
	X3 += 0.00000000002*np.cos(2.48371068324 + 1603.2999892854*t)
	X3 += 0.00000000002*np.cos(2.33183931476 + 867.4234757536*t)
	X3 += 0.00000000002*np.cos(2.19577030344 + 2648.454825473*t)
	X3 += 0.00000000003*np.cos(3.98168020133 + 56.6223513026*t)
	X3 += 0.00000000002*np.cos(5.45688610067 + 846.0828347512*t)
	X3 += 0.00000000002*np.cos(2.65700192125 + 643.0786800517*t)
	X3 += 0.00000000002*np.cos(1.84112643531 + 721.6494195302*t)
	X3 += 0.00000000002*np.cos(2.08476192747 + 750.1036075334*t)
	X3 += 0.00000000002*np.cos(2.42918053212 + 635.9651330509*t)
	X3 += 0.00000000002*np.cos(5.79217247184 + 231.4583427027*t)
	X3 += 0.00000000002*np.cos(4.02167835510 + 269.9214467406*t)
	X3 += 0.00000000002*np.cos(5.21252267104 + 408.4389436113*t)
	X3 += 0.00000000002*np.cos(2.50697839724 + 963.4027029714*t)
	X3 += 0.00000000002*np.cos(4.04816193043 + 1368.660252845*t)
	X3 += 0.00000000002*np.cos(3.20483541487 + 1685.0521225016*t)
	X3 += 0.00000000002*np.cos(6.08001443327 + 22.0914005278*t)
	X3 += 0.00000000002*np.cos(2.57522241240 + 1055.4497769261*t)
	X3 += 0.00000000002*np.cos(4.65923813596 + 241.7532834412*t)
	X3 += 0.00000000002*np.cos(3.01020812339 + 151.0476698429*t)
	X3 += 0.00000000002*np.cos(2.30328844097 + 415.5524906121*t)
	X3 += 0.00000000002*np.cos(3.33031033737 + 526.5095713569*t)
	X3 += 0.00000000002*np.cos(4.15196796459 + 532.8723588323*t)
	X3 += 0.00000000001*np.cos(0.85517205788 + 277.0349937414*t)
	X3 += 0.00000000002*np.cos(1.70893188663 + 430.5303441391*t)
	X3 += 0.00000000002*np.cos(4.15254535573 + 92.940845832*t)
	X3 += 0.00000000002*np.cos(3.92611152496 + 1361.5467058442*t)
	X3 += 0.00000000001*np.cos(2.09298651615 + 416.3032501375*t)
	X3 += 0.00000000002*np.cos(0.38432620826 + 1279.794572628*t)
	X3 += 0.00000000001*np.cos(0.44109528380 + 1478.8665740644*t)
	X3 += 0.00000000002*np.cos(2.44054024033 + 2111.6503133776*t)
	X3 += 0.00000000002*np.cos(1.02806088947 + 1056.2005364515*t)
	X3 += 0.00000000001*np.cos(4.33843290510 + 81.7521332162*t)
	X3 += 0.00000000001*np.cos(2.56904089278 + 160.6088973985*t)
	X3 += 0.00000000001*np.cos(3.19745338253 + 483.2205421786*t)
	X3 += 0.00000000001*np.cos(5.07229232557 + 35.1640902212*t)
	X3 += 0.00000000001*np.cos(0.01253715020 + 1692.1656695024*t)
	X3 += 0.00000000001*np.cos(4.69846613681 + 405.2575498736*t)
	X3 += 0.00000000001*np.cos(3.34457667490 + 184.8449074348*t)
	X3 += 0.00000000001*np.cos(1.28958525047 + 2420.9286360334*t)
	X3 += 0.00000000001*np.cos(0.50080361601 + 2097.423219376*t)
	X3 += 0.00000000001*np.cos(2.40988764568 + 41.1019810544*t)
	X3 += 0.00000000001*np.cos(3.12659159503 + 661.2379273164*t)
	X3 += 0.00000000001*np.cos(4.28786284652 + 153.4953503977*t)
	X3 += 0.00000000001*np.cos(1.27230121095 + 1069.6768709277*t)
	X3 += 0.00000000001*np.cos(0.83896009084 + 1141.1340634054*t)
	X3 += 0.00000000001*np.cos(4.62910391320 + 1677.9385755008*t)
	X3 += 0.00000000001*np.cos(1.33615111395 + 295.0512286542*t)
	X3 += 0.00000000001*np.cos(5.19392652959 + 2008.557539159*t)
	X3 += 0.00000000001*np.cos(1.70895997922 + 2524.021410252*t)
	X3 += 0.00000000001*np.cos(2.85145645242 + 1148.2476104062*t)
	X3 += 0.00000000001*np.cos(3.87668679749 + 1049.0869894507*t)
	X3 += 0.00000000001*np.cos(1.26644803792 + 67.6680515665*t)
	X3 += 0.00000000001*np.cos(1.41200645133 + 1080.7225711916*t)
	X3 += 0.00000000001*np.cos(0.30648573345 + 81.8951455681*t)
	X3 += 0.00000000001*np.cos(2.22060985607 + 398.1440028728*t)
	X3 += 0.00000000001*np.cos(3.40234826657 + 1898.3512179396*t)
	X3 += 0.00000000001*np.cos(4.93950810432 + 1382.8873468466*t)
	X3 += 0.00000000001*np.cos(2.11509401909 + 497.4476361802*t)
	X3 += 0.00000000001*np.cos(5.51414228015 + 113.3877149571*t)
	X3 += 0.00000000001*np.cos(5.53031383413 + 52.6901980395*t)
	X3 += 0.00000000001*np.cos(4.68815631126 + 65.2203710117*t)
	X3 += 0.00000000001*np.cos(1.61397437787 + 2200.5159935946*t)
	X3 += 0.00000000001*np.cos(2.78615435517 + 362.8622925726*t)
	X3 += 0.00000000001*np.cos(5.17635659202 + 87.3117715395*t)
	X3 += 0.00000000001*np.cos(5.51686120993 + 106.2741679563*t)
	X3 += 0.00000000001*np.cos(1.55449599970 + 127.4717966068*t)
	X3 += 0.00000000001*np.cos(3.35446680425 + 84.3428261229*t)
	X3 += 0.00000000001*np.cos(1.81267436298 + 2840.4132799086*t)
	X3 += 0.00000000001*np.cos(1.17976882041 + 1905.4647649404*t)
	X3 += 0.00000000001*np.cos(3.08843634733 + 148.0787244263*t)
	X3 += 0.00000000001*np.cos(1.02492612113 + 1802.3719907218*t)
	X3 += 0.00000000001*np.cos(1.63677815266 + 1464.6394800628*t)
	X3 += 0.00000000001*np.cos(3.78415196409 + 1994.3304451574*t)
	X3 += 0.00000000001*np.cos(3.72506013500 + 525.7588118315*t)
	X3 += 0.00000000001*np.cos(3.75721816696 + 533.6231183577*t)
	X3 += 0.00000000001*np.cos(4.38707763857 + 146.3818033969*t)
	X3 += 0.00000000001*np.cos(3.40658169212 + 1251.3403846248*t)
	X3 += 0.00000000001*np.cos(1.77287268239 + 1375.7737998458*t)
	X3 += 0.00000000001*np.cos(5.52446051191 + 10.2949407385*t)
	X3 += 0.00000000001*np.cos(3.43458357100 + 650.9429865779*t)
	X3 += 0.00000000001*np.cos(3.77240220445 + 195.8906076987*t)
	X3 += 0.00000000001*np.cos(4.25881661572 + 230.7075831773*t)
	X3 += 0.00000000001*np.cos(1.87052300978 + 2015.6710861598*t)
	X3 += 0.00000000001*np.cos(1.58322970617 + 824.7421937488*t)
	X3 += 0.00000000001*np.cos(4.65847413168 + 344.7030453079*t)
	X3 += 0.00000000001*np.cos(4.99298501823 + 191.2076949102*t)
	X3 += 0.00000000001*np.cos(0.59254425211 + 636.7158925763*t)
	X3 += 0.00000000001*np.cos(0.25429623911 + 2221.856634597*t)
	X3 += 0.00000000000*np.cos(1.11477290890 + 107.0249274817*t)
	X3 += 0.00000000001*np.cos(2.73652770490 + 1788.1448967202*t)
	X3 += 0.00000000001*np.cos(2.47098918303 + 927.8349679674*t)
	X3 += 0.00000000000*np.cos(6.18121716090 + 235.3904959658*t)
	X3 += 0.00000000000*np.cos(0.45100914365 + 1354.4331588434*t)
	return X3*t*t*t




def Sun_X4 (t): # 84 terms of order 4

	X4 = 0.
	X4 += 0.00000002272*np.cos(1.56364838180 + 206.1855484372*t)
	X4 += 0.00000002236*np.cos(3.28143366276 + 220.4126424388*t)
	X4 += 0.00000001682*np.cos(4.46996330708 + 522.5774180938*t)
	X4 += 0.00000001638*np.cos(6.17513895178 + 536.8045120954*t)
	X4 += 0.00000000430*np.cos(3.20713267334 + 227.5261894396*t)
	X4 += 0.00000000348*np.cos(2.26681787351 + 433.7117378768*t)
	X4 += 0.00000000291*np.cos(4.56956279775 + 515.463871093*t)
	X4 += 0.00000000206*np.cos(6.05364860885 + 543.9180590962*t)
	X4 += 0.00000000202*np.cos(1.69320982304 + 199.0720014364*t)
	X4 += 0.00000000123*np.cos(0.67135155073 + 1066.49547719*t)
	X4 += 0.00000000099*np.cos(0.99265774704 + 419.4846438752*t)
	X4 += 0.00000000113*np.cos(1.85695441801 + 426.598190876*t)
	X4 += 0.00000000080*np.cos(4.55016686641 + 7.1135470008*t)
	X4 -= 0.00000000090
	X4 += 0.00000000062*np.cos(4.48609878362 + 14.2270940016*t)
	X4 += 0.00000000053*np.cos(4.95103975600 + 1059.3819301892*t)
	X4 += 0.00000000066*np.cos(4.20375595982 + 1052.2683831884*t)
	X4 += 0.00000000050*np.cos(2.28699829686 + 440.8252848776*t)
	X4 += 0.00000000060*np.cos(0.97558287548 + 639.897286314*t)
	X4 += 0.00000000049*np.cos(1.31593641965 + 647.0108333148*t)
	X4 += 0.00000000031*np.cos(6.26226050601 + 213.299095438*t)
	X4 += 0.00000000024*np.cos(3.05754167589 + 234.6397364404*t)
	X4 += 0.00000000023*np.cos(3.61004405073 + 1045.1548361876*t)
	X4 += 0.00000000014*np.cos(4.76472781912 + 508.3503240922*t)
	X4 += 0.00000000013*np.cos(6.04976474685 + 1589.0728952838*t)
	X4 += 0.00000000011*np.cos(0.54626079593 + 412.3710968744*t)
	X4 += 0.00000000012*np.cos(0.15818608564 + 853.196381752*t)
	X4 += 0.00000000010*np.cos(0.31907502124 + 1073.6090241908*t)
	X4 += 0.00000000010*np.cos(1.35560891851 + 1596.1864422846*t)
	X4 += 0.00000000009*np.cos(4.24672231397 + 21.3406410024*t)
	X4 += 0.00000000011*np.cos(3.71353247018 + 117.3198682202*t)
	X4 += 0.00000000008*np.cos(1.50012562224 + 103.0927742186*t)
	X4 += 0.00000000007*np.cos(6.08752157484 + 95.9792272178*t)
	X4 += 0.00000000007*np.cos(6.27374846424 + 529.6909650946*t)
	X4 += 0.00000000007*np.cos(5.71854398962 + 551.031606097*t)
	X4 += 0.00000000006*np.cos(1.40413206867 + 654.1243803156*t)
	X4 += 0.00000000005*np.cos(2.81686507397 + 124.433415221*t)
	X4 += 0.00000000005*np.cos(3.21271191075 + 625.6701923124*t)
	X4 += 0.00000000006*np.cos(0.43509868093 + 860.3099287528*t)
	X4 += 0.00000000004*np.cos(1.55213484100 + 632.7837393132*t)
	X4 += 0.00000000005*np.cos(3.17881881452 + 728.762966531*t)
	X4 += 0.00000000004*np.cos(1.76651819729 + 330.6189636582*t)
	X4 += 0.00000000005*np.cos(2.10225977593 + 942.062061969*t)
	X4 += 0.00000000004*np.cos(5.76705671645 + 88.865680217*t)
	X4 += 0.00000000004*np.cos(3.27648798915 + 735.8765135318*t)
	X4 += 0.00000000003*np.cos(4.78415680549 + 618.5566453116*t)
	X4 += 0.00000000003*np.cos(0.90449193126 + 110.2063212194*t)
	X4 += 0.00000000003*np.cos(2.17395214560 + 447.9388318784*t)
	X4 += 0.00000000003*np.cos(4.27605231904 + 1581.959348283*t)
	X4 += 0.00000000003*np.cos(1.69135933489 + 323.5054166574*t)
	X4 += 0.00000000002*np.cos(5.71553727369 + 1169.5882514086*t)
	X4 += 0.00000000003*np.cos(2.34507379864 + 191.9584544356*t)
	X4 += 0.00000000002*np.cos(3.94362184472 + 1155.361157407*t)
	X4 += 0.00000000002*np.cos(1.55420041399 + 429.7795846137*t)
	X4 += 0.00000000003*np.cos(2.59535343316 + 302.164775655*t)
	X4 += 0.00000000002*np.cos(5.59314231958 + 316.3918696566*t)
	X4 += 0.00000000002*np.cos(3.65310721758 + 831.8557407496*t)
	X4 += 0.00000000002*np.cos(1.87311938884 + 309.2783226558*t)
	X4 += 0.00000000002*np.cos(0.19771789728 + 2118.7638603784*t)
	X4 += 0.00000000001*np.cos(3.56862151179 + 63.7358983034*t)
	X4 += 0.00000000002*np.cos(5.35217786853 + 203.0041546995*t)
	X4 += 0.00000000002*np.cos(2.67875662282 + 223.5940361765*t)
	X4 += 0.00000000001*np.cos(2.20334472347 + 149.5631971346*t)
	X4 += 0.00000000001*np.cos(3.76725001228 + 742.9900605326*t)
	X4 += 0.00000000001*np.cos(4.25784375307 + 85.8272988312*t)
	X4 += 0.00000000001*np.cos(3.65033183467 + 1574.8458012822*t)
	X4 += 0.00000000001*np.cos(3.66978405000 + 956.2891559706*t)
	X4 += 0.00000000001*np.cos(4.05229848373 + 423.4167971383*t)
	X4 += 0.00000000001*np.cos(5.47495901718 + 210.1177017003*t)
	X4 += 0.00000000001*np.cos(1.24151950182 + 337.732510659*t)
	X4 += 0.00000000001*np.cos(3.54926161114 + 405.2575498736*t)
	X4 += 0.00000000001*np.cos(2.60896952082 + 216.4804891757*t)
	X4 += 0.00000000001*np.cos(2.42395684459 + 949.1756089698*t)
	X4 += 0.00000000001*np.cos(3.82101733440 + 1038.0412891868*t)
	X4 += 0.00000000001*np.cos(1.64419675533 + 422.6660376129*t)
	X4 += 0.00000000001*np.cos(0.48555445682 + 18.1592472647*t)
	X4 += 0.00000000001*np.cos(4.82540662391 + 1258.4539316256*t)
	X4 += 0.00000000001*np.cos(2.21769054640 + 131.5469622218*t)
	X4 += 0.00000000001*np.cos(4.37722467188 + 838.9692877504*t)
	X4 += 0.00000000001*np.cos(5.43667975947 + 1485.9801210652*t)
	X4 += 0.00000000001*np.cos(5.09123218327 + 184.8449074348*t)
	X4 += 0.00000000001*np.cos(2.93998663691 + 241.7532834412*t)
	X4 += 0.00000000000*np.cos(1.39622585652 + 611.4430983108*t)
	X4 += 0.00000000000*np.cos(3.75725614820 + 1471.7530270636*t)
	return X4*t*t*t*t




def Sun_X5 (t): # 34 terms of order 5

	X5 = 0.
	X5 += 0.00000000168*np.cos(3.28069809842 + 206.1855484372*t)
	X5 += 0.00000000167*np.cos(1.52399958265 + 220.4126424388*t)
	X5 += 0.00000000126*np.cos(0.07122523863 + 522.5774180938*t)
	X5 += 0.00000000121*np.cos(4.30466267493 + 536.8045120954*t)
	X5 += 0.00000000064*np.cos(1.46493444949 + 227.5261894396*t)
	X5 += 0.00000000047*np.cos(0.05687052745 + 515.463871093*t)
	X5 += 0.00000000037*np.cos(0.48304760543 + 433.7117378768*t)
	X5 += 0.00000000032*np.cos(4.26961178617 + 543.9180590962*t)
	X5 += 0.00000000028*np.cos(3.41370273509 + 199.0720014364*t)
	X5 += 0.00000000011*np.cos(2.75798781903 + 14.2270940016*t)
	X5 += 0.00000000011*np.cos(5.33499883960 + 1066.49547719*t)
	X5 += 0.00000000010*np.cos(0.51443337467 + 440.8252848776*t)
	X5 += 0.00000000007*np.cos(5.80467663011 + 647.0108333148*t)
	X5 += 0.00000000004*np.cos(0.20088280204 + 1052.2683831884*t)
	X5 += 0.00000000004*np.cos(3.59221465704 + 419.4846438752*t)
	X5 += 0.00000000003*np.cos(5.43212710597 + 639.897286314*t)
	X5 += 0.00000000003*np.cos(1.37528056638 + 234.6397364404*t)
	X5 += 0.00000000002*np.cos(0.38337547624 + 191.9584544356*t)
	X5 += 0.00000000002*np.cos(5.49829989028 + 426.598190876*t)
	X5 += 0.00000000002*np.cos(4.89397151114 + 1073.6090241908*t)
	X5 += 0.00000000002*np.cos(6.21263006019 + 1045.1548361876*t)
	X5 += 0.00000000001*np.cos(1.31653362066 + 88.865680217*t)
	X5 += 0.00000000001*np.cos(5.40855784676 + 405.2575498736*t)
	X5 += 0.00000000001*np.cos(5.90670816840 + 654.1243803156*t)
	X5 += 0.00000000001*np.cos(3.71891583567 + 302.164775655*t)
	X5 += 0.00000000001*np.cos(4.55685868846 + 853.196381752*t)
	X5 += 0.00000000001*np.cos(3.69401301909 + 213.299095438*t)
	X5 += 0.00000000001*np.cos(5.15663977426 + 7.1135470008*t)
	X5 += 0.00000000001*np.cos(0.75807081859 + 124.433415221*t)
	X5 += 0.00000000001*np.cos(0.11340000355 + 508.3503240922*t)
	X5 += 0.00000000001*np.cos(1.08569299123 + 551.031606097*t)
	X5 += 0.00000000001*np.cos(2.74702261476 + 110.2063212194*t)
	X5 += 0.00000000001*np.cos(4.89128041335 + 860.3099287528*t)
	X5 += 0.00000000001*np.cos(0.44519622714 + 447.9388318784*t)
	return X5*t*t*t*t*t




def Sun_Y0 (t): # 1291 terms of order 0

	Y0 = 0.
	Y0 += 0.00495536218*np.cos(2.17046712634 + 529.6909650946*t)
	Y0 += 0.00272185821*np.cos(2.44443364925 + 213.299095438*t)
	Y0 += 0.00155444313*np.cos(0.59927010840 + 38.1330356378*t)
	Y0 += 0.00083755792*np.cos(0.76880164710 + 74.7815985673*t)
	Y0 += 0.00033869535
	Y0 += 0.00012011827*np.cos(2.52003147880 + 1059.3819301892*t)
	Y0 += 0.00007585830*np.cos(1.66995483217 + 426.598190876*t)
	Y0 += 0.00001963743*np.cos(5.70773655842 + 206.1855484372*t)
	Y0 += 0.00001891503*np.cos(2.32096821003 + 220.4126424388*t)
	Y0 += 0.00001940124*np.cos(3.22686130461 + 149.5631971346*t)
	Y0 += 0.00001436841*np.cos(2.30161968078 + 522.5774180938*t)
	Y0 += 0.00001405975*np.cos(5.18858607879 + 536.8045120954*t)
	Y0 += 0.00001185515*np.cos(5.48969329104 + 76.2660712756*t)
	Y0 += 0.00000813077*np.cos(1.68393442622 + 36.6485629295*t)
	Y0 += 0.00000767125*np.cos(2.65620459324 + 39.6175083461*t)
	Y0 += 0.00000628788*np.cos(4.99295631526 + 73.297125859*t)
	Y0 += 0.00000436632*np.cos(2.86969820654 + 1589.0728952838*t)
	Y0 += 0.00000382844*np.cos(3.57213982765 + 7.1135470008*t)
	Y0 += 0.00000317511*np.cos(4.53536380695 + 419.4846438752*t)
	Y0 += 0.00000309191*np.cos(0.92301535903 + 639.897286314*t)
	Y0 += 0.00000287366*np.cos(3.36314089821 + 110.2063212194*t)
	Y0 += 0.00000304013*np.cos(3.32425157103 + 6283.0758499914*t)
	Y0 += 0.00000269924*np.cos(0.29178785093 + 103.0927742186*t)
	Y0 += 0.00000213445*np.cos(4.22099738237 + 316.3918696566*t)
	Y0 += 0.00000177041*np.cos(4.74733135300 + 10213.285546211*t)
	Y0 += 0.00000138577*np.cos(0.43043981485 + 1.4844727083*t)
	Y0 += 0.00000112761*np.cos(0.85382170184 + 632.7837393132*t)
	Y0 += 0.00000105538*np.cos(1.55181188435 + 433.7117378768*t)
	Y0 += 0.00000098007*np.cos(1.45965911177 + 1052.2683831884*t)
	Y0 += 0.00000109014*np.cos(1.58735183284 + 1162.4747044078*t)
	Y0 += 0.00000069581*np.cos(5.53444845615 + 1066.49547719*t)
	Y0 += 0.00000056638*np.cos(6.03067632809 + 949.1756089698*t)
	Y0 += 0.00000066066*np.cos(4.98950696350 + 846.0828347512*t)
	Y0 += 0.00000063109*np.cos(4.22325583135 + 148.0787244263*t)
	Y0 += 0.00000063108*np.cos(5.44406082112 + 224.3447957019*t)
	Y0 += 0.00000048910*np.cos(1.49052112890 + 3340.6124266998*t)
	Y0 += 0.00000034784*np.cos(3.03113665420 + 35.1640902212*t)
	Y0 += 0.00000030366*np.cos(2.65225160596 + 11.0457002639*t)
	Y0 += 0.00000028582*np.cos(1.27599593473 + 41.1019810544*t)
	Y0 += 0.00000028733*np.cos(2.14315245629 + 151.0476698429*t)
	Y0 += 0.00000027688*np.cos(5.44433605847 + 63.7358983034*t)
	Y0 += 0.00000023815*np.cos(2.19051967809 + 227.5261894396*t)
	Y0 += 0.00000023457*np.cos(0.09576335036 + 71.8126531507*t)
	Y0 += 0.00000023256*np.cos(5.18050538435 + 85.8272988312*t)
	Y0 += 0.00000018818*np.cos(3.21978774117 + 2118.7638603784*t)
	Y0 += 0.00000022104*np.cos(2.36649230999 + 2.9689454166*t)
	Y0 += 0.00000021981*np.cos(4.82484958838 + 77.7505439839*t)
	Y0 += 0.00000020052*np.cos(2.45637769313 + 209.3669421749*t)
	Y0 += 0.00000019691*np.cos(5.58713076986 + 217.2312487011*t)
	Y0 += 0.00000015682*np.cos(3.70800811377 + 742.9900605326*t)
	Y0 += 0.00000018552*np.cos(4.31061638297 + 202.2533951741*t)
	Y0 += 0.00000018318*np.cos(1.49471267476 + 323.5054166574*t)
	Y0 += 0.00000017492*np.cos(1.45131471586 + 138.5174968707*t)
	Y0 += 0.00000015554*np.cos(1.06805925164 + 735.8765135318*t)
	Y0 += 0.00000015545*np.cos(2.44244738845 + 515.463871093*t)
	Y0 += 0.00000016381*np.cos(0.25980625854 + 853.196381752*t)
	Y0 += 0.00000011595*np.cos(5.83451477433 + 199.0720014364*t)
	Y0 += 0.00000010833*np.cos(5.05422968004 + 543.9180590962*t)
	Y0 += 0.00000011585*np.cos(5.32336141881 + 525.7588118315*t)
	Y0 += 0.00000011435*np.cos(2.15573411853 + 533.6231183577*t)
	Y0 += 0.00000007912*np.cos(0.86429104720 + 1478.8665740644*t)
	Y0 += 0.00000008319*np.cos(1.95435351055 + 1692.1656695024*t)
	Y0 += 0.00000007196*np.cos(1.94802350337 + 216.4804891757*t)
	Y0 += 0.00000007036*np.cos(6.09743344991 + 210.1177017003*t)
	Y0 += 0.00000007148*np.cos(0.89057242152 + 415.5524906121*t)
	Y0 += 0.00000006899*np.cos(2.82570489004 + 117.3198682202*t)
	Y0 += 0.00000007245*np.cos(2.48166026447 + 1265.5674786264*t)
	Y0 += 0.00000006960*np.cos(1.29290894763 + 956.2891559706*t)
	Y0 += 0.00000007569*np.cos(3.42743646666 + 14.2270940016*t)
	Y0 += 0.00000006604*np.cos(0.80525786731 + 647.0108333148*t)
	Y0 += 0.00000007374*np.cos(1.70513414627 + 1581.959348283*t)
	Y0 += 0.00000007040*np.cos(0.48482036852 + 95.9792272178*t)
	Y0 += 0.00000006330*np.cos(3.87859376833 + 70.8494453042*t)
	Y0 += 0.00000005078*np.cos(2.67641304277 + 526.5095713569*t)
	Y0 += 0.00000004977*np.cos(4.80328860665 + 532.8723588323*t)
	Y0 += 0.00000005879*np.cos(0.79782511263 + 78.7137518304*t)
	Y0 += 0.00000006300*np.cos(5.97937567752 + 26087.9031415742*t)
	Y0 += 0.00000006103*np.cos(4.10884733063 + 111.4301614968*t)
	Y0 += 0.00000004361*np.cos(5.32253972289 + 1375.7737998458*t)
	Y0 += 0.00000004423*np.cos(6.24070525621 + 277.0349937414*t)
	Y0 += 0.00000004713*np.cos(3.21489250017 + 114.3991069134*t)
	Y0 += 0.00000005182*np.cos(0.28726404719 + 222.8603229936*t)
	Y0 += 0.00000003758*np.cos(5.87986928750 + 1596.1864422846*t)
	Y0 += 0.00000004577*np.cos(5.47618219772 + 146.594251718*t)
	Y0 += 0.00000002830*np.cos(5.36742188515 + 309.2783226558*t)
	Y0 += 0.00000003761*np.cos(5.75801604585 + 490.3340891794*t)
	Y0 += 0.00000002820*np.cos(1.86334392833 + 299.1263942692*t)
	Y0 += 0.00000003425*np.cos(0.95244785238 + 351.8165923087*t)
	Y0 += 0.00000002922*np.cos(5.30505468617 + 109.9456887885*t)
	Y0 += 0.00000002471*np.cos(1.29713026645 + 625.6701923124*t)
	Y0 += 0.00000002540*np.cos(3.28107325303 + 12566.1516999828*t)
	Y0 += 0.00000002281*np.cos(1.82907071974 + 6681.2248533996*t)
	Y0 += 0.00000002269*np.cos(5.79898675704 + 3.9321532631*t)
	Y0 += 0.00000002547*np.cos(4.75277405496 + 1169.5882514086*t)
	Y0 += 0.00000002285*np.cos(1.22344285748 + 1045.1548361876*t)
	Y0 += 0.00000001913*np.cos(1.75777087654 + 1155.361157407*t)
	Y0 += 0.00000001820*np.cos(4.24734832675 + 33.6796175129*t)
	Y0 += 0.00000001649*np.cos(1.44498561983 + 440.8252848776*t)
	Y0 += 0.00000001844*np.cos(1.12596393242 + 4.4534181249*t)
	Y0 += 0.00000001439*np.cos(6.16071128287 + 942.062061969*t)
	Y0 += 0.00000001487*np.cos(4.35858219478 + 412.3710968744*t)
	Y0 += 0.00000001428*np.cos(4.17962469716 + 65.2203710117*t)
	Y0 += 0.00000001413*np.cos(0.07531190902 + 42.5864537627*t)
	Y0 += 0.00000001485*np.cos(6.11611294959 + 210.8514148832*t)
	Y0 += 0.00000001473*np.cos(1.91659379347 + 215.7467759928*t)
	Y0 += 0.00000001422*np.cos(4.41813139873 + 225.8292684102*t)
	Y0 += 0.00000001091*np.cos(1.25744389434 + 422.6660376129*t)
	Y0 += 0.00000001368*np.cos(3.55740359860 + 79.2350166922*t)
	Y0 += 0.00000001019*np.cos(5.67612773072 + 145.6310438715*t)
	Y0 += 0.00000001421*np.cos(0.83890525684 + 152.5321425512*t)
	Y0 += 0.00000001188*np.cos(1.28708061167 + 70.3281804424*t)
	Y0 += 0.00000001031*np.cos(1.65365925948 + 1795.258443721*t)
	Y0 += 0.00000000977*np.cos(0.76357046359 + 84.3428261229*t)
	Y0 += 0.00000000964*np.cos(4.63043034198 + 1272.6810256272*t)
	Y0 += 0.00000001076*np.cos(5.29118995114 + 212.3358875915*t)
	Y0 += 0.00000001071*np.cos(2.73962355675 + 214.2623032845*t)
	Y0 += 0.00000001243*np.cos(1.30343744920 + 184.7272873558*t)
	Y0 += 0.00000000891*np.cos(2.41639607024 + 213.2509113282*t)
	Y0 += 0.00000000890*np.cos(5.61419511254 + 213.3472795478*t)
	Y0 += 0.00000000891*np.cos(3.57007763083 + 2648.454825473*t)
	Y0 += 0.00000001041*np.cos(4.23685547840 + 137.0330241624*t)
	Y0 += 0.00000000968*np.cos(2.96119647882 + 437.6438911399*t)
	Y0 += 0.00000000812*np.cos(0.69907573293 + 288.0806940053*t)
	Y0 += 0.00000000819*np.cos(5.28403120371 + 529.6427809848*t)
	Y0 += 0.00000000819*np.cos(2.19867289777 + 529.7391492044*t)
	Y0 += 0.00000001037*np.cos(2.70514798372 + 527.2432845398*t)
	Y0 += 0.00000001029*np.cos(4.77626567802 + 532.1386456494*t)
	Y0 += 0.00000000859*np.cos(0.82190799976 + 74.6697239827*t)
	Y0 += 0.00000000858*np.cos(3.85737061744 + 74.8934731519*t)
	Y0 += 0.00000000776*np.cos(2.50668810243 + 203.7378678824*t)
	Y0 += 0.00000000734*np.cos(3.78800004602 + 112.9146342051*t)
	Y0 += 0.00000000711*np.cos(0.35309558162 + 628.8515860501*t)
	Y0 += 0.00000000925*np.cos(1.39948133634 + 160.6088973985*t)
	Y0 += 0.00000000663*np.cos(3.47906442185 + 1368.660252845*t)
	Y0 += 0.00000000742*np.cos(1.23961445295 + 9.5612275556*t)
	Y0 += 0.00000000647*np.cos(1.38461879483 + 2008.557539159*t)
	Y0 += 0.00000000875*np.cos(3.77647530400 + 380.12776796*t)
	Y0 += 0.00000000599*np.cos(5.62726409830 + 20426.571092422*t)
	Y0 += 0.00000000599*np.cos(1.67376937095 + 2111.6503133776*t)
	Y0 += 0.00000000619*np.cos(5.21680002932 + 430.5303441391*t)
	Y0 += 0.00000000661*np.cos(2.90920830849 + 1063.3140834523*t)
	Y0 += 0.00000000663*np.cos(2.12818812670 + 838.9692877504*t)
	Y0 += 0.00000000598*np.cos(5.09026310864 + 423.4167971383*t)
	Y0 += 0.00000000633*np.cos(1.58661078881 + 12.5301729722*t)
	Y0 += 0.00000000647*np.cos(1.86412144751 + 528.7277572481*t)
	Y0 += 0.00000000646*np.cos(5.61853780158 + 530.6541729411*t)
	Y0 += 0.00000000640*np.cos(2.74650543543 + 52175.8062831484*t)
	Y0 += 0.00000000547*np.cos(2.31713581375 + 2221.856634597*t)
	Y0 += 0.00000000541*np.cos(5.63219919123 + 1055.4497769261*t)
	Y0 += 0.00000000672*np.cos(1.51129840313 + 221.3758502853*t)
	Y0 += 0.00000000490*np.cos(1.40385202337 + 71.6002048296*t)
	Y0 += 0.00000000473*np.cos(3.26277772078 + 77.962992305*t)
	Y0 += 0.00000000648*np.cos(6.03788509546 + 22.0914005278*t)
	Y0 += 0.00000000624*np.cos(1.28974618222 + 330.6189636582*t)
	Y0 += 0.00000000653*np.cos(1.15486761496 + 388.4651552382*t)
	Y0 += 0.00000000468*np.cos(5.41054107443 + 1073.6090241908*t)
	Y0 += 0.00000000532*np.cos(1.20297674206 + 728.762966531*t)
	Y0 += 0.00000000574*np.cos(4.09850700417 + 87.3117715395*t)
	Y0 += 0.00000000604*np.cos(0.41299096165 + 984.6003316219*t)
	Y0 += 0.00000000541*np.cos(1.50869067477 + 72.3339180125*t)
	Y0 += 0.00000000468*np.cos(3.76982493207 + 212.7778305762*t)
	Y0 += 0.00000000466*np.cos(4.26202338577 + 213.8203602998*t)
	Y0 += 0.00000000419*np.cos(1.18672277137 + 429.7795846137*t)
	Y0 += 0.00000000423*np.cos(5.23795043183 + 340.7708920448*t)
	Y0 += 0.00000000462*np.cos(0.09066955654 + 860.3099287528*t)
	Y0 += 0.00000000511*np.cos(3.34354440535 + 77.2292791221*t)
	Y0 += 0.00000000491*np.cos(3.39044076994 + 3.1813937377*t)
	Y0 += 0.00000000413*np.cos(0.42041417925 + 145.1097790097*t)
	Y0 += 0.00000000336*np.cos(5.60932577353 + 127.4717966068*t)
	Y0 += 0.00000000409*np.cos(0.70233676711 + 350.3321196004*t)
	Y0 += 0.00000000383*np.cos(4.56297720194 + 909.8187330546*t)
	Y0 += 0.00000000375*np.cos(0.23620758788 + 108.4612160802*t)
	Y0 += 0.00000000313*np.cos(2.04966851954 + 234.6397364404*t)
	Y0 += 0.00000000382*np.cos(0.24418522119 + 186.2117600641*t)
	Y0 += 0.00000000288*np.cos(5.63178266285 + 1905.4647649404*t)
	Y0 += 0.00000000308*np.cos(1.11858229845 + 362.8622925726*t)
	Y0 += 0.00000000311*np.cos(2.87485251647 + 297.6419215609*t)
	Y0 += 0.00000000289*np.cos(0.35271915498 + 529.1697002328*t)
	Y0 += 0.00000000264*np.cos(2.24237848599 + 1485.9801210652*t)
	Y0 += 0.00000000289*np.cos(0.84527308658 + 530.2122299564*t)
	Y0 += 0.00000000366*np.cos(1.35412421660 + 604.4725636619*t)
	Y0 += 0.00000000282*np.cos(0.06832834990 + 62.2514255951*t)
	Y0 += 0.00000000263*np.cos(4.77643040513 + 52.6901980395*t)
	Y0 += 0.00000000257*np.cos(2.63966270921 + 1258.4539316256*t)
	Y0 += 0.00000000324*np.cos(5.37496427957 + 200.7689224658*t)
	Y0 += 0.00000000275*np.cos(6.25194576299 + 565.1156877467*t)
	Y0 += 0.00000000269*np.cos(4.90534085198 + 140.001969579*t)
	Y0 += 0.00000000321*np.cos(5.03461670419 + 703.6331846174*t)
	Y0 += 0.00000000249*np.cos(4.80534758404 + 210.3783341312*t)
	Y0 += 0.00000000248*np.cos(3.22187918056 + 216.2198567448*t)
	Y0 += 0.00000000243*np.cos(5.15609899738 + 1062.5633239269*t)
	Y0 += 0.00000000336*np.cos(6.10975677385 + 454.9093665273*t)
	Y0 += 0.00000000240*np.cos(1.67381717935 + 37.611770776*t)
	Y0 += 0.00000000237*np.cos(2.15132956903 + 212.5483359126*t)
	Y0 += 0.00000000255*np.cos(3.33122871209 + 153.4953503977*t)
	Y0 += 0.00000000236*np.cos(5.87788994285 + 214.0498549634*t)
	Y0 += 0.00000000236*np.cos(2.66792286959 + 38.6543004996*t)
	Y0 += 0.00000000252*np.cos(3.03988883560 + 209.106309744*t)
	Y0 += 0.00000000248*np.cos(4.98513016170 + 217.491881132*t)
	Y0 += 0.00000000225*np.cos(1.81041528541 + 223.5940361765*t)
	Y0 += 0.00000000224*np.cos(3.94824411240 + 38.084851528*t)
	Y0 += 0.00000000223*np.cos(0.39234241482 + 38.1812197476*t)
	Y0 += 0.00000000216*np.cos(6.22908327759 + 2125.8774073792*t)
	Y0 += 0.00000000244*np.cos(2.64604748092 + 173.9422195228*t)
	Y0 += 0.00000000234*np.cos(5.26336192114 + 74.2603337055*t)
	Y0 += 0.00000000233*np.cos(5.70130722395 + 75.3028634291*t)
	Y0 += 0.00000000247*np.cos(5.27605423414 + 252.6559713532*t)
	Y0 += 0.00000000203*np.cos(5.54978754111 + 18.1592472647*t)
	Y0 += 0.00000000282*np.cos(6.12964546434 + 563.6312150384*t)
	Y0 += 0.00000000224*np.cos(0.66388865647 + 88.865680217*t)
	Y0 += 0.00000000205*np.cos(4.98750840184 + 417.0369633204*t)
	Y0 += 0.00000000211*np.cos(3.56508711838 + 37.1698277913*t)
	Y0 += 0.00000000215*np.cos(5.07155551847 + 1699.2792165032*t)
	Y0 += 0.00000000192*np.cos(2.70968461449 + 66.70484372*t)
	Y0 += 0.00000000204*np.cos(2.47411750627 + 207.6700211455*t)
	Y0 += 0.00000000228*np.cos(3.58367417249 + 207.8824694666*t)
	Y0 += 0.00000000203*np.cos(0.77682463263 + 39.0962434843*t)
	Y0 += 0.00000000186*np.cos(2.34538148826 + 1898.3512179396*t)
	Y0 += 0.00000000220*np.cos(4.46432405157 + 218.7157214094*t)
	Y0 += 0.00000000186*np.cos(2.59788381829 + 508.3503240922*t)
	Y0 += 0.00000000195*np.cos(5.53819155539 + 218.9281697305*t)
	Y0 += 0.00000000178*np.cos(4.08297672654 + 211.8146227297*t)
	Y0 += 0.00000000224*np.cos(2.49436555659 + 1056.2005364515*t)
	Y0 += 0.00000000195*np.cos(0.90841744066 + 28.5718080822*t)
	Y0 += 0.00000000190*np.cos(4.35107066119 + 142.4496501338*t)
	Y0 += 0.00000000171*np.cos(1.38853028989 + 526.7702037878*t)
	Y0 += 0.00000000186*np.cos(5.42678326989 + 554.0699874828*t)
	Y0 += 0.00000000169*np.cos(6.09402587013 + 532.6117264014*t)
	Y0 += 0.00000000217*np.cos(2.01707572818 + 124.433415221*t)
	Y0 += 0.00000000175*np.cos(5.92248308601 + 525.4981794006*t)
	Y0 += 0.00000000160*np.cos(2.16768657112 + 10021.8372800994*t)
	Y0 += 0.00000000187*np.cos(1.52481751621 + 1574.8458012822*t)
	Y0 += 0.00000000158*np.cos(5.04734034343 + 528.9402055692*t)
	Y0 += 0.00000000169*np.cos(0.93171590629 + 1471.7530270636*t)
	Y0 += 0.00000000157*np.cos(2.43465536306 + 530.44172462*t)
	Y0 += 0.00000000188*np.cos(1.87050370857 + 569.0478410098*t)
	Y0 += 0.00000000194*np.cos(2.55166855580 + 183.2428146475*t)
	Y0 += 0.00000000199*np.cos(2.28730999946 + 1685.0521225016*t)
	Y0 += 0.00000000178*np.cos(6.20228633181 + 5.9378908332*t)
	Y0 += 0.00000000207*np.cos(0.24572465192 + 73.8183907208*t)
	Y0 += 0.00000000185*np.cos(3.34815986923 + 265.9892934775*t)
	Y0 += 0.00000000175*np.cos(5.99371438486 + 217.964961884*t)
	Y0 += 0.00000000148*np.cos(2.83101653780 + 519.3960243561*t)
	Y0 += 0.00000000146*np.cos(2.06659470489 + 82.8583534146*t)
	Y0 += 0.00000000192*np.cos(4.39395898967 + 425.1137181677*t)
	Y0 += 0.00000000149*np.cos(1.96157392100 + 414.0680179038*t)
	Y0 += 0.00000000165*np.cos(3.65136085639 + 231.4583427027*t)
	Y0 += 0.00000000201*np.cos(4.11002299299 + 453.424893819*t)
	Y0 += 0.00000000200*np.cos(4.96476307548 + 1439.5096981492*t)
	Y0 += 0.00000000140*np.cos(4.10887314023 + 408.4389436113*t)
	Y0 += 0.00000000191*np.cos(4.47590456732 + 75.7448064138*t)
	Y0 += 0.00000000149*np.cos(1.58541955295 + 533.8837507886*t)
	Y0 += 0.00000000158*np.cos(2.03821572977 + 208.633228992*t)
	Y0 += 0.00000000153*np.cos(3.42669369028 + 47.6942631934*t)
	Y0 += 0.00000000131*np.cos(6.22770537067 + 203.0041546995*t)
	Y0 += 0.00000000183*np.cos(0.59231255504 + 1021.2488945514*t)
	Y0 += 0.00000000139*np.cos(4.27354999851 + 373.9079928365*t)
	Y0 += 0.00000000139*np.cos(4.04425486837 + 214.7835681463*t)
	Y0 += 0.00000000166*np.cos(1.38695682715 + 305.3461693927*t)
	Y0 += 0.00000000130*np.cos(0.69748880175 + 654.1243803156*t)
	Y0 += 0.00000000144*np.cos(6.26381421560 + 4.192785694*t)
	Y0 += 0.00000000139*np.cos(5.93780077355 + 251.4321310758*t)
	Y0 += 0.00000000121*np.cos(3.73123340759 + 479.2883889155*t)
	Y0 += 0.00000000119*np.cos(5.90821338773 + 114.1384744825*t)
	Y0 += 0.00000000115*np.cos(4.65379442884 + 539.9859058331*t)
	Y0 += 0.00000000114*np.cos(3.22069040111 + 213.4109700226*t)
	Y0 += 0.00000000114*np.cos(4.81084790265 + 213.1872208534*t)
	Y0 += 0.00000000129*np.cos(6.17361043988 + 302.164775655*t)
	Y0 += 0.00000000116*np.cos(5.36019004356 + 524.0618908021*t)
	Y0 += 0.00000000115*np.cos(2.12419003336 + 535.3200393871*t)
	Y0 += 0.00000000126*np.cos(5.34406107671 + 540.7366653585*t)
	Y0 += 0.00000000119*np.cos(4.95824095217 + 983.1158589136*t)
	Y0 += 0.00000000115*np.cos(0.35603129387 + 98.8999885246*t)
	Y0 += 0.00000000118*np.cos(4.91950265277 + 525.0250986486*t)
	Y0 += 0.00000000102*np.cos(1.89629804705 + 56.6223513026*t)
	Y0 += 0.00000000100*np.cos(2.14566059864 + 529.851023789*t)
	Y0 += 0.00000000100*np.cos(5.33661471676 + 529.5309064002*t)
	Y0 += 0.00000000099*np.cos(0.29530316101 + 198.321241911*t)
	Y0 += 0.00000000102*np.cos(6.02433300674 + 963.4027029714*t)
	Y0 += 0.00000000109*np.cos(2.17221801259 + 175.1660598002*t)
	Y0 += 0.00000000111*np.cos(6.01414242152 + 80.1982245387*t)
	Y0 += 0.00000000096*np.cos(5.43048994495 + 213.0866471169*t)
	Y0 += 0.00000000096*np.cos(2.60104835880 + 213.5115437591*t)
	Y0 += 0.00000000099*np.cos(4.90758830995 + 551.031606097*t)
	Y0 += 0.00000000113*np.cos(1.88238867485 + 2324.9494088156*t)
	Y0 += 0.00000000111*np.cos(2.56844286864 + 534.3568315406*t)
	Y0 += 0.00000000117*np.cos(0.19396627342 + 524.2743391232*t)
	Y0 += 0.00000000095*np.cos(3.70643398698 + 327.4375699205*t)
	Y0 += 0.00000000104*np.cos(5.47404374073 + 32.1951448046*t)
	Y0 += 0.00000000127*np.cos(3.26672162678 + 21.3406410024*t)
	Y0 += 0.00000000115*np.cos(1.00365590687 + 535.107591066*t)
	Y0 += 0.00000000097*np.cos(5.79658161560 + 78263.70942472259*t)
	Y0 += 0.00000000096*np.cos(4.77567549605 + 35.685355083*t)
	Y0 += 0.00000000103*np.cos(2.84917048342 + 219.891377577*t)
	Y0 += 0.00000000091*np.cos(4.79589087629 + 1802.3719907218*t)
	Y0 += 0.00000000090*np.cos(1.60104298475 + 1382.8873468466*t)
	Y0 += 0.00000000093*np.cos(4.20565309570 + 99.1606209555*t)
	Y0 += 0.00000000087*np.cos(1.28166497839 + 228.276948965*t)
	Y0 += 0.00000000100*np.cos(1.82319423846 + 96.8729990951*t)
	Y0 += 0.00000000085*np.cos(3.63689104790 + 74.8297826771*t)
	Y0 += 0.00000000085*np.cos(1.04303023325 + 74.7334144575*t)
	Y0 += 0.00000000113*np.cos(5.85548952542 + 177.8743727859*t)
	Y0 += 0.00000000085*np.cos(5.99437376237 + 191.9584544356*t)
	Y0 += 0.00000000087*np.cos(5.84639583938 + 40.5807161926*t)
	Y0 += 0.00000000102*np.cos(4.67254721576 + 131.4039498699*t)
	Y0 += 0.00000000093*np.cos(5.77977069690 + 74.5209661364*t)
	Y0 += 0.00000000093*np.cos(5.18093640996 + 75.0422309982*t)
	Y0 += 0.00000000080*np.cos(2.87647086515 + 278.5194664497*t)
	Y0 += 0.00000000089*np.cos(1.46011729281 + 191.2076949102*t)
	Y0 += 0.00000000079*np.cos(2.74811848231 + 38.0211610532*t)
	Y0 += 0.00000000079*np.cos(1.59253269036 + 38.2449102224*t)
	Y0 += 0.00000000083*np.cos(0.78518936484 + 300.6108669775*t)
	Y0 += 0.00000000078*np.cos(5.64618149774 + 30.0562807905*t)
	Y0 += 0.00000000097*np.cos(3.75597837361 + 259.5088859231*t)
	Y0 += 0.00000000085*np.cos(5.14758347117 + 44.070926471*t)
	Y0 += 0.00000000089*np.cos(2.25592202290 + 835.0371344873*t)
	Y0 += 0.00000000076*np.cos(3.13724740029 + 106.2741679563*t)
	Y0 += 0.00000000091*np.cos(2.31009109472 + 80.7194894005*t)
	Y0 += 0.00000000075*np.cos(0.93284040810 + 205.2223405907*t)
	Y0 += 0.00000000079*np.cos(1.02058994543 + 74.6215398729*t)
	Y0 += 0.00000000078*np.cos(3.65920759701 + 74.9416572617*t)
	Y0 += 0.00000000077*np.cos(1.39895481144 + 195.1398481733*t)
	Y0 += 0.00000000072*np.cos(4.78502700351 + 213.0384630071*t)
	Y0 += 0.00000000072*np.cos(3.24651089369 + 213.5597278689*t)
	Y0 += 0.00000000096*np.cos(2.67801150530 + 483.2205421786*t)
	Y0 += 0.00000000086*np.cos(2.73735833770 + 2.4476805548*t)
	Y0 += 0.00000000095*np.cos(2.11170756015 + 248.7238180901*t)
	Y0 += 0.00000000069*np.cos(1.88886878891 + 529.4785167735*t)
	Y0 += 0.00000000069*np.cos(5.59340951305 + 529.9034134157*t)
	Y0 += 0.00000000076*np.cos(1.98904461594 + 518.6452648307*t)
	Y0 += 0.00000000066*np.cos(0.44946982323 + 635.9651330509*t)
	Y0 += 0.00000000066*np.cos(1.92154628038 + 2214.7430875962*t)
	Y0 += 0.00000000074*np.cos(2.48641792134 + 68.8437077341*t)
	Y0 += 0.00000000084*np.cos(5.41269775901 + 424.1505103212*t)
	Y0 += 0.00000000071*np.cos(1.03137133715 + 275.5505210331*t)
	Y0 += 0.00000000066*np.cos(4.46930207827 + 33.9402499438*t)
	Y0 += 0.00000000063*np.cos(1.65767004610 + 20.6069278195*t)
	Y0 += 0.00000000083*np.cos(5.09775374255 + 404.5067903482*t)
	Y0 += 0.00000000063*np.cos(2.94014383007 + 8.0767548473*t)
	Y0 += 0.00000000068*np.cos(2.22365421702 + 831.8557407496*t)
	Y0 += 0.00000000082*np.cos(5.88510225867 + 154.0166152595*t)
	Y0 += 0.00000000081*np.cos(2.12955581519 + 37.8724032069*t)
	Y0 += 0.00000000073*np.cos(5.60150844280 + 115.8835796217*t)
	Y0 += 0.00000000080*np.cos(2.21108404080 + 38.3936680687*t)
	Y0 += 0.00000000064*np.cos(4.44827566878 + 284.1485407422*t)
	Y0 += 0.00000000070*np.cos(0.48885804664 + 107.0249274817*t)
	Y0 += 0.00000000069*np.cos(0.94467164100 + 511.5317178299*t)
	Y0 += 0.00000000058*np.cos(4.95419870669 + 46.2097904851*t)
	Y0 += 0.00000000079*np.cos(4.15336422499 + 531.1754378029*t)
	Y0 += 0.00000000067*np.cos(5.81376296368 + 643.8294395771*t)
	Y0 += 0.00000000056*np.cos(6.15449621937 + 842.1506814881*t)
	Y0 += 0.00000000065*np.cos(0.26869494906 + 547.8502123593*t)
	Y0 += 0.00000000069*np.cos(3.21235031019 + 269.9214467406*t)
	Y0 += 0.00000000075*np.cos(3.14349504273 + 227.3137411185*t)
	Y0 += 0.00000000061*np.cos(4.72931440223 + 121.2520214833*t)
	Y0 += 0.00000000061*np.cos(1.41008037643 + 429.0458714308*t)
	Y0 += 0.00000000064*np.cos(2.72423324964 + 159.1244246902*t)
	Y0 += 0.00000000061*np.cos(2.23944425679 + 650.9429865779*t)
	Y0 += 0.00000000073*np.cos(3.31073272937 + 528.2064923863*t)
	Y0 += 0.00000000057*np.cos(1.89137287758 + 92.940845832*t)
	Y0 += 0.00000000068*np.cos(5.14472869299 + 219.4494345923*t)
	Y0 += 0.00000000051*np.cos(3.53345258541 + 1048.3362299253*t)
	Y0 += 0.00000000062*np.cos(4.52301275304 + 425.6349830295*t)
	Y0 += 0.00000000065*np.cos(1.17174840770 + 14.977853527*t)
	Y0 += 0.00000000058*np.cos(4.32481237367 + 72.0732855816*t)
	Y0 += 0.00000000050*np.cos(6.18510990638 + 960.2213092337*t)
	Y0 += 0.00000000055*np.cos(0.04281344157 + 42.3258213318*t)
	Y0 += 0.00000000050*np.cos(4.83446941002 + 426.6463749858*t)
	Y0 += 0.00000000049*np.cos(3.21271029936 + 514.7131115676*t)
	Y0 += 0.00000000065*np.cos(2.41337358880 + 494.2662424425*t)
	Y0 += 0.00000000067*np.cos(2.57317423197 + 618.5566453116*t)
	Y0 += 0.00000000052*np.cos(1.85871885411 + 2641.3412784722*t)
	Y0 += 0.00000000062*np.cos(6.11167050077 + 750.1036075334*t)
	Y0 += 0.00000000053*np.cos(0.86945819735 + 2428.0421830342*t)
	Y0 += 0.00000000050*np.cos(1.63663518288 + 426.5500067662*t)
	Y0 += 0.00000000047*np.cos(4.26489760399 + 544.6688186216*t)
	Y0 += 0.00000000047*np.cos(4.45256678947 + 387.2413149608*t)
	Y0 += 0.00000000055*np.cos(3.70101890767 + 81.8951455681*t)
	Y0 += 0.00000000060*np.cos(0.53980789709 + 488.8496164711*t)
	Y0 += 0.00000000064*np.cos(2.60081517768 + 1364.7280995819*t)
	Y0 += 0.00000000052*np.cos(2.81764658144 + 210.5907824523*t)
	Y0 += 0.00000000053*np.cos(2.05896623723 + 427.5613987225*t)
	Y0 += 0.00000000051*np.cos(5.21356444643 + 216.0074084237*t)
	Y0 += 0.00000000050*np.cos(3.05458837611 + 1056.9342496344*t)
	Y0 += 0.00000000049*np.cos(6.03922030861 + 501.3797894433*t)
	Y0 += 0.00000000044*np.cos(1.83359720481 + 2538.2485042536*t)
	Y0 += 0.00000000044*np.cos(3.59534331356 + 74.0308390419*t)
	Y0 += 0.00000000050*np.cos(5.77173682772 + 355.7487455718*t)
	Y0 += 0.00000000044*np.cos(1.08481523531 + 75.5323580927*t)
	Y0 += 0.00000000043*np.cos(5.70834575414 + 213.4591541324*t)
	Y0 += 0.00000000043*np.cos(2.32287306604 + 213.1390367436*t)
	Y0 += 0.00000000043*np.cos(5.47593276555 + 220.4608265486*t)
	Y0 += 0.00000000056*np.cos(1.59993474661 + 491.8185618877*t)
	Y0 += 0.00000000054*np.cos(5.39695767554 + 187.6962327724*t)
	Y0 += 0.00000000050*np.cos(3.99260483640 + 296.1574488526*t)
	Y0 += 0.00000000057*np.cos(5.35044527046 + 1061.829610744*t)
	Y0 += 0.00000000043*np.cos(3.24179066608 + 128.9562693151*t)
	Y0 += 0.00000000047*np.cos(4.95696645233 + 1279.794572628*t)
	Y0 += 0.00000000054*np.cos(2.89069416534 + 207.1487562837*t)
	Y0 += 0.00000000048*np.cos(1.44348407688 + 106.9767433719*t)
	Y0 += 0.00000000056*np.cos(3.88391523095 + 1057.8974574809*t)
	Y0 += 0.00000000047*np.cos(3.45990384746 + 679.2541622292*t)
	Y0 += 0.00000000053*np.cos(0.36365795711 + 601.7642506762*t)
	Y0 += 0.00000000045*np.cos(3.92464674406 + 3178.1457905676*t)
	Y0 += 0.00000000040*np.cos(2.54799612698 + 1059.430114299*t)
	Y0 += 0.00000000045*np.cos(3.08256873858 + 10.2949407385*t)
	Y0 += 0.00000000051*np.cos(4.18413102003 + 344.7030453079*t)
	Y0 += 0.00000000042*np.cos(2.30009534060 + 220.364458329*t)
	Y0 += 0.00000000055*np.cos(5.75395220831 + 188.9200730498*t)
	Y0 += 0.00000000053*np.cos(0.70077978084 + 67.6680515665*t)
	Y0 += 0.00000000039*np.cos(1.93706467599 + 1788.1448967202*t)
	Y0 += 0.00000000044*np.cos(4.99425187685 + 179.3588454942*t)
	Y0 += 0.00000000044*np.cos(0.26434468297 + 289.5651667136*t)
	Y0 += 0.00000000040*np.cos(4.73960650797 + 436.1594184316*t)
	Y0 += 0.00000000040*np.cos(3.26413558741 + 149.45132255*t)
	Y0 += 0.00000000047*np.cos(1.24067371450 + 1038.0412891868*t)
	Y0 += 0.00000000044*np.cos(0.82332847780 + 358.9301393095*t)
	Y0 += 0.00000000036*np.cos(1.35884346175 + 68.1893164283*t)
	Y0 += 0.00000000036*np.cos(2.69669701623 + 2751.5475996916*t)
	Y0 += 0.00000000047*np.cos(5.73121342219 + 523.5406259403*t)
	Y0 += 0.00000000036*np.cos(1.89385828446 + 59.8037450403*t)
	Y0 += 0.00000000040*np.cos(5.63337030653 + 1059.3337460794*t)
	Y0 += 0.00000000038*np.cos(4.07163115574 + 212.0270710508*t)
	Y0 += 0.00000000037*np.cos(3.95930414230 + 214.5711198252*t)
	Y0 += 0.00000000047*np.cos(0.89434277888 + 50.4025761791*t)
	Y0 += 0.00000000039*np.cos(0.73367000632 + 1514.2912967165*t)
	Y0 += 0.00000000040*np.cos(5.57904418434 + 497.4476361802*t)
	Y0 += 0.00000000035*np.cos(2.73744180385 + 672.1406152284*t)
	Y0 += 0.00000000040*np.cos(1.63699678518 + 143.6253063014*t)
	Y0 += 0.00000000036*np.cos(3.56130087049 + 1361.5467058442*t)
	Y0 += 0.00000000035*np.cos(3.08830623607 + 89.7594520943*t)
	Y0 += 0.00000000040*np.cos(0.01680612963 + 149.6750717192*t)
	Y0 += 0.00000000043*np.cos(1.35224903493 + 312.4597163935*t)
	Y0 += 0.00000000042*np.cos(1.76079418628 + 535.8413042489*t)
	Y0 += 0.00000000035*np.cos(0.17606718200 + 529.9515975255*t)
	Y0 += 0.00000000035*np.cos(1.02336134569 + 529.4303326637*t)
	Y0 += 0.00000000032*np.cos(2.54476552980 + 206.1373643274*t)
	Y0 += 0.00000000045*np.cos(5.30626896435 + 1512.8068240082*t)
	Y0 += 0.00000000043*np.cos(2.21665582542 + 237.6781178262*t)
	Y0 += 0.00000000040*np.cos(3.35479050773 + 1593.0050485469*t)
	Y0 += 0.00000000033*np.cos(2.42762603478 + 2001.4439921582*t)
	Y0 += 0.00000000034*np.cos(2.34445071844 + 522.6256022036*t)
	Y0 += 0.00000000031*np.cos(3.37478583123 + 81.3738807063*t)
	Y0 += 0.00000000031*np.cos(5.42920592130 + 522.529233984*t)
	Y0 += 0.00000000032*np.cos(3.35243256009 + 767.3690829208*t)
	Y0 += 0.00000000038*np.cos(5.10282384073 + 92.0470739547*t)
	Y0 += 0.00000000031*np.cos(6.06589927522 + 35.212274331*t)
	Y0 += 0.00000000033*np.cos(6.06643896212 + 1060.3451380357*t)
	Y0 += 0.00000000032*np.cos(3.23800955917 + 18849.2275499742*t)
	Y0 += 0.00000000033*np.cos(4.63488708885 + 5.4166259714*t)
	Y0 += 0.00000000036*np.cos(5.94088407657 + 181.0557665236*t)
	Y0 += 0.00000000031*np.cos(5.71228872293 + 206.233732547*t)
	Y0 += 0.00000000029*np.cos(5.95807433561 + 1585.1407420207*t)
	Y0 += 0.00000000029*np.cos(2.97395589358 + 426.0769260142*t)
	Y0 += 0.00000000027*np.cos(0.43069996566 + 643.0786800517*t)
	Y0 += 0.00000000034*np.cos(2.04440145216 + 245.5424243524*t)
	Y0 += 0.00000000029*np.cos(3.97759672159 + 458.8415197904*t)
	Y0 += 0.00000000027*np.cos(2.79321900732 + 113.3877149571*t)
	Y0 += 0.00000000029*np.cos(5.12998256913 + 536.7563279856*t)
	Y0 += 0.00000000026*np.cos(2.06190087041 + 536.8526962052*t)
	Y0 += 0.00000000030*np.cos(2.98025809633 + 247.2393453818*t)
	Y0 += 0.00000000031*np.cos(1.37524160449 + 567.8240007324*t)
	Y0 += 0.00000000027*np.cos(2.98857169783 + 558.0021407459*t)
	Y0 += 0.00000000033*np.cos(1.49583126452 + 885.4397106664*t)
	Y0 += 0.00000000026*np.cos(0.62593148485 + 528.4189407074*t)
	Y0 += 0.00000000033*np.cos(4.03510285925 + 68.5618234438*t)
	Y0 += 0.00000000026*np.cos(0.57312068081 + 530.9629894818*t)
	Y0 += 0.00000000025*np.cos(1.86315259104 + 144.1465711632*t)
	Y0 += 0.00000000030*np.cos(4.12682460945 + 69.1525242748*t)
	Y0 += 0.00000000031*np.cos(5.38346601432 + 235.3904959658*t)
	Y0 += 0.00000000026*np.cos(4.88440379376 + 69.3649725959*t)
	Y0 += 0.00000000024*np.cos(4.58671428072 + 41.0537969446*t)
	Y0 += 0.00000000024*np.cos(6.27647996519 + 934.9485149682*t)
	Y0 += 0.00000000026*np.cos(1.01956540442 + 746.9222137957*t)
	Y0 += 0.00000000027*np.cos(2.81184546014 + 88.7962442478*t)
	Y0 += 0.00000000024*np.cos(2.04291264310 + 54.1746707478*t)
	Y0 += 0.00000000026*np.cos(5.16330947382 + 206.706813299*t)
	Y0 += 0.00000000026*np.cos(3.48718560303 + 427.1194557378*t)
	Y0 += 0.00000000023*np.cos(3.87311020164 + 146.3818033969*t)
	Y0 += 0.00000000024*np.cos(1.35152561667 + 447.9388318784*t)
	Y0 += 0.00000000023*np.cos(4.31374933960 + 31.5407534988*t)
	Y0 += 0.00000000031*np.cos(2.21418055348 + 1058.4187223427*t)
	Y0 += 0.00000000029*np.cos(4.96198802688 + 23.5758732361*t)
	Y0 += 0.00000000023*np.cos(0.96856236499 + 523.0986829556*t)
	Y0 += 0.00000000025*np.cos(2.35513367075 + 39.3568759152*t)
	Y0 += 0.00000000023*np.cos(0.25207950257 + 14.0146456805*t)
	Y0 += 0.00000000029*np.cos(6.28195292509 + 1023.9572075371*t)
	Y0 += 0.00000000027*np.cos(1.49068438865 + 258.0244132148*t)
	Y0 += 0.00000000021*np.cos(1.44135675848 + 420.9691165835*t)
	Y0 += 0.00000000024*np.cos(3.38673660916 + 342.2553647531*t)
	Y0 += 0.00000000028*np.cos(0.32194633183 + 162.0933701068*t)
	Y0 += 0.00000000026*np.cos(5.47900878960 + 152.0108776894*t)
	Y0 += 0.00000000022*np.cos(4.68575585219 + 320.3240229197*t)
	Y0 += 0.00000000027*np.cos(0.60945244318 + 81.0013736908*t)
	Y0 += 0.00000000026*np.cos(4.75752764914 + 1158.5425511447*t)
	Y0 += 0.00000000024*np.cos(2.71292041287 + 260.9933586314*t)
	Y0 += 0.00000000022*np.cos(0.96530934897 + 337.732510659*t)
	Y0 += 0.00000000024*np.cos(1.73470580103 + 1134.1635287565*t)
	Y0 += 0.00000000023*np.cos(0.91598037938 + 4.665866446*t)
	Y0 += 0.00000000020*np.cos(1.57021274170 + 2104.5367663768*t)
	Y0 += 0.00000000021*np.cos(0.23251071113 + 536.2832472336*t)
	Y0 += 0.00000000021*np.cos(2.06391569985 + 521.6142102473*t)
	Y0 += 0.00000000023*np.cos(3.92597486873 + 391.1734682239*t)
	Y0 += 0.00000000020*np.cos(1.26511552629 + 212.0752551606*t)
	Y0 += 0.00000000020*np.cos(0.48291798671 + 214.5229357154*t)
	Y0 += 0.00000000020*np.cos(0.82904675049 + 99.9113804809*t)
	Y0 += 0.00000000022*np.cos(3.97512645943 + 621.7380390493*t)
	Y0 += 0.00000000024*np.cos(0.37655000500 + 31.019488637*t)
	Y0 += 0.00000000020*np.cos(3.96183227004 + 630.3360587584*t)
	Y0 += 0.00000000020*np.cos(1.51439029768 + 692.5874843535*t)
	Y0 += 0.00000000020*np.cos(4.83495758164 + 230.5645708254*t)
	Y0 += 0.00000000023*np.cos(1.56251814290 + 495.7507151508*t)
	Y0 += 0.00000000023*np.cos(3.81105398957 + 181.7583419392*t)
	Y0 += 0.00000000026*np.cos(5.38965597987 + 776.9303104764*t)
	Y0 += 0.00000000021*np.cos(1.23628963571 + 60.7669528868*t)
	Y0 += 0.00000000019*np.cos(3.91126145868 + 423.6774295692*t)
	Y0 += 0.00000000023*np.cos(3.16482764080 + 353.301065017*t)
	Y0 += 0.00000000019*np.cos(5.74511374097 + 1603.2999892854*t)
	Y0 += 0.00000000021*np.cos(1.90244085454 + 73.4090004436*t)
	Y0 += 0.00000000019*np.cos(1.66681958500 + 2531.1349572528*t)
	Y0 += 0.00000000020*np.cos(1.47362321872 + 211.6021744086*t)
	Y0 += 0.00000000019*np.cos(0.10308351886 + 6.1503391543*t)
	Y0 += 0.00000000020*np.cos(5.35567175214 + 372.4235201282*t)
	Y0 += 0.00000000023*np.cos(4.95211633898 + 561.934294009*t)
	Y0 += 0.00000000020*np.cos(4.03436943213 + 157.6399519819*t)
	Y0 += 0.00000000018*np.cos(6.19626793608 + 953.1077622329*t)
	Y0 += 0.00000000018*np.cos(2.56391351376 + 104351.61256629678*t)
	Y0 += 0.00000000019*np.cos(3.47582025777 + 1098.7388061044*t)
	Y0 += 0.00000000018*np.cos(4.43520040650 + 6.592282139*t)
	Y0 += 0.00000000017*np.cos(0.00246430284 + 44.7253177768*t)
	Y0 += 0.00000000023*np.cos(4.43878616883 + 916.9322800554*t)
	Y0 += 0.00000000017*np.cos(4.51884922337 + 636.7158925763*t)
	Y0 += 0.00000000017*np.cos(1.69909042950 + 184.9879197867*t)
	Y0 += 0.00000000019*np.cos(4.99623549098 + 7.4223635415*t)
	Y0 += 0.00000000018*np.cos(2.31152779617 + 32.2433289144*t)
	Y0 += 0.00000000017*np.cos(1.25157436898 + 152.7445908723*t)
	Y0 += 0.00000000020*np.cos(1.75617954135 + 696.5196376166*t)
	Y0 += 0.00000000017*np.cos(5.49705406575 + 526.9826521089*t)
	Y0 += 0.00000000016*np.cos(1.56945304094 + 267.4737661858*t)
	Y0 += 0.00000000017*np.cos(3.55351176831 + 600.5404103988*t)
	Y0 += 0.00000000017*np.cos(2.31154641456 + 182.279606801*t)
	Y0 += 0.00000000022*np.cos(1.53237346528 + 6.2197751235*t)
	Y0 += 0.00000000021*np.cos(2.71350199726 + 286.596221297*t)
	Y0 += 0.00000000017*np.cos(5.42837245904 + 537.7677199419*t)
	Y0 += 0.00000000020*np.cos(1.57340365568 + 1166.4068576709*t)
	Y0 += 0.00000000017*np.cos(0.68412522074 + 2744.4340526908*t)
	Y0 += 0.00000000019*np.cos(4.13175891930 + 220.9339073006*t)
	Y0 += 0.00000000019*np.cos(5.65622064409 + 778.4147831847*t)
	Y0 += 0.00000000016*np.cos(5.80893325127 + 2435.155730035*t)
	Y0 += 0.00000000021*np.cos(4.02549892208 + 141.4864422873*t)
	Y0 += 0.00000000016*np.cos(1.06850165415 + 436.8931316145*t)
	Y0 += 0.00000000016*np.cos(0.62904330584 + 319.5732633943*t)
	Y0 += 0.00000000016*np.cos(0.38882783166 + 5.6290742925*t)
	Y0 += 0.00000000017*np.cos(0.26609772175 + 214.9960164674*t)
	Y0 += 0.00000000015*np.cos(1.77611950715 + 1049.0869894507*t)
	Y0 += 0.00000000016*np.cos(5.41922843655 + 2228.9701815978*t)
	Y0 += 0.00000000015*np.cos(1.44946241177 + 627.3671133418*t)
	Y0 += 0.00000000018*np.cos(6.18538776686 + 576.1613880106*t)
	Y0 += 0.00000000016*np.cos(2.01756151519 + 312.1990839626*t)
	Y0 += 0.00000000020*np.cos(2.43269100690 + 505.3119427064*t)
	Y0 += 0.00000000017*np.cos(2.29578624620 + 273.1028404783*t)
	Y0 += 0.00000000018*np.cos(5.32449106801 + 1969.2006632438*t)
	Y0 += 0.00000000019*np.cos(6.09825025640 + 760.25553592*t)
	Y0 += 0.00000000015*np.cos(5.61342452402 + 491.5579294568*t)
	Y0 += 0.00000000016*np.cos(3.55570458351 + 95.3885263868*t)
	Y0 += 0.00000000017*np.cos(3.94668990411 + 0.9632078465*t)
	Y0 += 0.00000000017*np.cos(0.27209841055 + 221.1634019642*t)
	Y0 += 0.00000000015*np.cos(2.00349398121 + 532.3992780803*t)
	Y0 += 0.00000000017*np.cos(4.97483387876 + 416.3032501375*t)
	Y0 += 0.00000000015*np.cos(2.54331959767 + 988.532484885*t)
	Y0 += 0.00000000015*np.cos(3.69020943763 + 731.9443602687*t)
	Y0 += 0.00000000016*np.cos(4.67719181508 + 2.9207613068*t)
	Y0 += 0.00000000018*np.cos(1.00894858228 + 421.93232443*t)
	Y0 += 0.00000000015*np.cos(0.98715474942 + 292.0128472684*t)
	Y0 += 0.00000000014*np.cos(3.48141058348 + 7.065362891*t)
	Y0 += 0.00000000014*np.cos(0.44059222370 + 211.8628068395*t)
	Y0 += 0.00000000014*np.cos(1.30744128930 + 214.7353840365*t)
	Y0 += 0.00000000016*np.cos(5.04374358810 + 73.1852512744*t)
	Y0 += 0.00000000014*np.cos(6.14971506999 + 241.6102710893*t)
	Y0 += 0.00000000015*np.cos(2.86446650235 + 444.7574381407*t)
	Y0 += 0.00000000014*np.cos(2.42647496893 + 2317.8358618148*t)
	Y0 += 0.00000000014*np.cos(0.70147362527 + 1058.8606653274*t)
	Y0 += 0.00000000014*np.cos(5.66142782541 + 282.4516197128*t)
	Y0 += 0.00000000014*np.cos(0.14477892919 + 1070.4276304531*t)
	Y0 += 0.00000000018*np.cos(2.31049190433 + 523.4711899711*t)
	Y0 += 0.00000000014*np.cos(3.08712252242 + 135.5485514541*t)
	Y0 += 0.00000000018*np.cos(5.17633752146 + 535.9107402181*t)
	Y0 += 0.00000000014*np.cos(1.96375670227 + 219.6618829134*t)
	Y0 += 0.00000000016*np.cos(4.11900515617 + 418.5214360287*t)
	Y0 += 0.00000000017*np.cos(1.90617951181 + 439.1283638482*t)
	Y0 += 0.00000000013*np.cos(1.61003658474 + 27.0873353739*t)
	Y0 += 0.00000000018*np.cos(3.71589155069 + 45.2465826386*t)
	Y0 += 0.00000000014*np.cos(4.21557167873 + 430.79097657*t)
	Y0 += 0.00000000018*np.cos(0.25726617504 + 1151.4290041439*t)
	Y0 += 0.00000000013*np.cos(1.39924383122 + 425.8474313506*t)
	Y0 += 0.00000000014*np.cos(2.43371472113 + 429.5189521828*t)
	Y0 += 0.00000000017*np.cos(4.36239429201 + 347.8844390456*t)
	Y0 += 0.00000000013*np.cos(5.06401541079 + 617.8058857862*t)
	Y0 += 0.00000000013*np.cos(0.04661077494 + 339.2864193365*t)
	Y0 += 0.00000000014*np.cos(3.25137938878 + 2015.6710861598*t)
	Y0 += 0.00000000014*np.cos(2.46383671446 + 35.4247226521*t)
	Y0 += 0.00000000013*np.cos(2.63747376701 + 1585.8915015461*t)
	Y0 += 0.00000000015*np.cos(0.38582816164 + 199.2844497575*t)
	Y0 += 0.00000000016*np.cos(3.65694985324 + 638.4128136057*t)
	Y0 += 0.00000000014*np.cos(6.00616793883 + 192.6921676185*t)
	Y0 += 0.00000000014*np.cos(0.09396317091 + 166.828672522*t)
	Y0 += 0.00000000013*np.cos(5.17736473658 + 498.6714764576*t)
	Y0 += 0.00000000013*np.cos(5.50576363446 + 1592.2542890215*t)
	Y0 += 0.00000000015*np.cos(2.64799753677 + 945.2434557067*t)
	Y0 += 0.00000000012*np.cos(2.17299880235 + 421.1815649046*t)
	Y0 += 0.00000000014*np.cos(4.87931858618 + 36.7604375141*t)
	Y0 += 0.00000000013*np.cos(0.30717055378 + 2655.5683724738*t)
	Y0 += 0.00000000012*np.cos(2.38062047657 + 598.8434893694*t)
	Y0 += 0.00000000013*np.cos(2.50540068014 + 13362.4497067992*t)
	Y0 += 0.00000000014*np.cos(0.37482179977 + 7.1617311106*t)
	Y0 += 0.00000000014*np.cos(0.92860467846 + 1550.939859646*t)
	Y0 += 0.00000000012*np.cos(1.77909600497 + 46.470422916*t)
	Y0 += 0.00000000015*np.cos(1.32940629775 + 205.4347889118*t)
	Y0 += 0.00000000012*np.cos(4.77187228430 + 938.1299087059*t)
	Y0 += 0.00000000014*np.cos(3.94138074971 + 147.1155165798*t)
	Y0 += 0.00000000014*np.cos(5.69803666962 + 39.5056337615*t)
	Y0 += 0.00000000015*np.cos(0.22782971575 + 1289.9465010146*t)
	Y0 += 0.00000000012*np.cos(3.63916581155 + 24.3790223882*t)
	Y0 += 0.00000000012*np.cos(2.47711415015 + 597.3590166611*t)
	Y0 += 0.00000000012*np.cos(4.38568792647 + 527.9940440652*t)
	Y0 += 0.00000000012*np.cos(3.09659037549 + 531.387886124*t)
	Y0 += 0.00000000012*np.cos(2.33536001070 + 560.7104537316*t)
	Y0 += 0.00000000011*np.cos(5.60694561960 + 244.318584075*t)
	Y0 += 0.00000000013*np.cos(3.89614170159 + 205.6642835754*t)
	Y0 += 0.00000000011*np.cos(1.80047192955 + 33.1371007917*t)
	Y0 += 0.00000000014*np.cos(1.19670750106 + 1059.903195051*t)
	Y0 += 0.00000000015*np.cos(0.46435508259 + 150.5264049811*t)
	Y0 += 0.00000000013*np.cos(4.66605634483 + 432.2272651685*t)
	Y0 += 0.00000000011*np.cos(5.60057273842 + 210.3301500214*t)
	Y0 += 0.00000000011*np.cos(3.81513615951 + 608.404716925*t)
	Y0 += 0.00000000012*np.cos(0.73222820933 + 120.9913890524*t)
	Y0 += 0.00000000011*np.cos(3.19330091388 + 528.2546764961*t)
	Y0 += 0.00000000011*np.cos(4.28897738808 + 531.1272536931*t)
	Y0 += 0.00000000011*np.cos(6.07804682582 + 206.9363079626*t)
	Y0 += 0.00000000011*np.cos(2.46888718235 + 1148.2476104062*t)
	Y0 += 0.00000000011*np.cos(5.94501754776 + 51.2057253312*t)
	Y0 += 0.00000000010*np.cos(5.23866808164 + 427.3489504014*t)
	Y0 += 0.00000000011*np.cos(1.86995093557 + 150.0844619964*t)
	Y0 += 0.00000000014*np.cos(4.86804065893 + 378.6432952517*t)
	Y0 += 0.00000000013*np.cos(3.59748191688 + 428.0826635843*t)
	Y0 += 0.00000000011*np.cos(1.28291000987 + 209.1544938538*t)
	Y0 += 0.00000000010*np.cos(1.36138347225 + 629.6023455755*t)
	Y0 += 0.00000000010*np.cos(0.40978579418 + 125.9873238985*t)
	Y0 += 0.00000000010*np.cos(5.79679358031 + 415.2918581812*t)
	Y0 += 0.00000000014*np.cos(6.15362111420 + 1173.5204046717*t)
	Y0 += 0.00000000013*np.cos(2.40937624104 + 212.4053235607*t)
	Y0 += 0.00000000013*np.cos(5.62184257913 + 214.1928673153*t)
	Y0 += 0.00000000010*np.cos(2.80479558635 + 605.9570363702*t)
	Y0 += 0.00000000010*np.cos(2.56668543311 + 1891.2376709388*t)
	Y0 += 0.00000000010*np.cos(6.22635612142 + 867.4234757536*t)
	Y0 += 0.00000000013*np.cos(5.94179661012 + 1041.2226829245*t)
	Y0 += 0.00000000010*np.cos(0.45068933139 + 217.4436970222*t)
	Y0 += 0.00000000010*np.cos(3.15383743619 + 181.806526049*t)
	Y0 += 0.00000000010*np.cos(4.07002674149 + 405.2575498736*t)
	Y0 += 0.00000000012*np.cos(5.84786866785 + 381.6122406683*t)
	Y0 += 0.00000000009*np.cos(2.09284564023 + 1159.2933106701*t)
	Y0 += 0.00000000010*np.cos(2.22671529337 + 333.657345044*t)
	Y0 += 0.00000000010*np.cos(2.31187236025 + 546.956440482*t)
	Y0 += 0.00000000010*np.cos(5.25684077542 + 431.264057322*t)
	Y0 += 0.00000000012*np.cos(1.61460398653 + 738.7972748386*t)
	Y0 += 0.00000000010*np.cos(5.40123990345 + 460.5384408198*t)
	Y0 += 0.00000000010*np.cos(0.14404716850 + 155.7829722581*t)
	Y0 += 0.00000000012*np.cos(3.14924236088 + 450.9772132642*t)
	Y0 += 0.00000000009*np.cos(4.03213133235 + 528.4671248172*t)
	Y0 += 0.00000000011*np.cos(2.88621334050 + 28.3111756513*t)
	Y0 += 0.00000000009*np.cos(4.19555404950 + 1165.6560981455*t)
	Y0 += 0.00000000008*np.cos(3.46097740255 + 530.914805372*t)
	Y0 += 0.00000000009*np.cos(0.04637931204 + 69.6737891366*t)
	Y0 += 0.00000000009*np.cos(5.40753282752 + 754.0357607965*t)
	Y0 += 0.00000000012*np.cos(1.38537383177 + 721.6494195302*t)
	Y0 += 0.00000000009*np.cos(4.19100388815 + 0.5212648618*t)
	Y0 += 0.00000000012*np.cos(3.43831701560 + 134.5853436076*t)
	Y0 += 0.00000000009*np.cos(4.72240285304 + 465.9550667912*t)
	Y0 += 0.00000000009*np.cos(3.70709245487 + 280.9671470045*t)
	Y0 += 0.00000000008*np.cos(1.46946168036 + 131.5469622218*t)
	Y0 += 0.00000000008*np.cos(1.73516019806 + 1056.4611688824*t)
	Y0 += 0.00000000010*np.cos(0.06865542606 + 448.6895914038*t)
	Y0 += 0.00000000008*np.cos(1.72917243692 + 192.8522263129*t)
	Y0 += 0.00000000008*np.cos(4.46770744193 + 361.3778198643*t)
	Y0 += 0.00000000008*np.cos(3.26923868189 + 405.9912630565*t)
	Y0 += 0.00000000011*np.cos(0.11612223196 + 1020.025054274*t)
	Y0 += 0.00000000008*np.cos(4.92087563189 + 313.2104759189*t)
	Y0 += 0.00000000010*np.cos(4.32768014997 + 189.1807054807*t)
	Y0 += 0.00000000008*np.cos(4.67907344342 + 79.889407998*t)
	Y0 += 0.00000000008*np.cos(5.04946311938 + 464.7312265138*t)
	Y0 += 0.00000000009*np.cos(1.71810953684 + 36.5366883449*t)
	Y0 += 0.00000000008*np.cos(4.84240352586 + 244.791664827*t)
	Y0 += 0.00000000010*np.cos(4.41832107849 + 381.3516082374*t)
	Y0 += 0.00000000010*np.cos(2.20742015711 + 530.5847369719*t)
	Y0 += 0.00000000010*np.cos(5.27485814485 + 528.7971932173*t)
	Y0 += 0.00000000008*np.cos(5.39721379669 + 1058.6311706638*t)
	Y0 += 0.00000000009*np.cos(2.73227763941 + 29.2049475286*t)
	Y0 += 0.00000000008*np.cos(4.63518203907 + 411.620337349*t)
	Y0 += 0.00000000009*np.cos(2.19295323979 + 103.3534066495*t)
	Y0 += 0.00000000008*np.cos(5.18381379645 + 462.0229135281*t)
	Y0 += 0.00000000008*np.cos(2.79749742555 + 422.405405182*t)
	Y0 += 0.00000000008*np.cos(3.32979544985 + 533.8355666788*t)
	Y0 += 0.00000000009*np.cos(2.69655297859 + 39.7293829307*t)
	Y0 += 0.00000000007*np.cos(3.32680253166 + 521.8266585684*t)
	Y0 += 0.00000000009*np.cos(1.06248243670 + 395.578702239*t)
	Y0 += 0.00000000009*np.cos(4.89300038136 + 710.7467316182*t)
	Y0 += 0.00000000008*np.cos(4.18600288174 + 525.5463635104*t)
	Y0 += 0.00000000010*np.cos(1.91529997720 + 259.769518354*t)
	Y0 += 0.00000000007*np.cos(4.15570065598 + 537.5552716208*t)
	Y0 += 0.00000000007*np.cos(0.01886158971 + 233.7459645631*t)
	Y0 += 0.00000000009*np.cos(3.91753991774 + 218.4069048687*t)
	Y0 += 0.00000000008*np.cos(0.15958851658 + 1062.302691496*t)
	Y0 += 0.00000000009*np.cos(3.13387610584 + 556.5176680376*t)
	Y0 += 0.00000000007*np.cos(1.95813917019 + 1064.7985561606*t)
	Y0 += 0.00000000007*np.cos(1.93378768698 + 1063.5747158832*t)
	Y0 += 0.00000000007*np.cos(3.27297531111 + 412.5835451955*t)
	Y0 += 0.00000000009*np.cos(1.25976113938 + 2957.7331481288*t)
	Y0 += 0.00000000009*np.cos(2.68780752055 + 148.5999892881*t)
	Y0 += 0.00000000008*np.cos(2.78415263682 + 1060.1326897146*t)
	Y0 += 0.00000000007*np.cos(2.61068773535 + 216.2680408546*t)
	Y0 += 0.00000000010*np.cos(4.95742849118 + 456.3938392356*t)
	Y0 += 0.00000000008*np.cos(3.05834752866 + 329.7251917809*t)
	Y0 += 0.00000000007*np.cos(1.74393304100 + 420.4478517217*t)
	Y0 += 0.00000000007*np.cos(3.06771631981 + 19.1224551112*t)
	Y0 += 0.00000000008*np.cos(0.32773950650 + 214.9436268407*t)
	Y0 += 0.00000000008*np.cos(1.42029400650 + 211.6545640353*t)
	Y0 += 0.00000000008*np.cos(1.46996458441 + 149.0419322728*t)
	Y0 += 0.00000000008*np.cos(3.84046364591 + 116.4260963429*t)
	Y0 += 0.00000000007*np.cos(5.43372978042 + 229.9738699944*t)
	Y0 += 0.00000000009*np.cos(4.16665868672 + 1201.831580323*t)
	Y0 += 0.00000000007*np.cos(1.97658084158 + 212.4959462859*t)
	Y0 += 0.00000000007*np.cos(6.05463797860 + 214.1022445901*t)
	Y0 += 0.00000000008*np.cos(0.85401055465 + 73.88782669*t)
	Y0 += 0.00000000008*np.cos(3.82539188135 + 75.6753704446*t)
	Y0 += 0.00000000008*np.cos(2.15142736957 + 49.1787359017*t)
	Y0 += 0.00000000009*np.cos(2.31949929685 + 2854.6403739102*t)
	Y0 += 0.00000000008*np.cos(2.98103710968 + 41.6444977756*t)
	Y0 += 0.00000000008*np.cos(5.05063897472 + 2332.0629558164*t)
	Y0 += 0.00000000007*np.cos(3.50267459549 + 100.3844612329*t)
	Y0 += 0.00000000007*np.cos(1.39940681150 + 2847.5268269094*t)
	Y0 += 0.00000000007*np.cos(2.29089037502 + 154.979823106*t)
	Y0 += 0.00000000008*np.cos(6.03076773173 + 0.7507595254*t)
	Y0 += 0.00000000006*np.cos(5.29793183943 + 7.6348118626*t)
	Y0 += 0.00000000006*np.cos(4.33898289564 + 1054.7160637432*t)
	Y0 += 0.00000000007*np.cos(2.21667984430 + 952.3570027075*t)
	Y0 += 0.00000000006*np.cos(4.41633931314 + 357.4456666012*t)
	Y0 += 0.00000000007*np.cos(1.57131024362 + 294.6729761443*t)
	Y0 += 0.00000000006*np.cos(0.39345391900 + 37.9205873167*t)
	Y0 += 0.00000000007*np.cos(5.37764563731 + 36.8610112506*t)
	Y0 += 0.00000000006*np.cos(3.96294945086 + 38.3454839589*t)
	Y0 += 0.00000000006*np.cos(4.05963533879 + 426.4863162914*t)
	Y0 += 0.00000000006*np.cos(3.06727638129 + 33.0252262071*t)
	Y0 += 0.00000000006*np.cos(2.04032164082 + 1912.5783119412*t)
	Y0 += 0.00000000009*np.cos(2.53138734107 + 602.9880909536*t)
	Y0 += 0.00000000007*np.cos(4.45371648459 + 264.5048207692*t)
	Y0 += 0.00000000006*np.cos(3.94156942560 + 857.1285350151*t)
	Y0 += 0.00000000006*np.cos(0.85484505811 + 81.7521332162*t)
	Y0 += 0.00000000007*np.cos(2.89403815639 + 207.0793203145*t)
	Y0 += 0.00000000006*np.cos(4.68519638634 + 57.255490749*t)
	Y0 += 0.00000000006*np.cos(4.77751420257 + 224.6054281328*t)
	Y0 += 0.00000000006*np.cos(0.44574132526 + 40.8413486235*t)
	Y0 += 0.00000000007*np.cos(0.21140156839 + 945.9942152321*t)
	Y0 += 0.00000000006*np.cos(2.46947783725 + 426.7100654606*t)
	Y0 += 0.00000000007*np.cos(4.57368950238 + 1060.8664028975*t)
	Y0 += 0.00000000007*np.cos(3.37399536314 + 3337.0893083508*t)
	Y0 += 0.00000000007*np.cos(2.74863508294 + 3344.1355450488*t)
	Y0 += 0.00000000006*np.cos(3.10055471072 + 223.3334037456*t)
	Y0 += 0.00000000006*np.cos(5.12204822125 + 219.5188705615*t)
	Y0 += 0.00000000006*np.cos(5.24513134042 + 39.405060025*t)
	Y0 += 0.00000000008*np.cos(2.53065731568 + 76.154196691*t)
	Y0 += 0.00000000006*np.cos(1.96645231708 + 1035.002907801*t)
	Y0 += 0.00000000006*np.cos(0.86486901616 + 241.8709035202*t)
	Y0 += 0.00000000007*np.cos(0.22818174779 + 849.2642284889*t)
	Y0 += 0.00000000006*np.cos(3.63430070900 + 392.6579409322*t)
	Y0 += 0.00000000006*np.cos(5.36826892088 + 402.2191684878*t)
	Y0 += 0.00000000006*np.cos(1.71954777094 + 457.617679513*t)
	Y0 += 0.00000000006*np.cos(5.56251980409 + 156.1554792736*t)
	Y0 += 0.00000000006*np.cos(3.77873797012 + 531.3354964973*t)
	Y0 += 0.00000000006*np.cos(3.70354033184 + 528.0464336919*t)
	Y0 += 0.00000000006*np.cos(2.61327362115 + 120.358249606*t)
	Y0 += 0.00000000006*np.cos(1.42537638849 + 76.4785195967*t)
	Y0 += 0.00000000006*np.cos(0.43627502894 + 30.7106720963*t)
	Y0 += 0.00000000007*np.cos(1.09433571082 + 82.2039621088*t)
	Y0 += 0.00000000007*np.cos(6.23226532477 + 1055.1891444952*t)
	Y0 += 0.00000000006*np.cos(6.12459912861 + 498.1983957056*t)
	Y0 += 0.00000000006*np.cos(2.42617941492 + 1276.6131788903*t)
	Y0 += 0.00000000006*np.cos(5.00298394883 + 156.6767441354*t)
	Y0 += 0.00000000006*np.cos(0.54499619759 + 162.8965192589*t)
	Y0 += 0.00000000006*np.cos(4.00320905630 + 343.2185725996*t)
	Y0 += 0.00000000006*np.cos(1.75008991191 + 130.4407420234*t)
	Y0 += 0.00000000006*np.cos(6.20575790615 + 334.2904844904*t)
	Y0 += 0.00000000007*np.cos(1.26011578705 + 129.9194771616*t)
	Y0 += 0.00000000007*np.cos(1.67958887971 + 480.7728616238*t)
	Y0 += 0.00000000005*np.cos(2.87874618735 + 1251.3403846248*t)
	Y0 += 0.00000000005*np.cos(4.40527085788 + 513.2286388593*t)
	Y0 += 0.00000000005*np.cos(4.12994130638 + 432.0148168474*t)
	Y0 += 0.00000000005*np.cos(2.07525052037 + 2634.2277314714*t)
	Y0 += 0.00000000005*np.cos(1.84983579495 + 426.8106391971*t)
	Y0 += 0.00000000005*np.cos(4.67927738109 + 426.3857425549*t)
	Y0 += 0.00000000005*np.cos(1.22418687439 + 810.6581120991*t)
	Y0 += 0.00000000005*np.cos(3.65053466527 + 486.4019359163*t)
	Y0 += 0.00000000005*np.cos(0.03793556312 + 1091.6252591036*t)
	Y0 += 0.00000000005*np.cos(3.16523175807 + 1677.9385755008*t)
	Y0 += 0.00000000006*np.cos(0.54424275059 + 1053.9653042178*t)
	Y0 += 0.00000000006*np.cos(3.93503423364 + 45.5553991793*t)
	Y0 += 0.00000000006*np.cos(2.77886758144 + 555.5544601911*t)
	Y0 += 0.00000000007*np.cos(0.32836306040 + 707.5653378805*t)
	Y0 += 0.00000000006*np.cos(2.77453457915 + 61.448276443*t)
	Y0 += 0.00000000006*np.cos(2.65718513722 + 105.4922706636*t)
	Y0 += 0.00000000005*np.cos(2.91666423856 + 1064.0477966352*t)
	Y0 += 0.00000000005*np.cos(5.75232137659 + 1176.7017984094*t)
	Y0 += 0.00000000005*np.cos(3.07700731231 + 546.1532913299*t)
	Y0 += 0.00000000006*np.cos(4.84262159998 + 905.8865797915*t)
	Y0 += 0.00000000007*np.cos(1.28065014879 + 739.8086667949*t)
	Y0 += 0.00000000005*np.cos(1.95177657961 + 45.5766510387*t)
	Y0 += 0.00000000005*np.cos(2.36606388404 + 112.6540017742*t)
	Y0 += 0.00000000006*np.cos(0.43877853444 + 306.830642101*t)
	Y0 += 0.00000000005*np.cos(0.45194596155 + 3060.8259223474*t)
	Y0 += 0.00000000006*np.cos(4.80275465774 + 175.4266922311*t)
	Y0 += 0.00000000005*np.cos(4.27804958023 + 850.0149880143*t)
	Y0 += 0.00000000005*np.cos(0.11172244091 + 92.3077063856*t)
	Y0 += 0.00000000005*np.cos(1.23903018931 + 43.2408450685*t)
	Y0 += 0.00000000005*np.cos(2.95228726274 + 831.1049812242*t)
	Y0 += 0.00000000006*np.cos(2.89014633398 + 240.3864308119*t)
	Y0 += 0.00000000005*np.cos(1.75462037643 + 79.4474650133*t)
	Y0 += 0.00000000006*np.cos(4.68867443457 + 1053.7528558967*t)
	Y0 += 0.00000000007*np.cos(5.73085786268 + 141.2258098564*t)
	Y0 += 0.00000000005*np.cos(1.53838601581 + 230.7075831773*t)
	Y0 += 0.00000000005*np.cos(5.68585738307 + 1059.2218714948*t)
	Y0 += 0.00000000005*np.cos(4.66068869017 + 419.532827985*t)
	Y0 += 0.00000000005*np.cos(1.38371746998 + 199.9657733137*t)
	Y0 += 0.00000000006*np.cos(1.10531583980 + 42.5382696529*t)
	Y0 += 0.00000000005*np.cos(4.78693057512 + 477.8039162072*t)
	Y0 += 0.00000000005*np.cos(1.96712978699 + 88.1149206916*t)
	Y0 += 0.00000000005*np.cos(0.27963845276 + 552.5855147745*t)
	Y0 += 0.00000000005*np.cos(1.14824029811 + 263.7016716171*t)
	Y0 += 0.00000000006*np.cos(5.63323977459 + 423.6292454594*t)
	Y0 += 0.00000000005*np.cos(1.29581999755 + 254.9435932136*t)
	Y0 += 0.00000000005*np.cos(1.95397343376 + 469.8872200543*t)
	Y0 += 0.00000000005*np.cos(0.62939525517 + 107.7586406646*t)
	Y0 += 0.00000000005*np.cos(1.99404230729 + 66.9172920411*t)
	Y0 += 0.00000000005*np.cos(3.24249864256 + 375.3924655448*t)
	Y0 += 0.00000000005*np.cos(5.34846050308 + 171.6545976624*t)
	Y0 += 0.00000000005*np.cos(2.06621135712 + 6279.5527316424*t)
	Y0 += 0.00000000005*np.cos(1.44073593407 + 6286.5989683404*t)
	Y0 += 0.00000000006*np.cos(4.94169220322 + 206.3979967583*t)
	Y0 += 0.00000000006*np.cos(2.82796912730 + 256.5399405065*t)
	Y0 += 0.00000000006*np.cos(5.63575606894 + 908.3342603463*t)
	Y0 += 0.00000000006*np.cos(4.67979511902 + 155.5010879678*t)
	Y0 += 0.00000000005*np.cos(3.71793644532 + 67.3592350258*t)
	Y0 += 0.00000000005*np.cos(2.49550905044 + 1059.5419888836*t)
	Y0 += 0.00000000005*np.cos(3.24017992541 + 54.3347294422*t)
	Y0 += 0.00000000005*np.cos(5.87095870265 + 1493.093668066*t)
	Y0 += 0.00000000006*np.cos(5.38294343974 + 512.4254897072*t)
	Y0 += 0.00000000005*np.cos(1.95584308803 + 285.3723810196*t)
	Y0 += 0.00000000005*np.cos(4.98985796917 + 1069.6768709277*t)
	Y0 += 0.00000000004*np.cos(0.23180542080 + 295.0512286542*t)
	Y0 += 0.00000000004*np.cos(4.68477590546 + 220.3007678542*t)
	Y0 += 0.00000000004*np.cos(0.07779353591 + 36.4361146084*t)
	Y0 += 0.00000000005*np.cos(0.35635469026 + 226.6324175623*t)
	Y0 += 0.00000000006*np.cos(6.11086179074 + 31.492569389*t)
	Y0 += 0.00000000004*np.cos(4.70847901375 + 211.2933578679*t)
	Y0 += 0.00000000004*np.cos(3.32273980643 + 215.3048330081*t)
	Y0 += 0.00000000005*np.cos(3.33007728324 + 220.2001941177*t)
	Y0 += 0.00000000005*np.cos(4.64353655079 + 637.4496057592*t)
	Y0 += 0.00000000005*np.cos(3.08811796544 + 512.2824773553*t)
	Y0 += 0.00000000004*np.cos(4.62155469575 + 509.2440959695*t)
	Y0 += 0.00000000005*np.cos(0.05776010630 + 364.3467652809*t)
	Y0 += 0.00000000004*np.cos(1.20032881219 + 642.3449668688*t)
	Y0 += 0.00000000006*np.cos(1.57410775703 + 593.426863398*t)
	Y0 += 0.00000000005*np.cos(4.48756352642 + 199.8057146193*t)
	Y0 += 0.00000000004*np.cos(2.87324956196 + 550.1378342197*t)
	Y0 += 0.00000000005*np.cos(4.24468533160 + 203.8979265768*t)
	Y0 += 0.00000000005*np.cos(2.00362741907 + 233.9060232575*t)
	Y0 += 0.00000000005*np.cos(6.10787864510 + 724.8308132679*t)
	Y0 += 0.00000000005*np.cos(1.47578911718 + 419.4364597654*t)
	Y0 += 0.00000000005*np.cos(1.88450516703 + 409.9234163196*t)
	Y0 += 0.00000000004*np.cos(4.26279371314 + 39.8299566672*t)
	Y0 += 0.00000000004*np.cos(5.27754931678 + 1080.7225711916*t)
	Y0 += 0.00000000005*np.cos(0.74020210751 + 98.3574718034*t)
	Y0 += 0.00000000004*np.cos(3.39498045153 + 195.7729876197*t)
	Y0 += 0.00000000005*np.cos(2.51647214808 + 980.6681783588*t)
	Y0 += 0.00000000005*np.cos(3.59781478063 + 668.2084619653*t)
	Y0 += 0.00000000004*np.cos(4.04095166158 + 1127.0499817557*t)
	Y0 += 0.00000000005*np.cos(3.75866179788 + 172.4577468145*t)
	Y0 += 0.00000000005*np.cos(5.78187789560 + 302.0953396858*t)
	Y0 += 0.00000000005*np.cos(4.51160719825 + 348.8476468921*t)
	Y0 += 0.00000000004*np.cos(3.78574244699 + 222.7002642992*t)
	Y0 += 0.00000000004*np.cos(2.49529855865 + 426.8588233069*t)
	Y0 += 0.00000000004*np.cos(1.03273332059 + 441.576044403*t)
	Y0 += 0.00000000004*np.cos(4.94416760472 + 93.9040536785*t)
	Y0 += 0.00000000004*np.cos(4.03381466848 + 426.3375584451*t)
	Y0 += 0.00000000004*np.cos(4.71644896302 + 230.8252032563*t)
	Y0 += 0.00000000004*np.cos(1.95799618639 + 149.3025647037*t)
	Y0 += 0.00000000005*np.cos(1.54458129421 + 170.0100662597*t)
	Y0 += 0.00000000004*np.cos(4.85620428785 + 970.5162499722*t)
	Y0 += 0.00000000004*np.cos(6.09801780440 + 149.6113812444*t)
	Y0 += 0.00000000004*np.cos(6.09702737419 + 512.1648572763*t)
	Y0 += 0.00000000005*np.cos(5.99011856749 + 757.2171545342*t)
	Y0 += 0.00000000004*np.cos(1.49473827676 + 519.656656787*t)
	Y0 += 0.00000000005*np.cos(3.84533101165 + 685.4739373527*t)
	Y0 += 0.00000000005*np.cos(2.37600858697 + 1065.0110044817*t)
	Y0 += 0.00000000004*np.cos(3.09268278234 + 220.5245170234*t)
	Y0 += 0.00000000005*np.cos(6.18849027411 + 702.1487119091*t)
	Y0 += 0.00000000004*np.cos(5.03027859896 + 43.2890291783*t)
	Y0 += 0.00000000004*np.cos(3.50415777352 + 149.5150130248*t)
	Y0 += 0.00000000004*np.cos(0.10667756573 + 1489.9122743283*t)
	Y0 += 0.00000000005*np.cos(0.11392585787 + 55.6591434561*t)
	Y0 += 0.00000000004*np.cos(2.85036336853 + 73.5577582899*t)
	Y0 += 0.00000000004*np.cos(1.18511383194 + 74.1484591209*t)
	Y0 += 0.00000000004*np.cos(3.49428860406 + 75.4147380137*t)
	Y0 += 0.00000000004*np.cos(1.38904040751 + 76.42612997*t)
	Y0 += 0.00000000004*np.cos(1.38525078831 + 547.2170729129*t)
	Y0 += 0.00000000004*np.cos(0.28976395349 + 434.6749457233*t)
	Y0 += 0.00000000005*np.cos(2.38969625576 + 274.0660483248*t)
	Y0 += 0.00000000004*np.cos(4.04730973428 + 1578.0271950199*t)
	Y0 += 0.00000000004*np.cos(5.08993936389 + 554.8207470082*t)
	Y0 += 0.00000000004*np.cos(3.91537493540 + 991.7138786227*t)
	Y0 += 0.00000000005*np.cos(3.81298318563 + 1087.6931058405*t)
	Y0 += 0.00000000004*np.cos(0.97736096631 + 25.6028626656*t)
	Y0 += 0.00000000005*np.cos(0.83096018609 + 782.3469364478*t)
	Y0 += 0.00000000004*np.cos(4.82166454325 + 106.0135355254*t)
	Y0 += 0.00000000004*np.cos(4.86234837049 + 32.7164096664*t)
	Y0 += 0.00000000004*np.cos(1.68446223486 + 36.6967470393*t)
	Y0 += 0.00000000004*np.cos(1.86808454060 + 241.7532834412*t)
	Y0 += 0.00000000005*np.cos(2.08498093723 + 228.7982138268*t)
	Y0 += 0.00000000005*np.cos(4.71053495896 + 81.682697247*t)
	Y0 += 0.00000000004*np.cos(3.69634529841 + 775.233389447*t)
	Y0 += 0.00000000004*np.cos(3.64994770025 + 111.1695290659*t)
	Y0 += 0.00000000005*np.cos(0.38404917281 + 258.8757464767*t)
	Y0 += 0.00000000004*np.cos(0.65015195501 + 472.1748419147*t)
	Y0 += 0.00000000004*np.cos(3.53470981638 + 110.1581371096*t)
	Y0 += 0.00000000005*np.cos(0.24406627292 + 1025.4416802454*t)
	Y0 += 0.00000000004*np.cos(4.95008752174 + 502.8642621516*t)
	Y0 += 0.00000000005*np.cos(3.22652185341 + 251.1714986449*t)
	Y0 += 0.00000000004*np.cos(1.46322874353 + 864.2420820159*t)
	Y0 += 0.00000000004*np.cos(2.69111017006 + 82.6459050935*t)
	Y0 += 0.00000000004*np.cos(6.12032389052 + 149.723255829*t)
	Y0 += 0.00000000005*np.cos(0.86561408573 + 705.1176573257*t)
	Y0 += 0.00000000004*np.cos(3.95917742176 + 580.0935412737*t)
	Y0 += 0.00000000004*np.cos(6.16458246293 + 572.2292347475*t)
	Y0 += 0.00000000004*np.cos(2.28426689317 + 3171.0322435668*t)
	Y0 += 0.00000000004*np.cos(6.10104919920 + 567.5633683015*t)
	Y0 += 0.00000000004*np.cos(0.42832918870 + 1894.4190646765*t)
	Y0 += 0.00000000003*np.cos(5.61450581208 + 130439.51570787099*t)
	Y0 += 0.00000000004*np.cos(2.84597832055 + 142.1408335931*t)
	Y0 += 0.00000000004*np.cos(0.01348355565 + 173.6815870919*t)
	Y0 += 0.00000000004*np.cos(3.29966255649 + 420.005908737*t)
	Y0 += 0.00000000004*np.cos(4.31279855698 + 107.2855599126*t)
	Y0 += 0.00000000004*np.cos(4.23814100611 + 1587.5884225755*t)
	Y0 += 0.00000000003*np.cos(4.73061190758 + 394.3548619616*t)
	Y0 += 0.00000000004*np.cos(4.62536014517 + 19.643719973*t)
	Y0 += 0.00000000004*np.cos(5.67360440697 + 2042.4977891028*t)
	Y0 += 0.00000000004*np.cos(3.45346544892 + 238.5718897035*t)
	Y0 += 0.00000000003*np.cos(1.94705044808 + 280.003939158*t)
	Y0 += 0.00000000003*np.cos(3.60870461616 + 73.1370671646*t)
	Y0 += 0.00000000004*np.cos(1.36099408435 + 149.8238295655*t)
	Y0 += 0.00000000004*np.cos(5.80751631620 + 188.1693135244*t)
	Y0 += 0.00000000004*np.cos(3.46226806872 + 739.0579072695*t)
	Y0 += 0.00000000003*np.cos(5.94295357882 + 1059.5943785103*t)
	Y0 += 0.00000000003*np.cos(2.47326068340 + 3067.9394693482*t)
	Y0 += 0.00000000003*np.cos(0.22557675889 + 110.2545053292*t)
	Y0 += 0.00000000004*np.cos(3.48185168741 + 149.4031384402*t)
	Y0 += 0.00000000004*np.cos(0.14394017655 + 370.9390474199*t)
	Y0 += 0.00000000003*np.cos(6.22196011434 + 531.6967026647*t)
	Y0 += 0.00000000003*np.cos(3.17055586789 + 26.0235537909*t)
	Y0 += 0.00000000003*np.cos(5.66177212198 + 714.6788848813*t)
	Y0 += 0.00000000003*np.cos(1.25974158121 + 527.6852275245*t)
	Y0 += 0.00000000003*np.cos(2.25722693493 + 119.5069163441*t)
	Y0 += 0.00000000004*np.cos(4.35437473297 + 547.0994528339*t)
	Y0 += 0.00000000004*np.cos(5.96554793073 + 76.3779458602*t)
	Y0 += 0.00000000003*np.cos(2.99900688541 + 36.1272980677*t)
	Y0 += 0.00000000004*np.cos(5.34750220863 + 386.9806825299*t)
	Y0 += 0.00000000003*np.cos(4.93777453806 + 203.2647871304*t)
	Y0 += 0.00000000003*np.cos(2.20572290308 + 2207.6295405954*t)
	Y0 += 0.00000000004*np.cos(2.38646827469 + 193.655375465*t)
	Y0 += 0.00000000003*np.cos(1.55169999397 + 196.8367692027*t)
	Y0 += 0.00000000004*np.cos(2.45688070761 + 303.8616966844*t)
	Y0 += 0.00000000003*np.cos(4.28706572007 + 254.1404440615*t)
	Y0 += 0.00000000003*np.cos(3.41531610417 + 611.4430983108*t)
	Y0 += 0.00000000004*np.cos(2.51725792281 + 189.7232222019*t)
	Y0 += 0.00000000003*np.cos(4.11419214708 + 639.9454704238*t)
	Y0 += 0.00000000004*np.cos(5.80239406360 + 43.5496616092*t)
	Y0 += 0.00000000004*np.cos(3.79734739797 + 638.9340784675*t)
	Y0 += 0.00000000003*np.cos(2.23841285469 + 1059.1694818681*t)
	Y0 += 0.00000000004*np.cos(4.40683142592 + 432.7485300303*t)
	Y0 += 0.00000000003*np.cos(1.15399574131 + 3274.1250177854*t)
	Y0 += 0.00000000004*np.cos(6.12767326091 + 403.0223176399*t)
	Y0 += 0.00000000003*np.cos(0.62240490398 + 1077.5411774539*t)
	Y0 += 0.00000000003*np.cos(1.34293298217 + 1049.8207026336*t)
	Y0 += 0.00000000004*np.cos(4.49082255335 + 221.8971151471*t)
	Y0 += 0.00000000004*np.cos(1.95106483965 + 331.3215390738*t)
	Y0 += 0.00000000004*np.cos(6.04941411982 + 987.3086446076*t)
	Y0 += 0.00000000004*np.cos(2.48513057884 + 196.0336200506*t)
	Y0 += 0.00000000003*np.cos(3.34672294499 + 206.2974230218*t)
	Y0 += 0.00000000004*np.cos(5.98714927091 + 815.0633461142*t)
	Y0 += 0.00000000003*np.cos(1.87321139373 + 16.04163511*t)
	Y0 += 0.00000000003*np.cos(0.91640384102 + 639.8491022042*t)
	Y0 += 0.00000000004*np.cos(3.19240126580 + 226.7924762567*t)
	Y0 += 0.00000000003*np.cos(0.90437166824 + 570.5323137181*t)
	Y0 += 0.00000000003*np.cos(5.99284266424 + 539.7252734022*t)
	Y0 += 0.00000000003*np.cos(3.32571391209 + 201.9927627432*t)
	Y0 += 0.00000000004*np.cos(2.51968636978 + 986.0848043302*t)
	Y0 += 0.00000000004*np.cos(0.83940380786 + 2.7083129857*t)
	Y0 += 0.00000000003*np.cos(3.50097703738 + 73.9784494152*t)
	Y0 += 0.00000000003*np.cos(1.17842539862 + 75.5847477194*t)
	Y0 += 0.00000000004*np.cos(3.04590086413 + 105.5404547734*t)
	Y0 += 0.00000000003*np.cos(1.37134739659 + 186.472392495*t)
	Y0 += 0.00000000003*np.cos(1.79933435460 + 468.2426886516*t)
	Y0 += 0.00000000003*np.cos(5.37711250197 + 589.4947101349*t)
	Y0 += 0.00000000004*np.cos(3.66517949468 + 543.0242872189*t)
	Y0 += 0.00000000004*np.cos(5.18247226124 + 1123.1178284926*t)
	Y0 += 0.00000000003*np.cos(1.56928708064 + 262.4778313397*t)
	Y0 += 0.00000000003*np.cos(3.03717673431 + 70.0462961521*t)
	Y0 += 0.00000000003*np.cos(6.27277258269 + 16.4623262353*t)
	Y0 += 0.00000000003*np.cos(2.52485262253 + 1269.4996318895*t)
	Y0 += 0.00000000003*np.cos(5.66096256697 + 1065.6017053127*t)
	Y0 += 0.00000000003*np.cos(0.60812634918 + 911.3032057629*t)
	Y0 += 0.00000000003*np.cos(6.21684488334 + 522.6892926784*t)
	Y0 += 0.00000000003*np.cos(1.26543341862 + 536.6926375108*t)
	Y0 += 0.00000000004*np.cos(1.12014485627 + 812.1425848074*t)
	Y0 += 0.00000000003*np.cos(4.59530161668 + 194.1766403268*t)
	Y0 += 0.00000000003*np.cos(4.77625421178 + 433.7599219866*t)
	Y0 += 0.00000000003*np.cos(2.43746348253 + 504.561183181*t)
	Y0 += 0.00000000003*np.cos(5.11223657305 + 76.7873361374*t)
	Y0 += 0.00000000003*np.cos(1.37712875627 + 640.8604941605*t)
	Y0 += 0.00000000003*np.cos(0.49083651970 + 119.767548775*t)
	Y0 += 0.00000000004*np.cos(0.19166337793 + 256.5881246163*t)
	Y0 += 0.00000000003*np.cos(5.74368313027 + 1591.5205758386*t)
	Y0 += 0.00000000003*np.cos(3.89236217311 + 219.1406180516*t)
	Y0 += 0.00000000003*np.cos(1.66779796238 + 944.9828232758*t)
	Y0 += 0.00000000004*np.cos(0.46469103319 + 977.4867846211*t)
	Y0 += 0.00000000003*np.cos(3.40467646537 + 1586.625214729*t)
	Y0 += 0.00000000003*np.cos(5.41886713273 + 16.6747745564*t)
	Y0 += 0.00000000003*np.cos(5.35709346348 + 406.954470903*t)
	Y0 += 0.00000000003*np.cos(1.18463169105 + 504.4181708291*t)
	Y0 += 0.00000000003*np.cos(0.29639889493 + 240.125798381*t)
	Y0 += 0.00000000004*np.cos(6.18520958096 + 109.2431133729*t)
	Y0 += 0.00000000003*np.cos(0.50288020555 + 1012.9115072732*t)
	Y0 += 0.00000000003*np.cos(1.34717493471 + 100.6450936638*t)
	Y0 += 0.00000000003*np.cos(1.58813559089 + 433.663553767*t)
	Y0 += 0.00000000003*np.cos(2.06659817346 + 423.8898778903*t)
	Y0 += 0.00000000004*np.cos(3.99019117649 + 332.8060117821*t)
	Y0 += 0.00000000003*np.cos(2.68144529736 + 334.5511169213*t)
	Y0 += 0.00000000003*np.cos(6.24199966414 + 229.7614216733*t)
	Y0 += 0.00000000003*np.cos(4.84237233565 + 117.36805233*t)
	Y0 += 0.00000000003*np.cos(1.56582347375 + 1567.7322542814*t)
	Y0 += 0.00000000003*np.cos(2.59468901357 + 967.3348562345*t)
	Y0 += 0.00000000003*np.cos(3.26359178932 + 204.7010757289*t)
	Y0 += 0.00000000003*np.cos(2.65313234396 + 36.9091953604*t)
	Y0 += 0.00000000003*np.cos(1.11540581919 + 3163.918696566*t)
	Y0 += 0.00000000003*np.cos(3.89282571562 + 101.8689339412*t)
	Y0 += 0.00000000003*np.cos(0.81501257642 + 1482.7987273275*t)
	Y0 += 0.00000000003*np.cos(5.20903239624 + 67.0773507355*t)
	Y0 += 0.00000000003*np.cos(3.42217383358 + 594.6507036754*t)
	Y0 += 0.00000000003*np.cos(0.85408846981 + 326.6868103951*t)
	Y0 += 0.00000000003*np.cos(1.34692233951 + 95.2284676924*t)
	Y0 += 0.00000000003*np.cos(2.11458768070 + 238.4288773516*t)
	Y0 += 0.00000000003*np.cos(0.10572797311 + 389.9496279465*t)
	Y0 += 0.00000000003*np.cos(0.02803810607 + 554.9637593601*t)
	Y0 += 0.00000000002*np.cos(3.97627726370 + 1474.9344208013*t)
	Y0 += 0.00000000003*np.cos(5.04593897585 + 25.2727942655*t)
	Y0 += 0.00000000003*np.cos(2.13154149861 + 5223.6939198022*t)
	Y0 += 0.00000000003*np.cos(4.14506010302 + 1215.1649024473*t)
	Y0 += 0.00000000003*np.cos(2.96936351901 + 572.9799942729*t)
	Y0 += 0.00000000003*np.cos(4.46251505367 + 429.3065038617*t)
	Y0 += 0.00000000003*np.cos(1.53717569068 + 2420.9286360334*t)
	Y0 += 0.00000000003*np.cos(4.84459368978 + 70.1157321213*t)
	Y0 += 0.00000000003*np.cos(4.93921322136 + 206.0736738526*t)
	Y0 += 0.00000000003*np.cos(5.87646484421 + 325.9530972122*t)
	Y0 += 0.00000000003*np.cos(4.63407991490 + 71.1582618449*t)
	Y0 += 0.00000000003*np.cos(1.35304494207 + 58.1068240109*t)
	Y0 += 0.00000000002*np.cos(4.95729295762 + 426.7582495704*t)
	Y0 += 0.00000000002*np.cos(0.35093935298 + 103.1409583284*t)
	Y0 += 0.00000000002*np.cos(1.57182026951 + 426.4381321816*t)
	Y0 += 0.00000000003*np.cos(0.22414431985 + 30639.856638633*t)
	Y0 += 0.00000000002*np.cos(2.47348953400 + 824.7421937488*t)
	Y0 += 0.00000000003*np.cos(2.34672218997 + 140.9651774255*t)
	Y0 += 0.00000000003*np.cos(3.75424963526 + 104.0559820651*t)
	Y0 += 0.00000000003*np.cos(1.48331291617 + 539.2521926502*t)
	Y0 += 0.00000000003*np.cos(5.02556949389 + 180.2738692309*t)
	Y0 += 0.00000000002*np.cos(3.04412797959 + 71.8608372605*t)
	Y0 += 0.00000000003*np.cos(5.95049731065 + 536.91638668*t)
	Y0 += 0.00000000003*np.cos(1.53178099131 + 522.4655435092*t)
	Y0 += 0.00000000003*np.cos(2.12746057045 + 176.6505325085*t)
	Y0 += 0.00000000003*np.cos(4.00780371970 + 649.4585138696*t)
	Y0 += 0.00000000003*np.cos(3.03013352437 + 14143.4952424306*t)
	Y0 += 0.00000000002*np.cos(3.85530156976 + 194.3890886479*t)
	Y0 += 0.00000000002*np.cos(0.56671168618 + 661.2379273164*t)
	Y0 += 0.00000000003*np.cos(2.46622131533 + 453.6855262499*t)
	Y0 += 0.00000000002*np.cos(3.46450853334 + 103.0445901088*t)
	Y0 += 0.00000000003*np.cos(0.03733657207 + 78.4049352897*t)
	Y0 += 0.00000000002*np.cos(5.19806115333 + 167.0893049529*t)
	Y0 += 0.00000000002*np.cos(4.61438536730 + 1074.3597837162*t)
	Y0 += 0.00000000003*np.cos(2.51782058807 + 187.4356003415*t)
	Y0 += 0.00000000002*np.cos(3.06218083197 + 3281.2385647862*t)
	Y0 += 0.00000000003*np.cos(4.79366988176 + 97.4155158163*t)
	Y0 += 0.00000000003*np.cos(6.20828867659 + 310.1720945331*t)
	Y0 += 0.00000000003*np.cos(3.48692805917 + 354.5249052944*t)
	Y0 += 0.00000000003*np.cos(1.35327433550 + 7.8643065262*t)
	Y0 += 0.00000000002*np.cos(5.33895570631 + 5.1078094307*t)
	Y0 += 0.00000000003*np.cos(0.14790051128 + 102.1295663721*t)
	Y0 += 0.00000000002*np.cos(6.15305969404 + 148.8124376092*t)
	Y0 += 0.00000000002*np.cos(1.63527454889 + 77.7023598741*t)
	Y0 += 0.00000000003*np.cos(0.96448948153 + 538.2889848037*t)
	Y0 += 0.00000000003*np.cos(0.23460351325 + 521.0929453855*t)
	Y0 += 0.00000000003*np.cos(4.79253603301 + 135.336103133*t)
	Y0 += 0.00000000002*np.cos(5.83269526756 + 570.7447620392*t)
	Y0 += 0.00000000003*np.cos(3.35428536949 + 143.9341228421*t)
	Y0 += 0.00000000003*np.cos(1.46153229106 + 522.7898664149*t)
	Y0 += 0.00000000003*np.cos(6.02074601090 + 536.5920637743*t)
	Y0 += 0.00000000002*np.cos(5.68217414257 + 65.3804297061*t)
	Y0 += 0.00000000002*np.cos(5.59130337229 + 842.9014410135*t)
	Y0 += 0.00000000002*np.cos(3.76188061934 + 1090.4014188262*t)
	Y0 += 0.00000000002*np.cos(5.95499666472 + 295.1942410061*t)
	Y0 += 0.00000000002*np.cos(0.93511964703 + 3340.629680352*t)
	Y0 += 0.00000000002*np.cos(5.18753332271 + 3340.5951730476*t)
	Y0 += 0.00000000002*np.cos(1.73244132435 + 530.324104541*t)
	Y0 += 0.00000000002*np.cos(5.74983697761 + 529.0578256482*t)
	Y0 += 0.00000000002*np.cos(4.15154941233 + 207.4575728244*t)
	Y0 += 0.00000000002*np.cos(1.05653519123 + 255.8373650909*t)
	Y0 += 0.00000000003*np.cos(6.11670486582 + 17.5261078183*t)
	Y0 += 0.00000000003*np.cos(4.51202777337 + 526.722019678*t)
	Y0 += 0.00000000003*np.cos(2.97025052859 + 532.6599105112*t)
	Y0 += 0.00000000002*np.cos(5.99294704910 + 1053.2315910349*t)
	Y0 += 0.00000000002*np.cos(1.88430780231 + 806.725958836*t)
	Y0 += 0.00000000002*np.cos(3.64212431845 + 31.6526280834*t)
	Y0 += 0.00000000003*np.cos(2.23364374205 + 380.3884003909*t)
	Y0 += 0.00000000002*np.cos(1.84809557699 + 74.4090915518*t)
	Y0 += 0.00000000002*np.cos(2.83130685901 + 75.1541055828*t)
	Y0 += 0.00000000002*np.cos(3.64808127126 + 13.4933808187*t)
	Y0 += 0.00000000002*np.cos(1.71844352497 + 732.6951197941*t)
	Y0 += 0.00000000002*np.cos(2.86599389489 + 366.7944458357*t)
	Y0 += 0.00000000003*np.cos(5.74724216185 + 82.4858463991*t)
	Y0 += 0.00000000002*np.cos(3.86762575697 + 91.4563731237*t)
	Y0 += 0.00000000003*np.cos(1.24871596090 + 170.7608257851*t)
	Y0 += 0.00000000002*np.cos(2.89764541348 + 1589.1210793936*t)
	Y0 += 0.00000000002*np.cos(1.01311833095 + 2043.9822618111*t)
	Y0 += 0.00000000002*np.cos(4.17591768574 + 232.2091022281*t)
	Y0 += 0.00000000002*np.cos(3.17462388385 + 142.9709149956*t)
	Y0 += 0.00000000003*np.cos(1.36141936485 + 12036.4607348882*t)
	Y0 += 0.00000000002*np.cos(4.18855382222 + 48.9181034708*t)
	Y0 += 0.00000000003*np.cos(0.75585909025 + 1440.9941708575*t)
	Y0 += 0.00000000002*np.cos(6.23976588694 + 249.9476583675*t)
	Y0 += 0.00000000002*np.cos(3.83130375496 + 32.5039613453*t)
	Y0 += 0.00000000003*np.cos(6.04631945781 + 1438.0252254409*t)
	Y0 += 0.00000000003*np.cos(6.15517284809 + 61.2882177486*t)
	Y0 += 0.00000000002*np.cos(5.72805402572 + 224.2329211173*t)
	Y0 += 0.00000000002*np.cos(1.86985001792 + 76.0054388447*t)
	Y0 += 0.00000000002*np.cos(1.87161415648 + 2950.619601128*t)
	Y0 += 0.00000000002*np.cos(5.35806344878 + 1094.8066528413*t)
	Y0 += 0.00000000003*np.cos(4.45129885636 + 18073.7049386502*t)
	Y0 += 0.00000000003*np.cos(1.64099417707 + 172.2452984934*t)
	Y0 += 0.00000000003*np.cos(1.34694957073 + 418.0001711669*t)
	Y0 += 0.00000000002*np.cos(1.25812287736 + 1254.5217783625*t)
	Y0 += 0.00000000003*np.cos(2.09254584965 + 343.7398374614*t)
	Y0 += 0.00000000002*np.cos(1.59643352277 + 79.5169009825*t)
	Y0 += 0.00000000002*np.cos(2.75759498395 + 418.9633790134*t)
	Y0 += 0.00000000003*np.cos(4.05627319560 + 562.1467423301*t)
	Y0 += 0.00000000002*np.cos(3.32071979355 + 425.3261664888*t)
	Y0 += 0.00000000002*np.cos(5.30365229443 + 1067.4586850365*t)
	Y0 += 0.00000000002*np.cos(0.29972788635 + 195.8906076987*t)
	Y0 += 0.00000000003*np.cos(2.05914279241 + 451.9404211107*t)
	Y0 += 0.00000000002*np.cos(3.92254201471 + 291.262087743*t)
	Y0 += 0.00000000002*np.cos(3.07294300003 + 104.5772469269*t)
	Y0 += 0.00000000002*np.cos(5.48139692876 + 84.9335269539*t)
	Y0 += 0.00000000002*np.cos(2.86413061580 + 520.129737539*t)
	Y0 += 0.00000000003*np.cos(3.69900224280 + 1130.2313754934*t)
	Y0 += 0.00000000002*np.cos(1.95094892773 + 122.4758617607*t)
	Y0 += 0.00000000002*np.cos(5.31979368264 + 74.1272072615*t)
	Y0 += 0.00000000002*np.cos(5.64279406054 + 75.4359898731*t)
	Y0 += 0.00000000002*np.cos(4.70654871417 + 902.7051860538*t)
	Y0 += 0.00000000003*np.cos(0.28305438643 + 2281.2304965106*t)
	Y0 += 0.00000000002*np.cos(0.49354626945 + 535.5324877082*t)
	Y0 += 0.00000000002*np.cos(0.70554672533 + 523.849442481*t)
	Y0 += 0.00000000002*np.cos(3.20839343358 + 427.8702152632*t)
	Y0 += 0.00000000002*np.cos(5.50588162867 + 110.7275860812*t)
	Y0 += 0.00000000002*np.cos(0.37703553450 + 57.5161231799*t)
	Y0 += 0.00000000002*np.cos(5.24322037873 + 97.6761482472*t)
	Y0 += 0.00000000002*np.cos(4.83025888108 + 1286.9081196288*t)
	Y0 += 0.00000000002*np.cos(5.11723082937 + 1688.2335162393*t)
	Y0 += 0.00000000002*np.cos(5.28064708885 + 84.1827674285*t)
	Y0 += 0.00000000002*np.cos(3.48920681716 + 150.31395666*t)
	Y0 += 0.00000000002*np.cos(5.96235967690 + 196.6243208816*t)
	Y0 += 0.00000000002*np.cos(0.34664714788 + 1553.6481726317*t)
	Y0 += 0.00000000003*np.cos(4.59283708276 + 190.4045457581*t)
	Y0 += 0.00000000002*np.cos(0.18901638718 + 268.9582388941*t)
	Y0 += 0.00000000002*np.cos(3.67967650386 + 25.0603459444*t)
	Y0 += 0.00000000002*np.cos(0.25989731478 + 3377.217792004*t)
	Y0 += 0.00000000002*np.cos(5.59231258562 + 239.1625905345*t)
	Y0 += 0.00000000002*np.cos(3.13454820759 + 28.4541880032*t)
	Y0 += 0.00000000002*np.cos(2.90037576777 + 501.2367770914*t)
	Y0 += 0.00000000002*np.cos(4.13041028192 + 1819.6374661092*t)
	Y0 += 0.00000000002*np.cos(3.03453555896 + 1994.3304451574*t)
	Y0 += 0.00000000002*np.cos(0.52128023131 + 43.7621099303*t)
	Y0 += 0.00000000002*np.cos(5.59697552672 + 683.1863154923*t)
	Y0 += 0.00000000002*np.cos(5.18746174179 + 990.2294059144*t)
	Y0 += 0.00000000002*np.cos(3.73211587819 + 1208.9451273238*t)
	Y0 += 0.00000000002*np.cos(1.41451851434 + 70.5888128733*t)
	Y0 += 0.00000000002*np.cos(2.43244429712 + 25.1297819136*t)
	Y0 += 0.00000000002*np.cos(0.81246242776 + 22.633917249*t)
	Y0 += 0.00000000002*np.cos(5.39698422155 + 313.9441891018*t)
	Y0 += 0.00000000002*np.cos(2.67348527835 + 2942.4634232916*t)
	Y0 += 0.00000000002*np.cos(4.59332206447 + 488.63716815*t)
	Y0 += 0.00000000002*np.cos(3.69176301864 + 128.3655684841*t)
	Y0 += 0.00000000002*np.cos(1.90032189588 + 2352.8661537718*t)
	Y0 += 0.00000000002*np.cos(1.77846525648 + 34.5096989154*t)
	Y0 += 0.00000000002*np.cos(4.03588409062 + 373.0142209592*t)
	Y0 += 0.00000000002*np.cos(5.99985796092 + 856.3777754897*t)
	Y0 += 0.00000000002*np.cos(0.25170947285 + 1590.0361031303*t)
	Y0 += 0.00000000002*np.cos(4.25418483437 + 3707.8367556622*t)
	Y0 += 0.00000000002*np.cos(3.78942233655 + 8.9068362498*t)
	Y0 += 0.00000000002*np.cos(4.76344927967 + 72.4939767069*t)
	Y0 += 0.00000000002*np.cos(5.34264408967 + 88.274979386*t)
	Y0 += 0.00000000002*np.cos(1.87084508090 + 821.703812363*t)
	Y0 += 0.00000000002*np.cos(2.11063891013 + 397.3932433474*t)
	Y0 += 0.00000000002*np.cos(5.05881014833 + 115.6229471908*t)
	Y0 += 0.00000000002*np.cos(2.35569015656 + 1415.130675761*t)
	Y0 += 0.00000000002*np.cos(2.65368789715 + 33.4671691918*t)
	Y0 += 0.00000000002*np.cos(0.52347522628 + 1059.6425626201*t)
	Y0 += 0.00000000002*np.cos(2.24658725094 + 639.3760214522*t)
	Y0 += 0.00000000002*np.cos(3.84217977006 + 2122.6960136415*t)
	Y0 += 0.00000000002*np.cos(2.59143729160 + 19.0105805266*t)
	Y0 += 0.00000000002*np.cos(2.11053066710 + 1065.5322693435*t)
	Y0 += 0.00000000002*np.cos(4.62291687545 + 1432.3961511484*t)
	Y0 += 0.00000000002*np.cos(3.22823645198 + 125.1841747464*t)
	Y0 += 0.00000000002*np.cos(2.47703669434 + 75.6329318292*t)
	Y0 += 0.00000000002*np.cos(2.20236574167 + 73.9302653054*t)
	Y0 += 0.00000000002*np.cos(5.98301959303 + 1589.024711174*t)
	Y0 += 0.00000000002*np.cos(1.88445167412 + 395.105621487*t)
	Y0 += 0.00000000002*np.cos(1.42267938577 + 447.2051186955*t)
	Y0 += 0.00000000002*np.cos(2.63729203449 + 328.9220426288*t)
	Y0 += 0.00000000002*np.cos(3.31696453560 + 78.9743842613*t)
	Y0 += 0.00000000002*np.cos(5.79714411355 + 503.8274699981*t)
	Y0 += 0.00000000002*np.cos(0.41710679619 + 7.7042478318*t)
	Y0 += 0.00000000002*np.cos(5.24648026819 + 1261.6353253633*t)
	Y0 += 0.00000000002*np.cos(6.21351657373 + 34.2008823747*t)
	Y0 += 0.00000000002*np.cos(2.91767078449 + 293.188503436*t)
	Y0 += 0.00000000002*np.cos(2.48054400991 + 224.4566702865*t)
	Y0 += 0.00000000002*np.cos(0.91982264535 + 73.0846775379*t)
	Y0 += 0.00000000002*np.cos(4.99111215304 + 109.6850563576*t)
	Y0 += 0.00000000002*np.cos(5.58085981671 + 995.6460318858*t)
	Y0 += 0.00000000002*np.cos(1.96128794169 + 91.2439248026*t)
	Y0 += 0.00000000002*np.cos(1.66229448417 + 215.9592243139*t)
	Y0 += 0.00000000002*np.cos(0.08573902883 + 210.6389665621*t)
	Y0 += 0.00000000002*np.cos(1.63673119740 + 1446.62324515*t)
	Y0 += 0.00000000002*np.cos(6.20915190658 + 709.0498105888*t)
	Y0 += 0.00000000002*np.cos(0.93074847493 + 369.9758395734*t)
	Y0 += 0.00000000002*np.cos(5.12392972449 + 1268.7488723641*t)
	Y0 += 0.00000000002*np.cos(0.42210200786 + 385.5443939314*t)
	Y0 += 0.00000000002*np.cos(3.84047382097 + 1128.534454464*t)
	Y0 += 0.00000000002*np.cos(1.88984981653 + 5.6772584023*t)
	Y0 += 0.00000000002*np.cos(1.57331781556 + 136.0698163159*t)
	Y0 += 0.00000000002*np.cos(1.11042413370 + 756.3233826569*t)
	Y0 += 0.00000000002*np.cos(1.82238270853 + 76.2178871658*t)
	Y0 += 0.00000000002*np.cos(2.68265649767 + 5753.3848848968*t)
	Y0 += 0.00000000002*np.cos(1.41051039403 + 610.6923387854*t)
	Y0 += 0.00000000002*np.cos(6.09065311046 + 51.8870488874*t)
	Y0 += 0.00000000002*np.cos(3.42034575912 + 3738.761430108*t)
	Y0 += 0.00000000002*np.cos(0.63823960133 + 384.0599212231*t)
	Y0 += 0.00000000002*np.cos(2.52481446936 + 1474.6737883704*t)
	Y0 += 0.00000000002*np.cos(0.85532727083 + 516.1975842759*t)
	Y0 += 0.00000000002*np.cos(0.34376572395 + 543.1843459133*t)
	Y0 += 0.00000000002*np.cos(3.10279109671 + 833.552661779*t)
	Y0 += 0.00000000002*np.cos(0.68808488652 + 6812.766815086*t)
	Y0 += 0.00000000002*np.cos(0.02196799093 + 17.2654753874*t)
	Y0 += 0.00000000002*np.cos(1.00918922832 + 1051.3051753419*t)
	Y0 += 0.00000000002*np.cos(2.92755118448 + 376.1956146969*t)
	Y0 += 0.00000000002*np.cos(1.32686473690 + 657.1627617014*t)
	Y0 += 0.00000000002*np.cos(4.57611534969 + 76.3142553854*t)
	Y0 += 0.00000000002*np.cos(3.66186077986 + 93.531546663*t)
	Y0 += 0.00000000002*np.cos(5.99350252909 + 5621.8429232104*t)
	Y0 += 0.00000000002*np.cos(2.76365638460 + 640.4185511758*t)
	Y0 += 0.00000000002*np.cos(3.77708599943 + 319.3126309634*t)
	Y0 += 0.00000000002*np.cos(3.78888892856 + 4705.7323075436*t)
	Y0 += 0.00000000002*np.cos(2.13982322599 + 433.190473015*t)
	Y0 += 0.00000000002*np.cos(1.61241793848 + 700.6642392008*t)
	Y0 += 0.00000000002*np.cos(4.66499962068 + 208.1912860073*t)
	Y0 += 0.00000000001*np.cos(6.25977296149 + 77.0692204277*t)
	Y0 += 0.00000000002*np.cos(1.67489994505 + 502.6036297207*t)
	Y0 += 0.00000000002*np.cos(2.16728307749 + 771.3012361839*t)
	Y0 += 0.00000000001*np.cos(2.85994975068 + 55.1378785943*t)
	Y0 += 0.00000000001*np.cos(3.33817930601 + 1518.2234499796*t)
	Y0 += 0.00000000002*np.cos(2.68969506441 + 1340.3490771937*t)
	Y0 += 0.00000000002*np.cos(4.73606085732 + 184.0941479094*t)
	Y0 += 0.00000000001*np.cos(0.57635206460 + 154.6710065653*t)
	Y0 += 0.00000000002*np.cos(2.37370373800 + 566.600160455*t)
	Y0 += 0.00000000002*np.cos(2.30458522042 + 142.6620984549*t)
	Y0 += 0.00000000001*np.cos(2.59207478919 + 1.3725981237*t)
	Y0 += 0.00000000002*np.cos(1.64284544569 + 132.8884225782*t)
	Y0 += 0.00000000002*np.cos(1.50487653073 + 0.8031491521*t)
	return Y0




def Sun_Y1 (t): # 814 terms of order 1

	Y1 = 0.
	Y1 += 0.00000898747*np.cos(5.84062157690 + 426.598190876*t)
	Y1 += 0.00000781392*np.cos(1.12962797123 + 206.1855484372*t)
	Y1 += 0.00000754898*np.cos(0.61969438775 + 220.4126424388*t)
	Y1 += 0.00000605551*np.cos(1.67748431613 + 1059.3819301892*t)
	Y1 += 0.00000573282*np.cos(4.00088433502 + 522.5774180938*t)
	Y1 += 0.00000561304*np.cos(3.48675865561 + 536.8045120954*t)
	Y1 += 0.00000102847*np.cos(1.87716874734 + 7.1135470008*t)
	Y1 += 0.00000072695*np.cos(5.07718907269 + 639.897286314*t)
	Y1 += 0.00000087320*np.cos(0.09065280320 + 419.4846438752*t)
	Y1 += 0.00000053759*np.cos(6.03942421773 + 433.7117378768*t)
	Y1 += 0.00000047287*np.cos(2.15306225354 + 213.299095438*t)
	Y1 += 0.00000044572*np.cos(5.05981982210 + 529.6909650946*t)
	Y1 += 0.00000044061*np.cos(2.02795830775 + 1589.0728952838*t)
	Y1 += 0.00000031010*np.cos(3.31770926852 + 1052.2683831884*t)
	Y1 += 0.00000030160*np.cos(3.91376481697 + 1066.49547719*t)
	Y1 += 0.00000032071*np.cos(1.27581809571 + 149.5631971346*t)
	Y1 += 0.00000021415*np.cos(5.30131509744 + 316.3918696566*t)
	Y1 += 0.00000019019*np.cos(0.48946385175 + 227.5261894396*t)
	Y1 += 0.00000016129*np.cos(2.44989442588 + 110.2063212194*t)
	Y1 += 0.00000015875*np.cos(4.20914007335 + 76.2660712756*t)
	Y1 += 0.00000012413*np.cos(4.14057132118 + 515.463871093*t)
	Y1 += 0.00000013252*np.cos(3.58925185460 + 36.6485629295*t)
	Y1 += 0.00000011814*np.cos(1.50628561093 + 632.7837393132*t)
	Y1 += 0.00000012488*np.cos(0.74887488462 + 39.6175083461*t)
	Y1 += 0.00000010164*np.cos(0.62992310390 + 73.297125859*t)
	Y1 += 0.00000009222*np.cos(1.25927718333 + 199.0720014364*t)
	Y1 += 0.00000008663*np.cos(3.35360012494 + 543.9180590962*t)
	Y1 += 0.00000007755*np.cos(1.44764390538 + 949.1756089698*t)
	Y1 += 0.00000007691*np.cos(1.12047989646 + 103.0927742186*t)
	Y1 += 0.00000005487*np.cos(4.43944248381 + 853.196381752*t)
	Y1 += 0.00000005170*np.cos(0.37516758388 + 209.3669421749*t)
	Y1 += 0.00000005081*np.cos(1.39059455730 + 217.2312487011*t)
	Y1 += 0.00000004660*np.cos(0.15626149972 + 216.4804891757*t)
	Y1 += 0.00000004553*np.cos(1.60431626596 + 210.1177017003*t)
	Y1 += 0.00000004447*np.cos(5.48065037241 + 323.5054166574*t)
	Y1 += 0.00000006117
	Y1 += 0.00000004151*np.cos(1.93098926861 + 63.7358983034*t)
	Y1 += 0.00000004099*np.cos(5.22964063969 + 647.0108333148*t)
	Y1 += 0.00000005058*np.cos(1.73136117173 + 14.2270940016*t)
	Y1 += 0.00000004293*np.cos(2.71452907477 + 735.8765135318*t)
	Y1 += 0.00000003443*np.cos(2.77873462243 + 85.8272988312*t)
	Y1 += 0.00000003302*np.cos(0.78944659795 + 11.0457002639*t)
	Y1 += 0.00000003246*np.cos(4.47251198694 + 526.5095713569*t)
	Y1 += 0.00000003180*np.cos(3.00772018402 + 532.8723588323*t)
	Y1 += 0.00000002903*np.cos(3.22514351914 + 525.7588118315*t)
	Y1 += 0.00000002896*np.cos(1.12069020939 + 117.3198682202*t)
	Y1 += 0.00000002863*np.cos(4.25448918131 + 533.6231183577*t)
	Y1 += 0.00000002838*np.cos(0.45959307618 + 202.2533951741*t)
	Y1 += 0.00000002863*np.cos(2.16989496338 + 95.9792272178*t)
	Y1 += 0.00000002852*np.cos(2.37763116158 + 2118.7638603784*t)
	Y1 += 0.00000002044*np.cos(3.86812530423 + 138.5174968707*t)
	Y1 += 0.00000001977*np.cos(2.19636388255 + 742.9900605326*t)
	Y1 += 0.00000001909*np.cos(0.39529260174 + 956.2891559706*t)
	Y1 += 0.00000001768*np.cos(4.34051785227 + 1596.1864422846*t)
	Y1 += 0.00000001699*np.cos(1.87566644469 + 70.8494453042*t)
	Y1 += 0.00000001570*np.cos(2.80724611689 + 78.7137518304*t)
	Y1 += 0.00000001493*np.cos(5.97213767442 + 440.8252848776*t)
	Y1 += 0.00000001810*np.cos(3.43597556192 + 1581.959348283*t)
	Y1 += 0.00000001465*np.cos(1.19009717807 + 74.7815985673*t)
	Y1 += 0.00000001559*np.cos(2.97028792257 + 1045.1548361876*t)
	Y1 += 0.00000001646*np.cos(2.40413866073 + 224.3447957019*t)
	Y1 += 0.00000001133*np.cos(4.77291959539 + 35.1640902212*t)
	Y1 += 0.00000001057*np.cos(0.79522639484 + 309.2783226558*t)
	Y1 += 0.00000001112*np.cos(2.89652371372 + 625.6701923124*t)
	Y1 += 0.00000001000*np.cos(4.09863557302 + 1265.5674786264*t)
	Y1 += 0.00000000989*np.cos(6.14826697847 + 412.3710968744*t)
	Y1 += 0.00000000882*np.cos(5.83304308882 + 41.1019810544*t)
	Y1 += 0.00000000936*np.cos(2.99521995909 + 1169.5882514086*t)
	Y1 += 0.00000000943*np.cos(0.21048093986 + 151.0476698429*t)
	Y1 += 0.00000000771*np.cos(1.58200018736 + 942.062061969*t)
	Y1 += 0.00000000762*np.cos(3.43418344370 + 1155.361157407*t)
	Y1 += 0.00000000712*np.cos(1.82235727085 + 71.8126531507*t)
	Y1 += 0.00000000718*np.cos(2.94974266304 + 77.7505439839*t)
	Y1 += 0.00000000718*np.cos(1.70498371588 + 1162.4747044078*t)
	Y1 += 0.00000000504*np.cos(2.36012441072 + 277.0349937414*t)
	Y1 += 0.00000000486*np.cos(5.53252452947 + 422.6660376129*t)
	Y1 += 0.00000000455*np.cos(1.18907814059 + 1692.1656695024*t)
	Y1 += 0.00000000391*np.cos(3.73837604066 + 1073.6090241908*t)
	Y1 += 0.00000000375*np.cos(0.35041804232 + 234.6397364404*t)
	Y1 += 0.00000000373*np.cos(3.98254461376 + 415.5524906121*t)
	Y1 += 0.00000000361*np.cos(5.90601998518 + 846.0828347512*t)
	Y1 += 0.00000000384*np.cos(5.64976516740 + 330.6189636582*t)
	Y1 += 0.00000000335*np.cos(4.48297896956 + 860.3099287528*t)
	Y1 += 0.00000000337*np.cos(3.18444650009 + 71.6002048296*t)
	Y1 += 0.00000000324*np.cos(0.71684229879 + 423.4167971383*t)
	Y1 += 0.00000000433*np.cos(1.36147512776 + 3.9321532631*t)
	Y1 += 0.00000000326*np.cos(1.48465704932 + 77.962992305*t)
	Y1 += 0.00000000384*np.cos(1.50030220266 + 1478.8665740644*t)
	Y1 += 0.00000000316*np.cos(5.62533566974 + 429.7795846137*t)
	Y1 += 0.00000000304*np.cos(3.98761648250 + 145.6310438715*t)
	Y1 += 0.00000000352*np.cos(0.64575728139 + 2.9689454166*t)
	Y1 += 0.00000000384*np.cos(4.55881127062 + 210.8514148832*t)
	Y1 += 0.00000000380*np.cos(3.47993786173 + 215.7467759928*t)
	Y1 += 0.00000000360*np.cos(2.88459167183 + 728.762966531*t)
	Y1 += 0.00000000338*np.cos(4.31589716519 + 148.0787244263*t)
	Y1 += 0.00000000255*np.cos(0.68716361250 + 437.6438911399*t)
	Y1 += 0.00000000284*np.cos(3.67849455855 + 838.9692877504*t)
	Y1 += 0.00000000234*np.cos(0.03317726903 + 223.5940361765*t)
	Y1 += 0.00000000222*np.cos(4.29914928209 + 508.3503240922*t)
	Y1 += 0.00000000233*np.cos(3.30440847719 + 1272.6810256272*t)
	Y1 += 0.00000000265*np.cos(1.64615612331 + 3.1813937377*t)
	Y1 += 0.00000000201*np.cos(4.46138168832 + 1375.7737998458*t)
	Y1 += 0.00000000178*np.cos(0.37969055043 + 6681.2248533996*t)
	Y1 += 0.00000000181*np.cos(2.37018594067 + 88.865680217*t)
	Y1 += 0.00000000199*np.cos(1.40110998613 + 430.5303441391*t)
	Y1 += 0.00000000189*np.cos(0.25718944825 + 124.433415221*t)
	Y1 += 0.00000000174*np.cos(5.22081710422 + 1368.660252845*t)
	Y1 += 0.00000000167*np.cos(3.42353804022 + 1062.5633239269*t)
	Y1 += 0.00000000180*np.cos(2.72835603995 + 2648.454825473*t)
	Y1 += 0.00000000156*np.cos(1.29021233927 + 12566.1516999828*t)
	Y1 += 0.00000000152*np.cos(5.50666765279 + 160.6088973985*t)
	Y1 += 0.00000000172*np.cos(0.02323350795 + 65.2203710117*t)
	Y1 += 0.00000000154*np.cos(4.59717983879 + 519.3960243561*t)
	Y1 += 0.00000000139*np.cos(3.64890818066 + 1055.4497769261*t)
	Y1 += 0.00000000138*np.cos(4.30414447043 + 1258.4539316256*t)
	Y1 += 0.00000000132*np.cos(5.18037129096 + 654.1243803156*t)
	Y1 += 0.00000000136*np.cos(1.73632400099 + 203.0041546995*t)
	Y1 += 0.00000000121*np.cos(4.88476463619 + 1063.3140834523*t)
	Y1 += 0.00000000118*np.cos(3.20236689438 + 551.031606097*t)
	Y1 += 0.00000000120*np.cos(2.88381733148 + 539.9859058331*t)
	Y1 += 0.00000000140*np.cos(4.29359662977 + 1056.2005364515*t)
	Y1 += 0.00000000111*np.cos(4.11806246187 + 222.8603229936*t)
	Y1 += 0.00000000111*np.cos(4.75059162228 + 2125.8774073792*t)
	Y1 += 0.00000000133*np.cos(3.06193509061 + 22.0914005278*t)
	Y1 += 0.00000000136*np.cos(1.56582531149 + 21.3406410024*t)
	Y1 += 0.00000000144*np.cos(6.19128577365 + 299.1263942692*t)
	Y1 += 0.00000000108*np.cos(1.67634660643 + 302.164775655*t)
	Y1 += 0.00000000101*np.cos(1.41448120448 + 191.9584544356*t)
	Y1 += 0.00000000139*np.cos(1.37682327925 + 1485.9801210652*t)
	Y1 += 0.00000000095*np.cos(3.83184038977 + 18.1592472647*t)
	Y1 += 0.00000000094*np.cos(1.74801590640 + 87.3117715395*t)
	Y1 += 0.00000000119*np.cos(3.20779882655 + 1574.8458012822*t)
	Y1 += 0.00000000122*np.cos(4.95627332740 + 84.3428261229*t)
	Y1 += 0.00000000097*np.cos(4.30891602532 + 217.964961884*t)
	Y1 += 0.00000000096*np.cos(3.59501512720 + 2111.6503133776*t)
	Y1 += 0.00000000093*np.cos(6.00441441624 + 33.6796175129*t)
	Y1 += 0.00000000087*np.cos(1.75505290273 + 231.4583427027*t)
	Y1 += 0.00000000097*np.cos(0.07381843439 + 72.3339180125*t)
	Y1 += 0.00000000090*np.cos(3.89285886336 + 628.8515860501*t)
	Y1 += 0.00000000089*np.cos(3.43002043997 + 1699.2792165032*t)
	Y1 += 0.00000000080*np.cos(5.99267916099 + 12.5301729722*t)
	Y1 += 0.00000000086*np.cos(3.72646183478 + 208.633228992*t)
	Y1 += 0.00000000076*np.cos(4.88733161640 + 9.5612275556*t)
	Y1 += 0.00000000077*np.cos(4.73669756226 + 38.1330356378*t)
	Y1 += 0.00000000076*np.cos(4.18947022170 + 288.0806940053*t)
	Y1 += 0.00000000096*np.cos(4.64169775712 + 203.7378678824*t)
	Y1 += 0.00000000076*np.cos(5.12453730610 + 362.8622925726*t)
	Y1 += 0.00000000076*np.cos(2.48257518078 + 1471.7530270636*t)
	Y1 += 0.00000000075*np.cos(0.38132378506 + 525.0250986486*t)
	Y1 += 0.00000000069*np.cos(2.64295754993 + 114.3991069134*t)
	Y1 += 0.00000000068*np.cos(5.35287430069 + 153.4953503977*t)
	Y1 += 0.00000000068*np.cos(5.70841220182 + 73.8183907208*t)
	Y1 += 0.00000000071*np.cos(0.81628722181 + 534.3568315406*t)
	Y1 += 0.00000000064*np.cos(5.24500232218 + 75.7448064138*t)
	Y1 += 0.00000000066*np.cos(4.60699109440 + 42.5864537627*t)
	Y1 += 0.00000000061*np.cos(1.32159131349 + 207.8824694666*t)
	Y1 += 0.00000000059*np.cos(0.45173742414 + 218.7157214094*t)
	Y1 += 0.00000000059*np.cos(5.95742231142 + 408.4389436113*t)
	Y1 += 0.00000000067*np.cos(5.29778871808 + 152.5321425512*t)
	Y1 += 0.00000000076*np.cos(4.82056450443 + 77.2292791221*t)
	Y1 += 0.00000000063*np.cos(1.72943225747 + 79.2350166922*t)
	Y1 += 0.00000000055*np.cos(1.48510731583 + 200.7689224658*t)
	Y1 += 0.00000000055*np.cos(2.03729558857 + 340.7708920448*t)
	Y1 += 0.00000000076*np.cos(0.68351123517 + 146.594251718*t)
	Y1 += 0.00000000072*np.cos(1.86379528122 + 127.4717966068*t)
	Y1 += 0.00000000055*np.cos(3.89290884441 + 831.8557407496*t)
	Y1 += 0.00000000051*np.cos(1.99163070525 + 225.8292684102*t)
	Y1 += 0.00000000058*np.cos(1.52964509339 + 2221.856634597*t)
	Y1 += 0.00000000057*np.cos(5.68632410752 + 4.4534181249*t)
	Y1 += 0.00000000059*np.cos(4.32589692662 + 618.5566453116*t)
	Y1 += 0.00000000064*np.cos(3.86347940489 + 1685.0521225016*t)
	Y1 += 0.00000000053*np.cos(3.04286367857 + 70.3281804424*t)
	Y1 += 0.00000000049*np.cos(1.07108765064 + 2008.557539159*t)
	Y1 += 0.00000000048*np.cos(2.75851599881 + 350.3321196004*t)
	Y1 += 0.00000000051*np.cos(0.22846885309 + 210.3783341312*t)
	Y1 += 0.00000000051*np.cos(1.50810894489 + 216.2198567448*t)
	Y1 += 0.00000000049*np.cos(4.34430964617 + 963.4027029714*t)
	Y1 += 0.00000000052*np.cos(5.97532002180 + 142.4496501338*t)
	Y1 += 0.00000000045*np.cos(3.23715580244 + 37.611770776*t)
	Y1 += 0.00000000044*np.cos(2.92943406327 + 62.2514255951*t)
	Y1 += 0.00000000050*np.cos(2.96247842378 + 1038.0412891868*t)
	Y1 += 0.00000000044*np.cos(4.06912509984 + 524.2743391232*t)
	Y1 += 0.00000000044*np.cos(1.10360628000 + 38.6543004996*t)
	Y1 += 0.00000000044*np.cos(3.41315318980 + 535.107591066*t)
	Y1 += 0.00000000042*np.cos(2.49665470541 + 20426.571092422*t)
	Y1 += 0.00000000059*np.cos(4.20691421118 + 1795.258443721*t)
	Y1 += 0.00000000042*np.cos(3.26999492630 + 195.1398481733*t)
	Y1 += 0.00000000043*np.cos(2.09042966596 + 74.8934731519*t)
	Y1 += 0.00000000043*np.cos(2.58927275174 + 74.6697239827*t)
	Y1 += 0.00000000050*np.cos(0.24741236723 + 131.4039498699*t)
	Y1 += 0.00000000049*np.cos(4.20329151784 + 207.6700211455*t)
	Y1 += 0.00000000048*np.cos(0.71033320787 + 109.9456887885*t)
	Y1 += 0.00000000039*np.cos(0.11315588432 + 1382.8873468466*t)
	Y1 += 0.00000000038*np.cos(2.82768070464 + 703.6331846174*t)
	Y1 += 0.00000000040*np.cos(1.29300189092 + 10.2949407385*t)
	Y1 += 0.00000000046*np.cos(3.79813773531 + 218.9281697305*t)
	Y1 += 0.00000000037*np.cos(2.83593964107 + 511.5317178299*t)
	Y1 += 0.00000000035*np.cos(4.28290669029 + 565.1156877467*t)
	Y1 += 0.00000000035*np.cos(4.65527976927 + 547.8502123593*t)
	Y1 += 0.00000000039*np.cos(2.38629347866 + 490.3340891794*t)
	Y1 += 0.00000000042*np.cos(3.87683640837 + 56.6223513026*t)
	Y1 += 0.00000000033*np.cos(3.96639362427 + 750.1036075334*t)
	Y1 += 0.00000000037*np.cos(4.69414299267 + 635.9651330509*t)
	Y1 += 0.00000000038*np.cos(4.43072611572 + 483.2205421786*t)
	Y1 += 0.00000000035*np.cos(3.11075553675 + 526.7702037878*t)
	Y1 += 0.00000000035*np.cos(4.37175047624 + 532.6117264014*t)
	Y1 += 0.00000000037*np.cos(0.13743210410 + 265.9892934775*t)
	Y1 += 0.00000000031*np.cos(5.89336305342 + 447.9388318784*t)
	Y1 += 0.00000000030*np.cos(5.15245353060 + 209.106309744*t)
	Y1 += 0.00000000030*np.cos(2.87235713038 + 217.491881132*t)
	Y1 += 0.00000000030*np.cos(0.02207663615 + 92.940845832*t)
	Y1 += 0.00000000039*np.cos(5.08202984393 + 1.4844727083*t)
	Y1 += 0.00000000038*np.cos(0.97224853307 + 52.6901980395*t)
	Y1 += 0.00000000028*np.cos(1.77462370325 + 80.1982245387*t)
	Y1 += 0.00000000034*np.cos(5.07299879866 + 269.9214467406*t)
	Y1 += 0.00000000028*np.cos(2.45238897056 + 107.0249274817*t)
	Y1 += 0.00000000028*np.cos(1.18666538399 + 106.2741679563*t)
	Y1 += 0.00000000031*np.cos(3.61860838672 + 424.1505103212*t)
	Y1 += 0.00000000027*np.cos(2.79364979031 + 1279.794572628*t)
	Y1 += 0.00000000027*np.cos(3.23525952036 + 1802.3719907218*t)
	Y1 += 0.00000000025*np.cos(0.71925595839 + 10021.8372800994*t)
	Y1 += 0.00000000027*np.cos(4.24057714278 + 1898.3512179396*t)
	Y1 += 0.00000000023*np.cos(6.28082090370 + 650.9429865779*t)
	Y1 += 0.00000000023*np.cos(4.99790910102 + 137.0330241624*t)
	Y1 += 0.00000000023*np.cos(3.28519702781 + 35.685355083*t)
	Y1 += 0.00000000023*np.cos(3.28897425519 + 28.5718080822*t)
	Y1 += 0.00000000022*np.cos(5.43332862700 + 337.732510659*t)
	Y1 += 0.00000000023*np.cos(5.16035150168 + 2.4476805548*t)
	Y1 += 0.00000000023*np.cos(4.82793901796 + 643.0786800517*t)
	Y1 += 0.00000000024*np.cos(5.25759177705 + 1361.5467058442*t)
	Y1 += 0.00000000022*np.cos(1.70327289493 + 934.9485149682*t)
	Y1 += 0.00000000023*np.cos(2.98215154259 + 284.1485407422*t)
	Y1 += 0.00000000024*np.cos(4.50083076815 + 191.2076949102*t)
	Y1 += 0.00000000021*np.cos(1.05341004601 + 40.5807161926*t)
	Y1 += 0.00000000021*np.cos(1.35819574535 + 525.4981794006*t)
	Y1 += 0.00000000024*np.cos(3.37809061150 + 540.7366653585*t)
	Y1 += 0.00000000025*np.cos(5.09676204562 + 96.8729990951*t)
	Y1 += 0.00000000020*np.cos(3.97670500643 + 251.4321310758*t)
	Y1 += 0.00000000027*np.cos(4.63548485210 + 1905.4647649404*t)
	Y1 += 0.00000000024*np.cos(3.34248986355 + 219.4494345923*t)
	Y1 += 0.00000000019*np.cos(1.29742572058 + 99.1606209555*t)
	Y1 += 0.00000000020*np.cos(1.96622391594 + 81.8951455681*t)
	Y1 += 0.00000000022*np.cos(2.04754590576 + 114.1384744825*t)
	Y1 += 0.00000000021*np.cos(5.89651875201 + 344.7030453079*t)
	Y1 += 0.00000000018*np.cos(0.41312927370 + 479.2883889155*t)
	Y1 += 0.00000000018*np.cos(1.05659266627 + 47.6942631934*t)
	Y1 += 0.00000000019*np.cos(1.03948249798 + 113.3877149571*t)
	Y1 += 0.00000000018*np.cos(5.36139144851 + 66.70484372*t)
	Y1 += 0.00000000017*np.cos(2.91822171111 + 235.3904959658*t)
	Y1 += 0.00000000018*np.cos(5.53310135976 + 436.8931316145*t)
	Y1 += 0.00000000016*np.cos(4.13205563870 + 1603.2999892854*t)
	Y1 += 0.00000000017*np.cos(5.48950262612 + 909.8187330546*t)
	Y1 += 0.00000000018*np.cos(5.39681560820 + 358.9301393095*t)
	Y1 += 0.00000000017*np.cos(6.15299165414 + 533.8837507886*t)
	Y1 += 0.00000000016*np.cos(3.68087340604 + 1788.1448967202*t)
	Y1 += 0.00000000019*np.cos(4.72886285917 + 207.1487562837*t)
	Y1 += 0.00000000018*np.cos(2.57871349196 + 67.6680515665*t)
	Y1 += 0.00000000018*np.cos(1.20805528524 + 52175.8062831484*t)
	Y1 += 0.00000000017*np.cos(3.83900403821 + 497.4476361802*t)
	Y1 += 0.00000000017*np.cos(5.84159114613 + 417.0369633204*t)
	Y1 += 0.00000000014*np.cos(4.20789843971 + 175.1660598002*t)
	Y1 += 0.00000000015*np.cos(3.58225207772 + 220.4608265486*t)
	Y1 += 0.00000000014*np.cos(0.57687637914 + 416.3032501375*t)
	Y1 += 0.00000000015*np.cos(5.66819746086 + 146.3818033969*t)
	Y1 += 0.00000000019*np.cos(1.98725402688 + 554.0699874828*t)
	Y1 += 0.00000000014*np.cos(2.61946078132 + 99.9113804809*t)
	Y1 += 0.00000000014*np.cos(3.43836595760 + 518.6452648307*t)
	Y1 += 0.00000000014*np.cos(0.47904403018 + 10213.285546211*t)
	Y1 += 0.00000000014*np.cos(3.65383778432 + 1049.0869894507*t)
	Y1 += 0.00000000014*np.cos(3.58473930386 + 351.8165923087*t)
	Y1 += 0.00000000014*np.cos(3.09174780856 + 429.0458714308*t)
	Y1 += 0.00000000016*np.cos(1.89603210492 + 404.5067903482*t)
	Y1 += 0.00000000014*np.cos(4.23117767971 + 181.0557665236*t)
	Y1 += 0.00000000015*np.cos(5.51517239045 + 4.665866446*t)
	Y1 += 0.00000000013*np.cos(0.38270943937 + 636.7158925763*t)
	Y1 += 0.00000000014*np.cos(3.79902684902 + 245.5424243524*t)
	Y1 += 0.00000000013*np.cos(5.65675422016 + 82.8583534146*t)
	Y1 += 0.00000000013*np.cos(3.69737120977 + 501.3797894433*t)
	Y1 += 0.00000000013*np.cos(3.82545867862 + 205.2223405907*t)
	Y1 += 0.00000000012*np.cos(4.39382701202 + 867.4234757536*t)
	Y1 += 0.00000000013*np.cos(2.07858336172 + 145.1097790097*t)
	Y1 += 0.00000000011*np.cos(6.02905899204 + 131.5469622218*t)
	Y1 += 0.00000000011*np.cos(3.70434496261 + 2214.7430875962*t)
	Y1 += 0.00000000012*np.cos(3.18799737238 + 14.977853527*t)
	Y1 += 0.00000000011*np.cos(3.07588280051 + 3178.1457905676*t)
	Y1 += 0.00000000012*np.cos(4.30176223804 + 3340.6124266998*t)
	Y1 += 0.00000000011*np.cos(0.88747625993 + 211.8146227297*t)
	Y1 += 0.00000000010*np.cos(2.67518472775 + 121.2520214833*t)
	Y1 += 0.00000000010*np.cos(4.32081630166 + 214.0498549634*t)
	Y1 += 0.00000000012*np.cos(4.08903506366 + 198.321241911*t)
	Y1 += 0.00000000010*np.cos(3.21317176695 + 2104.5367663768*t)
	Y1 += 0.00000000013*np.cos(3.04628805544 + 721.6494195302*t)
	Y1 += 0.00000000010*np.cos(5.85525484044 + 405.2575498736*t)
	Y1 += 0.00000000010*np.cos(0.95353223766 + 444.7574381407*t)
	Y1 += 0.00000000010*np.cos(4.44991640752 + 289.5651667136*t)
	Y1 += 0.00000000011*np.cos(1.96513444262 + 108.4612160802*t)
	Y1 += 0.00000000011*np.cos(4.54905670073 + 206.1373643274*t)
	Y1 += 0.00000000010*np.cos(1.45962507451 + 643.8294395771*t)
	Y1 += 0.00000000009*np.cos(5.82248345678 + 152.7445908723*t)
	Y1 += 0.00000000009*np.cos(3.76555090929 + 212.5483359126*t)
	Y1 += 0.00000000009*np.cos(0.52740652256 + 177.8743727859*t)
	Y1 += 0.00000000009*np.cos(3.37901002476 + 275.5505210331*t)
	Y1 += 0.00000000009*np.cos(6.22383357370 + 140.001969579*t)
	Y1 += 0.00000000010*np.cos(0.04924916522 + 604.4725636619*t)
	Y1 += 0.00000000009*np.cos(0.89636070253 + 112.9146342051*t)
	Y1 += 0.00000000010*np.cos(5.90599957866 + 33.9402499438*t)
	Y1 += 0.00000000010*np.cos(5.00030882649 + 319.5732633943*t)
	Y1 += 0.00000000010*np.cos(5.60951690643 + 69.1525242748*t)
	Y1 += 0.00000000011*np.cos(2.14229269933 + 2015.6710861598*t)
	Y1 += 0.00000000012*np.cos(3.62719609541 + 842.1506814881*t)
	Y1 += 0.00000000010*np.cos(3.83093061667 + 1592.2542890215*t)
	Y1 += 0.00000000010*np.cos(2.06240666657 + 373.9079928365*t)
	Y1 += 0.00000000008*np.cos(4.10335886056 + 1148.2476104062*t)
	Y1 += 0.00000000009*np.cos(0.42800870352 + 561.934294009*t)
	Y1 += 0.00000000008*np.cos(0.94852393070 + 32.1951448046*t)
	Y1 += 0.00000000008*np.cos(4.13055580345 + 1585.1407420207*t)
	Y1 += 0.00000000008*np.cos(2.55201196235 + 81.7521332162*t)
	Y1 += 0.00000000008*np.cos(3.03880062155 + 629.6023455755*t)
	Y1 += 0.00000000008*np.cos(1.18973384884 + 248.7238180901*t)
	Y1 += 0.00000000008*np.cos(4.45302946532 + 5.9378908332*t)
	Y1 += 0.00000000009*np.cos(4.79269618550 + 414.0680179038*t)
	Y1 += 0.00000000010*np.cos(2.61596011042 + 436.1594184316*t)
	Y1 += 0.00000000008*np.cos(0.94778655827 + 214.7835681463*t)
	Y1 += 0.00000000010*np.cos(1.31103197356 + 454.9093665273*t)
	Y1 += 0.00000000008*np.cos(4.61033798635 + 42.3258213318*t)
	Y1 += 0.00000000008*np.cos(2.75059975447 + 98.8999885246*t)
	Y1 += 0.00000000010*np.cos(1.02582111721 + 297.6419215609*t)
	Y1 += 0.00000000009*np.cos(5.65248521015 + 621.7380390493*t)
	Y1 += 0.00000000008*np.cos(0.64686923791 + 159.1244246902*t)
	Y1 += 0.00000000007*np.cos(4.05705631944 + 576.1613880106*t)
	Y1 += 0.00000000008*np.cos(3.92242352986 + 2001.4439921582*t)
	Y1 += 0.00000000007*np.cos(0.25912882540 + 320.3240229197*t)
	Y1 += 0.00000000008*np.cos(1.14800859952 + 355.7487455718*t)
	Y1 += 0.00000000007*np.cos(2.15288626818 + 30.0562807905*t)
	Y1 += 0.00000000007*np.cos(6.13248181563 + 427.5613987225*t)
	Y1 += 0.00000000007*np.cos(3.90217030714 + 2228.9701815978*t)
	Y1 += 0.00000000007*np.cos(5.21901491319 + 2655.5683724738*t)
	Y1 += 0.00000000008*np.cos(0.79426105202 + 327.4375699205*t)
	Y1 += 0.00000000007*np.cos(4.59822415945 + 278.5194664497*t)
	Y1 += 0.00000000008*np.cos(5.63930068564 + 458.8415197904*t)
	Y1 += 0.00000000007*np.cos(0.43203382811 + 528.9402055692*t)
	Y1 += 0.00000000007*np.cos(0.76705916667 + 530.44172462*t)
	Y1 += 0.00000000008*np.cos(4.46099447090 + 1585.8915015461*t)
	Y1 += 0.00000000009*np.cos(2.20436298259 + 31.019488637*t)
	Y1 += 0.00000000007*np.cos(2.71750635954 + 1158.5425511447*t)
	Y1 += 0.00000000007*np.cos(5.25570024840 + 20.6069278195*t)
	Y1 += 0.00000000007*np.cos(2.40405222005 + 425.6349830295*t)
	Y1 += 0.00000000007*np.cos(3.50836604374 + 431.264057322*t)
	Y1 += 0.00000000007*np.cos(1.75300700374 + 953.1077622329*t)
	Y1 += 0.00000000006*np.cos(0.33314344280 + 1048.3362299253*t)
	Y1 += 0.00000000006*np.cos(4.54559452887 + 601.7642506762*t)
	Y1 += 0.00000000006*np.cos(2.89252113944 + 69.3649725959*t)
	Y1 += 0.00000000007*np.cos(4.76015023992 + 558.0021407459*t)
	Y1 += 0.00000000008*np.cos(3.66343793703 + 228.276948965*t)
	Y1 += 0.00000000007*np.cos(4.41204133594 + 221.3758502853*t)
	Y1 += 0.00000000006*np.cos(2.40738361691 + 1165.6560981455*t)
	Y1 += 0.00000000006*np.cos(0.01573246447 + 8.0767548473*t)
	Y1 += 0.00000000006*np.cos(1.96764604578 + 295.0512286542*t)
	Y1 += 0.00000000007*np.cos(1.96227011480 + 45.2465826386*t)
	Y1 += 0.00000000006*np.cos(0.15099417807 + 241.7532834412*t)
	Y1 += 0.00000000006*np.cos(0.41129479661 + 313.2104759189*t)
	Y1 += 0.00000000006*np.cos(3.95802571920 + 1159.2933106701*t)
	Y1 += 0.00000000006*np.cos(4.49803481526 + 186.2117600641*t)
	Y1 += 0.00000000006*np.cos(5.79072032919 + 983.1158589136*t)
	Y1 += 0.00000000006*np.cos(6.01412605038 + 128.9562693151*t)
	Y1 += 0.00000000007*np.cos(2.79563557161 + 421.93232443*t)
	Y1 += 0.00000000006*np.cos(2.07270670843 + 23.5758732361*t)
	Y1 += 0.00000000007*np.cos(6.04497108744 + 230.7075831773*t)
	Y1 += 0.00000000006*np.cos(0.51992227470 + 80.7194894005*t)
	Y1 += 0.00000000005*np.cos(3.16289590584 + 387.2413149608*t)
	Y1 += 0.00000000006*np.cos(1.37475809876 + 2538.2485042536*t)
	Y1 += 0.00000000006*np.cos(2.72954939538 + 426.6463749858*t)
	Y1 += 0.00000000006*np.cos(3.54269187319 + 494.2662424425*t)
	Y1 += 0.00000000006*np.cos(0.16815043613 + 421.1815649046*t)
	Y1 += 0.00000000005*np.cos(1.19100214631 + 92.0470739547*t)
	Y1 += 0.00000000005*np.cos(4.53664008849 + 1251.3403846248*t)
	Y1 += 0.00000000006*np.cos(2.73998495017 + 68.5618234438*t)
	Y1 += 0.00000000005*np.cos(3.64390526925 + 1166.4068576709*t)
	Y1 += 0.00000000006*np.cos(1.55322241284 + 35.212274331*t)
	Y1 += 0.00000000005*np.cos(1.80435428469 + 1041.2226829245*t)
	Y1 += 0.00000000006*np.cos(5.50205577201 + 89.7594520943*t)
	Y1 += 0.00000000005*np.cos(3.38712516669 + 44.070926471*t)
	Y1 += 0.00000000006*np.cos(3.05256935232 + 188.9200730498*t)
	Y1 += 0.00000000005*np.cos(4.25922999784 + 78263.70942472259*t)
	Y1 += 0.00000000006*np.cos(4.23283059947 + 1891.2376709388*t)
	Y1 += 0.00000000005*np.cos(2.18932379818 + 46.2097904851*t)
	Y1 += 0.00000000005*np.cos(4.46609874857 + 162.0933701068*t)
	Y1 += 0.00000000005*np.cos(0.66097382878 + 205.4347889118*t)
	Y1 += 0.00000000005*np.cos(5.21179771886 + 1593.0050485469*t)
	Y1 += 0.00000000006*np.cos(6.23379482805 + 5.4166259714*t)
	Y1 += 0.00000000005*np.cos(6.03346324760 + 505.3119427064*t)
	Y1 += 0.00000000005*np.cos(2.17367426894 + 916.9322800554*t)
	Y1 += 0.00000000005*np.cos(0.64013502451 + 29.2049475286*t)
	Y1 += 0.00000000005*np.cos(3.51363623564 + 1080.7225711916*t)
	Y1 += 0.00000000005*np.cos(4.97953496675 + 14.0146456805*t)
	Y1 += 0.00000000005*np.cos(0.51698818497 + 88.7962442478*t)
	Y1 += 0.00000000005*np.cos(4.08794365187 + 154.0166152595*t)
	Y1 += 0.00000000005*np.cos(2.79015937613 + 41.0537969446*t)
	Y1 += 0.00000000005*np.cos(5.87885246993 + 439.1283638482*t)
	Y1 += 0.00000000006*np.cos(2.51299128730 + 347.8844390456*t)
	Y1 += 0.00000000006*np.cos(4.89665330264 + 512.2824773553*t)
	Y1 += 0.00000000005*np.cos(3.49486880744 + 778.4147831847*t)
	Y1 += 0.00000000006*np.cos(1.89186725600 + 2751.5475996916*t)
	Y1 += 0.00000000005*np.cos(1.40593163243 + 134.5853436076*t)
	Y1 += 0.00000000005*np.cos(4.97045994829 + 237.6781178262*t)
	Y1 += 0.00000000004*np.cos(4.40910062645 + 672.1406152284*t)
	Y1 += 0.00000000005*np.cos(4.30539423988 + 50.4025761791*t)
	Y1 += 0.00000000004*np.cos(5.19254582564 + 312.4597163935*t)
	Y1 += 0.00000000005*np.cos(3.26128860166 + 1069.6768709277*t)
	Y1 += 0.00000000006*np.cos(3.60171276442 + 696.5196376166*t)
	Y1 += 0.00000000005*np.cos(3.45043381496 + 498.6714764576*t)
	Y1 += 0.00000000006*np.cos(5.81420130998 + 426.5500067662*t)
	Y1 += 0.00000000004*np.cos(4.24223135959 + 68.8437077341*t)
	Y1 += 0.00000000005*np.cos(1.92308153633 + 945.9942152321*t)
	Y1 += 0.00000000005*np.cos(4.39801286539 + 54.1746707478*t)
	Y1 += 0.00000000004*np.cos(5.10290768552 + 33.1371007917*t)
	Y1 += 0.00000000004*np.cos(3.11218759329 + 710.7467316182*t)
	Y1 += 0.00000000004*np.cos(2.51922309877 + 679.2541622292*t)
	Y1 += 0.00000000005*np.cos(5.14267536259 + 300.6108669775*t)
	Y1 += 0.00000000005*np.cos(4.03184405759 + 560.7104537316*t)
	Y1 += 0.00000000005*np.cos(4.52503825820 + 305.3461693927*t)
	Y1 += 0.00000000004*np.cos(4.74372430470 + 1070.4276304531*t)
	Y1 += 0.00000000004*np.cos(0.63523381995 + 152.0108776894*t)
	Y1 += 0.00000000005*np.cos(1.80112800270 + 600.5404103988*t)
	Y1 += 0.00000000004*np.cos(4.57704452507 + 849.2642284889*t)
	Y1 += 0.00000000004*np.cos(1.91608807989 + 81.0013736908*t)
	Y1 += 0.00000000004*np.cos(1.24701283181 + 18849.2275499742*t)
	Y1 += 0.00000000004*np.cos(3.39351596474 + 746.9222137957*t)
	Y1 += 0.00000000004*np.cos(5.13064710784 + 611.4430983108*t)
	Y1 += 0.00000000005*np.cos(0.54073458961 + 182.279606801*t)
	Y1 += 0.00000000004*np.cos(4.13404557998 + 757.2171545342*t)
	Y1 += 0.00000000004*np.cos(2.62733309764 + 312.1990839626*t)
	Y1 += 0.00000000004*np.cos(4.12169541877 + 2317.8358618148*t)
	Y1 += 0.00000000004*np.cos(0.47183936992 + 2324.9494088156*t)
	Y1 += 0.00000000005*np.cos(3.75152504592 + 835.0371344873*t)
	Y1 += 0.00000000004*np.cos(0.19646748056 + 196.0336200506*t)
	Y1 += 0.00000000004*np.cos(3.22264415537 + 739.8086667949*t)
	Y1 += 0.00000000004*np.cos(1.51249981586 + 166.828672522*t)
	Y1 += 0.00000000005*np.cos(4.16544589772 + 32.2433289144*t)
	Y1 += 0.00000000004*np.cos(3.16847102979 + 970.5162499722*t)
	Y1 += 0.00000000004*np.cos(1.22637241875 + 1064.0477966352*t)
	Y1 += 0.00000000004*np.cos(1.25167189753 + 221.1634019642*t)
	Y1 += 0.00000000004*np.cos(0.47247654290 + 952.3570027075*t)
	Y1 += 0.00000000005*np.cos(2.88741075556 + 432.2272651685*t)
	Y1 += 0.00000000004*np.cos(0.61099360580 + 429.5189521828*t)
	Y1 += 0.00000000003*np.cos(5.07832575262 + 661.2379273164*t)
	Y1 += 0.00000000004*np.cos(6.09425485756 + 381.3516082374*t)
	Y1 += 0.00000000004*np.cos(5.63426885292 + 395.578702239*t)
	Y1 += 0.00000000003*np.cos(0.93359542515 + 227.3137411185*t)
	Y1 += 0.00000000004*np.cos(4.89804621575 + 1677.9385755008*t)
	Y1 += 0.00000000003*np.cos(1.67414862418 + 230.5645708254*t)
	Y1 += 0.00000000003*np.cos(0.61597689295 + 554.8207470082*t)
	Y1 += 0.00000000003*np.cos(2.11116737815 + 430.79097657*t)
	Y1 += 0.00000000003*np.cos(1.82839708948 + 148.5999892881*t)
	Y1 += 0.00000000003*np.cos(1.41412552298 + 150.5264049811*t)
	Y1 += 0.00000000004*np.cos(5.77022599962 + 59.8037450403*t)
	Y1 += 0.00000000003*np.cos(3.22119174668 + 776.9303104764*t)
	Y1 += 0.00000000003*np.cos(0.64456789097 + 95.3885263868*t)
	Y1 += 0.00000000004*np.cos(2.51532394255 + 547.0994528339*t)
	Y1 += 0.00000000003*np.cos(4.52599780974 + 120.358249606*t)
	Y1 += 0.00000000003*np.cos(1.49835001208 + 498.1983957056*t)
	Y1 += 0.00000000003*np.cos(5.54303395569 + 280.9671470045*t)
	Y1 += 0.00000000004*np.cos(4.23287658110 + 333.657345044*t)
	Y1 += 0.00000000003*np.cos(0.88390238607 + 426.0769260142*t)
	Y1 += 0.00000000004*np.cos(1.28591106549 + 196.6243208816*t)
	Y1 += 0.00000000004*np.cos(1.14722532028 + 111.4301614968*t)
	Y1 += 0.00000000003*np.cos(0.10691845516 + 432.0148168474*t)
	Y1 += 0.00000000003*np.cos(0.27991616640 + 5849.3641121146*t)
	Y1 += 0.00000000003*np.cos(3.72232280654 + 2641.3412784722*t)
	Y1 += 0.00000000003*np.cos(2.85150782065 + 6.2197751235*t)
	Y1 += 0.00000000003*np.cos(2.74003656022 + 199.2844497575*t)
	Y1 += 0.00000000003*np.cos(2.93435836852 + 206.706813299*t)
	Y1 += 0.00000000003*np.cos(4.19994093679 + 824.7421937488*t)
	Y1 += 0.00000000003*np.cos(4.44459326429 + 1176.7017984094*t)
	Y1 += 0.00000000003*np.cos(3.48375728607 + 2531.1349572528*t)
	Y1 += 0.00000000003*np.cos(5.68764293707 + 343.2185725996*t)
	Y1 += 0.00000000003*np.cos(2.67538476843 + 192.6921676185*t)
	Y1 += 0.00000000003*np.cos(4.65809367119 + 501.2367770914*t)
	Y1 += 0.00000000003*np.cos(4.36524690085 + 199.9657733137*t)
	Y1 += 0.00000000003*np.cos(1.56791574278 + 238.5718897035*t)
	Y1 += 0.00000000003*np.cos(1.50943252003 + 28.4541880032*t)
	Y1 += 0.00000000003*np.cos(1.70638280941 + 9779.5738083342*t)
	Y1 += 0.00000000003*np.cos(0.57617048599 + 1912.5783119412*t)
	Y1 += 0.00000000003*np.cos(4.91470925902 + 181.806526049*t)
	Y1 += 0.00000000003*np.cos(1.77878548079 + 617.8058857862*t)
	Y1 += 0.00000000003*np.cos(2.25511953715 + 767.3690829208*t)
	Y1 += 0.00000000003*np.cos(4.02619725623 + 188.1693135244*t)
	Y1 += 0.00000000003*np.cos(0.19036454807 + 184.9879197867*t)
	Y1 += 0.00000000003*np.cos(1.37546754264 + 427.1194557378*t)
	Y1 += 0.00000000003*np.cos(5.87232681349 + 214.5711198252*t)
	Y1 += 0.00000000003*np.cos(2.15889200669 + 212.0270710508*t)
	Y1 += 0.00000000003*np.cos(4.24478106072 + 183.2428146475*t)
	Y1 += 0.00000000003*np.cos(2.94755802459 + 129.9194771616*t)
	Y1 += 0.00000000003*np.cos(4.09892634083 + 597.3590166611*t)
	Y1 += 0.00000000003*np.cos(0.54792542025 + 938.1299087059*t)
	Y1 += 0.00000000003*np.cos(1.13500653011 + 70.1157321213*t)
	Y1 += 0.00000000003*np.cos(1.13993502060 + 244.318584075*t)
	Y1 += 0.00000000003*np.cos(3.18647743144 + 1567.7322542814*t)
	Y1 += 0.00000000003*np.cos(0.66423751204 + 1054.7160637432*t)
	Y1 += 0.00000000003*np.cos(1.05783089120 + 13362.4497067992*t)
	Y1 += 0.00000000003*np.cos(2.74220041329 + 1151.4290041439*t)
	Y1 += 0.00000000003*np.cos(6.01987463810 + 5863.5912061162*t)
	Y1 += 0.00000000003*np.cos(3.66597213442 + 226.6324175623*t)
	Y1 += 0.00000000004*np.cos(3.01448280004 + 563.6312150384*t)
	Y1 += 0.00000000003*np.cos(0.56020536939 + 504.561183181*t)
	Y1 += 0.00000000003*np.cos(0.08209488176 + 945.2434557067*t)
	Y1 += 0.00000000003*np.cos(1.95261315638 + 16.6747745564*t)
	Y1 += 0.00000000003*np.cos(6.05762261270 + 144.1465711632*t)
	Y1 += 0.00000000003*np.cos(1.44101553226 + 241.6102710893*t)
	Y1 += 0.00000000003*np.cos(4.50959081342 + 149.6750717192*t)
	Y1 += 0.00000000003*np.cos(0.16509004420 + 259.769518354*t)
	Y1 += 0.00000000003*np.cos(3.94823501116 + 537.5552716208*t)
	Y1 += 0.00000000003*np.cos(3.53404329080 + 521.8266585684*t)
	Y1 += 0.00000000003*np.cos(0.41212961912 + 79.4474650133*t)
	Y1 += 0.00000000002*np.cos(3.07207590151 + 960.2213092337*t)
	Y1 += 0.00000000003*np.cos(4.28612489555 + 1061.829610744*t)
	Y1 += 0.00000000002*np.cos(4.32422664943 + 546.956440482*t)
	Y1 += 0.00000000003*np.cos(3.06146670306 + 156.6767441354*t)
	Y1 += 0.00000000002*np.cos(1.63486779240 + 1098.7388061044*t)
	Y1 += 0.00000000003*np.cos(2.80451196921 + 637.4496057592*t)
	Y1 += 0.00000000003*np.cos(1.16271414275 + 9793.8009023358*t)
	Y1 += 0.00000000003*np.cos(4.28556965974 + 173.9422195228*t)
	Y1 += 0.00000000003*np.cos(2.21533745284 + 1056.9342496344*t)
	Y1 += 0.00000000002*np.cos(5.71662769418 + 76.4785195967*t)
	Y1 += 0.00000000002*np.cos(2.81376509752 + 147.1155165798*t)
	Y1 += 0.00000000002*np.cos(2.11369744657 + 73.0846775379*t)
	Y1 += 0.00000000003*np.cos(1.02379910840 + 39.3568759152*t)
	Y1 += 0.00000000003*np.cos(4.82119114104 + 556.5176680376*t)
	Y1 += 0.00000000002*np.cos(3.14311151538 + 244.791664827*t)
	Y1 += 0.00000000003*np.cos(4.00814185003 + 212.4053235607*t)
	Y1 += 0.00000000003*np.cos(4.02307697015 + 214.1928673153*t)
	Y1 += 0.00000000003*np.cos(4.30066080154 + 206.233732547*t)
	Y1 += 0.00000000002*np.cos(4.38847101834 + 115.8835796217*t)
	Y1 += 0.00000000003*np.cos(3.46436300084 + 2332.0629558164*t)
	Y1 += 0.00000000002*np.cos(0.03501449150 + 116.4260963429*t)
	Y1 += 0.00000000003*np.cos(4.70398688083 + 2.9207613068*t)
	Y1 += 0.00000000002*np.cos(0.58873624989 + 220.364458329*t)
	Y1 += 0.00000000003*np.cos(3.27371209320 + 60.7669528868*t)
	Y1 += 0.00000000002*np.cos(4.66464361308 + 68.1893164283*t)
	Y1 += 0.00000000002*np.cos(3.90921171113 + 238.4288773516*t)
	Y1 += 0.00000000003*np.cos(3.91156191123 + 45.5766510387*t)
	Y1 += 0.00000000002*np.cos(1.68077121292 + 157.6399519819*t)
	Y1 += 0.00000000002*np.cos(2.46440714355 + 258.8757464767*t)
	Y1 += 0.00000000002*np.cos(4.42896551558 + 572.2292347475*t)
	Y1 += 0.00000000002*np.cos(2.55992427117 + 411.620337349*t)
	Y1 += 0.00000000003*np.cos(3.30145154159 + 19.643719973*t)
	Y1 += 0.00000000002*np.cos(4.55139938315 + 1053.9653042178*t)
	Y1 += 0.00000000002*np.cos(0.22827702637 + 535.9107402181*t)
	Y1 += 0.00000000002*np.cos(4.41302788419 + 988.532484885*t)
	Y1 += 0.00000000003*np.cos(2.85243375789 + 125.9873238985*t)
	Y1 += 0.00000000002*np.cos(1.12812237680 + 31.5407534988*t)
	Y1 += 0.00000000002*np.cos(3.08242169807 + 464.7312265138*t)
	Y1 += 0.00000000002*np.cos(6.25577465024 + 1514.2912967165*t)
	Y1 += 0.00000000002*np.cos(5.41469941455 + 326.6868103951*t)
	Y1 += 0.00000000002*np.cos(5.47916086166 + 864.2420820159*t)
	Y1 += 0.00000000002*np.cos(1.06140573319 + 282.4516197128*t)
	Y1 += 0.00000000002*np.cos(4.80102912211 + 627.3671133418*t)
	Y1 += 0.00000000002*np.cos(4.27109903933 + 2428.0421830342*t)
	Y1 += 0.00000000003*np.cos(0.38056225347 + 273.1028404783*t)
	Y1 += 0.00000000002*np.cos(2.95934287457 + 357.4456666012*t)
	Y1 += 0.00000000002*np.cos(6.12823756827 + 186.472392495*t)
	Y1 += 0.00000000002*np.cos(0.93619730720 + 523.4711899711*t)
	Y1 += 0.00000000002*np.cos(5.15800386599 + 74.0308390419*t)
	Y1 += 0.00000000002*np.cos(3.40528256310 + 7.8643065262*t)
	Y1 += 0.00000000002*np.cos(4.41666723984 + 267.4737661858*t)
	Y1 += 0.00000000002*np.cos(3.19052718716 + 106.9767433719*t)
	Y1 += 0.00000000002*np.cos(4.79341833598 + 1059.3337460794*t)
	Y1 += 0.00000000002*np.cos(5.79369557277 + 75.5323580927*t)
	Y1 += 0.00000000002*np.cos(2.97188495962 + 394.3548619616*t)
	Y1 += 0.00000000002*np.cos(2.88556704278 + 1286.9081196288*t)
	Y1 += 0.00000000002*np.cos(3.15732830451 + 504.4181708291*t)
	Y1 += 0.00000000002*np.cos(3.60779142066 + 1173.5204046717*t)
	Y1 += 0.00000000002*np.cos(3.22327905779 + 531.3354964973*t)
	Y1 += 0.00000000002*np.cos(4.25899924417 + 528.0464336919*t)
	Y1 += 0.00000000002*np.cos(3.49313395703 + 732.6951197941*t)
	Y1 += 0.00000000002*np.cos(3.43300131965 + 5230.807466803*t)
	Y1 += 0.00000000002*np.cos(0.92053233477 + 491.5579294568*t)
	Y1 += 0.00000000002*np.cos(1.50564838899 + 638.4128136057*t)
	Y1 += 0.00000000002*np.cos(0.13368292105 + 567.8240007324*t)
	Y1 += 0.00000000002*np.cos(3.26062753913 + 462.0229135281*t)
	Y1 += 0.00000000002*np.cos(5.81824205609 + 4.192785694*t)
	Y1 += 0.00000000002*np.cos(3.77916171170 + 1064.7985561606*t)
	Y1 += 0.00000000002*np.cos(2.95760664555 + 339.2864193365*t)
	Y1 += 0.00000000002*np.cos(2.07655563562 + 6275.9623029906*t)
	Y1 += 0.00000000002*np.cos(4.25675437170 + 570.7447620392*t)
	Y1 += 0.00000000002*np.cos(5.08235384239 + 1077.5411774539*t)
	Y1 += 0.00000000002*np.cos(1.42730921408 + 6290.1893969922*t)
	Y1 += 0.00000000002*np.cos(3.11817367090 + 460.5384408198*t)
	Y1 += 0.00000000002*np.cos(0.02447324341 + 81.3738807063*t)
	Y1 += 0.00000000002*np.cos(4.34244254893 + 1493.093668066*t)
	Y1 += 0.00000000002*np.cos(4.32494971180 + 554.9637593601*t)
	Y1 += 0.00000000002*np.cos(4.88317820252 + 1062.302691496*t)
	Y1 += 0.00000000002*np.cos(6.18819820129 + 329.7251917809*t)
	Y1 += 0.00000000002*np.cos(4.27946751620 + 154.979823106*t)
	Y1 += 0.00000000002*np.cos(3.87847666768 + 2207.6295405954*t)
	Y1 += 0.00000000002*np.cos(4.85668661800 + 9161.0171630226*t)
	Y1 += 0.00000000002*np.cos(3.76999626134 + 5216.5803728014*t)
	Y1 += 0.00000000002*np.cos(3.50183258103 + 10206.1719992102*t)
	Y1 += 0.00000000002*np.cos(3.85268592734 + 2634.2277314714*t)
	Y1 += 0.00000000002*np.cos(2.85404500399 + 10220.3990932118*t)
	Y1 += 0.00000000002*np.cos(0.54766082415 + 569.0478410098*t)
	Y1 += 0.00000000002*np.cos(0.25390066162 + 211.0114735776*t)
	Y1 += 0.00000000002*np.cos(1.49413285138 + 215.5867172984*t)
	Y1 += 0.00000000002*np.cos(4.51116983682 + 27.0873353739*t)
	Y1 += 0.00000000002*np.cos(3.13412922369 + 427.3489504014*t)
	Y1 += 0.00000000002*np.cos(2.21000124599 + 195.8906076987*t)
	Y1 += 0.00000000002*np.cos(4.20293195329 + 193.655375465*t)
	Y1 += 0.00000000002*np.cos(3.34461455493 + 143.6253063014*t)
	Y1 += 0.00000000002*np.cos(5.19596883971 + 9146.790069021*t)
	Y1 += 0.00000000002*np.cos(3.46985315556 + 187.6962327724*t)
	Y1 += 0.00000000002*np.cos(3.89820699478 + 420.9691165835*t)
	Y1 += 0.00000000002*np.cos(5.70202328723 + 342.2553647531*t)
	Y1 += 0.00000000002*np.cos(1.37422853966 + 1058.4187223427*t)
	Y1 += 0.00000000002*np.cos(2.51108244669 + 432.7485300303*t)
	Y1 += 0.00000000002*np.cos(5.96593279473 + 692.5874843535*t)
	Y1 += 0.00000000002*np.cos(3.20830347652 + 58.1068240109*t)
	Y1 += 0.00000000002*np.cos(4.07929140550 + 856.3777754897*t)
	Y1 += 0.00000000002*np.cos(1.70804415643 + 1059.430114299*t)
	Y1 += 0.00000000002*np.cos(6.03506057835 + 66.9172920411*t)
	Y1 += 0.00000000002*np.cos(0.11244181660 + 135.5485514541*t)
	Y1 += 0.00000000002*np.cos(5.42909715908 + 422.405405182*t)
	Y1 += 0.00000000002*np.cos(5.04147876842 + 233.9060232575*t)
	Y1 += 0.00000000001*np.cos(4.13942778568 + 598.8434893694*t)
	Y1 += 0.00000000002*np.cos(1.76612707799 + 240.125798381*t)
	Y1 += 0.00000000002*np.cos(2.67737558460 + 472.1748419147*t)
	Y1 += 0.00000000001*np.cos(1.02693136508 + 104351.61256629678*t)
	Y1 += 0.00000000002*np.cos(0.08477095585 + 423.6774295692*t)
	Y1 += 0.00000000002*np.cos(4.83981166713 + 528.2064923863*t)
	Y1 += 0.00000000001*np.cos(5.29490934815 + 149.45132255*t)
	Y1 += 0.00000000002*np.cos(4.36299251699 + 26087.9031415742*t)
	Y1 += 0.00000000001*np.cos(2.41374931369 + 1474.9344208013*t)
	Y1 += 0.00000000001*np.cos(2.78513411351 + 488.8496164711*t)
	Y1 += 0.00000000001*np.cos(4.37473074790 + 254.9435932136*t)
	Y1 += 0.00000000002*np.cos(5.90311974004 + 107.7586406646*t)
	Y1 += 0.00000000002*np.cos(1.78334570034 + 259.5088859231*t)
	Y1 += 0.00000000002*np.cos(5.89998053657 + 41.6444977756*t)
	Y1 += 0.00000000001*np.cos(2.21493064855 + 3067.9394693482*t)
	Y1 += 0.00000000001*np.cos(2.68570647593 + 6283.0758499914*t)
	Y1 += 0.00000000002*np.cos(6.27435757956 + 24.3790223882*t)
	Y1 += 0.00000000002*np.cos(4.17342626797 + 1364.7280995819*t)
	Y1 += 0.00000000002*np.cos(0.08548639180 + 135.336103133*t)
	Y1 += 0.00000000001*np.cos(1.71341722642 + 486.4019359163*t)
	Y1 += 0.00000000001*np.cos(3.29312751256 + 1056.4611688824*t)
	Y1 += 0.00000000001*np.cos(4.64149585974 + 120.9913890524*t)
	Y1 += 0.00000000002*np.cos(5.12723388834 + 1060.3451380357*t)
	Y1 += 0.00000000002*np.cos(3.64850037062 + 252.6559713532*t)
	Y1 += 0.00000000001*np.cos(0.36034329711 + 334.5511169213*t)
	Y1 += 0.00000000001*np.cos(4.39466029867 + 295.1942410061*t)
	Y1 += 0.00000000001*np.cos(1.10134326147 + 842.9014410135*t)
	Y1 += 0.00000000001*np.cos(1.13303550116 + 264.5048207692*t)
	Y1 += 0.00000000002*np.cos(2.68418641726 + 531.1754378029*t)
	Y1 += 0.00000000001*np.cos(4.78127054633 + 650.1922270525*t)
	Y1 += 0.00000000001*np.cos(2.40609836860 + 291.262087743*t)
	Y1 += 0.00000000001*np.cos(2.09313561852 + 724.8308132679*t)
	Y1 += 0.00000000002*np.cos(2.36362156274 + 73.88782669*t)
	Y1 += 0.00000000002*np.cos(2.31578087326 + 75.6753704446*t)
	Y1 += 0.00000000002*np.cos(0.03996600393 + 850.0149880143*t)
	Y1 += 0.00000000002*np.cos(2.09864893203 + 51.2057253312*t)
	Y1 += 0.00000000001*np.cos(3.29683770430 + 418.5214360287*t)
	Y1 += 0.00000000002*np.cos(2.45122124390 + 22.633917249*t)
	Y1 += 0.00000000001*np.cos(0.69053592913 + 1134.1635287565*t)
	Y1 += 0.00000000001*np.cos(1.82895661083 + 1091.6252591036*t)
	Y1 += 0.00000000002*np.cos(3.63498067900 + 229.9738699944*t)
	Y1 += 0.00000000001*np.cos(2.23595051816 + 977.4867846211*t)
	Y1 += 0.00000000001*np.cos(1.81960663117 + 72.4939767069*t)
	Y1 += 0.00000000001*np.cos(2.85979580483 + 77.0692204277*t)
	Y1 += 0.00000000001*np.cos(4.59913476835 + 1269.4996318895*t)
	Y1 += 0.00000000002*np.cos(4.99308283862 + 82.6459050935*t)
	Y1 += 0.00000000001*np.cos(4.70410533706 + 184.7272873558*t)
	Y1 += 0.00000000001*np.cos(4.75393153666 + 1439.5096981492*t)
	Y1 += 0.00000000001*np.cos(5.30756251605 + 1354.4331588434*t)
	Y1 += 0.00000000002*np.cos(5.42740175778 + 373.0142209592*t)
	Y1 += 0.00000000001*np.cos(3.31619768089 + 448.6895914038*t)
	Y1 += 0.00000000001*np.cos(3.24600200410 + 7.4223635415*t)
	Y1 += 0.00000000001*np.cos(3.13097037272 + 44.7253177768*t)
	Y1 += 0.00000000001*np.cos(2.73545465146 + 558.1451530978*t)
	Y1 += 0.00000000001*np.cos(0.71587254604 + 201.5196819912*t)
	Y1 += 0.00000000001*np.cos(4.17375362055 + 225.0785088848*t)
	Y1 += 0.00000000001*np.cos(0.03539244562 + 43.2890291783*t)
	Y1 += 0.00000000001*np.cos(3.70339401072 + 25.2727942655*t)
	Y1 += 0.00000000002*np.cos(1.67137097926 + 739.0579072695*t)
	Y1 += 0.00000000001*np.cos(5.84679681094 + 491.8185618877*t)
	Y1 += 0.00000000001*np.cos(0.93643099423 + 428.0826635843*t)
	Y1 += 0.00000000001*np.cos(2.64823517322 + 171.6545976624*t)
	Y1 += 0.00000000001*np.cos(0.00815638007 + 1446.62324515*t)
	Y1 += 0.00000000001*np.cos(1.21528959287 + 155.7829722581*t)
	Y1 += 0.00000000001*np.cos(1.83799490254 + 991.7138786227*t)
	Y1 += 0.00000000001*np.cos(0.74017607185 + 425.1137181677*t)
	Y1 += 0.00000000001*np.cos(3.80212026560 + 1475.6851803267*t)
	Y1 += 0.00000000001*np.cos(1.27500486752 + 2854.6403739102*t)
	Y1 += 0.00000000001*np.cos(5.37097302281 + 369.9758395734*t)
	Y1 += 0.00000000001*np.cos(3.99158949615 + 364.3467652809*t)
	Y1 += 0.00000000001*np.cos(4.52707012896 + 520.129737539*t)
	Y1 += 0.00000000001*np.cos(4.78661320883 + 1994.3304451574*t)
	Y1 += 0.00000000001*np.cos(2.14977480942 + 1482.0479678021*t)
	Y1 += 0.00000000001*np.cos(0.17477502107 + 658.0565335787*t)
	Y1 += 0.00000000001*np.cos(3.96416667976 + 98.3574718034*t)
	Y1 += 0.00000000001*np.cos(5.69421265027 + 42.5382696529*t)
	Y1 += 0.00000000001*np.cos(4.65849455361 + 219.891377577*t)
	Y1 += 0.00000000001*np.cos(2.77049765217 + 433.7599219866*t)
	Y1 += 0.00000000001*np.cos(3.70171276331 + 409.9234163196*t)
	Y1 += 0.00000000001*np.cos(3.68817958962 + 2950.619601128*t)
	Y1 += 0.00000000001*np.cos(0.05752383974 + 1141.1340634054*t)
	Y1 += 0.00000000001*np.cos(0.48265974775 + 1063.5747158832*t)
	Y1 += 0.00000000001*np.cos(1.83857308274 + 1464.6394800628*t)
	Y1 += 0.00000000001*np.cos(2.20975363476 + 292.0128472684*t)
	Y1 += 0.00000000001*np.cos(4.19264936275 + 397.3932433474*t)
	Y1 += 0.00000000001*np.cos(2.58885686529 + 32.7164096664*t)
	Y1 += 0.00000000001*np.cos(2.45534850580 + 205.6642835754*t)
	Y1 += 0.00000000001*np.cos(3.40261971116 + 1482.7987273275*t)
	Y1 += 0.00000000001*np.cos(6.06079671120 + 49.1787359017*t)
	Y1 += 0.00000000001*np.cos(3.36874421575 + 211.6021744086*t)
	Y1 += 0.00000000001*np.cos(1.52088195084 + 214.9960164674*t)
	Y1 += 0.00000000001*np.cos(6.09072476788 + 539.2521926502*t)
	Y1 += 0.00000000001*np.cos(2.07913854408 + 91.4563731237*t)
	Y1 += 0.00000000001*np.cos(3.28965441039 + 2847.5268269094*t)
	Y1 += 0.00000000001*np.cos(2.48697852384 + 361.3778198643*t)
	Y1 += 0.00000000001*np.cos(2.43406090927 + 220.9339073006*t)
	Y1 += 0.00000000001*np.cos(2.46490677835 + 465.9550667912*t)
	Y1 += 0.00000000001*np.cos(5.65268635199 + 189.7232222019*t)
	Y1 += 0.00000000001*np.cos(5.99966516425 + 61.448276443*t)
	Y1 += 0.00000000001*np.cos(4.73589775737 + 586.3133163972*t)
	Y1 += 0.00000000001*np.cos(0.94448751019 + 406.954470903*t)
	Y1 += 0.00000000001*np.cos(2.87479224414 + 170.7608257851*t)
	Y1 += 0.00000000001*np.cos(0.46948421466 + 120.5012619579*t)
	Y1 += 0.00000000001*np.cos(1.42038295073 + 211.6545640353*t)
	Y1 += 0.00000000001*np.cos(0.32765056227 + 214.9436268407*t)
	Y1 += 0.00000000001*np.cos(3.12243467050 + 418.0001711669*t)
	Y1 += 0.00000000001*np.cos(4.43777830473 + 388.4651552382*t)
	Y1 += 0.00000000001*np.cos(6.16520049664 + 19.1224551112*t)
	Y1 += 0.00000000001*np.cos(5.95922226198 + 255.8373650909*t)
	Y1 += 0.00000000001*np.cos(1.87132620908 + 236.8749686741*t)
	Y1 += 0.00000000001*np.cos(3.51249504378 + 536.8526962052*t)
	Y1 += 0.00000000001*np.cos(0.82819060458 + 522.529233984*t)
	Y1 += 0.00000000001*np.cos(4.80518650654 + 2758.6611466924*t)
	Y1 += 0.00000000001*np.cos(5.02248998685 + 2435.155730035*t)
	Y1 += 0.00000000001*np.cos(6.06577966570 + 405.9912630565*t)
	Y1 += 0.00000000001*np.cos(5.38561675035 + 4164.311989613*t)
	Y1 += 0.00000000001*np.cos(2.66240237827 + 403.0223176399*t)
	Y1 += 0.00000000001*np.cos(1.39320171448 + 223.3334037456*t)
	Y1 += 0.00000000001*np.cos(3.49642445211 + 203.2647871304*t)
	Y1 += 0.00000000001*np.cos(1.82337627866 + 201.9927627432*t)
	Y1 += 0.00000000001*np.cos(3.06624988793 + 224.6054281328*t)
	Y1 += 0.00000000001*np.cos(0.18336428542 + 170.0100662597*t)
	Y1 += 0.00000000001*np.cos(4.72269036599 + 380.12776796*t)
	Y1 += 0.00000000001*np.cos(4.45060305823 + 1969.2006632438*t)
	Y1 += 0.00000000001*np.cos(5.51731666633 + 775.233389447*t)
	Y1 += 0.00000000001*np.cos(5.65559652159 + 46.470422916*t)
	Y1 += 0.00000000001*np.cos(4.74663576123 + 6062.6632075526*t)
	Y1 += 0.00000000001*np.cos(0.41891403323 + 731.9443602687*t)
	Y1 += 0.00000000001*np.cos(4.86799277271 + 468.2426886516*t)
	Y1 += 0.00000000001*np.cos(5.69342138022 + 561.1835344836*t)
	Y1 += 0.00000000001*np.cos(4.03962015957 + 441.576044403*t)
	Y1 += 0.00000000001*np.cos(2.92547650185 + 92.7978334801*t)
	Y1 += 0.00000000001*np.cos(4.92514598271 + 782.3469364478*t)
	Y1 += 0.00000000001*np.cos(2.16953945169 + 3384.3313390048*t)
	Y1 += 0.00000000001*np.cos(1.58682154010 + 57.255490749*t)
	Y1 += 0.00000000001*np.cos(3.95685518773 + 2545.3620512544*t)
	Y1 += 0.00000000001*np.cos(0.49427187598 + 1432.3961511484*t)
	Y1 += 0.00000000001*np.cos(0.53234525648 + 8094.5216858326*t)
	Y1 += 0.00000000001*np.cos(0.31187394017 + 33.0252262071*t)
	Y1 += 0.00000000001*np.cos(6.16695505816 + 9992.8729037722*t)
	Y1 += 0.00000000001*np.cos(0.31468391615 + 536.7563279856*t)
	Y1 += 0.00000000001*np.cos(4.02600173222 + 522.6256022036*t)
	Y1 += 0.00000000001*np.cos(5.59137701229 + 100.6450936638*t)
	Y1 += 0.00000000001*np.cos(1.75389649920 + 11.3063326948*t)
	Y1 += 0.00000000001*np.cos(1.56614581861 + 477.8039162072*t)
	Y1 += 0.00000000001*np.cos(5.28106838880 + 425.8474313506*t)
	Y1 += 0.00000000001*np.cos(3.13615202063 + 2420.9286360334*t)
	Y1 += 0.00000000001*np.cos(5.73687516892 + 487.1526954417*t)
	Y1 += 0.00000000001*np.cos(1.70013445431 + 128.3655684841*t)
	Y1 += 0.00000000001*np.cos(0.77718146995 + 39.405060025*t)
	Y1 += 0.00000000001*np.cos(3.56340579640 + 36.8610112506*t)
	Y1 += 0.00000000001*np.cos(3.64081162235 + 69.6737891366*t)
	Y1 += 0.00000000001*np.cos(1.77011080502 + 43.5496616092*t)
	Y1 += 0.00000000001*np.cos(0.89553424537 + 17.2654753874*t)
	Y1 += 0.00000000001*np.cos(0.88127397089 + 3803.81598288*t)
	Y1 += 0.00000000001*np.cos(1.12340012683 + 84.9335269539*t)
	Y1 += 0.00000000001*np.cos(2.70733833124 + 473.068613792*t)
	Y1 += 0.00000000001*np.cos(3.74118532285 + 409.1897031367*t)
	Y1 += 0.00000000001*np.cos(0.67814541025 + 220.5245170234*t)
	Y1 += 0.00000000001*np.cos(5.35523608655 + 4539.6924964118*t)
	Y1 += 0.00000000001*np.cos(4.33917242351 + 33.4671691918*t)
	Y1 += 0.00000000001*np.cos(0.93030615448 + 857.1285350151*t)
	Y1 += 0.00000000001*np.cos(3.10630847749 + 92.3077063856*t)
	Y1 += 0.00000000001*np.cos(5.24183699624 + 344.8460576598*t)
	Y1 += 0.00000000001*np.cos(5.39326866741 + 608.404716925*t)
	Y1 += 0.00000000001*np.cos(3.80540835421 + 815.0633461142*t)
	Y1 += 0.00000000001*np.cos(5.15197668342 + 100.3844612329*t)
	Y1 += 0.00000000001*np.cos(4.96186857942 + 8617.0991039264*t)
	Y1 += 0.00000000001*np.cos(0.64538179149 + 184.0941479094*t)
	Y1 += 0.00000000001*np.cos(2.68697465913 + 9153.9036160218*t)
	Y1 += 0.00000000001*np.cos(1.10244402543 + 5636.0650166766*t)
	Y1 += 0.00000000001*np.cos(1.67426725605 + 638.9340784675*t)
	Y1 += 0.00000000001*np.cos(4.49147743251 + 55.1378785943*t)
	Y1 += 0.00000000001*np.cos(0.07229277478 + 902.7051860538*t)
	Y1 += 0.00000000001*np.cos(4.82030088303 + 151.260118164*t)
	Y1 += 0.00000000001*np.cos(2.72235307477 + 79.1868325824*t)
	Y1 += 0.00000000001*np.cos(4.11491504396 + 1578.7779545453*t)
	Y1 += 0.00000000001*np.cos(3.85535836500 + 3810.9295298808*t)
	Y1 += 0.00000000001*np.cos(1.26868352153 + 67.8804998876*t)
	Y1 += 0.00000000001*np.cos(1.03859109860 + 79.889407998*t)
	Y1 += 0.00000000001*np.cos(6.19726985235 + 77204.32749453338*t)
	Y1 += 0.00000000001*np.cos(5.66962891894 + 455.0523788792*t)
	Y1 += 0.00000000001*np.cos(2.10184940043 + 6076.8903015542*t)
	Y1 += 0.00000000001*np.cos(3.69212458235 + 521.6142102473*t)
	Y1 += 0.00000000001*np.cos(0.64856106602 + 537.7677199419*t)
	Y1 += 0.00000000001*np.cos(5.24552391338 + 8631.326197928*t)
	Y1 += 0.00000000001*np.cos(5.10232765199 + 13.3333221243*t)
	Y1 += 0.00000000001*np.cos(5.46466510691 + 640.8604941605*t)
	Y1 += 0.00000000001*np.cos(4.57975016194 + 254.3528923826*t)
	Y1 += 0.00000000001*np.cos(5.20115319331 + 88.1149206916*t)
	Y1 += 0.00000000001*np.cos(1.11136134324 + 319.3126309634*t)
	Y1 += 0.00000000001*np.cos(0.35675553051 + 1059.903195051*t)
	return Y1*t




def Sun_Y2 (t): # 470 terms of order 2

	Y2 = 0.
	Y2 += 0.00000160849*np.cos(2.83104666823 + 206.1855484372*t)
	Y2 += 0.00000155973*np.cos(5.19309730583 + 220.4126424388*t)
	Y2 += 0.00000118316*np.cos(5.70681506981 + 522.5774180938*t)
	Y2 += 0.00000115781*np.cos(1.78259431361 + 536.8045120954*t)
	Y2 += 0.00000103374*np.cos(4.03691274682 + 213.299095438*t)
	Y2 += 0.00000065392*np.cos(4.05826871786 + 426.598190876*t)
	Y2 += 0.00000073065*np.cos(0.61752643976 + 529.6909650946*t)
	Y2 -= 0.00000055814
	Y2 += 0.00000039447*np.cos(0.41095552166 + 1059.3819301892*t)
	Y2 += 0.00000014254*np.cos(4.25680464915 + 433.7117378768*t)
	Y2 += 0.00000014479*np.cos(0.14336346755 + 7.1135470008*t)
	Y2 += 0.00000012723*np.cos(1.91903810105 + 419.4846438752*t)
	Y2 += 0.00000009344*np.cos(3.14385567645 + 639.897286314*t)
	Y2 += 0.00000007720*np.cos(5.06798604557 + 227.5261894396*t)
	Y2 += 0.00000006795*np.cos(2.30303656447 + 1066.49547719*t)
	Y2 += 0.00000005452*np.cos(5.20193437243 + 1052.2683831884*t)
	Y2 += 0.00000005040*np.cos(5.84239832938 + 515.463871093*t)
	Y2 += 0.00000003852*np.cos(0.87182418595 + 1589.0728952838*t)
	Y2 += 0.00000003729*np.cos(2.96611895542 + 199.0720014364*t)
	Y2 += 0.00000003521*np.cos(1.65043749771 + 543.9180590962*t)
	Y2 += 0.00000001351*np.cos(0.59351678849 + 316.3918696566*t)
	Y2 += 0.00000001409*np.cos(4.65471130275 + 216.4804891757*t)
	Y2 += 0.00000001321*np.cos(3.39383854482 + 647.0108333148*t)
	Y2 += 0.00000001368*np.cos(3.38543777835 + 210.1177017003*t)
	Y2 += 0.00000001717*np.cos(0.02861328541 + 14.2270940016*t)
	Y2 += 0.00000000974*np.cos(2.45036377276 + 853.196381752*t)
	Y2 += 0.00000000950*np.cos(2.81842708673 + 632.7837393132*t)
	Y2 += 0.00000000848*np.cos(6.23917434526 + 526.5095713569*t)
	Y2 += 0.00000000806*np.cos(2.96434145307 + 103.0927742186*t)
	Y2 += 0.00000000825*np.cos(1.24361863355 + 532.8723588323*t)
	Y2 += 0.00000000761*np.cos(4.73161044526 + 209.3669421749*t)
	Y2 += 0.00000000733*np.cos(3.30972792259 + 217.2312487011*t)
	Y2 += 0.00000000885*np.cos(0.58376168802 + 110.2063212194*t)
	Y2 += 0.00000000689*np.cos(4.21955395780 + 440.8252848776*t)
	Y2 += 0.00000000631*np.cos(5.67308971270 + 117.3198682202*t)
	Y2 += 0.00000000600*np.cos(3.56706010534 + 323.5054166574*t)
	Y2 += 0.00000000549*np.cos(3.24495575230 + 949.1756089698*t)
	Y2 += 0.00000000606*np.cos(3.86357846284 + 95.9792272178*t)
	Y2 += 0.00000000726*np.cos(5.43722942949 + 74.7815985673*t)
	Y2 += 0.00000000545*np.cos(4.73162468373 + 1045.1548361876*t)
	Y2 += 0.00000000599*np.cos(4.43359462367 + 735.8765135318*t)
	Y2 += 0.00000000490*np.cos(1.25898273127 + 525.7588118315*t)
	Y2 += 0.00000000488*np.cos(6.22654201321 + 533.6231183577*t)
	Y2 += 0.00000000437*np.cos(2.81553406247 + 1596.1864422846*t)
	Y2 += 0.00000000519*np.cos(4.53503189245 + 149.5631971346*t)
	Y2 += 0.00000000317*np.cos(1.28846217460 + 2118.7638603784*t)
	Y2 += 0.00000000349*np.cos(4.12933332026 + 63.7358983034*t)
	Y2 += 0.00000000337*np.cos(1.63942541135 + 412.3710968744*t)
	Y2 += 0.00000000270*np.cos(5.28007746957 + 1581.959348283*t)
	Y2 += 0.00000000260*np.cos(4.50952770985 + 625.6701923124*t)
	Y2 += 0.00000000237*np.cos(0.07292901465 + 70.8494453042*t)
	Y2 += 0.00000000227*np.cos(4.92862031663 + 234.6397364404*t)
	Y2 += 0.00000000219*np.cos(5.43349299793 + 11.0457002639*t)
	Y2 += 0.00000000256*np.cos(5.25900695618 + 956.2891559706*t)
	Y2 += 0.00000000218*np.cos(4.61617873387 + 78.7137518304*t)
	Y2 += 0.00000000283*np.cos(0.60090092021 + 85.8272988312*t)
	Y2 += 0.00000000211*np.cos(3.29348428114 + 942.062061969*t)
	Y2 += 0.00000000226*np.cos(3.69462756239 + 73.297125859*t)
	Y2 += 0.00000000235*np.cos(0.31453942563 + 36.6485629295*t)
	Y2 += 0.00000000213*np.cos(2.54349021425 + 309.2783226558*t)
	Y2 += 0.00000000224*np.cos(4.02383631251 + 39.6175083461*t)
	Y2 += 0.00000000231*np.cos(2.66318410477 + 202.2533951741*t)
	Y2 += 0.00000000187*np.cos(1.29115653830 + 1169.5882514086*t)
	Y2 += 0.00000000167*np.cos(2.07259165182 + 1073.6090241908*t)
	Y2 += 0.00000000196*np.cos(5.64541899687 + 224.3447957019*t)
	Y2 += 0.00000000158*np.cos(5.13689612572 + 1155.361157407*t)
	Y2 += 0.00000000137*np.cos(0.50600690701 + 742.9900605326*t)
	Y2 += 0.00000000135*np.cos(5.63458486706 + 138.5174968707*t)
	Y2 += 0.00000000148*np.cos(1.53909219281 + 76.2660712756*t)
	Y2 += 0.00000000133*np.cos(6.00639174435 + 508.3503240922*t)
	Y2 += 0.00000000126*np.cos(3.76226961231 + 330.6189636582*t)
	Y2 += 0.00000000126*np.cos(2.61435997717 + 860.3099287528*t)
	Y2 += 0.00000000158*np.cos(2.17797348306 + 38.1330356378*t)
	Y2 += 0.00000000115*np.cos(4.52412782775 + 223.5940361765*t)
	Y2 += 0.00000000110*np.cos(4.93056089704 + 71.6002048296*t)
	Y2 += 0.00000000115*np.cos(3.76754615650 + 429.7795846137*t)
	Y2 += 0.00000000106*np.cos(6.02834271847 + 77.962992305*t)
	Y2 += 0.00000000123*np.cos(4.57966985938 + 728.762966531*t)
	Y2 += 0.00000000105*np.cos(6.21526366678 + 1162.4747044078*t)
	Y2 += 0.00000000102*np.cos(3.63292130858 + 422.6660376129*t)
	Y2 += 0.00000000084*np.cos(4.77208861984 + 124.433415221*t)
	Y2 += 0.00000000074*np.cos(4.08123538694 + 88.865680217*t)
	Y2 += 0.00000000076*np.cos(2.63432357020 + 423.4167971383*t)
	Y2 += 0.00000000073*np.cos(5.78330657332 + 1265.5674786264*t)
	Y2 += 0.00000000071*np.cos(1.48891806144 + 551.031606097*t)
	Y2 += 0.00000000081*np.cos(0.13371582190 + 519.3960243561*t)
	Y2 += 0.00000000068*np.cos(3.39472444791 + 654.1243803156*t)
	Y2 += 0.00000000072*np.cos(6.15951862716 + 21.3406410024*t)
	Y2 += 0.00000000060*np.cos(3.13717737901 + 191.9584544356*t)
	Y2 += 0.00000000065*np.cos(3.55971117777 + 203.0041546995*t)
	Y2 += 0.00000000064*np.cos(1.05451249819 + 539.9859058331*t)
	Y2 += 0.00000000061*np.cos(5.33630384952 + 838.9692877504*t)
	Y2 += 0.00000000061*np.cos(0.00617004446 + 3.1813937377*t)
	Y2 += 0.00000000047*np.cos(3.46367064388 + 302.164775655*t)
	Y2 += 0.00000000045*np.cos(2.73683504159 + 846.0828347512*t)
	Y2 += 0.00000000045*np.cos(2.31642282675 + 145.6310438715*t)
	Y2 += 0.00000000047*np.cos(1.74738635330 + 1062.5633239269*t)
	Y2 += 0.00000000046*np.cos(3.14760491945 + 3.9321532631*t)
	Y2 += 0.00000000038*np.cos(5.98916947033 + 1258.4539316256*t)
	Y2 += 0.00000000035*np.cos(6.26763450664 + 1692.1656695024*t)
	Y2 += 0.00000000033*np.cos(4.03936498647 + 277.0349937414*t)
	Y2 += 0.00000000030*np.cos(3.29256356524 + 2125.8774073792*t)
	Y2 += 0.00000000035*np.cos(5.96755475967 + 1056.2005364515*t)
	Y2 += 0.00000000039*np.cos(4.91039224856 + 1574.8458012822*t)
	Y2 += 0.00000000036*np.cos(4.84158532799 + 437.6438911399*t)
	Y2 += 0.00000000028*np.cos(1.90040914464 + 1055.4497769261*t)
	Y2 += 0.00000000031*np.cos(1.82502538910 + 1272.6810256272*t)
	Y2 += 0.00000000027*np.cos(4.68673408301 + 1038.0412891868*t)
	Y2 += 0.00000000029*np.cos(0.08375583590 + 1485.9801210652*t)
	Y2 += 0.00000000027*np.cos(6.07872663556 + 618.5566453116*t)
	Y2 += 0.00000000026*np.cos(5.52380000200 + 415.5524906121*t)
	Y2 += 0.00000000026*np.cos(3.49078871449 + 430.5303441391*t)
	Y2 += 0.00000000024*np.cos(1.99820614050 + 18.1592472647*t)
	Y2 += 0.00000000023*np.cos(6.16563076611 + 231.4583427027*t)
	Y2 += 0.00000000023*np.cos(5.58098323545 + 831.8557407496*t)
	Y2 += 0.00000000025*np.cos(1.67396248390 + 2648.454825473*t)
	Y2 += 0.00000000021*np.cos(4.15712645283 + 447.9388318784*t)
	Y2 += 0.00000000024*np.cos(0.66675947895 + 1368.660252845*t)
	Y2 += 0.00000000020*np.cos(5.70175704295 + 10.2949407385*t)
	Y2 += 0.00000000022*np.cos(3.76535003503 + 151.0476698429*t)
	Y2 += 0.00000000020*np.cos(1.82615991897 + 1699.2792165032*t)
	Y2 += 0.00000000019*np.cos(0.17448576187 + 1063.3140834523*t)
	Y2 += 0.00000000020*np.cos(0.96756200367 + 35.1640902212*t)
	Y2 += 0.00000000021*np.cos(4.76218572464 + 72.3339180125*t)
	Y2 += 0.00000000018*np.cos(4.04819585578 + 1471.7530270636*t)
	Y2 += 0.00000000016*np.cos(3.64206691792 + 1478.8665740644*t)
	Y2 += 0.00000000016*np.cos(0.58395212576 + 22.0914005278*t)
	Y2 += 0.00000000017*np.cos(0.49891545478 + 77.7505439839*t)
	Y2 += 0.00000000016*np.cos(3.38818988576 + 41.1019810544*t)
	Y2 += 0.00000000014*np.cos(3.27141245862 + 1375.7737998458*t)
	Y2 += 0.00000000015*np.cos(3.46067246830 + 160.6088973985*t)
	Y2 += 0.00000000017*np.cos(0.01999942730 + 77.2292791221*t)
	Y2 += 0.00000000014*np.cos(4.11314424872 + 71.8126531507*t)
	Y2 += 0.00000000015*np.cos(1.62123638185 + 65.2203710117*t)
	Y2 += 0.00000000013*np.cos(2.10315959516 + 131.4039498699*t)
	Y2 += 0.00000000012*np.cos(3.60070147194 + 337.732510659*t)
	Y2 += 0.00000000012*np.cos(5.16899217088 + 195.1398481733*t)
	Y2 += 0.00000000013*np.cos(1.57968548593 + 408.4389436113*t)
	Y2 += 0.00000000014*np.cos(5.41918866932 + 2111.6503133776*t)
	Y2 += 0.00000000011*np.cos(4.73842604358 + 511.5317178299*t)
	Y2 += 0.00000000012*np.cos(2.63845374146 + 963.4027029714*t)
	Y2 += 0.00000000010*np.cos(2.74385211018 + 547.8502123593*t)
	Y2 += 0.00000000010*np.cos(4.24006763767 + 127.4717966068*t)
	Y2 += 0.00000000010*np.cos(3.10795031986 + 362.8622925726*t)
	Y2 += 0.00000000012*np.cos(5.50291077360 + 1685.0521225016*t)
	Y2 += 0.00000000010*np.cos(3.38695373136 + 934.9485149682*t)
	Y2 += 0.00000000013*np.cos(3.34698985021 + 84.3428261229*t)
	Y2 += 0.00000000009*np.cos(4.89802068656 + 1382.8873468466*t)
	Y2 += 0.00000000012*np.cos(1.08976567704 + 148.0787244263*t)
	Y2 += 0.00000000009*np.cos(0.86970882362 + 153.4953503977*t)
	Y2 += 0.00000000010*np.cos(5.98112560726 + 56.6223513026*t)
	Y2 += 0.00000000011*np.cos(1.80725352207 + 222.8603229936*t)
	Y2 += 0.00000000008*np.cos(4.44940554836 + 92.940845832*t)
	Y2 += 0.00000000011*np.cos(2.71165214295 + 635.9651330509*t)
	Y2 += 0.00000000011*np.cos(6.25031686000 + 203.7378678824*t)
	Y2 += 0.00000000008*np.cos(1.97062836873 + 750.1036075334*t)
	Y2 += 0.00000000010*np.cos(3.73718799858 + 436.8931316145*t)
	Y2 += 0.00000000008*np.cos(0.62172049419 + 269.9214467406*t)
	Y2 += 0.00000000010*np.cos(2.95730289498 + 643.0786800517*t)
	Y2 += 0.00000000008*np.cos(4.28675667624 + 131.5469622218*t)
	Y2 += 0.00000000007*np.cos(2.53028727253 + 1603.2999892854*t)
	Y2 += 0.00000000007*np.cos(5.10450860305 + 6681.2248533996*t)
	Y2 += 0.00000000009*np.cos(0.64587598578 + 1279.794572628*t)
	Y2 += 0.00000000007*np.cos(6.16053809700 + 483.2205421786*t)
	Y2 += 0.00000000009*np.cos(5.81958505267 + 87.3117715395*t)
	Y2 += 0.00000000007*np.cos(5.97116809594 + 12566.1516999828*t)
	Y2 += 0.00000000007*np.cos(2.57134529838 + 867.4234757536*t)
	Y2 += 0.00000000008*np.cos(0.69696747390 + 1361.5467058442*t)
	Y2 += 0.00000000006*np.cos(4.24193398289 + 107.0249274817*t)
	Y2 += 0.00000000006*np.cos(3.25108918094 + 9.5612275556*t)
	Y2 += 0.00000000007*np.cos(4.78448266738 + 721.6494195302*t)
	Y2 += 0.00000000006*np.cos(5.72007706352 + 106.2741679563*t)
	Y2 += 0.00000000006*np.cos(4.36194061397 + 12.5301729722*t)
	Y2 += 0.00000000006*np.cos(3.00522390508 + 52.6901980395*t)
	Y2 += 0.00000000006*np.cos(0.31871061944 + 2221.856634597*t)
	Y2 += 0.00000000006*np.cos(2.49037028744 + 288.0806940053*t)
	Y2 += 0.00000000006*np.cos(1.63049926151 + 35.685355083*t)
	Y2 += 0.00000000007*np.cos(1.46168801536 + 142.4496501338*t)
	Y2 += 0.00000000006*np.cos(1.28923147875 + 405.2575498736*t)
	Y2 += 0.00000000006*np.cos(5.62733178540 + 113.3877149571*t)
	Y2 += 0.00000000005*np.cos(2.71015544529 + 40.5807161926*t)
	Y2 += 0.00000000005*np.cos(2.54250601710 + 416.3032501375*t)
	Y2 += 0.00000000006*np.cos(5.93990081718 + 1795.258443721*t)
	Y2 += 0.00000000005*np.cos(2.05453158249 + 628.8515860501*t)
	Y2 += 0.00000000005*np.cos(3.67826495011 + 299.1263942692*t)
	Y2 += 0.00000000004*np.cos(4.28304952979 + 81.7521332162*t)
	Y2 += 0.00000000005*np.cos(4.41481024230 + 99.9113804809*t)
	Y2 += 0.00000000004*np.cos(2.63096828553 + 265.9892934775*t)
	Y2 += 0.00000000005*np.cos(2.37794711687 + 1.4844727083*t)
	Y2 += 0.00000000006*np.cos(3.64636080185 + 200.7689224658*t)
	Y2 += 0.00000000004*np.cos(4.73704179984 + 241.7532834412*t)
	Y2 += 0.00000000004*np.cos(4.79876284125 + 225.8292684102*t)
	Y2 += 0.00000000005*np.cos(1.33638591879 + 344.7030453079*t)
	Y2 += 0.00000000006*np.cos(3.95183892541 + 2.9689454166*t)
	Y2 += 0.00000000004*np.cos(3.59509349235 + 80.1982245387*t)
	Y2 += 0.00000000006*np.cos(5.63297540234 + 1049.0869894507*t)
	Y2 += 0.00000000004*np.cos(3.71597820582 + 295.0512286542*t)
	Y2 += 0.00000000004*np.cos(2.43954742926 + 96.8729990951*t)
	Y2 += 0.00000000005*np.cos(1.18144370768 + 146.3818033969*t)
	Y2 += 0.00000000005*np.cos(4.32438666743 + 340.7708920448*t)
	Y2 += 0.00000000004*np.cos(3.65979462851 + 358.9301393095*t)
	Y2 += 0.00000000004*np.cos(1.53439242952 + 1802.3719907218*t)
	Y2 += 0.00000000004*np.cos(4.33674716223 + 67.6680515665*t)
	Y2 += 0.00000000004*np.cos(0.88741176946 + 490.3340891794*t)
	Y2 += 0.00000000004*np.cos(1.47636301964 + 284.1485407422*t)
	Y2 += 0.00000000004*np.cos(2.43069407838 + 181.0557665236*t)
	Y2 += 0.00000000004*np.cos(4.16249740193 + 650.9429865779*t)
	Y2 += 0.00000000004*np.cos(5.33225362650 + 444.7574381407*t)
	Y2 += 0.00000000003*np.cos(1.63325210753 + 424.1505103212*t)
	Y2 += 0.00000000003*np.cos(2.17849854835 + 561.934294009*t)
	Y2 += 0.00000000003*np.cos(0.28442912913 + 81.8951455681*t)
	Y2 += 0.00000000003*np.cos(6.23743929416 + 501.2367770914*t)
	Y2 += 0.00000000004*np.cos(5.46844304994 + 1788.1448967202*t)
	Y2 += 0.00000000003*np.cos(4.39999749193 + 350.3321196004*t)
	Y2 += 0.00000000004*np.cos(5.19094501525 + 62.2514255951*t)
	Y2 += 0.00000000004*np.cos(0.92232764086 + 191.2076949102*t)
	Y2 += 0.00000000003*np.cos(5.84603699432 + 1148.2476104062*t)
	Y2 += 0.00000000003*np.cos(5.12901924955 + 14.977853527*t)
	Y2 += 0.00000000003*np.cos(5.61442182281 + 245.5424243524*t)
	Y2 += 0.00000000003*np.cos(0.96877732576 + 703.6331846174*t)
	Y2 += 0.00000000003*np.cos(0.98185914685 + 2015.6710861598*t)
	Y2 += 0.00000000003*np.cos(4.13284762562 + 152.7445908723*t)
	Y2 += 0.00000000003*np.cos(0.36290468467 + 2.4476805548*t)
	Y2 += 0.00000000003*np.cos(2.38051469960 + 351.8165923087*t)
	Y2 += 0.00000000003*np.cos(4.95099113946 + 2104.5367663768*t)
	Y2 += 0.00000000003*np.cos(1.47669060951 + 1069.6768709277*t)
	Y2 += 0.00000000003*np.cos(1.82747855775 + 33.6796175129*t)
	Y2 += 0.00000000003*np.cos(2.54140657037 + 636.7158925763*t)
	Y2 += 0.00000000003*np.cos(0.51639260266 + 235.3904959658*t)
	Y2 += 0.00000000003*np.cos(1.74048283842 + 1080.7225711916*t)
	Y2 += 0.00000000002*np.cos(3.31947858603 + 661.2379273164*t)
	Y2 += 0.00000000003*np.cos(2.19636619794 + 1592.2542890215*t)
	Y2 += 0.00000000002*np.cos(0.48948862546 + 611.4430983108*t)
	Y2 += 0.00000000003*np.cos(0.11884474556 + 1898.3512179396*t)
	Y2 += 0.00000000002*np.cos(2.47771838961 + 565.1156877467*t)
	Y2 += 0.00000000002*np.cos(5.72650908152 + 2008.557539159*t)
	Y2 += 0.00000000002*np.cos(1.96886682971 + 5849.3641121146*t)
	Y2 += 0.00000000002*np.cos(4.33824833645 + 404.5067903482*t)
	Y2 += 0.00000000002*np.cos(5.72106936632 + 79.2350166922*t)
	Y2 += 0.00000000002*np.cos(4.33074956694 + 5863.5912061162*t)
	Y2 += 0.00000000002*np.cos(0.29374413767 + 10213.285546211*t)
	Y2 += 0.00000000002*np.cos(3.39244631760 + 9779.5738083342*t)
	Y2 += 0.00000000003*np.cos(3.22473672245 + 319.5732633943*t)
	Y2 += 0.00000000002*np.cos(0.08755117660 + 1251.3403846248*t)
	Y2 += 0.00000000002*np.cos(5.75433263256 + 9793.8009023358*t)
	Y2 += 0.00000000002*np.cos(3.75555673654 + 2655.5683724738*t)
	Y2 += 0.00000000002*np.cos(4.73000748906 + 629.6023455755*t)
	Y2 += 0.00000000002*np.cos(2.46951852139 + 42.5864537627*t)
	Y2 += 0.00000000002*np.cos(5.50023586360 + 10021.8372800994*t)
	Y2 += 0.00000000002*np.cos(0.36359574780 + 137.0330241624*t)
	Y2 += 0.00000000002*np.cos(2.35083792212 + 313.2104759189*t)
	Y2 += 0.00000000002*np.cos(2.25297552783 + 208.633228992*t)
	Y2 += 0.00000000002*np.cos(3.54076915127 + 1905.4647649404*t)
	Y2 += 0.00000000002*np.cos(5.23123120810 + 70.3281804424*t)
	Y2 += 0.00000000002*np.cos(2.63436119239 + 217.964961884*t)
	Y2 += 0.00000000002*np.cos(0.63092019383 + 429.0458714308*t)
	Y2 += 0.00000000002*np.cos(3.00197118340 + 152.5321425512*t)
	Y2 += 0.00000000002*np.cos(2.46824302833 + 757.2171545342*t)
	Y2 += 0.00000000002*np.cos(2.10730094512 + 497.4476361802*t)
	Y2 += 0.00000000002*np.cos(6.01446832325 + 824.7421937488*t)
	Y2 += 0.00000000002*np.cos(1.08622053153 + 621.7380390493*t)
	Y2 += 0.00000000002*np.cos(1.54993622536 + 970.5162499722*t)
	Y2 += 0.00000000002*np.cos(4.07396574578 + 31.019488637*t)
	Y2 += 0.00000000002*np.cos(5.56159898916 + 2428.0421830342*t)
	Y2 += 0.00000000002*np.cos(3.99712167326 + 114.1384744825*t)
	Y2 += 0.00000000002*np.cos(1.14624828994 + 558.1451530978*t)
	Y2 += 0.00000000002*np.cos(4.96694647070 + 28.5718080822*t)
	Y2 += 0.00000000002*np.cos(0.64969123750 + 1165.6560981455*t)
	Y2 += 0.00000000002*np.cos(2.35334721621 + 114.3991069134*t)
	Y2 += 0.00000000002*np.cos(6.07129464792 + 6290.1893969922*t)
	Y2 += 0.00000000002*np.cos(1.31226038890 + 6283.0758499914*t)
	Y2 += 0.00000000002*np.cos(2.34688734548 + 1585.1407420207*t)
	Y2 += 0.00000000002*np.cos(4.78822293690 + 29.2049475286*t)
	Y2 += 0.00000000002*np.cos(5.77381759981 + 1159.2933106701*t)
	Y2 += 0.00000000002*np.cos(0.38565699394 + 20426.571092422*t)
	Y2 += 0.00000000002*np.cos(1.21211712503 + 10220.3990932118*t)
	Y2 += 0.00000000002*np.cos(0.26385323307 + 45.2465826386*t)
	Y2 += 0.00000000002*np.cos(3.70753245269 + 6275.9623029906*t)
	Y2 += 0.00000000002*np.cos(1.39351766866 + 5.4166259714*t)
	Y2 += 0.00000000002*np.cos(1.05043937613 + 69.3649725959*t)
	Y2 += 0.00000000002*np.cos(5.99570494575 + 1585.8915015461*t)
	Y2 += 0.00000000002*np.cos(0.42112793003 + 195.8906076987*t)
	Y2 += 0.00000000002*np.cos(5.13168311008 + 10206.1719992102*t)
	Y2 += 0.00000000001*np.cos(1.16336057471 + 842.1506814881*t)
	Y2 += 0.00000000001*np.cos(5.66855617017 + 2001.4439921582*t)
	Y2 += 0.00000000002*np.cos(4.44354843368 + 230.7075831773*t)
	Y2 += 0.00000000002*np.cos(4.03650266922 + 945.9942152321*t)
	Y2 += 0.00000000001*np.cos(0.51823226436 + 436.1594184316*t)
	Y2 += 0.00000000001*np.cos(3.62004187184 + 643.8294395771*t)
	Y2 += 0.00000000001*np.cos(1.12985825918 + 121.2520214833*t)
	Y2 += 0.00000000001*np.cos(5.58815396394 + 99.1606209555*t)
	Y2 += 0.00000000002*np.cos(1.03432737355 + 69.1525242748*t)
	Y2 += 0.00000000001*np.cos(5.65468955610 + 47.6942631934*t)
	Y2 += 0.00000000001*np.cos(1.73139400382 + 5230.807466803*t)
	Y2 += 0.00000000001*np.cos(5.65611387601 + 5216.5803728014*t)
	Y2 += 0.00000000001*np.cos(5.89624546658 + 1891.2376709388*t)
	Y2 += 0.00000000002*np.cos(4.84722510012 + 1567.7322542814*t)
	Y2 += 0.00000000001*np.cos(5.94827760074 + 175.1660598002*t)
	Y2 += 0.00000000001*np.cos(2.37250061422 + 576.1613880106*t)
	Y2 += 0.00000000001*np.cos(2.59247403756 + 289.5651667136*t)
	Y2 += 0.00000000001*np.cos(0.36698157416 + 1677.9385755008*t)
	Y2 += 0.00000000001*np.cos(2.26157295446 + 251.4321310758*t)
	Y2 += 0.00000000001*np.cos(3.15438105740 + 9161.0171630226*t)
	Y2 += 0.00000000002*np.cos(2.01011040392 + 3178.1457905676*t)
	Y2 += 0.00000000001*np.cos(0.79592911691 + 9146.790069021*t)
	Y2 += 0.00000000001*np.cos(5.73831370908 + 23.5758732361*t)
	Y2 += 0.00000000001*np.cos(5.81822645021 + 2324.9494088156*t)
	Y2 += 0.00000000001*np.cos(5.96540508289 + 134.5853436076*t)
	Y2 += 0.00000000001*np.cos(2.55358663752 + 2228.9701815978*t)
	Y2 += 0.00000000001*np.cos(2.99553257497 + 20.6069278195*t)
	Y2 += 0.00000000001*np.cos(1.84993618508 + 501.3797894433*t)
	Y2 += 0.00000000001*np.cos(2.22118706305 + 152.0108776894*t)
	Y2 += 0.00000000001*np.cos(4.94875862213 + 398.1440028728*t)
	Y2 += 0.00000000001*np.cos(0.36458315975 + 347.8844390456*t)
	Y2 += 0.00000000001*np.cos(5.23137106395 + 2744.4340526908*t)
	Y2 += 0.00000000001*np.cos(1.27065579743 + 710.7467316182*t)
	Y2 += 0.00000000001*np.cos(2.79744783766 + 479.2883889155*t)
	Y2 += 0.00000000001*np.cos(3.70018208886 + 953.1077622329*t)
	Y2 += 0.00000000001*np.cos(5.35737520786 + 3274.1250177854*t)
	Y2 += 0.00000000001*np.cos(4.79815423480 + 1912.5783119412*t)
	Y2 += 0.00000000001*np.cos(0.00065469527 + 333.657345044*t)
	Y2 += 0.00000000001*np.cos(5.67204734229 + 2641.3412784722*t)
	Y2 += 0.00000000001*np.cos(3.47622735141 + 518.6452648307*t)
	Y2 += 0.00000000001*np.cos(0.86445829696 + 540.7366653585*t)
	Y2 += 0.00000000001*np.cos(5.74733400372 + 2214.7430875962*t)
	Y2 += 0.00000000001*np.cos(3.19933914622 + 5856.4776591154*t)
	Y2 += 0.00000000001*np.cos(0.13768637054 + 2538.2485042536*t)
	Y2 += 0.00000000001*np.cos(1.23591181819 + 156.6767441354*t)
	Y2 += 0.00000000001*np.cos(4.67004055598 + 196.0336200506*t)
	Y2 += 0.00000000001*np.cos(3.18162540168 + 166.828672522*t)
	Y2 += 0.00000000001*np.cos(0.49385381517 + 5223.6939198022*t)
	Y2 += 0.00000000001*np.cos(6.15313463951 + 732.6951197941*t)
	Y2 += 0.00000000001*np.cos(4.95857892660 + 952.3570027075*t)
	Y2 += 0.00000000001*np.cos(0.66659052588 + 909.8187330546*t)
	Y2 += 0.00000000001*np.cos(2.35995882928 + 33.1371007917*t)
	Y2 += 0.00000000001*np.cos(0.46306820374 + 3487.4241132234*t)
	Y2 += 0.00000000001*np.cos(4.62443289306 + 9786.687355335*t)
	Y2 += 0.00000000001*np.cos(3.20286559446 + 4.4534181249*t)
	Y2 += 0.00000000001*np.cos(0.74616886001 + 1158.5425511447*t)
	Y2 += 0.00000000001*np.cos(1.00887699538 + 3281.2385647862*t)
	Y2 += 0.00000000001*np.cos(2.88323069926 + 70.1157321213*t)
	Y2 += 0.00000000001*np.cos(3.29339389414 + 146.594251718*t)
	Y2 += 0.00000000001*np.cos(2.50636479968 + 3340.6124266998*t)
	Y2 += 0.00000000001*np.cos(1.12415620436 + 89.7594520943*t)
	Y2 += 0.00000000001*np.cos(1.48337620620 + 431.264057322*t)
	Y2 += 0.00000000001*np.cos(0.56673920792 + 414.0680179038*t)
	Y2 += 0.00000000001*np.cos(5.08277064952 + 159.1244246902*t)
	Y2 += 0.00000000001*np.cos(1.18340721766 + 2332.0629558164*t)
	Y2 += 0.00000000001*np.cos(5.44453915950 + 739.8086667949*t)
	Y2 += 0.00000000001*np.cos(3.89849675205 + 395.578702239*t)
	Y2 += 0.00000000001*np.cos(0.83227279875 + 5753.3848848968*t)
	Y2 += 0.00000000001*np.cos(0.25710797851 + 120.358249606*t)
	Y2 += 0.00000000001*np.cos(4.94407537007 + 79.4474650133*t)
	Y2 += 0.00000000001*np.cos(1.54036364628 + 381.3516082374*t)
	Y2 += 0.00000000001*np.cos(0.93911384664 + 1670.82502850*t)
	Y2 += 0.00000000001*np.cos(3.37322355301 + 306.0969289181*t)
	Y2 += 0.00000000001*np.cos(0.98633433635 + 2751.5475996916*t)
	Y2 += 0.00000000001*np.cos(4.31576515905 + 3693.6096616606*t)
	Y2 += 0.00000000001*np.cos(4.68952440895 + 259.769518354*t)
	Y2 += 0.00000000001*np.cos(0.97999719406 + 1286.9081196288*t)
	Y2 += 0.00000000001*np.cos(4.41863788124 + 312.1990839626*t)
	Y2 += 0.00000000001*np.cos(5.60093024182 + 1166.4068576709*t)
	Y2 += 0.00000000001*np.cos(0.58666119928 + 54.1746707478*t)
	Y2 += 0.00000000001*np.cos(2.05615125313 + 849.2642284889*t)
	Y2 += 0.00000000001*np.cos(3.56744225567 + 326.6868103951*t)
	Y2 += 0.00000000001*np.cos(3.55729227127 + 59.8037450403*t)
	Y2 += 0.00000000001*np.cos(3.22792504906 + 84.9335269539*t)
	Y2 += 0.00000000001*np.cos(2.26267682874 + 9683.5945811164*t)
	Y2 += 0.00000000001*np.cos(2.37282657679 + 320.3240229197*t)
	Y2 += 0.00000000001*np.cos(2.67374803167 + 572.2292347475*t)
	Y2 += 0.00000000001*np.cos(5.95184882679 + 45.5766510387*t)
	Y2 += 0.00000000001*np.cos(5.52574402266 + 409.1897031367*t)
	Y2 += 0.00000000001*np.cos(0.73609253311 + 4694.0029547076*t)
	Y2 += 0.00000000001*np.cos(5.08148636540 + 275.5505210331*t)
	Y2 += 0.00000000001*np.cos(3.87234579479 + 73.0846775379*t)
	Y2 += 0.00000000001*np.cos(6.09895100348 + 546.956440482*t)
	Y2 += 0.00000000001*np.cos(1.81752363716 + 1141.1340634054*t)
	Y2 += 0.00000000001*np.cos(3.95570051411 + 76.4785195967*t)
	Y2 += 0.00000000001*np.cos(4.88364229478 + 3899.7952100978*t)
	Y2 += 0.00000000001*np.cos(5.48244275135 + 696.5196376166*t)
	Y2 += 0.00000000001*np.cos(4.42768661818 + 98.8999885246*t)
	Y2 += 0.00000000001*np.cos(3.45410478809 + 230.5645708254*t)
	Y2 += 0.00000000001*np.cos(2.35103532734 + 41.6444977756*t)
	Y2 += 0.00000000001*np.cos(1.53479194111 + 135.336103133*t)
	Y2 += 0.00000000001*np.cos(0.95541678518 + 421.93232443*t)
	Y2 += 0.00000000001*np.cos(4.99690538988 + 188.0263011725*t)
	Y2 += 0.00000000001*np.cos(0.55348583653 + 1354.4331588434*t)
	Y2 += 0.00000000001*np.cos(1.50631465068 + 237.6781178262*t)
	Y2 += 0.00000000001*np.cos(5.28108947987 + 3576.2897934404*t)
	Y2 += 0.00000000001*np.cos(4.25810155296 + 554.0699874828*t)
	Y2 += 0.00000000001*np.cos(4.87247047344 + 129.9194771616*t)
	Y2 += 0.00000000001*np.cos(0.73724286055 + 1987.2168981566*t)
	Y2 += 0.00000000001*np.cos(6.00780137351 + 2854.6403739102*t)
	Y2 += 0.00000000001*np.cos(2.15790052752 + 8624.2126509272*t)
	Y2 += 0.00000000001*np.cos(5.68233348434 + 205.2223405907*t)
	Y2 += 0.00000000001*np.cos(0.63630416733 + 92.0470739547*t)
	Y2 += 0.00000000001*np.cos(0.44455866910 + 3149.6916025644*t)
	Y2 += 0.00000000001*np.cos(6.17112850125 + 238.5718897035*t)
	Y2 += 0.00000000001*np.cos(0.14353409670 + 16.6747745564*t)
	Y2 += 0.00000000001*np.cos(4.01714550628 + 6069.7767545534*t)
	Y2 += 0.00000000001*np.cos(5.90379133758 + 3384.3313390048*t)
	Y2 += 0.00000000001*np.cos(1.36515072276 + 19.643719973*t)
	Y2 += 0.00000000001*np.cos(0.28427523570 + 916.9322800554*t)
	Y2 += 0.00000000001*np.cos(5.47573025682 + 2207.6295405954*t)
	Y2 += 0.00000000001*np.cos(5.47946050532 + 3803.81598288*t)
	Y2 += 0.00000000001*np.cos(5.37599551242 + 9999.986450773*t)
	Y2 += 0.00000000001*np.cos(0.21918059465 + 188.9200730498*t)
	Y2 += 0.00000000001*np.cos(4.66732756371 + 3796.7024358792*t)
	Y2 += 0.00000000001*np.cos(0.91763434486 + 432.2272651685*t)
	Y2 += 0.00000000001*np.cos(2.12955452056 + 162.0933701068*t)
	Y2 += 0.00000000001*np.cos(5.00797241857 + 3480.3105662226*t)
	Y2 += 0.00000000001*np.cos(3.69838844313 + 2545.3620512544*t)
	Y2 += 0.00000000001*np.cos(5.07347670876 + 3060.8259223474*t)
	Y2 += 0.00000000001*np.cos(3.16759642831 + 5643.1785636774*t)
	Y2 += 0.00000000001*np.cos(4.50726047038 + 60.7669528868*t)
	Y2 += 0.00000000001*np.cos(1.82628719241 + 229.9738699944*t)
	Y2 += 0.00000000001*np.cos(3.06333897418 + 196.6243208816*t)
	Y2 += 0.00000000001*np.cos(1.69689950284 + 128.9562693151*t)
	Y2 += 0.00000000001*np.cos(4.40175932282 + 3789.5888888784*t)
	Y2 += 0.00000000001*np.cos(5.13644054133 + 3590.516887442*t)
	Y2 += 0.00000000001*np.cos(1.05515969254 + 2435.155730035*t)
	Y2 += 0.00000000001*np.cos(0.75706049519 + 147.1155165798*t)
	Y2 += 0.00000000001*np.cos(5.97901187658 + 3046.5988283458*t)
	Y2 += 0.00000000001*np.cos(3.27199698305 + 2861.753920911*t)
	Y2 += 0.00000000001*np.cos(0.27205849281 + 2097.423219376*t)
	Y2 += 0.00000000001*np.cos(2.96009025986 + 650.1922270525*t)
	Y2 += 0.00000000001*np.cos(0.03824015749 + 2413.8150890326*t)
	Y2 += 0.00000000001*np.cos(6.17146638802 + 600.5404103988*t)
	Y2 += 0.00000000001*np.cos(4.61020780649 + 120.5012619579*t)
	Y2 += 0.00000000001*np.cos(4.39946261271 + 2420.9286360334*t)
	Y2 += 0.00000000001*np.cos(4.55703814948 + 9573.388259897*t)
	Y2 += 0.00000000001*np.cos(5.58884415892 + 221.3758502853*t)
	Y2 += 0.00000000001*np.cos(3.13088689229 + 207.1487562837*t)
	Y2 += 0.00000000001*np.cos(1.75873927430 + 219.4494345923*t)
	Y2 += 0.00000000001*np.cos(1.23590582215 + 33.9402499438*t)
	Y2 += 0.00000000001*np.cos(2.08190815683 + 220.4608265486*t)
	Y2 += 0.00000000001*np.cos(2.80771800976 + 206.1373643274*t)
	Y2 += 0.00000000001*np.cos(0.23418242733 + 556.5176680376*t)
	Y2 += 0.00000000001*np.cos(2.50249904501 + 116.4260963429*t)
	Y2 += 0.00000000001*np.cos(4.82349288945 + 1493.093668066*t)
	Y2 += 0.00000000001*np.cos(1.89232109393 + 9153.9036160218*t)
	Y2 += 0.00000000001*np.cos(2.14909355507 + 856.3777754897*t)
	Y2 += 0.00000000000*np.cos(1.38426236033 + 417.0369633204*t)
	Y2 += 0.00000000001*np.cos(3.43527356273 + 344.8460576598*t)
	Y2 += 0.00000000001*np.cos(0.51791265542 + 2303.6087678132*t)
	Y2 += 0.00000000001*np.cos(2.60128705007 + 570.7447620392*t)
	Y2 += 0.00000000000*np.cos(0.66223171138 + 425.6349830295*t)
	Y2 += 0.00000000000*np.cos(5.08246358661 + 327.4375699205*t)
	Y2 += 0.00000000001*np.cos(4.68142095001 + 421.1815649046*t)
	Y2 += 0.00000000000*np.cos(2.46829179881 + 25.2727942655*t)
	Y2 += 0.00000000000*np.cos(4.01075222334 + 455.0523788792*t)
	Y2 += 0.00000000000*np.cos(4.39794506516 + 427.5613987225*t)
	Y2 += 0.00000000001*np.cos(4.36950697648 + 186.472392495*t)
	Y2 += 0.00000000000*np.cos(4.93079272630 + 898.7730327907*t)
	Y2 += 0.00000000000*np.cos(0.98841405744 + 343.2185725996*t)
	Y2 += 0.00000000001*np.cos(3.61451936174 + 439.1283638482*t)
	Y2 += 0.00000000001*np.cos(5.31122160315 + 373.9079928365*t)
	Y2 += 0.00000000001*np.cos(1.10887048478 + 913.0001267923*t)
	Y2 += 0.00000000001*np.cos(4.43514549703 + 3370.1042450032*t)
	Y2 += 0.00000000000*np.cos(3.04667487495 + 42.3258213318*t)
	Y2 += 0.00000000001*np.cos(4.79006420310 + 312.4597163935*t)
	Y2 += 0.00000000001*np.cos(1.14062607705 + 458.8415197904*t)
	Y2 += 0.00000000000*np.cos(1.01611200023 + 280.9671470045*t)
	Y2 += 0.00000000001*np.cos(1.20291170495 + 2964.8466951296*t)
	Y2 += 0.00000000000*np.cos(4.58900627845 + 258.8757464767*t)
	Y2 += 0.00000000000*np.cos(2.83520339972 + 211.8146227297*t)
	Y2 += 0.00000000001*np.cos(5.99600722280 + 3700.7232086614*t)
	Y2 += 0.00000000001*np.cos(4.52546489976 + 173.9422195228*t)
	Y2 += 0.00000000000*np.cos(4.45232107208 + 51.2057253312*t)
	Y2 += 0.00000000000*np.cos(4.30824410406 + 3252.784376783*t)
	return Y2*t*t




def Sun_Y3 (t): # 206 terms of order 3

	Y3 = 0.
	Y3 += 0.00000022088*np.cos(4.54598360855 + 206.1855484372*t)
	Y3 += 0.00000021546*np.cos(3.46116671016 + 220.4126424388*t)
	Y3 += 0.00000016300*np.cos(1.14934178921 + 522.5774180938*t)
	Y3 += 0.00000015923*np.cos(0.06221071687 + 536.8045120954*t)
	Y3 += 0.00000003093*np.cos(2.22514436528 + 426.598190876*t)
	Y3 += 0.00000002568*np.cos(2.47493921494 + 433.7117378768*t)
	Y3 += 0.00000002105*np.cos(3.35595521974 + 227.5261894396*t)
	Y3 += 0.00000002639
	Y3 += 0.00000001700*np.cos(5.13510489936 + 1059.3819301892*t)
	Y3 += 0.00000001378*np.cos(1.27086042787 + 515.463871093*t)
	Y3 += 0.00000001266*np.cos(3.80209162712 + 419.4846438752*t)
	Y3 += 0.00000001363*np.cos(4.63636570705 + 7.1135470008*t)
	Y3 += 0.00000001013*np.cos(4.67704889552 + 199.0720014364*t)
	Y3 += 0.00000001037*np.cos(0.69915801725 + 1066.49547719*t)
	Y3 += 0.00000000964*np.cos(6.22045145850 + 543.9180590962*t)
	Y3 += 0.00000000849*np.cos(1.26670686968 + 639.897286314*t)
	Y3 += 0.00000000678*np.cos(0.79554783130 + 1052.2683831884*t)
	Y3 += 0.00000000392*np.cos(4.59101411052 + 14.2270940016*t)
	Y3 += 0.00000000291*np.cos(1.57357745396 + 647.0108333148*t)
	Y3 += 0.00000000248*np.cos(5.85725743749 + 1589.0728952838*t)
	Y3 += 0.00000000214*np.cos(2.46865385667 + 440.8252848776*t)
	Y3 += 0.00000000231*np.cos(2.85226310193 + 216.4804891757*t)
	Y3 += 0.00000000220*np.cos(5.18394074276 + 210.1177017003*t)
	Y3 += 0.00000000129*np.cos(0.22762324749 + 1045.1548361876*t)
	Y3 += 0.00000000123*np.cos(0.51351773704 + 853.196381752*t)
	Y3 += 0.00000000137*np.cos(2.15435863260 + 529.6909650946*t)
	Y3 += 0.00000000092*np.cos(3.22442461302 + 234.6397364404*t)
	Y3 += 0.00000000087*np.cos(4.52965482365 + 103.0927742186*t)
	Y3 += 0.00000000092*np.cos(3.90819414656 + 117.3198682202*t)
	Y3 += 0.00000000085*np.cos(5.57189606315 + 95.9792272178*t)
	Y3 += 0.00000000094*np.cos(2.25901632919 + 213.299095438*t)
	Y3 += 0.00000000075*np.cos(1.30082808866 + 1596.1864422846*t)
	Y3 += 0.00000000078*np.cos(4.96547279129 + 110.2063212194*t)
	Y3 += 0.00000000071*np.cos(4.48281367743 + 632.7837393132*t)
	Y3 += 0.00000000076*np.cos(3.40988387446 + 412.3710968744*t)
	Y3 += 0.00000000064*np.cos(2.39566214965 + 316.3918696566*t)
	Y3 += 0.00000000056*np.cos(1.44254805098 + 508.3503240922*t)
	Y3 += 0.00000000055*np.cos(1.71252125469 + 323.5054166574*t)
	Y3 += 0.00000000048*np.cos(0.40111970766 + 1073.6090241908*t)
	Y3 += 0.00000000056*np.cos(6.19540120033 + 735.8765135318*t)
	Y3 += 0.00000000042*np.cos(6.13276553266 + 625.6701923124*t)
	Y3 += 0.00000000039*np.cos(5.02961841371 + 942.062061969*t)
	Y3 += 0.00000000036*np.cos(3.01279484364 + 209.3669421749*t)
	Y3 += 0.00000000031*np.cos(0.88356246900 + 1581.959348283*t)
	Y3 += 0.00000000031*np.cos(6.03310463140 + 551.031606097*t)
	Y3 += 0.00000000032*np.cos(4.98300318004 + 217.2312487011*t)
	Y3 += 0.00000000033*np.cos(0.75212348383 + 860.3099287528*t)
	Y3 += 0.00000000030*np.cos(4.51763020093 + 70.8494453042*t)
	Y3 += 0.00000000027*np.cos(2.35184788494 + 149.5631971346*t)
	Y3 += 0.00000000028*np.cos(1.91930691377 + 330.6189636582*t)
	Y3 += 0.00000000027*np.cos(0.05305218851 + 2118.7638603784*t)
	Y3 += 0.00000000028*np.cos(0.17790568355 + 78.7137518304*t)
	Y3 += 0.00000000027*np.cos(4.37487614145 + 21.3406410024*t)
	Y3 += 0.00000000029*np.cos(5.17540731322 + 949.1756089698*t)
	Y3 += 0.00000000025*np.cos(3.02081007506 + 124.433415221*t)
	Y3 += 0.00000000033*np.cos(2.73570572399 + 223.5940361765*t)
	Y3 += 0.00000000025*np.cos(5.88306502494 + 1169.5882514086*t)
	Y3 += 0.00000000024*np.cos(6.25389986741 + 63.7358983034*t)
	Y3 += 0.00000000024*np.cos(4.81432332838 + 191.9584544356*t)
	Y3 += 0.00000000028*np.cos(0.01012773075 + 728.762966531*t)
	Y3 += 0.00000000024*np.cos(1.59054971444 + 654.1243803156*t)
	Y3 += 0.00000000030*np.cos(4.35202882411 + 309.2783226558*t)
	Y3 += 0.00000000022*np.cos(0.58430377684 + 1155.361157407*t)
	Y3 += 0.00000000020*np.cos(5.79574932921 + 88.865680217*t)
	Y3 += 0.00000000023*np.cos(3.64404039148 + 956.2891559706*t)
	Y3 += 0.00000000019*np.cos(4.74503190924 + 85.8272988312*t)
	Y3 += 0.00000000019*np.cos(5.66498805054 + 73.297125859*t)
	Y3 += 0.00000000025*np.cos(1.94036276937 + 429.7795846137*t)
	Y3 += 0.00000000024*np.cos(1.95947716237 + 519.3960243561*t)
	Y3 += 0.00000000020*np.cos(0.29570924626 + 71.6002048296*t)
	Y3 += 0.00000000018*np.cos(4.38365354248 + 77.962992305*t)
	Y3 += 0.00000000016*np.cos(4.70914310164 + 202.2533951741*t)
	Y3 += 0.00000000020*np.cos(5.48263393467 + 539.9859058331*t)
	Y3 += 0.00000000016*np.cos(3.45867068386 + 224.3447957019*t)
	Y3 += 0.00000000015*np.cos(5.26771574252 + 302.164775655*t)
	Y3 += 0.00000000014*np.cos(5.35318240788 + 76.2660712756*t)
	Y3 += 0.00000000017*np.cos(5.40518600219 + 203.0041546995*t)
	Y3 += 0.00000000011*np.cos(3.87206824630 + 11.0457002639*t)
	Y3 += 0.00000000010*np.cos(2.40929335654 + 36.6485629295*t)
	Y3 += 0.00000000012*np.cos(1.79980409055 + 422.6660376129*t)
	Y3 += 0.00000000009*np.cos(1.93147151515 + 39.6175083461*t)
	Y3 += 0.00000000009*np.cos(0.16500567398 + 1038.0412891868*t)
	Y3 += 0.00000000009*np.cos(0.79081879948 + 838.9692877504*t)
	Y3 += 0.00000000009*np.cos(2.40868380460 + 447.9388318784*t)
	Y3 += 0.00000000008*np.cos(1.59402806626 + 618.5566453116*t)
	Y3 += 0.00000000009*np.cos(2.51756026677 + 74.7815985673*t)
	Y3 += 0.00000000008*np.cos(5.09979031312 + 423.4167971383*t)
	Y3 += 0.00000000009*np.cos(0.33848481291 + 1574.8458012822*t)
	Y3 += 0.00000000007*np.cos(1.37888755215 + 1258.4539316256*t)
	Y3 += 0.00000000006*np.cos(1.09195739886 + 831.8557407496*t)
	Y3 += 0.00000000006*np.cos(1.00867247429 + 138.5174968707*t)
	Y3 += 0.00000000006*np.cos(4.91543048225 + 742.9900605326*t)
	Y3 += 0.00000000006*np.cos(1.82818120946 + 2125.8774073792*t)
	Y3 += 0.00000000005*np.cos(0.60506372351 + 145.6310438715*t)
	Y3 += 0.00000000007*np.cos(5.32328426995 + 38.1330356378*t)
	Y3 += 0.00000000005*np.cos(0.66965342943 + 195.1398481733*t)
	Y3 += 0.00000000004*np.cos(0.41274254704 + 18.1592472647*t)
	Y3 += 0.00000000004*np.cos(1.83690246048 + 337.732510659*t)
	Y3 += 0.00000000004*np.cos(1.32611242407 + 1265.5674786264*t)
	Y3 += 0.00000000004*np.cos(2.71001820282 + 437.6438911399*t)
	Y3 += 0.00000000003*np.cos(5.02306065714 + 1485.9801210652*t)
	Y3 += 0.00000000004*np.cos(4.61647130206 + 3.9321532631*t)
	Y3 += 0.00000000004*np.cos(4.86205883099 + 3.1813937377*t)
	Y3 += 0.00000000003*np.cos(0.24146698930 + 1699.2792165032*t)
	Y3 += 0.00000000003*np.cos(2.54047104670 + 131.5469622218*t)
	Y3 += 0.00000000003*np.cos(5.19663268688 + 934.9485149682*t)
	Y3 += 0.00000000003*np.cos(1.89821812188 + 436.8931316145*t)
	Y3 += 0.00000000003*np.cos(4.05827327245 + 846.0828347512*t)
	Y3 += 0.00000000003*np.cos(0.84357940935 + 1062.5633239269*t)
	Y3 += 0.00000000003*np.cos(0.21598966041 + 721.6494195302*t)
	Y3 += 0.00000000002*np.cos(0.53670508526 + 2648.454825473*t)
	Y3 += 0.00000000002*np.cos(3.92186370454 + 131.4039498699*t)
	Y3 += 0.00000000002*np.cos(0.91291435645 + 1603.2999892854*t)
	Y3 += 0.00000000002*np.cos(0.76104298796 + 867.4234757536*t)
	Y3 += 0.00000000002*np.cos(1.08620559446 + 643.0786800517*t)
	Y3 += 0.00000000003*np.cos(6.03930177407 + 1471.7530270636*t)
	Y3 += 0.00000000002*np.cos(0.85856016250 + 635.9651330509*t)
	Y3 += 0.00000000002*np.cos(4.22140945210 + 231.4583427027*t)
	Y3 += 0.00000000002*np.cos(1.66761053003 + 56.6223513026*t)
	Y3 += 0.00000000002*np.cos(2.40289635523 + 1368.660252845*t)
	Y3 += 0.00000000002*np.cos(2.45646924027 + 269.9214467406*t)
	Y3 += 0.00000000002*np.cos(0.51395931456 + 1272.6810256272*t)
	Y3 += 0.00000000002*np.cos(3.61461152227 + 408.4389436113*t)
	Y3 += 0.00000000002*np.cos(0.93616194604 + 963.4027029714*t)
	Y3 += 0.00000000002*np.cos(1.58523848820 + 1685.0521225016*t)
	Y3 += 0.00000000002*np.cos(5.51445164570 + 295.0512286542*t)
	Y3 += 0.00000000002*np.cos(1.00442608560 + 1055.4497769261*t)
	Y3 += 0.00000000002*np.cos(4.49509966736 + 22.0914005278*t)
	Y3 += 0.00000000002*np.cos(3.08845244449 + 241.7532834412*t)
	Y3 += 0.00000000002*np.cos(1.43941179659 + 151.0476698429*t)
	Y3 += 0.00000000001*np.cos(3.44704587186 + 1382.8873468466*t)
	Y3 += 0.00000000002*np.cos(0.57010178031 + 1788.1448967202*t)
	Y3 += 0.00000000002*np.cos(0.42335354864 + 416.3032501375*t)
	Y3 += 0.00000000002*np.cos(1.75951401058 + 526.5095713569*t)
	Y3 += 0.00000000002*np.cos(2.58117163779 + 532.8723588323*t)
	Y3 += 0.00000000001*np.cos(5.48681505441 + 277.0349937414*t)
	Y3 += 0.00000000002*np.cos(0.13809144454 + 430.5303441391*t)
	Y3 += 0.00000000002*np.cos(2.58174480747 + 92.940845832*t)
	Y3 += 0.00000000001*np.cos(6.06441593546 + 81.7521332162*t)
	Y3 += 0.00000000001*np.cos(0.71058040619 + 415.5524906121*t)
	Y3 += 0.00000000002*np.cos(5.06827598270 + 1279.794572628*t)
	Y3 += 0.00000000001*np.cos(5.87510766420 + 1162.4747044078*t)
	Y3 += 0.00000000001*np.cos(3.29813464894 + 611.4430983108*t)
	Y3 += 0.00000000001*np.cos(0.09891059453 + 2104.5367663768*t)
	Y3 += 0.00000000002*np.cos(2.46195810488 + 1361.5467058442*t)
	Y3 += 0.00000000002*np.cos(5.74044986985 + 1056.2005364515*t)
	Y3 += 0.00000000001*np.cos(0.99824910705 + 160.6088973985*t)
	Y3 += 0.00000000001*np.cos(1.62638790866 + 483.2205421786*t)
	Y3 += 0.00000000001*np.cos(3.50149700133 + 35.1640902212*t)
	Y3 += 0.00000000001*np.cos(5.76299413440 + 2420.9286360334*t)
	Y3 += 0.00000000001*np.cos(0.83909020657 + 41.1019810544*t)
	Y3 += 0.00000000001*np.cos(1.85607665951 + 184.8449074348*t)
	Y3 += 0.00000000001*np.cos(6.01210640761 + 2008.557539159*t)
	Y3 += 0.00000000001*np.cos(1.55579526823 + 661.2379273164*t)
	Y3 += 0.00000000001*np.cos(3.18610098524 + 1141.1340634054*t)
	Y3 += 0.00000000001*np.cos(2.71706778222 + 153.4953503977*t)
	Y3 += 0.00000000001*np.cos(5.56272445862 + 1478.8665740644*t)
	Y3 += 0.00000000001*np.cos(3.16336664316 + 405.2575498736*t)
	Y3 += 0.00000000001*np.cos(5.98469019133 + 1069.6768709277*t)
	Y3 += 0.00000000001*np.cos(2.34179341386 + 824.7421937488*t)
	Y3 += 0.00000000001*np.cos(1.98918668419 + 2097.423219376*t)
	Y3 += 0.00000000001*np.cos(3.14828548619 + 1884.124123938*t)
	Y3 += 0.00000000001*np.cos(2.30589047070 + 1049.0869894507*t)
	Y3 += 0.00000000001*np.cos(0.33221185756 + 127.4717966068*t)
	Y3 += 0.00000000001*np.cos(1.01697211367 + 1251.3403846248*t)
	Y3 += 0.00000000001*np.cos(0.51740544611 + 398.1440028728*t)
	Y3 += 0.00000000001*np.cos(1.92391474730 + 1994.3304451574*t)
	Y3 += 0.00000000001*np.cos(5.43547907327 + 52.6901980395*t)
	Y3 += 0.00000000001*np.cos(6.12439543171 + 1080.7225711916*t)
	Y3 += 0.00000000001*np.cos(5.01886732456 + 81.8951455681*t)
	Y3 += 0.00000000001*np.cos(1.43286480461 + 1148.2476104062*t)
	Y3 += 0.00000000001*np.cos(5.90371148838 + 67.6680515665*t)
	Y3 += 0.00000000001*np.cos(0.54399015451 + 497.4476361802*t)
	Y3 += 0.00000000001*np.cos(3.08298225417 + 65.2203710117*t)
	Y3 += 0.00000000001*np.cos(3.24857906892 + 99.9113804809*t)
	Y3 += 0.00000000001*np.cos(1.09299822176 + 2207.6295405954*t)
	Y3 += 0.00000000001*np.cos(1.21511802190 + 362.8622925726*t)
	Y3 += 0.00000000001*np.cos(6.06528783230 + 2840.4132799086*t)
	Y3 += 0.00000000001*np.cos(3.60557527393 + 87.3117715395*t)
	Y3 += 0.00000000001*np.cos(1.71749231580 + 2001.4439921582*t)
	Y3 += 0.00000000001*np.cos(1.78357856645 + 84.3428261229*t)
	Y3 += 0.00000000001*np.cos(3.83228371563 + 10.2949407385*t)
	Y3 += 0.00000000001*np.cos(3.99500661462 + 113.3877149571*t)
	Y3 += 0.00000000001*np.cos(1.51764002054 + 148.0787244263*t)
	Y3 += 0.00000000001*np.cos(1.38776317458 + 2111.6503133776*t)
	Y3 += 0.00000000001*np.cos(1.56601766592 + 1898.3512179396*t)
	Y3 += 0.00000000001*np.cos(2.15426380820 + 525.7588118315*t)
	Y3 += 0.00000000001*np.cos(2.18642184017 + 533.6231183577*t)
	Y3 += 0.00000000001*np.cos(2.81628023205 + 146.3818033969*t)
	Y3 += 0.00000000001*np.cos(5.95282849380 + 750.1036075334*t)
	Y3 += 0.00000000001*np.cos(2.55909626745 + 2641.3412784722*t)
	Y3 += 0.00000000001*np.cos(1.02781900657 + 1567.7322542814*t)
	Y3 += 0.00000000001*np.cos(1.86378724420 + 650.9429865779*t)
	Y3 += 0.00000000001*np.cos(2.20160587766 + 195.8906076987*t)
	Y3 += 0.00000000001*np.cos(2.68802028893 + 230.7075831773*t)
	Y3 += 0.00000000001*np.cos(4.62503696155 + 2538.2485042536*t)
	Y3 += 0.00000000001*np.cos(3.08782857136 + 344.7030453079*t)
	Y3 += 0.00000000001*np.cos(4.11498666639 + 927.8349679674*t)
	Y3 += 0.00000000001*np.cos(3.42218194283 + 191.2076949102*t)
	Y3 += 0.00000000001*np.cos(5.30495237690 + 636.7158925763*t)
	Y3 += 0.00000000001*np.cos(0.22317096940 + 1905.4647649404*t)
	Y3 += 0.00000000000*np.cos(4.61042977384 + 235.3904959658*t)
	Y3 += 0.00000000000*np.cos(0.32708790118 + 1354.4331588434*t)
	Y3 += 0.00000000000*np.cos(1.63826756079 + 2214.7430875962*t)
	Y3 += 0.00000000000*np.cos(6.22055375222 + 2015.6710861598*t)
	Y3 += 0.00000000001*np.cos(1.63051943172 + 2310.722314814*t)
	return Y3*t*t*t




def Sun_Y4 (t): # 87 terms of order 4

	Y4 = 0.
	Y4 += 0.00000002278*np.cos(6.27388903010 + 206.1855484372*t)
	Y4 += 0.00000002245*np.cos(1.70782913671 + 220.4126424388*t)
	Y4 += 0.00000001682*np.cos(2.89988955370 + 522.5774180938*t)
	Y4 += 0.00000001636*np.cos(4.60365551069 + 536.8045120954*t)
	Y4 += 0.00000000431*np.cos(1.63508563664 + 227.5261894396*t)
	Y4 += 0.00000000349*np.cos(0.69586528581 + 433.7117378768*t)
	Y4 += 0.00000000291*np.cos(3.00165310731 + 515.463871093*t)
	Y4 += 0.00000000206*np.cos(4.48461122025 + 543.9180590962*t)
	Y4 += 0.00000000204*np.cos(0.11049991144 + 199.0720014364*t)
	Y4 += 0.00000000123*np.cos(5.38340390628 + 1066.49547719*t)
	Y4 += 0.00000000099*np.cos(5.70623543947 + 419.4846438752*t)
	Y4 += 0.00000000117*np.cos(0.28020890432 + 426.598190876*t)
	Y4 += 0.00000000096*np.cos(2.80306869168 + 7.1135470008*t)
	Y4 += 0.00000000061*np.cos(2.82818345895 + 14.2270940016*t)
	Y4 += 0.00000000052*np.cos(3.37268534533 + 1059.3819301892*t)
	Y4 += 0.00000000066*np.cos(2.63263056615 + 1052.2683831884*t)
	Y4 += 0.00000000050*np.cos(0.71576934216 + 440.8252848776*t)
	Y4 += 0.00000000065
	Y4 += 0.00000000059*np.cos(5.69532892910 + 639.897286314*t)
	Y4 += 0.00000000049*np.cos(6.02940323662 + 647.0108333148*t)
	Y4 += 0.00000000028*np.cos(0.26064157330 + 213.299095438*t)
	Y4 += 0.00000000024*np.cos(1.48209397973 + 234.6397364404*t)
	Y4 += 0.00000000023*np.cos(2.06131193005 + 1045.1548361876*t)
	Y4 += 0.00000000014*np.cos(3.25423631036 + 508.3503240922*t)
	Y4 += 0.00000000013*np.cos(4.48491117264 + 1589.0728952838*t)
	Y4 += 0.00000000011*np.cos(5.24080280774 + 412.3710968744*t)
	Y4 += 0.00000000012*np.cos(4.87116288717 + 853.196381752*t)
	Y4 += 0.00000000010*np.cos(5.03146150255 + 1073.6090241908*t)
	Y4 += 0.00000000010*np.cos(1.05727005468 + 95.9792272178*t)
	Y4 += 0.00000000010*np.cos(6.06799555020 + 1596.1864422846*t)
	Y4 += 0.00000000010*np.cos(5.71091802020 + 529.6909650946*t)
	Y4 += 0.00000000009*np.cos(2.76384051230 + 21.3406410024*t)
	Y4 += 0.00000000008*np.cos(6.23072779166 + 103.0927742186*t)
	Y4 += 0.00000000010*np.cos(2.05522879011 + 117.3198682202*t)
	Y4 += 0.00000000007*np.cos(3.08813888762 + 110.2063212194*t)
	Y4 += 0.00000000007*np.cos(4.14773765350 + 551.031606097*t)
	Y4 += 0.00000000006*np.cos(6.11652071967 + 654.1243803156*t)
	Y4 += 0.00000000005*np.cos(1.24583749139 + 124.433415221*t)
	Y4 += 0.00000000005*np.cos(0.40108066581 + 942.062061969*t)
	Y4 += 0.00000000006*np.cos(5.14748397921 + 860.3099287528*t)
	Y4 += 0.00000000005*np.cos(1.40699621378 + 88.865680217*t)
	Y4 += 0.00000000004*np.cos(6.24919197648 + 632.7837393132*t)
	Y4 += 0.00000000005*np.cos(1.37080964211 + 625.6701923124*t)
	Y4 += 0.00000000004*np.cos(0.18776272435 + 330.6189636582*t)
	Y4 += 0.00000000004*np.cos(1.88093591443 + 728.762966531*t)
	Y4 += 0.00000000004*np.cos(0.14204776620 + 309.2783226558*t)
	Y4 += 0.00000000003*np.cos(0.28739337099 + 191.9584544356*t)
	Y4 += 0.00000000004*np.cos(1.69042467345 + 735.8765135318*t)
	Y4 += 0.00000000003*np.cos(0.60316005015 + 447.9388318784*t)
	Y4 += 0.00000000003*np.cos(0.87226207854 + 302.164775655*t)
	Y4 += 0.00000000003*np.cos(2.70524481937 + 1581.959348283*t)
	Y4 += 0.00000000002*np.cos(4.14482411178 + 1169.5882514086*t)
	Y4 += 0.00000000003*np.cos(0.15041780827 + 323.5054166574*t)
	Y4 += 0.00000000002*np.cos(2.35344419082 + 1155.361157407*t)
	Y4 += 0.00000000002*np.cos(6.26658939437 + 429.7795846137*t)
	Y4 += 0.00000000003*np.cos(4.51313719193 + 316.3918696566*t)
	Y4 += 0.00000000002*np.cos(4.91016885399 + 2118.7638603784*t)
	Y4 += 0.00000000001*np.cos(1.99781026892 + 63.7358983034*t)
	Y4 += 0.00000000002*np.cos(3.78135920108 + 203.0041546995*t)
	Y4 += 0.00000000002*np.cos(1.10796316689 + 223.5940361765*t)
	Y4 += 0.00000000001*np.cos(4.06879161823 + 831.8557407496*t)
	Y4 += 0.00000000001*np.cos(2.20650566797 + 1574.8458012822*t)
	Y4 += 0.00000000001*np.cos(5.87060797450 + 742.9900605326*t)
	Y4 += 0.00000000001*np.cos(0.63254839667 + 149.5631971346*t)
	Y4 += 0.00000000001*np.cos(0.94220550086 + 216.4804891757*t)
	Y4 += 0.00000000001*np.cos(2.68706304185 + 85.8272988312*t)
	Y4 += 0.00000000001*np.cos(2.48150215693 + 423.4167971383*t)
	Y4 += 0.00000000001*np.cos(4.27355998947 + 618.5566453116*t)
	Y4 += 0.00000000001*np.cos(3.90416269039 + 210.1177017003*t)
	Y4 += 0.00000000001*np.cos(5.95376541263 + 337.732510659*t)
	Y4 += 0.00000000001*np.cos(1.98203543124 + 405.2575498736*t)
	Y4 += 0.00000000001*np.cos(3.07160685109 + 1258.4539316256*t)
	Y4 += 0.00000000001*np.cos(0.85310461685 + 949.1756089698*t)
	Y4 += 0.00000000001*np.cos(2.10284025716 + 956.2891559706*t)
	Y4 += 0.00000000001*np.cos(2.25015975765 + 1038.0412891868*t)
	Y4 += 0.00000000001*np.cos(0.07340042854 + 422.6660376129*t)
	Y4 += 0.00000000001*np.cos(5.19829003041 + 18.1592472647*t)
	Y4 += 0.00000000001*np.cos(0.74799227200 + 295.0512286542*t)
	Y4 += 0.00000000001*np.cos(2.74786174307 + 838.9692877504*t)
	Y4 += 0.00000000001*np.cos(0.64687171783 + 131.5469622218*t)
	Y4 += 0.00000000001*np.cos(3.86612290643 + 1485.9801210652*t)
	Y4 += 0.00000000001*np.cos(3.52043585648 + 184.8449074348*t)
	Y4 += 0.00000000001*np.cos(1.36919031011 + 241.7532834412*t)
	Y4 += 0.00000000000*np.cos(5.69629039994 + 1251.3403846248*t)
	Y4 += 0.00000000000*np.cos(2.96705876683 + 611.4430983108*t)
	Y4 += 0.00000000001*np.cos(0.96127473040 + 1361.5467058442*t)
	Y4 += 0.00000000000*np.cos(2.18676531283 + 1471.7530270636*t)
	return Y4*t*t*t*t




def Sun_Y5 (t): # 34 terms of order 5

	Y5 = 0.
	Y5 += 0.00000000168*np.cos(1.70751121627 + 206.1855484372*t)
	Y5 += 0.00000000168*np.cos(6.23113008656 + 220.4126424388*t)
	Y5 += 0.00000000126*np.cos(4.78360062168 + 522.5774180938*t)
	Y5 += 0.00000000121*np.cos(2.73213408225 + 536.8045120954*t)
	Y5 += 0.00000000065*np.cos(6.17991345652 + 227.5261894396*t)
	Y5 += 0.00000000047*np.cos(4.76645839063 + 515.463871093*t)
	Y5 += 0.00000000038*np.cos(5.19126826175 + 433.7117378768*t)
	Y5 += 0.00000000032*np.cos(2.69880941648 + 543.9180590962*t)
	Y5 += 0.00000000027*np.cos(1.88223142168 + 199.0720014364*t)
	Y5 += 0.00000000011*np.cos(1.18187733048 + 14.2270940016*t)
	Y5 += 0.00000000011*np.cos(3.76420251280 + 1066.49547719*t)
	Y5 += 0.00000000010*np.cos(5.22684912304 + 440.8252848776*t)
	Y5 += 0.00000000007*np.cos(4.23388483049 + 647.0108333148*t)
	Y5 += 0.00000000004*np.cos(4.91327178242 + 1052.2683831884*t)
	Y5 += 0.00000000004*np.cos(2.02140363828 + 419.4846438752*t)
	Y5 += 0.00000000003*np.cos(3.88823715659 + 639.897286314*t)
	Y5 += 0.00000000003*np.cos(6.08770400766 + 234.6397364404*t)
	Y5 += 0.00000000002*np.cos(5.07541839899 + 191.9584544356*t)
	Y5 += 0.00000000002*np.cos(4.00021439308 + 426.598190876*t)
	Y5 += 0.00000000002*np.cos(3.32317518434 + 1073.6090241908*t)
	Y5 += 0.00000000002*np.cos(4.64180795349 + 1045.1548361876*t)
	Y5 += 0.00000000001*np.cos(3.09946039705 + 88.865680217*t)
	Y5 += 0.00000000001*np.cos(0.32868254087 + 7.1135470008*t)
	Y5 += 0.00000000001*np.cos(3.90945727398 + 405.2575498736*t)
	Y5 += 0.00000000001*np.cos(5.35212670493 + 213.299095438*t)
	Y5 += 0.00000000001*np.cos(4.33591184160 + 654.1243803156*t)
	Y5 += 0.00000000001*np.cos(2.98586613188 + 853.196381752*t)
	Y5 += 0.00000000001*np.cos(5.47044078046 + 124.433415221*t)
	Y5 += 0.00000000001*np.cos(4.82578898393 + 508.3503240922*t)
	Y5 += 0.00000000001*np.cos(5.79808197162 + 551.031606097*t)
	Y5 += 0.00000000001*np.cos(4.34409570572 + 110.2063212194*t)
	Y5 += 0.00000000001*np.cos(3.32048408656 + 860.3099287528*t)
	Y5 += 0.00000000001*np.cos(5.15758520752 + 447.9388318784*t)
	Y5 += 0.00000000000*np.cos(3.53521969532 + 302.164775655*t)
	return Y5*t*t*t*t*t




def Sun_Z0 (t): # 376 terms of order 0

	Z0 = 0.
	Z0 += 0.00011810648*np.cos(0.46078690233 + 213.299095438*t)
	Z0 += 0.00011277700*np.cos(0.41689943638 + 529.6909650946*t)
	Z0 += 0.00004802048*np.cos(4.58264723370 + 38.1330356378*t)
	Z0 += 0.00001131046*np.cos(5.75877139035 + 74.7815985673*t)
	Z0 -= 0.00001152656
	Z0 += 0.00000329820*np.cos(5.97879747107 + 426.598190876*t)
	Z0 += 0.00000273335*np.cos(0.76652182727 + 1059.3819301892*t)
	Z0 += 0.00000094247*np.cos(3.71017552866 + 206.1855484372*t)
	Z0 += 0.00000081859*np.cos(0.33908959552 + 220.4126424388*t)
	Z0 += 0.00000040793*np.cos(0.45519444489 + 522.5774180938*t)
	Z0 += 0.00000031695*np.cos(3.44538862917 + 536.8045120954*t)
	Z0 += 0.00000024534*np.cos(5.66491831903 + 36.6485629295*t)
	Z0 += 0.00000026057*np.cos(1.93178628731 + 149.5631971346*t)
	Z0 += 0.00000023291*np.cos(0.36646817056 + 39.6175083461*t)
	Z0 += 0.00000019730*np.cos(3.16782731236 + 76.2660712756*t)
	Z0 += 0.00000021801*np.cos(1.54437894252 + 7.1135470008*t)
	Z0 += 0.00000014512*np.cos(1.58375269275 + 110.2063212194*t)
	Z0 += 0.00000013582*np.cos(5.23992989955 + 639.897286314*t)
	Z0 += 0.00000010504*np.cos(2.26694979515 + 316.3918696566*t)
	Z0 += 0.00000010498*np.cos(2.71149033603 + 419.4846438752*t)
	Z0 += 0.00000009935*np.cos(1.11620289745 + 1589.0728952838*t)
	Z0 += 0.00000010483*np.cos(3.40865102614 + 10213.285546211*t)
	Z0 += 0.00000008040*np.cos(3.77010741170 + 73.297125859*t)
	Z0 += 0.00000005440*np.cos(2.41692841439 + 103.0927742186*t)
	Z0 += 0.00000004610*np.cos(5.85854264972 + 433.7117378768*t)
	Z0 += 0.00000003948*np.cos(0.33532528162 + 1.4844727083*t)
	Z0 += 0.00000002610*np.cos(5.41057398526 + 632.7837393132*t)
	Z0 += 0.00000002454*np.cos(6.12024070891 + 1162.4747044078*t)
	Z0 += 0.00000002375*np.cos(6.05534556046 + 1052.2683831884*t)
	Z0 += 0.00000001783*np.cos(3.14608208810 + 846.0828347512*t)
	Z0 += 0.00000001581*np.cos(0.62529460112 + 3340.6124266998*t)
	Z0 += 0.00000001594*np.cos(3.78244334906 + 1066.49547719*t)
	Z0 += 0.00000001566*np.cos(1.99768150464 + 202.2533951741*t)
	Z0 += 0.00000001473*np.cos(0.17358194104 + 35.1640902212*t)
	Z0 += 0.00000001332*np.cos(4.33184702387 + 949.1756089698*t)
	Z0 += 0.00000001137*np.cos(6.15183461939 + 2.9689454166*t)
	Z0 += 0.00000001028*np.cos(0.21025596115 + 227.5261894396*t)
	Z0 += 0.00000000882*np.cos(0.48413591726 + 209.3669421749*t)
	Z0 += 0.00000000862*np.cos(5.26762490934 + 41.1019810544*t)
	Z0 += 0.00000000764*np.cos(5.13454347326 + 26087.9031415742*t)
	Z0 += 0.00000000864*np.cos(2.92013522974 + 148.0787244263*t)
	Z0 += 0.00000000846*np.cos(3.60649450344 + 217.2312487011*t)
	Z0 += 0.00000000779*np.cos(3.77257775192 + 63.7358983034*t)
	Z0 += 0.00000000831*np.cos(6.20016431490 + 323.5054166574*t)
	Z0 += 0.00000000693*np.cos(4.54324890551 + 853.196381752*t)
	Z0 += 0.00000000687*np.cos(2.88181717922 + 71.8126531507*t)
	Z0 += 0.00000000559*np.cos(1.77674120898 + 742.9900605326*t)
	Z0 += 0.00000000459*np.cos(3.95268976842 + 77.7505439839*t)
	Z0 += 0.00000000575*np.cos(3.85836565065 + 199.0720014364*t)
	Z0 += 0.00000000427*np.cos(1.46616895111 + 2118.7638603784*t)
	Z0 += 0.00000000421*np.cos(5.42036909165 + 11.0457002639*t)
	Z0 += 0.00000000421*np.cos(3.41138490065 + 224.3447957019*t)
	Z0 += 0.00000000534*np.cos(0.54255389653 + 515.463871093*t)
	Z0 += 0.00000000385*np.cos(0.88914902748 + 151.0476698429*t)
	Z0 += 0.00000000429*np.cos(1.40544578224 + 14.2270940016*t)
	Z0 += 0.00000000319*np.cos(1.05944718196 + 117.3198682202*t)
	Z0 += 0.00000000312*np.cos(6.24838646568 + 216.4804891757*t)
	Z0 += 0.00000000290*np.cos(5.11770361174 + 647.0108333148*t)
	Z0 += 0.00000000314*np.cos(4.10256974515 + 210.1177017003*t)
	Z0 += 0.00000000296*np.cos(1.59458223926 + 309.2783226558*t)
	Z0 += 0.00000000298*np.cos(5.25958947836 + 415.5524906121*t)
	Z0 += 0.00000000276*np.cos(3.54425558449 + 525.7588118315*t)
	Z0 += 0.00000000317*np.cos(3.85456671343 + 85.8272988312*t)
	Z0 += 0.00000000277*np.cos(0.31958662741 + 138.5174968707*t)
	Z0 += 0.00000000241*np.cos(3.32660302434 + 543.9180590962*t)
	Z0 += 0.00000000198*np.cos(2.49240240273 + 95.9792272178*t)
	Z0 += 0.00000000186*np.cos(4.39437140248 + 277.0349937414*t)
	Z0 += 0.00000000188*np.cos(0.20392851067 + 1692.1656695024*t)
	Z0 += 0.00000000175*np.cos(5.39840733123 + 1478.8665740644*t)
	Z0 += 0.00000000242*np.cos(0.43270824867 + 533.6231183577*t)
	Z0 += 0.00000000179*np.cos(5.79528713551 + 956.2891559706*t)
	Z0 += 0.00000000161*np.cos(3.79231132145 + 490.3340891794*t)
	Z0 += 0.00000000146*np.cos(0.92939894424 + 114.3991069134*t)
	Z0 += 0.00000000170*np.cos(6.26857937202 + 1581.959348283*t)
	Z0 += 0.00000000157*np.cos(0.79065950021 + 1265.5674786264*t)
	Z0 += 0.00000000154*np.cos(0.00941929392 + 735.8765135318*t)
	Z0 += 0.00000000129*np.cos(5.30043284887 + 351.8165923087*t)
	Z0 += 0.00000000117*np.cos(4.81725910872 + 625.6701923124*t)
	Z0 += 0.00000000113*np.cos(3.04973288935 + 532.8723588323*t)
	Z0 += 0.00000000116*np.cos(0.92093201468 + 526.5095713569*t)
	Z0 += 0.00000000129*np.cos(1.11079063120 + 33.6796175129*t)
	Z0 += 0.00000000107*np.cos(3.52070197299 + 1375.7737998458*t)
	Z0 += 0.00000000095*np.cos(4.92440852569 + 4.4534181249*t)
	Z0 += 0.00000000106*np.cos(2.29924580245 + 111.4301614968*t)
	Z0 += 0.00000000103*np.cos(3.99294762314 + 70.3281804424*t)
	Z0 += 0.00000000085*np.cos(4.12867184796 + 1596.1864422846*t)
	Z0 += 0.00000000085*np.cos(6.03717451925 + 127.4717966068*t)
	Z0 += 0.00000000078*np.cos(1.90056477405 + 52175.8062831484*t)
	Z0 += 0.00000000081*np.cos(5.75718254218 + 78.7137518304*t)
	Z0 += 0.00000000076*np.cos(4.37868021510 + 146.594251718*t)
	Z0 += 0.00000000073*np.cos(5.74180456867 + 440.8252848776*t)
	Z0 += 0.00000000094*np.cos(2.55599744292 + 70.8494453042*t)
	Z0 += 0.00000000074*np.cos(0.96384756907 + 6681.2248533996*t)
	Z0 += 0.00000000074*np.cos(6.17414394369 + 137.0330241624*t)
	Z0 += 0.00000000065*np.cos(4.13140277621 + 210.8514148832*t)
	Z0 += 0.00000000064*np.cos(6.21657611750 + 215.7467759928*t)
	Z0 += 0.00000000066*np.cos(4.90503958113 + 222.8603229936*t)
	Z0 += 0.00000000050*np.cos(0.81093625490 + 3.9321532631*t)
	Z0 += 0.00000000055*np.cos(2.96642314550 + 1169.5882514086*t)
	Z0 += 0.00000000046*np.cos(0.75603425226 + 214.2623032845*t)
	Z0 += 0.00000000047*np.cos(5.59856718264 + 422.6660376129*t)
	Z0 += 0.00000000043*np.cos(0.99886063885 + 437.6438911399*t)
	Z0 += 0.00000000042*np.cos(4.06841238442 + 42.5864537627*t)
	Z0 += 0.00000000047*np.cos(3.95753360395 + 109.9456887885*t)
	Z0 += 0.00000000055*np.cos(5.81384971899 + 1045.1548361876*t)
	Z0 += 0.00000000039*np.cos(4.38780950886 + 942.062061969*t)
	Z0 += 0.00000000047*np.cos(3.30738241951 + 212.3358875915*t)
	Z0 += 0.00000000039*np.cos(3.63042667673 + 213.3472795478*t)
	Z0 += 0.00000000038*np.cos(0.54320017724 + 299.1263942692*t)
	Z0 += 0.00000000039*np.cos(5.79384191199 + 380.12776796*t)
	Z0 += 0.00000000035*np.cos(4.28856176749 + 20426.571092422*t)
	Z0 += 0.00000000039*np.cos(0.43264760342 + 213.2509113282*t)
	Z0 += 0.00000000030*np.cos(2.75112354254 + 838.9692877504*t)
	Z0 += 0.00000000030*np.cos(3.04343823849 + 200.7689224658*t)
	Z0 += 0.00000000040*np.cos(6.23354889167 + 1155.361157407*t)
	Z0 += 0.00000000032*np.cos(4.71988612983 + 628.8515860501*t)
	Z0 += 0.00000000031*np.cos(0.58732919927 + 9.5612275556*t)
	Z0 += 0.00000000028*np.cos(5.43761306842 + 388.4651552382*t)
	Z0 += 0.00000000026*np.cos(1.28059116172 + 3.1813937377*t)
	Z0 += 0.00000000025*np.cos(2.59359350223 + 79.2350166922*t)
	Z0 += 0.00000000024*np.cos(5.82405443219 + 108.4612160802*t)
	Z0 += 0.00000000023*np.cos(2.63193831591 + 1272.6810256272*t)
	Z0 += 0.00000000028*np.cos(3.25606570751 + 430.5303441391*t)
	Z0 += 0.00000000022*np.cos(1.93497630901 + 112.9146342051*t)
	Z0 += 0.00000000027*np.cos(5.97682655989 + 330.6189636582*t)
	Z0 += 0.00000000022*np.cos(6.25135477615 + 1795.258443721*t)
	Z0 += 0.00000000020*np.cos(1.78582040688 + 212.7778305762*t)
	Z0 += 0.00000000024*np.cos(0.95152270008 + 527.2432845398*t)
	Z0 += 0.00000000021*np.cos(1.81704412200 + 2648.454825473*t)
	Z0 += 0.00000000019*np.cos(4.36776418254 + 860.3099287528*t)
	Z0 += 0.00000000026*np.cos(3.14039215361 + 423.4167971383*t)
	Z0 += 0.00000000019*np.cos(0.44526121834 + 529.7391492044*t)
	Z0 += 0.00000000023*np.cos(3.02283149606 + 532.1386456494*t)
	Z0 += 0.00000000018*np.cos(1.83971917997 + 1368.660252845*t)
	Z0 += 0.00000000020*np.cos(5.86174074496 + 152.5321425512*t)
	Z0 += 0.00000000019*np.cos(3.53063536661 + 529.6427809848*t)
	Z0 += 0.00000000018*np.cos(5.51118637621 + 429.7795846137*t)
	Z0 += 0.00000000023*np.cos(5.85045041991 + 191.2076949102*t)
	Z0 += 0.00000000018*np.cos(4.95715442948 + 350.3321196004*t)
	Z0 += 0.00000000017*np.cos(5.31530503909 + 288.0806940053*t)
	Z0 += 0.00000000017*np.cos(0.12434288249 + 184.7272873558*t)
	Z0 += 0.00000000020*np.cos(2.27820678920 + 213.8203602998*t)
	Z0 += 0.00000000015*np.cos(5.13468114097 + 195.1398481733*t)
	Z0 += 0.00000000014*np.cos(5.91247133994 + 2008.557539159*t)
	Z0 += 0.00000000015*np.cos(0.30526718104 + 203.7378678824*t)
	Z0 += 0.00000000015*np.cos(3.86419292499 + 530.6541729411*t)
	Z0 += 0.00000000014*np.cos(0.06812069189 + 234.6397364404*t)
	Z0 += 0.00000000014*np.cos(3.04648891279 + 703.6331846174*t)
	Z0 += 0.00000000013*np.cos(5.67578126072 + 84.3428261229*t)
	Z0 += 0.00000000013*np.cos(6.26540514488 + 2111.6503133776*t)
	Z0 += 0.00000000013*np.cos(0.65559035913 + 173.9422195228*t)
	Z0 += 0.00000000013*np.cos(0.50817236658 + 2221.856634597*t)
	Z0 += 0.00000000014*np.cos(4.51668225775 + 145.6310438715*t)
	Z0 += 0.00000000013*np.cos(3.86846352248 + 1055.4497769261*t)
	Z0 += 0.00000000015*np.cos(1.17798794037 + 1063.3140834523*t)
	Z0 += 0.00000000014*np.cos(0.82164896652 + 52.6901980395*t)
	Z0 += 0.00000000012*np.cos(5.81331949760 + 74.6697239827*t)
	Z0 += 0.00000000013*np.cos(4.43466163358 + 453.424893819*t)
	Z0 += 0.00000000011*np.cos(3.65812718259 + 1073.6090241908*t)
	Z0 += 0.00000000011*np.cos(4.51381934850 + 265.9892934775*t)
	Z0 += 0.00000000011*np.cos(4.38170902192 + 565.1156877467*t)
	Z0 += 0.00000000012*np.cos(4.95053521430 + 78263.70942472259*t)
	Z0 += 0.00000000015*np.cos(0.11132517079 + 528.7277572481*t)
	Z0 += 0.00000000012*np.cos(4.19270486844 + 563.6312150384*t)
	Z0 += 0.00000000011*np.cos(3.00019809243 + 217.491881132*t)
	Z0 += 0.00000000012*np.cos(3.25432749571 + 252.6559713532*t)
	Z0 += 0.00000000011*np.cos(2.82174388634 + 210.3783341312*t)
	Z0 += 0.00000000012*np.cos(1.52824474801 + 302.164775655*t)
	Z0 += 0.00000000011*np.cos(5.84037285819 + 145.1097790097*t)
	Z0 += 0.00000000013*np.cos(4.98231508398 + 984.6003316219*t)
	Z0 += 0.00000000012*np.cos(2.22934356868 + 32.1951448046*t)
	Z0 += 0.00000000010*np.cos(0.58421334028 + 160.6088973985*t)
	Z0 += 0.00000000010*np.cos(0.16740688394 + 212.5483359126*t)
	Z0 += 0.00000000010*np.cos(1.61286239287 + 207.8824694666*t)
	Z0 += 0.00000000012*np.cos(5.37679401763 + 362.8622925726*t)
	Z0 += 0.00000000012*np.cos(5.18451722763 + 68.8437077341*t)
	Z0 += 0.00000000009*np.cos(3.00647036484 + 417.0369633204*t)
	Z0 += 0.00000000010*np.cos(5.21528526304 + 412.3710968744*t)
	Z0 += 0.00000000009*np.cos(0.50158036935 + 207.6700211455*t)
	Z0 += 0.00000000010*np.cos(3.89389777532 + 214.0498549634*t)
	Z0 += 0.00000000009*np.cos(4.22285311504 + 12.5301729722*t)
	Z0 += 0.00000000010*np.cos(6.10994422833 + 223.5940361765*t)
	Z0 += 0.00000000012*np.cos(2.56562021906 + 74.8934731519*t)
	Z0 += 0.00000000009*np.cos(0.17310329267 + 124.433415221*t)
	Z0 += 0.00000000011*np.cos(1.23818152928 + 216.2198567448*t)
	Z0 += 0.00000000010*np.cos(0.11060519587 + 221.3758502853*t)
	Z0 += 0.00000000008*np.cos(2.67369883765 + 88.865680217*t)
	Z0 += 0.00000000009*np.cos(3.73069830414 + 5.9378908332*t)
	Z0 += 0.00000000010*np.cos(2.48242357336 + 218.7157214094*t)
	Z0 += 0.00000000011*np.cos(1.05838551520 + 209.106309744*t)
	Z0 += 0.00000000008*np.cos(2.44699715379 + 425.1137181677*t)
	Z0 += 0.00000000010*np.cos(2.92834886255 + 65.2203710117*t)
	Z0 += 0.00000000008*np.cos(4.00825868583 + 217.964961884*t)
	Z0 += 0.00000000007*np.cos(1.66055890695 + 231.4583427027*t)
	Z0 += 0.00000000010*np.cos(2.73461620208 + 225.8292684102*t)
	Z0 += 0.00000000008*np.cos(4.90600221547 + 62.2514255951*t)
	Z0 += 0.00000000008*np.cos(1.19554688546 + 21.3406410024*t)
	Z0 += 0.00000000007*np.cos(4.87306863016 + 28.5718080822*t)
	Z0 += 0.00000000008*np.cos(3.29730720599 + 305.3461693927*t)
	Z0 += 0.00000000007*np.cos(0.23049597733 + 72.3339180125*t)
	Z0 += 0.00000000007*np.cos(2.40752510020 + 142.4496501338*t)
	Z0 += 0.00000000007*np.cos(5.67401911362 + 22.0914005278*t)
	Z0 += 0.00000000006*np.cos(3.95251620961 + 1905.4647649404*t)
	Z0 += 0.00000000007*np.cos(4.88185185222 + 529.1697002328*t)
	Z0 += 0.00000000006*np.cos(1.82944367335 + 479.2883889155*t)
	Z0 += 0.00000000008*np.cos(2.80166552164 + 87.3117715395*t)
	Z0 += 0.00000000009*np.cos(3.57088949662 + 218.9281697305*t)
	Z0 += 0.00000000007*np.cos(5.65779313171 + 37.611770776*t)
	Z0 += 0.00000000006*np.cos(2.76592406875 + 99.1606209555*t)
	Z0 += 0.00000000007*np.cos(0.11176716535 + 71.6002048296*t)
	Z0 += 0.00000000006*np.cos(0.34840869276 + 1485.9801210652*t)
	Z0 += 0.00000000006*np.cos(1.97988087490 + 77.962992305*t)
	Z0 += 0.00000000006*np.cos(2.33983244145 + 408.4389436113*t)
	Z0 += 0.00000000007*np.cos(2.05125547236 + 77.2292791221*t)
	Z0 += 0.00000000007*np.cos(1.26502119681 + 37.1698277913*t)
	Z0 += 0.00000000006*np.cos(4.75926901961 + 39.0962434843*t)
	Z0 += 0.00000000008*np.cos(2.80763220983 + 909.8187330546*t)
	Z0 += 0.00000000006*np.cos(4.99539912729 + 654.1243803156*t)
	Z0 += 0.00000000007*np.cos(0.36785724335 + 38.6543004996*t)
	Z0 += 0.00000000007*np.cos(5.93538750806 + 728.762966531*t)
	Z0 += 0.00000000006*np.cos(1.04402130219 + 47.6942631934*t)
	Z0 += 0.00000000007*np.cos(0.05886999652 + 208.633228992*t)
	Z0 += 0.00000000007*np.cos(5.37708600345 + 530.2122299564*t)
	Z0 += 0.00000000005*np.cos(4.39889286649 + 211.8146227297*t)
	Z0 += 0.00000000007*np.cos(1.64817840189 + 38.084851528*t)
	Z0 += 0.00000000007*np.cos(3.54582842707 + 554.0699874828*t)
	Z0 += 0.00000000006*np.cos(3.40201446866 + 1062.5633239269*t)
	Z0 += 0.00000000007*np.cos(4.37546201284 + 38.1812197476*t)
	Z0 += 0.00000000006*np.cos(0.03712217401 + 414.0680179038*t)
	Z0 += 0.00000000005*np.cos(2.82786902692 + 213.1872208534*t)
	Z0 += 0.00000000005*np.cos(4.28715606019 + 203.0041546995*t)
	Z0 += 0.00000000005*np.cos(0.95506131549 + 1258.4539316256*t)
	Z0 += 0.00000000005*np.cos(2.52632427156 + 18.1592472647*t)
	Z0 += 0.00000000005*np.cos(6.10386016322 + 175.1660598002*t)
	Z0 += 0.00000000005*np.cos(4.47751518123 + 2125.8774073792*t)
	Z0 += 0.00000000005*np.cos(3.88286920561 + 177.8743727859*t)
	Z0 += 0.00000000005*np.cos(3.24026868236 + 1699.2792165032*t)
	Z0 += 0.00000000005*np.cos(5.08227739812 + 186.2117600641*t)
	Z0 += 0.00000000005*np.cos(3.69130628228 + 251.4321310758*t)
	Z0 += 0.00000000005*np.cos(0.95548121243 + 67.6680515665*t)
	Z0 += 0.00000000005*np.cos(6.26978034311 + 604.4725636619*t)
	Z0 += 0.00000000004*np.cos(4.49259592162 + 114.1384744825*t)
	Z0 += 0.00000000004*np.cos(4.59778317885 + 618.5566453116*t)
	Z0 += 0.00000000005*np.cos(0.78722944883 + 508.3503240922*t)
	Z0 += 0.00000000004*np.cos(3.86592568969 + 4.192785694*t)
	Z0 += 0.00000000005*np.cos(0.87260625701 + 106.9767433719*t)
	Z0 += 0.00000000004*np.cos(3.64892863235 + 340.7708920448*t)
	Z0 += 0.00000000005*np.cos(3.18062186793 + 1439.5096981492*t)
	Z0 += 0.00000000004*np.cos(1.57925854393 + 297.6419215609*t)
	Z0 += 0.00000000005*np.cos(4.23847965207 + 525.4981794006*t)
	Z0 += 0.00000000004*np.cos(1.71117403450 + 327.4375699205*t)
	Z0 += 0.00000000004*np.cos(4.62320298963 + 198.321241911*t)
	Z0 += 0.00000000004*np.cos(0.61806948308 + 213.5115437591*t)
	Z0 += 0.00000000004*np.cos(0.20798163037 + 248.7238180901*t)
	Z0 += 0.00000000004*np.cos(0.65358039136 + 483.2205421786*t)
	Z0 += 0.00000000005*np.cos(0.92416895439 + 1056.2005364515*t)
	Z0 += 0.00000000005*np.cos(1.23771152538 + 213.4109700226*t)
	Z0 += 0.00000000004*np.cos(6.03932173906 + 1574.8458012822*t)
	Z0 += 0.00000000004*np.cos(3.44751106922 + 213.0866471169*t)
	Z0 += 0.00000000004*np.cos(2.16136322532 + 153.4953503977*t)
	Z0 += 0.00000000005*np.cos(1.30207792902 + 10021.8372800994*t)
	Z0 += 0.00000000004*np.cos(5.73892739508 + 228.276948965*t)
	Z0 += 0.00000000004*np.cos(6.10222002951 + 526.7702037878*t)
	Z0 += 0.00000000004*np.cos(4.52323052516 + 532.6117264014*t)
	Z0 += 0.00000000004*np.cos(0.73656742279 + 1898.3512179396*t)
	Z0 += 0.00000000004*np.cos(3.47714842774 + 528.9402055692*t)
	Z0 += 0.00000000004*np.cos(0.86380555242 + 530.44172462*t)
	Z0 += 0.00000000004*np.cos(3.45183925667 + 424.1505103212*t)
	Z0 += 0.00000000004*np.cos(0.31042772808 + 569.0478410098*t)
	Z0 += 0.00000000005*np.cos(4.45656375895 + 214.7835681463*t)
	Z0 += 0.00000000003*np.cos(1.26242501430 + 519.3960243561*t)
	Z0 += 0.00000000004*np.cos(0.65373789334 + 1685.0521225016*t)
	Z0 += 0.00000000004*np.cos(4.68405391870 + 454.9093665273*t)
	Z0 += 0.00000000003*np.cos(1.42298337785 + 106.2741679563*t)
	Z0 += 0.00000000003*np.cos(3.60108817122 + 497.4476361802*t)
	Z0 += 0.00000000003*np.cos(1.56100045133 + 183.2428146475*t)
	Z0 += 0.00000000003*np.cos(4.40391204851 + 75.3028634291*t)
	Z0 += 0.00000000003*np.cos(4.73005761431 + 635.9651330509*t)
	Z0 += 0.00000000003*np.cos(3.14146857719 + 121.2520214833*t)
	Z0 += 0.00000000003*np.cos(0.01448243696 + 533.8837507886*t)
	Z0 += 0.00000000003*np.cos(5.27126652032 + 1471.7530270636*t)
	Z0 += 0.00000000003*np.cos(1.49623954615 + 269.9214467406*t)
	Z0 += 0.00000000004*np.cos(5.30459820962 + 1021.2488945514*t)
	Z0 += 0.00000000003*np.cos(1.26353092862 + 213.5597278689*t)
	Z0 += 0.00000000003*np.cos(0.99178205337 + 10.2949407385*t)
	Z0 += 0.00000000004*np.cos(4.70393407981 + 750.1036075334*t)
	Z0 += 0.00000000003*np.cos(5.25738520526 + 205.2223405907*t)
	Z0 += 0.00000000003*np.cos(5.55501782187 + 275.5505210331*t)
	Z0 += 0.00000000003*np.cos(4.10708041863 + 842.1506814881*t)
	Z0 += 0.00000000003*np.cos(2.80204703845 + 213.0384630071*t)
	Z0 += 0.00000000003*np.cos(4.18388521649 + 235.3904959658*t)
	Z0 += 0.00000000003*np.cos(0.25581283397 + 650.9429865779*t)
	Z0 += 0.00000000003*np.cos(2.47503296189 + 35.685355083*t)
	Z0 += 0.00000000003*np.cos(3.16089499657 + 219.4494345923*t)
	Z0 += 0.00000000003*np.cos(4.82271966597 + 488.8496164711*t)
	Z0 += 0.00000000003*np.cos(1.62037648658 + 39.3568759152*t)
	Z0 += 0.00000000003*np.cos(2.88672082290 + 44.070926471*t)
	Z0 += 0.00000000003*np.cos(4.74121551082 + 312.1990839626*t)
	Z0 += 0.00000000003*np.cos(3.08300146416 + 539.9859058331*t)
	Z0 += 0.00000000003*np.cos(0.80509814807 + 278.5194664497*t)
	Z0 += 0.00000000003*np.cos(1.34175195856 + 66.70484372*t)
	Z0 += 0.00000000003*np.cos(4.06718362675 + 2.4476805548*t)
	Z0 += 0.00000000003*np.cos(3.54633119645 + 40.5807161926*t)
	Z0 += 0.00000000002*np.cos(6.11301257096 + 37.8724032069*t)
	Z0 += 0.00000000003*np.cos(5.23687077390 + 73.8183907208*t)
	Z0 += 0.00000000002*np.cos(6.19420370730 + 38.3936680687*t)
	Z0 += 0.00000000003*np.cos(3.54293329241 + 131.4039498699*t)
	Z0 += 0.00000000003*np.cos(3.36863903830 + 983.1158589136*t)
	Z0 += 0.00000000003*np.cos(3.15402716719 + 75.7448064138*t)
	Z0 += 0.00000000003*np.cos(3.78870221205 + 524.0618908021*t)
	Z0 += 0.00000000003*np.cos(3.39440162062 + 551.031606097*t)
	Z0 += 0.00000000003*np.cos(3.97161590444 + 74.2603337055*t)
	Z0 += 0.00000000002*np.cos(0.87766747457 + 125.9873238985*t)
	Z0 += 0.00000000003*np.cos(0.55319601436 + 535.3200393871*t)
	Z0 += 0.00000000003*np.cos(3.78788861052 + 540.7366653585*t)
	Z0 += 0.00000000002*np.cos(0.09797771520 + 427.5613987225*t)
	Z0 += 0.00000000003*np.cos(3.67226584399 + 140.001969579*t)
	Z0 += 0.00000000002*np.cos(0.83380732359 + 210.5907824523*t)
	Z0 += 0.00000000002*np.cos(4.29984135121 + 963.4027029714*t)
	Z0 += 0.00000000003*np.cos(3.34199482893 + 525.0250986486*t)
	Z0 += 0.00000000003*np.cos(2.56620131433 + 425.6349830295*t)
	Z0 += 0.00000000002*np.cos(3.78355960007 + 188.9200730498*t)
	Z0 += 0.00000000002*np.cos(5.89760344409 + 491.8185618877*t)
	Z0 += 0.00000000002*np.cos(3.92732845875 + 116.4260963429*t)
	Z0 += 0.00000000002*np.cos(3.76551699050 + 529.5309064002*t)
	Z0 += 0.00000000002*np.cos(0.57516865787 + 529.851023789*t)
	Z0 += 0.00000000002*np.cos(1.40676994502 + 219.891377577*t)
	Z0 += 0.00000000002*np.cos(0.91879764925 + 207.1487562837*t)
	Z0 += 0.00000000003*np.cos(3.34153277688 + 30.0562807905*t)
	Z0 += 0.00000000002*np.cos(6.17413064816 + 1382.8873468466*t)
	Z0 += 0.00000000003*np.cos(5.73437173488 + 429.0458714308*t)
	Z0 += 0.00000000002*np.cos(0.81033890062 + 82.8583534146*t)
	Z0 += 0.00000000002*np.cos(0.99764796582 + 534.3568315406*t)
	Z0 += 0.00000000002*np.cos(4.69520660438 + 601.7642506762*t)
	Z0 += 0.00000000003*np.cos(4.90630340295 + 524.2743391232*t)
	Z0 += 0.00000000002*np.cos(2.60978508795 + 284.1485407422*t)
	Z0 += 0.00000000002*np.cos(2.87955115067 + 426.6463749858*t)
	Z0 += 0.00000000003*np.cos(5.71565359127 + 535.107591066*t)
	Z0 += 0.00000000002*np.cos(3.18089886744 + 115.8835796217*t)
	Z0 += 0.00000000002*np.cos(3.00030752679 + 1802.3719907218*t)
	Z0 += 0.00000000002*np.cos(2.97888325744 + 1279.794572628*t)
	Z0 += 0.00000000002*np.cos(2.05786530818 + 72.0732855816*t)
	Z0 += 0.00000000002*np.cos(0.44805276245 + 38.0211610532*t)
	Z0 += 0.00000000002*np.cos(0.20667053083 + 237.6781178262*t)
	Z0 += 0.00000000002*np.cos(0.17210708937 + 2324.9494088156*t)
	Z0 += 0.00000000002*np.cos(4.67891472304 + 289.5651667136*t)
	Z0 += 0.00000000002*np.cos(2.00908637681 + 33.9402499438*t)
	Z0 += 0.00000000002*np.cos(1.71762766651 + 104351.61256629678*t)
	Z0 += 0.00000000002*np.cos(3.22972846783 + 216.0074084237*t)
	Z0 += 0.00000000002*np.cos(5.04182015718 + 134.5853436076*t)
	Z0 += 0.00000000002*np.cos(3.49209986964 + 220.4608265486*t)
	Z0 += 0.00000000002*np.cos(3.72450811952 + 213.4591541324*t)
	Z0 += 0.00000000002*np.cos(5.57565232466 + 38.2449102224*t)
	Z0 += 0.00000000002*np.cos(3.43364776514 + 404.5067903482*t)
	Z0 += 0.00000000002*np.cos(3.03767067561 + 373.9079928365*t)
	Z0 += 0.00000000002*np.cos(0.33903543142 + 213.1390367436*t)
	Z0 += 0.00000000002*np.cos(5.96494167994 + 426.5500067662*t)
	Z0 += 0.00000000002*np.cos(6.03577549956 + 312.4597163935*t)
	Z0 += 0.00000000002*np.cos(4.02556255437 + 42.3258213318*t)
	Z0 += 0.00000000002*np.cos(2.08779280853 + 212.0270710508*t)
	Z0 += 0.00000000002*np.cos(3.01270661235 + 179.3588454942*t)
	Z0 += 0.00000000002*np.cos(3.87238789264 + 355.7487455718*t)
	Z0 += 0.00000000002*np.cos(1.04922950735 + 247.2393453818*t)
	Z0 += 0.00000000002*np.cos(4.60061147679 + 501.3797894433*t)
	Z0 += 0.00000000002*np.cos(2.65135116397 + 46.2097904851*t)
	Z0 += 0.00000000002*np.cos(3.57852035408 + 128.9562693151*t)
	Z0 += 0.00000000002*np.cos(0.63486230084 + 518.6452648307*t)
	Z0 += 0.00000000002*np.cos(3.95801018748 + 181.0557665236*t)
	Z0 += 0.00000000002*np.cos(3.71481844603 + 643.8294395771*t)
	Z0 += 0.00000000002*np.cos(4.02261318625 + 529.9034134157*t)
	Z0 += 0.00000000002*np.cos(0.31807246212 + 529.4785167735*t)
	Z0 += 0.00000000002*np.cos(4.73928465313 + 80.1982245387*t)
	Z0 += 0.00000000002*np.cos(5.13009702873 + 81.8951455681*t)
	Z0 += 0.00000000002*np.cos(1.38730096276 + 80.7194894005*t)
	Z0 += 0.00000000002*np.cos(1.53818574837 + 621.7380390493*t)
	Z0 += 0.00000000002*np.cos(2.29718443877 + 636.7158925763*t)
	return Z0




def Sun_Z1 (t): # 243 terms of order 1

	Z1 = 0.
	Z1 += 0.00000544343*np.cos(1.80383716985 + 213.299095438*t)
	Z1 += 0.00000388234*np.cos(4.66855221170 + 529.6909650946*t)
	Z1 += 0.00000133398
	Z1 += 0.00000037294*np.cos(5.40133589632 + 206.1855484372*t)
	Z1 += 0.00000028944*np.cos(4.93245710560 + 220.4126424388*t)
	Z1 += 0.00000028635*np.cos(3.15447649004 + 74.7815985673*t)
	Z1 += 0.00000024988*np.cos(3.65752330365 + 426.598190876*t)
	Z1 += 0.00000019373*np.cos(5.74043087058 + 1059.3819301892*t)
	Z1 += 0.00000013746*np.cos(1.71298046603 + 536.8045120954*t)
	Z1 += 0.00000012168*np.cos(2.31196328906 + 522.5774180938*t)
	Z1 += 0.00000008010*np.cos(5.28413417446 + 38.1330356378*t)
	Z1 += 0.00000004978*np.cos(4.29826949554 + 419.4846438752*t)
	Z1 += 0.00000004388*np.cos(6.14545946311 + 7.1135470008*t)
	Z1 += 0.00000002586*np.cos(3.01944725018 + 639.897286314*t)
	Z1 += 0.00000002131*np.cos(4.06053382034 + 433.7117378768*t)
	Z1 += 0.00000001560*np.cos(3.28261094599 + 316.3918696566*t)
	Z1 += 0.00000001173*np.cos(0.00063234885 + 1589.0728952838*t)
	Z1 += 0.00000001029*np.cos(5.86675536556 + 149.5631971346*t)
	Z1 += 0.00000000775*np.cos(4.79688880139 + 227.5261894396*t)
	Z1 += 0.00000000739*np.cos(2.12600457660 + 1066.49547719*t)
	Z1 += 0.00000000645*np.cos(1.62570263847 + 1052.2683831884*t)
	Z1 += 0.00000000692*np.cos(0.27213238919 + 6283.0758499914*t)
	Z1 += 0.00000000542*np.cos(1.44488755125 + 110.2063212194*t)
	Z1 += 0.00000000533*np.cos(2.34579176940 + 76.2660712756*t)
	Z1 += 0.00000000509*np.cos(5.03126544101 + 10213.285546211*t)
	Z1 += 0.00000000403*np.cos(1.25691345472 + 36.6485629295*t)
	Z1 += 0.00000000352*np.cos(4.79823464785 + 39.6175083461*t)
	Z1 += 0.00000000446*np.cos(5.55248874462 + 199.0720014364*t)
	Z1 += 0.00000000368*np.cos(5.32358181908 + 103.0927742186*t)
	Z1 += 0.00000000302*np.cos(5.15335876647 + 632.7837393132*t)
	Z1 += 0.00000000343*np.cos(2.32388226037 + 515.463871093*t)
	Z1 += 0.00000000258*np.cos(5.99544147559 + 14.2270940016*t)
	Z1 += 0.00000000266*np.cos(0.49468027720 + 73.297125859*t)
	Z1 += 0.00000000251*np.cos(5.58497774438 + 217.2312487011*t)
	Z1 += 0.00000000210*np.cos(5.87638250776 + 210.1177017003*t)
	Z1 += 0.00000000200*np.cos(1.60953815793 + 543.9180590962*t)
	Z1 += 0.00000000205*np.cos(2.38357660053 + 853.196381752*t)
	Z1 += 0.00000000186*np.cos(4.63128120913 + 209.3669421749*t)
	Z1 += 0.00000000166*np.cos(3.25384215179 + 647.0108333148*t)
	Z1 += 0.00000000188*np.cos(4.45601446980 + 216.4804891757*t)
	Z1 += 0.00000000147*np.cos(4.91154015633 + 202.2533951741*t)
	Z1 += 0.00000000148*np.cos(6.00943832296 + 949.1756089698*t)
	Z1 += 0.00000000143*np.cos(3.70203142149 + 323.5054166574*t)
	Z1 += 0.00000000140*np.cos(0.83132381305 + 735.8765135318*t)
	Z1 += 0.00000000122*np.cos(5.67146512225 + 117.3198682202*t)
	Z1 += 0.00000000100*np.cos(2.78745027781 + 1.4844727083*t)
	Z1 += 0.00000000107*np.cos(2.90868508133 + 3340.6124266998*t)
	Z1 += 0.00000000084*np.cos(4.30248448955 + 1162.4747044078*t)
	Z1 += 0.00000000077*np.cos(4.22942639128 + 95.9792272178*t)
	Z1 += 0.00000000079*np.cos(0.36636125409 + 11.0457002639*t)
	Z1 += 0.00000000075*np.cos(1.47982807612 + 525.7588118315*t)
	Z1 += 0.00000000076*np.cos(1.24245643745 + 532.8723588323*t)
	Z1 += 0.00000000096*np.cos(0.86129378681 + 63.7358983034*t)
	Z1 += 0.00000000071*np.cos(2.75365102566 + 526.5095713569*t)
	Z1 += 0.00000000071*np.cos(0.43437193243 + 2118.7638603784*t)
	Z1 += 0.00000000063*np.cos(3.98868546710 + 440.8252848776*t)
	Z1 += 0.00000000061*np.cos(2.62473045895 + 533.6231183577*t)
	Z1 += 0.00000000054*np.cos(1.42941204449 + 85.8272988312*t)
	Z1 += 0.00000000057*np.cos(3.98493436395 + 309.2783226558*t)
	Z1 += 0.00000000051*np.cos(0.39392917326 + 742.9900605326*t)
	Z1 += 0.00000000049*np.cos(4.84482792493 + 956.2891559706*t)
	Z1 += 0.00000000043*np.cos(2.55616001516 + 1596.1864422846*t)
	Z1 += 0.00000000036*np.cos(0.55224025396 + 625.6701923124*t)
	Z1 += 0.00000000039*np.cos(2.77790342477 + 35.1640902212*t)
	Z1 += 0.00000000030*np.cos(4.35442775962 + 412.3710968744*t)
	Z1 += 0.00000000038*np.cos(5.38040433295 + 224.3447957019*t)
	Z1 += 0.00000000035*np.cos(1.26816443678 + 1045.1548361876*t)
	Z1 += 0.00000000031*np.cos(0.64597904023 + 70.8494453042*t)
	Z1 += 0.00000000036*np.cos(1.74852565178 + 1581.959348283*t)
	Z1 += 0.00000000026*np.cos(3.58372397053 + 41.1019810544*t)
	Z1 += 0.00000000030*np.cos(3.31574729193 + 138.5174968707*t)
	Z1 += 0.00000000024*np.cos(1.14783906654 + 71.8126531507*t)
	Z1 += 0.00000000022*np.cos(1.56359401952 + 78.7137518304*t)
	Z1 += 0.00000000022*np.cos(1.22800274368 + 1169.5882514086*t)
	Z1 += 0.00000000024*np.cos(0.09566124749 + 277.0349937414*t)
	Z1 += 0.00000000019*np.cos(1.46315634551 + 215.7467759928*t)
	Z1 += 0.00000000018*np.cos(6.15872883408 + 942.062061969*t)
	Z1 += 0.00000000021*np.cos(4.93349279148 + 151.0476698429*t)
	Z1 += 0.00000000018*np.cos(0.76975485466 + 26087.9031415742*t)
	Z1 += 0.00000000017*np.cos(0.45299038457 + 148.0787244263*t)
	Z1 += 0.00000000017*np.cos(1.01231551874 + 415.5524906121*t)
	Z1 += 0.00000000017*np.cos(2.42309662009 + 1265.5674786264*t)
	Z1 += 0.00000000016*np.cos(4.65513429214 + 234.6397364404*t)
	Z1 += 0.00000000019*np.cos(3.54990981323 + 422.6660376129*t)
	Z1 += 0.00000000015*np.cos(4.05286495428 + 330.6189636582*t)
	Z1 += 0.00000000017*np.cos(1.47291446860 + 77.7505439839*t)
	Z1 += 0.00000000015*np.cos(4.99910482431 + 423.4167971383*t)
	Z1 += 0.00000000014*np.cos(2.62615297219 + 210.8514148832*t)
	Z1 += 0.00000000016*np.cos(1.68091549808 + 1155.361157407*t)
	Z1 += 0.00000000013*np.cos(2.45853344415 + 860.3099287528*t)
	Z1 += 0.00000000013*np.cos(2.99861766415 + 846.0828347512*t)
	Z1 += 0.00000000012*np.cos(5.65589126671 + 3.1813937377*t)
	Z1 += 0.00000000014*np.cos(5.19944091841 + 1692.1656695024*t)
	Z1 += 0.00000000013*np.cos(3.66006461043 + 429.7795846137*t)
	Z1 += 0.00000000011*np.cos(4.40128024814 + 2.9689454166*t)
	Z1 += 0.00000000011*np.cos(1.10505354081 + 3.9321532631*t)
	Z1 += 0.00000000010*np.cos(1.95569420228 + 1073.6090241908*t)
	Z1 += 0.00000000010*np.cos(5.59867007444 + 430.5303441391*t)
	Z1 += 0.00000000010*np.cos(4.88911638894 + 437.6438911399*t)
	Z1 += 0.00000000008*np.cos(5.78717497024 + 21.3406410024*t)
	Z1 += 0.00000000010*np.cos(4.33333704289 + 223.5940361765*t)
	Z1 += 0.00000000007*np.cos(5.35409000250 + 490.3340891794*t)
	Z1 += 0.00000000007*np.cos(4.34819824133 + 88.865680217*t)
	Z1 += 0.00000000007*np.cos(4.70532379473 + 124.433415221*t)
	Z1 += 0.00000000007*np.cos(1.14440533228 + 728.762966531*t)
	Z1 += 0.00000000007*np.cos(3.68649801447 + 127.4717966068*t)
	Z1 += 0.00000000006*np.cos(6.04907029839 + 203.0041546995*t)
	Z1 += 0.00000000006*np.cos(4.95034875779 + 137.0330241624*t)
	Z1 += 0.00000000006*np.cos(0.30570108881 + 351.8165923087*t)
	Z1 += 0.00000000006*np.cos(3.20318007478 + 654.1243803156*t)
	Z1 += 0.00000000005*np.cos(1.42127686013 + 1272.6810256272*t)
	Z1 += 0.00000000005*np.cos(2.44842875080 + 203.7378678824*t)
	Z1 += 0.00000000005*np.cos(5.11972485720 + 1478.8665740644*t)
	Z1 += 0.00000000006*np.cos(2.41904485988 + 508.3503240922*t)
	Z1 += 0.00000000006*np.cos(2.36270756836 + 1375.7737998458*t)
	Z1 += 0.00000000006*np.cos(0.22902005605 + 12566.1516999828*t)
	Z1 += 0.00000000004*np.cos(0.17343495362 + 77.962992305*t)
	Z1 += 0.00000000004*np.cos(0.82804020722 + 2648.454825473*t)
	Z1 += 0.00000000004*np.cos(3.45025275060 + 302.164775655*t)
	Z1 += 0.00000000004*np.cos(2.71504785765 + 145.6310438715*t)
	Z1 += 0.00000000004*np.cos(2.33499481674 + 217.964961884*t)
	Z1 += 0.00000000005*np.cos(1.92784340899 + 71.6002048296*t)
	Z1 += 0.00000000005*np.cos(1.79793964328 + 838.9692877504*t)
	Z1 += 0.00000000004*np.cos(1.85326390850 + 1062.5633239269*t)
	Z1 += 0.00000000004*np.cos(6.03119287364 + 231.4583427027*t)
	Z1 += 0.00000000003*np.cos(3.02744600090 + 519.3960243561*t)
	Z1 += 0.00000000004*np.cos(0.89049397706 + 195.1398481733*t)
	Z1 += 0.00000000003*np.cos(2.01193875506 + 1055.4497769261*t)
	Z1 += 0.00000000004*np.cos(1.72058950460 + 208.633228992*t)
	Z1 += 0.00000000003*np.cos(0.56878235962 + 20426.571092422*t)
	Z1 += 0.00000000004*np.cos(2.89875785554 + 191.2076949102*t)
	Z1 += 0.00000000003*np.cos(1.49763820612 + 628.8515860501*t)
	Z1 += 0.00000000003*np.cos(2.50968075109 + 1258.4539316256*t)
	Z1 += 0.00000000003*np.cos(3.79377402256 + 33.6796175129*t)
	Z1 += 0.00000000003*np.cos(1.66372269460 + 551.031606097*t)
	Z1 += 0.00000000003*np.cos(3.41950816047 + 1063.3140834523*t)
	Z1 += 0.00000000003*np.cos(1.37221108578 + 1574.8458012822*t)
	Z1 += 0.00000000003*np.cos(4.01135882339 + 408.4389436113*t)
	Z1 += 0.00000000003*np.cos(4.46251874070 + 210.3783341312*t)
	Z1 += 0.00000000003*np.cos(4.75315110074 + 6681.2248533996*t)
	Z1 += 0.00000000003*np.cos(4.63049206271 + 218.7157214094*t)
	Z1 += 0.00000000003*np.cos(5.64204586528 + 1485.9801210652*t)
	Z1 += 0.00000000003*np.cos(1.31558469253 + 539.9859058331*t)
	Z1 += 0.00000000003*np.cos(2.72430580528 + 1056.2005364515*t)
	Z1 += 0.00000000002*np.cos(2.16230487068 + 207.6700211455*t)
	Z1 += 0.00000000002*np.cos(3.18147754305 + 2125.8774073792*t)
	Z1 += 0.00000000003*np.cos(5.61280205664 + 200.7689224658*t)
	Z1 += 0.00000000003*np.cos(4.44842975611 + 65.2203710117*t)
	Z1 += 0.00000000003*np.cos(2.17328098941 + 222.8603229936*t)
	Z1 += 0.00000000002*np.cos(5.49080131787 + 10.2949407385*t)
	Z1 += 0.00000000002*np.cos(5.99685840632 + 191.9584544356*t)
	Z1 += 0.00000000002*np.cos(3.06118586135 + 362.8622925726*t)
	Z1 += 0.00000000003*np.cos(4.54121152593 + 160.6088973985*t)
	Z1 += 0.00000000002*np.cos(3.72250870728 + 1368.660252845*t)
	Z1 += 0.00000000002*np.cos(2.46011533669 + 22.0914005278*t)
	Z1 += 0.00000000002*np.cos(2.10233966328 + 214.2623032845*t)
	Z1 += 0.00000000003*np.cos(5.66595709433 + 340.7708920448*t)
	Z1 += 0.00000000003*np.cos(0.57835093859 + 350.3321196004*t)
	Z1 += 0.00000000002*np.cos(3.15161180799 + 4.4534181249*t)
	Z1 += 0.00000000003*np.cos(4.69656362747 + 299.1263942692*t)
	Z1 += 0.00000000002*np.cos(4.65398203665 + 212.3358875915*t)
	Z1 += 0.00000000002*np.cos(1.67392936462 + 1699.2792165032*t)
	Z1 += 0.00000000002*np.cos(2.32968256943 + 42.5864537627*t)
	Z1 += 0.00000000002*np.cos(5.53004407893 + 207.8824694666*t)
	Z1 += 0.00000000002*np.cos(2.06776737123 + 2111.6503133776*t)
	Z1 += 0.00000000002*np.cos(0.04144913456 + 618.5566453116*t)
	Z1 += 0.00000000002*np.cos(0.91015862835 + 1471.7530270636*t)
	Z1 += 0.00000000002*np.cos(4.26405752011 + 52.6901980395*t)
	Z1 += 0.00000000002*np.cos(3.52721961173 + 84.3428261229*t)
	Z1 += 0.00000000002*np.cos(4.02999355633 + 142.4496501338*t)
	Z1 += 0.00000000002*np.cos(0.83557674544 + 18.1592472647*t)
	Z1 += 0.00000000002*np.cos(4.97693506446 + 213.3472795478*t)
	Z1 += 0.00000000002*np.cos(3.17528194538 + 1795.258443721*t)
	Z1 += 0.00000000002*np.cos(0.28786653402 + 114.3991069134*t)
	Z1 += 0.00000000002*np.cos(2.54422423819 + 750.1036075334*t)
	Z1 += 0.00000000002*np.cos(5.09272772324 + 525.0250986486*t)
	Z1 += 0.00000000002*np.cos(0.34055034122 + 87.3117715395*t)
	Z1 += 0.00000000002*np.cos(5.47951702029 + 12.5301729722*t)
	Z1 += 0.00000000002*np.cos(2.96402022406 + 209.106309744*t)
	Z1 += 0.00000000002*np.cos(3.13274783491 + 265.9892934775*t)
	Z1 += 0.00000000002*np.cos(5.52867791022 + 534.3568315406*t)
	Z1 += 0.00000000002*np.cos(3.88090223309 + 447.9388318784*t)
	Z1 += 0.00000000002*np.cos(2.45221075350 + 483.2205421786*t)
	Z1 += 0.00000000002*np.cos(1.83965429968 + 218.9281697305*t)
	Z1 += 0.00000000001*np.cos(0.20989248113 + 111.4301614968*t)
	Z1 += 0.00000000001*np.cos(4.98194449679 + 72.3339180125*t)
	Z1 += 0.00000000002*np.cos(1.77913926799 + 213.2509113282*t)
	Z1 += 0.00000000002*np.cos(2.70676486201 + 635.9651330509*t)
	Z1 += 0.00000000001*np.cos(2.63547460277 + 288.0806940053*t)
	Z1 += 0.00000000001*np.cos(5.68543673774 + 2221.856634597*t)
	Z1 += 0.00000000001*np.cos(0.08047778521 + 79.2350166922*t)
	Z1 += 0.00000000001*np.cos(1.56819267678 + 424.1505103212*t)
	Z1 += 0.00000000002*np.cos(5.83111779361 + 216.2198567448*t)
	Z1 += 0.00000000002*np.cos(3.16129229610 + 269.9214467406*t)
	Z1 += 0.00000000001*np.cos(1.40901613690 + 235.3904959658*t)
	Z1 += 0.00000000001*np.cos(1.00631007100 + 1279.794572628*t)
	Z1 += 0.00000000001*np.cos(0.93647094311 + 37.611770776*t)
	Z1 += 0.00000000001*np.cos(5.74259270837 + 554.0699874828*t)
	Z1 += 0.00000000001*np.cos(6.11538771726 + 106.2741679563*t)
	Z1 += 0.00000000001*np.cos(1.84003176748 + 497.4476361802*t)
	Z1 += 0.00000000001*np.cos(0.31086841657 + 388.4651552382*t)
	Z1 += 0.00000000001*np.cos(3.76468586063 + 152.5321425512*t)
	Z1 += 0.00000000001*np.cos(5.08672600352 + 38.6543004996*t)
	Z1 += 0.00000000001*np.cos(1.41115224290 + 1685.0521225016*t)
	Z1 += 0.00000000001*np.cos(2.49327633124 + 67.6680515665*t)
	Z1 += 0.00000000001*np.cos(2.79899486004 + 934.9485149682*t)
	Z1 += 0.00000000001*np.cos(2.97580776066 + 9.5612275556*t)
	Z1 += 0.00000000001*np.cos(2.02490299321 + 62.2514255951*t)
	Z1 += 0.00000000001*np.cos(2.49832684365 + 524.2743391232*t)
	Z1 += 0.00000000001*np.cos(5.76079014921 + 113.3877149571*t)
	Z1 += 0.00000000001*np.cos(1.30865112809 + 1148.2476104062*t)
	Z1 += 0.00000000001*np.cos(1.37538181177 + 1038.0412891868*t)
	Z1 += 0.00000000001*np.cos(1.84235881885 + 535.107591066*t)
	Z1 += 0.00000000001*np.cos(3.04251444851 + 2428.0421830342*t)
	Z1 += 0.00000000001*np.cos(1.29065795333 + 219.4494345923*t)
	Z1 += 0.00000000001*np.cos(2.95250802930 + 56.6223513026*t)
	Z1 += 0.00000000001*np.cos(3.13251435442 + 212.7778305762*t)
	Z1 += 0.00000000001*np.cos(4.41660907664 + 73.8183907208*t)
	Z1 += 0.00000000001*np.cos(5.07517172587 + 2008.557539159*t)
	Z1 += 0.00000000001*np.cos(4.59727399039 + 650.9429865779*t)
	Z1 += 0.00000000001*np.cos(3.68457589532 + 77.2292791221*t)
	Z1 += 0.00000000001*np.cos(4.56491862614 + 1382.8873468466*t)
	Z1 += 0.00000000001*np.cos(3.95195861818 + 75.7448064138*t)
	Z1 += 0.00000000001*np.cos(1.31668004242 + 107.0249274817*t)
	Z1 += 0.00000000001*np.cos(3.62412377729 + 213.8203602998*t)
	Z1 += 0.00000000001*np.cos(1.63794916868 + 212.5483359126*t)
	Z1 += 0.00000000001*np.cos(1.27002779619 + 511.5317178299*t)
	Z1 += 0.00000000001*np.cos(3.99921418950 + 153.4953503977*t)
	Z1 += 0.00000000001*np.cos(0.52271655373 + 74.8934731519*t)
	Z1 += 0.00000000001*np.cos(4.45248239012 + 344.7030453079*t)
	Z1 += 0.00000000001*np.cos(0.64297228899 + 1788.1448967202*t)
	Z1 += 0.00000000001*np.cos(2.87243947976 + 643.0786800517*t)
	Z1 += 0.00000000001*np.cos(3.08500358340 + 547.8502123593*t)
	Z1 += 0.00000000001*np.cos(0.94741803528 + 284.1485407422*t)
	Z1 += 0.00000000001*np.cos(4.33222478926 + 337.732510659*t)
	Z1 += 0.00000000001*np.cos(4.83872793621 + 636.7158925763*t)
	Z1 += 0.00000000001*np.cos(0.02867386798 + 98.8999885246*t)
	Z1 += 0.00000000001*np.cos(3.34183609891 + 1905.4647649404*t)
	Z1 += 0.00000000001*np.cos(5.55010206352 + 131.4039498699*t)
	Z1 += 0.00000000001*np.cos(1.53995824219 + 526.7702037878*t)
	Z1 += 0.00000000001*np.cos(2.80095524257 + 532.6117264014*t)
	Z1 += 0.00000000001*np.cos(0.46243786333 + 703.6331846174*t)
	Z1 += 0.00000000001*np.cos(1.45358374772 + 146.594251718*t)
	return Z1*t




def Sun_Z2 (t): # 123 terms of order 2

	Z2 = 0.
	Z2 += 0.00000037478*np.cos(3.23028568613 + 213.299095438*t)
	Z2 += 0.00000027315*np.cos(6.15507992196 + 529.6909650946*t)
	Z2 += 0.00000008616*np.cos(0.77209239310 + 206.1855484372*t)
	Z2 += 0.00000005511*np.cos(3.23377546695 + 220.4126424388*t)
	Z2 += 0.00000002969*np.cos(6.27419756063 + 536.8045120954*t)
	Z2 += 0.00000002272*np.cos(4.09618627765 + 522.5774180938*t)
	Z2 += 0.00000001982*np.cos(2.34242027589 + 426.598190876*t)
	Z2 += 0.00000001250*np.cos(5.19399610895 + 1059.3819301892*t)
	Z2 -= 0.00000001678
	Z2 += 0.00000000743*np.cos(6.08844686068 + 419.4846438752*t)
	Z2 += 0.00000000641*np.cos(4.89317483950 + 74.7815985673*t)
	Z2 += 0.00000000527*np.cos(2.28325191846 + 433.7117378768*t)
	Z2 += 0.00000000519*np.cos(4.43200328483 + 7.1135470008*t)
	Z2 += 0.00000000300*np.cos(3.09602587558 + 227.5261894396*t)
	Z2 += 0.00000000294*np.cos(1.18226869992 + 639.897286314*t)
	Z2 += 0.00000000173*np.cos(0.49687224658 + 1066.49547719*t)
	Z2 += 0.00000000184*np.cos(0.95286916137 + 199.0720014364*t)
	Z2 += 0.00000000149*np.cos(4.90906266305 + 316.3918696566*t)
	Z2 += 0.00000000119*np.cos(4.09508225076 + 515.463871093*t)
	Z2 += 0.00000000106*np.cos(3.65846401642 + 1052.2683831884*t)
	Z2 += 0.00000000111*np.cos(5.37256662943 + 1589.0728952838*t)
	Z2 += 0.00000000085*np.cos(6.16812793384 + 543.9180590962*t)
	Z2 += 0.00000000079*np.cos(4.29766380692 + 14.2270940016*t)
	Z2 += 0.00000000068*np.cos(1.33776656115 + 210.1177017003*t)
	Z2 += 0.00000000065*np.cos(5.05560764351 + 38.1330356378*t)
	Z2 += 0.00000000058*np.cos(1.55728577024 + 103.0927742186*t)
	Z2 += 0.00000000050*np.cos(1.42158496561 + 647.0108333148*t)
	Z2 += 0.00000000042*np.cos(1.14028846687 + 217.2312487011*t)
	Z2 += 0.00000000053*np.cos(2.67570413760 + 216.4804891757*t)
	Z2 += 0.00000000031*np.cos(4.21025720942 + 110.2063212194*t)
	Z2 += 0.00000000029*np.cos(6.18539185721 + 632.7837393132*t)
	Z2 += 0.00000000028*np.cos(2.23145809257 + 440.8252848776*t)
	Z2 += 0.00000000030*np.cos(2.01074460556 + 6283.0758499914*t)
	Z2 += 0.00000000033*np.cos(0.42157783312 + 853.196381752*t)
	Z2 += 0.00000000025*np.cos(3.95236444346 + 117.3198682202*t)
	Z2 += 0.00000000025*np.cos(2.78460430400 + 209.3669421749*t)
	Z2 += 0.00000000022*np.cos(0.20631739913 + 10213.285546211*t)
	Z2 += 0.00000000021*np.cos(5.74317740279 + 532.8723588323*t)
	Z2 += 0.00000000018*np.cos(1.87060868220 + 323.5054166574*t)
	Z2 += 0.00000000017*np.cos(4.58615737180 + 526.5095713569*t)
	Z2 += 0.00000000017*np.cos(6.02623550832 + 95.9792272178*t)
	Z2 += 0.00000000016*np.cos(6.02211293999 + 412.3710968744*t)
	Z2 += 0.00000000015*np.cos(0.00767394500 + 202.2533951741*t)
	Z2 += 0.00000000012*np.cos(2.50603952514 + 149.5631971346*t)
	Z2 += 0.00000000013*np.cos(5.75707842894 + 525.7588118315*t)
	Z2 += 0.00000000011*np.cos(2.77607629936 + 73.297125859*t)
	Z2 += 0.00000000011*np.cos(0.99969948118 + 1596.1864422846*t)
	Z2 += 0.00000000012*np.cos(3.07376705363 + 1045.1548361876*t)
	Z2 += 0.00000000011*np.cos(0.01879438470 + 309.2783226558*t)
	Z2 += 0.00000000010*np.cos(4.70919553736 + 533.6231183577*t)
	Z2 += 0.00000000009*np.cos(2.95298668799 + 234.6397364404*t)
	Z2 += 0.00000000008*np.cos(5.32804606956 + 1162.4747044078*t)
	Z2 += 0.00000000010*np.cos(2.94983110269 + 735.8765135318*t)
	Z2 += 0.00000000009*np.cos(5.72498770637 + 2118.7638603784*t)
	Z2 += 0.00000000008*np.cos(2.26838540542 + 625.6701923124*t)
	Z2 += 0.00000000009*np.cos(2.32555299082 + 949.1756089698*t)
	Z2 += 0.00000000007*np.cos(4.26888098753 + 36.6485629295*t)
	Z2 += 0.00000000007*np.cos(3.46601151480 + 956.2891559706*t)
	Z2 += 0.00000000007*np.cos(1.63081873969 + 39.6175083461*t)
	Z2 += 0.00000000005*np.cos(3.78134955861 + 1581.959348283*t)
	Z2 += 0.00000000005*np.cos(5.79930116461 + 1169.5882514086*t)
	Z2 += 0.00000000005*np.cos(2.33387808307 + 330.6189636582*t)
	Z2 += 0.00000000005*np.cos(3.55135533961 + 224.3447957019*t)
	Z2 += 0.00000000004*np.cos(4.18372117957 + 3340.6124266998*t)
	Z2 += 0.00000000004*np.cos(4.10663814883 + 21.3406410024*t)
	Z2 += 0.00000000005*np.cos(0.57738242740 + 860.3099287528*t)
	Z2 += 0.00000000004*np.cos(0.44270397791 + 1073.6090241908*t)
	Z2 += 0.00000000005*np.cos(5.42524693917 + 85.8272988312*t)
	Z2 += 0.00000000004*np.cos(0.59720671044 + 423.4167971383*t)
	Z2 += 0.00000000004*np.cos(4.95079393388 + 70.8494453042*t)
	Z2 += 0.00000000004*np.cos(1.70877653176 + 942.062061969*t)
	Z2 += 0.00000000005*np.cos(2.54022722440 + 223.5940361765*t)
	Z2 += 0.00000000004*np.cos(1.79684320381 + 429.7795846137*t)
	Z2 += 0.00000000004*np.cos(6.22298149928 + 76.2660712756*t)
	Z2 += 0.00000000004*np.cos(1.66020203630 + 422.6660376129*t)
	Z2 += 0.00000000003*np.cos(1.55704409970 + 203.0041546995*t)
	Z2 += 0.00000000003*np.cos(4.44130584150 + 508.3503240922*t)
	Z2 += 0.00000000003*np.cos(2.94487074403 + 124.433415221*t)
	Z2 += 0.00000000003*np.cos(3.32056352021 + 11.0457002639*t)
	Z2 += 0.00000000003*np.cos(2.81673969588 + 63.7358983034*t)
	Z2 += 0.00000000004*np.cos(3.08638029988 + 3.9321532631*t)
	Z2 += 0.00000000003*np.cos(3.54543066660 + 1155.361157407*t)
	Z2 += 0.00000000003*np.cos(6.06819480018 + 88.865680217*t)
	Z2 += 0.00000000003*np.cos(2.90469145846 + 728.762966531*t)
	Z2 += 0.00000000003*np.cos(1.40705858439 + 654.1243803156*t)
	Z2 += 0.00000000003*np.cos(3.50771998464 + 78.7137518304*t)
	Z2 += 0.00000000002*np.cos(3.05223400181 + 415.5524906121*t)
	Z2 += 0.00000000002*np.cos(4.55871260975 + 1.4844727083*t)
	Z2 += 0.00000000003*np.cos(1.74563621629 + 277.0349937414*t)
	Z2 += 0.00000000002*np.cos(1.29217914825 + 191.9584544356*t)
	Z2 += 0.00000000002*np.cos(3.65769145122 + 3.1813937377*t)
	Z2 += 0.00000000002*np.cos(6.19154062961 + 551.031606097*t)
	Z2 += 0.00000000002*np.cos(4.90344281834 + 742.9900605326*t)
	Z2 += 0.00000000002*np.cos(4.83054979229 + 519.3960243561*t)
	Z2 += 0.00000000002*np.cos(3.65849721547 + 838.9692877504*t)
	Z2 += 0.00000000002*np.cos(4.97173254231 + 138.5174968707*t)
	Z2 += 0.00000000001*np.cos(4.68187656594 + 77.962992305*t)
	Z2 += 0.00000000001*np.cos(6.09694449819 + 1265.5674786264*t)
	Z2 += 0.00000000002*np.cos(1.32236719420 + 430.5303441391*t)
	Z2 += 0.00000000001*np.cos(4.18707848416 + 1258.4539316256*t)
	Z2 += 0.00000000001*np.cos(5.76690496135 + 539.9859058331*t)
	Z2 += 0.00000000001*np.cos(3.77513962818 + 10.2949407385*t)
	Z2 += 0.00000000001*np.cos(2.77324979146 + 437.6438911399*t)
	Z2 += 0.00000000001*np.cos(3.71383368268 + 71.6002048296*t)
	Z2 += 0.00000000001*np.cos(0.17659043471 + 1062.5633239269*t)
	Z2 += 0.00000000001*np.cos(4.80392096696 + 1692.1656695024*t)
	Z2 += 0.00000000001*np.cos(2.83679481305 + 215.7467759928*t)
	Z2 += 0.00000000001*np.cos(2.14142933440 + 447.9388318784*t)
	Z2 += 0.00000000001*np.cos(4.52180798836 + 231.4583427027*t)
	Z2 += 0.00000000001*np.cos(5.00825132072 + 302.164775655*t)
	Z2 += 0.00000000001*np.cos(1.66736807710 + 846.0828347512*t)
	Z2 += 0.00000000001*np.cos(5.51936807154 + 1485.9801210652*t)
	Z2 += 0.00000000001*np.cos(4.85111818330 + 35.1640902212*t)
	Z2 += 0.00000000001*np.cos(4.96700459105 + 1471.7530270636*t)
	Z2 += 0.00000000001*np.cos(0.61229993124 + 145.6310438715*t)
	Z2 += 0.00000000001*np.cos(3.93844655248 + 210.8514148832*t)
	Z2 += 0.00000000001*np.cos(3.18478454807 + 195.1398481733*t)
	Z2 += 0.00000000001*np.cos(3.85177021783 + 71.8126531507*t)
	Z2 += 0.00000000001*np.cos(5.85402997867 + 18.1592472647*t)
	Z2 += 0.00000000001*np.cos(3.38148739918 + 1898.3512179396*t)
	Z2 += 0.00000000001*np.cos(0.00721267106 + 408.4389436113*t)
	Z2 += 0.00000000000*np.cos(1.08851543423 + 41.1019810544*t)
	Z2 += 0.00000000001*np.cos(3.22453393143 + 831.8557407496*t)
	return Z2*t*t




def Sun_Z3 (t): # 61 terms of order 3

	Z3 = 0.
	Z3 += 0.00000001302*np.cos(4.84806136860 + 213.299095438*t)
	Z3 += 0.00000001364*np.cos(2.43564490971 + 206.1855484372*t)
	Z3 += 0.00000000920*np.cos(1.65069146673 + 529.6909650946*t)
	Z3 -= 0.00000001238
	Z3 += 0.00000000716*np.cos(1.50799790954 + 220.4126424388*t)
	Z3 += 0.00000000423*np.cos(4.54129218357 + 536.8045120954*t)
	Z3 += 0.00000000282*np.cos(5.95440671732 + 522.5774180938*t)
	Z3 += 0.00000000090*np.cos(0.51819099535 + 433.7117378768*t)
	Z3 += 0.00000000094*np.cos(1.55249614896 + 419.4846438752*t)
	Z3 += 0.00000000079*np.cos(1.38892285542 + 227.5261894396*t)
	Z3 += 0.00000000094*np.cos(0.17438010106 + 426.598190876*t)
	Z3 += 0.00000000048*np.cos(3.11903200545 + 1059.3819301892*t)
	Z3 += 0.00000000050*np.cos(2.64433369691 + 199.0720014364*t)
	Z3 += 0.00000000042*np.cos(2.65785543548 + 7.1135470008*t)
	Z3 += 0.00000000028*np.cos(5.89394518040 + 515.463871093*t)
	Z3 += 0.00000000027*np.cos(5.17159300173 + 1066.49547719*t)
	Z3 += 0.00000000024*np.cos(4.43334493389 + 543.9180590962*t)
	Z3 += 0.00000000026*np.cos(5.61220088462 + 639.897286314*t)
	Z3 += 0.00000000018*np.cos(0.02154769101 + 74.7815985673*t)
	Z3 += 0.00000000017*np.cos(2.57902262762 + 14.2270940016*t)
	Z3 += 0.00000000013*np.cos(3.07320748125 + 210.1177017003*t)
	Z3 += 0.00000000012*np.cos(5.68952008926 + 1052.2683831884*t)
	Z3 += 0.00000000011*np.cos(0.06567554803 + 316.3918696566*t)
	Z3 += 0.00000000011*np.cos(5.88691938543 + 647.0108333148*t)
	Z3 += 0.00000000009*np.cos(0.49541679064 + 440.8252848776*t)
	Z3 += 0.00000000007*np.cos(4.01090297903 + 1589.0728952838*t)
	Z3 += 0.00000000008*np.cos(0.88032790118 + 216.4804891757*t)
	Z3 += 0.00000000006*np.cos(6.21088176821 + 38.1330356378*t)
	Z3 += 0.00000000007*np.cos(3.28974856542 + 103.0927742186*t)
	Z3 += 0.00000000004*np.cos(4.75446574078 + 853.196381752*t)
	Z3 += 0.00000000004*np.cos(1.59186789207 + 632.7837393132*t)
	Z3 += 0.00000000004*np.cos(1.52800084237 + 412.3710968744*t)
	Z3 += 0.00000000003*np.cos(2.72859893423 + 217.2312487011*t)
	Z3 += 0.00000000004*np.cos(1.24971088361 + 234.6397364404*t)
	Z3 += 0.00000000004*np.cos(2.23695164343 + 117.3198682202*t)
	Z3 += 0.00000000003*np.cos(5.03266763204 + 1045.1548361876*t)
	Z3 += 0.00000000002*np.cos(1.54692325590 + 95.9792272178*t)
	Z3 += 0.00000000002*np.cos(2.47873978537 + 21.3406410024*t)
	Z3 += 0.00000000002*np.cos(5.89071888876 + 1596.1864422846*t)
	Z3 += 0.00000000001*np.cos(2.39068115930 + 309.2783226558*t)
	Z3 += 0.00000000001*np.cos(4.51750108995 + 110.2063212194*t)
	Z3 += 0.00000000001*np.cos(0.22878957149 + 323.5054166574*t)
	Z3 += 0.00000000001*np.cos(6.15405801099 + 508.3503240922*t)
	Z3 += 0.00000000001*np.cos(2.20057567411 + 202.2533951741*t)
	Z3 += 0.00000000001*np.cos(0.75305469601 + 223.5940361765*t)
	Z3 += 0.00000000001*np.cos(4.90745082069 + 735.8765135318*t)
	Z3 += 0.00000000001*np.cos(5.14951363778 + 1073.6090241908*t)
	Z3 += 0.00000000001*np.cos(2.94450371786 + 191.9584544356*t)
	Z3 += 0.00000000001*np.cos(4.98822441421 + 860.3099287528*t)
	Z3 += 0.00000000001*np.cos(3.42053691338 + 942.062061969*t)
	Z3 += 0.00000000001*np.cos(1.15047179526 + 124.433415221*t)
	Z3 += 0.00000000001*np.cos(6.22510869621 + 429.7795846137*t)
	Z3 += 0.00000000001*np.cos(3.73572524089 + 6283.0758499914*t)
	Z3 += 0.00000000001*np.cos(4.69195154363 + 625.6701923124*t)
	Z3 += 0.00000000001*np.cos(1.51434913816 + 209.3669421749*t)
	Z3 += 0.00000000001*np.cos(5.90568466315 + 654.1243803156*t)
	Z3 += 0.00000000001*np.cos(1.49277395876 + 330.6189636582*t)
	Z3 += 0.00000000001*np.cos(1.47510307007 + 88.865680217*t)
	Z3 += 0.00000000001*np.cos(1.73488850781 + 10213.285546211*t)
	Z3 += 0.00000000001*np.cos(3.84782364103 + 203.0041546995*t)
	Z3 += 0.00000000000*np.cos(1.56743396293 + 224.3447957019*t)
	return Z3*t*t*t




def Sun_Z4 (t): # 26 terms of order 4

	Z4 = 0.
	Z4 += 0.00000000164*np.cos(4.10546661445 + 206.1855484372*t)
	Z4 += 0.00000000072*np.cos(6.04348211714 + 220.4126424388*t)
	Z4 += 0.00000000070*np.cos(6.10651561968 + 213.299095438*t)
	Z4 += 0.00000000044*np.cos(2.79536133222 + 536.8045120954*t)
	Z4 += 0.00000000026*np.cos(1.66128176108 + 522.5774180938*t)
	Z4 += 0.00000000016*np.cos(5.95724279756 + 227.5261894396*t)
	Z4 += 0.00000000011*np.cos(4.33140895473 + 199.0720014364*t)
	Z4 += 0.00000000012*np.cos(5.02489197754 + 433.7117378768*t)
	Z4 += 0.00000000010
	Z4 += 0.00000000008*np.cos(3.36029048603 + 419.4846438752*t)
	Z4 += 0.00000000006*np.cos(1.39462759175 + 515.463871093*t)
	Z4 += 0.00000000005*np.cos(2.67511593664 + 543.9180590962*t)
	Z4 += 0.00000000004*np.cos(4.65054077397 + 529.6909650946*t)
	Z4 += 0.00000000005*np.cos(4.82245392155 + 426.598190876*t)
	Z4 += 0.00000000003*np.cos(0.96348403857 + 7.1135470008*t)
	Z4 += 0.00000000003*np.cos(0.80949781331 + 14.2270940016*t)
	Z4 += 0.00000000003*np.cos(3.63118822382 + 1066.49547719*t)
	Z4 += 0.00000000002*np.cos(3.76452892490 + 639.897286314*t)
	Z4 += 0.00000000002*np.cos(5.03281213584 + 440.8252848776*t)
	Z4 += 0.00000000002*np.cos(4.07799495792 + 647.0108333148*t)
	Z4 += 0.00000000001*np.cos(1.44530794356 + 1059.3819301892*t)
	Z4 += 0.00000000001*np.cos(1.37231576384 + 1052.2683831884*t)
	Z4 += 0.00000000001*np.cos(5.80470544513 + 234.6397364404*t)
	Z4 += 0.00000000001*np.cos(1.63696733565 + 117.3198682202*t)
	Z4 += 0.00000000001*np.cos(3.60628665626 + 853.196381752*t)
	Z4 += 0.00000000000*np.cos(2.65796643505 + 110.2063212194*t)
	return Z4*t*t*t*t




def Sun_Z5 (t): # 9 terms of order 5

	Z5 = 0.
	Z5 += 0.00000000015*np.cos(5.75563126750 + 206.1855484372*t)
	Z5 += 0.00000000005*np.cos(4.29978807671 + 220.4126424388*t)
	Z5 += 0.00000000003*np.cos(0.96254361103 + 536.8045120954*t)
	Z5 += 0.00000000003
	Z5 += 0.00000000002*np.cos(3.96773929080 + 522.5774180938*t)
	Z5 += 0.00000000002*np.cos(4.22112932205 + 227.5261894396*t)
	Z5 += 0.00000000002*np.cos(6.02426931559 + 199.0720014364*t)
	Z5 += 0.00000000001*np.cos(3.19657723128 + 515.463871093*t)
	Z5 += 0.00000000001*np.cos(3.25850463040 + 433.7117378768*t)
	return Z5*t*t*t*t*t




